ratios = {   
    'AA': 0,
    'AAB': 0,
    'AABERG': 0,
    'AABY': 0,
    'AADLAND': 0,
    'AAFEDT': 0,
    'AAGAARD': 0,
    'AAGARD': 0,
    'AAGESEN': 0,
    'AAKER': 0,
    'AAKHUS': 0,
    'AAKRE': 0,
    'AALAND': 0,
    'AALBERS': 0,
    'AALDERINK': 0,
    'AALFS': 0,
    'AALGAARD': 0,
    'AALTO': 0,
    'AAMODT': 0,
    'AAMOLD': 0,
    'AAMOT': 0,
    'AAMOTH': 0,
    'AANDERUD': 0,
    'AANENSON': 0,
    'AANERUD': 0,
    'AANESTAD': 0,
    'AANONSEN': 0,
    'AARDAL': 0,
    'AARDEMA': 0,
    'AARDSMA': 0,
    'AARESTAD': 0,
    'AARHUS': 0,
    'AARON': 0.9776987718164188,
    'AARONS': 0,
    'AARONSON': 0,
    'AARRIS': 0,
    'AARSTAD': 0,
    'AARSVOLD': 0,
    'AARTS': 0,
    'AAS': 0,
    'AASAND': 0,
    'AASE': 0,
    'AASEN': 0,
    'AASHEIM': 0,
    'AASLAND': 0,
    'AASNESS': 0,
    'AB': 0,
    'ABA': 0,
    'ABAD': 0,
    'ABADI': 0,
    'ABADIA': 0,
    'ABADIE': 0,
    'ABADILLA': 0,
    'ABADIR': 0,
    'ABADY': 0,
    'ABAIR': 0,
    'ABAJIAN': 0,
    'ABALO': 0,
    'ABALOS': 0,
    'ABAN': 0,
    'ABANG': 0,
    'ABANO': 0,
    'ABANTO': 0,
    'ABAR': 0,
    'ABARA': 0,
    'ABARBANEL': 0,
    'ABARCA': 0,
    'ABARE': 0,
    'ABARNO': 0,
    'ABARQUEZ': 0,
    'ABARR': 0,
    'ABAS': 0,
    'ABASCAL': 0,
    'ABASOLO': 0,
    'ABASS': 0,
    'ABASSI': 0,
    'ABASTA': 0,
    'ABAT': 0,
    'ABATA': 0,
    'ABATANGELO': 0,
    'ABATE': 0,
    'ABATECOLA': 0,
    'ABATEMARCO': 0,
    'ABATI': 0,
    'ABATO': 0,
    'ABAUNZA': 0,
    'ABAWI': 0,
    'ABAY': 0,
    'ABAYA': 0,
    'ABAYEV': 0,
    'ABAZA': 0,
    'ABB': 0,
    'ABBA': 0,
    'ABBADESSA': 0,
    'ABBAMONTE': 0,
    'ABBAN': 0,
    'ABBARNO': 0,
    'ABBAS': 0,
    'ABBASI': 0,
    'ABBASS': 0,
    'ABBASSI': 0,
    'ABBATE': 0,
    'ABBATEMARCO': 0,
    'ABBATIELLO': 0,
    'ABBATOY': 0,
    'ABBATTISTA': 0,
    'ABBAZIA': 0,
    'ABBE': 0,
    'ABBEN': 0,
    'ABBENANTE': 0,
    'ABBENE': 0,
    'ABBETT': 0,
    'ABBEY': 0.6837606837606838,
    'ABBIE': 1,
    'ABBINANTE': 0,
    'ABBINANTI': 0,
    'ABBINGTON': 0,
    'ABBINK': 0,
    'ABBITT': 0,
    'ABBO': 0,
    'ABBONDANDOLO': 0,
    'ABBONDANZA': 0,
    'ABBONIZIO': 0,
    'ABBOT': 0,
    'ABBOTT': 0,
    'ABBOTTS': 0,
    'ABBOUD': 0,
    'ABBRUSCATO': 0,
    'ABBRUZZESE': 0,
    'ABBRUZZI': 0,
    'ABBS': 0,
    'ABBUHL': 0,
    'ABBY': 0.9919404835709857,
    'ABCEDE': 0,
    'ABDALA': 0,
    'ABDALI': 0,
    'ABDALLA': 0,
    'ABDALLAH': 0,
    'ABDEEN': 0,
    'ABDEL': 0,
    'ABDELAAL': 0,
    'ABDELAZIZ': 0,
    'ABDELFATTAH': 0,
    'ABDELGHANI': 0,
    'ABDELHADI': 0,
    'ABDELHADY': 0,
    'ABDELHALIM': 0,
    'ABDELHAMID': 0,
    'ABDELJABER': 0,
    'ABDELJAWAD': 0,
    'ABDELKADER': 0,
    'ABDELKARIM': 0,
    'ABDELLA': 0,
    'ABDELLATIF': 0,
    'ABDELMALAK': 0,
    'ABDELMALEK': 0,
    'ABDELMESSIH': 0,
    'ABDELNABI': 0,
    'ABDELNOUR': 0,
    'ABDELQADER': 0,
    'ABDELRAHIM': 0,
    'ABDELRAHMAN': 0,
    'ABDELSALAM': 0,
    'ABDELSAYED': 0,
    'ABDELWAHAB': 0,
    'ABDI': 0,
    'ABDILL': 0,
    'ABDIN': 0,
    'ABDIRAHMAN': 0,
    'ABDO': 0,
    'ABDOLLAHI': 0,
    'ABDON': 0,
    'ABDOO': 0,
    'ABDOOL': 0,
    'ABDOU': 0,
    'ABDOW': 0,
    'ABDU': 0,
    'ABDUL': 0.9247027741083222,
    'ABDULA': 0,
    'ABDULAH': 0,
    'ABDULAHAD': 0,
    'ABDULAHI': 0,
    'ABDULAZIZ': 0,
    'ABDULGHANI': 0,
    'ABDULHADI': 0,
    'ABDULHAKIM': 0,
    'ABDULHAMID': 0,
    'ABDULHAQQ': 0,
    'ABDULJABBAR': 0,
    'ABDULKADIR': 0,
    'ABDULKAREEM': 0,
    'ABDULKARIM': 0,
    'ABDULLA': 0,
    'ABDULLAH': 0,
    'ABDULLAHI': 0,
    'ABDULLATIF': 0,
    'ABDULLE': 0,
    'ABDULMALIK': 0,
    'ABDULRAHEEM': 0,
    'ABDULRAHIM': 0,
    'ABDULRAHMAN': 0,
    'ABDURAHMAN': 0,
    'ABDURAKHMANOV': 0,
    'ABDURRAHIM': 0,
    'ABDURRAHMAN': 0,
    'ABDUSSALAAM': 0,
    'ABE': 0.8438818565400843,
    'ABEA': 0,
    'ABEAR': 0,
    'ABEBE': 0,
    'ABECASSIS': 0,
    'ABED': 0,
    'ABEDI': 0,
    'ABEDIN': 0,
    'ABEDRABBO': 0,
    'ABEE': 0,
    'ABEEL': 0,
    'ABEGG': 0,
    'ABEGGLEN': 0,
    'ABEITA': 0,
    'ABEJA': 0,
    'ABEL': 0.7375776397515528,
    'ABELA': 0,
    'ABELAR': 0,
    'ABELARD': 0,
    'ABELARDO': 0,
    'ABELE': 0,
    'ABELEDA': 0,
    'ABELES': 0,
    'ABELING': 0,
    'ABELINO': 0,
    'ABELL': 0,
    'ABELLA': 0,
    'ABELLANA': 0,
    'ABELLAR': 0,
    'ABELLARD': 0,
    'ABELLERA': 0,
    'ABELLI': 0,
    'ABELLO': 0,
    'ABELMAN': 0,
    'ABELN': 0,
    'ABELON': 0,
    'ABELOW': 0,
    'ABELS': 0,
    'ABELSON': 0,
    'ABELY': 0,
    'ABEN': 0,
    'ABENANTE': 0,
    'ABEND': 0,
    'ABENDANO': 0,
    'ABENDROTH': 0,
    'ABENDSCHEIN': 0,
    'ABENE': 0,
    'ABENOJA': 0,
    'ABENOJAR': 0,
    'ABENS': 0,
    'ABER': 0,
    'ABERA': 0,
    'ABERASTURI': 0,
    'ABERCROMBIE': 0,
    'ABERDEEN': 0,
    'ABEREGG': 0,
    'ABERG': 0,
    'ABERGEL': 0,
    'ABERIN': 0,
    'ABERLE': 0,
    'ABERMAN': 0,
    'ABERNATHEY': 0,
    'ABERNATHY': 0,
    'ABERNETHY': 0,
    'ABERRA': 0,
    'ABERS': 0,
    'ABERSOLD': 0,
    'ABERSON': 0,
    'ABERT': 0,
    'ABERTS': 0,
    'ABES': 0,
    'ABESAMIS': 0,
    'ABETE': 0,
    'ABEY': 0,
    'ABEYTA': 0,
    'ABEYTIA': 0,
    'ABFALL': 0,
    'ABFALTER': 0,
    'ABHOLD': 0,
    'ABHYANKAR': 0,
    'ABICHT': 0,
    'ABID': 0,
    'ABIDE': 0,
    'ABIDI': 0,
    'ABIERA': 0,
    'ABIGAIL': 1,
    'ABILA': 0,
    'ABILD': 0,
    'ABILES': 0,
    'ABILEZ': 0,
    'ABINA': 0,
    'ABINADER': 0,
    'ABING': 0,
    'ABINGTON': 0,
    'ABIOLA': 0,
    'ABITBOL': 0,
    'ABITIA': 0,
    'ABITZ': 0,
    'ABIUSO': 0,
    'ABIVA': 0,
    'ABKARIAN': 0,
    'ABKE': 0,
    'ABLA': 0,
    'ABLAN': 0,
    'ABLANG': 0,
    'ABLAO': 0,
    'ABLAZA': 0,
    'ABLE': 0,
    'ABLEIDINGER': 0,
    'ABLEMAN': 0,
    'ABLER': 0,
    'ABLES': 0,
    'ABLETT': 0,
    'ABLIN': 0,
    'ABLING': 0,
    'ABLOG': 0,
    'ABLONDI': 0,
    'ABMA': 0,
    'ABNER': 0,
    'ABNET': 0,
    'ABNEY': 0,
    'ABO': 0,
    'ABOAGYE': 0,
    'ABODEELY': 0,
    'ABOLAFIA': 0,
    'ABOLINS': 0,
    'ABOLT': 0,
    'ABON': 0,
    'ABONCE': 0,
    'ABONZA': 0,
    'ABOOD': 0,
    'ABORDO': 0,
    'ABORN': 0,
    'ABOTT': 0,
    'ABOUD': 0,
    'ABOUJAOUDE': 0,
    'ABOULAFIA': 0,
    'ABOULHOSN': 0,
    'ABOUNADER': 0,
    'ABOUZEID': 0,
    'ABOY': 0,
    'ABOYTES': 0,
    'ABPLANALP': 0,
    'ABRAHA': 0,
    'ABRAHAM': 0.7858105074090705,
    'ABRAHAMIAN': 0,
    'ABRAHAMS': 0,
    'ABRAHAMSEN': 0,
    'ABRAHAMSON': 0,
    'ABRAHAMYAN': 0,
    'ABRAHANTE': 0,
    'ABRAHIM': 0,
    'ABRAHMS': 0,
    'ABRAJAN': 0,
    'ABRAM': 0.7246376811594204,
    'ABRAMCZYK': 0,
    'ABRAMIAN': 0,
    'ABRAMO': 0,
    'ABRAMOFF': 0,
    'ABRAMOV': 0,
    'ABRAMOVA': 0,
    'ABRAMOVICH': 0,
    'ABRAMOVITZ': 0,
    'ABRAMOWICZ': 0,
    'ABRAMOWITZ': 0,
    'ABRAMOWSKI': 0,
    'ABRAMS': 0,
    'ABRAMSKI': 0,
    'ABRAMSKY': 0,
    'ABRAMSON': 0,
    'ABRAMYAN': 0,
    'ABRANTES': 0,
    'ABRAO': 0,
    'ABRECHT': 0,
    'ABREGO': 0,
    'ABRELL': 0,
    'ABRENICA': 0,
    'ABREO': 0,
    'ABRERA': 0,
    'ABRESCH': 0,
    'ABREU': 0,
    'ABREV': 0,
    'ABREW': 0,
    'ABREY': 0,
    'ABRHAM': 0,
    'ABRIAM': 0,
    'ABRICA': 0,
    'ABRIEL': 0,
    'ABRIGO': 0,
    'ABRIL': 0,
    'ABRIOLA': 0,
    'ABRISHAMI': 0,
    'ABRO': 0,
    'ABROM': 0,
    'ABROMAITIS': 0,
    'ABRON': 0,
    'ABRUSCATO': 0,
    'ABRUZZESE': 0,
    'ABRUZZI': 0,
    'ABRUZZINO': 0,
    'ABRUZZO': 0,
    'ABRY': 0,
    'ABSALOM': 0,
    'ABSALON': 0,
    'ABSHEAR': 0,
    'ABSHER': 0,
    'ABSHERE': 0,
    'ABSHIER': 0,
    'ABSHIRE': 0,
    'ABSON': 0,
    'ABSTEN': 0,
    'ABSTON': 0,
    'ABT': 0,
    'ABTAHI': 0,
    'ABTS': 0,
    'ABU': 0,
    'ABUALI': 0,
    'ABUAN': 0,
    'ABUBAKAR': 0,
    'ABUBAKER': 0,
    'ABUD': 0,
    'ABUEG': 0,
    'ABUEL': 0,
    'ABUELHAWA': 0,
    'ABUGHANNAM': 0,
    'ABUGHAZALEH': 0,
    'ABUHAMDEH': 0,
    'ABUKAR': 0,
    'ABULENCIA': 0,
    'ABUNDES': 0,
    'ABUNDEZ': 0,
    'ABUNDIS': 0,
    'ABUNDIZ': 0,
    'ABUNDO': 0,
    'ABURTO': 0,
    'ABUSHANAB': 0,
    'ABUT': 0,
    'ABUTIN': 0,
    'ABUZAID': 0,
    'ABY': 0,
    'ACA': 0,
    'ACACIO': 0,
    'ACADEMIA': 0,
    'ACAIN': 0,
    'ACAMPORA': 0,
    'ACANFORA': 0,
    'ACAR': 0,
    'ACASIO': 0,
    'ACAYAN': 0,
    'ACCARDI': 0,
    'ACCARDO': 0,
    'ACCETTA': 0,
    'ACCETTURA': 0,
    'ACCETTURO': 0,
    'ACCHIONE': 0,
    'ACCIARDO': 0,
    'ACCIARI': 0,
    'ACCIAVATTI': 0,
    'ACCIME': 0,
    'ACCIUS': 0,
    'ACCOLA': 0,
    'ACCOMANDO': 0,
    'ACCORD': 0,
    'ACCORDINO': 0,
    'ACCORNERO': 0,
    'ACCORSI': 0,
    'ACCURSO': 0,
    'ACE': 0,
    'ACEBAL': 0,
    'ACEBEDO': 0,
    'ACEBO': 0,
    'ACEDO': 0,
    'ACEE': 0,
    'ACEITUNO': 0,
    'ACELLO': 0,
    'ACENCIO': 0,
    'ACER': 0,
    'ACERET': 0,
    'ACERO': 0,
    'ACERRA': 0,
    'ACETI': 0,
    'ACETO': 0,
    'ACEUEDO': 0,
    'ACEVADO': 0,
    'ACEVEDO': 0,
    'ACEVES': 0,
    'ACEVEZ': 0,
    'ACEY': 0,
    'ACFALLE': 0,
    'ACH': 0,
    'ACHA': 0,
    'ACHACOSO': 0,
    'ACHAN': 0,
    'ACHARYA': 0,
    'ACHATZ': 0,
    'ACHBERGER': 0,
    'ACHE': 0,
    'ACHEAMPONG': 0,
    'ACHEE': 0,
    'ACHELPOHL': 0,
    'ACHEN': 0,
    'ACHENBACH': 0,
    'ACHER': 0,
    'ACHESON': 0,
    'ACHEY': 0,
    'ACHILLE': 0,
    'ACHILLES': 0,
    'ACHILLI': 0,
    'ACHIM': 0,
    'ACHIN': 0,
    'ACHKAR': 0,
    'ACHMAN': 0,
    'ACHO': 0,
    'ACHONG': 0,
    'ACHOR': 0,
    'ACHORD': 0,
    'ACHORN': 0,
    'ACHS': 0,
    'ACHTEN': 0,
    'ACHTENBERG': 0,
    'ACHTER': 0,
    'ACHTERBERG': 0,
    'ACHTERHOF': 0,
    'ACHUFF': 0,
    'ACHZIGER': 0,
    'ACIDERA': 0,
    'ACIERNO': 0,
    'ACIERTO': 0,
    'ACIO': 0,
    'ACITELLI': 0,
    'ACITO': 0,
    'ACKAH': 0,
    'ACKEL': 0,
    'ACKELS': 0,
    'ACKELSON': 0,
    'ACKEN': 0,
    'ACKER': 0,
    'ACKERBERG': 0,
    'ACKERET': 0,
    'ACKERKNECHT': 0,
    'ACKERLAND': 0,
    'ACKERLEY': 0,
    'ACKERLY': 0,
    'ACKERMAN': 0,
    'ACKERMANN': 0,
    'ACKERS': 0,
    'ACKERSON': 0,
    'ACKERT': 0,
    'ACKEY': 0,
    'ACKINS': 0,
    'ACKISON': 0,
    'ACKISS': 0,
    'ACKLAND': 0,
    'ACKLEN': 0,
    'ACKLER': 0,
    'ACKLES': 0,
    'ACKLEY': 0,
    'ACKLIN': 0,
    'ACKMAN': 0,
    'ACKMANN': 0,
    'ACKROYD': 0,
    'ACKS': 0,
    'ACLAN': 0,
    'ACOB': 0,
    'ACOBA': 0,
    'ACOCELLA': 0,
    'ACOCK': 0,
    'ACOFF': 0,
    'ACOMB': 0,
    'ACON': 0,
    'ACOR': 0,
    'ACORD': 0,
    'ACORDA': 0,
    'ACORN': 0,
    'ACORS': 0,
    'ACOSTA': 0,
    'ACOTT': 0,
    'ACOX': 0,
    'ACQUAFREDDA': 0,
    'ACQUAH': 0,
    'ACQUARD': 0,
    'ACQUAVELLA': 0,
    'ACQUAVIVA': 0,
    'ACQUAYE': 0,
    'ACQUILANO': 0,
    'ACQUISTA': 0,
    'ACQUISTAPACE': 0,
    'ACQUISTO': 0,
    'ACRA': 0,
    'ACRE': 0,
    'ACREE': 0,
    'ACREMAN': 0,
    'ACRES': 0,
    'ACREY': 0,
    'ACRI': 0,
    'ACS': 0,
    'ACTIS': 0,
    'ACTKINSON': 0,
    'ACTON': 0,
    'ACUFF': 0,
    'ACUNA': 0,
    'ACUNTO': 0,
    'ACUP': 0,
    'ACY': 0,
    'ADA': 0.9977244880098023,
    'ADACHI': 0,
    'ADAH': 1,
    'ADAIR': 0,
    'ADAJAR': 0,
    'ADAKAI': 0,
    'ADALBERTO': 1,
    'ADALINE': 1,
    'ADAM': 0.9828752882470798,
    'ADAMA': 0,
    'ADAMAITIS': 0,
    'ADAMANY': 0,
    'ADAMCHAK': 0,
    'ADAMCHICK': 0,
    'ADAMCIK': 0,
    'ADAMCZAK': 0,
    'ADAMCZYK': 0,
    'ADAME': 0,
    'ADAMEC': 0,
    'ADAMEK': 0,
    'ADAMES': 0,
    'ADAMETZ': 0,
    'ADAMEZ': 0,
    'ADAMI': 0,
    'ADAMIAK': 0,
    'ADAMIAN': 0,
    'ADAMIC': 0,
    'ADAMICH': 0,
    'ADAMICK': 0,
    'ADAMIEC': 0,
    'ADAMIETZ': 0,
    'ADAMIK': 0,
    'ADAMITIS': 0,
    'ADAMKIEWICZ': 0,
    'ADAMO': 0,
    'ADAMONIS': 0,
    'ADAMOPOULOS': 0,
    'ADAMOS': 0,
    'ADAMOV': 0,
    'ADAMOVICH': 0,
    'ADAMOWICZ': 0,
    'ADAMOWSKI': 0,
    'ADAMS': 0,
    'ADAMSEN': 0,
    'ADAMSKI': 0,
    'ADAMSKY': 0,
    'ADAMSON': 0,
    'ADAMU': 0,
    'ADAMUS': 0,
    'ADAMY': 0,
    'ADAMYAN': 0,
    'ADAN': 0.8958566629339306,
    'ADANK': 0,
    'ADANS': 0,
    'ADAO': 0,
    'ADAR': 0,
    'ADAS': 0,
    'ADATO': 0,
    'ADAUTO': 0,
    'ADAWAY': 0,
    'ADAY': 0,
    'ADAYA': 0,
    'ADCOCK': 0,
    'ADCOX': 0,
    'ADDABBO': 0,
    'ADDAE': 0,
    'ADDAI': 0,
    'ADDAIR': 0,
    'ADDAMO': 0,
    'ADDAMS': 0,
    'ADDANTE': 0,
    'ADDARIO': 0,
    'ADDEN': 0,
    'ADDEO': 0,
    'ADDERLEY': 0,
    'ADDERLY': 0,
    'ADDERSON': 0,
    'ADDESA': 0,
    'ADDESSI': 0,
    'ADDESSO': 0,
    'ADDI': 0,
    'ADDICKS': 0,
    'ADDICOTT': 0,
    'ADDIE': 0.9900990099009901,
    'ADDIEGO': 0,
    'ADDINGTON': 0,
    'ADDIS': 0,
    'ADDISON': 0,
    'ADDLEMAN': 0,
    'ADDLER': 0,
    'ADDLEY': 0,
    'ADDO': 0,
    'ADDONA': 0,
    'ADDONIZIO': 0,
    'ADDOTTA': 0,
    'ADDUCCI': 0,
    'ADDUCI': 0,
    'ADDY': 0,
    'ADE': 0,
    'ADEBAYO': 0,
    'ADEBIYI': 0,
    'ADEDEJI': 0,
    'ADEE': 0,
    'ADEGOKE': 0,
    'ADEKOYA': 0,
    'ADEKUNLE': 0,
    'ADEL': 0,
    'ADELA': 1,
    'ADELAIDA': 1,
    'ADELAIDE': 1,
    'ADELBERG': 0,
    'ADELE': 1,
    'ADELEKE': 0,
    'ADELEYE': 0,
    'ADELHARDT': 0,
    'ADELIA': 1,
    'ADELINA': 1,
    'ADELINE': 1,
    'ADELIZZI': 0,
    'ADELL': 0.9505703422053231,
    'ADELLA': 1,
    'ADELLE': 1,
    'ADELMAN': 0,
    'ADELMANN': 0,
    'ADELMEYER': 0,
    'ADELMUND': 0,
    'ADELS': 0,
    'ADELSBERG': 0,
    'ADELSBERGER': 0,
    'ADELSON': 0,
    'ADELSPERGER': 0,
    'ADELSTEIN': 0,
    'ADEM': 0,
    'ADEMA': 0,
    'ADEMI': 0,
    'ADEN': 0,
    'ADENA': 1,
    'ADENIJI': 0,
    'ADENIRAN': 0,
    'ADENIYI': 0,
    'ADENT': 0,
    'ADEOYE': 0,
    'ADEPOJU': 0,
    'ADER': 0,
    'ADERHOLD': 0,
    'ADERHOLDT': 0,
    'ADERHOLT': 0,
    'ADERMAN': 0,
    'ADERMANN': 0,
    'ADERS': 0,
    'ADERSON': 0,
    'ADES': 0,
    'ADESANYA': 0,
    'ADESINA': 0,
    'ADESSA': 0,
    'ADESSO': 0,
    'ADETUNJI': 0,
    'ADEWALE': 0,
    'ADEWOLE': 0,
    'ADEWUMI': 0,
    'ADEWUNMI': 0,
    'ADEY': 0,
    'ADEYEMI': 0,
    'ADEYEMO': 0,
    'ADEYEYE': 0,
    'ADEYINKA': 0,
    'ADGATE': 0,
    'ADGER': 0,
    'ADGERSON': 0,
    'ADHAM': 0,
    'ADHAMI': 0,
    'ADHIKARI': 0,
    'ADI': 0,
    'ADIB': 0,
    'ADIBI': 0,
    'ADICKES': 0,
    'ADIE': 0,
    'ADIGUN': 0,
    'ADIL': 0,
    'ADILI': 0,
    'ADIN': 0,
    'ADINA': 1,
    'ADINOLFI': 0,
    'ADIPIETRO': 0,
    'ADIS': 0,
    'ADISON': 0,
    'ADIX': 0,
    'ADJEI': 0,
    'ADJEMIAN': 0,
    'ADJUTANT': 0,
    'ADKERSON': 0,
    'ADKIN': 0,
    'ADKINS': 0,
    'ADKINSON': 0,
    'ADKISON': 0,
    'ADKISSON': 0,
    'ADLAM': 0,
    'ADLAWAN': 0,
    'ADLE': 0,
    'ADLEMAN': 0,
    'ADLER': 0,
    'ADLEY': 0,
    'ADLINGTON': 0,
    'ADMAS': 0,
    'ADMIRE': 0,
    'ADNAN': 0,
    'ADNER': 0,
    'ADNEY': 0,
    'ADOLF': 0,
    'ADOLFO': 0.9929078014184397,
    'ADOLFSON': 0,
    'ADOLPH': 0.9409751924721984,
    'ADOLPHE': 0,
    'ADOLPHSEN': 0,
    'ADOLPHSON': 0,
    'ADOLPHUS': 0,
    'ADOM': 0,
    'ADOMAITIS': 0,
    'ADOMAKO': 0,
    'ADON': 0,
    'ADONA': 0,
    'ADONIS': 0,
    'ADORE': 0,
    'ADORJAN': 0,
    'ADORNATO': 0,
    'ADORNETTO': 0,
    'ADORNO': 0,
    'ADRAGNA': 0,
    'ADREON': 0,
    'ADRIA': 1,
    'ADRIAN': 0.9757317988491369,
    'ADRIANA': 1,
    'ADRIANCE': 0,
    'ADRIANE': 1,
    'ADRIANI': 0,
    'ADRIANNA': 1,
    'ADRIANNE': 1,
    'ADRIANO': 0,
    'ADRIANSE': 0,
    'ADRIANSON': 0,
    'ADRIANZEN': 0,
    'ADRIATICO': 0,
    'ADRIEN': 0.8695652173913043,
    'ADRIENE': 1,
    'ADRIENNE': 1,
    'ADRION': 0,
    'ADROVER': 0,
    'ADSIDE': 0,
    'ADSIT': 0,
    'ADSITT': 0,
    'ADSON': 0,
    'ADU': 0,
    'ADUBATO': 0,
    'ADUDDELL': 0,
    'ADUNA': 0,
    'ADUSEI': 0,
    'ADUSUMILLI': 0,
    'ADVANI': 0,
    'ADVIENTO': 0,
    'ADVINCULA': 0,
    'ADWELL': 0,
    'ADY': 0,
    'ADZIMA': 0,
    'AEBERSOLD': 0,
    'AEBI': 0,
    'AEBISCHER': 0,
    'AEBLY': 0,
    'AEBY': 0,
    'AEDO': 0,
    'AEGERTER': 0,
    'AEH': 0,
    'AEILTS': 0,
    'AELING': 0,
    'AEMISEGGER': 0,
    'AEMMER': 0,
    'AEPPLI': 0,
    'AERNI': 0,
    'AERTS': 0,
    'AERY': 0,
    'AESCHBACHER': 0,
    'AESCHLEMAN': 0,
    'AESCHLIMAN': 0,
    'AESCHLIMANN': 0,
    'AESOPH': 0,
    'AFABLE': 0,
    'AFALAVA': 0,
    'AFANADOR': 0,
    'AFDAHL': 0,
    'AFEWORK': 0,
    'AFFATATO': 0,
    'AFFELD': 0,
    'AFFELDT': 0,
    'AFFHOLTER': 0,
    'AFFINITO': 0,
    'AFFLECK': 0,
    'AFFLERBACH': 0,
    'AFFLICK': 0,
    'AFFLITTO': 0,
    'AFFOLDER': 0,
    'AFFOLTER': 0,
    'AFFONSO': 0,
    'AFFRONTI': 0,
    'AFFRUNTI': 0,
    'AFFUL': 0,
    'AFFUSO': 0,
    'AFGHANI': 0,
    'AFIF': 0,
    'AFIFI': 0,
    'AFLAGUE': 0,
    'AFLLEJE': 0,
    'AFMAN': 0,
    'AFOA': 0,
    'AFOLABI': 0,
    'AFONG': 0,
    'AFONIN': 0,
    'AFONSO': 0,
    'AFRAM': 0,
    'AFRASIABI': 0,
    'AFRE': 0,
    'AFRICA': 0,
    'AFRICANO': 0,
    'AFRIDI': 0,
    'AFRIYIE': 0,
    'AFSAR': 0,
    'AFSHAR': 0,
    'AFSHARI': 0,
    'AFTAB': 0,
    'AFTANAS': 0,
    'AFTON': 0.970873786407767,
    'AFU': 0,
    'AFZAL': 0,
    'AFZALI': 0,
    'AGA': 0,
    'AGADO': 0,
    'AGAG': 0,
    'AGAHI': 0,
    'AGAJANIAN': 0,
    'AGAN': 0,
    'AGANON': 0,
    'AGANS': 0,
    'AGAPAY': 0,
    'AGAPITO': 0,
    'AGAR': 0,
    'AGARAN': 0,
    'AGARD': 0,
    'AGARWAL': 0,
    'AGARWALA': 0,
    'AGAS': 0,
    'AGATE': 0,
    'AGATEP': 0,
    'AGATHA': 1,
    'AGATI': 0,
    'AGATON': 0,
    'AGAZARYAN': 0,
    'AGAZZI': 0,
    'AGBAY': 0,
    'AGBAYANI': 0,
    'AGBO': 0,
    'AGBOOLA': 0,
    'AGBULOS': 0,
    'AGBUNAG': 0,
    'AGCAOILI': 0,
    'AGDEPPA': 0,
    'AGE': 0,
    'AGEE': 0,
    'AGEL': 0,
    'AGEMA': 0,
    'AGEN': 0,
    'AGENA': 0,
    'AGENBROAD': 0,
    'AGENOR': 0,
    'AGENS': 0,
    'AGENT': 0,
    'AGER': 0,
    'AGERS': 0,
    'AGERTER': 0,
    'AGERTON': 0,
    'AGEY': 0,
    'AGGARWAL': 0,
    'AGGAS': 0,
    'AGGELER': 0,
    'AGGEN': 0,
    'AGGER': 0,
    'AGGERS': 0,
    'AGGISON': 0,
    'AGGOTT': 0,
    'AGGREY': 0,
    'AGHA': 0,
    'AGHAJANI': 0,
    'AGHAJANIAN': 0,
    'AGHASSI': 0,
    'AGHAZARIAN': 0,
    'AGHILI': 0,
    'AGI': 0,
    'AGIC': 0,
    'AGILERA': 0,
    'AGIN': 0,
    'AGINS': 0,
    'AGIRRE': 0,
    'AGIUS': 0,
    'AGLE': 0,
    'AGLER': 0,
    'AGLIAM': 0,
    'AGLIANO': 0,
    'AGLIATA': 0,
    'AGLIETTI': 0,
    'AGLIO': 0,
    'AGLIPAY': 0,
    'AGMATA': 0,
    'AGNANT': 0,
    'AGNE': 0,
    'AGNELLI': 0,
    'AGNELLO': 0,
    'AGNER': 0,
    'AGNES': 0.9971509971509971,
    'AGNESE': 0,
    'AGNESS': 0,
    'AGNETA': 0,
    'AGNEW': 0,
    'AGNEY': 0,
    'AGNIHOTRI': 0,
    'AGNITSCH': 0,
    'AGNO': 0,
    'AGNOLI': 0,
    'AGNONE': 0,
    'AGNOR': 0,
    'AGNOS': 0,
    'AGNUS': 1,
    'AGO': 0,
    'AGOGLIA': 0,
    'AGOLLI': 0,
    'AGONCILLO': 0,
    'AGONEY': 0,
    'AGONOY': 0,
    'AGOPIAN': 0,
    'AGOR': 0,
    'AGOSTA': 0,
    'AGOSTI': 0,
    'AGOSTINE': 0,
    'AGOSTINELLI': 0,
    'AGOSTINHO': 0,
    'AGOSTINI': 0,
    'AGOSTINO': 0,
    'AGOSTO': 0,
    'AGOSTON': 0,
    'AGOVINO': 0,
    'AGPAOA': 0,
    'AGPOON': 0,
    'AGRA': 0,
    'AGRAMONTE': 0,
    'AGRANOFF': 0,
    'AGRAS': 0,
    'AGRAWAL': 0,
    'AGRAZ': 0,
    'AGRE': 0,
    'AGREDA': 0,
    'AGREDANO': 0,
    'AGRELLA': 0,
    'AGREN': 0,
    'AGRES': 0,
    'AGRESS': 0,
    'AGRESTA': 0,
    'AGRESTI': 0,
    'AGRESTO': 0,
    'AGRI': 0,
    'AGRICOLA': 0,
    'AGRIESTI': 0,
    'AGRILLO': 0,
    'AGRIMSON': 0,
    'AGRIPINA': 1,
    'AGRO': 0,
    'AGRON': 0,
    'AGRONT': 0,
    'AGRUSA': 0,
    'AGTARAP': 0,
    'AGU': 0,
    'AGUADA': 0,
    'AGUADO': 0,
    'AGUALLO': 0,
    'AGUANNO': 0,
    'AGUAS': 0,
    'AGUASVIVAS': 0,
    'AGUAYO': 0,
    'AGUDA': 0,
    'AGUDELO': 0,
    'AGUDO': 0,
    'AGUE': 0,
    'AGUEDA': 0.9259259259259258,
    'AGUELAR': 0,
    'AGUERO': 0,
    'AGUEROS': 0,
    'AGUERRE': 0,
    'AGUGLIA': 0,
    'AGUGLIARO': 0,
    'AGUIAR': 0,
    'AGUIGUI': 0,
    'AGUILA': 0,
    'AGUILAR': 0,
    'AGUILER': 0,
    'AGUILERA': 0,
    'AGUILLAR': 0,
    'AGUILLARD': 0,
    'AGUILLERA': 0,
    'AGUILLON': 0,
    'AGUILO': 0,
    'AGUILUZ': 0,
    'AGUINA': 0,
    'AGUINAGA': 0,
    'AGUINALDO': 0,
    'AGUINIGA': 0,
    'AGUINO': 0,
    'AGUIRRE': 0,
    'AGUIRRES': 0,
    'AGULLAR': 0,
    'AGUNDEZ': 0,
    'AGUNDIS': 0,
    'AGUNDIZ': 0,
    'AGUON': 0,
    'AGURCIA': 0,
    'AGURKIS': 0,
    'AGURRE': 0,
    'AGURS': 0,
    'AGURTO': 0,
    'AGUS': 0,
    'AGUSTA': 0,
    'AGUSTI': 0,
    'AGUSTIN': 0.9101941747572815,
    'AGUSTINA': 1,
    'AGUSTINE': 0,
    'AGUSTO': 0,
    'AGWU': 0,
    'AGY': 0,
    'AGYAPONG': 0,
    'AGYEI': 0,
    'AGYEKUM': 0,
    'AGYEMAN': 0,
    'AGYEMANG': 0,
    'AH': 0,
    'AHAD': 0,
    'AHADI': 0,
    'AHALT': 0,
    'AHAMAD': 0,
    'AHAMED': 0,
    'AHARON': 0,
    'AHARONI': 0,
    'AHARONIAN': 0,
    'AHART': 0,
    'AHASTEEN': 0,
    'AHAUS': 0,
    'AHDOOT': 0,
    'AHEARN': 0,
    'AHEARNE': 0,
    'AHEDO': 0,
    'AHEE': 0,
    'AHERN': 0,
    'AHERNE': 0,
    'AHERNS': 0,
    'AHIA': 0,
    'AHINA': 0,
    'AHIR': 0,
    'AHL': 0,
    'AHLBERG': 0,
    'AHLBORN': 0,
    'AHLBRAND': 0,
    'AHLBRANDT': 0,
    'AHLBRECHT': 0,
    'AHLE': 0,
    'AHLEFELD': 0,
    'AHLEMEYER': 0,
    'AHLEN': 0,
    'AHLER': 0,
    'AHLERS': 0,
    'AHLERSMEYER': 0,
    'AHLERT': 0,
    'AHLES': 0,
    'AHLF': 0,
    'AHLFELD': 0,
    'AHLFIELD': 0,
    'AHLGREN': 0,
    'AHLGRIM': 0,
    'AHLHEIM': 0,
    'AHLIN': 0,
    'AHLM': 0,
    'AHLMAN': 0,
    'AHLO': 0,
    'AHLQUIST': 0,
    'AHLRICH': 0,
    'AHLRICHS': 0,
    'AHLSCHLAGER': 0,
    'AHLSTEDT': 0,
    'AHLSTRAND': 0,
    'AHLSTROM': 0,
    'AHLSWEDE': 0,
    'AHLUM': 0,
    'AHLUWALIA': 0,
    'AHLVERS': 0,
    'AHMAD': 0.5870841487279844,
    'AHMADI': 0,
    'AHMADIAN': 0,
    'AHMADY': 0,
    'AHMADZAI': 0,
    'AHMANN': 0,
    'AHMED': 0.3364737550471063,
    'AHMER': 0,
    'AHMETAJ': 0,
    'AHMETI': 0,
    'AHMETOVIC': 0,
    'AHN': 0,
    'AHNE': 0,
    'AHNEE': 0,
    'AHNEN': 0,
    'AHNER': 0,
    'AHNERT': 0,
    'AHO': 0,
    'AHOLA': 0,
    'AHOLELEI': 0,
    'AHOLT': 0,
    'AHONEN': 0,
    'AHQUIN': 0,
    'AHR': 0,
    'AHREND': 0,
    'AHRENDSEN': 0,
    'AHRENDT': 0,
    'AHRENHOLTZ': 0,
    'AHRENHOLZ': 0,
    'AHRENS': 0,
    'AHRENT': 0,
    'AHRING': 0,
    'AHRNDT': 0,
    'AHRNS': 0,
    'AHSAM': 0,
    'AHSAN': 0,
    'AHSING': 0,
    'AHUJA': 0,
    'AHUMADA': 0,
    'AHUNA': 0,
    'AI': 0.8928571428571428,
    'AICH': 0,
    'AICHELE': 0,
    'AICHER': 0,
    'AICHINGER': 0,
    'AID': 0,
    'AIDA': 0.9978308026030368,
    'AIDALA': 0,
    'AIDE': 0.9009009009009009,
    'AIDOO': 0,
    'AIELLO': 0,
    'AIGNER': 0,
    'AIHARA': 0,
    'AIKEN': 0,
    'AIKENS': 0,
    'AIKEY': 0,
    'AIKIN': 0,
    'AIKINS': 0,
    'AIKMAN': 0,
    'AIKO': 1,
    'AILEEN': 1,
    'AILENE': 1,
    'AILES': 0,
    'AILEY': 0,
    'AILIFF': 0,
    'AILL': 0,
    'AILLS': 0,
    'AILOR': 0,
    'AILPORT': 0,
    'AILSHIE': 0,
    'AILSTOCK': 0,
    'AILSWORTH': 0,
    'AILTS': 0,
    'AIM': 0,
    'AIMAN': 0,
    'AIMAR': 0,
    'AIME': 0,
    'AIMEE': 1,
    'AIMES': 0,
    'AIMONE': 0,
    'AIMS': 0,
    'AIN': 0,
    'AINA': 0,
    'AINBINDER': 0,
    'AINES': 0,
    'AINGE': 0,
    'AINGER': 0,
    'AINLEY': 0,
    'AINSCOUGH': 0,
    'AINSLEY': 0,
    'AINSLIE': 0,
    'AINSWORTH': 0,
    'AIONA': 0,
    'AIONO': 0,
    'AIOSA': 0,
    'AIPPERSPACH': 0,
    'AIRD': 0,
    'AIRES': 0,
    'AIREY': 0,
    'AIRGOOD': 0,
    'AIRHART': 0,
    'AIRHEART': 0,
    'AIRINGTON': 0,
    'AIRO': 0,
    'AIROLA': 0,
    'AIROLDI': 0,
    'AIRTH': 0,
    'AIRY': 0,
    'AISENBERG': 0,
    'AISENBREY': 0,
    'AISHA': 1,
    'AISPURO': 0,
    'AISTROP': 0,
    'AITA': 0,
    'AITCHESON': 0,
    'AITCHISON': 0,
    'AITES': 0,
    'AITKEN': 0,
    'AITKENS': 0,
    'AITKIN': 0,
    'AITON': 0,
    'AIU': 0,
    'AIUTO': 0,
    'AIVAZIAN': 0,
    'AIWOHI': 0,
    'AIZAWA': 0,
    'AJA': 0.9463722397476342,
    'AJAJ': 0,
    'AJALA': 0,
    'AJAMI': 0,
    'AJAMIAN': 0,
    'AJANEL': 0,
    'AJANI': 0,
    'AJAO': 0,
    'AJAX': 0,
    'AJAYI': 0,
    'AJDARI': 0,
    'AJELLO': 0,
    'AJEMIAN': 0,
    'AJERO': 0,
    'AJIBOLA': 0,
    'AJIFU': 0,
    'AJLOUNY': 0,
    'AJLUNI': 0,
    'AJMERA': 0,
    'AJMERI': 0,
    'AKA': 0,
    'AKAGI': 0,
    'AKAHOSHI': 0,
    'AKAI': 0,
    'AKAKA': 0,
    'AKAM': 0,
    'AKAMATSU': 0,
    'AKAMINE': 0,
    'AKANA': 0,
    'AKANBI': 0,
    'AKANDE': 0,
    'AKAO': 0,
    'AKAR': 0,
    'AKARD': 0,
    'AKASHI': 0,
    'AKAU': 0,
    'AKAZAWA': 0,
    'AKBAR': 0,
    'AKBARI': 0,
    'AKE': 0,
    'AKEE': 0,
    'AKEHURST': 0,
    'AKEL': 0,
    'AKELEY': 0,
    'AKELLA': 0,
    'AKEMAN': 0,
    'AKEMANN': 0,
    'AKEMON': 0,
    'AKEN': 0,
    'AKENS': 0,
    'AKEO': 0,
    'AKER': 0,
    'AKERBERG': 0,
    'AKERLEY': 0,
    'AKERLUND': 0,
    'AKERLY': 0,
    'AKERMAN': 0,
    'AKEROYD': 0,
    'AKERS': 0,
    'AKERSON': 0,
    'AKERSTROM': 0,
    'AKERY': 0,
    'AKES': 0,
    'AKESON': 0,
    'AKESSON': 0,
    'AKEY': 0,
    'AKHAVAN': 0,
    'AKHTAR': 0,
    'AKHTER': 0,
    'AKI': 0,
    'AKIBA': 0,
    'AKIKO': 1,
    'AKIL': 0,
    'AKILAH': 1,
    'AKILOV': 0,
    'AKIMOTO': 0,
    'AKIN': 0,
    'AKINA': 0,
    'AKINDELE': 0,
    'AKINES': 0,
    'AKINOLA': 0,
    'AKINS': 0,
    'AKINSANYA': 0,
    'AKINWANDE': 0,
    'AKINYEMI': 0,
    'AKIONA': 0,
    'AKITA': 0,
    'AKIU': 0,
    'AKIYAMA': 0,
    'AKIYOSHI': 0,
    'AKKAYA': 0,
    'AKKERMAN': 0,
    'AKL': 0,
    'AKLES': 0,
    'AKLEY': 0,
    'AKMAL': 0,
    'AKMAN': 0,
    'AKO': 0,
    'AKOPIAN': 0,
    'AKOPOV': 0,
    'AKOPYAN': 0,
    'AKOTO': 0,
    'AKPAN': 0,
    'AKRAM': 0,
    'AKRAWI': 0,
    'AKRE': 0,
    'AKRIDGE': 0,
    'AKRIGHT': 0,
    'AKROUSH': 0,
    'AKSAMIT': 0,
    'AKSELROD': 0,
    'AKSOY': 0,
    'AKSU': 0,
    'AKTAR': 0,
    'AKTER': 0,
    'AKTHER': 0,
    'AKUI': 0,
    'AKULA': 0,
    'AKUNA': 0,
    'AKUTAGAWA': 0,
    'AL': 0.9922346850733391,
    'ALA': 0,
    'ALABAUGH': 0,
    'ALABED': 0,
    'ALABI': 0,
    'ALABRAN': 0,
    'ALABRE': 0,
    'ALADE': 0,
    'ALADIN': 0,
    'ALAFA': 0,
    'ALAFFA': 0,
    'ALAGIC': 0,
    'ALAGNA': 0,
    'ALAGO': 0,
    'ALAHMAD': 0,
    'ALAI': 0,
    'ALAIMO': 0,
    'ALAIN': 0,
    'ALAINA': 1,
    'ALAINE': 1,
    'ALALI': 0,
    'ALAM': 0,
    'ALAMA': 0,
    'ALAMAN': 0,
    'ALAMBAR': 0,
    'ALAMEDA': 0,
    'ALAMEIDA': 0,
    'ALAMERI': 0,
    'ALAMGIR': 0,
    'ALAMI': 0,
    'ALAMIA': 0,
    'ALAMILLA': 0,
    'ALAMILLO': 0,
    'ALAMIN': 0,
    'ALAMO': 0,
    'ALAMOS': 0,
    'ALAMPI': 0,
    'ALAN': 0.997506234413965,
    'ALANA': 0.9917355371900827,
    'ALAND': 0,
    'ALANDER': 0,
    'ALANDT': 0,
    'ALANE': 1,
    'ALANI': 0,
    'ALANIS': 0,
    'ALANIZ': 0,
    'ALANNA': 1,
    'ALANO': 0,
    'ALANZO': 0,
    'ALAO': 0,
    'ALAOUI': 0,
    'ALAPAI': 0,
    'ALAPATI': 0,
    'ALAQUINEZ': 0,
    'ALAR': 0,
    'ALARCON': 0,
    'ALARDIN': 0,
    'ALARI': 0,
    'ALARID': 0,
    'ALARIE': 0,
    'ALARIO': 0,
    'ALAS': 0,
    'ALASPA': 0,
    'ALATALO': 0,
    'ALATI': 0,
    'ALATORRE': 0,
    'ALATRISTE': 0,
    'ALATTAR': 0,
    'ALAVA': 0,
    'ALAVERDYAN': 0,
    'ALAVEZ': 0,
    'ALAVI': 0,
    'ALAWAR': 0,
    'ALAWI': 0,
    'ALAY': 0,
    'ALAYA': 0,
    'ALAYNA': 1,
    'ALAYON': 0,
    'ALB': 0,
    'ALBA': 0.7109004739336493,
    'ALBACH': 0,
    'ALBAIR': 0,
    'ALBAKRI': 0,
    'ALBALA': 0,
    'ALBALADEJO': 0,
    'ALBAN': 0,
    'ALBANES': 0,
    'ALBANESE': 0,
    'ALBANESI': 0,
    'ALBANEZ': 0,
    'ALBANI': 0,
    'ALBANNA': 0,
    'ALBANO': 0,
    'ALBANY': 0,
    'ALBARADO': 0,
    'ALBARAN': 0,
    'ALBARELLA': 0,
    'ALBARELLI': 0,
    'ALBARENGA': 0,
    'ALBARES': 0,
    'ALBAREZ': 0,
    'ALBARRACIN': 0,
    'ALBARRAN': 0,
    'ALBAUGH': 0,
    'ALBAUM': 0,
    'ALBAVERA': 0,
    'ALBAY': 0,
    'ALBE': 0,
    'ALBEA': 0,
    'ALBEAR': 0,
    'ALBECK': 0,
    'ALBEE': 0,
    'ALBELO': 0,
    'ALBEN': 0,
    'ALBER': 0,
    'ALBERA': 0,
    'ALBERDA': 0,
    'ALBERDI': 0,
    'ALBERDING': 0,
    'ALBERG': 0,
    'ALBERGA': 0,
    'ALBERGHINI': 0,
    'ALBERGO': 0,
    'ALBERHASKY': 0,
    'ALBERICI': 0,
    'ALBERICO': 0,
    'ALBERINI': 0,
    'ALBERINO': 0,
    'ALBERNAZ': 0,
    'ALBERO': 0,
    'ALBERRY': 0,
    'ALBERS': 0,
    'ALBERSON': 0,
    'ALBERT': 0.9646302250803858,
    'ALBERTA': 0.9963594558344511,
    'ALBERTELLI': 0,
    'ALBERTER': 0,
    'ALBERTH': 0,
    'ALBERTHA': 1,
    'ALBERTI': 0,
    'ALBERTIE': 0,
    'ALBERTIN': 0,
    'ALBERTINA': 1,
    'ALBERTINE': 0.970873786407767,
    'ALBERTINI': 0,
    'ALBERTO': 0.9701629141497345,
    'ALBERTONI': 0,
    'ALBERTS': 0,
    'ALBERTSEN': 0,
    'ALBERTSON': 0,
    'ALBERTUS': 0,
    'ALBERTY': 0,
    'ALBERTZ': 0,
    'ALBERY': 0,
    'ALBI': 0,
    'ALBIANI': 0,
    'ALBIAR': 0,
    'ALBIDREZ': 0,
    'ALBILLAR': 0,
    'ALBIN': 0,
    'ALBINA': 1,
    'ALBINGER': 0,
    'ALBINI': 0,
    'ALBINO': 0,
    'ALBINSON': 0,
    'ALBION': 0,
    'ALBIS': 0,
    'ALBISTON': 0,
    'ALBITER': 0,
    'ALBITRE': 0,
    'ALBITZ': 0,
    'ALBIZU': 0,
    'ALBIZURES': 0,
    'ALBO': 0,
    'ALBON': 0,
    'ALBONE': 0,
    'ALBONETTI': 0,
    'ALBOR': 0,
    'ALBORES': 0,
    'ALBORN': 0,
    'ALBORNOZ': 0,
    'ALBRACHT': 0,
    'ALBRANDT': 0,
    'ALBRECHT': 0,
    'ALBRECHTSEN': 0,
    'ALBRETSEN': 0,
    'ALBRICH': 0,
    'ALBRIGHT': 0,
    'ALBRING': 0,
    'ALBRITTON': 0,
    'ALBRO': 0,
    'ALBRYCHT': 0,
    'ALBU': 0,
    'ALBUERNE': 0,
    'ALBUJA': 0,
    'ALBUQUERQUE': 0,
    'ALBUREZ': 0,
    'ALBURGER': 0,
    'ALBURQUERQUE': 0,
    'ALBURY': 0,
    'ALBUS': 0,
    'ALBY': 0,
    'ALCAIDE': 0,
    'ALCALA': 0,
    'ALCALDE': 0,
    'ALCAMO': 0,
    'ALCANTAR': 0,
    'ALCANTARA': 0,
    'ALCANTER': 0,
    'ALCANTRA': 0,
    'ALCARAS': 0,
    'ALCARAZ': 0,
    'ALCAREZ': 0,
    'ALCARO': 0,
    'ALCASID': 0,
    'ALCAUTER': 0,
    'ALCAZAR': 0,
    'ALCE': 0,
    'ALCEDO': 0,
    'ALCERRO': 0,
    'ALCH': 0,
    'ALCHIN': 0,
    'ALCID': 0,
    'ALCIDE': 0,
    'ALCIME': 0,
    'ALCINA': 0,
    'ALCINDOR': 0,
    'ALCINI': 0,
    'ALCIUS': 0,
    'ALCIVAR': 0,
    'ALCOCER': 0,
    'ALCOCK': 0,
    'ALCON': 0,
    'ALCONCEL': 0,
    'ALCORAN': 0,
    'ALCORN': 0,
    'ALCORTA': 0,
    'ALCOSER': 0,
    'ALCOTT': 0,
    'ALCOVER': 0,
    'ALCOX': 0,
    'ALCOZER': 0,
    'ALD': 0,
    'ALDA': 0.9876543209876544,
    'ALDABA': 0,
    'ALDACO': 0,
    'ALDAG': 0,
    'ALDAMA': 0,
    'ALDAN': 0,
    'ALDANA': 0,
    'ALDAPA': 0,
    'ALDAPE': 0,
    'ALDARONDO': 0,
    'ALDAS': 0,
    'ALDAVA': 0,
    'ALDAVE': 0,
    'ALDAY': 0,
    'ALDAZ': 0,
    'ALDE': 0,
    'ALDEA': 0,
    'ALDECOA': 0,
    'ALDEGUER': 0,
    'ALDEN': 0.7453416149068323,
    'ALDENDERFER': 0,
    'ALDER': 0,
    'ALDERDICE': 0,
    'ALDERETE': 0,
    'ALDERETTE': 0,
    'ALDERFER': 0,
    'ALDERINK': 0,
    'ALDERMAN': 0,
    'ALDERS': 0,
    'ALDERSON': 0,
    'ALDERTON': 0,
    'ALDI': 0,
    'ALDIA': 0,
    'ALDIN': 0,
    'ALDINGER': 0,
    'ALDIS': 0,
    'ALDO': 0.9915014164305949,
    'ALDOUS': 0,
    'ALDRED': 0,
    'ALDREDGE': 0,
    'ALDRETE': 0,
    'ALDRICH': 0,
    'ALDRIDGE': 0,
    'ALDRIGE': 0,
    'ALDRIN': 0,
    'ALDSTADT': 0,
    'ALDWORTH': 0,
    'ALDY': 0,
    'ALE': 0,
    'ALEA': 0,
    'ALEASE': 1,
    'ALEC': 0.9933774834437086,
    'ALECCI': 0,
    'ALECIA': 1,
    'ALECIO': 0,
    'ALECK': 0,
    'ALECKSON': 0,
    'ALEDO': 0,
    'ALEE': 0,
    'ALEEM': 0,
    'ALEEN': 1,
    'ALEF': 0,
    'ALEGADO': 0,
    'ALEGRE': 0,
    'ALEGRIA': 0,
    'ALEIDA': 1,
    'ALEISHA': 1,
    'ALEIXO': 0,
    'ALEJANDRA': 0.9966777408637874,
    'ALEJANDRE': 0,
    'ALEJANDRES': 0,
    'ALEJANDREZ': 0,
    'ALEJANDRINA': 1,
    'ALEJANDRINO': 0,
    'ALEJANDRO': 0.951959264998893,
    'ALEJO': 0,
    'ALEJOS': 0,
    'ALEKNA': 0,
    'ALEKSA': 0,
    'ALEKSANDROV': 0,
    'ALEKSANDROWICZ': 0,
    'ALEKSANYAN': 0,
    'ALEKSEYEV': 0,
    'ALEKSIC': 0,
    'ALEKSICH': 0,
    'ALELLO': 0,
    'ALEM': 0,
    'ALEMAN': 0,
    'ALEMANY': 0,
    'ALEMAYEHU': 0,
    'ALEMI': 0,
    'ALEMU': 0,
    'ALEN': 0,
    'ALENA': 0.9836065573770493,
    'ALENCAR': 0,
    'ALENCASTRO': 0,
    'ALENE': 1,
    'ALEO': 0,
    'ALEQUIN': 0,
    'ALER': 0,
    'ALERS': 0,
    'ALERT': 0,
    'ALERTE': 0,
    'ALES': 0,
    'ALESANDRO': 0,
    'ALESCH': 0,
    'ALESCI': 0,
    'ALESE': 0,
    'ALESHA': 1,
    'ALESHIA': 1,
    'ALESHIRE': 0,
    'ALESI': 0,
    'ALESIA': 0.9852216748768473,
    'ALESIO': 0,
    'ALESNA': 0,
    'ALESSANDRA': 0.9009009009009009,
    'ALESSANDRI': 0,
    'ALESSANDRINI': 0,
    'ALESSANDRO': 0,
    'ALESSANDRONI': 0,
    'ALESSI': 0,
    'ALESSIO': 0,
    'ALESSO': 0,
    'ALESTRA': 0,
    'ALETA': 1,
    'ALETHA': 1,
    'ALETHEA': 1,
    'ALETHIA': 1,
    'ALEVEDO': 0,
    'ALEVIZOS': 0,
    'ALEWEL': 0,
    'ALEWINE': 0,
    'ALEX': 0.9865092748735245,
    'ALEXA': 0.975609756097561,
    'ALEXADER': 0,
    'ALEXAKOS': 0,
    'ALEXANDER': 0.6514024597734674,
    'ALEXANDERSON': 0,
    'ALEXANDRA': 0.9938837920489296,
    'ALEXANDRE': 0,
    'ALEXANDRIA': 0.9915014164305949,
    'ALEXANDRIS': 0,
    'ALEXANDRO': 0,
    'ALEXANDROU': 0,
    'ALEXANDROV': 0,
    'ALEXANDROWICZ': 0,
    'ALEXANIAN': 0,
    'ALEXIA': 1,
    'ALEXIADES': 0,
    'ALEXIE': 0,
    'ALEXION': 0,
    'ALEXIOU': 0,
    'ALEXIS': 0.9568261376896149,
    'ALEXIUS': 0,
    'ALEXOPOULOS': 0,
    'ALEXSON': 0,
    'ALEXY': 0,
    'ALEY': 0,
    'ALF': 0,
    'ALFAFARA': 0,
    'ALFANO': 0,
    'ALFARD': 0,
    'ALFARO': 0,
    'ALFATLAWI': 0,
    'ALFELD': 0,
    'ALFEO': 0,
    'ALFERES': 0,
    'ALFEREZ': 0,
    'ALFEROS': 0,
    'ALFERS': 0,
    'ALFES': 0,
    'ALFF': 0,
    'ALFI': 0,
    'ALFIERI': 0,
    'ALFIERO': 0,
    'ALFINI': 0,
    'ALFLEN': 0,
    'ALFMAN': 0,
    'ALFONE': 0,
    'ALFONSE': 0,
    'ALFONSECA': 0,
    'ALFONSI': 0,
    'ALFONSO': 0.9141207601635795,
    'ALFONZO': 0.967741935483871,
    'ALFORD': 0,
    'ALFRED': 0.9871427700932301,
    'ALFREDA': 1,
    'ALFREDIA': 1,
    'ALFREDO': 0.9970457902511077,
    'ALFREDSON': 0,
    'ALFREE': 0,
    'ALFREY': 0,
    'ALFSEN': 0,
    'ALFSON': 0,
    'ALFSTAD': 0,
    'ALFT': 0,
    'ALGAHIM': 0,
    'ALGAR': 0,
    'ALGARIN': 0,
    'ALGAZE': 0,
    'ALGE': 0,
    'ALGEE': 0,
    'ALGEO': 0,
    'ALGER': 0,
    'ALGERI': 0,
    'ALGERIO': 0,
    'ALGHAMDI': 0,
    'ALGHAZALI': 0,
    'ALGIE': 0,
    'ALGIER': 0,
    'ALGIERE': 0,
    'ALGIERI': 0,
    'ALGIERS': 0,
    'ALGIRE': 0,
    'ALGOOD': 0,
    'ALGREN': 0,
    'ALGRIM': 0,
    'ALGUERA': 0,
    'ALGUIRE': 0,
    'ALHADDAD': 0,
    'ALHADEFF': 0,
    'ALHAJ': 0,
    'ALHAKIM': 0,
    'ALHAMBRA': 0,
    'ALHARBI': 0,
    'ALHASSAN': 0,
    'ALHINDI': 0,
    'ALI': 0.5115089514066496,
    'ALIA': 0.9174311926605505,
    'ALIABADI': 0,
    'ALIAGA': 0,
    'ALIANO': 0,
    'ALIAS': 0,
    'ALIBASIC': 0,
    'ALIBERTI': 0,
    'ALIBHAI': 0,
    'ALIBOZEK': 0,
    'ALIBRANDI': 0,
    'ALIC': 0,
    'ALICA': 1,
    'ALICANDRO': 0,
    'ALICE': 0.9995520215029678,
    'ALICEA': 0,
    'ALICH': 0,
    'ALICIA': 0.9989053092501368,
    'ALICK': 0,
    'ALIDA': 1,
    'ALIE': 0,
    'ALIEN': 0,
    'ALIER': 0,
    'ALIFF': 0,
    'ALIG': 0,
    'ALIHODZIC': 0,
    'ALIKHAN': 0,
    'ALIM': 0,
    'ALIMENA': 0,
    'ALIMENTI': 0,
    'ALIMI': 0,
    'ALIMO': 0,
    'ALIMONTI': 0,
    'ALIN': 0,
    'ALINA': 1,
    'ALINDOGAN': 0,
    'ALINE': 0.995475113122172,
    'ALIOTO': 0,
    'ALIOTTA': 0,
    'ALIOTTI': 0,
    'ALIPERTI': 0,
    'ALIPIO': 0,
    'ALIPOUR': 0,
    'ALIRE': 0,
    'ALIRES': 0,
    'ALIREZ': 0,
    'ALIS': 0,
    'ALISA': 0.997506234413965,
    'ALISE': 0.9756097560975611,
    'ALISEA': 0,
    'ALISEO': 0,
    'ALISHA': 1,
    'ALISHIA': 1,
    'ALISIA': 1,
    'ALISON': 0.9946290033817385,
    'ALISSA': 0.9963768115942029,
    'ALITA': 1,
    'ALITZ': 0,
    'ALIU': 0,
    'ALIX': 0.8196721311475409,
    'ALIYEVA': 0,
    'ALIZA': 1,
    'ALIZADEH': 0,
    'ALJAHMI': 0,
    'ALJAMAL': 0,
    'ALJETS': 0,
    'ALJOE': 0,
    'ALKA': 0,
    'ALKAN': 0,
    'ALKEMA': 0,
    'ALKEN': 0,
    'ALKER': 0,
    'ALKHAFAJI': 0,
    'ALKHATEEB': 0,
    'ALKHATIB': 0,
    'ALKINS': 0,
    'ALKIRE': 0,
    'ALKMAN': 0,
    'ALKURDI': 0,
    'ALL': 0,
    'ALLA': 0.966183574879227,
    'ALLABAND': 0,
    'ALLABAUGH': 0,
    'ALLADIN': 0,
    'ALLAH': 0,
    'ALLAIN': 0,
    'ALLAIRE': 0,
    'ALLALA': 0,
    'ALLAM': 0,
    'ALLAMAN': 0,
    'ALLAMBY': 0,
    'ALLAMON': 0,
    'ALLAMONG': 0,
    'ALLAN': 0.9387503847337643,
    'ALLAND': 0,
    'ALLANSON': 0,
    'ALLAR': 0,
    'ALLARA': 0,
    'ALLARD': 0,
    'ALLARDICE': 0,
    'ALLARDYCE': 0,
    'ALLAS': 0,
    'ALLAWAY': 0,
    'ALLBAUGH': 0,
    'ALLBEE': 0,
    'ALLBERRY': 0,
    'ALLBERT': 0,
    'ALLBERY': 0,
    'ALLBRIGHT': 0,
    'ALLBRITTEN': 0,
    'ALLBRITTON': 0,
    'ALLBROOK': 0,
    'ALLBROOKS': 0,
    'ALLCHIN': 0,
    'ALLCOCK': 0,
    'ALLCORN': 0,
    'ALLCOTT': 0,
    'ALLDAFFER': 0,
    'ALLDAY': 0,
    'ALLDER': 0,
    'ALLDREDGE': 0,
    'ALLDRIDGE': 0,
    'ALLDRITT': 0,
    'ALLE': 0,
    'ALLEBACH': 0,
    'ALLEC': 0,
    'ALLEE': 0,
    'ALLEEN': 1,
    'ALLEGA': 0,
    'ALLEGAR': 0,
    'ALLEGER': 0,
    'ALLEGOOD': 0,
    'ALLEGRA': 0.9090909090909091,
    'ALLEGRE': 0,
    'ALLEGRETTA': 0,
    'ALLEGRETTI': 0,
    'ALLEGRETTO': 0,
    'ALLEGREZZA': 0,
    'ALLEGRI': 0,
    'ALLEGRINI': 0,
    'ALLEGRO': 0,
    'ALLELY': 0,
    'ALLEM': 0,
    'ALLEMAN': 0,
    'ALLEMAND': 0,
    'ALLEMANG': 0,
    'ALLEMANN': 0,
    'ALLEMEIER': 0,
    'ALLEMON': 0,
    'ALLEMOND': 0,
    'ALLEN': 0.5060816056589125,
    'ALLENA': 1,
    'ALLENBACH': 0,
    'ALLENBAUGH': 0,
    'ALLENBERG': 0,
    'ALLENBRAND': 0,
    'ALLENBY': 0,
    'ALLENDE': 0,
    'ALLENDER': 0,
    'ALLENDORF': 0,
    'ALLENE': 1,
    'ALLENSON': 0,
    'ALLENSPACH': 0,
    'ALLENSWORTH': 0,
    'ALLER': 0,
    'ALLERDING': 0,
    'ALLERDINGS': 0,
    'ALLERHEILIGEN': 0,
    'ALLERS': 0,
    'ALLERT': 0,
    'ALLERTON': 0,
    'ALLERY': 0,
    'ALLES': 0,
    'ALLESHOUSE': 0,
    'ALLESSIO': 0,
    'ALLETTO': 0,
    'ALLEVA': 0,
    'ALLEVATO': 0,
    'ALLEX': 0,
    'ALLEY': 0,
    'ALLEYNE': 0,
    'ALLFORD': 0,
    'ALLFREY': 0,
    'ALLGAIER': 0,
    'ALLGEIER': 0,
    'ALLGEYER': 0,
    'ALLGIER': 0,
    'ALLGIRE': 0,
    'ALLGOOD': 0,
    'ALLGOR': 0,
    'ALLGYER': 0,
    'ALLHANDS': 0,
    'ALLHISER': 0,
    'ALLI': 0,
    'ALLIA': 0,
    'ALLIBONE': 0,
    'ALLICK': 0,
    'ALLICOCK': 0,
    'ALLIE': 0.9509875640087784,
    'ALLIEGRO': 0,
    'ALLIGER': 0,
    'ALLIGOOD': 0,
    'ALLIMAN': 0,
    'ALLIN': 0,
    'ALLINDER': 0,
    'ALLINE': 1,
    'ALLING': 0,
    'ALLINGER': 0,
    'ALLINGHAM': 0,
    'ALLINGTON': 0,
    'ALLINSON': 0,
    'ALLIO': 0,
    'ALLIS': 0,
    'ALLISON': 0.8281573498964804,
    'ALLISS': 0,
    'ALLISTER': 0,
    'ALLISTON': 0,
    'ALLMAN': 0,
    'ALLMAND': 0,
    'ALLMANDINGER': 0,
    'ALLMANN': 0,
    'ALLMARAS': 0,
    'ALLMENDINGER': 0,
    'ALLMER': 0,
    'ALLMON': 0,
    'ALLMOND': 0,
    'ALLNUTT': 0,
    'ALLO': 0,
    'ALLOCCA': 0,
    'ALLOCCO': 0,
    'ALLON': 0,
    'ALLOR': 0,
    'ALLORD': 0,
    'ALLORE': 0,
    'ALLOS': 0,
    'ALLOTEY': 0,
    'ALLOTT': 0,
    'ALLOTTA': 0,
    'ALLOWAY': 0,
    'ALLOY': 0,
    'ALLPHIN': 0,
    'ALLPORT': 0,
    'ALLREAD': 0,
    'ALLRED': 0,
    'ALLRICH': 0,
    'ALLRIDGE': 0,
    'ALLS': 0,
    'ALLSBROOK': 0,
    'ALLSBROOKS': 0,
    'ALLSBURY': 0,
    'ALLSHOUSE': 0,
    'ALLSMAN': 0,
    'ALLSOP': 0,
    'ALLSOPP': 0,
    'ALLSPACH': 0,
    'ALLSTON': 0,
    'ALLSTOT': 0,
    'ALLSUP': 0,
    'ALLSWORTH': 0,
    'ALLTON': 0,
    'ALLTOP': 0,
    'ALLUM': 0,
    'ALLUMBAUGH': 0,
    'ALLUMS': 0,
    'ALLURI': 0,
    'ALLWARDT': 0,
    'ALLWEIN': 0,
    'ALLWINE': 0,
    'ALLWOOD': 0,
    'ALLWORTH': 0,
    'ALLY': 0,
    'ALLYN': 0.6060606060606061,
    'ALLYSON': 0.9969325153374232,
    'ALM': 0,
    'ALMA': 0.9982912132386006,
    'ALMACK': 0,
    'ALMADA': 0,
    'ALMADER': 0,
    'ALMAGER': 0,
    'ALMAGUER': 0,
    'ALMAN': 0,
    'ALMAND': 0,
    'ALMANSA': 0,
    'ALMANY': 0,
    'ALMANZA': 0,
    'ALMANZAN': 0,
    'ALMANZAR': 0,
    'ALMARAS': 0,
    'ALMARAZ': 0,
    'ALMAREZ': 0,
    'ALMARIO': 0,
    'ALMAROAD': 0,
    'ALMARODE': 0,
    'ALMAS': 0,
    'ALMASAN': 0,
    'ALMASI': 0,
    'ALMASRI': 0,
    'ALMASSY': 0,
    'ALMASY': 0,
    'ALMAZAN': 0,
    'ALMAZAR': 0,
    'ALMAZO': 0,
    'ALMBERG': 0,
    'ALME': 0,
    'ALMEDA': 0.8746355685131195,
    'ALMEDIA': 0,
    'ALMEDINA': 0,
    'ALMEIDA': 0,
    'ALMEJO': 0,
    'ALMEKINDER': 0,
    'ALMEN': 0,
    'ALMENAS': 0,
    'ALMENDARES': 0,
    'ALMENDAREZ': 0,
    'ALMENDARIZ': 0,
    'ALMENDINGER': 0,
    'ALMENGOR': 0,
    'ALMER': 0,
    'ALMERAZ': 0,
    'ALMERICO': 0,
    'ALMERO': 0,
    'ALMES': 0,
    'ALMESTICA': 0,
    'ALMETA': 1,
    'ALMETER': 0,
    'ALMEYDA': 0,
    'ALMGREN': 0,
    'ALMIRA': 0,
    'ALMIRALL': 0,
    'ALMIROL': 0,
    'ALMIRON': 0,
    'ALMLI': 0,
    'ALMO': 0,
    'ALMODOVA': 0,
    'ALMODOVAR': 0,
    'ALMON': 0,
    'ALMOND': 0,
    'ALMONEY': 0,
    'ALMONOR': 0,
    'ALMONT': 0,
    'ALMONTASER': 0,
    'ALMONTE': 0,
    'ALMONY': 0,
    'ALMORA': 0,
    'ALMORE': 0,
    'ALMOS': 0,
    'ALMOSAWI': 0,
    'ALMQUIST': 0,
    'ALMS': 0,
    'ALMSTEAD': 0,
    'ALMSTEDT': 0,
    'ALMSTROM': 0,
    'ALMUSAWI': 0,
    'ALMY': 0,
    'ALNAJJAR': 0,
    'ALNUTT': 0,
    'ALO': 0,
    'ALOE': 0,
    'ALOFS': 0,
    'ALOI': 0,
    'ALOIA': 0,
    'ALOIS': 0,
    'ALOISE': 0,
    'ALOISI': 0,
    'ALOISIO': 0,
    'ALOMA': 0,
    'ALOMAR': 0,
    'ALOMARI': 0,
    'ALOMIA': 0,
    'ALON': 0,
    'ALONA': 1,
    'ALONGE': 0,
    'ALONGI': 0,
    'ALONI': 0,
    'ALONSO': 0.3415883859948762,
    'ALONZI': 0,
    'ALONZO': 0.7843137254901961,
    'ALOR': 0,
    'ALOSI': 0,
    'ALOTAIBI': 0,
    'ALOTTA': 0,
    'ALOY': 0,
    'ALOYO': 0,
    'ALOZIE': 0,
    'ALPAUGH': 0,
    'ALPER': 0,
    'ALPERIN': 0,
    'ALPERN': 0,
    'ALPEROVICH': 0,
    'ALPERS': 0,
    'ALPERSTEIN': 0,
    'ALPERT': 0,
    'ALPETER': 0,
    'ALPHA': 0.9727626459143969,
    'ALPHIN': 0,
    'ALPHONSE': 0.9523809523809523,
    'ALPHONSO': 0.9803921568627451,
    'ALPI': 0,
    'ALPIN': 0,
    'ALPINE': 0,
    'ALPIZAR': 0,
    'ALPOUGH': 0,
    'ALPS': 0,
    'ALPUCHE': 0,
    'ALQAHTANI': 0,
    'ALQUICIRA': 0,
    'ALQUIST': 0,
    'ALQUIZA': 0,
    'ALREAD': 0,
    'ALRED': 0,
    'ALRIDGE': 0,
    'ALS': 0,
    'ALSAADI': 0,
    'ALSABROOK': 0,
    'ALSADI': 0,
    'ALSAGER': 0,
    'ALSAIDI': 0,
    'ALSAKER': 0,
    'ALSALEH': 0,
    'ALSALMAN': 0,
    'ALSAYED': 0,
    'ALSBERRY': 0,
    'ALSBROOK': 0,
    'ALSBROOKS': 0,
    'ALSBURY': 0,
    'ALSDORF': 0,
    'ALSEN': 0,
    'ALSEPT': 0,
    'ALSETH': 0,
    'ALSHAMI': 0,
    'ALSHARIF': 0,
    'ALSHEIKH': 0,
    'ALSHEIMER': 0,
    'ALSHOUSE': 0,
    'ALSINA': 0,
    'ALSING': 0,
    'ALSIP': 0,
    'ALSLEBEN': 0,
    'ALSMAN': 0,
    'ALSOBROOK': 0,
    'ALSOBROOKS': 0,
    'ALSON': 0,
    'ALSOP': 0,
    'ALSPACH': 0,
    'ALSPAUGH': 0,
    'ALSPAW': 0,
    'ALSPURO': 0,
    'ALSTAD': 0,
    'ALSTADT': 0,
    'ALSTATT': 0,
    'ALSTEEN': 0,
    'ALSTER': 0,
    'ALSTON': 0,
    'ALSTOTT': 0,
    'ALSTROM': 0,
    'ALSUM': 0,
    'ALSUP': 0,
    'ALSWORTH': 0,
    'ALT': 0,
    'ALTA': 1,
    'ALTADONNA': 0,
    'ALTAF': 0,
    'ALTAFFER': 0,
    'ALTAGRACIA': 1,
    'ALTAHA': 0,
    'ALTAMIMI': 0,
    'ALTAMIRA': 0,
    'ALTAMIRANO': 0,
    'ALTAMORE': 0,
    'ALTAMURA': 0,
    'ALTAMURO': 0,
    'ALTAN': 0,
    'ALTARES': 0,
    'ALTAVILLA': 0,
    'ALTAZAN': 0,
    'ALTEMA': 0,
    'ALTEMEIER': 0,
    'ALTEMOSE': 0,
    'ALTEMUS': 0,
    'ALTEN': 0,
    'ALTENA': 0,
    'ALTENAU': 0,
    'ALTENBACH': 0,
    'ALTENBAUMER': 0,
    'ALTENBERG': 0,
    'ALTENBERGER': 0,
    'ALTENBERN': 0,
    'ALTENBERND': 0,
    'ALTENBURG': 0,
    'ALTENBURGER': 0,
    'ALTENDORF': 0,
    'ALTENHOF': 0,
    'ALTENHOFEN': 0,
    'ALTENHOFF': 0,
    'ALTENOR': 0,
    'ALTEPETER': 0,
    'ALTER': 0,
    'ALTERGOTT': 0,
    'ALTERI': 0,
    'ALTERIO': 0,
    'ALTERMAN': 0,
    'ALTERMATT': 0,
    'ALTERS': 0,
    'ALTES': 0,
    'ALTEVOGT': 0,
    'ALTFILLISCH': 0,
    'ALTGILBERS': 0,
    'ALTHA': 1,
    'ALTHAUS': 0,
    'ALTHAUSER': 0,
    'ALTHEA': 1,
    'ALTHEIDE': 0,
    'ALTHEIMER': 0,
    'ALTHEN': 0,
    'ALTHER': 0,
    'ALTHERR': 0,
    'ALTHISER': 0,
    'ALTHOF': 0,
    'ALTHOFF': 0,
    'ALTHOLZ': 0,
    'ALTHOUSE': 0,
    'ALTIC': 0,
    'ALTICE': 0,
    'ALTICK': 0,
    'ALTIDOR': 0,
    'ALTIER': 0,
    'ALTIERE': 0,
    'ALTIERI': 0,
    'ALTIERO': 0,
    'ALTIERY': 0,
    'ALTIG': 0,
    'ALTILIO': 0,
    'ALTIMARI': 0,
    'ALTIMORE': 0,
    'ALTIMUS': 0,
    'ALTINE': 0,
    'ALTIS': 0,
    'ALTIZER': 0,
    'ALTLAND': 0,
    'ALTMAIER': 0,
    'ALTMAN': 0,
    'ALTMANN': 0,
    'ALTMAYER': 0,
    'ALTMEYER': 0,
    'ALTMILLER': 0,
    'ALTMIRE': 0,
    'ALTMYER': 0,
    'ALTO': 0,
    'ALTOBELL': 0,
    'ALTOBELLI': 0,
    'ALTOBELLO': 0,
    'ALTOM': 0,
    'ALTOMARE': 0,
    'ALTOMARI': 0,
    'ALTOMONTE': 0,
    'ALTON': 0.9548611111111112,
    'ALTONEN': 0,
    'ALTORFER': 0,
    'ALTOUNIAN': 0,
    'ALTPETER': 0,
    'ALTRECHE': 0,
    'ALTRICHTER': 0,
    'ALTRINGER': 0,
    'ALTSCHUL': 0,
    'ALTSCHULER': 0,
    'ALTSHULER': 0,
    'ALTSMAN': 0,
    'ALTSTADT': 0,
    'ALTSTAETTER': 0,
    'ALTSTATT': 0,
    'ALTUM': 0,
    'ALTUNA': 0,
    'ALTURA': 0,
    'ALTUS': 0,
    'ALTVATER': 0,
    'ALTWIES': 0,
    'ALTY': 0,
    'ALU': 0,
    'ALUARADO': 0,
    'ALUAREZ': 0,
    'ALUIA': 0,
    'ALUISE': 0,
    'ALUKO': 0,
    'ALUKONIS': 0,
    'ALUMBAUGH': 0,
    'ALUNNI': 0,
    'ALUQDAH': 0,
    'ALVA': 0.8843537414965986,
    'ALVANOS': 0,
    'ALVAR': 0,
    'ALVARA': 0,
    'ALVARADO': 0,
    'ALVARAN': 0,
    'ALVARDO': 0,
    'ALVARE': 0,
    'ALVARENGA': 0,
    'ALVARES': 0,
    'ALVAREZ': 0,
    'ALVARINO': 0,
    'ALVARO': 0.970873786407767,
    'ALVARRAN': 0,
    'ALVEAR': 0,
    'ALVELO': 0,
    'ALVEN': 0,
    'ALVER': 0,
    'ALVERA': 0.9756097560975611,
    'ALVERAZ': 0,
    'ALVERIO': 0,
    'ALVERNAZ': 0,
    'ALVERO': 0,
    'ALVERS': 0,
    'ALVERSON': 0,
    'ALVERTA': 1,
    'ALVES': 0,
    'ALVESTAD': 0,
    'ALVESTEFFER': 0,
    'ALVEY': 0,
    'ALVEZ': 0,
    'ALVI': 0,
    'ALVIA': 0,
    'ALVIANI': 0,
    'ALVIAR': 0,
    'ALVIDRES': 0,
    'ALVIDREZ': 0,
    'ALVILLAR': 0,
    'ALVIN': 0.9962994591517221,
    'ALVINA': 1,
    'ALVINE': 0,
    'ALVINO': 0,
    'ALVIRA': 0,
    'ALVIREZ': 0,
    'ALVIS': 0,
    'ALVISO': 0,
    'ALVITER': 0,
    'ALVITI': 0,
    'ALVIZAR': 0,
    'ALVIZO': 0,
    'ALVIZURES': 0,
    'ALVORD': 0,
    'ALVSTAD': 0,
    'ALWAN': 0,
    'ALWANI': 0,
    'ALWARD': 0,
    'ALWARDT': 0,
    'ALWAY': 0,
    'ALWELL': 0,
    'ALWES': 0,
    'ALWIN': 0,
    'ALWINE': 0,
    'ALWOOD': 0,
    'ALWORTH': 0,
    'ALY': 0,
    'ALYCE': 1,
    'ALYCIA': 1,
    'ALYEA': 0,
    'ALYSA': 1,
    'ALYSE': 1,
    'ALYSHA': 1,
    'ALYSIA': 1,
    'ALYSON': 1,
    'ALYSSA': 1,
    'ALZAGA': 0,
    'ALZAHRANI': 0,
    'ALZAMORA': 0,
    'ALZATE': 0,
    'ALZONA': 0,
    'ALZOUBI': 0,
    'ALZUGARAY': 0,
    'AM': 0,
    'AMA': 0,
    'AMABILE': 0,
    'AMABLE': 0,
    'AMACHER': 0,
    'AMACK': 0,
    'AMACKER': 0,
    'AMAD': 0,
    'AMADA': 0.986842105263158,
    'AMADEI': 0,
    'AMADEO': 0,
    'AMADI': 0,
    'AMADIO': 0,
    'AMADO': 0.8333333333333334,
    'AMADON': 0,
    'AMADOR': 0,
    'AMAECHI': 0,
    'AMAKER': 0,
    'AMAL': 1,
    'AMALBERT': 0,
    'AMALFI': 0,
    'AMALFITANO': 0,
    'AMALIA': 1,
    'AMALLA': 0,
    'AMAN': 0,
    'AMANCIO': 0,
    'AMAND': 0,
    'AMANDA': 0.9998515072019007,
    'AMANI': 0,
    'AMANKWAH': 0,
    'AMANN': 0,
    'AMANO': 0,
    'AMANS': 0,
    'AMANT': 0,
    'AMANTE': 0,
    'AMANTEA': 0,
    'AMANTI': 0,
    'AMANTIA': 0,
    'AMANUEL': 0,
    'AMAR': 0,
    'AMARA': 0,
    'AMARAL': 0,
    'AMARANTE': 0,
    'AMARE': 0,
    'AMARI': 0,
    'AMARILLAS': 0,
    'AMARILLO': 0,
    'AMARO': 0,
    'AMAROSA': 0,
    'AMARU': 0,
    'AMASH': 0,
    'AMASON': 0,
    'AMASS': 0,
    'AMAT': 0,
    'AMATA': 0,
    'AMATANGELO': 0,
    'AMATI': 0,
    'AMATO': 0,
    'AMATON': 0,
    'AMATORE': 0,
    'AMATRUDA': 0,
    'AMATUCCI': 0,
    'AMATULLI': 0,
    'AMAVISCA': 0,
    'AMAVIZCA': 0,
    'AMAYA': 0,
    'AMAYO': 0,
    'AMAZAN': 0,
    'AMAZEEN': 0,
    'AMBACH': 0,
    'AMBACHER': 0,
    'AMBARTSUMYAN': 0,
    'AMBAT': 0,
    'AMBEAU': 0,
    'AMBER': 0.9984399375975039,
    'AMBERG': 0,
    'AMBERGER': 0,
    'AMBERLY': 1,
    'AMBERMAN': 0,
    'AMBERS': 0,
    'AMBERSLEY': 0,
    'AMBERSON': 0,
    'AMBERT': 0,
    'AMBLE': 0,
    'AMBLER': 0,
    'AMBO': 0,
    'AMBORN': 0,
    'AMBORSKI': 0,
    'AMBOS': 0,
    'AMBRA': 0,
    'AMBRE': 0,
    'AMBRIDGE': 0,
    'AMBRIS': 0,
    'AMBRISTER': 0,
    'AMBRIZ': 0,
    'AMBRO': 0,
    'AMBROCIO': 0,
    'AMBROGI': 0,
    'AMBROGIO': 0,
    'AMBROISE': 0,
    'AMBROS': 0,
    'AMBROSE': 0.39254170755642787,
    'AMBROSELLI': 0,
    'AMBROSETTI': 0,
    'AMBROSI': 0,
    'AMBROSIA': 0,
    'AMBROSINI': 0,
    'AMBROSINO': 0,
    'AMBROSIO': 0,
    'AMBROSIUS': 0,
    'AMBROSO': 0,
    'AMBROSY': 0,
    'AMBROZ': 0,
    'AMBROZIAK': 0,
    'AMBROZY': 0,
    'AMBRUS': 0,
    'AMBRUSO': 0,
    'AMBS': 0,
    'AMBUEHL': 0,
    'AMBURG': 0,
    'AMBURGEY': 0,
    'AMBURGY': 0,
    'AMBURN': 0,
    'AMBUS': 0,
    'AMBUSH': 0,
    'AMDAHL': 0,
    'AMDAL': 0,
    'AMDOR': 0,
    'AMDUR': 0,
    'AMED': 0,
    'AMEDEE': 0,
    'AMEDEO': 0,
    'AMEDI': 0,
    'AMEDIO': 0,
    'AMEDURI': 0,
    'AMEE': 1,
    'AMEEL': 0,
    'AMEELE': 0,
    'AMEEN': 0,
    'AMEER': 0,
    'AMEIGH': 0,
    'AMELANG': 0,
    'AMELIA': 0.9990393852065322,
    'AMELING': 0,
    'AMELIO': 0,
    'AMELL': 0,
    'AMELOTTE': 0,
    'AMELSE': 0,
    'AMELUNG': 0,
    'AMELUNKE': 0,
    'AMEMIYA': 0,
    'AMEN': 0,
    'AMEND': 0,
    'AMENDA': 0,
    'AMENDE': 0,
    'AMENDOLA': 0,
    'AMENDOLARA': 0,
    'AMENDOLARE': 0,
    'AMENDOLIA': 0,
    'AMENDT': 0,
    'AMENGUAL': 0,
    'AMENSON': 0,
    'AMENT': 0,
    'AMENTA': 0,
    'AMENTO': 0,
    'AMER': 0,
    'AMERAL': 0,
    'AMERI': 0,
    'AMERICA': 0.967741935483871,
    'AMERICAN': 0,
    'AMERICANHORSE': 0,
    'AMERICANO': 0,
    'AMERICO': 0,
    'AMERIN': 0,
    'AMERINE': 0,
    'AMERIO': 0,
    'AMERLING': 0,
    'AMERMAN': 0,
    'AMERO': 0,
    'AMERSON': 0,
    'AMERY': 0,
    'AMES': 0,
    'AMESBURY': 0,
    'AMESCUA': 0,
    'AMESQUITA': 0,
    'AMESTOY': 0,
    'AMEY': 0,
    'AMEZAGA': 0,
    'AMEZCUA': 0,
    'AMEZOLA': 0,
    'AMEZQUITA': 0,
    'AMI': 0.9852216748768473,
    'AMIAN': 0,
    'AMIANO': 0,
    'AMICI': 0,
    'AMICK': 0,
    'AMICO': 0,
    'AMICONE': 0,
    'AMICUCCI': 0,
    'AMID': 0,
    'AMIDEI': 0,
    'AMIDON': 0,
    'AMIE': 0.9863429438543249,
    'AMIEE': 1,
    'AMIEL': 0,
    'AMIEVA': 0,
    'AMIG': 0,
    'AMIGH': 0,
    'AMIGO': 0,
    'AMIGON': 0,
    'AMIKER': 0,
    'AMIL': 0,
    'AMILCAR': 0,
    'AMILL': 0,
    'AMIN': 0,
    'AMINA': 0.9615384615384616,
    'AMINE': 0,
    'AMINI': 0,
    'AMINIAN': 0,
    'AMINOV': 0,
    'AMINOVA': 0,
    'AMIOT': 0,
    'AMIOTT': 0,
    'AMIOTTE': 0,
    'AMIR': 0,
    'AMIRA': 0.9523809523809523,
    'AMIRAULT': 0,
    'AMIREH': 0,
    'AMIRI': 0,
    'AMIRIAN': 0,
    'AMIRKHANIAN': 0,
    'AMIS': 0,
    'AMISON': 0,
    'AMISS': 0,
    'AMIT': 0,
    'AMITH': 0,
    'AMITRANO': 0,
    'AMJAD': 0,
    'AMJADI': 0,
    'AMLANI': 0,
    'AMLAW': 0,
    'AMLIN': 0,
    'AMLING': 0,
    'AMLONG': 0,
    'AMLUNG': 0,
    'AMMAN': 0,
    'AMMANN': 0,
    'AMMAR': 0,
    'AMMARI': 0,
    'AMMEL': 0,
    'AMMEN': 0,
    'AMMER': 0,
    'AMMERMAN': 0,
    'AMMERMANN': 0,
    'AMMETER': 0,
    'AMMIE': 1,
    'AMMIRATA': 0,
    'AMMIRATI': 0,
    'AMMIRATO': 0,
    'AMMON': 0,
    'AMMONS': 0,
    'AMO': 0,
    'AMOAH': 0,
    'AMOAKO': 0,
    'AMODEI': 0,
    'AMODEO': 0,
    'AMODIO': 0,
    'AMODO': 0,
    'AMOIA': 0,
    'AMOLE': 0,
    'AMOLSCH': 0,
    'AMON': 0,
    'AMOND': 0,
    'AMONETT': 0,
    'AMONETTE': 0,
    'AMONS': 0,
    'AMONSON': 0,
    'AMOR': 0,
    'AMORA': 0,
    'AMORE': 0,
    'AMORELLI': 0,
    'AMORELLO': 0,
    'AMORES': 0,
    'AMORESE': 0,
    'AMORI': 0,
    'AMORIELLO': 0,
    'AMORIM': 0,
    'AMORIN': 0,
    'AMORMINO': 0,
    'AMOROS': 0,
    'AMOROSA': 0,
    'AMOROSE': 0,
    'AMOROSI': 0,
    'AMOROSO': 0,
    'AMORUSO': 0,
    'AMORY': 0,
    'AMOS': 0.7027406886858749,
    'AMOSS': 0,
    'AMOTH': 0,
    'AMOTT': 0,
    'AMOUR': 0,
    'AMPARAN': 0,
    'AMPARANO': 0,
    'AMPARO': 0.96051227321238,
    'AMPE': 0,
    'AMPER': 0,
    'AMPEY': 0,
    'AMPIE': 0,
    'AMPOFO': 0,
    'AMPONSAH': 0,
    'AMPUDIA': 0,
    'AMPUERO': 0,
    'AMPY': 0,
    'AMRAM': 0,
    'AMRANI': 0,
    'AMREIN': 0,
    'AMRHEIN': 0,
    'AMRICH': 0,
    'AMRINE': 0,
    'AMRO': 0,
    'AMS': 0,
    'AMSBAUGH': 0,
    'AMSBERRY': 0,
    'AMSBURY': 0,
    'AMSCHLER': 0,
    'AMSDEN': 0,
    'AMSDILL': 0,
    'AMSEL': 0,
    'AMSHOFF': 0,
    'AMSLER': 0,
    'AMSLEY': 0,
    'AMSPACHER': 0,
    'AMSPAUGH': 0,
    'AMSPOKER': 0,
    'AMSTADT': 0,
    'AMSTER': 0,
    'AMSTERDAM': 0,
    'AMSTRONG': 0,
    'AMSTUTZ': 0,
    'AMTHOR': 0,
    'AMTMANN': 0,
    'AMTOWER': 0,
    'AMUNDSEN': 0,
    'AMUNDSON': 0,
    'AMUNRUD': 0,
    'AMURAO': 0,
    'AMUSO': 0,
    'AMWEG': 0,
    'AMY': 0.9983176908092792,
    'AMYOT': 0,
    'AMYOTTE': 0,
    'AMYX': 0,
    'AN': 0.33222591362126247,
    'ANA': 0.9993337774816788,
    'ANABEL': 1,
    'ANABLE': 0,
    'ANABTAWI': 0,
    'ANACKER': 0,
    'ANACLETO': 0,
    'ANAGNOS': 0,
    'ANAGNOST': 0,
    'ANAGNOSTIS': 0,
    'ANAGNOSTOPOULOS': 0,
    'ANAGNOSTOU': 0,
    'ANAIR': 0,
    'ANALCO': 0,
    'ANALISA': 1,
    'ANALLA': 0,
    'ANAM': 0,
    'ANAMA': 0,
    'ANAMARIA': 1,
    'ANAN': 0,
    'ANAND': 0,
    'ANANE': 0,
    'ANANI': 0,
    'ANANIA': 0,
    'ANANIAN': 0,
    'ANANIAS': 0,
    'ANANTHARAMAN': 0,
    'ANAS': 0,
    'ANASCO': 0,
    'ANAST': 0,
    'ANASTACIA': 1,
    'ANASTACIO': 0,
    'ANASTAS': 0,
    'ANASTASI': 0,
    'ANASTASIA': 0.966183574879227,
    'ANASTASIADIS': 0,
    'ANASTASIO': 0,
    'ANASTASIOU': 0,
    'ANASTASOPOULOS': 0,
    'ANASTOS': 0,
    'ANATRA': 0,
    'ANAWALT': 0,
    'ANAYA': 0,
    'ANCA': 0,
    'ANCAR': 0,
    'ANCARROW': 0,
    'ANCEL': 0,
    'ANCELET': 0,
    'ANCELL': 0,
    'ANCHETA': 0,
    'ANCHIA': 0,
    'ANCHONDO': 0,
    'ANCHOR': 0,
    'ANCHORS': 0,
    'ANCHUNDIA': 0,
    'ANCICH': 0,
    'ANCIL': 0,
    'ANCIRA': 0,
    'ANCISO': 0,
    'ANCKER': 0,
    'ANCOG': 0,
    'ANCONA': 0,
    'ANCRUM': 0,
    'ANCTIL': 0,
    'AND': 0,
    'ANDA': 0,
    'ANDABLO': 0,
    'ANDAL': 0,
    'ANDALON': 0,
    'ANDALORA': 0,
    'ANDALORO': 0,
    'ANDALUZ': 0,
    'ANDARA': 0,
    'ANDARY': 0,
    'ANDAVERDE': 0,
    'ANDAYA': 0,
    'ANDAZOLA': 0,
    'ANDE': 0,
    'ANDEL': 0,
    'ANDELIN': 0,
    'ANDELL': 0,
    'ANDELMAN': 0,
    'ANDER': 0,
    'ANDERA': 0.9174311926605505,
    'ANDERBERG': 0,
    'ANDERECK': 0,
    'ANDEREGG': 0,
    'ANDERER': 0,
    'ANDERES': 0,
    'ANDERKIN': 0,
    'ANDERKO': 0,
    'ANDERL': 0,
    'ANDERLE': 0,
    'ANDERLIK': 0,
    'ANDERMAN': 0,
    'ANDERMANN': 0,
    'ANDEROSN': 0,
    'ANDERS': 0,
    'ANDERSCH': 0,
    'ANDERSEN': 0,
    'ANDERSON': 0.024169601546854498,
    'ANDERSSON': 0,
    'ANDERT': 0,
    'ANDERTON': 0,
    'ANDERWALD': 0,
    'ANDES': 0,
    'ANDESON': 0,
    'ANDEXLER': 0,
    'ANDIA': 0,
    'ANDING': 0,
    'ANDINO': 0,
    'ANDIS': 0,
    'ANDLER': 0,
    'ANDO': 0,
    'ANDOE': 0,
    'ANDOH': 0,
    'ANDOLINA': 0,
    'ANDOLINO': 0,
    'ANDOLSEK': 0,
    'ANDON': 0,
    'ANDONIAN': 0,
    'ANDOR': 0,
    'ANDORF': 0,
    'ANDORFER': 0,
    'ANDOW': 0,
    'ANDRA': 0.9765625,
    'ANDRACA': 0,
    'ANDRACKI': 0,
    'ANDRADA': 0,
    'ANDRADE': 0,
    'ANDRADES': 0,
    'ANDRAE': 0,
    'ANDRAKO': 0,
    'ANDRAOS': 0,
    'ANDRAS': 0,
    'ANDRASCHKO': 0,
    'ANDRASCIK': 0,
    'ANDRASIK': 0,
    'ANDRASKO': 0,
    'ANDRASSY': 0,
    'ANDRE': 0.9622501850481125,
    'ANDREA': 0.9977735631236084,
    'ANDREACCHIO': 0,
    'ANDREADIS': 0,
    'ANDREAE': 0,
    'ANDREANI': 0,
    'ANDREANO': 0,
    'ANDREAS': 0.8064516129032259,
    'ANDREASEN': 0,
    'ANDREASON': 0,
    'ANDREASSEN': 0,
    'ANDREASSI': 0,
    'ANDREASSON': 0,
    'ANDREATTA': 0,
    'ANDREDE': 0,
    'ANDREE': 0.8097165991902835,
    'ANDREEN': 0,
    'ANDREEV': 0,
    'ANDREGG': 0,
    'ANDREI': 0,
    'ANDREINI': 0,
    'ANDREIS': 0,
    'ANDREJACK': 0,
    'ANDREJKO': 0,
    'ANDREN': 0,
    'ANDREOLA': 0,
    'ANDREOLI': 0,
    'ANDREONE': 0,
    'ANDREONI': 0,
    'ANDREOTTA': 0,
    'ANDREOTTI': 0,
    'ANDREOTTOLA': 0,
    'ANDREOU': 0,
    'ANDREOZZI': 0,
    'ANDREPONT': 0,
    'ANDRES': 0.9013785790031814,
    'ANDRESEN': 0,
    'ANDRESKI': 0,
    'ANDRESKY': 0,
    'ANDRESON': 0,
    'ANDRESS': 0,
    'ANDRETTA': 0,
    'ANDRETTI': 0,
    'ANDREU': 0,
    'ANDREUCCI': 0,
    'ANDREW': 0.9910456542923861,
    'ANDREWS': 0,
    'ANDREWSKI': 0,
    'ANDREWSON': 0,
    'ANDREY': 0,
    'ANDREYEV': 0,
    'ANDRIA': 0.9900990099009901,
    'ANDRIACCHI': 0,
    'ANDRIANI': 0,
    'ANDRIANO': 0,
    'ANDRIANOS': 0,
    'ANDRIC': 0,
    'ANDRICH': 0,
    'ANDRICK': 0,
    'ANDRIE': 0,
    'ANDRIES': 0,
    'ANDRIESE': 0,
    'ANDRIEU': 0,
    'ANDRIEUX': 0,
    'ANDRIGHETTI': 0,
    'ANDRING': 0,
    'ANDRINGA': 0,
    'ANDRINI': 0,
    'ANDRINO': 0,
    'ANDRIOLA': 0,
    'ANDRION': 0,
    'ANDRIOT': 0,
    'ANDRIOTIS': 0,
    'ANDRIS': 0,
    'ANDRISANI': 0,
    'ANDRIST': 0,
    'ANDRIULLI': 0,
    'ANDRIX': 0,
    'ANDRLE': 0,
    'ANDRO': 0,
    'ANDROES': 0,
    'ANDROFF': 0,
    'ANDRON': 0,
    'ANDRONACO': 0,
    'ANDRONICO': 0,
    'ANDROS': 0,
    'ANDROSKI': 0,
    'ANDROSKO': 0,
    'ANDROSKY': 0,
    'ANDROVICH': 0,
    'ANDRSON': 0,
    'ANDRULIS': 0,
    'ANDRULONIS': 0,
    'ANDRUS': 0,
    'ANDRUSKO': 0,
    'ANDRUSS': 0,
    'ANDRUSZKIEWICZ': 0,
    'ANDRUZZI': 0,
    'ANDRY': 0,
    'ANDRYSHAK': 0,
    'ANDRYSIAK': 0,
    'ANDRZEJAK': 0,
    'ANDRZEJCZAK': 0,
    'ANDRZEJCZYK': 0,
    'ANDRZEJEWSKI': 0,
    'ANDUHA': 0,
    'ANDUJAR': 0,
    'ANDUJO': 0,
    'ANDURAY': 0,
    'ANDY': 0.9951259138911455,
    'ANE': 0,
    'ANEJA': 0,
    'ANELLI': 0,
    'ANELLO': 0,
    'ANEMA': 0,
    'ANEMONE': 0,
    'ANENE': 0,
    'ANERSON': 0,
    'ANES': 0,
    'ANESI': 0,
    'ANEST': 0,
    'ANETSBERGER': 0,
    'ANETTE': 1,
    'ANEWALT': 0,
    'ANEY': 0,
    'ANEZ': 0,
    'ANFANG': 0,
    'ANFIELD': 0,
    'ANFINSON': 0,
    'ANFUSO': 0,
    'ANG': 0,
    'ANGAMARCA': 0,
    'ANGARA': 0,
    'ANGARANO': 0,
    'ANGARITA': 0,
    'ANGAROLA': 0,
    'ANGE': 0,
    'ANGEL': 0.9423324742268041,
    'ANGELA': 0.9998290890446079,
    'ANGELAKIS': 0,
    'ANGELAKOS': 0,
    'ANGELASTRO': 0,
    'ANGELBECK': 0,
    'ANGELE': 0.966183574879227,
    'ANGELENA': 1,
    'ANGELERI': 0,
    'ANGELES': 0.37807183364839325,
    'ANGELETTE': 0,
    'ANGELETTI': 0,
    'ANGELI': 0,
    'ANGELIA': 1,
    'ANGELIC': 1,
    'ANGELICA': 0.996168582375479,
    'ANGELICH': 0,
    'ANGELICO': 0,
    'ANGELICOLA': 0,
    'ANGELIDES': 0,
    'ANGELIKA': 1,
    'ANGELILLI': 0,
    'ANGELILLO': 0,
    'ANGELINA': 0.9970358393963891,
    'ANGELINE': 0.9883720930232558,
    'ANGELINI': 0,
    'ANGELINO': 0,
    'ANGELIQUE': 1,
    'ANGELIS': 0,
    'ANGELITA': 1,
    'ANGELITO': 0,
    'ANGELL': 0,
    'ANGELLA': 1,
    'ANGELLE': 0,
    'ANGELLO': 0,
    'ANGELLOTTI': 0,
    'ANGELLY': 0,
    'ANGELO': 0.9354323522701347,
    'ANGELOFF': 0,
    'ANGELONE': 0,
    'ANGELONI': 0,
    'ANGELOPOULOS': 0,
    'ANGELOS': 0,
    'ANGELOSANTO': 0,
    'ANGELOTTI': 0,
    'ANGELOU': 0,
    'ANGELOV': 0,
    'ANGELOZZI': 0,
    'ANGELS': 0,
    'ANGELUCCI': 0,
    'ANGELUS': 0,
    'ANGELYN': 1,
    'ANGEN': 0,
    'ANGER': 0,
    'ANGERAME': 0,
    'ANGERER': 0,
    'ANGERHOFER': 0,
    'ANGERMAN': 0,
    'ANGERMEIER': 0,
    'ANGERON': 0,
    'ANGERS': 0,
    'ANGERSTEIN': 0,
    'ANGERT': 0,
    'ANGEVINE': 0,
    'ANGHEL': 0,
    'ANGI': 0,
    'ANGIANO': 0,
    'ANGIE': 0.9985207100591715,
    'ANGIER': 0,
    'ANGILA': 1,
    'ANGILERI': 0,
    'ANGILLETTA': 0,
    'ANGIOLETTI': 0,
    'ANGIOLILLO': 0,
    'ANGIONE': 0,
    'ANGIULI': 0,
    'ANGIULO': 0,
    'ANGLA': 1,
    'ANGLADA': 0,
    'ANGLADE': 0,
    'ANGLAND': 0,
    'ANGLE': 0.4987531172069826,
    'ANGLEA': 0.970873786407767,
    'ANGLEBERGER': 0,
    'ANGLEBRANDT': 0,
    'ANGLEMYER': 0,
    'ANGLEN': 0,
    'ANGLERO': 0,
    'ANGLES': 0,
    'ANGLESEY': 0,
    'ANGLETON': 0,
    'ANGLEY': 0,
    'ANGLIM': 0,
    'ANGLIN': 0,
    'ANGLO': 0,
    'ANGLUM': 0,
    'ANGON': 0,
    'ANGONA': 0,
    'ANGONE': 0,
    'ANGOTT': 0,
    'ANGOTTI': 0,
    'ANGOVE': 0,
    'ANGRAND': 0,
    'ANGRICK': 0,
    'ANGRISANI': 0,
    'ANGRISANO': 0,
    'ANGRUM': 0,
    'ANGRY': 0,
    'ANGST': 0,
    'ANGSTADT': 0,
    'ANGSTEN': 0,
    'ANGSTMAN': 0,
    'ANGSTROM': 0,
    'ANGTON': 0,
    'ANGUAY': 0,
    'ANGUEIRA': 0,
    'ANGUELOVA': 0,
    'ANGUIANO': 0,
    'ANGUINO': 0,
    'ANGUISH': 0,
    'ANGULO': 0,
    'ANGUS': 0,
    'ANGWIN': 0,
    'ANGYAL': 0,
    'ANH': 1,
    'ANHALT': 0,
    'ANHORN': 0,
    'ANI': 0,
    'ANIBAL': 0.9881422924901185,
    'ANIBAS': 0,
    'ANICA': 0,
    'ANICETE': 0,
    'ANICETO': 0,
    'ANICH': 0,
    'ANICK': 0,
    'ANIDO': 0,
    'ANIEL': 0,
    'ANIELLO': 0,
    'ANIKA': 1,
    'ANIL': 0,
    'ANIM': 0,
    'ANIMA': 0,
    'ANIMAS': 0,
    'ANIMASHAUN': 0,
    'ANIOL': 0,
    'ANIS': 0,
    'ANISA': 1,
    'ANISH': 0,
    'ANISHA': 1,
    'ANISIMOV': 0,
    'ANISSA': 1,
    'ANITA': 0.9997531473710195,
    'ANITRA': 1,
    'ANJA': 1,
    'ANJANETTE': 1,
    'ANJELICA': 1,
    'ANJOS': 0,
    'ANJUM': 0,
    'ANKE': 0,
    'ANKELE': 0,
    'ANKENBAUER': 0,
    'ANKENBRAND': 0,
    'ANKENBRANDT': 0,
    'ANKENBRUCK': 0,
    'ANKENEY': 0,
    'ANKENMAN': 0,
    'ANKENY': 0,
    'ANKER': 0,
    'ANKERS': 0,
    'ANKERSON': 0,
    'ANKIEWICZ': 0,
    'ANKLAM': 0,
    'ANKLEY': 0,
    'ANKNER': 0,
    'ANKNEY': 0,
    'ANKRAH': 0,
    'ANKROM': 0,
    'ANKRUM': 0,
    'ANKUM': 0,
    'ANLAUF': 0,
    'ANLEU': 0,
    'ANLIKER': 0,
    'ANN': 0.9993685308733493,
    'ANNA': 0.9992051776995572,
    'ANNABEL': 0.9836065573770493,
    'ANNABELL': 1,
    'ANNABELLE': 1,
    'ANNABLE': 0,
    'ANNAL': 0,
    'ANNALA': 0,
    'ANNALEE': 1,
    'ANNALISA': 1,
    'ANNAMAE': 1,
    'ANNAMALAI': 0,
    'ANNAMARIA': 1,
    'ANNAMARIE': 1,
    'ANNAN': 0,
    'ANNAND': 0,
    'ANNARINO': 0,
    'ANNARUMMA': 0,
    'ANNAS': 0,
    'ANNE': 0.9992987377279102,
    'ANNEAR': 0,
    'ANNEKEN': 0,
    'ANNELIESE': 1,
    'ANNELLE': 1,
    'ANNEMARIE': 1,
    'ANNEN': 0,
    'ANNER': 0,
    'ANNERINO': 0,
    'ANNES': 0,
    'ANNESE': 0,
    'ANNESI': 0,
    'ANNESLEY': 0,
    'ANNESS': 0,
    'ANNETT': 0.8849557522123894,
    'ANNETTA': 1,
    'ANNETTE': 0.9993604093380236,
    'ANNIBALE': 0,
    'ANNICCHIARICO': 0,
    'ANNICE': 1,
    'ANNICELLI': 0,
    'ANNICHIARICO': 0,
    'ANNIE': 1,
    'ANNIKA': 1,
    'ANNIN': 0,
    'ANNING': 0,
    'ANNINO': 0,
    'ANNIS': 0.5434782608695653,
    'ANNISON': 0,
    'ANNITA': 1,
    'ANNMARIE': 1,
    'ANNO': 0,
    'ANNON': 0,
    'ANNONI': 0,
    'ANNORENO': 0,
    'ANNUNZIATA': 0,
    'ANNUNZIATO': 0,
    'ANNUZZI': 0,
    'ANO': 0,
    'ANON': 0,
    'ANONUEVO': 0,
    'ANONYMOUS': 0,
    'ANORVE': 0,
    'ANOSIKE': 0,
    'ANSAH': 0,
    'ANSALDI': 0,
    'ANSALDO': 0,
    'ANSARA': 0,
    'ANSARDI': 0,
    'ANSARI': 0,
    'ANSARY': 0,
    'ANSAY': 0,
    'ANSBACH': 0,
    'ANSBERRY': 0,
    'ANSBRO': 0,
    'ANSCHUETZ': 0,
    'ANSCHUTZ': 0,
    'ANSEL': 0,
    'ANSELL': 0,
    'ANSELM': 0,
    'ANSELME': 0,
    'ANSELMENT': 0,
    'ANSELMI': 0,
    'ANSELMO': 0,
    'ANSETH': 0,
    'ANSHUTZ': 0,
    'ANSLEY': 0,
    'ANSLINGER': 0,
    'ANSLOW': 0,
    'ANSMAN': 0,
    'ANSOLABEHERE': 0,
    'ANSON': 0,
    'ANSONG': 0,
    'ANSORGE': 0,
    'ANSPACH': 0,
    'ANSPAUGH': 0,
    'ANSTADT': 0,
    'ANSTAETT': 0,
    'ANSTEAD': 0,
    'ANSTED': 0,
    'ANSTETT': 0,
    'ANSTEY': 0,
    'ANSTINE': 0,
    'ANSTROM': 0,
    'ANTA': 0,
    'ANTAKI': 0,
    'ANTAL': 0,
    'ANTALEK': 0,
    'ANTAO': 0,
    'ANTAR': 0,
    'ANTAYA': 0,
    'ANTCLIFF': 0,
    'ANTCZAK': 0,
    'ANTE': 0,
    'ANTEAU': 0,
    'ANTEBI': 0,
    'ANTEE': 0,
    'ANTEL': 0,
    'ANTELL': 0,
    'ANTELO': 0,
    'ANTELOPE': 0,
    'ANTENOR': 0,
    'ANTENUCCI': 0,
    'ANTEPARA': 0,
    'ANTER': 0,
    'ANTES': 0,
    'ANTEZANA': 0,
    'ANTHES': 0,
    'ANTHIS': 0,
    'ANTHOFER': 0,
    'ANTHOLZ': 0,
    'ANTHON': 0,
    'ANTHONEY': 0,
    'ANTHONY': 0.9739953990825072,
    'ANTHROP': 0,
    'ANTI': 0,
    'ANTIA': 0,
    'ANTIC': 0,
    'ANTICH': 0,
    'ANTICO': 0,
    'ANTIDORMI': 0,
    'ANTIEAU': 0,
    'ANTIGUA': 0,
    'ANTIL': 0,
    'ANTILA': 0,
    'ANTILL': 0,
    'ANTILLA': 0,
    'ANTILLEY': 0,
    'ANTILLON': 0,
    'ANTIMO': 0,
    'ANTIN': 0,
    'ANTINORE': 0,
    'ANTINORI': 0,
    'ANTINORO': 0,
    'ANTINOZZI': 0,
    'ANTINUCCI': 0,
    'ANTIONE': 0.99009900990099,
    'ANTIONETTE': 1,
    'ANTIS': 0,
    'ANTISDEL': 0,
    'ANTISTA': 0,
    'ANTKIEWICZ': 0,
    'ANTKOWIAK': 0,
    'ANTLE': 0,
    'ANTLER': 0,
    'ANTLEY': 0,
    'ANTMAN': 0,
    'ANTO': 0,
    'ANTOCI': 0,
    'ANTOGNOLI': 0,
    'ANTOINE': 0.8501594048884166,
    'ANTOINETTE': 0.9989594172736732,
    'ANTOL': 0,
    'ANTOLAK': 0,
    'ANTOLICK': 0,
    'ANTOLIK': 0,
    'ANTOLIN': 0,
    'ANTOLINE': 0,
    'ANTOLINI': 0,
    'ANTOLINO': 0,
    'ANTON': 0.8469055374592833,
    'ANTONA': 0,
    'ANTONACCI': 0,
    'ANTONACCIO': 0,
    'ANTONAKOS': 0,
    'ANTONE': 0.8223684210526316,
    'ANTONELLI': 0,
    'ANTONELLIS': 0,
    'ANTONELLO': 0,
    'ANTONETTA': 1,
    'ANTONETTE': 0.9900990099009901,
    'ANTONETTI': 0,
    'ANTONETTY': 0,
    'ANTONGIORGI': 0,
    'ANTONGIOVANNI': 0,
    'ANTONI': 0,
    'ANTONIA': 0.9982083439979523,
    'ANTONIADES': 0,
    'ANTONIADIS': 0,
    'ANTONIAK': 0,
    'ANTONIAN': 0,
    'ANTONIAZZI': 0,
    'ANTONICELLI': 0,
    'ANTONICH': 0,
    'ANTONICK': 0,
    'ANTONIDES': 0,
    'ANTONIE': 0,
    'ANTONIELLO': 0,
    'ANTONIETTA': 1,
    'ANTONIETTI': 0,
    'ANTONIEWICZ': 0,
    'ANTONIK': 0,
    'ANTONINA': 1,
    'ANTONINI': 0,
    'ANTONINO': 0,
    'ANTONIO': 0.9805423624942546,
    'ANTONIOLI': 0,
    'ANTONIOS': 0,
    'ANTONIOTTI': 0,
    'ANTONIOU': 0,
    'ANTONIS': 0,
    'ANTONITIS': 0,
    'ANTONIUK': 0,
    'ANTONOFF': 0,
    'ANTONOPOULOS': 0,
    'ANTONOV': 0,
    'ANTONOVICH': 0,
    'ANTONOWICZ': 0,
    'ANTONS': 0,
    'ANTONSEN': 0,
    'ANTONSON': 0,
    'ANTONUCCI': 0,
    'ANTONUCCIO': 0,
    'ANTONY': 0.9512485136741974,
    'ANTONYAN': 0,
    'ANTOON': 0,
    'ANTOR': 0,
    'ANTOS': 0,
    'ANTOSH': 0,
    'ANTOSIEWICZ': 0,
    'ANTOSZ': 0,
    'ANTOSZEWSKI': 0,
    'ANTOUN': 0,
    'ANTRAM': 0,
    'ANTRICAN': 0,
    'ANTRIM': 0,
    'ANTROBUS': 0,
    'ANTRUM': 0,
    'ANTTILA': 0,
    'ANTU': 0,
    'ANTUNA': 0,
    'ANTUNES': 0,
    'ANTUNEZ': 0,
    'ANTUS': 0,
    'ANTWAN': 1,
    'ANTWI': 0,
    'ANTWINE': 0,
    'ANTZ': 0,
    'ANUNCIACION': 0,
    'ANUNDSON': 0,
    'ANUNSON': 0,
    'ANUSZEWSKI': 0,
    'ANUSZKIEWICZ': 0,
    'ANVARI': 0,
    'ANWAR': 0,
    'ANWARI': 0,
    'ANWAY': 0,
    'ANWEILER': 0,
    'ANWER': 0,
    'ANYA': 1,
    'ANYAN': 0,
    'ANYANWU': 0,
    'ANZ': 0,
    'ANZAI': 0,
    'ANZALDI': 0,
    'ANZALDO': 0,
    'ANZALDUA': 0,
    'ANZALONE': 0,
    'ANZANO': 0,
    'ANZAR': 0,
    'ANZELC': 0,
    'ANZELMO': 0,
    'ANZELONE': 0,
    'ANZEVINO': 0,
    'ANZIANI': 0,
    'ANZIANO': 0,
    'ANZILOTTI': 0,
    'ANZIVINO': 0,
    'ANZO': 0,
    'ANZOLA': 0,
    'ANZORA': 0,
    'ANZOVINO': 0,
    'ANZUALDA': 0,
    'ANZUETO': 0,
    'ANZUR': 0,
    'ANZURES': 0,
    'AO': 0,
    'AOKI': 0,
    'AONO': 0,
    'AOUDE': 0,
    'AOUN': 0,
    'AOYAGI': 0,
    'AOYAMA': 0,
    'APA': 0,
    'APACHE': 0,
    'APACHITO': 0,
    'APACIBLE': 0,
    'APAEZ': 0,
    'APALATEGUI': 0,
    'APANA': 0,
    'APARICIO': 0,
    'APARO': 0,
    'APAZA': 0,
    'APEL': 0,
    'APELIAN': 0,
    'APELT': 0,
    'APER': 0,
    'APFEL': 0,
    'APFELBAUM': 0,
    'APFELBECK': 0,
    'APFFEL': 0,
    'APGAR': 0,
    'APGER': 0,
    'APGOOD': 0,
    'APICE': 0,
    'APICELLA': 0,
    'APICELLI': 0,
    'APIGO': 0,
    'APILADO': 0,
    'APISA': 0,
    'APITZ': 0,
    'APKARIAN': 0,
    'APKE': 0,
    'APKER': 0,
    'APKING': 0,
    'APLAND': 0,
    'APLEY': 0,
    'APLIN': 0,
    'APLING': 0,
    'APO': 0,
    'APODACA': 0,
    'APOL': 0,
    'APOLINAR': 0,
    'APOLINARIO': 0,
    'APOLITO': 0,
    'APOLLO': 0,
    'APOLLON': 0,
    'APOLLONIO': 0,
    'APOLO': 0,
    'APOLONIA': 1,
    'APOLONIO': 0,
    'APON': 0,
    'APONE': 0,
    'APONTE': 0,
    'APOSHIAN': 0,
    'APOSTLE': 0,
    'APOSTOL': 0,
    'APOSTOLAKIS': 0,
    'APOSTOLICO': 0,
    'APOSTOLIDES': 0,
    'APOSTOLIDIS': 0,
    'APOSTOLOPOULOS': 0,
    'APOSTOLOS': 0,
    'APOSTOLOU': 0,
    'APP': 0,
    'APPEL': 0,
    'APPELBAUM': 0,
    'APPELDORN': 0,
    'APPELGATE': 0,
    'APPELGREN': 0,
    'APPELHANS': 0,
    'APPELHANZ': 0,
    'APPELL': 0,
    'APPELLO': 0,
    'APPELMAN': 0,
    'APPELQUIST': 0,
    'APPELT': 0,
    'APPENZELLER': 0,
    'APPERSON': 0,
    'APPERT': 0,
    'APPIAH': 0,
    'APPICE': 0,
    'APPL': 0,
    'APPLE': 0,
    'APPLEBAUM': 0,
    'APPLEBEE': 0,
    'APPLEBERRY': 0,
    'APPLEBURY': 0,
    'APPLEBY': 0,
    'APPLEFORD': 0,
    'APPLEGARTH': 0,
    'APPLEGATE': 0,
    'APPLEGET': 0,
    'APPLEHANS': 0,
    'APPLEMAN': 0,
    'APPLEN': 0,
    'APPLEQUIST': 0,
    'APPLER': 0,
    'APPLETON': 0,
    'APPLEWHAITE': 0,
    'APPLEWHITE': 0,
    'APPLEY': 0,
    'APPLEYARD': 0,
    'APPLIN': 0,
    'APPLING': 0,
    'APPOLD': 0,
    'APPOLON': 0,
    'APPOLONIA': 0,
    'APPS': 0,
    'APRAHAMIAN': 0,
    'APREA': 0,
    'APREZA': 0,
    'APRIL': 0.9968282736746715,
    'APRILE': 0,
    'APRILL': 0,
    'APRUZZESE': 0,
    'APRYL': 1,
    'APSEY': 0,
    'APSLEY': 0,
    'APT': 0,
    'APTAKER': 0,
    'APTE': 0,
    'APTED': 0,
    'APTEKAR': 0,
    'APTER': 0,
    'APTHORP': 0,
    'APUZZO': 0,
    'AQEEL': 0,
    'AQUADRO': 0,
    'AQUI': 0,
    'AQUIL': 0,
    'AQUILA': 0,
    'AQUILANTE': 0,
    'AQUILAR': 0,
    'AQUILINA': 0,
    'AQUILINO': 0,
    'AQUILLA': 0,
    'AQUININGOC': 0,
    'AQUINO': 0,
    'AQUIRRE': 0,
    'AR': 0,
    'ARA': 0.8333333333333334,
    'ARAB': 0,
    'ARABI': 0,
    'ARABIA': 0,
    'ARABIAN': 0,
    'ARABIE': 0,
    'ARABO': 0,
    'ARABYAN': 0,
    'ARACE': 0,
    'ARACELI': 1,
    'ARACELIS': 1,
    'ARACELY': 1,
    'ARACENA': 0,
    'ARAD': 0,
    'ARADO': 0,
    'ARAFA': 0,
    'ARAFAT': 0,
    'ARAGAKI': 0,
    'ARAGHI': 0,
    'ARAGO': 0,
    'ARAGON': 0,
    'ARAGONA': 0,
    'ARAGONES': 0,
    'ARAGONEZ': 0,
    'ARAGUNDI': 0,
    'ARAGUZ': 0,
    'ARAI': 0,
    'ARAIA': 0,
    'ARAICA': 0,
    'ARAIN': 0,
    'ARAIZA': 0,
    'ARAJ': 0,
    'ARAKAKI': 0,
    'ARAKAWA': 0,
    'ARAKELIAN': 0,
    'ARAKELYAN': 0,
    'ARAKI': 0,
    'ARAM': 0,
    'ARAMAKI': 0,
    'ARAMAYO': 0,
    'ARAMBEL': 0,
    'ARAMBUL': 0,
    'ARAMBULA': 0,
    'ARAMBULO': 0,
    'ARAMBURO': 0,
    'ARAMBURU': 0,
    'ARAMINI': 0,
    'ARAN': 0,
    'ARANA': 0,
    'ARANAS': 0,
    'ARANCIBIA': 0,
    'ARANCIO': 0,
    'ARAND': 0,
    'ARANDA': 0,
    'ARANDIA': 0,
    'ARANEDA': 0,
    'ARANEO': 0,
    'ARANETA': 0,
    'ARANGIO': 0,
    'ARANGO': 0,
    'ARANGUA': 0,
    'ARANGURE': 0,
    'ARANGUREN': 0,
    'ARANIBAR': 0,
    'ARANIVA': 0,
    'ARANJO': 0,
    'ARANKI': 0,
    'ARANO': 0,
    'ARANOFF': 0,
    'ARANT': 0,
    'ARANTES': 0,
    'ARANYOS': 0,
    'ARANZA': 0,
    'ARANZAZU': 0,
    'ARAO': 0,
    'ARAOS': 0,
    'ARAOZ': 0,
    'ARAQUE': 0,
    'ARAS': 0,
    'ARASHIRO': 0,
    'ARASIM': 0,
    'ARASIN': 0,
    'ARASMITH': 0,
    'ARASTU': 0,
    'ARATA': 0,
    'ARATANI': 0,
    'ARATO': 0,
    'ARAU': 0,
    'ARAUGO': 0,
    'ARAUJO': 0,
    'ARAUZ': 0,
    'ARAUZA': 0,
    'ARAVE': 0,
    'ARAVENA': 0,
    'ARAVJO': 0,
    'ARAYA': 0,
    'ARAZA': 0,
    'ARAZI': 0,
    'ARB': 0,
    'ARBACH': 0,
    'ARBAIZA': 0,
    'ARBALLO': 0,
    'ARBAN': 0,
    'ARBANAS': 0,
    'ARBAUGH': 0,
    'ARBEGAST': 0,
    'ARBEIT': 0,
    'ARBEITER': 0,
    'ARBELAEZ': 0,
    'ARBELO': 0,
    'ARBER': 0,
    'ARBERRY': 0,
    'ARBES': 0,
    'ARBIA': 0,
    'ARBINI': 0,
    'ARBISI': 0,
    'ARBIT': 0,
    'ARBIZO': 0,
    'ARBIZU': 0,
    'ARBLASTER': 0,
    'ARBLE': 0,
    'ARBO': 0,
    'ARBOGAST': 0,
    'ARBOLEDA': 0,
    'ARBON': 0,
    'ARBONA': 0,
    'ARBOR': 0,
    'ARBORE': 0,
    'ARBOUR': 0,
    'ARBUCCI': 0,
    'ARBUCKLE': 0,
    'ARBULU': 0,
    'ARBUTHNOT': 0,
    'ARBUTINA': 0,
    'ARCA': 0,
    'ARCADI': 0,
    'ARCADIA': 0,
    'ARCADIO': 0,
    'ARCADIPANE': 0,
    'ARCAMONE': 0,
    'ARCAND': 0,
    'ARCANGEL': 0,
    'ARCANGELI': 0,
    'ARCARA': 0,
    'ARCARI': 0,
    'ARCARO': 0,
    'ARCE': 0,
    'ARCEGA': 0,
    'ARCELAY': 0,
    'ARCELIA': 1,
    'ARCELLA': 0,
    'ARCEMENT': 0,
    'ARCEMONT': 0,
    'ARCENEAUX': 0,
    'ARCENTALES': 0,
    'ARCEO': 0,
    'ARCERI': 0,
    'ARCESE': 0,
    'ARCH': 0,
    'ARCHACKI': 0,
    'ARCHAMBAULT': 0,
    'ARCHAMBEAU': 0,
    'ARCHAMBEAULT': 0,
    'ARCHAMBO': 0,
    'ARCHANGEL': 0,
    'ARCHARD': 0,
    'ARCHBALD': 0,
    'ARCHBELL': 0,
    'ARCHBOLD': 0,
    'ARCHDALE': 0,
    'ARCHDEACON': 0,
    'ARCHE': 0,
    'ARCHER': 0,
    'ARCHEY': 0,
    'ARCHIBALD': 0,
    'ARCHIBEQUE': 0,
    'ARCHIBOLD': 0,
    'ARCHIE': 0.9322033898305085,
    'ARCHIELD': 0,
    'ARCHILA': 0,
    'ARCHILLA': 0,
    'ARCHINAL': 0,
    'ARCHULETA': 0,
    'ARCHULETTA': 0,
    'ARCHUNDE': 0,
    'ARCHUNDIA': 0,
    'ARCHUT': 0,
    'ARCIA': 0,
    'ARCIAGA': 0,
    'ARCIDIACONO': 0,
    'ARCIERI': 0,
    'ARCIERO': 0,
    'ARCIGA': 0,
    'ARCILA': 0,
    'ARCILLA': 0,
    'ARCINAS': 0,
    'ARCINIEGA': 0,
    'ARCINIEGAS': 0,
    'ARCISZEWSKI': 0,
    'ARCO': 0,
    'ARCOLEO': 0,
    'ARCOREN': 0,
    'ARCOS': 0,
    'ARCURE': 0,
    'ARCURI': 0,
    'ARCUS': 0,
    'ARD': 0,
    'ARDAGNA': 0,
    'ARDALAN': 0,
    'ARDAN': 0,
    'ARDARY': 0,
    'ARDATH': 1,
    'ARDELEAN': 0,
    'ARDELIA': 1,
    'ARDELJAN': 0,
    'ARDELL': 0.9523809523809523,
    'ARDELLA': 1,
    'ARDELLE': 1,
    'ARDEN': 0.8385744234800838,
    'ARDENTE': 0,
    'ARDERY': 0,
    'ARDILA': 0,
    'ARDILLO': 0,
    'ARDINGER': 0,
    'ARDIRE': 0,
    'ARDIS': 0.8771929824561403,
    'ARDISON': 0,
    'ARDISTER': 0,
    'ARDITH': 1,
    'ARDITI': 0,
    'ARDITO': 0,
    'ARDIZZONE': 0,
    'ARDLEY': 0,
    'ARDNER': 0,
    'ARDO': 0,
    'ARDOIN': 0,
    'ARDOLINO': 0,
    'ARDON': 0,
    'ARDRA': 0,
    'ARDREY': 0,
    'ARDRY': 0,
    'ARDS': 0,
    'ARDUINI': 0,
    'ARDUINO': 0,
    'ARDUSER': 0,
    'ARE': 0,
    'AREA': 0,
    'AREAS': 0,
    'AREBALO': 0,
    'AREBALOS': 0,
    'ARECHAR': 0,
    'ARECHIGA': 0,
    'AREDONDO': 0,
    'AREF': 0,
    'AREFORD': 0,
    'AREGOOD': 0,
    'AREHART': 0,
    'AREHEART': 0,
    'AREIAS': 0,
    'AREIZAGA': 0,
    'AREL': 0,
    'ARELIANES': 0,
    'ARELL': 0,
    'ARELLAND': 0,
    'ARELLANES': 0,
    'ARELLANO': 0,
    'ARELLANOS': 0,
    'ARENA': 0,
    'ARENAL': 0,
    'ARENALES': 0,
    'ARENAS': 0,
    'ARENBERG': 0,
    'ARENCIBIA': 0,
    'AREND': 0,
    'ARENDALE': 0,
    'ARENDALL': 0,
    'ARENDAS': 0,
    'ARENDELL': 0,
    'ARENDER': 0,
    'ARENDES': 0,
    'ARENDS': 0,
    'ARENDSEN': 0,
    'ARENDT': 0,
    'ARENELLA': 0,
    'ARENIVAR': 0,
    'ARENIVAS': 0,
    'ARENS': 0,
    'ARENSBERG': 0,
    'ARENSDORF': 0,
    'ARENSMAN': 0,
    'ARENSMEYER': 0,
    'ARENSON': 0,
    'ARENSTEIN': 0,
    'ARENT': 0,
    'ARENTH': 0,
    'ARENTS': 0,
    'ARENTSEN': 0,
    'ARENTZ': 0,
    'ARENZ': 0,
    'AREOLA': 0,
    'ARES': 0,
    'ARESCO': 0,
    'ARESON': 0,
    'ARETAKIS': 0,
    'ARETHA': 1,
    'ARETZ': 0,
    'AREVALO': 0,
    'AREVALOS': 0,
    'AREY': 0,
    'AREYAN': 0,
    'AREYANO': 0,
    'ARFA': 0,
    'ARFLACK': 0,
    'ARFLIN': 0,
    'ARFMAN': 0,
    'ARFORD': 0,
    'ARFSTEN': 0,
    'ARFT': 0,
    'ARGABRIGHT': 0,
    'ARGABRITE': 0,
    'ARGALL': 0,
    'ARGANBRIGHT': 0,
    'ARGANDA': 0,
    'ARGANDONA': 0,
    'ARGAST': 0,
    'ARGEL': 0,
    'ARGELIA': 1,
    'ARGENAL': 0,
    'ARGENBRIGHT': 0,
    'ARGENIO': 0,
    'ARGENT': 0,
    'ARGENTA': 0,
    'ARGENTI': 0,
    'ARGENTIERI': 0,
    'ARGENTINA': 0.9433962264150944,
    'ARGENTINE': 0,
    'ARGENTINO': 0,
    'ARGENTO': 0,
    'ARGENZIANO': 0,
    'ARGENZIO': 0,
    'ARGEROS': 0,
    'ARGERSINGER': 0,
    'ARGETA': 0,
    'ARGETSINGER': 0,
    'ARGILA': 0,
    'ARGIRO': 0,
    'ARGIROS': 0,
    'ARGO': 0,
    'ARGOE': 0,
    'ARGOMANIZ': 0,
    'ARGON': 0,
    'ARGOT': 0,
    'ARGOTE': 0,
    'ARGOTSINGER': 0,
    'ARGOTT': 0,
    'ARGRAVES': 0,
    'ARGUDIN': 0,
    'ARGUDO': 0,
    'ARGUE': 0,
    'ARGUEDAS': 0,
    'ARGUELLES': 0,
    'ARGUELLEZ': 0,
    'ARGUELLO': 0,
    'ARGUERA': 0,
    'ARGUETA': 0,
    'ARGUIJO': 0,
    'ARGUILEZ': 0,
    'ARGUIN': 0,
    'ARGUINZONI': 0,
    'ARGUMANIZ': 0,
    'ARGUMEDO': 0,
    'ARGUS': 0,
    'ARGUST': 0,
    'ARGY': 0,
    'ARGYLE': 0,
    'ARGYRIS': 0,
    'ARGYROPOULOS': 0,
    'ARGYROS': 0,
    'ARHART': 0,
    'ARHELGER': 0,
    'ARI': 0,
    'ARIA': 0,
    'ARIAGA': 0,
    'ARIAIL': 0,
    'ARIAL': 0,
    'ARIAN': 0,
    'ARIANA': 1,
    'ARIANE': 1,
    'ARIANNA': 1,
    'ARIANNE': 1,
    'ARIANO': 0,
    'ARIANS': 0,
    'ARIAS': 0,
    'ARIAZ': 0,
    'ARICA': 1,
    'ARICK': 0,
    'ARICO': 0,
    'ARIDA': 0,
    'ARIDI': 0,
    'ARIE': 0.9523809523809523,
    'ARIEL': 0.9887005649717513,
    'ARIELLE': 1,
    'ARIEMMA': 0,
    'ARIENO': 0,
    'ARIENS': 0,
    'ARIENT': 0,
    'ARIES': 0,
    'ARIETA': 0,
    'ARIETTA': 0,
    'ARIF': 0,
    'ARIFI': 0,
    'ARIGO': 0,
    'ARIGONI': 0,
    'ARIMA': 0,
    'ARIMOTO': 0,
    'ARIN': 0,
    'ARINAGA': 0,
    'ARINDER': 0,
    'ARING': 0,
    'ARINGTON': 0,
    'ARINI': 0,
    'ARINO': 0,
    'ARIOLA': 0,
    'ARION': 0,
    'ARIOS': 0,
    'ARIS': 0,
    'ARISMAN': 0,
    'ARISMENDEZ': 0,
    'ARISMENDI': 0,
    'ARISON': 0,
    'ARISPE': 0,
    'ARISS': 0,
    'ARISTA': 0,
    'ARISTIDE': 0,
    'ARISTIL': 0,
    'ARISTILDE': 0,
    'ARISTIZABAL': 0,
    'ARISTONDO': 0,
    'ARISTY': 0,
    'ARITA': 0,
    'ARIVETT': 0,
    'ARIZ': 0,
    'ARIZA': 0,
    'ARIZAGA': 0,
    'ARIZMENDEZ': 0,
    'ARIZMENDI': 0,
    'ARIZOLA': 0,
    'ARIZONA': 0,
    'ARIZPE': 0,
    'ARIZZI': 0,
    'ARJES': 0,
    'ARJON': 0,
    'ARJONA': 0,
    'ARJOON': 0,
    'ARJUN': 0,
    'ARJUNE': 0,
    'ARK': 0,
    'ARKADIE': 0,
    'ARKANSAS': 0,
    'ARKELL': 0,
    'ARKEMA': 0,
    'ARKENBERG': 0,
    'ARKENS': 0,
    'ARKFELD': 0,
    'ARKIN': 0,
    'ARKINS': 0,
    'ARKINSON': 0,
    'ARKLE': 0,
    'ARKLEY': 0,
    'ARKO': 0,
    'ARKUS': 0,
    'ARKWRIGHT': 0,
    'ARLA': 1,
    'ARLAN': 0,
    'ARLAND': 0,
    'ARLE': 0,
    'ARLEAN': 1,
    'ARLEDGE': 0,
    'ARLEEN': 1,
    'ARLEN': 0.9592326139088729,
    'ARLENA': 1,
    'ARLENE': 1,
    'ARLEO': 0,
    'ARLET': 0,
    'ARLETH': 0,
    'ARLETHA': 1,
    'ARLETTA': 1,
    'ARLETTE': 1,
    'ARLIA': 0,
    'ARLIE': 1,
    'ARLIN': 0,
    'ARLINDA': 1,
    'ARLINE': 0.9514747859181731,
    'ARLING': 0,
    'ARLINGHAUS': 0,
    'ARLINGTON': 0,
    'ARLINT': 0,
    'ARLISS': 0,
    'ARLOTTA': 0,
    'ARLOW': 0,
    'ARLT': 0,
    'ARLYNE': 1,
    'ARM': 0,
    'ARMA': 0,
    'ARMACOST': 0,
    'ARMADA': 0,
    'ARMADILLO': 0,
    'ARMAGOST': 0,
    'ARMAH': 0,
    'ARMALY': 0,
    'ARMAN': 0,
    'ARMAND': 0.9331259720062208,
    'ARMANDA': 1,
    'ARMANDINA': 1,
    'ARMANDO': 0.9963923724445971,
    'ARMANI': 0,
    'ARMANINI': 0,
    'ARMANINO': 0,
    'ARMANIOUS': 0,
    'ARMANN': 0,
    'ARMANT': 0,
    'ARMANTROUT': 0,
    'ARMAO': 0,
    'ARMAS': 0,
    'ARMATA': 0,
    'ARMATIS': 0,
    'ARMATO': 0,
    'ARMATYS': 0,
    'ARMBRECHT': 0,
    'ARMBRESTER': 0,
    'ARMBRISTER': 0,
    'ARMBRUST': 0,
    'ARMBRUSTER': 0,
    'ARMEL': 0,
    'ARMELI': 0,
    'ARMELIN': 0,
    'ARMELL': 0,
    'ARMELLINO': 0,
    'ARMEN': 0,
    'ARMENDAREZ': 0,
    'ARMENDARIS': 0,
    'ARMENDARIZ': 0,
    'ARMENGOL': 0,
    'ARMENI': 0,
    'ARMENIA': 0,
    'ARMENIO': 0,
    'ARMENT': 0,
    'ARMENTA': 0,
    'ARMENTANO': 0,
    'ARMENTEROS': 0,
    'ARMENTI': 0,
    'ARMENTO': 0,
    'ARMENTOR': 0,
    'ARMENTROUT': 0,
    'ARMER': 0,
    'ARMES': 0,
    'ARMESTO': 0,
    'ARMET': 0,
    'ARMETTA': 0,
    'ARMEY': 0,
    'ARMFIELD': 0,
    'ARMIDA': 1,
    'ARMIENTA': 0,
    'ARMIGER': 0,
    'ARMIJO': 0,
    'ARMIJOS': 0,
    'ARMIN': 0,
    'ARMINDA': 1,
    'ARMINGTON': 0,
    'ARMINIO': 0,
    'ARMINTROUT': 0,
    'ARMISTEAD': 0,
    'ARMITAGE': 0,
    'ARMITSTEAD': 0,
    'ARMKNECHT': 0,
    'ARMLIN': 0,
    'ARMOCIDA': 0,
    'ARMOCK': 0,
    'ARMOGAN': 0,
    'ARMOLD': 0,
    'ARMOLT': 0,
    'ARMON': 0,
    'ARMOND': 0,
    'ARMONTROUT': 0,
    'ARMOR': 0,
    'ARMOUR': 0,
    'ARMS': 0,
    'ARMSTEAD': 0,
    'ARMSTER': 0,
    'ARMSTONG': 0,
    'ARMSTRONG': 0,
    'ARMWOOD': 0,
    'ARMY': 0,
    'ARN': 0,
    'ARNAIZ': 0,
    'ARNAL': 0,
    'ARNALDO': 0,
    'ARNALL': 0,
    'ARNAO': 0,
    'ARNAOUT': 0,
    'ARNASON': 0,
    'ARNAU': 0,
    'ARNAUD': 0,
    'ARNAUDO': 0,
    'ARNAULT': 0,
    'ARNAUT': 0,
    'ARNAUTOVIC': 0,
    'ARNBERG': 0,
    'ARNCE': 0,
    'ARNDELL': 0,
    'ARNDER': 0,
    'ARNDORFER': 0,
    'ARNDT': 0,
    'ARNDTS': 0,
    'ARNE': 0,
    'ARNEBERG': 0,
    'ARNEL': 0,
    'ARNELL': 0,
    'ARNEMANN': 0,
    'ARNER': 0,
    'ARNERICH': 0,
    'ARNES': 0,
    'ARNESEN': 0,
    'ARNESON': 0,
    'ARNESS': 0,
    'ARNEST': 0,
    'ARNET': 0,
    'ARNETT': 0,
    'ARNETTA': 1,
    'ARNETTE': 0.5181347150259067,
    'ARNEY': 0,
    'ARNEZ': 0,
    'ARNHART': 0,
    'ARNHOLD': 0,
    'ARNHOLT': 0,
    'ARNICK': 0,
    'ARNIERI': 0,
    'ARNIM': 0,
    'ARNING': 0,
    'ARNITA': 1,
    'ARNN': 0,
    'ARNO': 0,
    'ARNOFF': 0,
    'ARNOLD': 0.5876111972578144,
    'ARNOLDI': 0,
    'ARNOLDO': 1,
    'ARNOLDUSSEN': 0,
    'ARNOLDY': 0,
    'ARNON': 0,
    'ARNONE': 0,
    'ARNOS': 0,
    'ARNOT': 0,
    'ARNOTT': 0,
    'ARNOULD': 0,
    'ARNOULT': 0,
    'ARNOUX': 0,
    'ARNOW': 0,
    'ARNOWITZ': 0,
    'ARNQUIST': 0,
    'ARNS': 0,
    'ARNSDORF': 0,
    'ARNSDORFF': 0,
    'ARNSON': 0,
    'ARNSPARGER': 0,
    'ARNSPIGER': 0,
    'ARNST': 0,
    'ARNSTEIN': 0,
    'ARNSTON': 0,
    'ARNSWALD': 0,
    'ARNT': 0,
    'ARNTSEN': 0,
    'ARNTSON': 0,
    'ARNTZ': 0,
    'ARNTZEN': 0,
    'ARNULFO': 1,
    'ARNWINE': 0,
    'ARNY': 0,
    'ARNZEN': 0,
    'ARO': 0,
    'AROCA': 0,
    'AROCHA': 0,
    'AROCHE': 0,
    'AROCHO': 0,
    'AROLA': 0,
    'AROLD': 0,
    'AROLLO': 0,
    'AROMANDO': 0,
    'AROMIN': 0,
    'ARON': 0.8849557522123894,
    'ARONE': 0,
    'ARONHALT': 0,
    'ARONICA': 0,
    'ARONIN': 0,
    'ARONIS': 0,
    'ARONNE': 0,
    'ARONOFF': 0,
    'ARONOV': 0,
    'ARONOVA': 0,
    'ARONOVITZ': 0,
    'ARONOW': 0,
    'ARONOWITZ': 0,
    'ARONS': 0,
    'ARONSON': 0,
    'ARONSTEIN': 0,
    'ARORA': 0,
    'AROS': 0,
    'AROSEMENA': 0,
    'AROSTEGUI': 0,
    'AROUTIOUNIAN': 0,
    'AROYAN': 0,
    'AROYO': 0,
    'AROZ': 0,
    'ARP': 0,
    'ARPAIA': 0,
    'ARPAN': 0,
    'ARPERO': 0,
    'ARPI': 0,
    'ARPIN': 0,
    'ARPINO': 0,
    'ARPKE': 0,
    'ARPS': 0,
    'ARQUERO': 0,
    'ARQUETA': 0,
    'ARQUETTE': 0,
    'ARQUILLA': 0,
    'ARQUINES': 0,
    'ARQUITT': 0,
    'ARR': 0,
    'ARRA': 0,
    'ARRABITO': 0,
    'ARRADONDO': 0,
    'ARRAMBIDE': 0,
    'ARRANAGA': 0,
    'ARRAND': 0,
    'ARRANT': 0,
    'ARRANTS': 0,
    'ARRAS': 0,
    'ARRASMITH': 0,
    'ARRASTIA': 0,
    'ARRATIA': 0,
    'ARRAZOLA': 0,
    'ARRE': 0,
    'ARREAGA': 0,
    'ARREAZOLA': 0,
    'ARRECHEA': 0,
    'ARRECIS': 0,
    'ARREDONDO': 0,
    'ARREGUI': 0,
    'ARREGUIN': 0,
    'ARRELL': 0,
    'ARRELLANO': 0,
    'ARRELLIN': 0,
    'ARRENDALE': 0,
    'ARRENDELL': 0,
    'ARRENDO': 0,
    'ARRENDONDO': 0,
    'ARREOLA': 0,
    'ARREY': 0,
    'ARREZ': 0,
    'ARREZOLA': 0,
    'ARRIA': 0,
    'ARRIAGA': 0,
    'ARRIAGADA': 0,
    'ARRIAZA': 0,
    'ARRIAZOLA': 0,
    'ARRIBAS': 0,
    'ARRICK': 0,
    'ARRIERO': 0,
    'ARRIES': 0,
    'ARRIETA': 0,
    'ARRIGA': 0,
    'ARRIGHI': 0,
    'ARRIGO': 0,
    'ARRIGONI': 0,
    'ARRINDELL': 0,
    'ARRINGTON': 0,
    'ARRIOLA': 0,
    'ARRIS': 0,
    'ARRISOLA': 0,
    'ARRISON': 0,
    'ARRITOLA': 0,
    'ARRITT': 0,
    'ARRIVILLAGA': 0,
    'ARRIZOLA': 0,
    'ARRIZON': 0,
    'ARRO': 0,
    'ARROCHA': 0,
    'ARROJO': 0,
    'ARROLIGA': 0,
    'ARROLLO': 0,
    'ARRON': 0.9864364981504316,
    'ARRONA': 0,
    'ARROTT': 0,
    'ARROW': 0,
    'ARROWOOD': 0,
    'ARROWSMITH': 0,
    'ARROYA': 0,
    'ARROYAVE': 0,
    'ARROYD': 0,
    'ARROYO': 0,
    'ARROYOS': 0,
    'ARRUDA': 0,
    'ARRUE': 0,
    'ARRUFAT': 0,
    'ARRUNATEGUI': 0,
    'ARSCOTT': 0,
    'ARSEMENT': 0,
    'ARSENAULT': 0,
    'ARSENEAU': 0,
    'ARSENEAULT': 0,
    'ARSENIAN': 0,
    'ARSHAD': 0,
    'ARSLAN': 0,
    'ARSLANIAN': 0,
    'ARSOLA': 0,
    'ARSON': 0,
    'ART': 0.974025974025974,
    'ARTALE': 0,
    'ARTALEJO': 0,
    'ARTAVIA': 0,
    'ARTEAGA': 0,
    'ARTECHE': 0,
    'ARTEGA': 0,
    'ARTEMENKO': 0,
    'ARTER': 0,
    'ARTERBERRY': 0,
    'ARTERBURN': 0,
    'ARTERBURY': 0,
    'ARTERO': 0,
    'ARTERS': 0,
    'ARTES': 0,
    'ARTESE': 0,
    'ARTETA': 0,
    'ARTH': 0,
    'ARTHAUD': 0,
    'ARTHER': 0,
    'ARTHERTON': 0,
    'ARTHO': 0,
    'ARTHOFER': 0,
    'ARTHUR': 0.9707619184790436,
    'ARTHURS': 0,
    'ARTHURTON': 0,
    'ARTIAGA': 0,
    'ARTIBEE': 0,
    'ARTICA': 0,
    'ARTICE': 0,
    'ARTIE': 1,
    'ARTIGA': 0,
    'ARTIGAS': 0,
    'ARTIGUE': 0,
    'ARTIGUES': 0,
    'ARTILES': 0,
    'ARTIM': 0,
    'ARTIME': 0,
    'ARTIN': 0,
    'ARTINGER': 0,
    'ARTINIAN': 0,
    'ARTINO': 0,
    'ARTIS': 0,
    'ARTISON': 0,
    'ARTIST': 0,
    'ARTLEY': 0,
    'ARTLIP': 0,
    'ARTMAN': 0,
    'ARTMANN': 0,
    'ARTOLA': 0,
    'ARTON': 0,
    'ARTRIP': 0,
    'ARTS': 0,
    'ARTURA': 0,
    'ARTURI': 0,
    'ARTURO': 0.9976798143851507,
    'ARTUS': 0,
    'ARTUSA': 0,
    'ARTUSO': 0,
    'ARTUZ': 0,
    'ARTWELL': 0,
    'ARTY': 0,
    'ARTZ': 0,
    'ARTZER': 0,
    'ARUCAN': 0,
    'ARUDA': 0,
    'ARUFFO': 0,
    'ARUMUGAM': 0,
    'ARUN': 0,
    'ARUNACHALAM': 0,
    'ARUNDALE': 0,
    'ARUNDEL': 0,
    'ARUTA': 0,
    'ARUTUNIAN': 0,
    'ARUTUNYAN': 0,
    'ARUTYUNOV': 0,
    'ARUTYUNYAN': 0,
    'ARVAI': 0,
    'ARVALLO': 0,
    'ARVAN': 0,
    'ARVANITES': 0,
    'ARVANITIS': 0,
    'ARVAY': 0,
    'ARVAYO': 0,
    'ARVELO': 0,
    'ARVESEN': 0,
    'ARVESON': 0,
    'ARVEY': 0,
    'ARVIA': 0,
    'ARVIDSON': 0,
    'ARVIE': 0,
    'ARVILLA': 1,
    'ARVIN': 0,
    'ARVISO': 0,
    'ARVIZO': 0,
    'ARVIZU': 0,
    'ARVOLD': 0,
    'ARWAY': 0,
    'ARWINE': 0,
    'ARWOOD': 0,
    'ARY': 0,
    'ARYA': 0,
    'ARYAL': 0,
    'ARYAN': 0,
    'ARYEE': 0,
    'ARYEH': 0,
    'ARZA': 0,
    'ARZADON': 0,
    'ARZAGA': 0,
    'ARZATE': 0,
    'ARZBERGER': 0,
    'ARZE': 0,
    'ARZETA': 0,
    'ARZILLO': 0,
    'ARZOLA': 0,
    'ARZOUMANIAN': 0,
    'ARZT': 0,
    'ARZU': 0,
    'ARZUAGA': 0,
    'ARZUMANYAN': 0,
    'ASA': 0.9615384615384616,
    'ASAAD': 0,
    'ASAD': 0,
    'ASADA': 0,
    'ASADI': 0,
    'ASADOORIAN': 0,
    'ASADORIAN': 0,
    'ASADOURIAN': 0,
    'ASAI': 0,
    'ASAKAWA': 0,
    'ASAKURA': 0,
    'ASAL': 0,
    'ASAM': 0,
    'ASAMI': 0,
    'ASAMOAH': 0,
    'ASAN': 0,
    'ASANI': 0,
    'ASANO': 0,
    'ASANTE': 0,
    'ASAO': 0,
    'ASARE': 0,
    'ASARI': 0,
    'ASARO': 0,
    'ASATO': 0,
    'ASATRYAN': 0,
    'ASAY': 0,
    'ASBACH': 0,
    'ASBECK': 0,
    'ASBEL': 0,
    'ASBELL': 0,
    'ASBERRY': 0,
    'ASBERY': 0,
    'ASBILL': 0,
    'ASBRA': 0,
    'ASBRIDGE': 0,
    'ASBROCK': 0,
    'ASBURY': 0,
    'ASBY': 0,
    'ASCANI': 0,
    'ASCANIO': 0,
    'ASCANO': 0,
    'ASCENCIO': 0,
    'ASCENCION': 0,
    'ASCENSIO': 0,
    'ASCENZI': 0,
    'ASCENZO': 0,
    'ASCH': 0,
    'ASCHAUER': 0,
    'ASCHBACHER': 0,
    'ASCHBRENNER': 0,
    'ASCHE': 0,
    'ASCHEMAN': 0,
    'ASCHENBACH': 0,
    'ASCHENBECK': 0,
    'ASCHENBRENER': 0,
    'ASCHENBRENNER': 0,
    'ASCHER': 0,
    'ASCHERL': 0,
    'ASCHERMAN': 0,
    'ASCHETTINO': 0,
    'ASCHIM': 0,
    'ASCHINGER': 0,
    'ASCHLIMAN': 0,
    'ASCHOFF': 0,
    'ASCHWANDEN': 0,
    'ASCI': 0,
    'ASCIOLLA': 0,
    'ASCIONE': 0,
    'ASCIUTTO': 0,
    'ASCOLESE': 0,
    'ASCOLI': 0,
    'ASCUE': 0,
    'ASDOURIAN': 0,
    'ASEBEDO': 0,
    'ASEFA': 0,
    'ASEL': 0,
    'ASELAGE': 0,
    'ASELTINE': 0,
    'ASEMOTA': 0,
    'ASEN': 0,
    'ASENCIO': 0,
    'ASENDORF': 0,
    'ASENJO': 0,
    'ASENSIO': 0,
    'ASEVEDO': 0,
    'ASFAHA': 0,
    'ASFAR': 0,
    'ASFAW': 0,
    'ASFELD': 0,
    'ASFOUR': 0,
    'ASGARI': 0,
    'ASGHAR': 0,
    'ASGHARI': 0,
    'ASH': 0,
    'ASHA': 1,
    'ASHABRANNER': 0,
    'ASHANTI': 1,
    'ASHAR': 0,
    'ASHAUER': 0,
    'ASHBA': 0,
    'ASHBACHER': 0,
    'ASHBAKER': 0,
    'ASHBAUGH': 0,
    'ASHBECK': 0,
    'ASHBEE': 0,
    'ASHBERRY': 0,
    'ASHBRIDGE': 0,
    'ASHBROOK': 0,
    'ASHBURN': 0,
    'ASHBURNER': 0,
    'ASHBURY': 0,
    'ASHBY': 0,
    'ASHCOM': 0,
    'ASHCRAFT': 0,
    'ASHCROFT': 0,
    'ASHDOWN': 0,
    'ASHE': 0,
    'ASHEIM': 0,
    'ASHELY': 1,
    'ASHEN': 0,
    'ASHENBRENNER': 0,
    'ASHENFELDER': 0,
    'ASHENFELTER': 0,
    'ASHENHURST': 0,
    'ASHER': 0,
    'ASHERMAN': 0,
    'ASHEY': 0,
    'ASHFAQ': 0,
    'ASHFIELD': 0,
    'ASHFORD': 0,
    'ASHFORTH': 0,
    'ASHIDA': 0,
    'ASHING': 0,
    'ASHINHURST': 0,
    'ASHJIAN': 0,
    'ASHKAR': 0,
    'ASHKENAZI': 0,
    'ASHKENAZY': 0,
    'ASHKER': 0,
    'ASHKIN': 0,
    'ASHLAND': 0,
    'ASHLAW': 0,
    'ASHLEA': 1,
    'ASHLEE': 1,
    'ASHLEIGH': 1,
    'ASHLEY': 0.958514755684567,
    'ASHLI': 1,
    'ASHLIE': 1,
    'ASHLIN': 0,
    'ASHLINE': 0,
    'ASHLOCK': 0,
    'ASHLY': 1,
    'ASHLYN': 1,
    'ASHMAN': 0,
    'ASHMEAD': 0,
    'ASHMEADE': 0,
    'ASHMENT': 0,
    'ASHMON': 0,
    'ASHMORE': 0,
    'ASHMUN': 0,
    'ASHMUS': 0,
    'ASHNER': 0,
    'ASHOK': 0,
    'ASHORN': 0,
    'ASHOUR': 0,
    'ASHPAUGH': 0,
    'ASHPOLE': 0,
    'ASHRAF': 0,
    'ASHRAFI': 0,
    'ASHTIANI': 0,
    'ASHTON': 0.48134777376654636,
    'ASHUROV': 0,
    'ASHURST': 0,
    'ASHWELL': 0,
    'ASHWILL': 0,
    'ASHWOOD': 0,
    'ASHWORTH': 0,
    'ASHY': 0,
    'ASI': 0,
    'ASIA': 0.9803921568627452,
    'ASIALA': 0,
    'ASIEDU': 0,
    'ASIF': 0,
    'ASIM': 0,
    'ASIMAKOPOULOS': 0,
    'ASING': 0,
    'ASIRE': 0,
    'ASIS': 0,
    'ASITIMBAY': 0,
    'ASK': 0,
    'ASKA': 0,
    'ASKAM': 0,
    'ASKAR': 0,
    'ASKARI': 0,
    'ASKE': 0,
    'ASKEA': 0,
    'ASKELAND': 0,
    'ASKELSON': 0,
    'ASKEN': 0,
    'ASKER': 0,
    'ASKEW': 0,
    'ASKEY': 0,
    'ASKIN': 0,
    'ASKINS': 0,
    'ASKLAND': 0,
    'ASKREN': 0,
    'ASKVIG': 0,
    'ASLAKSON': 0,
    'ASLAM': 0,
    'ASLAMI': 0,
    'ASLAN': 0,
    'ASLANI': 0,
    'ASLANIAN': 0,
    'ASLANYAN': 0,
    'ASLESEN': 0,
    'ASLESON': 0,
    'ASLETT': 0,
    'ASLEY': 1,
    'ASLIN': 0,
    'ASLINGER': 0,
    'ASMA': 0,
    'ASMAN': 0,
    'ASMANN': 0,
    'ASMAR': 0,
    'ASMUS': 0,
    'ASMUSSEN': 0,
    'ASMUTH': 0,
    'ASNER': 0,
    'ASNES': 0,
    'ASO': 0,
    'ASOKAN': 0,
    'ASON': 0,
    'ASP': 0,
    'ASPAAS': 0,
    'ASPDEN': 0,
    'ASPEGREN': 0,
    'ASPEITIA': 0,
    'ASPEL': 0,
    'ASPELIN': 0,
    'ASPELL': 0,
    'ASPELUND': 0,
    'ASPEN': 0,
    'ASPENGREN': 0,
    'ASPENLEITER': 0,
    'ASPENSON': 0,
    'ASPENWALL': 0,
    'ASPER': 0,
    'ASPERA': 0,
    'ASPERY': 0,
    'ASPESI': 0,
    'ASPEY': 0,
    'ASPIAZU': 0,
    'ASPIN': 0,
    'ASPINALL': 0,
    'ASPINWALL': 0,
    'ASPIRAS': 0,
    'ASPLEN': 0,
    'ASPLIN': 0,
    'ASPLUND': 0,
    'ASPRER': 0,
    'ASPREY': 0,
    'ASPROMONTE': 0,
    'ASPURIA': 0,
    'ASPY': 0,
    'ASQUITH': 0,
    'ASRAT': 0,
    'ASSA': 0,
    'ASSAAD': 0,
    'ASSAD': 0,
    'ASSADI': 0,
    'ASSADOURIAN': 0,
    'ASSAEL': 0,
    'ASSAF': 0,
    'ASSAL': 0,
    'ASSALONE': 0,
    'ASSAM': 0,
    'ASSANTE': 0,
    'ASSAR': 0,
    'ASSARIAN': 0,
    'ASSEF': 0,
    'ASSEFA': 0,
    'ASSEL': 0,
    'ASSELIN': 0,
    'ASSELL': 0,
    'ASSELTA': 0,
    'ASSENHEIMER': 0,
    'ASSENMACHER': 0,
    'ASSENZA': 0,
    'ASSI': 0,
    'ASSID': 0,
    'ASSIL': 0,
    'ASSING': 0,
    'ASSINI': 0,
    'ASSINK': 0,
    'ASSIS': 0,
    'ASSMAN': 0,
    'ASSMANN': 0,
    'ASSMUS': 0,
    'ASSON': 0,
    'ASSUNCAO': 0,
    'ASSUNTA': 1,
    'AST': 0,
    'ASTA': 0,
    'ASTACIO': 0,
    'ASTALOS': 0,
    'ASTARITA': 0,
    'ASTBURY': 0,
    'ASTE': 0,
    'ASTELLO': 0,
    'ASTEMBORSKI': 0,
    'ASTENGO': 0,
    'ASTER': 0,
    'ASTHANA': 0,
    'ASTHEIMER': 0,
    'ASTI': 0,
    'ASTILLERO': 0,
    'ASTIN': 0,
    'ASTLE': 0,
    'ASTLEFORD': 0,
    'ASTLEY': 0,
    'ASTOLFI': 0,
    'ASTON': 0,
    'ASTONE': 0,
    'ASTOR': 0,
    'ASTORE': 0,
    'ASTORGA': 0,
    'ASTORINO': 0,
    'ASTRACHAN': 0,
    'ASTRAN': 0,
    'ASTRAUSKAS': 0,
    'ASTRELLA': 0,
    'ASTRID': 1,
    'ASTROM': 0,
    'ASTRUP': 0,
    'ASTRY': 0,
    'ASTUDILLO': 0,
    'ASTURI': 0,
    'ASTURIAS': 0,
    'ASTUTO': 0,
    'ASTWOOD': 0,
    'ASUEGA': 0,
    'ASUNCION': 0.6369426751592356,
    'ASWAD': 0,
    'ASWANI': 0,
    'ASWEGAN': 0,
    'ASWELL': 0,
    'ASZMAN': 0,
    'ASZTALOS': 0,
    'ATA': 0,
    'ATACK': 0,
    'ATAIDE': 0,
    'ATALLA': 0,
    'ATALLAH': 0,
    'ATAMIAN': 0,
    'ATANACIO': 0,
    'ATANASIO': 0,
    'ATANASOFF': 0,
    'ATANASSOV': 0,
    'ATANGAN': 0,
    'ATASSI': 0,
    'ATAY': 0,
    'ATAYA': 0,
    'ATAYDE': 0,
    'ATCHER': 0,
    'ATCHERSON': 0,
    'ATCHESON': 0,
    'ATCHINSON': 0,
    'ATCHISON': 0,
    'ATCHLEY': 0,
    'ATCHUE': 0,
    'ATCITTY': 0,
    'ATEHORTUA': 0,
    'ATEMPA': 0,
    'ATEN': 0,
    'ATENCIO': 0,
    'ATENCO': 0,
    'ATENE': 0,
    'ATER': 0,
    'ATES': 0,
    'ATH': 0,
    'ATHA': 0,
    'ATHAN': 0,
    'ATHANAS': 0,
    'ATHANASIADIS': 0,
    'ATHANASIOU': 0,
    'ATHANASOPOULOS': 0,
    'ATHANS': 0,
    'ATHAR': 0,
    'ATHAS': 0,
    'ATHAY': 0,
    'ATHEARN': 0,
    'ATHEN': 0,
    'ATHENA': 1,
    'ATHENS': 0,
    'ATHER': 0,
    'ATHERHOLT': 0,
    'ATHERLEY': 0,
    'ATHERLY': 0,
    'ATHERTON': 0,
    'ATHEY': 0,
    'ATHMAN': 0,
    'ATHMANN': 0,
    'ATHMER': 0,
    'ATHON': 0,
    'ATHWAL': 0,
    'ATHY': 0,
    'ATIA': 0,
    'ATIEH': 0,
    'ATIENZA': 0,
    'ATIENZO': 0,
    'ATIK': 0,
    'ATILANO': 0,
    'ATILES': 0,
    'ATIS': 0,
    'ATIYA': 0,
    'ATIYEH': 0,
    'ATKERSON': 0,
    'ATKESON': 0,
    'ATKIN': 0,
    'ATKINS': 0,
    'ATKINSON': 0,
    'ATKISON': 0,
    'ATKISSON': 0,
    'ATLAS': 0,
    'ATLEE': 0,
    'ATLER': 0,
    'ATLEY': 0,
    'ATLURI': 0,
    'ATMORE': 0,
    'ATNIP': 0,
    'ATOIGUE': 0,
    'ATON': 0,
    'ATONDO': 0,
    'ATOR': 0,
    'ATRI': 0,
    'ATRIA': 0,
    'ATRIAN': 0,
    'ATTA': 0,
    'ATTAKAI': 0,
    'ATTAL': 0,
    'ATTALLA': 0,
    'ATTALLAH': 0,
    'ATTANASIO': 0,
    'ATTAR': 0,
    'ATTARD': 0,
    'ATTARDI': 0,
    'ATTARDO': 0,
    'ATTARIAN': 0,
    'ATTAWAY': 0,
    'ATTAYA': 0,
    'ATTEA': 0,
    'ATTEBERRY': 0,
    'ATTEBERY': 0,
    'ATTEBURY': 0,
    'ATTEMA': 0,
    'ATTENBERGER': 0,
    'ATTENBOROUGH': 0,
    'ATTER': 0,
    'ATTERBERRY': 0,
    'ATTERBURY': 0,
    'ATTERHOLT': 0,
    'ATTERSON': 0,
    'ATTERTON': 0,
    'ATTI': 0,
    'ATTIA': 0,
    'ATTIANESE': 0,
    'ATTIAS': 0,
    'ATTIE': 0,
    'ATTIG': 0,
    'ATTILIO': 0,
    'ATTINELLO': 0,
    'ATTINGER': 0,
    'ATTISHA': 0,
    'ATTIX': 0,
    'ATTKISSON': 0,
    'ATTLESON': 0,
    'ATTO': 0,
    'ATTOE': 0,
    'ATTON': 0,
    'ATTRIDGE': 0,
    'ATTWELL': 0,
    'ATTWOOD': 0,
    'ATTY': 0,
    'ATUATASI': 0,
    'ATWAL': 0,
    'ATWATER': 0,
    'ATWELL': 0,
    'ATWILL': 0,
    'ATWOOD': 0,
    'ATZ': 0,
    'ATZERT': 0,
    'ATZINGER': 0,
    'AU': 0,
    'AUBAIN': 0,
    'AUBART': 0,
    'AUBE': 0,
    'AUBEL': 0,
    'AUBELE': 0,
    'AUBER': 0,
    'AUBERGER': 0,
    'AUBERRY': 0,
    'AUBERT': 0,
    'AUBERTIN': 0,
    'AUBERTINE': 0,
    'AUBIN': 0,
    'AUBLE': 0,
    'AUBOL': 0,
    'AUBOURG': 0,
    'AUBRECHT': 0,
    'AUBREY': 0.9420289855072463,
    'AUBRY': 0,
    'AUBUCHON': 0,
    'AUBURN': 0,
    'AUBUT': 0,
    'AUCAPINA': 0,
    'AUCH': 0,
    'AUCHARD': 0,
    'AUCHENBACH': 0,
    'AUCHEY': 0,
    'AUCHINCLOSS': 0,
    'AUCHMOODY': 0,
    'AUCHTER': 0,
    'AUCHTERLONIE': 0,
    'AUCIELLO': 0,
    'AUCK': 0,
    'AUCKER': 0,
    'AUCKERMAN': 0,
    'AUCKLAND': 0,
    'AUCLAIR': 0,
    'AUCOIN': 0,
    'AUCONE': 0,
    'AUCUTT': 0,
    'AUD': 0,
    'AUDA': 0,
    'AUDAIN': 0,
    'AUDAS': 0,
    'AUDE': 0,
    'AUDELO': 0,
    'AUDET': 0,
    'AUDETTE': 0,
    'AUDI': 0,
    'AUDIA': 0,
    'AUDIBERT': 0,
    'AUDIE': 0.9708737864077669,
    'AUDIFFRED': 0,
    'AUDINO': 0,
    'AUDIRSCH': 0,
    'AUDISH': 0,
    'AUDISS': 0,
    'AUDITORE': 0,
    'AUDLEY': 0,
    'AUDRA': 1,
    'AUDRAIN': 0,
    'AUDREA': 1,
    'AUDREY': 0.9994491225308885,
    'AUDRIA': 1,
    'AUDRIE': 1,
    'AUDRY': 1,
    'AUDSLEY': 0,
    'AUDUONG': 0,
    'AUDY': 0,
    'AUE': 0,
    'AUEL': 0,
    'AUELUA': 0,
    'AUEN': 0,
    'AUER': 0,
    'AUERBACH': 0,
    'AUERSWALD': 0,
    'AUFDENBERG': 0,
    'AUFDENKAMP': 0,
    'AUFDERHAR': 0,
    'AUFDERHEIDE': 0,
    'AUFFANT': 0,
    'AUFFERT': 0,
    'AUFFREY': 0,
    'AUFIERO': 0,
    'AUFLICK': 0,
    'AUFMUTH': 0,
    'AUG': 0,
    'AUGARE': 0,
    'AUGE': 0,
    'AUGELLI': 0,
    'AUGELLO': 0,
    'AUGENSTEIN': 0,
    'AUGER': 0,
    'AUGERI': 0,
    'AUGHE': 0,
    'AUGHENBAUGH': 0,
    'AUGHEY': 0,
    'AUGHINBAUGH': 0,
    'AUGHTMAN': 0,
    'AUGHTRY': 0,
    'AUGILAR': 0,
    'AUGILLARD': 0,
    'AUGLE': 0,
    'AUGSBURGER': 0,
    'AUGSPURGER': 0,
    'AUGST': 0,
    'AUGUGLIARO': 0,
    'AUGUILLARD': 0,
    'AUGUR': 0,
    'AUGUST': 0.8695652173913043,
    'AUGUSTA': 0.9606147934678194,
    'AUGUSTAVE': 0,
    'AUGUSTE': 0,
    'AUGUSTIN': 0,
    'AUGUSTINA': 1,
    'AUGUSTINE': 0.6734006734006734,
    'AUGUSTINO': 0,
    'AUGUSTO': 0,
    'AUGUSTSON': 0,
    'AUGUSTUS': 0.8347245409015025,
    'AUGUSTYN': 0,
    'AUGUSTYNIAK': 0,
    'AUGUSTYNOWICZ': 0,
    'AUILA': 0,
    'AUILES': 0,
    'AUJLA': 0,
    'AUKAMP': 0,
    'AUKEMA': 0,
    'AUKEMAN': 0,
    'AUKER': 0,
    'AUKERMAN': 0,
    'AUKES': 0,
    'AUKLAND': 0,
    'AUL': 0,
    'AULABAUGH': 0,
    'AULAKH': 0,
    'AULBACH': 0,
    'AULD': 0,
    'AULDRIDGE': 0,
    'AULDS': 0,
    'AULENBACH': 0,
    'AULENBACHER': 0,
    'AULER': 0,
    'AULET': 0,
    'AULETTA': 0,
    'AULETTO': 0,
    'AULGUR': 0,
    'AULICINO': 0,
    'AULICK': 0,
    'AULIK': 0,
    'AULISIO': 0,
    'AULL': 0,
    'AULNER': 0,
    'AULT': 0,
    'AULTMAN': 0,
    'AULTZ': 0,
    'AULWES': 0,
    'AUMACK': 0,
    'AUMADA': 0,
    'AUMAN': 0,
    'AUMANN': 0,
    'AUMEN': 0,
    'AUMENT': 0,
    'AUMICK': 0,
    'AUMILLER': 0,
    'AUMOCK': 0,
    'AUMUA': 0,
    'AUN': 0,
    'AUNA': 0,
    'AUNCHMAN': 0,
    'AUNDREA': 1,
    'AUNE': 0,
    'AUNER': 0,
    'AUNG': 0,
    'AUNGST': 0,
    'AUNKST': 0,
    'AUNSPAUGH': 0,
    'AUPPERLE': 0,
    'AUPPERLEE': 0,
    'AURA': 0.9881422924901185,
    'AURAND': 0,
    'AURANDT': 0,
    'AURE': 0,
    'AUREA': 1,
    'AURELI': 0,
    'AURELIA': 0.9930486593843098,
    'AURELIEN': 0,
    'AURELIO': 0.9635974304068522,
    'AURELIUS': 0,
    'AURES': 0,
    'AURICCHIO': 0,
    'AURICH': 0,
    'AURIEMMA': 0,
    'AURIGEMMA': 0,
    'AURILIA': 0,
    'AURILIO': 0,
    'AURINGER': 0,
    'AURIOLES': 0,
    'AURIT': 0,
    'AURORA': 0.9933774834437086,
    'AURORE': 1,
    'AUS': 0,
    'AUSBAND': 0,
    'AUSBERRY': 0,
    'AUSBIE': 0,
    'AUSBON': 0,
    'AUSBORN': 0,
    'AUSBORNE': 0,
    'AUSBROOK': 0,
    'AUSBROOKS': 0,
    'AUSBUN': 0,
    'AUSBURN': 0,
    'AUSBY': 0,
    'AUSCH': 0,
    'AUSDEMORE': 0,
    'AUSEC': 0,
    'AUSEN': 0,
    'AUSENBAUGH': 0,
    'AUSHERMAN': 0,
    'AUSIELLO': 0,
    'AUSLAND': 0,
    'AUSLANDER': 0,
    'AUSLEY': 0,
    'AUSLOOS': 0,
    'AUSMAN': 0,
    'AUSMUS': 0,
    'AUSSEM': 0,
    'AUST': 0,
    'AUSTAD': 0,
    'AUSTEIN': 0,
    'AUSTELL': 0,
    'AUSTEN': 0,
    'AUSTER': 0,
    'AUSTERMAN': 0,
    'AUSTERMANN': 0,
    'AUSTERMILLER': 0,
    'AUSTGEN': 0,
    'AUSTILL': 0,
    'AUSTIN': 0.5175388154111558,
    'AUSTINE': 0,
    'AUSTING': 0,
    'AUSTINSON': 0,
    'AUSTON': 0,
    'AUSTRENG': 0,
    'AUSTRIA': 0,
    'AUTAR': 0,
    'AUTEN': 0,
    'AUTENRIETH': 0,
    'AUTER': 0,
    'AUTERA': 0,
    'AUTERI': 0,
    'AUTERSON': 0,
    'AUTERY': 0,
    'AUTH': 0,
    'AUTHEMENT': 0,
    'AUTHER': 0,
    'AUTHIER': 0,
    'AUTHOR': 0,
    'AUTIERI': 0,
    'AUTIN': 0,
    'AUTIO': 0,
    'AUTMAN': 0,
    'AUTOBEE': 0,
    'AUTON': 0,
    'AUTORE': 0,
    'AUTORINO': 0,
    'AUTREY': 0,
    'AUTRY': 0,
    'AUTTONBERRY': 0,
    'AUTUMN': 1,
    'AUTWELL': 0,
    'AUTY': 0,
    'AUVENSHINE': 0,
    'AUVIL': 0,
    'AUVILLE': 0,
    'AUWAE': 0,
    'AUWAERTER': 0,
    'AUWARTER': 0,
    'AUXIER': 0,
    'AUXTER': 0,
    'AUYEUNG': 0,
    'AUYONG': 0,
    'AUYOUNG': 0,
    'AUZA': 0,
    'AUZENNE': 0,
    'AV': 0,
    'AVA': 1,
    'AVAGYAN': 0,
    'AVAKIAN': 0,
    'AVAKYAN': 0,
    'AVALA': 0,
    'AVALLONE': 0,
    'AVALO': 0,
    'AVALON': 0,
    'AVALONE': 0,
    'AVALOS': 0,
    'AVALOZ': 0,
    'AVANCE': 0,
    'AVANCENA': 0,
    'AVANESIAN': 0,
    'AVANESSIAN': 0,
    'AVANESYAN': 0,
    'AVANS': 0,
    'AVANSINO': 0,
    'AVANT': 0,
    'AVANTS': 0,
    'AVANZATO': 0,
    'AVANZINO': 0,
    'AVARA': 0,
    'AVARCA': 0,
    'AVARD': 0,
    'AVARITT': 0,
    'AVARY': 0,
    'AVDIC': 0,
    'AVE': 0,
    'AVECILLA': 0,
    'AVECILLAS': 0,
    'AVEDIAN': 0,
    'AVEDIKIAN': 0,
    'AVEDISIAN': 0,
    'AVEDISSIAN': 0,
    'AVEDON': 0,
    'AVEIRO': 0,
    'AVELAR': 0,
    'AVELINA': 1,
    'AVELINO': 0,
    'AVELLA': 0,
    'AVELLAN': 0,
    'AVELLANEDA': 0,
    'AVELLANET': 0,
    'AVELLAR': 0,
    'AVELLINO': 0,
    'AVELLO': 0,
    'AVEN': 0,
    'AVENA': 0,
    'AVENARIUS': 0,
    'AVENDANO': 0,
    'AVENELL': 0,
    'AVENI': 0,
    'AVENIA': 0,
    'AVENOSO': 0,
    'AVENS': 0,
    'AVENSON': 0,
    'AVENT': 0,
    'AVER': 0,
    'AVERA': 0,
    'AVERBACH': 0,
    'AVERBECK': 0,
    'AVERBUCH': 0,
    'AVERBUKH': 0,
    'AVERELL': 0,
    'AVERETT': 0,
    'AVERETTE': 0,
    'AVERHART': 0,
    'AVERHOFF': 0,
    'AVERILL': 0,
    'AVERITT': 0,
    'AVERITTE': 0,
    'AVERKAMP': 0,
    'AVERNA': 0,
    'AVERS': 0,
    'AVERSA': 0,
    'AVERSANO': 0,
    'AVERSO': 0,
    'AVERY': 0.463678516228748,
    'AVERYT': 0,
    'AVES': 0,
    'AVETISIAN': 0,
    'AVETISYAN': 0,
    'AVETYAN': 0,
    'AVEY': 0,
    'AVEYARD': 0,
    'AVGERINOS': 0,
    'AVIE': 0,
    'AVIGLIANO': 0,
    'AVIGNONE': 0,
    'AVILA': 0,
    'AVILAR': 0,
    'AVILAS': 0,
    'AVILES': 0,
    'AVILEZ': 0,
    'AVILLA': 0,
    'AVIN': 0,
    'AVINA': 0,
    'AVINGER': 0,
    'AVINGTON': 0,
    'AVINO': 0,
    'AVINS': 0,
    'AVIRETT': 0,
    'AVIS': 0.9359251259899208,
    'AVISE': 0,
    'AVISON': 0,
    'AVITABILE': 0,
    'AVITABLE': 0,
    'AVITIA': 0,
    'AVIV': 0,
    'AVIZ': 0,
    'AVIZA': 0,
    'AVNER': 0,
    'AVNET': 0,
    'AVOLA': 0,
    'AVOLIO': 0,
    'AVON': 0,
    'AVONDET': 0,
    'AVRA': 0,
    'AVRAM': 0,
    'AVRAMIDIS': 0,
    'AVRETT': 0,
    'AVRIETT': 0,
    'AVRIL': 0.8849557522123894,
    'AVRIT': 0,
    'AVRITT': 0,
    'AW': 0,
    'AWA': 0,
    'AWAD': 0,
    'AWADA': 0,
    'AWADALLA': 0,
    'AWADALLAH': 0,
    'AWAI': 0,
    'AWAKUNI': 0,
    'AWAL': 0,
    'AWALD': 0,
    'AWALT': 0,
    'AWAN': 0,
    'AWANA': 0,
    'AWASTHI': 0,
    'AWAWDEH': 0,
    'AWAYA': 0,
    'AWBREY': 0,
    'AWE': 0,
    'AWEAU': 0,
    'AWENDER': 0,
    'AWES': 0,
    'AWILDA': 1,
    'AWKARD': 0,
    'AWKWARD': 0,
    'AWONG': 0,
    'AWOSIKA': 0,
    'AWREY': 0,
    'AWTREY': 0,
    'AWTRY': 0,
    'AWUAH': 0,
    'AWWAD': 0,
    'AX': 0,
    'AXBERG': 0,
    'AXE': 0,
    'AXEL': 0,
    'AXELL': 0,
    'AXELRAD': 0,
    'AXELROD': 0,
    'AXELSEN': 0,
    'AXELSON': 0,
    'AXELSSON': 0,
    'AXEN': 0,
    'AXFORD': 0,
    'AXIOTIS': 0,
    'AXLER': 0,
    'AXLEY': 0,
    'AXLINE': 0,
    'AXMACHER': 0,
    'AXMAN': 0,
    'AXNESS': 0,
    'AXON': 0,
    'AXSOM': 0,
    'AXSON': 0,
    'AXT': 0,
    'AXTELL': 0,
    'AXTHELM': 0,
    'AXTMAN': 0,
    'AXTMANN': 0,
    'AXTON': 0,
    'AY': 0,
    'AYA': 0,
    'AYACHE': 0,
    'AYAD': 0,
    'AYAIA': 0,
    'AYAKO': 1,
    'AYALA': 0,
    'AYALEW': 0,
    'AYALLA': 0,
    'AYAN': 0,
    'AYANA': 1,
    'AYANNA': 1,
    'AYAR': 0,
    'AYARS': 0,
    'AYASH': 0,
    'AYAU': 0,
    'AYAZ': 0,
    'AYBAR': 0,
    'AYCOCK': 0,
    'AYCOTH': 0,
    'AYCOX': 0,
    'AYD': 0,
    'AYDELL': 0,
    'AYDELOTT': 0,
    'AYDELOTTE': 0,
    'AYDIN': 0,
    'AYDLETT': 0,
    'AYDT': 0,
    'AYE': 0,
    'AYELE': 0,
    'AYEN': 0,
    'AYENDE': 0,
    'AYENI': 0,
    'AYER': 0,
    'AYERDIS': 0,
    'AYERS': 0,
    'AYERSMAN': 0,
    'AYES': 0,
    'AYESH': 0,
    'AYESHA': 1,
    'AYESTAS': 0,
    'AYINDE': 0,
    'AYLA': 0,
    'AYLER': 0,
    'AYLES': 0,
    'AYLESWORTH': 0,
    'AYLETT': 0,
    'AYLING': 0,
    'AYLLON': 0,
    'AYLMER': 0,
    'AYLOR': 0,
    'AYLSWORTH': 0,
    'AYLWARD': 0,
    'AYLWIN': 0,
    'AYMAMI': 0,
    'AYMAR': 0,
    'AYMOND': 0,
    'AYNES': 0,
    'AYO': 0,
    'AYODELE': 0,
    'AYON': 0,
    'AYOOB': 0,
    'AYOOLA': 0,
    'AYOTTE': 0,
    'AYOUB': 0,
    'AYOUBI': 0,
    'AYRAPETYAN': 0,
    'AYRE': 0,
    'AYRES': 0,
    'AYRTON': 0,
    'AYSCUE': 0,
    'AYSON': 0,
    'AYTCH': 0,
    'AYTES': 0,
    'AYTON': 0,
    'AYUB': 0,
    'AYUBI': 0,
    'AYUSO': 0,
    'AYVAR': 0,
    'AYVAZIAN': 0,
    'AYVAZYAN': 0,
    'AYYAD': 0,
    'AYYAGARI': 0,
    'AYYASH': 0,
    'AYZE': 0,
    'AYZENBERG': 0,
    'AZA': 0,
    'AZAD': 0,
    'AZADI': 0,
    'AZADIAN': 0,
    'AZALEE': 1,
    'AZAM': 0,
    'AZAMA': 0,
    'AZAMAR': 0,
    'AZAMI': 0,
    'AZAN': 0,
    'AZAR': 0,
    'AZARCON': 0,
    'AZARI': 0,
    'AZARIAN': 0,
    'AZBELL': 0,
    'AZBILL': 0,
    'AZCARATE': 0,
    'AZCONA': 0,
    'AZCUE': 0,
    'AZCUETA': 0,
    'AZCUY': 0,
    'AZEEM': 0,
    'AZEEZ': 0,
    'AZELTINE': 0,
    'AZELTON': 0,
    'AZEMAR': 0,
    'AZER': 0,
    'AZEREDO': 0,
    'AZEVEDO': 0,
    'AZHAR': 0,
    'AZIM': 0,
    'AZIMI': 0,
    'AZINGER': 0,
    'AZIZ': 0,
    'AZIZI': 0,
    'AZIZIAN': 0,
    'AZLIN': 0,
    'AZMI': 0,
    'AZNAR': 0,
    'AZOCAR': 0,
    'AZOR': 0,
    'AZORE': 0,
    'AZOULAY': 0,
    'AZPEITIA': 0,
    'AZRAK': 0,
    'AZUA': 0,
    'AZUARA': 0,
    'AZUCAR': 0,
    'AZUCENA': 0.9132420091324202,
    'AZULAY': 0,
    'AZUMA': 0,
    'AZURDIA': 0,
    'AZURE': 0,
    'AZURIN': 0,
    'AZZALINA': 0,
    'AZZAM': 0,
    'AZZANO': 0,
    'AZZARA': 0,
    'AZZARELLA': 0,
    'AZZARELLI': 0,
    'AZZARELLO': 0,
    'AZZARITI': 0,
    'AZZARITO': 0,
    'AZZARO': 0,
    'AZZARONE': 0,
    'AZZATO': 0,
    'AZZI': 0,
    'AZZIE': 1,
    'AZZINARO': 0,
    'AZZO': 0,
    'AZZOLINA': 0,
    'AZZOLINI': 0,
    'AZZOLINO': 0,
    'AZZOPARDI': 0,
    'BA': 0,
    'BAAB': 0,
    'BAACK': 0,
    'BAACKE': 0,
    'BAAD': 0,
    'BAADE': 0,
    'BAADER': 0,
    'BAADSGAARD': 0,
    'BAAH': 0,
    'BAAK': 0,
    'BAAKE': 0,
    'BAAL': 0,
    'BAALMAN': 0,
    'BAAR': 0,
    'BAARDA': 0,
    'BAARS': 0,
    'BAARSTAD': 0,
    'BAARTMAN': 0,
    'BAAS': 0,
    'BAASCH': 0,
    'BAASE': 0,
    'BAASKE': 0,
    'BAATZ': 0,
    'BABA': 0,
    'BABAD': 0,
    'BABADZHANOV': 0,
    'BABAEV': 0,
    'BABAIAN': 0,
    'BABAK': 0,
    'BABAKHANI': 0,
    'BABAKHANIAN': 0,
    'BABAKHANYAN': 0,
    'BABALOLA': 0,
    'BABAN': 0,
    'BABANI': 0,
    'BABAR': 0,
    'BABARA': 1,
    'BABAS': 0,
    'BABATUNDE': 0,
    'BABAUTA': 0,
    'BABAYAN': 0,
    'BABAYEV': 0,
    'BABAZADEH': 0,
    'BABB': 0,
    'BABBAGE': 0,
    'BABBAR': 0,
    'BABBEL': 0,
    'BABBIDGE': 0,
    'BABBIE': 0,
    'BABBIN': 0,
    'BABBIT': 0,
    'BABBITT': 0,
    'BABBS': 0,
    'BABBY': 0,
    'BABCOCK': 0,
    'BABE': 0,
    'BABECKI': 0,
    'BABEL': 0,
    'BABENKO': 0,
    'BABER': 0,
    'BABERS': 0,
    'BABETTE': 1,
    'BABEY': 0,
    'BABI': 0,
    'BABIAK': 0,
    'BABIAN': 0,
    'BABIARZ': 0,
    'BABIC': 0,
    'BABICH': 0,
    'BABICK': 0,
    'BABICKI': 0,
    'BABICZ': 0,
    'BABIGIAN': 0,
    'BABIJ': 0,
    'BABIK': 0,
    'BABIKIAN': 0,
    'BABILONIA': 0,
    'BABIN': 0,
    'BABINCHAK': 0,
    'BABINE': 0,
    'BABINEAU': 0,
    'BABINEAUX': 0,
    'BABINEC': 0,
    'BABINGTON': 0,
    'BABINO': 0,
    'BABINSKI': 0,
    'BABINSKY': 0,
    'BABIONE': 0,
    'BABIS': 0,
    'BABISH': 0,
    'BABITS': 0,
    'BABITZ': 0,
    'BABIY': 0,
    'BABJAK': 0,
    'BABKA': 0,
    'BABL': 0,
    'BABLE': 0,
    'BABLER': 0,
    'BABLES': 0,
    'BABO': 0,
    'BABON': 0,
    'BABOOLAL': 0,
    'BABOR': 0,
    'BABOS': 0,
    'BABSKI': 0,
    'BABSON': 0,
    'BABST': 0,
    'BABU': 0,
    'BABULA': 0,
    'BABY': 0,
    'BABYAK': 0,
    'BABYLON': 0,
    'BAC': 0,
    'BACA': 0,
    'BACAK': 0,
    'BACAL': 0,
    'BACALL': 0,
    'BACALLAO': 0,
    'BACANI': 0,
    'BACARELLA': 0,
    'BACARRO': 0,
    'BACAS': 0,
    'BACCA': 0,
    'BACCALA': 0,
    'BACCAM': 0,
    'BACCARELLA': 0,
    'BACCARI': 0,
    'BACCARO': 0,
    'BACCEI': 0,
    'BACCELLIERI': 0,
    'BACCHETTA': 0,
    'BACCHETTI': 0,
    'BACCHI': 0,
    'BACCHIOCCHI': 0,
    'BACCHUS': 0,
    'BACCI': 0,
    'BACCO': 0,
    'BACCUS': 0,
    'BACE': 0,
    'BACERRA': 0,
    'BACH': 0,
    'BACHA': 0,
    'BACHAN': 0,
    'BACHAND': 0,
    'BACHANT': 0,
    'BACHAR': 0,
    'BACHARA': 0,
    'BACHARACH': 0,
    'BACHE': 0,
    'BACHELDER': 0,
    'BACHELIER': 0,
    'BACHELLER': 0,
    'BACHELOR': 0,
    'BACHEMIN': 0,
    'BACHER': 0,
    'BACHERT': 0,
    'BACHETTI': 0,
    'BACHHOFER': 0,
    'BACHHUBER': 0,
    'BACHI': 0,
    'BACHICH': 0,
    'BACHICHA': 0,
    'BACHIK': 0,
    'BACHILLER': 0,
    'BACHINI': 0,
    'BACHINSKI': 0,
    'BACHINSKY': 0,
    'BACHLE': 0,
    'BACHLEDA': 0,
    'BACHLER': 0,
    'BACHMAN': 0,
    'BACHMANN': 0,
    'BACHMAYER': 0,
    'BACHMEIER': 0,
    'BACHMEYER': 0,
    'BACHNER': 0,
    'BACHO': 0,
    'BACHOFER': 0,
    'BACHOFNER': 0,
    'BACHOR': 0,
    'BACHORIK': 0,
    'BACHORSKI': 0,
    'BACHRACH': 0,
    'BACHSTEIN': 0,
    'BACHTA': 0,
    'BACHTEL': 0,
    'BACHTELL': 0,
    'BACHTOLD': 0,
    'BACHU': 0,
    'BACHUS': 0,
    'BACIAK': 0,
    'BACIC': 0,
    'BACICH': 0,
    'BACIGALUPI': 0,
    'BACIGALUPO': 0,
    'BACIK': 0,
    'BACILE': 0,
    'BACILIO': 0,
    'BACINO': 0,
    'BACIO': 0,
    'BACIU': 0,
    'BACK': 0,
    'BACKE': 0,
    'BACKEN': 0,
    'BACKENSTO': 0,
    'BACKER': 0,
    'BACKERS': 0,
    'BACKERT': 0,
    'BACKES': 0,
    'BACKEY': 0,
    'BACKFISCH': 0,
    'BACKHAUS': 0,
    'BACKHERMS': 0,
    'BACKHUS': 0,
    'BACKIEL': 0,
    'BACKLEY': 0,
    'BACKLIN': 0,
    'BACKLUND': 0,
    'BACKMAN': 0,
    'BACKMON': 0,
    'BACKNER': 0,
    'BACKO': 0,
    'BACKOF': 0,
    'BACKOFEN': 0,
    'BACKOFF': 0,
    'BACKOS': 0,
    'BACKOUS': 0,
    'BACKOWSKI': 0,
    'BACKS': 0,
    'BACKSCHEIDER': 0,
    'BACKSTROM': 0,
    'BACKUES': 0,
    'BACKUS': 0,
    'BACLAAN': 0,
    'BACLAWSKI': 0,
    'BACLE': 0,
    'BACLIG': 0,
    'BACO': 0,
    'BACOME': 0,
    'BACON': 0,
    'BACORN': 0,
    'BACOS': 0,
    'BACOT': 0,
    'BACOTE': 0,
    'BACQUE': 0,
    'BACSIK': 0,
    'BACTAD': 0,
    'BACUS': 0,
    'BACY': 0,
    'BACZEK': 0,
    'BACZEWSKI': 0,
    'BACZKOWSKI': 0,
    'BACZYNSKI': 0,
    'BADA': 0,
    'BADAGLIACCA': 0,
    'BADAL': 0,
    'BADALAMENTE': 0,
    'BADALAMENTI': 0,
    'BADALI': 0,
    'BADALIAN': 0,
    'BADALOV': 0,
    'BADALUCCO': 0,
    'BADALYAN': 0,
    'BADAME': 0,
    'BADAMI': 0,
    'BADAMO': 0,
    'BADANI': 0,
    'BADAR': 0,
    'BADARACCO': 0,
    'BADAT': 0,
    'BADAWI': 0,
    'BADAWY': 0,
    'BADDELEY': 0,
    'BADDER': 0,
    'BADDERS': 0,
    'BADDICK': 0,
    'BADDING': 0,
    'BADDLEY': 0,
    'BADDORF': 0,
    'BADDOUR': 0,
    'BADE': 0,
    'BADEA': 0,
    'BADEAU': 0,
    'BADEAUX': 0,
    'BADEJO': 0,
    'BADEL': 0,
    'BADELL': 0,
    'BADEN': 0,
    'BADENHOP': 0,
    'BADENOCH': 0,
    'BADER': 0,
    'BADERTSCHER': 0,
    'BADESSA': 0,
    'BADEY': 0,
    'BADGE': 0,
    'BADGER': 0,
    'BADGERO': 0,
    'BADGEROW': 0,
    'BADGETT': 0,
    'BADGLEY': 0,
    'BADGWELL': 0,
    'BADHAM': 0,
    'BADIA': 0,
    'BADIALI': 0,
    'BADIE': 0,
    'BADILLA': 0,
    'BADILLO': 0,
    'BADIN': 0,
    'BADING': 0,
    'BADINGER': 0,
    'BADINI': 0,
    'BADIO': 0,
    'BADKE': 0,
    'BADKER': 0,
    'BADLEY': 0,
    'BADMAN': 0,
    'BADNER': 0,
    'BADO': 0,
    'BADOLATO': 0,
    'BADON': 0,
    'BADONI': 0,
    'BADONIE': 0,
    'BADORE': 0,
    'BADOUR': 0,
    'BADOVINAC': 0,
    'BADOWSKI': 0,
    'BADR': 0,
    'BADRA': 0,
    'BADRAN': 0,
    'BADRI': 0,
    'BADTKE': 0,
    'BADU': 0,
    'BADUA': 0,
    'BADURA': 0,
    'BADWAL': 0,
    'BADWAN': 0,
    'BADWAY': 0,
    'BADY': 0,
    'BADYNA': 0,
    'BADZINSKI': 0,
    'BAE': 0,
    'BAEBLER': 0,
    'BAECHER': 0,
    'BAECHLE': 0,
    'BAECHLER': 0,
    'BAECKER': 0,
    'BAEDER': 0,
    'BAEDKE': 0,
    'BAEHL': 0,
    'BAEHLER': 0,
    'BAEHMAN': 0,
    'BAEHR': 0,
    'BAEHRE': 0,
    'BAEK': 0,
    'BAEL': 0,
    'BAENA': 0,
    'BAENEN': 0,
    'BAENZIGER': 0,
    'BAER': 0,
    'BAERENWALD': 0,
    'BAERG': 0,
    'BAERGA': 0,
    'BAERMAN': 0,
    'BAERT': 0,
    'BAERTLEIN': 0,
    'BAERTSCH': 0,
    'BAERTSCHI': 0,
    'BAERWALD': 0,
    'BAERWOLF': 0,
    'BAES': 0,
    'BAESA': 0,
    'BAESE': 0,
    'BAESLER': 0,
    'BAESMAN': 0,
    'BAESSLER': 0,
    'BAETA': 0,
    'BAETE': 0,
    'BAETEN': 0,
    'BAETHKE': 0,
    'BAETZ': 0,
    'BAEZ': 0,
    'BAEZA': 0,
    'BAFARO': 0,
    'BAFFA': 0,
    'BAFFI': 0,
    'BAFFO': 0,
    'BAFFONI': 0,
    'BAFFORD': 0,
    'BAFFUTO': 0,
    'BAFIA': 0,
    'BAFUS': 0,
    'BAG': 0,
    'BAGA': 0,
    'BAGAI': 0,
    'BAGALA': 0,
    'BAGAN': 0,
    'BAGANZ': 0,
    'BAGAOISAN': 0,
    'BAGAY': 0,
    'BAGBEY': 0,
    'BAGBY': 0,
    'BAGCHI': 0,
    'BAGDASARIAN': 0,
    'BAGDASARYAN': 0,
    'BAGDON': 0,
    'BAGDONAS': 0,
    'BAGE': 0,
    'BAGEANT': 0,
    'BAGEN': 0,
    'BAGENSTOSE': 0,
    'BAGENT': 0,
    'BAGER': 0,
    'BAGG': 0,
    'BAGGA': 0,
    'BAGGALEY': 0,
    'BAGGARLEY': 0,
    'BAGGARLY': 0,
    'BAGGE': 0,
    'BAGGENSTOS': 0,
    'BAGGENSTOSS': 0,
    'BAGGER': 0,
    'BAGGERLY': 0,
    'BAGGERMAN': 0,
    'BAGGET': 0,
    'BAGGETT': 0,
    'BAGGETTA': 0,
    'BAGGETTE': 0,
    'BAGGIO': 0,
    'BAGGOT': 0,
    'BAGGOTT': 0,
    'BAGGS': 0,
    'BAGHDADI': 0,
    'BAGHDASARIAN': 0,
    'BAGHDASSARIAN': 0,
    'BAGHERI': 0,
    'BAGI': 0,
    'BAGIN': 0,
    'BAGINSKI': 0,
    'BAGLEY': 0,
    'BAGLIA': 0,
    'BAGLIEN': 0,
    'BAGLIERI': 0,
    'BAGLIETTO': 0,
    'BAGLIN': 0,
    'BAGLINI': 0,
    'BAGLIO': 0,
    'BAGLIONE': 0,
    'BAGLIONI': 0,
    'BAGLIVO': 0,
    'BAGNAL': 0,
    'BAGNALL': 0,
    'BAGNASCO': 0,
    'BAGNATO': 0,
    'BAGNE': 0,
    'BAGNELL': 0,
    'BAGNER': 0,
    'BAGNI': 0,
    'BAGNIEWSKI': 0,
    'BAGNOLI': 0,
    'BAGO': 0,
    'BAGOLA': 0,
    'BAGOT': 0,
    'BAGOZZI': 0,
    'BAGRI': 0,
    'BAGROWSKI': 0,
    'BAGSBY': 0,
    'BAGSHAW': 0,
    'BAGSTAD': 0,
    'BAGTAS': 0,
    'BAGUIO': 0,
    'BAGULEY': 0,
    'BAGUM': 0,
    'BAGWELL': 0,
    'BAGWILL': 0,
    'BAH': 0,
    'BAHA': 0,
    'BAHADORI': 0,
    'BAHADUR': 0,
    'BAHAM': 0,
    'BAHAMON': 0,
    'BAHAMONDE': 0,
    'BAHAMONDES': 0,
    'BAHAMUNDI': 0,
    'BAHAN': 0,
    'BAHAR': 0,
    'BAHDE': 0,
    'BAHE': 0,
    'BAHEN': 0,
    'BAHENA': 0,
    'BAHER': 0,
    'BAHHUR': 0,
    'BAHIA': 0,
    'BAHK': 0,
    'BAHL': 0,
    'BAHLE': 0,
    'BAHLER': 0,
    'BAHLING': 0,
    'BAHLINGER': 0,
    'BAHLMAN': 0,
    'BAHLMANN': 0,
    'BAHLS': 0,
    'BAHM': 0,
    'BAHMER': 0,
    'BAHN': 0,
    'BAHNEMAN': 0,
    'BAHNER': 0,
    'BAHNEY': 0,
    'BAHNG': 0,
    'BAHNICK': 0,
    'BAHNMILLER': 0,
    'BAHNS': 0,
    'BAHNSEN': 0,
    'BAHNSON': 0,
    'BAHOU': 0,
    'BAHR': 0,
    'BAHRAMI': 0,
    'BAHRE': 0,
    'BAHRENBURG': 0,
    'BAHRET': 0,
    'BAHRI': 0,
    'BAHRKE': 0,
    'BAHRS': 0,
    'BAHRY': 0,
    'BAHTA': 0,
    'BAHU': 0,
    'BAI': 0,
    'BAIA': 0,
    'BAIAMONTE': 0,
    'BAIARDI': 0,
    'BAICH': 0,
    'BAID': 0,
    'BAIDA': 0,
    'BAIDE': 0,
    'BAIDOO': 0,
    'BAIDWIN': 0,
    'BAIE': 0,
    'BAIER': 0,
    'BAIERL': 0,
    'BAIERLEIN': 0,
    'BAIETTO': 0,
    'BAIG': 0,
    'BAIIARD': 0,
    'BAIK': 0,
    'BAIL': 0,
    'BAILE': 0,
    'BAILEN': 0,
    'BAILER': 0,
    'BAILES': 0,
    'BAILESS': 0,
    'BAILEX': 0,
    'BAILEY': 0.029536280397755243,
    'BAILIE': 0,
    'BAILIFF': 0,
    'BAILIN': 0,
    'BAILIS': 0,
    'BAILLARGEON': 0,
    'BAILLEY': 0,
    'BAILLIE': 0,
    'BAILLIF': 0,
    'BAILLIO': 0,
    'BAILLY': 0,
    'BAILO': 0,
    'BAILON': 0,
    'BAILOR': 0,
    'BAILS': 0,
    'BAILY': 0,
    'BAIM': 0,
    'BAIMA': 0,
    'BAIN': 0,
    'BAINBRIDGE': 0,
    'BAINE': 0,
    'BAINER': 0,
    'BAINES': 0,
    'BAINEY': 0,
    'BAINS': 0,
    'BAINTER': 0,
    'BAINTON': 0,
    'BAINUM': 0,
    'BAIO': 0,
    'BAIOCCHI': 0,
    'BAIOCCO': 0,
    'BAIONE': 0,
    'BAIONI': 0,
    'BAIR': 0,
    'BAIRD': 0,
    'BAIRE': 0,
    'BAIRES': 0,
    'BAIROS': 0,
    'BAIRRINGTON': 0,
    'BAIRSTOW': 0,
    'BAIS': 0,
    'BAISA': 0,
    'BAISCH': 0,
    'BAISDEN': 0,
    'BAISE': 0,
    'BAISEY': 0,
    'BAISH': 0,
    'BAISLEY': 0,
    'BAITH': 0,
    'BAITINGER': 0,
    'BAITY': 0,
    'BAITZ': 0,
    'BAIZ': 0,
    'BAIZA': 0,
    'BAIZAN': 0,
    'BAIZE': 0,
    'BAJ': 0,
    'BAJA': 0,
    'BAJADA': 0,
    'BAJAJ': 0,
    'BAJANA': 0,
    'BAJDA': 0,
    'BAJEK': 0,
    'BAJEMA': 0,
    'BAJER': 0,
    'BAJET': 0,
    'BAJIC': 0,
    'BAJKO': 0,
    'BAJKOWSKI': 0,
    'BAJO': 0,
    'BAJOR': 0,
    'BAJOREK': 0,
    'BAJPAI': 0,
    'BAJRAKTAREVIC': 0,
    'BAJRAKTARI': 0,
    'BAJRAMI': 0,
    'BAJRAMOVIC': 0,
    'BAJREKTAREVIC': 0,
    'BAJRIC': 0,
    'BAJUS': 0,
    'BAJWA': 0,
    'BAK': 0,
    'BAKA': 0,
    'BAKAITIS': 0,
    'BAKAL': 0,
    'BAKALAR': 0,
    'BAKALIAN': 0,
    'BAKALIS': 0,
    'BAKALYAR': 0,
    'BAKAN': 0,
    'BAKAR': 0,
    'BAKARE': 0,
    'BAKARI': 0,
    'BAKARICH': 0,
    'BAKAS': 0,
    'BAKAY': 0,
    'BAKE': 0,
    'BAKEBERG': 0,
    'BAKEL': 0,
    'BAKELY': 0,
    'BAKEMAN': 0,
    'BAKEN': 0,
    'BAKER': 0,
    'BAKERINK': 0,
    'BAKES': 0,
    'BAKEWELL': 0,
    'BAKEY': 0,
    'BAKHIT': 0,
    'BAKHSH': 0,
    'BAKHSHI': 0,
    'BAKHTIAR': 0,
    'BAKHTIARI': 0,
    'BAKI': 0,
    'BAKICH': 0,
    'BAKIES': 0,
    'BAKIR': 0,
    'BAKIS': 0,
    'BAKK': 0,
    'BAKKA': 0,
    'BAKKE': 0,
    'BAKKEN': 0,
    'BAKKER': 0,
    'BAKKILA': 0,
    'BAKKO': 0,
    'BAKKUM': 0,
    'BAKLE': 0,
    'BAKLEY': 0,
    'BAKMAN': 0,
    'BAKNER': 0,
    'BAKO': 0,
    'BAKOS': 0,
    'BAKOWSKI': 0,
    'BAKR': 0,
    'BAKRI': 0,
    'BAKSA': 0,
    'BAKSH': 0,
    'BAKSHI': 0,
    'BAKST': 0,
    'BAKULA': 0,
    'BAKUN': 0,
    'BAKUNAS': 0,
    'BAKUTIS': 0,
    'BAL': 0,
    'BALA': 0,
    'BALAAM': 0,
    'BALABAN': 0,
    'BALABON': 0,
    'BALACH': 0,
    'BALACHANDRAN': 0,
    'BALADAD': 0,
    'BALADES': 0,
    'BALADEZ': 0,
    'BALADO': 0,
    'BALADY': 0,
    'BALAGNA': 0,
    'BALAGOT': 0,
    'BALAGTAS': 0,
    'BALAGUER': 0,
    'BALAIS': 0,
    'BALAJ': 0,
    'BALAJADIA': 0,
    'BALAJI': 0,
    'BALAK': 0,
    'BALAKRISHNAN': 0,
    'BALALA': 0,
    'BALAM': 0,
    'BALAN': 0,
    'BALANAY': 0,
    'BALANCE': 0,
    'BALANCIO': 0,
    'BALAND': 0,
    'BALANDA': 0,
    'BALANDRA': 0,
    'BALANDRAN': 0,
    'BALANDRANO': 0,
    'BALANGUE': 0,
    'BALANI': 0,
    'BALANON': 0,
    'BALANZA': 0,
    'BALANZAR': 0,
    'BALAOING': 0,
    'BALAREZO': 0,
    'BALAS': 0,
    'BALASA': 0,
    'BALASCO': 0,
    'BALASH': 0,
    'BALASKI': 0,
    'BALASKO': 0,
    'BALASSONE': 0,
    'BALASUBRAMANIAM': 0,
    'BALASUBRAMANIAN': 0,
    'BALATA': 0,
    'BALATBAT': 0,
    'BALAWENDER': 0,
    'BALAY': 0,
    'BALAYAN': 0,
    'BALAZ': 0,
    'BALAZS': 0,
    'BALAZY': 0,
    'BALBACH': 0,
    'BALBAS': 0,
    'BALBASTRO': 0,
    'BALBAUGH': 0,
    'BALBER': 0,
    'BALBI': 0,
    'BALBIN': 0,
    'BALBO': 0,
    'BALBOA': 0,
    'BALBONI': 0,
    'BALBOSA': 0,
    'BALBUENA': 0,
    'BALCACER': 0,
    'BALCAR': 0,
    'BALCARCEL': 0,
    'BALCAZAR': 0,
    'BALCER': 0,
    'BALCERAK': 0,
    'BALCEREK': 0,
    'BALCERZAK': 0,
    'BALCH': 0,
    'BALCHUNAS': 0,
    'BALCITA': 0,
    'BALCIUNAS': 0,
    'BALCK': 0,
    'BALCOM': 0,
    'BALCOMB': 0,
    'BALCOMBE': 0,
    'BALCONI': 0,
    'BALCORTA': 0,
    'BALD': 0,
    'BALDA': 0,
    'BALDACCHINO': 0,
    'BALDACCI': 0,
    'BALDANZA': 0,
    'BALDARELLI': 0,
    'BALDASARE': 0,
    'BALDASARO': 0,
    'BALDASSANO': 0,
    'BALDASSARE': 0,
    'BALDASSARI': 0,
    'BALDASSARO': 0,
    'BALDASSARRE': 0,
    'BALDAUF': 0,
    'BALDAUFF': 0,
    'BALDAZO': 0,
    'BALDE': 0,
    'BALDELLI': 0,
    'BALDELOMAR': 0,
    'BALDEN': 0,
    'BALDENEGRO': 0,
    'BALDEO': 0,
    'BALDEON': 0,
    'BALDER': 0,
    'BALDERA': 0,
    'BALDERAMA': 0,
    'BALDERAS': 0,
    'BALDERAZ': 0,
    'BALDERRAMA': 0,
    'BALDERSON': 0,
    'BALDERSTON': 0,
    'BALDES': 0,
    'BALDESSARI': 0,
    'BALDEZ': 0,
    'BALDI': 0,
    'BALDIE': 0,
    'BALDIN': 0,
    'BALDINELLI': 0,
    'BALDING': 0,
    'BALDINGER': 0,
    'BALDINI': 0,
    'BALDINO': 0,
    'BALDIVIA': 0,
    'BALDIZAN': 0,
    'BALDIZON': 0,
    'BALDNER': 0,
    'BALDO': 0,
    'BALDOCCHI': 0,
    'BALDOCK': 0,
    'BALDOMERO': 0,
    'BALDON': 0,
    'BALDONADO': 0,
    'BALDONI': 0,
    'BALDOVIN': 0,
    'BALDOVINO': 0,
    'BALDOVINOS': 0,
    'BALDOWSKI': 0,
    'BALDOZ': 0,
    'BALDREE': 0,
    'BALDRICA': 0,
    'BALDRICK': 0,
    'BALDRIDGE': 0,
    'BALDRIGE': 0,
    'BALDRY': 0,
    'BALDUCCI': 0,
    'BALDUF': 0,
    'BALDUFF': 0,
    'BALDUS': 0,
    'BALDUZZI': 0,
    'BALDWIN': 0,
    'BALDY': 0,
    'BALDYGA': 0,
    'BALE': 0,
    'BALEK': 0,
    'BALEN': 0,
    'BALENCIA': 0,
    'BALENGER': 0,
    'BALENO': 0,
    'BALENSIEFEN': 0,
    'BALENT': 0,
    'BALENTINE': 0,
    'BALENZUELA': 0,
    'BALER': 0,
    'BALERIO': 0,
    'BALERO': 0,
    'BALES': 0,
    'BALESTER': 0,
    'BALESTERI': 0,
    'BALESTRA': 0,
    'BALESTRACCI': 0,
    'BALESTRERI': 0,
    'BALESTRI': 0,
    'BALESTRIERE': 0,
    'BALESTRIERI': 0,
    'BALESTRINO': 0,
    'BALEY': 0,
    'BALFANY': 0,
    'BALFANZ': 0,
    'BALFE': 0,
    'BALFOUR': 0,
    'BALGA': 0,
    'BALGOBIN': 0,
    'BALHORN': 0,
    'BALI': 0,
    'BALIAN': 0,
    'BALIC': 0,
    'BALICE': 0,
    'BALICH': 0,
    'BALICK': 0,
    'BALICKI': 0,
    'BALIDEMAJ': 0,
    'BALIEY': 0,
    'BALIGA': 0,
    'BALIGAD': 0,
    'BALIK': 0,
    'BALIKO': 0,
    'BALILES': 0,
    'BALIN': 0,
    'BALINA': 0,
    'BALINGIT': 0,
    'BALINO': 0,
    'BALINSKI': 0,
    'BALINT': 0,
    'BALIS': 0,
    'BALISACAN': 0,
    'BALISE': 0,
    'BALISH': 0,
    'BALISTERI': 0,
    'BALISTRERI': 0,
    'BALISTRIERI': 0,
    'BALIUS': 0,
    'BALK': 0,
    'BALKA': 0,
    'BALKAM': 0,
    'BALKAN': 0,
    'BALKARAN': 0,
    'BALKCOM': 0,
    'BALKCUM': 0,
    'BALKE': 0,
    'BALKEMA': 0,
    'BALKEN': 0,
    'BALKENBUSH': 0,
    'BALKEY': 0,
    'BALKIN': 0,
    'BALKISSOON': 0,
    'BALKMAN': 0,
    'BALKO': 0,
    'BALKOVEC': 0,
    'BALKUM': 0,
    'BALKUS': 0,
    'BALKWILL': 0,
    'BALL': 0,
    'BALLA': 0,
    'BALLACHINO': 0,
    'BALLADARES': 0,
    'BALLAGH': 0,
    'BALLAH': 0,
    'BALLAM': 0,
    'BALLAN': 0,
    'BALLANCE': 0,
    'BALLANGER': 0,
    'BALLANTINE': 0,
    'BALLANTYNE': 0,
    'BALLAR': 0,
    'BALLARD': 0,
    'BALLARDO': 0,
    'BALLAS': 0,
    'BALLASH': 0,
    'BALLAST': 0,
    'BALLATO': 0,
    'BALLATORE': 0,
    'BALLAY': 0,
    'BALLBACH': 0,
    'BALLE': 0,
    'BALLEIN': 0,
    'BALLEJO': 0,
    'BALLEJOS': 0,
    'BALLEK': 0,
    'BALLEN': 0,
    'BALLENGEE': 0,
    'BALLENGER': 0,
    'BALLENSKY': 0,
    'BALLENTINE': 0,
    'BALLER': 0,
    'BALLERINI': 0,
    'BALLERSTEIN': 0,
    'BALLES': 0,
    'BALLESTAS': 0,
    'BALLESTER': 0,
    'BALLESTERO': 0,
    'BALLESTEROS': 0,
    'BALLETTA': 0,
    'BALLETTO': 0,
    'BALLEW': 0,
    'BALLEZ': 0,
    'BALLEZA': 0,
    'BALLHAGEN': 0,
    'BALLI': 0,
    'BALLIET': 0,
    'BALLIETT': 0,
    'BALLIEW': 0,
    'BALLIF': 0,
    'BALLIN': 0,
    'BALLINA': 0,
    'BALLINAS': 0,
    'BALLINES': 0,
    'BALLING': 0,
    'BALLINGER': 0,
    'BALLINGHAM': 0,
    'BALLINGTON': 0,
    'BALLIS': 0,
    'BALLMAN': 0,
    'BALLMANN': 0,
    'BALLMER': 0,
    'BALLO': 0,
    'BALLOCK': 0,
    'BALLOG': 0,
    'BALLON': 0,
    'BALLONE': 0,
    'BALLOON': 0,
    'BALLOR': 0,
    'BALLOS': 0,
    'BALLOT': 0,
    'BALLOU': 0,
    'BALLOUT': 0,
    'BALLOW': 0,
    'BALLOWE': 0,
    'BALLS': 0,
    'BALLUFF': 0,
    'BALLWAY': 0,
    'BALLWEBER': 0,
    'BALLWEG': 0,
    'BALLY': 0,
    'BALM': 0,
    'BALMA': 0,
    'BALMACEDA': 0,
    'BALMAIN': 0,
    'BALMAN': 0,
    'BALMAS': 0,
    'BALMASEDA': 0,
    'BALMAT': 0,
    'BALMER': 0,
    'BALMERT': 0,
    'BALMES': 0,
    'BALMFORTH': 0,
    'BALMIR': 0,
    'BALMORES': 0,
    'BALMOS': 0,
    'BALNIS': 0,
    'BALO': 0,
    'BALOCCA': 0,
    'BALOCH': 0,
    'BALODIS': 0,
    'BALOG': 0,
    'BALOGA': 0,
    'BALOGH': 0,
    'BALOGUN': 0,
    'BALOH': 0,
    'BALOK': 0,
    'BALON': 0,
    'BALONE': 0,
    'BALONEY': 0,
    'BALONIS': 0,
    'BALOS': 0,
    'BALOT': 0,
    'BALOUGH': 0,
    'BALOUN': 0,
    'BALOW': 0,
    'BALOWSKI': 0,
    'BALOY': 0,
    'BALRAM': 0,
    'BALS': 0,
    'BALSAM': 0,
    'BALSAMA': 0,
    'BALSAMO': 0,
    'BALSAN': 0,
    'BALSANO': 0,
    'BALSARA': 0,
    'BALSBAUGH': 0,
    'BALSDON': 0,
    'BALSECA': 0,
    'BALSEIRO': 0,
    'BALSER': 0,
    'BALSEWICZ': 0,
    'BALSIGER': 0,
    'BALSIMO': 0,
    'BALSINGER': 0,
    'BALSIS': 0,
    'BALSITIS': 0,
    'BALSLEY': 0,
    'BALSMAN': 0,
    'BALSOM': 0,
    'BALSON': 0,
    'BALSTAD': 0,
    'BALSTER': 0,
    'BALSZ': 0,
    'BALT': 0,
    'BALTA': 0,
    'BALTAR': 0,
    'BALTAS': 0,
    'BALTASAR': 0,
    'BALTAYAN': 0,
    'BALTAZAR': 0,
    'BALTER': 0,
    'BALTERA': 0,
    'BALTES': 0,
    'BALTHASAR': 0,
    'BALTHASER': 0,
    'BALTHAZAR': 0,
    'BALTHAZOR': 0,
    'BALTHIS': 0,
    'BALTHROP': 0,
    'BALTIC': 0,
    'BALTICH': 0,
    'BALTIER': 0,
    'BALTIERRA': 0,
    'BALTIERREZ': 0,
    'BALTIMORE': 0,
    'BALTODANO': 0,
    'BALTON': 0,
    'BALTRIP': 0,
    'BALTRUS': 0,
    'BALTRUSAITIS': 0,
    'BALTRUSCH': 0,
    'BALTS': 0,
    'BALTUS': 0,
    'BALTZ': 0,
    'BALTZEGAR': 0,
    'BALTZELL': 0,
    'BALTZER': 0,
    'BALTZLEY': 0,
    'BALU': 0,
    'BALUCH': 0,
    'BALUJA': 0,
    'BALUN': 0,
    'BALUSEK': 0,
    'BALUT': 0,
    'BALUTA': 0,
    'BALUTIS': 0,
    'BALUYOT': 0,
    'BALUYUT': 0,
    'BALVANEDA': 0,
    'BALVANZ': 0,
    'BALVERDE': 0,
    'BALVIN': 0,
    'BALWIN': 0,
    'BALWINSKI': 0,
    'BALY': 0,
    'BALYAN': 0,
    'BALYEAT': 0,
    'BALZ': 0,
    'BALZA': 0,
    'BALZANO': 0,
    'BALZARINI': 0,
    'BALZEN': 0,
    'BALZER': 0,
    'BAMACA': 0,
    'BAMBA': 0,
    'BAMBACE': 0,
    'BAMBACH': 0,
    'BAMBARA': 0,
    'BAMBARGER': 0,
    'BAMBAS': 0,
    'BAMBAUER': 0,
    'BAMBENEK': 0,
    'BAMBER': 0,
    'BAMBERG': 0,
    'BAMBERGER': 0,
    'BAMBERY': 0,
    'BAMBI': 1,
    'BAMBIC': 0,
    'BAMBICO': 0,
    'BAMBINO': 0,
    'BAMBRICK': 0,
    'BAMBROUGH': 0,
    'BAMBURG': 0,
    'BAMBURY': 0,
    'BAME': 0,
    'BAMER': 0,
    'BAMERT': 0,
    'BAMESBERGER': 0,
    'BAMFIELD': 0,
    'BAMFORD': 0,
    'BAMFORTH': 0,
    'BAMMAN': 0,
    'BAMMANN': 0,
    'BAMMEL': 0,
    'BAMMER': 0,
    'BAMMERLIN': 0,
    'BAMMERT': 0,
    'BAMONTE': 0,
    'BAMRICK': 0,
    'BAMSEY': 0,
    'BAN': 0,
    'BANA': 0,
    'BANAAG': 0,
    'BANACH': 0,
    'BANACK': 0,
    'BANAGA': 0,
    'BANAGAN': 0,
    'BANAHAN': 0,
    'BANAL': 0,
    'BANALES': 0,
    'BANAR': 0,
    'BANARES': 0,
    'BANAS': 0,
    'BANASH': 0,
    'BANASIAK': 0,
    'BANASIEWICZ': 0,
    'BANASIK': 0,
    'BANASZAK': 0,
    'BANASZEK': 0,
    'BANASZEWSKI': 0,
    'BANASZYNSKI': 0,
    'BANAT': 0,
    'BANAYAN': 0,
    'BANBURY': 0,
    'BANCE': 0,
    'BANCHERO': 0,
    'BANCHS': 0,
    'BANCO': 0,
    'BANCROFT': 0,
    'BAND': 0,
    'BANDA': 0,
    'BANDAK': 0,
    'BANDARI': 0,
    'BANDAS': 0,
    'BANDEIRA': 0,
    'BANDEL': 0,
    'BANDELE': 0,
    'BANDELIN': 0,
    'BANDELL': 0,
    'BANDELOW': 0,
    'BANDEMER': 0,
    'BANDER': 0,
    'BANDERA': 0,
    'BANDERAS': 0,
    'BANDES': 0,
    'BANDFIELD': 0,
    'BANDI': 0,
    'BANDIERA': 0,
    'BANDIN': 0,
    'BANDINI': 0,
    'BANDISH': 0,
    'BANDLE': 0,
    'BANDLER': 0,
    'BANDLEY': 0,
    'BANDLOW': 0,
    'BANDO': 0,
    'BANDOLA': 0,
    'BANDONG': 0,
    'BANDONI': 0,
    'BANDOO': 0,
    'BANDOW': 0,
    'BANDS': 0,
    'BANDSTRA': 0,
    'BANDT': 0,
    'BANDUCCI': 0,
    'BANDUR': 0,
    'BANDURA': 0,
    'BANDURSKI': 0,
    'BANDY': 0,
    'BANDYK': 0,
    'BANDYOPADHYAY': 0,
    'BANE': 0,
    'BANECK': 0,
    'BANEGAS': 0,
    'BANEK': 0,
    'BANER': 0,
    'BANERJEE': 0,
    'BANERJI': 0,
    'BANES': 0,
    'BANET': 0,
    'BANEY': 0,
    'BANEZ': 0,
    'BANFI': 0,
    'BANFIELD': 0,
    'BANFILL': 0,
    'BANFORD': 0,
    'BANG': 0,
    'BANGA': 0,
    'BANGAR': 0,
    'BANGART': 0,
    'BANGASH': 0,
    'BANGASSER': 0,
    'BANGE': 0,
    'BANGEL': 0,
    'BANGEN': 0,
    'BANGER': 0,
    'BANGERT': 0,
    'BANGERTER': 0,
    'BANGHAM': 0,
    'BANGHART': 0,
    'BANGLE': 0,
    'BANGMA': 0,
    'BANGO': 0,
    'BANGOURA': 0,
    'BANGS': 0,
    'BANGSUND': 0,
    'BANGURA': 0,
    'BANH': 0,
    'BANHAM': 0,
    'BANHART': 0,
    'BANHOLZER': 0,
    'BANI': 0,
    'BANIA': 0,
    'BANIAGA': 0,
    'BANIAK': 0,
    'BANIC': 0,
    'BANICH': 0,
    'BANICK': 0,
    'BANICKI': 0,
    'BANIEWICZ': 0,
    'BANIGAN': 0,
    'BANIK': 0,
    'BANION': 0,
    'BANIQUED': 0,
    'BANIS': 0,
    'BANISH': 0,
    'BANISTER': 0,
    'BANITT': 0,
    'BANJO': 0,
    'BANK': 0,
    'BANKA': 0,
    'BANKARD': 0,
    'BANKE': 0,
    'BANKEMPER': 0,
    'BANKEN': 0,
    'BANKER': 0,
    'BANKERS': 0,
    'BANKERT': 0,
    'BANKES': 0,
    'BANKESTER': 0,
    'BANKEY': 0,
    'BANKHEAD': 0,
    'BANKO': 0,
    'BANKOLE': 0,
    'BANKOS': 0,
    'BANKOVICH': 0,
    'BANKOWSKI': 0,
    'BANKS': 0,
    'BANKSON': 0,
    'BANKSTON': 0,
    'BANKUS': 0,
    'BANKY': 0,
    'BANMAN': 0,
    'BANN': 0,
    'BANNA': 0,
    'BANNACH': 0,
    'BANNAN': 0,
    'BANNASCH': 0,
    'BANNEN': 0,
    'BANNER': 0,
    'BANNERMAN': 0,
    'BANNERT': 0,
    'BANNETT': 0,
    'BANNICK': 0,
    'BANNIGAN': 0,
    'BANNING': 0,
    'BANNISH': 0,
    'BANNISTER': 0,
    'BANNO': 0,
    'BANNON': 0,
    'BANNOW': 0,
    'BANO': 0,
    'BANOS': 0,
    'BANOVIC': 0,
    'BANOVICH': 0,
    'BANOWETZ': 0,
    'BANS': 0,
    'BANSAL': 0,
    'BANSBACH': 0,
    'BANSCHBACH': 0,
    'BANSE': 0,
    'BANSEMER': 0,
    'BANSEN': 0,
    'BANSER': 0,
    'BANSIL': 0,
    'BANSON': 0,
    'BANT': 0,
    'BANTA': 0,
    'BANTEL': 0,
    'BANTER': 0,
    'BANTHER': 0,
    'BANTILAN': 0,
    'BANTING': 0,
    'BANTLE': 0,
    'BANTON': 0,
    'BANTUG': 0,
    'BANTUM': 0,
    'BANTY': 0,
    'BANTZ': 0,
    'BANU': 0,
    'BANUCHI': 0,
    'BANUELAS': 0,
    'BANUELOS': 0,
    'BANVELOS': 0,
    'BANVILLE': 0,
    'BANWAIT': 0,
    'BANWART': 0,
    'BANWARTH': 0,
    'BANWELL': 0,
    'BANY': 0,
    'BANYAI': 0,
    'BANYARD': 0,
    'BANYAS': 0,
    'BANZ': 0,
    'BANZER': 0,
    'BANZET': 0,
    'BANZHAF': 0,
    'BANZHOF': 0,
    'BANZHOFF': 0,
    'BANZON': 0,
    'BAO': 0.7518796992481203,
    'BAPAT': 0,
    'BAPP': 0,
    'BAPPE': 0,
    'BAPPERT': 0,
    'BAPST': 0,
    'BAPTIE': 0,
    'BAPTISE': 0,
    'BAPTIST': 0,
    'BAPTISTA': 0,
    'BAPTISTE': 0,
    'BAQUE': 0,
    'BAQUEDANO': 0,
    'BAQUERA': 0,
    'BAQUERIZO': 0,
    'BAQUERO': 0,
    'BAQUET': 0,
    'BAQUI': 0,
    'BAQUIRAN': 0,
    'BAR': 0,
    'BARA': 0,
    'BARABAN': 0,
    'BARABARA': 1,
    'BARABAS': 0,
    'BARABASH': 0,
    'BARABASZ': 0,
    'BARABE': 0,
    'BARABIN': 0,
    'BARABINO': 0,
    'BARAC': 0,
    'BARACCO': 0,
    'BARACH': 0,
    'BARACK': 0,
    'BARACKMAN': 0,
    'BARAD': 0,
    'BARADA': 0,
    'BARADI': 0,
    'BARAGA': 0,
    'BARAGAN': 0,
    'BARAGAR': 0,
    'BARAGAS': 0,
    'BARAGER': 0,
    'BARAGONA': 0,
    'BARAHONA': 0,
    'BARAJAS': 0,
    'BARAK': 0,
    'BARAKA': 0,
    'BARAKAT': 0,
    'BARAL': 0,
    'BARALDI': 0,
    'BARALT': 0,
    'BARAM': 0,
    'BARAN': 0,
    'BARANAUSKAS': 0,
    'BARANCO': 0,
    'BARANCZYK': 0,
    'BARANDA': 0,
    'BARANEK': 0,
    'BARANELLO': 0,
    'BARANIAK': 0,
    'BARANICK': 0,
    'BARANIK': 0,
    'BARANKO': 0,
    'BARANOFF': 0,
    'BARANOSKI': 0,
    'BARANOV': 0,
    'BARANOWSKI': 0,
    'BARANSKI': 0,
    'BARANSKY': 0,
    'BARANY': 0,
    'BARANYAI': 0,
    'BARANYI': 0,
    'BARANYK': 0,
    'BARAO': 0,
    'BARAONA': 0,
    'BARARD': 0,
    'BARAS': 0,
    'BARASCH': 0,
    'BARASH': 0,
    'BARAT': 0,
    'BARATA': 0,
    'BARATH': 0,
    'BARATI': 0,
    'BARATS': 0,
    'BARATTA': 0,
    'BARATTI': 0,
    'BARATTINI': 0,
    'BARATTO': 0,
    'BARATZ': 0,
    'BARAUSKAS': 0,
    'BARAW': 0,
    'BARAY': 0,
    'BARAYUGA': 0,
    'BARAZA': 0,
    'BARAZI': 0,
    'BARB': 0.9009009009009008,
    'BARBA': 0,
    'BARBACCIA': 0,
    'BARBADILLO': 0,
    'BARBAGALLO': 0,
    'BARBAGELATA': 0,
    'BARBAGLIA': 0,
    'BARBALACE': 0,
    'BARBAN': 0,
    'BARBANELL': 0,
    'BARBANO': 0,
    'BARBAR': 0.9090909090909091,
    'BARBARA': 0.9989500830759508,
    'BARBARAA': 0,
    'BARBARAJ': 0,
    'BARBARAN': 0,
    'BARBARE': 0,
    'BARBAREE': 0,
    'BARBARI': 0,
    'BARBARIA': 0,
    'BARBARICH': 0,
    'BARBARICK': 0,
    'BARBARIN': 0,
    'BARBARINO': 0,
    'BARBARISI': 0,
    'BARBARITO': 0,
    'BARBARO': 0,
    'BARBAROSSA': 0,
    'BARBAROTTA': 0,
    'BARBARY': 0,
    'BARBAS': 0,
    'BARBASH': 0,
    'BARBAT': 0,
    'BARBATI': 0,
    'BARBATO': 0,
    'BARBAY': 0,
    'BARBE': 0,
    'BARBEAU': 0,
    'BARBECHO': 0,
    'BARBEE': 0,
    'BARBEITO': 0,
    'BARBEL': 0,
    'BARBELLA': 0,
    'BARBEN': 0,
    'BARBER': 0,
    'BARBERA': 0.6269592476489028,
    'BARBERAN': 0,
    'BARBERE': 0,
    'BARBERENA': 0,
    'BARBERI': 0,
    'BARBERICH': 0,
    'BARBERIE': 0,
    'BARBERIO': 0,
    'BARBERIS': 0,
    'BARBERO': 0,
    'BARBERY': 0,
    'BARBES': 0,
    'BARBETTA': 0,
    'BARBEY': 0,
    'BARBI': 0,
    'BARBIAN': 0,
    'BARBIC': 0,
    'BARBIE': 0.967741935483871,
    'BARBIER': 0,
    'BARBIERE': 0,
    'BARBIERI': 0,
    'BARBIERO': 0,
    'BARBIN': 0,
    'BARBINI': 0,
    'BARBIS': 0,
    'BARBISH': 0,
    'BARBITTA': 0,
    'BARBKNECHT': 0,
    'BARBO': 0,
    'BARBOA': 0,
    'BARBON': 0,
    'BARBONE': 0,
    'BARBONI': 0,
    'BARBOR': 0,
    'BARBORAK': 0,
    'BARBOSA': 0,
    'BARBOT': 0,
    'BARBOUR': 0,
    'BARBOZA': 0,
    'BARBRA': 0.9966777408637872,
    'BARBRE': 0,
    'BARBREE': 0,
    'BARBREY': 0,
    'BARBRICK': 0,
    'BARBROW': 0,
    'BARBU': 0,
    'BARBUR': 0,
    'BARBUS': 0,
    'BARBUSH': 0,
    'BARBUTI': 0,
    'BARBUTO': 0,
    'BARBY': 0,
    'BARC': 0,
    'BARCA': 0,
    'BARCAL': 0,
    'BARCALOW': 0,
    'BARCARSE': 0,
    'BARCE': 0,
    'BARCELLO': 0,
    'BARCELLONA': 0,
    'BARCELLOS': 0,
    'BARCELO': 0,
    'BARCELON': 0,
    'BARCELONA': 0,
    'BARCELOS': 0,
    'BARCENA': 0,
    'BARCENAS': 0,
    'BARCH': 0,
    'BARCHAK': 0,
    'BARCHARD': 0,
    'BARCHEERS': 0,
    'BARCHENGER': 0,
    'BARCHESKI': 0,
    'BARCHET': 0,
    'BARCHI': 0,
    'BARCHUS': 0,
    'BARCI': 0,
    'BARCIA': 0,
    'BARCIK': 0,
    'BARCIKOWSKI': 0,
    'BARCINAS': 0,
    'BARCK': 0,
    'BARCKLEY': 0,
    'BARCLAY': 0,
    'BARCLEY': 0,
    'BARCLIFF': 0,
    'BARCLIFT': 0,
    'BARCO': 0,
    'BARCOMB': 0,
    'BARCOME': 0,
    'BARCROFT': 0,
    'BARCUS': 0,
    'BARCZAK': 0,
    'BARCZEWSKI': 0,
    'BARCZYK': 0,
    'BARCZYKOWSKI': 0,
    'BARCZYNSKI': 0,
    'BARD': 0,
    'BARDA': 0,
    'BARDACH': 0,
    'BARDALES': 0,
    'BARDASH': 0,
    'BARDE': 0,
    'BARDEEN': 0,
    'BARDELL': 0,
    'BARDELLI': 0,
    'BARDEN': 0,
    'BARDENHAGEN': 0,
    'BARDER': 0,
    'BARDES': 0,
    'BARDGETT': 0,
    'BARDI': 0,
    'BARDILL': 0,
    'BARDIN': 0,
    'BARDING': 0,
    'BARDINI': 0,
    'BARDIS': 0,
    'BARDLEY': 0,
    'BARDNEY': 0,
    'BARDO': 0,
    'BARDOL': 0,
    'BARDON': 0,
    'BARDONI': 0,
    'BARDOS': 0,
    'BARDOT': 0,
    'BARDSLEY': 0,
    'BARDWELL': 0,
    'BARDY': 0,
    'BARE': 0,
    'BAREA': 0,
    'BAREFIELD': 0,
    'BAREFOOT': 0,
    'BAREFORD': 0,
    'BAREHAM': 0,
    'BAREIS': 0,
    'BAREISS': 0,
    'BAREL': 0,
    'BARELA': 0,
    'BARELLA': 0,
    'BARELLI': 0,
    'BARELLO': 0,
    'BAREMAN': 0,
    'BAREMORE': 0,
    'BAREN': 0,
    'BARENBAUM': 0,
    'BARENBERG': 0,
    'BARENDS': 0,
    'BARENDSE': 0,
    'BARENG': 0,
    'BARENO': 0,
    'BARENS': 0,
    'BARENTINE': 0,
    'BARENZ': 0,
    'BARER': 0,
    'BARERRA': 0,
    'BARES': 0,
    'BARESE': 0,
    'BARET': 0,
    'BARETTA': 0,
    'BARETTE': 0,
    'BARFELL': 0,
    'BARFIELD': 0,
    'BARFKNECHT': 0,
    'BARFOOT': 0,
    'BARFORD': 0,
    'BARFUSS': 0,
    'BARG': 0,
    'BARGA': 0,
    'BARGANIER': 0,
    'BARGAR': 0,
    'BARGAS': 0,
    'BARGE': 0,
    'BARGEN': 0,
    'BARGENDER': 0,
    'BARGENQUAST': 0,
    'BARGER': 0,
    'BARGERHUFF': 0,
    'BARGERON': 0,
    'BARGERSTOCK': 0,
    'BARGERY': 0,
    'BARGES': 0,
    'BARGFREDE': 0,
    'BARGIEL': 0,
    'BARGMAN': 0,
    'BARGMANN': 0,
    'BARGO': 0,
    'BARGSLEY': 0,
    'BARGY': 0,
    'BARHAM': 0,
    'BARHITE': 0,
    'BARHORST': 0,
    'BARHYDT': 0,
    'BARI': 0.746268656716418,
    'BARIA': 0,
    'BARIAS': 0,
    'BARIBAULT': 0,
    'BARIBEAU': 0,
    'BARIBEAULT': 0,
    'BARIC': 0,
    'BARICEVIC': 0,
    'BARICH': 0,
    'BARICKMAN': 0,
    'BARIE': 0,
    'BARIENTOS': 0,
    'BARIL': 0,
    'BARILA': 0,
    'BARILE': 0,
    'BARILL': 0,
    'BARILLA': 0,
    'BARILLARI': 0,
    'BARILLARO': 0,
    'BARILLAS': 0,
    'BARILLEAUX': 0,
    'BARILONE': 0,
    'BARIN': 0,
    'BARINA': 0,
    'BARINAS': 0,
    'BARINEAU': 0,
    'BARING': 0,
    'BARINGER': 0,
    'BARIOS': 0,
    'BARIS': 0,
    'BARISANO': 0,
    'BARISH': 0,
    'BARISIC': 0,
    'BARISO': 0,
    'BARITEAU': 0,
    'BARJAS': 0,
    'BARK': 0,
    'BARKA': 0,
    'BARKALOW': 0,
    'BARKAN': 0,
    'BARKAS': 0,
    'BARKAT': 0,
    'BARKAUSKAS': 0,
    'BARKDOLL': 0,
    'BARKDULL': 0,
    'BARKE': 0,
    'BARKEL': 0,
    'BARKELL': 0,
    'BARKEMA': 0,
    'BARKEMEYER': 0,
    'BARKEN': 0,
    'BARKER': 0,
    'BARKERS': 0,
    'BARKES': 0,
    'BARKET': 0,
    'BARKETT': 0,
    'BARKEY': 0,
    'BARKHIMER': 0,
    'BARKHO': 0,
    'BARKHOUSE': 0,
    'BARKHURST': 0,
    'BARKIE': 0,
    'BARKIN': 0,
    'BARKINS': 0,
    'BARKLAGE': 0,
    'BARKLEY': 0,
    'BARKLOW': 0,
    'BARKMAN': 0,
    'BARKMEIER': 0,
    'BARKO': 0,
    'BARKOFF': 0,
    'BARKOVICH': 0,
    'BARKOW': 0,
    'BARKOWSKI': 0,
    'BARKS': 0,
    'BARKSDALE': 0,
    'BARKUS': 0,
    'BARKWELL': 0,
    'BARKYOUMB': 0,
    'BARLAAN': 0,
    'BARLAGE': 0,
    'BARLAMENT': 0,
    'BARLAND': 0,
    'BARLAR': 0,
    'BARLAS': 0,
    'BARLASS': 0,
    'BARLATIER': 0,
    'BARLAU': 0,
    'BARLEEN': 0,
    'BARLET': 0,
    'BARLETT': 0,
    'BARLETTA': 0,
    'BARLETTO': 0,
    'BARLEY': 0,
    'BARLIN': 0,
    'BARLING': 0,
    'BARLOCK': 0,
    'BARLOG': 0,
    'BARLOON': 0,
    'BARLOTTA': 0,
    'BARLOW': 0,
    'BARLOWE': 0,
    'BARLUP': 0,
    'BARMAN': 0,
    'BARMANN': 0,
    'BARMER': 0,
    'BARMES': 0,
    'BARMETTLER': 0,
    'BARMORE': 0,
    'BARN': 0,
    'BARNA': 0,
    'BARNABA': 0,
    'BARNABAS': 0,
    'BARNABE': 0,
    'BARNABEI': 0,
    'BARNABY': 0,
    'BARNACHEA': 0,
    'BARNACK': 0,
    'BARNACLE': 0,
    'BARNAK': 0,
    'BARNARD': 0,
    'BARNAS': 0,
    'BARNAT': 0,
    'BARNBY': 0,
    'BARNCORD': 0,
    'BARND': 0,
    'BARNDOLLAR': 0,
    'BARNDT': 0,
    'BARNE': 0,
    'BARNEA': 0,
    'BARNEKOW': 0,
    'BARNELL': 0,
    'BARNELLO': 0,
    'BARNER': 0,
    'BARNES': 0,
    'BARNESS': 0,
    'BARNET': 0,
    'BARNETT': 0,
    'BARNETTE': 0,
    'BARNEY': 0.6093432633716994,
    'BARNEYCASTLE': 0,
    'BARNFATHER': 0,
    'BARNFIELD': 0,
    'BARNGROVER': 0,
    'BARNHARD': 0,
    'BARNHARDT': 0,
    'BARNHART': 0,
    'BARNHILL': 0,
    'BARNHISEL': 0,
    'BARNHORST': 0,
    'BARNHOUSE': 0,
    'BARNHURST': 0,
    'BARNI': 0,
    'BARNIAK': 0,
    'BARNICA': 0,
    'BARNICK': 0,
    'BARNICKEL': 0,
    'BARNICLE': 0,
    'BARNICOAT': 0,
    'BARNIDGE': 0,
    'BARNIER': 0,
    'BARNINGER': 0,
    'BARNINGHAM': 0,
    'BARNISH': 0,
    'BARNITZ': 0,
    'BARNO': 0,
    'BARNOSKI': 0,
    'BARNOSKY': 0,
    'BARNOWSKI': 0,
    'BARNOWSKY': 0,
    'BARNSHAW': 0,
    'BARNSLEY': 0,
    'BARNSON': 0,
    'BARNSTABLE': 0,
    'BARNSTEAD': 0,
    'BARNSWELL': 0,
    'BARNT': 0,
    'BARNTHOUSE': 0,
    'BARNTS': 0,
    'BARNUM': 0,
    'BARNWELL': 0,
    'BARO': 0,
    'BAROCAS': 0,
    'BAROCH': 0,
    'BAROCIO': 0,
    'BAROFF': 0,
    'BAROJAS': 0,
    'BARON': 0,
    'BARONA': 0,
    'BARONAS': 0,
    'BARONE': 0,
    'BARONET': 0,
    'BARONI': 0,
    'BARONIAN': 0,
    'BARONOWSKI': 0,
    'BAROODY': 0,
    'BAROS': 0,
    'BAROSH': 0,
    'BAROT': 0,
    'BAROTT': 0,
    'BAROUCH': 0,
    'BAROUDI': 0,
    'BAROUSSE': 0,
    'BAROWSKI': 0,
    'BAROWSKY': 0,
    'BAROZ': 0,
    'BARQUERA': 0,
    'BARQUERO': 0,
    'BARQUET': 0,
    'BARQUIN': 0,
    'BARQUIST': 0,
    'BARR': 0,
    'BARRA': 0,
    'BARRACA': 0,
    'BARRACATO': 0,
    'BARRACK': 0,
    'BARRACKS': 0,
    'BARRACLOUGH': 0,
    'BARRACO': 0,
    'BARRADAS': 0,
    'BARRAGAN': 0,
    'BARRAGER': 0,
    'BARRAGREE': 0,
    'BARRAJAS': 0,
    'BARRAL': 0,
    'BARRALAGA': 0,
    'BARRALE': 0,
    'BARRALES': 0,
    'BARRALL': 0,
    'BARRAMEDA': 0,
    'BARRAN': 0,
    'BARRANCA': 0,
    'BARRANCO': 0,
    'BARRAND': 0,
    'BARRANDEY': 0,
    'BARRANGER': 0,
    'BARRANTES': 0,
    'BARRANTI': 0,
    'BARRAR': 0,
    'BARRAS': 0,
    'BARRASA': 0,
    'BARRASS': 0,
    'BARRASSO': 0,
    'BARRATT': 0,
    'BARRAZA': 0,
    'BARRE': 0,
    'BARREA': 0,
    'BARREAU': 0,
    'BARRECA': 0,
    'BARREDA': 0,
    'BARREDO': 0,
    'BARREE': 0,
    'BARREIRA': 0,
    'BARREIRO': 0,
    'BARREIROS': 0,
    'BARRELA': 0,
    'BARRELL': 0,
    'BARRELLA': 0,
    'BARREN': 0,
    'BARRENA': 0,
    'BARRENECHEA': 0,
    'BARRENO': 0,
    'BARRENTINE': 0,
    'BARRER': 0,
    'BARRERA': 0,
    'BARRERAS': 0,
    'BARRERE': 0,
    'BARRERO': 0,
    'BARRES': 0,
    'BARRESE': 0,
    'BARRESI': 0,
    'BARRET': 0,
    'BARRETO': 0,
    'BARRETT': 0.12330456226880396,
    'BARRETTA': 0,
    'BARRETTE': 0,
    'BARRETTO': 0,
    'BARREZUETA': 0,
    'BARRI': 0,
    'BARRIA': 0,
    'BARRIAL': 0,
    'BARRIAULT': 0,
    'BARRIBEAU': 0,
    'BARRICELLA': 0,
    'BARRICELLI': 0,
    'BARRICK': 0,
    'BARRICKLOW': 0,
    'BARRICKMAN': 0,
    'BARRICKS': 0,
    'BARRIE': 0.5235602094240838,
    'BARRIEAU': 0,
    'BARRIENTES': 0,
    'BARRIENTEZ': 0,
    'BARRIENTO': 0,
    'BARRIENTOS': 0,
    'BARRIER': 0,
    'BARRIERA': 0,
    'BARRIERE': 0,
    'BARRIGA': 0,
    'BARRIGAN': 0,
    'BARRIGAR': 0,
    'BARRIGER': 0,
    'BARRILE': 0,
    'BARRILLEAUX': 0,
    'BARRINEAU': 0,
    'BARRINER': 0,
    'BARRINGER': 0,
    'BARRINGTON': 0,
    'BARRINO': 0,
    'BARRIO': 0,
    'BARRION': 0,
    'BARRIONUEVO': 0,
    'BARRIOS': 0,
    'BARRIS': 0,
    'BARRISH': 0,
    'BARRITA': 0,
    'BARRITEAU': 0,
    'BARRITT': 0,
    'BARRIX': 0,
    'BARRNETT': 0,
    'BARRO': 0,
    'BARROCAS': 0,
    'BARROGA': 0,
    'BARROIS': 0,
    'BARRON': 0,
    'BARRONE': 0,
    'BARRONS': 0,
    'BARROQUEIRO': 0,
    'BARROR': 0,
    'BARROS': 0,
    'BARROSO': 0,
    'BARROTT': 0,
    'BARROW': 0,
    'BARROWCLIFF': 0,
    'BARROWCLOUGH': 0,
    'BARROWMAN': 0,
    'BARROWS': 0,
    'BARROZO': 0,
    'BARRS': 0,
    'BARRUETA': 0,
    'BARRUS': 0,
    'BARRUTIA': 0,
    'BARRY': 0.889183808891838,
    'BARRYMORE': 0,
    'BARS': 0,
    'BARSA': 0,
    'BARSALOU': 0,
    'BARSAMIAN': 0,
    'BARSANTI': 0,
    'BARSCH': 0,
    'BARSE': 0,
    'BARSEGHIAN': 0,
    'BARSEGIAN': 0,
    'BARSEGYAN': 0,
    'BARSEMA': 0,
    'BARSH': 0,
    'BARSHAW': 0,
    'BARSHAY': 0,
    'BARSHINGER': 0,
    'BARSI': 0,
    'BARSIC': 0,
    'BARSKAYA': 0,
    'BARSKE': 0,
    'BARSKI': 0,
    'BARSKY': 0,
    'BARSNESS': 0,
    'BARSON': 0,
    'BARSOTTI': 0,
    'BARSOUM': 0,
    'BARSOUMIAN': 0,
    'BARSS': 0,
    'BARSTAD': 0,
    'BARSTOW': 0,
    'BARSUGLIA': 0,
    'BARSZCZ': 0,
    'BART': 0.9345794392523364,
    'BARTA': 0,
    'BARTAK': 0,
    'BARTAL': 0,
    'BARTASH': 0,
    'BARTCH': 0,
    'BARTCZAK': 0,
    'BARTE': 0,
    'BARTEAU': 0,
    'BARTEAUX': 0,
    'BARTECK': 0,
    'BARTEE': 0,
    'BARTEK': 0,
    'BARTEL': 0,
    'BARTELL': 0,
    'BARTELLE': 0,
    'BARTELLI': 0,
    'BARTELLO': 0,
    'BARTELLS': 0,
    'BARTELME': 0,
    'BARTELS': 0,
    'BARTELSON': 0,
    'BARTELT': 0,
    'BARTEN': 0,
    'BARTENHAGEN': 0,
    'BARTENSTEIN': 0,
    'BARTER': 0,
    'BARTES': 0,
    'BARTFIELD': 0,
    'BARTGES': 0,
    'BARTGIS': 0,
    'BARTH': 0,
    'BARTHA': 0,
    'BARTHALOW': 0,
    'BARTHE': 0,
    'BARTHEL': 0,
    'BARTHELEMY': 0,
    'BARTHELETTE': 0,
    'BARTHELL': 0,
    'BARTHELME': 0,
    'BARTHELMES': 0,
    'BARTHELMESS': 0,
    'BARTHELMY': 0,
    'BARTHELS': 0,
    'BARTHELUS': 0,
    'BARTHEN': 0,
    'BARTHLE': 0,
    'BARTHLOW': 0,
    'BARTHMAN': 0,
    'BARTHOL': 0,
    'BARTHOLD': 0,
    'BARTHOLET': 0,
    'BARTHOLF': 0,
    'BARTHOLIC': 0,
    'BARTHOLME': 0,
    'BARTHOLMEY': 0,
    'BARTHOLOMAE': 0,
    'BARTHOLOMAY': 0,
    'BARTHOLOME': 0,
    'BARTHOLOMEW': 0,
    'BARTHOLOMY': 0,
    'BARTHOLOW': 0,
    'BARTHULY': 0,
    'BARTICK': 0,
    'BARTIE': 0,
    'BARTIG': 0,
    'BARTIK': 0,
    'BARTIMUS': 0,
    'BARTIN': 0,
    'BARTIROMO': 0,
    'BARTIS': 0,
    'BARTISH': 0,
    'BARTKE': 0,
    'BARTKIEWICZ': 0,
    'BARTKO': 0,
    'BARTKOSKI': 0,
    'BARTKOWIAK': 0,
    'BARTKOWICZ': 0,
    'BARTKOWSKI': 0,
    'BARTKUS': 0,
    'BARTL': 0,
    'BARTLE': 0,
    'BARTLEBAUGH': 0,
    'BARTLEIN': 0,
    'BARTLES': 0,
    'BARTLESON': 0,
    'BARTLET': 0,
    'BARTLETT': 0,
    'BARTLETTE': 0,
    'BARTLEY': 0,
    'BARTLING': 0,
    'BARTLOME': 0,
    'BARTLOW': 0,
    'BARTMAN': 0,
    'BARTMANN': 0,
    'BARTMESS': 0,
    'BARTNER': 0,
    'BARTNESS': 0,
    'BARTNETT': 0,
    'BARTNICK': 0,
    'BARTNICKI': 0,
    'BARTNIK': 0,
    'BARTNIKOWSKI': 0,
    'BARTO': 0,
    'BARTOCCI': 0,
    'BARTOCK': 0,
    'BARTOE': 0,
    'BARTOK': 0,
    'BARTOL': 0,
    'BARTOLACCI': 0,
    'BARTOLD': 0,
    'BARTOLE': 0,
    'BARTOLETTI': 0,
    'BARTOLI': 0,
    'BARTOLINI': 0,
    'BARTOLINO': 0,
    'BARTOLO': 0,
    'BARTOLOME': 0,
    'BARTOLOMEI': 0,
    'BARTOLOMEO': 0,
    'BARTOLOMEY': 0,
    'BARTOLOMUCCI': 0,
    'BARTOLON': 0,
    'BARTOLONE': 0,
    'BARTOLONI': 0,
    'BARTOLOTTA': 0,
    'BARTOLOTTI': 0,
    'BARTOLOTTO': 0,
    'BARTOLOVICH': 0,
    'BARTOLOZZI': 0,
    'BARTOLUCCI': 0,
    'BARTON': 0.19543973941368079,
    'BARTONE': 0,
    'BARTONI': 0,
    'BARTOO': 0,
    'BARTOS': 0,
    'BARTOSCH': 0,
    'BARTOSEK': 0,
    'BARTOSH': 0,
    'BARTOSIAK': 0,
    'BARTOSIEWICZ': 0,
    'BARTOSIK': 0,
    'BARTOSZ': 0,
    'BARTOSZEK': 0,
    'BARTOSZEWICZ': 0,
    'BARTOW': 0,
    'BARTRA': 0,
    'BARTRAM': 0,
    'BARTROM': 0,
    'BARTRON': 0,
    'BARTRUFF': 0,
    'BARTRUG': 0,
    'BARTRUM': 0,
    'BARTS': 0,
    'BARTSCH': 0,
    'BARTSCHER': 0,
    'BARTSCHI': 0,
    'BARTSHE': 0,
    'BARTUCCA': 0,
    'BARTUCCI': 0,
    'BARTUCH': 0,
    'BARTULA': 0,
    'BARTUNEK': 0,
    'BARTUS': 0,
    'BARTUSCH': 0,
    'BARTUSEK': 0,
    'BARTUSH': 0,
    'BARTUSIAK': 0,
    'BARTUSKA': 0,
    'BARTY': 0,
    'BARTYZEL': 0,
    'BARTZ': 0,
    'BARTZEN': 0,
    'BARUA': 0,
    'BARUCH': 0,
    'BARUFFI': 0,
    'BARULICH': 0,
    'BARUM': 0,
    'BARUS': 0,
    'BARUT': 0,
    'BARUTH': 0,
    'BARUTHA': 0,
    'BARVA': 0,
    'BARVE': 0,
    'BARWARI': 0,
    'BARWELL': 0,
    'BARWICK': 0,
    'BARWIG': 0,
    'BARWIN': 0,
    'BARWISE': 0,
    'BARY': 0,
    'BARYLSKI': 0,
    'BARYS': 0,
    'BARZ': 0,
    'BARZAGA': 0,
    'BARZANO': 0,
    'BARZE': 0,
    'BARZEE': 0,
    'BARZEY': 0,
    'BARZILAY': 0,
    'BARZOLA': 0,
    'BARZYK': 0,
    'BAS': 0,
    'BASA': 0,
    'BASABE': 0,
    'BASAK': 0,
    'BASAL': 0,
    'BASALA': 0,
    'BASALDU': 0,
    'BASALDUA': 0,
    'BASALLA': 0,
    'BASALLO': 0,
    'BASALYGA': 0,
    'BASAN': 0,
    'BASANT': 0,
    'BASANTA': 0,
    'BASANTES': 0,
    'BASAR': 0,
    'BASARA': 0,
    'BASARAB': 0,
    'BASARABA': 0,
    'BASARAN': 0,
    'BASARGIN': 0,
    'BASARICH': 0,
    'BASART': 0,
    'BASAVE': 0,
    'BASBAS': 0,
    'BASCETTA': 0,
    'BASCH': 0,
    'BASCHE': 0,
    'BASCHNAGEL': 0,
    'BASCIANO': 0,
    'BASCLE': 0,
    'BASCO': 0,
    'BASCOM': 0,
    'BASCOMB': 0,
    'BASCOMBE': 0,
    'BASCON': 0,
    'BASCONCILLO': 0,
    'BASCONE': 0,
    'BASCUE': 0,
    'BASCUS': 0,
    'BASDEN': 0,
    'BASDEO': 0,
    'BASE': 0,
    'BASEDOW': 0,
    'BASEHORE': 0,
    'BASEL': 0,
    'BASELER': 0,
    'BASELEY': 0,
    'BASELICE': 0,
    'BASEMAN': 0,
    'BASEMORE': 0,
    'BASEN': 0,
    'BASENBACK': 0,
    'BASENBERG': 0,
    'BASER': 0,
    'BASEY': 0,
    'BASFORD': 0,
    'BASGALL': 0,
    'BASH': 0,
    'BASHA': 0,
    'BASHAM': 0,
    'BASHAN': 0,
    'BASHANT': 0,
    'BASHAR': 0,
    'BASHARA': 0,
    'BASHAW': 0,
    'BASHEER': 0,
    'BASHER': 0,
    'BASHFORD': 0,
    'BASHI': 0,
    'BASHIAN': 0,
    'BASHIOUM': 0,
    'BASHIR': 0,
    'BASHISTA': 0,
    'BASHLINE': 0,
    'BASHLOR': 0,
    'BASHOR': 0,
    'BASHORE': 0,
    'BASHOUR': 0,
    'BASI': 0,
    'BASIC': 0,
    'BASICH': 0,
    'BASIL': 0.9302325581395349,
    'BASILA': 0,
    'BASILE': 0,
    'BASILEO': 0,
    'BASILI': 0,
    'BASILIA': 1,
    'BASILICATO': 0,
    'BASILICO': 0,
    'BASILIERE': 0,
    'BASILIO': 0,
    'BASILONE': 0,
    'BASIN': 0,
    'BASINA': 0,
    'BASINGER': 0,
    'BASINSKI': 0,
    'BASIR': 0,
    'BASIRICO': 0,
    'BASISTA': 0,
    'BASIT': 0,
    'BASKA': 0,
    'BASKARAN': 0,
    'BASKE': 0,
    'BASKER': 0,
    'BASKERVILLE': 0,
    'BASKET': 0,
    'BASKETT': 0,
    'BASKETTE': 0,
    'BASKIN': 0,
    'BASKIND': 0,
    'BASKINS': 0,
    'BASKO': 0,
    'BASL': 0,
    'BASLEE': 0,
    'BASLER': 0,
    'BASLEY': 0,
    'BASLOW': 0,
    'BASMA': 0,
    'BASMADJIAN': 0,
    'BASMAJIAN': 0,
    'BASNAW': 0,
    'BASNER': 0,
    'BASNETT': 0,
    'BASNEY': 0,
    'BASNIGHT': 0,
    'BASO': 0,
    'BASOCO': 0,
    'BASOM': 0,
    'BASON': 0,
    'BASONE': 0,
    'BASORA': 0,
    'BASORE': 0,
    'BASPED': 0,
    'BASQUE': 0,
    'BASQUES': 0,
    'BASQUEZ': 0,
    'BASQUILL': 0,
    'BASQUIN': 0,
    'BASRA': 0,
    'BASS': 0,
    'BASSA': 0,
    'BASSAGE': 0,
    'BASSAN': 0,
    'BASSANI': 0,
    'BASSANO': 0,
    'BASSARD': 0,
    'BASSE': 0,
    'BASSEL': 0,
    'BASSELL': 0,
    'BASSEN': 0,
    'BASSET': 0,
    'BASSETT': 0,
    'BASSETTE': 0,
    'BASSETTI': 0,
    'BASSEY': 0,
    'BASSFORD': 0,
    'BASSHAM': 0,
    'BASSI': 0,
    'BASSIE': 0,
    'BASSIG': 0,
    'BASSIGNANI': 0,
    'BASSIL': 0,
    'BASSIN': 0,
    'BASSING': 0,
    'BASSINGER': 0,
    'BASSITT': 0,
    'BASSLER': 0,
    'BASSMAN': 0,
    'BASSO': 0,
    'BASSOLINO': 0,
    'BASSON': 0,
    'BASSUK': 0,
    'BAST': 0,
    'BASTA': 0,
    'BASTABLE': 0,
    'BASTAIN': 0,
    'BASTANI': 0,
    'BASTAR': 0,
    'BASTARACHE': 0,
    'BASTARDI': 0,
    'BASTARDO': 0,
    'BASTAS': 0,
    'BASTEAN': 0,
    'BASTEDO': 0,
    'BASTEK': 0,
    'BASTEN': 0,
    'BASTER': 0,
    'BASTERRECHEA': 0,
    'BASTI': 0,
    'BASTIAN': 0,
    'BASTIANELLI': 0,
    'BASTIANI': 0,
    'BASTIDA': 0,
    'BASTIDAS': 0,
    'BASTIEN': 0,
    'BASTILLE': 0,
    'BASTIN': 0,
    'BASTINE': 0,
    'BASTING': 0,
    'BASTION': 0,
    'BASTIS': 0,
    'BASTO': 0,
    'BASTON': 0,
    'BASTONE': 0,
    'BASTONI': 0,
    'BASTOS': 0,
    'BASTOW': 0,
    'BASTRESS': 0,
    'BASTRON': 0,
    'BASTYR': 0,
    'BASU': 0,
    'BASUA': 0,
    'BASUEL': 0,
    'BASULTO': 0,
    'BASURTO': 0,
    'BASWELL': 0,
    'BASYE': 0,
    'BASZLER': 0,
    'BATA': 0,
    'BATAC': 0,
    'BATACAN': 0,
    'BATAILLE': 0,
    'BATAL': 0,
    'BATALLA': 0,
    'BATALON': 0,
    'BATAN': 0,
    'BATANGAN': 0,
    'BATARA': 0,
    'BATARSE': 0,
    'BATARSEH': 0,
    'BATASTINI': 0,
    'BATAYEH': 0,
    'BATCH': 0,
    'BATCHA': 0,
    'BATCHAN': 0,
    'BATCHELDER': 0,
    'BATCHELER': 0,
    'BATCHELLER': 0,
    'BATCHELOR': 0,
    'BATCHER': 0,
    'BATCHLER': 0,
    'BATCHLOR': 0,
    'BATCHMAN': 0,
    'BATCHO': 0,
    'BATDORF': 0,
    'BATDORFF': 0,
    'BATE': 0,
    'BATEH': 0,
    'BATEL': 0,
    'BATELLI': 0,
    'BATEMAN': 0,
    'BATEMON': 0,
    'BATEN': 0,
    'BATENHORST': 0,
    'BATER': 0,
    'BATES': 0,
    'BATESOLE': 0,
    'BATESON': 0,
    'BATEY': 0,
    'BATH': 0,
    'BATHA': 0,
    'BATHALON': 0,
    'BATHAN': 0,
    'BATHAUER': 0,
    'BATHE': 0,
    'BATHEN': 0,
    'BATHER': 0,
    'BATHGATE': 0,
    'BATHIJA': 0,
    'BATHKE': 0,
    'BATHO': 0,
    'BATHON': 0,
    'BATHORY': 0,
    'BATHRICK': 0,
    'BATHURST': 0,
    'BATI': 0,
    'BATIE': 0,
    'BATIN': 0,
    'BATINICH': 0,
    'BATIS': 0,
    'BATISTA': 0,
    'BATISTE': 0,
    'BATIZ': 0,
    'BATKA': 0,
    'BATKE': 0,
    'BATKIEWICZ': 0,
    'BATKIN': 0,
    'BATKINS': 0,
    'BATKO': 0,
    'BATLA': 0,
    'BATLEY': 0,
    'BATLINER': 0,
    'BATLLE': 0,
    'BATMAN': 0,
    'BATO': 0,
    'BATOG': 0,
    'BATON': 0,
    'BATOON': 0,
    'BATOR': 0,
    'BATORY': 0,
    'BATOVSKY': 0,
    'BATRA': 0,
    'BATRES': 0,
    'BATREZ': 0,
    'BATSCH': 0,
    'BATSCHE': 0,
    'BATSEL': 0,
    'BATSELL': 0,
    'BATSFORD': 0,
    'BATSON': 0,
    'BATSTONE': 0,
    'BATT': 0,
    'BATTA': 0,
    'BATTAD': 0,
    'BATTAGLIA': 0,
    'BATTAGLINI': 0,
    'BATTAGLINO': 0,
    'BATTAILE': 0,
    'BATTAN': 0,
    'BATTANI': 0,
    'BATTAT': 0,
    'BATTCHER': 0,
    'BATTE': 0,
    'BATTEAST': 0,
    'BATTEE': 0,
    'BATTEIGER': 0,
    'BATTEL': 0,
    'BATTELL': 0,
    'BATTELLE': 0,
    'BATTEN': 0,
    'BATTENBERG': 0,
    'BATTENFELD': 0,
    'BATTENFIELD': 0,
    'BATTER': 0,
    'BATTERBEE': 0,
    'BATTERMAN': 0,
    'BATTERMANN': 0,
    'BATTERS': 0,
    'BATTERSBY': 0,
    'BATTERSHELL': 0,
    'BATTERSON': 0,
    'BATTERTON': 0,
    'BATTEY': 0,
    'BATTH': 0,
    'BATTI': 0,
    'BATTIATO': 0,
    'BATTICE': 0,
    'BATTIE': 0,
    'BATTIES': 0,
    'BATTIEST': 0,
    'BATTIG': 0,
    'BATTILANA': 0,
    'BATTIN': 0,
    'BATTINELLI': 0,
    'BATTINO': 0,
    'BATTIPAGLIA': 0,
    'BATTIS': 0,
    'BATTISE': 0,
    'BATTISON': 0,
    'BATTIST': 0,
    'BATTISTA': 0,
    'BATTISTE': 0,
    'BATTISTELLA': 0,
    'BATTISTELLI': 0,
    'BATTISTI': 0,
    'BATTISTINI': 0,
    'BATTISTO': 0,
    'BATTISTON': 0,
    'BATTISTONE': 0,
    'BATTISTONI': 0,
    'BATTJES': 0,
    'BATTLE': 0,
    'BATTLES': 0,
    'BATTLESON': 0,
    'BATTLEY': 0,
    'BATTO': 0,
    'BATTON': 0,
    'BATTREAL': 0,
    'BATTREALL': 0,
    'BATTS': 0,
    'BATTSON': 0,
    'BATTUNG': 0,
    'BATTY': 0,
    'BATULA': 0,
    'BATURA': 0,
    'BATY': 0,
    'BATYE': 0,
    'BATYKEFER': 0,
    'BATZ': 0,
    'BATZEL': 0,
    'BATZER': 0,
    'BATZLER': 0,
    'BAU': 0,
    'BAUBLIT': 0,
    'BAUBLITZ': 0,
    'BAUCH': 0,
    'BAUCHAM': 0,
    'BAUCHER': 0,
    'BAUCHMAN': 0,
    'BAUCK': 0,
    'BAUCKE': 0,
    'BAUCKMAN': 0,
    'BAUCOM': 0,
    'BAUCUM': 0,
    'BAUD': 0,
    'BAUDANZA': 0,
    'BAUDE': 0,
    'BAUDEAN': 0,
    'BAUDENDISTEL': 0,
    'BAUDER': 0,
    'BAUDERS': 0,
    'BAUDHUIN': 0,
    'BAUDIER': 0,
    'BAUDIN': 0,
    'BAUDINO': 0,
    'BAUDLER': 0,
    'BAUDO': 0,
    'BAUDOIN': 0,
    'BAUDOUIN': 0,
    'BAUDOUX': 0,
    'BAUDRY': 0,
    'BAUE': 0,
    'BAUER': 0,
    'BAUERLE': 0,
    'BAUERLEIN': 0,
    'BAUERLY': 0,
    'BAUERMEISTER': 0,
    'BAUERNFEIND': 0,
    'BAUERS': 0,
    'BAUERSCHMIDT': 0,
    'BAUERSFELD': 0,
    'BAUGESS': 0,
    'BAUGH': 0,
    'BAUGHAM': 0,
    'BAUGHAN': 0,
    'BAUGHCUM': 0,
    'BAUGHER': 0,
    'BAUGHEY': 0,
    'BAUGHMAN': 0,
    'BAUGHN': 0,
    'BAUGUESS': 0,
    'BAUGUS': 0,
    'BAUGUSS': 0,
    'BAUHOF': 0,
    'BAUHS': 0,
    'BAUKNECHT': 0,
    'BAUKNIGHT': 0,
    'BAUKOL': 0,
    'BAUL': 0,
    'BAULCH': 0,
    'BAULD': 0,
    'BAULDING': 0,
    'BAULDREE': 0,
    'BAULDRY': 0,
    'BAULE': 0,
    'BAULEKE': 0,
    'BAULER': 0,
    'BAULT': 0,
    'BAUM': 0,
    'BAUMAN': 0,
    'BAUMANN': 0,
    'BAUMBACH': 0,
    'BAUMBARGER': 0,
    'BAUMBERGER': 0,
    'BAUMCHEN': 0,
    'BAUMEISTER': 0,
    'BAUMEL': 0,
    'BAUMER': 0,
    'BAUMERT': 0,
    'BAUMES': 0,
    'BAUMFALK': 0,
    'BAUMGARD': 0,
    'BAUMGARDEN': 0,
    'BAUMGARDNER': 0,
    'BAUMGARDT': 0,
    'BAUMGARNER': 0,
    'BAUMGART': 0,
    'BAUMGARTE': 0,
    'BAUMGARTEL': 0,
    'BAUMGARTEN': 0,
    'BAUMGARTH': 0,
    'BAUMGARTNER': 0,
    'BAUMGRAS': 0,
    'BAUMHARDT': 0,
    'BAUMHOVER': 0,
    'BAUMILLER': 0,
    'BAUML': 0,
    'BAUMLE': 0,
    'BAUMLER': 0,
    'BAUMMER': 0,
    'BAUMSTARK': 0,
    'BAUMSTEIN': 0,
    'BAUMUNK': 0,
    'BAUN': 0,
    'BAUNACH': 0,
    'BAUNE': 0,
    'BAUR': 0,
    'BAURER': 0,
    'BAURES': 0,
    'BAURICHTER': 0,
    'BAURLE': 0,
    'BAUS': 0,
    'BAUSBACK': 0,
    'BAUSCH': 0,
    'BAUSCHER': 0,
    'BAUSE': 0,
    'BAUSER': 0,
    'BAUSERMAN': 0,
    'BAUSHER': 0,
    'BAUSINGER': 0,
    'BAUSKE': 0,
    'BAUSLEY': 0,
    'BAUSMAN': 0,
    'BAUSO': 0,
    'BAUST': 0,
    'BAUSTERT': 0,
    'BAUSTIAN': 0,
    'BAUSUM': 0,
    'BAUSWELL': 0,
    'BAUTA': 0,
    'BAUTCH': 0,
    'BAUTE': 0,
    'BAUTER': 0,
    'BAUTISTA': 0,
    'BAUTIZTA': 0,
    'BAUTSCH': 0,
    'BAUTZ': 0,
    'BAUWENS': 0,
    'BAUX': 0,
    'BAUZA': 0,
    'BAUZON': 0,
    'BAVA': 0,
    'BAVARO': 0,
    'BAVERY': 0,
    'BAVIER': 0,
    'BAVIN': 0,
    'BAVIS': 0,
    'BAVONE': 0,
    'BAVOSA': 0,
    'BAVUSO': 0,
    'BAWA': 0,
    'BAWANY': 0,
    'BAWCOM': 0,
    'BAWCUM': 0,
    'BAWDEN': 0,
    'BAWDON': 0,
    'BAWEJA': 0,
    'BAWEK': 0,
    'BAWOL': 0,
    'BAX': 0,
    'BAXA': 0,
    'BAXENDALE': 0,
    'BAXENDELL': 0,
    'BAXER': 0,
    'BAXI': 0,
    'BAXLEY': 0,
    'BAXTER': 0,
    'BAXTON': 0,
    'BAY': 0,
    'BAYA': 0,
    'BAYAN': 0,
    'BAYANI': 0,
    'BAYARD': 0,
    'BAYARDO': 0,
    'BAYAS': 0,
    'BAYAT': 0,
    'BAYATI': 0,
    'BAYBAYAN': 0,
    'BAYDOUN': 0,
    'BAYE': 0,
    'BAYENS': 0,
    'BAYER': 0,
    'BAYERL': 0,
    'BAYERLE': 0,
    'BAYERS': 0,
    'BAYES': 0,
    'BAYGENTS': 0,
    'BAYHA': 0,
    'BAYHAM': 0,
    'BAYHI': 0,
    'BAYKO': 0,
    'BAYLARK': 0,
    'BAYLE': 0,
    'BAYLEN': 0,
    'BAYLER': 0,
    'BAYLES': 0,
    'BAYLESS': 0,
    'BAYLEY': 0,
    'BAYLIE': 0,
    'BAYLIFF': 0,
    'BAYLIN': 0,
    'BAYLIS': 0,
    'BAYLISS': 0,
    'BAYLOCK': 0,
    'BAYLON': 0,
    'BAYLOR': 0,
    'BAYLOSIS': 0,
    'BAYLOUS': 0,
    'BAYLY': 0,
    'BAYMAN': 0,
    'BAYMILLER': 0,
    'BAYMON': 0,
    'BAYNARD': 0,
    'BAYNE': 0,
    'BAYNES': 0,
    'BAYNHAM': 0,
    'BAYNTON': 0,
    'BAYNUM': 0,
    'BAYO': 0,
    'BAYON': 0,
    'BAYONA': 0,
    'BAYONNE': 0,
    'BAYOT': 0,
    'BAYOUMI': 0,
    'BAYOUTH': 0,
    'BAYRAM': 0,
    'BAYRD': 0,
    'BAYRON': 0,
    'BAYS': 0,
    'BAYSA': 0,
    'BAYSDEN': 0,
    'BAYSE': 0,
    'BAYSINGER': 0,
    'BAYSMORE': 0,
    'BAYSORE': 0,
    'BAYTER': 0,
    'BAYTON': 0,
    'BAYTOPS': 0,
    'BAYUDAN': 0,
    'BAYUK': 0,
    'BAYUS': 0,
    'BAYZE': 0,
    'BAZ': 0,
    'BAZA': 0,
    'BAZALDUA': 0,
    'BAZAN': 0,
    'BAZANT': 0,
    'BAZAR': 0,
    'BAZARIAN': 0,
    'BAZATA': 0,
    'BAZE': 0,
    'BAZEL': 0,
    'BAZELAIS': 0,
    'BAZELL': 0,
    'BAZEMORE': 0,
    'BAZEN': 0,
    'BAZER': 0,
    'BAZIK': 0,
    'BAZIL': 0,
    'BAZILE': 0,
    'BAZILLE': 0,
    'BAZIN': 0,
    'BAZINET': 0,
    'BAZIS': 0,
    'BAZLEY': 0,
    'BAZNER': 0,
    'BAZO': 0,
    'BAZOR': 0,
    'BAZQUEZ': 0,
    'BAZUA': 0,
    'BAZURTO': 0,
    'BAZYDLO': 0,
    'BAZYK': 0,
    'BAZYLEWICZ': 0,
    'BAZZANI': 0,
    'BAZZANO': 0,
    'BAZZEL': 0,
    'BAZZELL': 0,
    'BAZZELLE': 0,
    'BAZZETT': 0,
    'BAZZI': 0,
    'BAZZINI': 0,
    'BAZZLE': 0,
    'BAZZO': 0,
    'BAZZOLI': 0,
    'BAZZY': 0,
    'BE': 0,
    'BEA': 0.9118541033434651,
    'BEABER': 0,
    'BEABOUT': 0,
    'BEACH': 0,
    'BEACHAM': 0,
    'BEACHAMP': 0,
    'BEACHBOARD': 0,
    'BEACHEL': 0,
    'BEACHELL': 0,
    'BEACHEM': 0,
    'BEACHER': 0,
    'BEACHEY': 0,
    'BEACHLER': 0,
    'BEACHLEY': 0,
    'BEACHMAN': 0,
    'BEACHNER': 0,
    'BEACHUM': 0,
    'BEACHY': 0,
    'BEACOM': 0,
    'BEACON': 0,
    'BEAD': 0,
    'BEADELL': 0,
    'BEADERSTADT': 0,
    'BEADLE': 0,
    'BEADLES': 0,
    'BEADLING': 0,
    'BEADNELL': 0,
    'BEADY': 0,
    'BEAGAN': 0,
    'BEAGLE': 0,
    'BEAGLES': 0,
    'BEAGLEY': 0,
    'BEAHAN': 0,
    'BEAHM': 0,
    'BEAHN': 0,
    'BEAHR': 0,
    'BEAIR': 0,
    'BEAIRD': 0,
    'BEAIRSTO': 0,
    'BEAK': 0,
    'BEAKES': 0,
    'BEAKLEY': 0,
    'BEAL': 0,
    'BEALE': 0,
    'BEALER': 0,
    'BEALES': 0,
    'BEALEY': 0,
    'BEALL': 0,
    'BEALLE': 0,
    'BEALMEAR': 0,
    'BEALOR': 0,
    'BEALS': 0,
    'BEAM': 0,
    'BEAMAN': 0,
    'BEAMER': 0,
    'BEAMES': 0,
    'BEAMESDERFER': 0,
    'BEAMIS': 0,
    'BEAMISH': 0,
    'BEAMON': 0,
    'BEAMS': 0,
    'BEAN': 0,
    'BEANBLOSSOM': 0,
    'BEANE': 0,
    'BEANER': 0,
    'BEANES': 0,
    'BEANEY': 0,
    'BEANLAND': 0,
    'BEANS': 0,
    'BEAR': 0,
    'BEARB': 0,
    'BEARBOWER': 0,
    'BEARCE': 0,
    'BEARD': 0,
    'BEARDALL': 0,
    'BEARDEN': 0,
    'BEARDMORE': 0,
    'BEARDON': 0,
    'BEARDS': 0,
    'BEARDSHEAR': 0,
    'BEARDSLEE': 0,
    'BEARDSLEY': 0,
    'BEARDSWORTH': 0,
    'BEARE': 0,
    'BEARER': 0,
    'BEARFIELD': 0,
    'BEARINGER': 0,
    'BEARLEY': 0,
    'BEARMAN': 0,
    'BEARNSON': 0,
    'BEAROR': 0,
    'BEARRY': 0,
    'BEARS': 0,
    'BEARSE': 0,
    'BEARSON': 0,
    'BEARSS': 0,
    'BEARUP': 0,
    'BEARY': 0,
    'BEAS': 0,
    'BEASEY': 0,
    'BEASINGER': 0,
    'BEASLEY': 0,
    'BEASLY': 0,
    'BEASOCK': 0,
    'BEASOM': 0,
    'BEASON': 0,
    'BEASTER': 0,
    'BEASTON': 0,
    'BEASY': 0,
    'BEAT': 0,
    'BEATA': 1,
    'BEATH': 0,
    'BEATHAM': 0,
    'BEATHARD': 0,
    'BEATHEA': 0,
    'BEATIE': 0,
    'BEATLEY': 0,
    'BEATO': 0,
    'BEATON': 0,
    'BEATRICE': 0.9969325153374232,
    'BEATRIS': 1,
    'BEATRIZ': 0.995575221238938,
    'BEATS': 0,
    'BEATSON': 0,
    'BEATTIE': 0,
    'BEATTY': 0,
    'BEATUS': 0,
    'BEATY': 0,
    'BEAU': 0.9879253567508233,
    'BEAUBIEN': 0,
    'BEAUBOUEF': 0,
    'BEAUBRUN': 0,
    'BEAUCAGE': 0,
    'BEAUCHAINE': 0,
    'BEAUCHAMP': 0,
    'BEAUCHANE': 0,
    'BEAUCHEMIN': 0,
    'BEAUCHENE': 0,
    'BEAUCHESNE': 0,
    'BEAUCLAIR': 0,
    'BEAUDET': 0,
    'BEAUDETTE': 0,
    'BEAUDIN': 0,
    'BEAUDINE': 0,
    'BEAUDION': 0,
    'BEAUDOIN': 0,
    'BEAUDREAU': 0,
    'BEAUDREAULT': 0,
    'BEAUDRIE': 0,
    'BEAUDROT': 0,
    'BEAUDRY': 0,
    'BEAUFAIT': 0,
    'BEAUFORD': 0,
    'BEAUFORT': 0,
    'BEAUGARD': 0,
    'BEAUGE': 0,
    'BEAUGEZ': 0,
    'BEAUGH': 0,
    'BEAUGRAND': 0,
    'BEAUJEAN': 0,
    'BEAULAC': 0,
    'BEAULAH': 1,
    'BEAULAURIER': 0,
    'BEAULE': 0,
    'BEAULIER': 0,
    'BEAULIEU': 0,
    'BEAUMAN': 0,
    'BEAUMIER': 0,
    'BEAUMONT': 0,
    'BEAUNE': 0,
    'BEAUPARLANT': 0,
    'BEAUPLAN': 0,
    'BEAUPRE': 0,
    'BEAUPREY': 0,
    'BEAUPREZ': 0,
    'BEAUREGARD': 0,
    'BEAUSEJOUR': 0,
    'BEAUSOLEIL': 0,
    'BEAUVAIS': 0,
    'BEAUVIL': 0,
    'BEAUVOIR': 0,
    'BEAUZILE': 0,
    'BEAVAN': 0,
    'BEAVEN': 0,
    'BEAVENS': 0,
    'BEAVER': 0,
    'BEAVERS': 0,
    'BEAVERSON': 0,
    'BEAVERT': 0,
    'BEAVIN': 0,
    'BEAVIS': 0,
    'BEAZ': 0,
    'BEAZER': 0,
    'BEAZLEY': 0,
    'BEBAR': 0,
    'BEBB': 0,
    'BEBBER': 0,
    'BEBBINGTON': 0,
    'BEBE': 0.9345794392523364,
    'BEBEAU': 0,
    'BEBEE': 0,
    'BEBEL': 0,
    'BEBEN': 0,
    'BEBENSEE': 0,
    'BEBER': 0,
    'BEBERMAN': 0,
    'BEBERMEYER': 0,
    'BEBKO': 0,
    'BEBLEY': 0,
    'BEBO': 0,
    'BEBOUT': 0,
    'BEBOW': 0,
    'BEC': 0,
    'BECAN': 0,
    'BECCARI': 0,
    'BECCARIA': 0,
    'BECCHETTI': 0,
    'BECCIA': 0,
    'BECCUE': 0,
    'BECENTI': 0,
    'BECERA': 0,
    'BECERRA': 0,
    'BECERRIL': 0,
    'BECH': 0,
    'BECHAM': 0,
    'BECHARA': 0,
    'BECHARD': 0,
    'BECHDEL': 0,
    'BECHDOLT': 0,
    'BECHEL': 0,
    'BECHELLI': 0,
    'BECHEN': 0,
    'BECHER': 0,
    'BECHERER': 0,
    'BECHERT': 0,
    'BECHLER': 0,
    'BECHMAN': 0,
    'BECHSTEIN': 0,
    'BECHT': 0,
    'BECHTEL': 0,
    'BECHTER': 0,
    'BECHTHOLD': 0,
    'BECHTLE': 0,
    'BECHTLER': 0,
    'BECHTOL': 0,
    'BECHTOLD': 0,
    'BECHTOLDT': 0,
    'BECHTOLT': 0,
    'BECIC': 0,
    'BECICKA': 0,
    'BECIREVIC': 0,
    'BECIROVIC': 0,
    'BECK': 0,
    'BECKA': 0,
    'BECKAGE': 0,
    'BECKAM': 0,
    'BECKE': 0,
    'BECKEL': 0,
    'BECKELHEIMER': 0,
    'BECKELHIMER': 0,
    'BECKELHYMER': 0,
    'BECKELMAN': 0,
    'BECKEMEYER': 0,
    'BECKEN': 0,
    'BECKENBACH': 0,
    'BECKENBAUGH': 0,
    'BECKENDORF': 0,
    'BECKENHAUER': 0,
    'BECKENSTEIN': 0,
    'BECKER': 0,
    'BECKERDITE': 0,
    'BECKERICH': 0,
    'BECKERING': 0,
    'BECKERLE': 0,
    'BECKERLEG': 0,
    'BECKERMAN': 0,
    'BECKERMANN': 0,
    'BECKERS': 0,
    'BECKERT': 0,
    'BECKES': 0,
    'BECKET': 0,
    'BECKETT': 0,
    'BECKETTE': 0,
    'BECKEY': 0,
    'BECKFORD': 0,
    'BECKHAM': 0,
    'BECKHORN': 0,
    'BECKHUSEN': 0,
    'BECKI': 1,
    'BECKIE': 1,
    'BECKING': 0,
    'BECKINGER': 0,
    'BECKINGHAM': 0,
    'BECKIUS': 0,
    'BECKLER': 0,
    'BECKLES': 0,
    'BECKLEY': 0,
    'BECKLIN': 0,
    'BECKLOFF': 0,
    'BECKLUND': 0,
    'BECKMAN': 0,
    'BECKMANN': 0,
    'BECKMEYER': 0,
    'BECKNEL': 0,
    'BECKNELL': 0,
    'BECKNER': 0,
    'BECKOM': 0,
    'BECKON': 0,
    'BECKRICH': 0,
    'BECKS': 0,
    'BECKSTEAD': 0,
    'BECKSTED': 0,
    'BECKSTEDT': 0,
    'BECKSTEIN': 0,
    'BECKSTRAND': 0,
    'BECKSTROM': 0,
    'BECKSVOORT': 0,
    'BECKTEL': 0,
    'BECKTELL': 0,
    'BECKTOLD': 0,
    'BECKTON': 0,
    'BECKUM': 0,
    'BECKWELL': 0,
    'BECKWITH': 0,
    'BECKWORTH': 0,
    'BECKY': 0.9992429977289933,
    'BECNEL': 0,
    'BECO': 0,
    'BECOAT': 0,
    'BECOATS': 0,
    'BECOTTE': 0,
    'BECRAFT': 0,
    'BECTON': 0,
    'BECVAR': 0,
    'BECWAR': 0,
    'BEDA': 0,
    'BEDAL': 0,
    'BEDAN': 0,
    'BEDAR': 0,
    'BEDARD': 0,
    'BEDDARD': 0,
    'BEDDES': 0,
    'BEDDIA': 0,
    'BEDDINGFIELD': 0,
    'BEDDO': 0,
    'BEDDOE': 0,
    'BEDDOES': 0,
    'BEDDOW': 0,
    'BEDE': 0,
    'BEDEAU': 0,
    'BEDEL': 0,
    'BEDELL': 0,
    'BEDEN': 0,
    'BEDENBAUGH': 0,
    'BEDENBENDER': 0,
    'BEDER': 0,
    'BEDERKA': 0,
    'BEDERMAN': 0,
    'BEDFORD': 0,
    'BEDGOOD': 0,
    'BEDI': 0,
    'BEDIA': 0,
    'BEDIAKO': 0,
    'BEDICS': 0,
    'BEDIENT': 0,
    'BEDIGIAN': 0,
    'BEDILION': 0,
    'BEDILLION': 0,
    'BEDINGER': 0,
    'BEDINGFIELD': 0,
    'BEDINGHAUS': 0,
    'BEDINI': 0,
    'BEDKE': 0,
    'BEDKER': 0,
    'BEDLEY': 0,
    'BEDLION': 0,
    'BEDNAR': 0,
    'BEDNARCIK': 0,
    'BEDNARCZYK': 0,
    'BEDNAREK': 0,
    'BEDNARIK': 0,
    'BEDNARK': 0,
    'BEDNARSKI': 0,
    'BEDNARZ': 0,
    'BEDNASH': 0,
    'BEDNER': 0,
    'BEDNEY': 0,
    'BEDNORZ': 0,
    'BEDO': 0,
    'BEDOLLA': 0,
    'BEDON': 0,
    'BEDONI': 0,
    'BEDONIE': 0,
    'BEDOR': 0,
    'BEDORE': 0,
    'BEDORTHA': 0,
    'BEDOSKY': 0,
    'BEDOW': 0,
    'BEDOY': 0,
    'BEDOYA': 0,
    'BEDRAN': 0,
    'BEDRICK': 0,
    'BEDRIN': 0,
    'BEDROSIAN': 0,
    'BEDROSSIAN': 0,
    'BEDSAUL': 0,
    'BEDSOLE': 0,
    'BEDSON': 0,
    'BEDSWORTH': 0,
    'BEDUHN': 0,
    'BEDWARD': 0,
    'BEDWAY': 0,
    'BEDWELL': 0,
    'BEE': 0.3703703703703704,
    'BEEBE': 0,
    'BEEBEE': 0,
    'BEEBER': 0,
    'BEEBOUT': 0,
    'BEEBY': 0,
    'BEECH': 0,
    'BEECHAM': 0,
    'BEECHEM': 0,
    'BEECHER': 0,
    'BEECHING': 0,
    'BEECHINOR': 0,
    'BEECHLER': 0,
    'BEECHNER': 0,
    'BEECHUM': 0,
    'BEECHY': 0,
    'BEECK': 0,
    'BEECKMAN': 0,
    'BEECROFT': 0,
    'BEED': 0,
    'BEEDE': 0,
    'BEEDIE': 0,
    'BEEDING': 0,
    'BEEDLE': 0,
    'BEEDLES': 0,
    'BEEDON': 0,
    'BEEDY': 0,
    'BEEGHLEY': 0,
    'BEEGHLY': 0,
    'BEEGLE': 0,
    'BEEH': 0,
    'BEEHLER': 0,
    'BEEHN': 0,
    'BEEHNER': 0,
    'BEEK': 0,
    'BEEKEN': 0,
    'BEEKER': 0,
    'BEEKLEY': 0,
    'BEEKMAN': 0,
    'BEEKS': 0,
    'BEEKSMA': 0,
    'BEEL': 0,
    'BEELAND': 0,
    'BEELEN': 0,
    'BEELER': 0,
    'BEELES': 0,
    'BEELEY': 0,
    'BEELMAN': 0,
    'BEELS': 0,
    'BEEM': 0,
    'BEEMAN': 0,
    'BEEMER': 0,
    'BEEMON': 0,
    'BEEMSTERBOER': 0,
    'BEEN': 0,
    'BEENE': 0,
    'BEENEN': 0,
    'BEENER': 0,
    'BEENEY': 0,
    'BEENKEN': 0,
    'BEENY': 0,
    'BEER': 0,
    'BEERBOHM': 0,
    'BEERBOWER': 0,
    'BEERE': 0,
    'BEERENS': 0,
    'BEERMAN': 0,
    'BEERMANN': 0,
    'BEERNINK': 0,
    'BEERS': 0,
    'BEERY': 0,
    'BEES': 0,
    'BEESE': 0,
    'BEESINGER': 0,
    'BEESLEY': 0,
    'BEESMER': 0,
    'BEESON': 0,
    'BEESTON': 0,
    'BEETEM': 0,
    'BEETER': 0,
    'BEETHAM': 0,
    'BEETHE': 0,
    'BEETLE': 0,
    'BEETLER': 0,
    'BEETON': 0,
    'BEETS': 0,
    'BEETZ': 0,
    'BEEVER': 0,
    'BEEVERS': 0,
    'BEEZER': 0,
    'BEEZHOLD': 0,
    'BEEZLEY': 0,
    'BEFFA': 0,
    'BEFORT': 0,
    'BEFUS': 0,
    'BEG': 0,
    'BEGA': 0,
    'BEGAN': 0,
    'BEGANOVIC': 0,
    'BEGANY': 0,
    'BEGAY': 0,
    'BEGAYE': 0,
    'BEGAZO': 0,
    'BEGBIE': 0,
    'BEGEL': 0,
    'BEGELMAN': 0,
    'BEGEMAN': 0,
    'BEGEMANN': 0,
    'BEGER': 0,
    'BEGERT': 0,
    'BEGEY': 0,
    'BEGG': 0,
    'BEGGAN': 0,
    'BEGGER': 0,
    'BEGGIN': 0,
    'BEGGS': 0,
    'BEGHTEL': 0,
    'BEGHTOL': 0,
    'BEGIC': 0,
    'BEGIN': 0,
    'BEGLAU': 0,
    'BEGLE': 0,
    'BEGLER': 0,
    'BEGLEY': 0,
    'BEGLIN': 0,
    'BEGLINGER': 0,
    'BEGLY': 0,
    'BEGNAUD': 0,
    'BEGNOCHE': 0,
    'BEGO': 0,
    'BEGODY': 0,
    'BEGOLE': 0,
    'BEGONIA': 0,
    'BEGONJA': 0,
    'BEGOR': 0,
    'BEGOVIC': 0,
    'BEGOVICH': 0,
    'BEGUE': 0,
    'BEGUHL': 0,
    'BEGUHN': 0,
    'BEGUIN': 0,
    'BEGUIRISTAIN': 0,
    'BEGUM': 0,
    'BEGUN': 0,
    'BEGY': 0,
    'BEH': 0,
    'BEHA': 0,
    'BEHAL': 0,
    'BEHAM': 0,
    'BEHAN': 0,
    'BEHANNA': 0,
    'BEHAR': 0,
    'BEHARI': 0,
    'BEHARRY': 0,
    'BEHARY': 0,
    'BEHBAHANI': 0,
    'BEHE': 0,
    'BEHEE': 0,
    'BEHEL': 0,
    'BEHELER': 0,
    'BEHEN': 0,
    'BEHENNA': 0,
    'BEHESHTI': 0,
    'BEHL': 0,
    'BEHLE': 0,
    'BEHLEN': 0,
    'BEHLER': 0,
    'BEHLES': 0,
    'BEHLIN': 0,
    'BEHLING': 0,
    'BEHLKE': 0,
    'BEHLMAN': 0,
    'BEHLMANN': 0,
    'BEHLMER': 0,
    'BEHM': 0,
    'BEHME': 0,
    'BEHMER': 0,
    'BEHMKE': 0,
    'BEHMLANDER': 0,
    'BEHN': 0,
    'BEHNAM': 0,
    'BEHNCKE': 0,
    'BEHNE': 0,
    'BEHNEN': 0,
    'BEHNER': 0,
    'BEHNEY': 0,
    'BEHNFELDT': 0,
    'BEHNING': 0,
    'BEHNKE': 0,
    'BEHNKEN': 0,
    'BEHNY': 0,
    'BEHOUNEK': 0,
    'BEHR': 0,
    'BEHRE': 0,
    'BEHREND': 0,
    'BEHRENDS': 0,
    'BEHRENDSEN': 0,
    'BEHRENDT': 0,
    'BEHRENS': 0,
    'BEHRENT': 0,
    'BEHRER': 0,
    'BEHRHORST': 0,
    'BEHRING': 0,
    'BEHRINGER': 0,
    'BEHRLE': 0,
    'BEHRMAN': 0,
    'BEHRMANN': 0,
    'BEHRNDT': 0,
    'BEHRNS': 0,
    'BEHUN': 0,
    'BEHUNIAK': 0,
    'BEHUNIN': 0,
    'BEHYMER': 0,
    'BEHZADI': 0,
    'BEI': 0,
    'BEICH': 0,
    'BEICHER': 0,
    'BEICHLER': 0,
    'BEICHNER': 0,
    'BEIDEL': 0,
    'BEIDELMAN': 0,
    'BEIDELSCHIES': 0,
    'BEIDEMAN': 0,
    'BEIDLEMAN': 0,
    'BEIDLER': 0,
    'BEIER': 0,
    'BEIERLE': 0,
    'BEIERLEIN': 0,
    'BEIERMAN': 0,
    'BEIERMANN': 0,
    'BEIERSCHMITT': 0,
    'BEIERSDORF': 0,
    'BEIG': 0,
    'BEIGEL': 0,
    'BEIGH': 0,
    'BEIGHEY': 0,
    'BEIGHLE': 0,
    'BEIGHLEY': 0,
    'BEIGHT': 0,
    'BEIGHTOL': 0,
    'BEIGHTS': 0,
    'BEIHL': 0,
    'BEIK': 0,
    'BEIKIRCH': 0,
    'BEIKMAN': 0,
    'BEIL': 0,
    'BEILBY': 0,
    'BEILE': 0,
    'BEILER': 0,
    'BEILFUSS': 0,
    'BEILHARZ': 0,
    'BEILIN': 0,
    'BEILKE': 0,
    'BEILMAN': 0,
    'BEILSMITH': 0,
    'BEILSTEIN': 0,
    'BEIM': 0,
    'BEIMBORN': 0,
    'BEIMEL': 0,
    'BEIMER': 0,
    'BEIMERS': 0,
    'BEIMLER': 0,
    'BEIN': 0,
    'BEINBORN': 0,
    'BEINE': 0,
    'BEINEKE': 0,
    'BEINER': 0,
    'BEINHORN': 0,
    'BEINING': 0,
    'BEINKE': 0,
    'BEINLICH': 0,
    'BEINS': 0,
    'BEINTEMA': 0,
    'BEIRD': 0,
    'BEIREIS': 0,
    'BEIRIGER': 0,
    'BEIRING': 0,
    'BEIRNE': 0,
    'BEIRO': 0,
    'BEISCH': 0,
    'BEISCHEL': 0,
    'BEISE': 0,
    'BEISEL': 0,
    'BEISER': 0,
    'BEISERT': 0,
    'BEISH': 0,
    'BEISHEIM': 0,
    'BEISHIR': 0,
    'BEISHLINE': 0,
    'BEISIEGEL': 0,
    'BEISLER': 0,
    'BEISLEY': 0,
    'BEISNER': 0,
    'BEISSEL': 0,
    'BEISSER': 0,
    'BEISTEL': 0,
    'BEISTLINE': 0,
    'BEISWANGER': 0,
    'BEISWENGER': 0,
    'BEITEL': 0,
    'BEITELSPACHER': 0,
    'BEITER': 0,
    'BEITH': 0,
    'BEITIA': 0,
    'BEITING': 0,
    'BEITLER': 0,
    'BEITMAN': 0,
    'BEITO': 0,
    'BEITRAN': 0,
    'BEITZ': 0,
    'BEITZEL': 0,
    'BEIZA': 0,
    'BEIZER': 0,
    'BEJA': 0,
    'BEJAN': 0,
    'BEJAR': 0,
    'BEJARAN': 0,
    'BEJARANO': 0,
    'BEJCEK': 0,
    'BEJERANO': 0,
    'BEJINES': 0,
    'BEJMA': 0,
    'BEK': 0,
    'BEKAERT': 0,
    'BEKAS': 0,
    'BEKE': 0,
    'BEKELE': 0,
    'BEKEMEIER': 0,
    'BEKER': 0,
    'BEKERMAN': 0,
    'BEKINS': 0,
    'BEKIS': 0,
    'BEKKALA': 0,
    'BEKKEN': 0,
    'BEKKER': 0,
    'BEKKERING': 0,
    'BEKO': 0,
    'BEKTAS': 0,
    'BEL': 0,
    'BELA': 0,
    'BELACHEW': 0,
    'BELAIR': 0,
    'BELAIRE': 0,
    'BELAK': 0,
    'BELALCAZAR': 0,
    'BELAN': 0,
    'BELAND': 0,
    'BELANGER': 0,
    'BELANGIA': 0,
    'BELANI': 0,
    'BELANICH': 0,
    'BELANSKY': 0,
    'BELANUS': 0,
    'BELARDE': 0,
    'BELARDI': 0,
    'BELARDINELLI': 0,
    'BELARDO': 0,
    'BELARMINO': 0,
    'BELAS': 0,
    'BELASCO': 0,
    'BELASKI': 0,
    'BELASQUEZ': 0,
    'BELAU': 0,
    'BELAY': 0,
    'BELBACK': 0,
    'BELBECK': 0,
    'BELBEN': 0,
    'BELBER': 0,
    'BELBIN': 0,
    'BELBOT': 0,
    'BELCASTRO': 0,
    'BELCH': 0,
    'BELCHER': 0,
    'BELCIK': 0,
    'BELCOURT': 0,
    'BELCZAK': 0,
    'BELCZYK': 0,
    'BELD': 0,
    'BELDA': 0,
    'BELDEN': 0,
    'BELDIN': 0,
    'BELDING': 0,
    'BELDO': 0,
    'BELDOCK': 0,
    'BELDON': 0,
    'BELE': 0,
    'BELEC': 0,
    'BELECHE': 0,
    'BELEN': 0.9174311926605504,
    'BELENKAYA': 0,
    'BELENKY': 0,
    'BELENO': 0,
    'BELENSKI': 0,
    'BELER': 0,
    'BELES': 0,
    'BELESKI': 0,
    'BELETE': 0,
    'BELEW': 0,
    'BELEY': 0,
    'BELEZ': 0,
    'BELFER': 0,
    'BELFI': 0,
    'BELFIELD': 0,
    'BELFIGLIO': 0,
    'BELFIORE': 0,
    'BELFLOWER': 0,
    'BELFON': 0,
    'BELFOR': 0,
    'BELFORD': 0,
    'BELFORT': 0,
    'BELFRY': 0,
    'BELGARD': 0,
    'BELGARDE': 0,
    'BELGE': 0,
    'BELGER': 0,
    'BELGRADE': 0,
    'BELGRAVE': 0,
    'BELGUM': 0,
    'BELHUMEUR': 0,
    'BELIA': 1,
    'BELIARD': 0,
    'BELIC': 0,
    'BELICA': 0,
    'BELICH': 0,
    'BELIEU': 0,
    'BELIEW': 0,
    'BELIK': 0,
    'BELILE': 0,
    'BELILES': 0,
    'BELILL': 0,
    'BELIN': 0,
    'BELINA': 0,
    'BELINDA': 0.9993224932249323,
    'BELING': 0,
    'BELINGER': 0,
    'BELINSKI': 0,
    'BELINSKY': 0,
    'BELIS': 0,
    'BELISARIO': 0,
    'BELISLE': 0,
    'BELITSKY': 0,
    'BELITZ': 0,
    'BELIVEAU': 0,
    'BELIZ': 0,
    'BELIZAIRE': 0,
    'BELJAN': 0,
    'BELK': 0,
    'BELKA': 0,
    'BELKE': 0,
    'BELKEN': 0,
    'BELKER': 0,
    'BELKIN': 0,
    'BELKIS': 1,
    'BELKNAP': 0,
    'BELKO': 0,
    'BELKOFER': 0,
    'BELKOWSKI': 0,
    'BELL': 0.010086746015735323,
    'BELLA': 0.8810572687224669,
    'BELLACE': 0,
    'BELLACH': 0,
    'BELLACK': 0,
    'BELLAFIORE': 0,
    'BELLAGAMBA': 0,
    'BELLAH': 0,
    'BELLAIR': 0,
    'BELLAIRE': 0,
    'BELLAIRS': 0,
    'BELLAK': 0,
    'BELLAM': 0,
    'BELLAMY': 0,
    'BELLAN': 0,
    'BELLANCA': 0,
    'BELLAND': 0,
    'BELLANDI': 0,
    'BELLANDO': 0,
    'BELLANGER': 0,
    'BELLANT': 0,
    'BELLANTE': 0,
    'BELLANTI': 0,
    'BELLANTONI': 0,
    'BELLANTUONO': 0,
    'BELLANY': 0,
    'BELLAR': 0,
    'BELLARD': 0,
    'BELLARDINI': 0,
    'BELLAS': 0,
    'BELLASSAI': 0,
    'BELLAVANCE': 0,
    'BELLAVIA': 0,
    'BELLAY': 0,
    'BELLE': 0.834326579261025,
    'BELLEAU': 0,
    'BELLECI': 0,
    'BELLEFEUILLE': 0,
    'BELLEFEVILLE': 0,
    'BELLEFLEUR': 0,
    'BELLEFONTAINE': 0,
    'BELLEGANTE': 0,
    'BELLEGARDE': 0,
    'BELLEISLE': 0,
    'BELLEMAN': 0,
    'BELLEMARE': 0,
    'BELLEMORE': 0,
    'BELLEN': 0,
    'BELLENDIR': 0,
    'BELLENGER': 0,
    'BELLER': 0,
    'BELLERIVE': 0,
    'BELLEROSE': 0,
    'BELLERS': 0,
    'BELLES': 0,
    'BELLESFIELD': 0,
    'BELLESTRI': 0,
    'BELLET': 0,
    'BELLETETE': 0,
    'BELLETTI': 0,
    'BELLETTO': 0,
    'BELLEVILLE': 0,
    'BELLEVUE': 0,
    'BELLEW': 0,
    'BELLEY': 0,
    'BELLEZA': 0,
    'BELLEZZA': 0,
    'BELLFIELD': 0,
    'BELLFLOWER': 0,
    'BELLFY': 0,
    'BELLGRAPH': 0,
    'BELLHORN': 0,
    'BELLI': 0,
    'BELLIA': 0,
    'BELLIARD': 0,
    'BELLIDO': 0,
    'BELLILE': 0,
    'BELLIN': 0,
    'BELLINA': 0,
    'BELLINDER': 0,
    'BELLING': 0,
    'BELLINGAR': 0,
    'BELLINGER': 0,
    'BELLINGHAM': 0,
    'BELLINGHAUSEN': 0,
    'BELLINGTON': 0,
    'BELLINI': 0,
    'BELLINO': 0,
    'BELLIO': 0,
    'BELLIS': 0,
    'BELLISARIO': 0,
    'BELLISH': 0,
    'BELLISLE': 0,
    'BELLISSIMO': 0,
    'BELLISTON': 0,
    'BELLITTI': 0,
    'BELLITTO': 0,
    'BELLIVEAU': 0,
    'BELLIZZI': 0,
    'BELLMAN': 0,
    'BELLMANN': 0,
    'BELLMER': 0,
    'BELLMON': 0,
    'BELLMORE': 0,
    'BELLMYER': 0,
    'BELLNER': 0,
    'BELLO': 0,
    'BELLOC': 0,
    'BELLOCCHIO': 0,
    'BELLOCK': 0,
    'BELLOFATTO': 0,
    'BELLOFF': 0,
    'BELLOLI': 0,
    'BELLOMA': 0,
    'BELLOMO': 0,
    'BELLOMY': 0,
    'BELLON': 0,
    'BELLONE': 0,
    'BELLONI': 0,
    'BELLOR': 0,
    'BELLORA': 0,
    'BELLORIN': 0,
    'BELLOS': 0,
    'BELLOSO': 0,
    'BELLOT': 0,
    'BELLOTT': 0,
    'BELLOTTE': 0,
    'BELLOTTI': 0,
    'BELLOVICH': 0,
    'BELLOW': 0,
    'BELLOWS': 0,
    'BELLRICHARD': 0,
    'BELLROSE': 0,
    'BELLS': 0,
    'BELLUARDO': 0,
    'BELLUCCI': 0,
    'BELLUE': 0,
    'BELLUOMINI': 0,
    'BELLUS': 0,
    'BELLUSCI': 0,
    'BELLUSCIO': 0,
    'BELLVILLE': 0,
    'BELLWOOD': 0,
    'BELMAN': 0,
    'BELMAR': 0,
    'BELMARES': 0,
    'BELMAREZ': 0,
    'BELMER': 0,
    'BELMONT': 0,
    'BELMONTE': 0,
    'BELMONTES': 0,
    'BELMONTEZ': 0,
    'BELMORE': 0,
    'BELNAP': 0,
    'BELNAVIS': 0,
    'BELO': 0,
    'BELOAT': 0,
    'BELOATE': 0,
    'BELOCK': 0,
    'BELOFF': 0,
    'BELOHLAVEK': 0,
    'BELOIN': 0,
    'BELON': 0,
    'BELONE': 0,
    'BELONEY': 0,
    'BELONG': 0,
    'BELONGA': 0,
    'BELONGIA': 0,
    'BELONGIE': 0,
    'BELONY': 0,
    'BELOT': 0,
    'BELOTE': 0,
    'BELOTT': 0,
    'BELOTTI': 0,
    'BELOUS': 0,
    'BELOUSOV': 0,
    'BELOV': 0,
    'BELOW': 0,
    'BELPEDIO': 0,
    'BELROSE': 0,
    'BELSAN': 0,
    'BELSCHER': 0,
    'BELSCHNER': 0,
    'BELSER': 0,
    'BELSHA': 0,
    'BELSHAW': 0,
    'BELSHE': 0,
    'BELSHEIM': 0,
    'BELSHER': 0,
    'BELSITO': 0,
    'BELSKI': 0,
    'BELSKIS': 0,
    'BELSKY': 0,
    'BELSLEY': 0,
    'BELSON': 0,
    'BELSTERLING': 0,
    'BELT': 0,
    'BELTER': 0,
    'BELTETON': 0,
    'BELTMAN': 0,
    'BELTON': 0,
    'BELTOWSKI': 0,
    'BELTRAM': 0,
    'BELTRAME': 0,
    'BELTRAMI': 0,
    'BELTRAMINI': 0,
    'BELTRAMO': 0,
    'BELTRAN': 0,
    'BELTRANI': 0,
    'BELTRANO': 0,
    'BELTRE': 0,
    'BELTRON': 0,
    'BELTS': 0,
    'BELTZ': 0,
    'BELTZER': 0,
    'BELUE': 0,
    'BELUS': 0,
    'BELUSKO': 0,
    'BELVA': 1,
    'BELVAL': 0,
    'BELVEAL': 0,
    'BELVEDERE': 0,
    'BELVILL': 0,
    'BELVILLE': 0,
    'BELVIN': 0,
    'BELVINS': 0,
    'BELVIS': 0,
    'BELVISO': 0,
    'BELWOOD': 0,
    'BELYEA': 0,
    'BELYEU': 0,
    'BELYEW': 0,
    'BELZ': 0,
    'BELZA': 0,
    'BELZER': 0,
    'BELZNER': 0,
    'BEM': 0,
    'BEMAN': 0,
    'BEMBEN': 0,
    'BEMBENEK': 0,
    'BEMBERY': 0,
    'BEMBOOM': 0,
    'BEMBRIDGE': 0,
    'BEMBRY': 0,
    'BEMBURY': 0,
    'BEMENT': 0,
    'BEMER': 0,
    'BEMILLER': 0,
    'BEMIS': 0,
    'BEMISH': 0,
    'BEMISS': 0,
    'BEMONT': 0,
    'BEMOWSKI': 0,
    'BEMROSE': 0,
    'BEMUS': 0,
    'BEN': 0.9867172675521821,
    'BENA': 0,
    'BENABE': 0,
    'BENABIDES': 0,
    'BENAC': 0,
    'BENACH': 0,
    'BENACK': 0,
    'BENADUM': 0,
    'BENAGE': 0,
    'BENAK': 0,
    'BENALCAZAR': 0,
    'BENALLIE': 0,
    'BENALLY': 0,
    'BENAMATI': 0,
    'BENAMI': 0,
    'BENANDER': 0,
    'BENANTI': 0,
    'BENARD': 0,
    'BENARDO': 0,
    'BENAS': 0,
    'BENASH': 0,
    'BENASSI': 0,
    'BENATAR': 0,
    'BENAVENTE': 0,
    'BENAVIDES': 0,
    'BENAVIDEZ': 0,
    'BENBENEK': 0,
    'BENBERRY': 0,
    'BENBOW': 0,
    'BENBROOK': 0,
    'BENCE': 0,
    'BENCES': 0,
    'BENCH': 0,
    'BENCHIMOL': 0,
    'BENCHLEY': 0,
    'BENCHOFF': 0,
    'BENCI': 0,
    'BENCIC': 0,
    'BENCINI': 0,
    'BENCIVENGA': 0,
    'BENCIVENGO': 0,
    'BENCK': 0,
    'BENCKERT': 0,
    'BENCO': 0,
    'BENCOMO': 0,
    'BENCOSME': 0,
    'BENCZE': 0,
    'BEND': 0,
    'BENDA': 0,
    'BENDALL': 0,
    'BENDANA': 0,
    'BENDAS': 0,
    'BENDAVID': 0,
    'BENDECK': 0,
    'BENDEL': 0,
    'BENDELE': 0,
    'BENDELL': 0,
    'BENDEN': 0,
    'BENDER': 0,
    'BENDERMAN': 0,
    'BENDERS': 0,
    'BENDERSKY': 0,
    'BENDERT': 0,
    'BENDETTI': 0,
    'BENDEWALD': 0,
    'BENDEZU': 0,
    'BENDFELDT': 0,
    'BENDICK': 0,
    'BENDICKSON': 0,
    'BENDIG': 0,
    'BENDIK': 0,
    'BENDINELLI': 0,
    'BENDING': 0,
    'BENDIS': 0,
    'BENDIT': 0,
    'BENDITT': 0,
    'BENDIX': 0,
    'BENDIXEN': 0,
    'BENDL': 0,
    'BENDLE': 0,
    'BENDLER': 0,
    'BENDLIN': 0,
    'BENDO': 0,
    'BENDOLPH': 0,
    'BENDON': 0,
    'BENDOR': 0,
    'BENDORF': 0,
    'BENDRICK': 0,
    'BENDT': 0,
    'BENDTSEN': 0,
    'BENDURE': 0,
    'BENDY': 0,
    'BENE': 0,
    'BENEAR': 0,
    'BENEBY': 0,
    'BENECKE': 0,
    'BENEDA': 0,
    'BENEDEK': 0,
    'BENEDETTI': 0,
    'BENEDETTO': 0,
    'BENEDICK': 0,
    'BENEDICT': 0.39062500000000006,
    'BENEDICTO': 0,
    'BENEDIK': 0,
    'BENEDIT': 0,
    'BENEDITH': 0,
    'BENEDITO': 0,
    'BENEDIX': 0,
    'BENEDUCE': 0,
    'BENEDUM': 0,
    'BENEFIEL': 0,
    'BENEFIELD': 0,
    'BENEGAS': 0,
    'BENEK': 0,
    'BENEKE': 0,
    'BENEKER': 0,
    'BENELL': 0,
    'BENELLI': 0,
    'BENENATI': 0,
    'BENENHALEY': 0,
    'BENENSON': 0,
    'BENES': 0,
    'BENESCH': 0,
    'BENESH': 0,
    'BENESKI': 0,
    'BENET': 0,
    'BENETATOS': 0,
    'BENETEAU': 0,
    'BENETT': 0,
    'BENETTE': 0,
    'BENETTI': 0,
    'BENETZ': 0,
    'BENEVENTI': 0,
    'BENEVENTO': 0,
    'BENEVIDES': 0,
    'BENEVIDEZ': 0,
    'BENEWAY': 0,
    'BENEZE': 0,
    'BENEZRA': 0,
    'BENFANTE': 0,
    'BENFATTI': 0,
    'BENFER': 0,
    'BENFIELD': 0,
    'BENFORD': 0,
    'BENG': 0,
    'BENGAL': 0,
    'BENGE': 0,
    'BENGEL': 0,
    'BENGER': 0,
    'BENGERT': 0,
    'BENGFORD': 0,
    'BENGLE': 0,
    'BENGOA': 0,
    'BENGOCHEA': 0,
    'BENGOECHEA': 0,
    'BENGRY': 0,
    'BENGS': 0,
    'BENGSON': 0,
    'BENGSTON': 0,
    'BENGTSON': 0,
    'BENGTSSON': 0,
    'BENHAIM': 0,
    'BENHAM': 0,
    'BENHAMOU': 0,
    'BENHARDT': 0,
    'BENHART': 0,
    'BENHOFF': 0,
    'BENI': 0,
    'BENIC': 0,
    'BENICH': 0,
    'BENICK': 0,
    'BENIFIELD': 0,
    'BENIGHT': 0,
    'BENIGNI': 0,
    'BENIGNO': 0,
    'BENIK': 0,
    'BENIKE': 0,
    'BENIN': 0,
    'BENINATI': 0,
    'BENINATO': 0,
    'BENINCASA': 0,
    'BENING': 0,
    'BENINGA': 0,
    'BENINI': 0,
    'BENINTENDE': 0,
    'BENINTENDI': 0,
    'BENION': 0,
    'BENIQUEZ': 0,
    'BENIS': 0,
    'BENISCH': 0,
    'BENISCHEK': 0,
    'BENISEK': 0,
    'BENISH': 0,
    'BENISHEK': 0,
    'BENISON': 0,
    'BENIT': 0,
    'BENITA': 1,
    'BENITES': 0,
    'BENITEZ': 0,
    'BENITO': 0.9621552277100706,
    'BENITZ': 0,
    'BENJAMEN': 0,
    'BENJAMIN': 0.9523473598814857,
    'BENJAMINE': 0,
    'BENJAMINS': 0,
    'BENJAMINSON': 0,
    'BENJIMAN': 0,
    'BENJUMEA': 0,
    'BENKA': 0,
    'BENKE': 0,
    'BENKELMAN': 0,
    'BENKEN': 0,
    'BENKENDORF': 0,
    'BENKER': 0,
    'BENKERT': 0,
    'BENKO': 0,
    'BENKOSKI': 0,
    'BENKOVIC': 0,
    'BENKOVICH': 0,
    'BENKOWSKI': 0,
    'BENLINE': 0,
    'BENN': 0,
    'BENNA': 0,
    'BENNAGE': 0,
    'BENNANI': 0,
    'BENNARD': 0,
    'BENNARDO': 0,
    'BENNE': 0,
    'BENNECKE': 0,
    'BENNEFELD': 0,
    'BENNEFIELD': 0,
    'BENNER': 0,
    'BENNERMAN': 0,
    'BENNERS': 0,
    'BENNERT': 0,
    'BENNES': 0,
    'BENNET': 0,
    'BENNETCH': 0,
    'BENNETHUM': 0,
    'BENNETSEN': 0,
    'BENNETT': 0.0827985924239288,
    'BENNETTE': 0,
    'BENNETTI': 0,
    'BENNETTS': 0,
    'BENNEWITZ': 0,
    'BENNEY': 0,
    'BENNICI': 0,
    'BENNICK': 0,
    'BENNICOFF': 0,
    'BENNIE': 0.9918616480162766,
    'BENNIEFIELD': 0,
    'BENNIGHT': 0,
    'BENNIN': 0,
    'BENNING': 0,
    'BENNINGER': 0,
    'BENNINGFIELD': 0,
    'BENNINGHOFF': 0,
    'BENNINGS': 0,
    'BENNINGTON': 0,
    'BENNINK': 0,
    'BENNION': 0,
    'BENNIS': 0,
    'BENNISH': 0,
    'BENNISON': 0,
    'BENNIT': 0,
    'BENNITT': 0,
    'BENNO': 0,
    'BENNS': 0,
    'BENNY': 0.986842105263158,
    'BENNYHOFF': 0,
    'BENO': 0,
    'BENOFF': 0,
    'BENOIST': 0,
    'BENOIT': 0,
    'BENOLIEL': 0,
    'BENOLKEN': 0,
    'BENORE': 0,
    'BENOTTI': 0,
    'BENOWITZ': 0,
    'BENOY': 0,
    'BENROTH': 0,
    'BENRUD': 0,
    'BENS': 0,
    'BENSCH': 0,
    'BENSCHOTER': 0,
    'BENSCOTER': 0,
    'BENSE': 0,
    'BENSEL': 0,
    'BENSEMA': 0,
    'BENSEN': 0,
    'BENSER': 0,
    'BENSFIELD': 0,
    'BENSHOFF': 0,
    'BENSHOOF': 0,
    'BENSIMON': 0,
    'BENSING': 0,
    'BENSINGER': 0,
    'BENSINK': 0,
    'BENSKIN': 0,
    'BENSKO': 0,
    'BENSKY': 0,
    'BENSLEY': 0,
    'BENSMAN': 0,
    'BENSO': 0,
    'BENSON': 0,
    'BENSTEAD': 0,
    'BENSTON': 0,
    'BENT': 0,
    'BENTANCOURT': 0,
    'BENTANCUR': 0,
    'BENTCH': 0,
    'BENTE': 0,
    'BENTEL': 0,
    'BENTER': 0,
    'BENTFIELD': 0,
    'BENTHAL': 0,
    'BENTHALL': 0,
    'BENTHAM': 0,
    'BENTHIEN': 0,
    'BENTHIN': 0,
    'BENTING': 0,
    'BENTIVEGNA': 0,
    'BENTKOWSKI': 0,
    'BENTLAGE': 0,
    'BENTLE': 0,
    'BENTLER': 0,
    'BENTLEY': 0,
    'BENTLY': 0,
    'BENTO': 0,
    'BENTON': 0.22560631697687536,
    'BENTRUP': 0,
    'BENTS': 0,
    'BENTSEN': 0,
    'BENTSON': 0,
    'BENTURA': 0,
    'BENTZ': 0,
    'BENTZEL': 0,
    'BENTZEN': 0,
    'BENTZINGER': 0,
    'BENTZLER': 0,
    'BENUS': 0,
    'BENUSA': 0,
    'BENVENISTE': 0,
    'BENVENUTI': 0,
    'BENVENUTO': 0,
    'BENVENUTTI': 0,
    'BENVIE': 0,
    'BENWARD': 0,
    'BENWARE': 0,
    'BENWAY': 0,
    'BENWELL': 0,
    'BENYA': 0,
    'BENYAK': 0,
    'BENYAMIN': 0,
    'BENYARD': 0,
    'BENYO': 0,
    'BENYON': 0,
    'BENZ': 0,
    'BENZA': 0,
    'BENZAKEN': 0,
    'BENZAQUEN': 0,
    'BENZEL': 0,
    'BENZENBERG': 0,
    'BENZER': 0,
    'BENZIE': 0,
    'BENZIGER': 0,
    'BENZIN': 0,
    'BENZINE': 0,
    'BENZING': 0,
    'BENZINGER': 0,
    'BENZLER': 0,
    'BENZO': 0,
    'BENZON': 0,
    'BENZOR': 0,
    'BENZSCHAWEL': 0,
    'BEOUGHER': 0,
    'BEPLER': 0,
    'BEPPLER': 0,
    'BEPPU': 0,
    'BEQIRI': 0,
    'BEQUEAITH': 0,
    'BEQUETTE': 0,
    'BER': 0,
    'BERA': 0,
    'BERAN': 0,
    'BERANEK': 0,
    'BERARD': 0,
    'BERARDELLI': 0,
    'BERARDI': 0,
    'BERARDINELLI': 0,
    'BERARDINI': 0,
    'BERARDINO': 0,
    'BERARDO': 0,
    'BERARDUCCI': 0,
    'BERAS': 0,
    'BERAUD': 0,
    'BERAZA': 0,
    'BERBAUM': 0,
    'BERBEN': 0,
    'BERBER': 0,
    'BERBERENA': 0,
    'BERBERET': 0,
    'BERBERIAN': 0,
    'BERBERICH': 0,
    'BERBERICK': 0,
    'BERBERT': 0,
    'BERBERYAN': 0,
    'BERCAW': 0,
    'BERCE': 0,
    'BERCEAU': 0,
    'BERCEGEAY': 0,
    'BERCH': 0,
    'BERCHEM': 0,
    'BERCHER': 0,
    'BERCHIN': 0,
    'BERCHTOLD': 0,
    'BERCIAN': 0,
    'BERCIER': 0,
    'BERCIK': 0,
    'BERCK': 0,
    'BERCKMAN': 0,
    'BERCOT': 0,
    'BERCOVICI': 0,
    'BERCUME': 0,
    'BERCY': 0,
    'BERD': 0,
    'BERDAHL': 0,
    'BERDAN': 0,
    'BERDAR': 0,
    'BERDECIA': 0,
    'BERDEJA': 0,
    'BERDEJO': 0,
    'BERDEN': 0,
    'BERDICHEVSKY': 0,
    'BERDIN': 0,
    'BERDINE': 0,
    'BERDING': 0,
    'BERDIS': 0,
    'BERDON': 0,
    'BERDUGO': 0,
    'BERDUO': 0,
    'BERDUSCO': 0,
    'BERDY': 0,
    'BERE': 0,
    'BERECZ': 0,
    'BEREITER': 0,
    'BEREK': 0,
    'BEREN': 0,
    'BERENATO': 0,
    'BERENBAUM': 0,
    'BERENBERG': 0,
    'BEREND': 0,
    'BERENDES': 0,
    'BERENDS': 0,
    'BERENDSEN': 0,
    'BERENDT': 0,
    'BERENDZEN': 0,
    'BERENGER': 0,
    'BERENGUER': 0,
    'BERENICE': 1,
    'BERENS': 0,
    'BERENSON': 0,
    'BERENSTEIN': 0,
    'BERENT': 0,
    'BERENTSEN': 0,
    'BERENTSON': 0,
    'BERENYI': 0,
    'BERENZ': 0,
    'BERES': 0,
    'BERESFORD': 0,
    'BERESH': 0,
    'BERESKY': 0,
    'BERETE': 0,
    'BERETTA': 0,
    'BEREZ': 0,
    'BEREZA': 0,
    'BEREZANSKY': 0,
    'BEREZIN': 0,
    'BEREZNAK': 0,
    'BEREZNY': 0,
    'BEREZOVSKY': 0,
    'BERFIELD': 0,
    'BERG': 0,
    'BERGA': 0,
    'BERGADO': 0,
    'BERGAMASCO': 0,
    'BERGAMINI': 0,
    'BERGAMO': 0,
    'BERGAN': 0,
    'BERGANT': 0,
    'BERGANTINO': 0,
    'BERGANZA': 0,
    'BERGARA': 0,
    'BERGBAUER': 0,
    'BERGBIGLER': 0,
    'BERGBOWER': 0,
    'BERGDAHL': 0,
    'BERGDALL': 0,
    'BERGDOLL': 0,
    'BERGDORF': 0,
    'BERGE': 0,
    'BERGEAUX': 0,
    'BERGEL': 0,
    'BERGELAND': 0,
    'BERGEMAN': 0,
    'BERGEMANN': 0,
    'BERGEN': 0,
    'BERGENDAHL': 0,
    'BERGENE': 0,
    'BERGENER': 0,
    'BERGENSTOCK': 0,
    'BERGEON': 0,
    'BERGER': 0,
    'BERGERE': 0,
    'BERGERON': 0,
    'BERGERS': 0,
    'BERGERSEN': 0,
    'BERGERSON': 0,
    'BERGERT': 0,
    'BERGERUD': 0,
    'BERGES': 0,
    'BERGESEN': 0,
    'BERGESON': 0,
    'BERGET': 0,
    'BERGEVIN': 0,
    'BERGEY': 0,
    'BERGEZ': 0,
    'BERGFALK': 0,
    'BERGFELD': 0,
    'BERGFIELD': 0,
    'BERGGREN': 0,
    'BERGH': 0,
    'BERGHAMMER': 0,
    'BERGHAUS': 0,
    'BERGHEGER': 0,
    'BERGHOEFER': 0,
    'BERGHOFF': 0,
    'BERGHOLM': 0,
    'BERGHOLTZ': 0,
    'BERGHOLZ': 0,
    'BERGHORN': 0,
    'BERGHORST': 0,
    'BERGHUIS': 0,
    'BERGIN': 0,
    'BERGKAMP': 0,
    'BERGLAND': 0,
    'BERGLER': 0,
    'BERGLES': 0,
    'BERGLIN': 0,
    'BERGLIND': 0,
    'BERGLOFF': 0,
    'BERGLUND': 0,
    'BERGMAN': 0,
    'BERGMANN': 0,
    'BERGMANS': 0,
    'BERGMARK': 0,
    'BERGMEIER': 0,
    'BERGNER': 0,
    'BERGO': 0,
    'BERGOLD': 0,
    'BERGONIA': 0,
    'BERGONZI': 0,
    'BERGQUIST': 0,
    'BERGREEN': 0,
    'BERGREN': 0,
    'BERGS': 0,
    'BERGSBAKEN': 0,
    'BERGSCHNEIDER': 0,
    'BERGSETH': 0,
    'BERGSIEKER': 0,
    'BERGSMA': 0,
    'BERGSMAN': 0,
    'BERGSON': 0,
    'BERGSRUD': 0,
    'BERGSTAD': 0,
    'BERGSTEDT': 0,
    'BERGSTEIN': 0,
    'BERGSTEN': 0,
    'BERGSTRAND': 0,
    'BERGSTRESSER': 0,
    'BERGSTROM': 0,
    'BERGT': 0,
    'BERGTHOLD': 0,
    'BERGUM': 0,
    'BERGUSON': 0,
    'BERGWALL': 0,
    'BERHALTER': 0,
    'BERHANE': 0,
    'BERHANU': 0,
    'BERHE': 0,
    'BERHORST': 0,
    'BERHOW': 0,
    'BERI': 0,
    'BERIA': 0,
    'BERICH': 0,
    'BERIDON': 0,
    'BERIGAN': 0,
    'BERILLA': 0,
    'BERIN': 0,
    'BERING': 0,
    'BERINGER': 0,
    'BERINI': 0,
    'BERIO': 0,
    'BERIS': 0,
    'BERISFORD': 0,
    'BERISH': 0,
    'BERISHA': 0,
    'BERISHAJ': 0,
    'BERISTAIN': 0,
    'BERK': 0,
    'BERKA': 0,
    'BERKBIGLER': 0,
    'BERKBUEGLER': 0,
    'BERKE': 0,
    'BERKEBILE': 0,
    'BERKEL': 0,
    'BERKELAND': 0,
    'BERKELEY': 0,
    'BERKEMEIER': 0,
    'BERKEMEYER': 0,
    'BERKEN': 0,
    'BERKENBILE': 0,
    'BERKENPAS': 0,
    'BERKENSTOCK': 0,
    'BERKER': 0,
    'BERKERY': 0,
    'BERKES': 0,
    'BERKEY': 0,
    'BERKHAHN': 0,
    'BERKHEIMER': 0,
    'BERKHEISER': 0,
    'BERKHIMER': 0,
    'BERKHOLTZ': 0,
    'BERKHOLZ': 0,
    'BERKHOUSE': 0,
    'BERKI': 0,
    'BERKIN': 0,
    'BERKINS': 0,
    'BERKLAND': 0,
    'BERKLEY': 0,
    'BERKMAN': 0,
    'BERKNER': 0,
    'BERKNESS': 0,
    'BERKO': 0,
    'BERKOBEN': 0,
    'BERKOFF': 0,
    'BERKOMPAS': 0,
    'BERKOSKI': 0,
    'BERKOVICH': 0,
    'BERKOVITS': 0,
    'BERKOVITZ': 0,
    'BERKOW': 0,
    'BERKOWICZ': 0,
    'BERKOWITZ': 0,
    'BERKS': 0,
    'BERKSHIRE': 0,
    'BERKSON': 0,
    'BERKSTRESSER': 0,
    'BERKUN': 0,
    'BERKY': 0,
    'BERL': 0,
    'BERLAGE': 0,
    'BERLAND': 0,
    'BERLANGA': 0,
    'BERLANT': 0,
    'BERLE': 0,
    'BERLEKAMP': 0,
    'BERLER': 0,
    'BERLET': 0,
    'BERLEW': 0,
    'BERLEY': 0,
    'BERLIER': 0,
    'BERLIN': 0,
    'BERLINER': 0,
    'BERLING': 0,
    'BERLINGER': 0,
    'BERLINGERI': 0,
    'BERLINGIERI': 0,
    'BERLINSKI': 0,
    'BERLINSKY': 0,
    'BERLO': 0,
    'BERLOW': 0,
    'BERLOWITZ': 0,
    'BERLS': 0,
    'BERLY': 0,
    'BERMAN': 0,
    'BERMANN': 0,
    'BERMEA': 0,
    'BERMEJO': 0,
    'BERMEL': 0,
    'BERMEO': 0,
    'BERMES': 0,
    'BERMINGHAM': 0,
    'BERMUDES': 0,
    'BERMUDEZ': 0,
    'BERN': 0,
    'BERNA': 0.7352941176470589,
    'BERNABE': 0,
    'BERNABEI': 0,
    'BERNABEL': 0,
    'BERNABEO': 0,
    'BERNABO': 0,
    'BERNACCHI': 0,
    'BERNACHE': 0,
    'BERNACKI': 0,
    'BERNADEL': 0,
    'BERNADETTE': 1,
    'BERNADIN': 0,
    'BERNADINE': 1,
    'BERNADINO': 0,
    'BERNADOTTE': 0,
    'BERNAI': 0,
    'BERNAICHE': 0,
    'BERNAL': 0,
    'BERNALDEZ': 0,
    'BERNALES': 0,
    'BERNARD': 0.9035930273923871,
    'BERNARDA': 1,
    'BERNARDE': 0,
    'BERNARDES': 0,
    'BERNARDEZ': 0,
    'BERNARDI': 0,
    'BERNARDIN': 0,
    'BERNARDINA': 1,
    'BERNARDINE': 1,
    'BERNARDING': 0,
    'BERNARDINI': 0,
    'BERNARDINO': 0,
    'BERNARDO': 0.8196721311475409,
    'BERNARDON': 0,
    'BERNARDONI': 0,
    'BERNARDS': 0,
    'BERNARDY': 0,
    'BERNAS': 0,
    'BERNASCONI': 0,
    'BERNASEK': 0,
    'BERNAT': 0,
    'BERNATCHEZ': 0,
    'BERNATH': 0,
    'BERNATOWICZ': 0,
    'BERNATZ': 0,
    'BERNAU': 0,
    'BERNAUER': 0,
    'BERNAZZANI': 0,
    'BERNBAUM': 0,
    'BERND': 0,
    'BERNDSEN': 0,
    'BERNDT': 0,
    'BERNDTSON': 0,
    'BERNE': 0,
    'BERNECKER': 0,
    'BERNEICE': 1,
    'BERNEKING': 0,
    'BERNEL': 0,
    'BERNER': 0,
    'BERNERO': 0,
    'BERNERT': 0,
    'BERNES': 0,
    'BERNET': 0,
    'BERNETHY': 0,
    'BERNETT': 0,
    'BERNETTA': 1,
    'BERNETTE': 0,
    'BERNEY': 0,
    'BERNFELD': 0,
    'BERNHAGEN': 0,
    'BERNHARD': 0,
    'BERNHARDSON': 0,
    'BERNHARDT': 0,
    'BERNHARDY': 0,
    'BERNHART': 0,
    'BERNHEIM': 0,
    'BERNHEIMER': 0,
    'BERNHEISEL': 0,
    'BERNHISEL': 0,
    'BERNHOFT': 0,
    'BERNHOLTZ': 0,
    'BERNI': 0,
    'BERNIARD': 0,
    'BERNICE': 0.999531469623614,
    'BERNICK': 0,
    'BERNICKY': 0,
    'BERNIE': 0.9891196834817013,
    'BERNIECE': 1,
    'BERNIER': 0,
    'BERNING': 0,
    'BERNINGER': 0,
    'BERNINI': 0,
    'BERNITA': 1,
    'BERNITT': 0,
    'BERNIUS': 0,
    'BERNKLAU': 0,
    'BERNO': 0,
    'BERNON': 0,
    'BERNOR': 0,
    'BERNOSKI': 0,
    'BERNOSKY': 0,
    'BERNOT': 0,
    'BERNOTAS': 0,
    'BERNS': 0,
    'BERNSDORF': 0,
    'BERNSEN': 0,
    'BERNSHAUSEN': 0,
    'BERNSKOETTER': 0,
    'BERNSON': 0,
    'BERNSTEIN': 0,
    'BERNSTEN': 0,
    'BERNSTINE': 0,
    'BERNT': 0,
    'BERNTH': 0,
    'BERNTHAL': 0,
    'BERNTSEN': 0,
    'BERNTSON': 0,
    'BERNU': 0,
    'BERNY': 0,
    'BERNZOTT': 0,
    'BERO': 0,
    'BERON': 0,
    'BEROTH': 0,
    'BERQUIST': 0,
    'BERR': 0,
    'BERRA': 0,
    'BERRAY': 0,
    'BERRELES': 0,
    'BERRELEZ': 0,
    'BERRELL': 0,
    'BERRELLEZ': 0,
    'BERRELLEZA': 0,
    'BERRENS': 0,
    'BERRERA': 0,
    'BERRES': 0,
    'BERRESFORD': 0,
    'BERRET': 0,
    'BERRETH': 0,
    'BERRETT': 0,
    'BERRETTA': 0,
    'BERREY': 0,
    'BERRI': 0,
    'BERRIAN': 0,
    'BERRICK': 0,
    'BERRIDGE': 0,
    'BERRIE': 0,
    'BERRIEN': 0,
    'BERRIER': 0,
    'BERRIGAN': 0,
    'BERRILL': 0,
    'BERRIMAN': 0,
    'BERRING': 0,
    'BERRINGER': 0,
    'BERRINGTON': 0,
    'BERRIO': 0,
    'BERRIOCHOA': 0,
    'BERRIOS': 0,
    'BERRIS': 0,
    'BERRISFORD': 0,
    'BERRO': 0,
    'BERROA': 0,
    'BERROCAL': 0,
    'BERRON': 0,
    'BERRONES': 0,
    'BERRONG': 0,
    'BERROSPE': 0,
    'BERROTERAN': 0,
    'BERROTH': 0,
    'BERROUET': 0,
    'BERRU': 0,
    'BERRUM': 0,
    'BERRY': 0.12734218664726216,
    'BERRYANN': 0,
    'BERRYESSA': 0,
    'BERRYHILL': 0,
    'BERRYMAN': 0,
    'BERS': 0,
    'BERSAMIN': 0,
    'BERSANI': 0,
    'BERSANO': 0,
    'BERSCH': 0,
    'BERSCHAUER': 0,
    'BERSCHE': 0,
    'BERSCHEID': 0,
    'BERSHAD': 0,
    'BERSHADSKY': 0,
    'BERSIN': 0,
    'BERSON': 0,
    'BERST': 0,
    'BERSTEIN': 0,
    'BERSTLER': 0,
    'BERT': 0.9691629955947136,
    'BERTA': 0.9451795841209829,
    'BERTACCHI': 0,
    'BERTAGNA': 0,
    'BERTAGNOLE': 0,
    'BERTAGNOLI': 0,
    'BERTAGNOLLI': 0,
    'BERTAIN': 0,
    'BERTALAN': 0,
    'BERTALOT': 0,
    'BERTALOTTO': 0,
    'BERTAN': 0,
    'BERTANI': 0,
    'BERTAO': 0,
    'BERTAUT': 0,
    'BERTCH': 0,
    'BERTE': 0,
    'BERTEAU': 0,
    'BERTEL': 0,
    'BERTELLI': 0,
    'BERTELS': 0,
    'BERTELSEN': 0,
    'BERTELSMAN': 0,
    'BERTELSON': 0,
    'BERTEN': 0,
    'BERTERA': 0,
    'BERTERO': 0,
    'BERTETTO': 0,
    'BERTGES': 0,
    'BERTH': 0,
    'BERTHA': 0.9985336219537742,
    'BERTHEL': 0,
    'BERTHELETTE': 0,
    'BERTHELOT': 0,
    'BERTHELSEN': 0,
    'BERTHELSON': 0,
    'BERTHIAUME': 0,
    'BERTHOLD': 0,
    'BERTHOLF': 0,
    'BERTHOUD': 0,
    'BERTI': 0,
    'BERTIE': 0.9911894273127753,
    'BERTIN': 0,
    'BERTINI': 0,
    'BERTINO': 0,
    'BERTKE': 0,
    'BERTLES': 0,
    'BERTLING': 0,
    'BERTMAN': 0,
    'BERTO': 0,
    'BERTOCCHI': 0,
    'BERTOCCI': 0,
    'BERTOCH': 0,
    'BERTOGLIO': 0,
    'BERTOIA': 0,
    'BERTOK': 0,
    'BERTOLA': 0,
    'BERTOLAMI': 0,
    'BERTOLDI': 0,
    'BERTOLDO': 0,
    'BERTOLET': 0,
    'BERTOLETTE': 0,
    'BERTOLI': 0,
    'BERTOLINA': 0,
    'BERTOLINI': 0,
    'BERTOLINO': 0,
    'BERTOLLI': 0,
    'BERTOLO': 0,
    'BERTOLONE': 0,
    'BERTOLOTTI': 0,
    'BERTOLOZZI': 0,
    'BERTOLUCCI': 0,
    'BERTON': 0,
    'BERTONCINI': 0,
    'BERTONE': 0,
    'BERTONI': 0,
    'BERTORELLI': 0,
    'BERTOT': 0,
    'BERTOTTI': 0,
    'BERTOVICH': 0,
    'BERTOZZI': 0,
    'BERTRAM': 0.6273525721455457,
    'BERTRAN': 0,
    'BERTRAND': 0,
    'BERTRANG': 0,
    'BERTRON': 0,
    'BERTSCH': 0,
    'BERTSCHE': 0,
    'BERTSCHI': 0,
    'BERTSCHINGER': 0,
    'BERTSCHY': 0,
    'BERTUCA': 0,
    'BERTUCCELLI': 0,
    'BERTUCCI': 0,
    'BERTUCCIO': 0,
    'BERTUGLIA': 0,
    'BERTUS': 0,
    'BERTUZZI': 0,
    'BERTWELL': 0,
    'BERTY': 0,
    'BERTZ': 0,
    'BERUBE': 0,
    'BERUMEN': 0,
    'BERUS': 0,
    'BERUTTI': 0,
    'BERVEN': 0,
    'BERWAGER': 0,
    'BERWALD': 0,
    'BERWANGER': 0,
    'BERWICK': 0,
    'BERWIND': 0,
    'BERY': 0,
    'BERYL': 1,
    'BERZ': 0,
    'BERZAS': 0,
    'BERZIN': 0,
    'BERZINS': 0,
    'BERZINSKI': 0,
    'BERZON': 0,
    'BERZOZA': 0,
    'BESA': 0,
    'BESADA': 0,
    'BESANCENEY': 0,
    'BESANCON': 0,
    'BESAND': 0,
    'BESANSON': 0,
    'BESANT': 0,
    'BESAW': 0,
    'BESCH': 0,
    'BESCHER': 0,
    'BESCHORNER': 0,
    'BESCHTA': 0,
    'BESCO': 0,
    'BESE': 0,
    'BESEAU': 0,
    'BESECKER': 0,
    'BESEDA': 0,
    'BESEKE': 0,
    'BESEL': 0,
    'BESELER': 0,
    'BESEMAN': 0,
    'BESEMER': 0,
    'BESEN': 0,
    'BESENDORFER': 0,
    'BESERRA': 0,
    'BESETT': 0,
    'BESGROVE': 0,
    'BESH': 0,
    'BESHAI': 0,
    'BESHARA': 0,
    'BESHAW': 0,
    'BESHAY': 0,
    'BESHEAR': 0,
    'BESHEARS': 0,
    'BESHEL': 0,
    'BESHER': 0,
    'BESHERS': 0,
    'BESHERSE': 0,
    'BESHIR': 0,
    'BESHIRES': 0,
    'BESHIRS': 0,
    'BESHORE': 0,
    'BESIC': 0,
    'BESING': 0,
    'BESINGER': 0,
    'BESIO': 0,
    'BESKE': 0,
    'BESKID': 0,
    'BESKIN': 0,
    'BESKOW': 0,
    'BESL': 0,
    'BESLAGIC': 0,
    'BESLER': 0,
    'BESLEY': 0,
    'BESMER': 0,
    'BESNER': 0,
    'BESON': 0,
    'BESONEN': 0,
    'BESONG': 0,
    'BESORE': 0,
    'BESOZZI': 0,
    'BESS': 0.6717850287907869,
    'BESSA': 0,
    'BESSANT': 0,
    'BESSARD': 0,
    'BESSE': 0,
    'BESSEL': 0,
    'BESSELL': 0,
    'BESSELLIEU': 0,
    'BESSELMAN': 0,
    'BESSEMER': 0,
    'BESSEN': 0,
    'BESSENT': 0,
    'BESSER': 0,
    'BESSERMAN': 0,
    'BESSERT': 0,
    'BESSETT': 0,
    'BESSETTE': 0,
    'BESSEY': 0,
    'BESSIE': 0.9995835068721366,
    'BESSINGER': 0,
    'BESSIRE': 0,
    'BESSIX': 0,
    'BESSLER': 0,
    'BESSMAN': 0,
    'BESSMER': 0,
    'BESSO': 0,
    'BESSOLO': 0,
    'BESSON': 0,
    'BESSONETTE': 0,
    'BESST': 0,
    'BEST': 0,
    'BESTA': 0,
    'BESTE': 0,
    'BESTEDER': 0,
    'BESTEMAN': 0,
    'BESTER': 0,
    'BESTERMAN': 0,
    'BESTGEN': 0,
    'BESTLAND': 0,
    'BESTLER': 0,
    'BESTMAN': 0,
    'BESTON': 0,
    'BESTOR': 0,
    'BESTUL': 0,
    'BESTWICK': 0,
    'BESU': 0,
    'BESWICK': 0,
    'BET': 0,
    'BETANCE': 0,
    'BETANCES': 0,
    'BETANCO': 0,
    'BETANCOUR': 0,
    'BETANCOURT': 0,
    'BETANCOURTH': 0,
    'BETANCUR': 0,
    'BETANCURT': 0,
    'BETANZOS': 0,
    'BETAR': 0,
    'BETBEZE': 0,
    'BETCHER': 0,
    'BETER': 0,
    'BETESH': 0,
    'BETETA': 0,
    'BETH': 0.9969186151894146,
    'BETHA': 0,
    'BETHAM': 0,
    'BETHANCOURT': 0,
    'BETHANIE': 1,
    'BETHANN': 1,
    'BETHANY': 0.9913573970513473,
    'BETHARD': 0,
    'BETHARDS': 0,
    'BETHAY': 0,
    'BETHE': 0,
    'BETHEA': 0,
    'BETHEL': 0.425531914893617,
    'BETHELL': 0,
    'BETHENCOURT': 0,
    'BETHERS': 0,
    'BETHGE': 0,
    'BETHKE': 0,
    'BETHLEY': 0,
    'BETHMANN': 0,
    'BETHONEY': 0,
    'BETHUNE': 0,
    'BETHUREM': 0,
    'BETHURUM': 0,
    'BETIT': 0,
    'BETITA': 0,
    'BETKA': 0,
    'BETKE': 0,
    'BETKER': 0,
    'BETKOWSKI': 0,
    'BETLACH': 0,
    'BETLEJEWSKI': 0,
    'BETLER': 0,
    'BETLEY': 0,
    'BETO': 0,
    'BETOURNE': 0,
    'BETRAND': 0,
    'BETRO': 0,
    'BETROS': 0,
    'BETSCH': 0,
    'BETSCHART': 0,
    'BETSCHER': 0,
    'BETSEY': 0.9708737864077669,
    'BETSILL': 0,
    'BETSINGER': 0,
    'BETSON': 0,
    'BETSWORTH': 0,
    'BETSY': 1,
    'BETT': 0,
    'BETTA': 0,
    'BETTAG': 0,
    'BETTCHER': 0,
    'BETTE': 0.9958071278825996,
    'BETTEGA': 0,
    'BETTELYOUN': 0,
    'BETTEN': 0,
    'BETTENCOURT': 0,
    'BETTENDORF': 0,
    'BETTENHAUSEN': 0,
    'BETTER': 0,
    'BETTERIDGE': 0,
    'BETTERLEY': 0,
    'BETTERLY': 0,
    'BETTERMAN': 0,
    'BETTERMANN': 0,
    'BETTERS': 0,
    'BETTERSON': 0,
    'BETTERTON': 0,
    'BETTES': 0,
    'BETTEZ': 0,
    'BETTGE': 0,
    'BETTGER': 0,
    'BETTHAUSER': 0,
    'BETTI': 0,
    'BETTIE': 0.9982638888888888,
    'BETTIES': 0,
    'BETTIGA': 0,
    'BETTILYON': 0,
    'BETTIN': 0,
    'BETTINA': 1,
    'BETTINELLI': 0,
    'BETTING': 0,
    'BETTINGER': 0,
    'BETTINI': 0,
    'BETTINSON': 0,
    'BETTIS': 0,
    'BETTISON': 0,
    'BETTLE': 0,
    'BETTLER': 0,
    'BETTLES': 0,
    'BETTMAN': 0,
    'BETTNER': 0,
    'BETTON': 0,
    'BETTRIDGE': 0,
    'BETTS': 0,
    'BETTWY': 0,
    'BETTY': 0.9991148982132946,
    'BETTYANN': 1,
    'BETTYE': 1,
    'BETTYJ': 0,
    'BETZ': 0,
    'BETZEL': 0,
    'BETZEN': 0,
    'BETZER': 0,
    'BETZING': 0,
    'BETZLER': 0,
    'BETZNER': 0,
    'BETZOLD': 0,
    'BEU': 0,
    'BEUCHAT': 0,
    'BEUCHER': 0,
    'BEUCHERT': 0,
    'BEUCK': 0,
    'BEUCLER': 0,
    'BEUERLE': 0,
    'BEUERLEIN': 0,
    'BEUHLER': 0,
    'BEUKE': 0,
    'BEUKELMAN': 0,
    'BEUKEMA': 0,
    'BEULA': 1,
    'BEULAH': 0.9983361064891847,
    'BEULKE': 0,
    'BEUMEL': 0,
    'BEUMER': 0,
    'BEUNING': 0,
    'BEURSKENS': 0,
    'BEURY': 0,
    'BEUS': 0,
    'BEUSCHEL': 0,
    'BEUSCHER': 0,
    'BEUSSE': 0,
    'BEUSSINK': 0,
    'BEUTE': 0,
    'BEUTEL': 0,
    'BEUTER': 0,
    'BEUTH': 0,
    'BEUTHIN': 0,
    'BEUTLER': 0,
    'BEUTNER': 0,
    'BEUTTEL': 0,
    'BEV': 1,
    'BEVACQUA': 0,
    'BEVAN': 0,
    'BEVANS': 0,
    'BEVARD': 0,
    'BEVEL': 0,
    'BEVELL': 0,
    'BEVELLE': 0,
    'BEVELS': 0,
    'BEVEN': 0,
    'BEVENOUR': 0,
    'BEVENS': 0,
    'BEVENUE': 0,
    'BEVER': 0,
    'BEVERAGE': 0,
    'BEVERE': 0,
    'BEVERIDGE': 0,
    'BEVERLEE': 1,
    'BEVERLEY': 0.9569377990430621,
    'BEVERLIN': 0,
    'BEVERLY': 0.9841141130072611,
    'BEVERS': 0,
    'BEVERSDORF': 0,
    'BEVEVINO': 0,
    'BEVIER': 0,
    'BEVIL': 0,
    'BEVILACQUA': 0,
    'BEVILL': 0,
    'BEVILLE': 0,
    'BEVIN': 0,
    'BEVING': 0,
    'BEVINGTON': 0,
    'BEVINS': 0,
    'BEVIS': 0,
    'BEVIVINO': 0,
    'BEVLY': 0,
    'BEW': 0,
    'BEWICK': 0,
    'BEWLEY': 0,
    'BEWS': 0,
    'BEX': 0,
    'BEXELL': 0,
    'BEXLEY': 0,
    'BEXTEN': 0,
    'BEY': 0,
    'BEYAH': 0,
    'BEYALE': 0,
    'BEYARD': 0,
    'BEYDA': 0,
    'BEYDLER': 0,
    'BEYDOUN': 0,
    'BEYE': 0,
    'BEYEA': 0,
    'BEYELER': 0,
    'BEYENE': 0,
    'BEYER': 0,
    'BEYERL': 0,
    'BEYERLE': 0,
    'BEYERLEIN': 0,
    'BEYERS': 0,
    'BEYERSDORF': 0,
    'BEYERSDORFER': 0,
    'BEYETTE': 0,
    'BEYKE': 0,
    'BEYL': 0,
    'BEYLER': 0,
    'BEYMER': 0,
    'BEYNON': 0,
    'BEYOR': 0,
    'BEYRER': 0,
    'BEZ': 0,
    'BEZA': 0,
    'BEZAK': 0,
    'BEZANILLA': 0,
    'BEZANSON': 0,
    'BEZARES': 0,
    'BEZDEK': 0,
    'BEZDICEK': 0,
    'BEZEK': 0,
    'BEZEMEK': 0,
    'BEZERRA': 0,
    'BEZET': 0,
    'BEZILLA': 0,
    'BEZIO': 0,
    'BEZNER': 0,
    'BEZOLD': 0,
    'BEZON': 0,
    'BEZONA': 0,
    'BEZOTTE': 0,
    'BEZY': 0,
    'BEZZANT': 0,
    'BHAGAT': 0,
    'BHAGWANDEEN': 0,
    'BHAGWANDIN': 0,
    'BHAGWAT': 0,
    'BHAI': 0,
    'BHAKTA': 0,
    'BHALLA': 0,
    'BHAMANI': 0,
    'BHAMBHANI': 0,
    'BHAN': 0,
    'BHANDAL': 0,
    'BHANDARI': 0,
    'BHANGOO': 0,
    'BHANGU': 0,
    'BHANOT': 0,
    'BHANSALI': 0,
    'BHARADWAJ': 0,
    'BHARAT': 0,
    'BHARATH': 0,
    'BHARDWAJ': 0,
    'BHARGAVA': 0,
    'BHARUCHA': 0,
    'BHARWANI': 0,
    'BHASIN': 0,
    'BHASKAR': 0,
    'BHASKARAN': 0,
    'BHAT': 0,
    'BHATIA': 0,
    'BHATNAGAR': 0,
    'BHATT': 0,
    'BHATTACHARJEE': 0,
    'BHATTACHARYA': 0,
    'BHATTACHARYYA': 0,
    'BHATTARAI': 0,
    'BHATTI': 0,
    'BHATTY': 0,
    'BHAUMIK': 0,
    'BHAVE': 0,
    'BHAVSAR': 0,
    'BHAYANI': 0,
    'BHIDE': 0,
    'BHIMANI': 0,
    'BHOGAL': 0,
    'BHOJANI': 0,
    'BHOJWANI': 0,
    'BHOLA': 0,
    'BHOLAT': 0,
    'BHOWMIK': 0,
    'BHUIYAN': 0,
    'BHULA': 0,
    'BHULLAR': 0,
    'BHUSHAN': 0,
    'BHUTA': 0,
    'BHUTANI': 0,
    'BHUTTA': 0,
    'BHUYAN': 0,
    'BI': 0,
    'BIA': 0,
    'BIAFORE': 0,
    'BIAGAS': 0,
    'BIAGETTI': 0,
    'BIAGGI': 0,
    'BIAGI': 0,
    'BIAGINI': 0,
    'BIAGIOLI': 0,
    'BIAGIONI': 0,
    'BIAGIOTTI': 0,
    'BIAIR': 0,
    'BIAKE': 0,
    'BIAL': 0,
    'BIALA': 0,
    'BIALAS': 0,
    'BIALASZEWSKI': 0,
    'BIALCZAK': 0,
    'BIALECKI': 0,
    'BIALEK': 0,
    'BIALER': 0,
    'BIALESCHKI': 0,
    'BIALICK': 0,
    'BIALIK': 0,
    'BIALK': 0,
    'BIALKA': 0,
    'BIALKE': 0,
    'BIALKO': 0,
    'BIALKOWSKI': 0,
    'BIALLAS': 0,
    'BIALO': 0,
    'BIALOBRZESKI': 0,
    'BIALON': 0,
    'BIALORUCKI': 0,
    'BIALOWAS': 0,
    'BIALY': 0,
    'BIAMONTE': 0,
    'BIAN': 0,
    'BIANCA': 0.9861932938856016,
    'BIANCALANA': 0,
    'BIANCAMANO': 0,
    'BIANCANIELLO': 0,
    'BIANCARDI': 0,
    'BIANCHARD': 0,
    'BIANCHETTI': 0,
    'BIANCHI': 0,
    'BIANCHINI': 0,
    'BIANCHINO': 0,
    'BIANCO': 0,
    'BIANCONE': 0,
    'BIANCONI': 0,
    'BIANCULLI': 0,
    'BIANCUZZO': 0,
    'BIAND': 0,
    'BIANDO': 0,
    'BIANK': 0,
    'BIANO': 0,
    'BIANUCCI': 0,
    'BIAR': 0,
    'BIARD': 0,
    'BIAS': 0,
    'BIASE': 0,
    'BIASELLA': 0,
    'BIASI': 0,
    'BIASOTTI': 0,
    'BIAVA': 0,
    'BIAZ': 0,
    'BIAZZO': 0,
    'BIBA': 0,
    'BIBB': 0,
    'BIBBEE': 0,
    'BIBBENS': 0,
    'BIBBER': 0,
    'BIBBEY': 0,
    'BIBBINS': 0,
    'BIBBO': 0,
    'BIBBS': 0,
    'BIBBY': 0,
    'BIBEAU': 0,
    'BIBEAULT': 0,
    'BIBEE': 0,
    'BIBENS': 0,
    'BIBER': 0,
    'BIBERDORF': 0,
    'BIBERSTEIN': 0,
    'BIBERSTINE': 0,
    'BIBEY': 0,
    'BIBI': 0.7407407407407407,
    'BIBIAN': 0,
    'BIBIANO': 0,
    'BIBIK': 0,
    'BIBLE': 0,
    'BIBLER': 0,
    'BIBLES': 0,
    'BIBO': 0,
    'BIBRIESCA': 0,
    'BIBY': 0,
    'BICA': 0,
    'BICAN': 0,
    'BICCUM': 0,
    'BICE': 0,
    'BICEK': 0,
    'BICH': 0,
    'BICHARA': 0,
    'BICHARD': 0,
    'BICHEL': 0,
    'BICHER': 0,
    'BICHLER': 0,
    'BICHSEL': 0,
    'BICK': 0,
    'BICKAR': 0,
    'BICKART': 0,
    'BICKEL': 0,
    'BICKELHAUPT': 0,
    'BICKELL': 0,
    'BICKELMAN': 0,
    'BICKER': 0,
    'BICKERS': 0,
    'BICKERSTAFF': 0,
    'BICKERT': 0,
    'BICKERTON': 0,
    'BICKET': 0,
    'BICKETT': 0,
    'BICKFORD': 0,
    'BICKHAM': 0,
    'BICKHART': 0,
    'BICKING': 0,
    'BICKINGS': 0,
    'BICKLE': 0,
    'BICKLER': 0,
    'BICKLEY': 0,
    'BICKLING': 0,
    'BICKMAN': 0,
    'BICKMEYER': 0,
    'BICKMORE': 0,
    'BICKNASE': 0,
    'BICKNELL': 0,
    'BICKNER': 0,
    'BICKNESE': 0,
    'BICKOFF': 0,
    'BICKSLER': 0,
    'BIDA': 0,
    'BIDDICK': 0,
    'BIDDING': 0,
    'BIDDINGER': 0,
    'BIDDINGS': 0,
    'BIDDISCOMBE': 0,
    'BIDDISON': 0,
    'BIDDIX': 0,
    'BIDDLE': 0,
    'BIDDLECOME': 0,
    'BIDDULPH': 0,
    'BIDDY': 0,
    'BIDEGAIN': 0,
    'BIDELMAN': 0,
    'BIDELSPACH': 0,
    'BIDEN': 0,
    'BIDER': 0,
    'BIDERMAN': 0,
    'BIDGOOD': 0,
    'BIDIGARE': 0,
    'BIDINGER': 0,
    'BIDLACK': 0,
    'BIDLE': 0,
    'BIDLEMAN': 0,
    'BIDNE': 0,
    'BIDNER': 0,
    'BIDNICK': 0,
    'BIDO': 0,
    'BIDOM': 0,
    'BIDON': 0,
    'BIDOT': 0,
    'BIDSTRUP': 0,
    'BIDWELL': 0,
    'BIE': 0,
    'BIEBEL': 0,
    'BIEBER': 0,
    'BIEBERICH': 0,
    'BIEBERLE': 0,
    'BIEBL': 0,
    'BIECHLER': 0,
    'BIECHY': 0,
    'BIECK': 0,
    'BIEDA': 0,
    'BIEDENBACH': 0,
    'BIEDENBENDER': 0,
    'BIEDENHARN': 0,
    'BIEDER': 0,
    'BIEDERMAN': 0,
    'BIEDERMANN': 0,
    'BIEDERWOLF': 0,
    'BIEDIGER': 0,
    'BIEDINGER': 0,
    'BIEDRON': 0,
    'BIEDRZYCKI': 0,
    'BIEG': 0,
    'BIEGA': 0,
    'BIEGALSKI': 0,
    'BIEGANOWSKI': 0,
    'BIEGANSKI': 0,
    'BIEGE': 0,
    'BIEGEL': 0,
    'BIEGELEISEN': 0,
    'BIEGEN': 0,
    'BIEGER': 0,
    'BIEGERT': 0,
    'BIEGGER': 0,
    'BIEGHLER': 0,
    'BIEGLER': 0,
    'BIEHL': 0,
    'BIEHLE': 0,
    'BIEHLER': 0,
    'BIEHN': 0,
    'BIEK': 0,
    'BIEKER': 0,
    'BIEKERT': 0,
    'BIEL': 0,
    'BIELA': 0,
    'BIELAK': 0,
    'BIELAMOWICZ': 0,
    'BIELANSKI': 0,
    'BIELAS': 0,
    'BIELAT': 0,
    'BIELAWA': 0,
    'BIELAWSKI': 0,
    'BIELBY': 0,
    'BIELE': 0,
    'BIELEC': 0,
    'BIELECKI': 0,
    'BIELEFELD': 0,
    'BIELEFELDT': 0,
    'BIELEK': 0,
    'BIELEMA': 0,
    'BIELEN': 0,
    'BIELENBERG': 0,
    'BIELENDA': 0,
    'BIELER': 0,
    'BIELEWICZ': 0,
    'BIELFELDT': 0,
    'BIELICH': 0,
    'BIELICKI': 0,
    'BIELIK': 0,
    'BIELING': 0,
    'BIELINSKI': 0,
    'BIELKE': 0,
    'BIELLER': 0,
    'BIELLI': 0,
    'BIELLING': 0,
    'BIELLO': 0,
    'BIELMA': 0,
    'BIELMAN': 0,
    'BIELMEIER': 0,
    'BIELSER': 0,
    'BIELSKI': 0,
    'BIELSS': 0,
    'BIELSTEIN': 0,
    'BIELY': 0,
    'BIEMER': 0,
    'BIEMILLER': 0,
    'BIEN': 0,
    'BIENAIME': 0,
    'BIENEK': 0,
    'BIENEMAN': 0,
    'BIENEMANN': 0,
    'BIENEMY': 0,
    'BIENENFELD': 0,
    'BIENER': 0,
    'BIENERT': 0,
    'BIENFANG': 0,
    'BIENHOFF': 0,
    'BIENIAS': 0,
    'BIENIASZ': 0,
    'BIENICK': 0,
    'BIENIEK': 0,
    'BIENKO': 0,
    'BIENKOWSKI': 0,
    'BIENSTOCK': 0,
    'BIENVENU': 0,
    'BIENVENUE': 0,
    'BIENZ': 0,
    'BIER': 0,
    'BIERA': 0,
    'BIERBAUM': 0,
    'BIERBOWER': 0,
    'BIERBRAUER': 0,
    'BIERCE': 0,
    'BIERD': 0,
    'BIERDEMAN': 0,
    'BIERE': 0,
    'BIEREMA': 0,
    'BIERER': 0,
    'BIERI': 0,
    'BIERIE': 0,
    'BIERIG': 0,
    'BIERING': 0,
    'BIERINGER': 0,
    'BIERKAMP': 0,
    'BIERL': 0,
    'BIERLE': 0,
    'BIERLEIN': 0,
    'BIERLEY': 0,
    'BIERLING': 0,
    'BIERLY': 0,
    'BIERMA': 0,
    'BIERMAIER': 0,
    'BIERMAN': 0,
    'BIERMANN': 0,
    'BIERMEIER': 0,
    'BIERNACKI': 0,
    'BIERNAT': 0,
    'BIERNBAUM': 0,
    'BIERNESSER': 0,
    'BIERS': 0,
    'BIERSACK': 0,
    'BIERSCHBACH': 0,
    'BIERSCHENK': 0,
    'BIERSCHWALE': 0,
    'BIERSTEDT': 0,
    'BIERUT': 0,
    'BIERWAGEN': 0,
    'BIERWIRTH': 0,
    'BIERY': 0,
    'BIES': 0,
    'BIESCHKE': 0,
    'BIESE': 0,
    'BIESECKER': 0,
    'BIESEL': 0,
    'BIESEMEIER': 0,
    'BIESEMEYER': 0,
    'BIESENBACH': 0,
    'BIESER': 0,
    'BIESIADA': 0,
    'BIESIADECKI': 0,
    'BIESINGER': 0,
    'BIESTER': 0,
    'BIESTERFELD': 0,
    'BIESTERVELD': 0,
    'BIESZCZAD': 0,
    'BIESZK': 0,
    'BIETH': 0,
    'BIETSCH': 0,
    'BIETZ': 0,
    'BIEVER': 0,
    'BIEVINS': 0,
    'BIEWER': 0,
    'BIEZE': 0,
    'BIFANO': 0,
    'BIFFAR': 0,
    'BIFFLE': 0,
    'BIFULCO': 0,
    'BIG': 0,
    'BIGA': 0,
    'BIGALK': 0,
    'BIGALKE': 0,
    'BIGALOW': 0,
    'BIGAM': 0,
    'BIGAOUETTE': 0,
    'BIGART': 0,
    'BIGBEAR': 0,
    'BIGBEE': 0,
    'BIGBIE': 0,
    'BIGBOY': 0,
    'BIGBY': 0,
    'BIGCROW': 0,
    'BIGDA': 0,
    'BIGEAGLE': 0,
    'BIGELOW': 0,
    'BIGENHO': 0,
    'BIGFORD': 0,
    'BIGG': 0,
    'BIGGANE': 0,
    'BIGGAR': 0,
    'BIGGART': 0,
    'BIGGE': 0,
    'BIGGER': 0,
    'BIGGERS': 0,
    'BIGGERSTAFF': 0,
    'BIGGERT': 0,
    'BIGGI': 0,
    'BIGGIE': 0,
    'BIGGIN': 0,
    'BIGGINS': 0,
    'BIGGIO': 0,
    'BIGGS': 0,
    'BIGHAM': 0,
    'BIGHORN': 0,
    'BIGHORSE': 0,
    'BIGI': 0,
    'BIGIO': 0,
    'BIGLANE': 0,
    'BIGLER': 0,
    'BIGLEY': 0,
    'BIGLIN': 0,
    'BIGLOW': 0,
    'BIGMAN': 0,
    'BIGNALL': 0,
    'BIGNELL': 0,
    'BIGNER': 0,
    'BIGNESS': 0,
    'BIGNEY': 0,
    'BIGONY': 0,
    'BIGORNIA': 0,
    'BIGOS': 0,
    'BIGOT': 0,
    'BIGOTT': 0,
    'BIGRIGG': 0,
    'BIGSBY': 0,
    'BIGUS': 0,
    'BIGWOOD': 0,
    'BIHARI': 0,
    'BIHARY': 0,
    'BIHL': 0,
    'BIHLER': 0,
    'BIHM': 0,
    'BIHN': 0,
    'BIHR': 0,
    'BIHUN': 0,
    'BIJAK': 0,
    'BIJARRO': 0,
    'BIJEAUX': 0,
    'BIJELIC': 0,
    'BIJOU': 0,
    'BIK': 0,
    'BIKEL': 0,
    'BIKOWSKI': 0,
    'BIL': 0,
    'BILA': 0,
    'BILADEAU': 0,
    'BILAGODY': 0,
    'BILAK': 0,
    'BILAL': 0,
    'BILAN': 0,
    'BILANCIA': 0,
    'BILAND': 0,
    'BILAS': 0,
    'BILBAO': 0,
    'BILBAY': 0,
    'BILBEE': 0,
    'BILBERRY': 0,
    'BILBO': 0,
    'BILBREW': 0,
    'BILBREY': 0,
    'BILBRO': 0,
    'BILBROUGH': 0,
    'BILBRUCK': 0,
    'BILBY': 0,
    'BILD': 0,
    'BILDEN': 0,
    'BILDER': 0,
    'BILDERBACK': 0,
    'BILDNER': 0,
    'BILDSTEIN': 0,
    'BILE': 0,
    'BILECKI': 0,
    'BILEK': 0,
    'BILELLA': 0,
    'BILELLO': 0,
    'BILER': 0,
    'BILES': 0,
    'BILEY': 0,
    'BILGER': 0,
    'BILHARZ': 0,
    'BILHEIMER': 0,
    'BILIC': 0,
    'BILICH': 0,
    'BILICKI': 0,
    'BILIK': 0,
    'BILINSKI': 0,
    'BILINSKY': 0,
    'BILIS': 0,
    'BILITER': 0,
    'BILKA': 0,
    'BILKE': 0,
    'BILKEY': 0,
    'BILKO': 0,
    'BILL': 0.9791065652592009,
    'BILLA': 0,
    'BILLADEAU': 0,
    'BILLADO': 0,
    'BILLAH': 0,
    'BILLALOBOS': 0,
    'BILLANTE': 0,
    'BILLANUEVA': 0,
    'BILLARD': 0,
    'BILLAU': 0,
    'BILLBE': 0,
    'BILLBERRY': 0,
    'BILLE': 0,
    'BILLEAUD': 0,
    'BILLEAUDEAU': 0,
    'BILLECI': 0,
    'BILLECK': 0,
    'BILLEDEAUX': 0,
    'BILLEDO': 0,
    'BILLEGAS': 0,
    'BILLEN': 0,
    'BILLENSTEIN': 0,
    'BILLER': 0,
    'BILLERA': 0,
    'BILLERBECK': 0,
    'BILLERMAN': 0,
    'BILLESBACH': 0,
    'BILLET': 0,
    'BILLETDEAUX': 0,
    'BILLETER': 0,
    'BILLETT': 0,
    'BILLETTE': 0,
    'BILLETTER': 0,
    'BILLEY': 0,
    'BILLGER': 0,
    'BILLHARTZ': 0,
    'BILLHEIMER': 0,
    'BILLHIMER': 0,
    'BILLI': 0.9523809523809523,
    'BILLIAN': 0,
    'BILLIARD': 0,
    'BILLICK': 0,
    'BILLIE': 0.9910117538603365,
    'BILLIEL': 0,
    'BILLIET': 0,
    'BILLIG': 0,
    'BILLIGMEIER': 0,
    'BILLIN': 0,
    'BILLING': 0,
    'BILLINGER': 0,
    'BILLINGHAM': 0,
    'BILLINGHURST': 0,
    'BILLINGS': 0,
    'BILLINGSLEA': 0,
    'BILLINGSLEY': 0,
    'BILLINGSLY': 0,
    'BILLINGTON': 0,
    'BILLINS': 0,
    'BILLION': 0,
    'BILLIONS': 0,
    'BILLIOT': 0,
    'BILLIPS': 0,
    'BILLIS': 0,
    'BILLITER': 0,
    'BILLMAIER': 0,
    'BILLMAN': 0,
    'BILLMEIER': 0,
    'BILLMEYER': 0,
    'BILLMYER': 0,
    'BILLO': 0,
    'BILLOCK': 0,
    'BILLODEAU': 0,
    'BILLON': 0,
    'BILLONE': 0,
    'BILLOPS': 0,
    'BILLOT': 0,
    'BILLOTTE': 0,
    'BILLOTTI': 0,
    'BILLOW': 0,
    'BILLS': 0,
    'BILLSON': 0,
    'BILLSTROM': 0,
    'BILLUE': 0,
    'BILLUPS': 0,
    'BILLY': 0.9951820551299265,
    'BILLYE': 1,
    'BILNOSKI': 0,
    'BILO': 0,
    'BILODEAU': 0,
    'BILOTTA': 0,
    'BILOTTI': 0,
    'BILOTTO': 0,
    'BILOUS': 0,
    'BILOW': 0,
    'BILS': 0,
    'BILSKI': 0,
    'BILSKIE': 0,
    'BILSKY': 0,
    'BILSLAND': 0,
    'BILSON': 0,
    'BILTOFT': 0,
    'BILTON': 0,
    'BILTZ': 0,
    'BILY': 0,
    'BILYEU': 0,
    'BILYK': 0,
    'BILYOU': 0,
    'BILZ': 0,
    'BIMBER': 0,
    'BIMBO': 0,
    'BIMLER': 0,
    'BIMONTE': 0,
    'BIMSON': 0,
    'BIN': 0,
    'BINA': 0,
    'BINAM': 0,
    'BINAU': 0,
    'BINCKLEY': 0,
    'BINDA': 0,
    'BINDAS': 0,
    'BINDE': 0,
    'BINDEL': 0,
    'BINDER': 0,
    'BINDERT': 0,
    'BINDERUP': 0,
    'BINDEWALD': 0,
    'BINDI': 0,
    'BINDL': 0,
    'BINDLEY': 0,
    'BINDNER': 0,
    'BINDON': 0,
    'BINDRA': 0,
    'BINDUS': 0,
    'BINE': 0,
    'BINEGAR': 0,
    'BINEK': 0,
    'BINER': 0,
    'BINES': 0,
    'BINET': 0,
    'BINETTE': 0,
    'BINETTI': 0,
    'BINEY': 0,
    'BINFET': 0,
    'BINFORD': 0,
    'BING': 0,
    'BINGAMAN': 0,
    'BINGAMON': 0,
    'BINGE': 0,
    'BINGEL': 0,
    'BINGEMAN': 0,
    'BINGEN': 0,
    'BINGENHEIMER': 0,
    'BINGER': 0,
    'BINGERT': 0,
    'BINGGELI': 0,
    'BINGHAM': 0,
    'BINGLE': 0,
    'BINGLER': 0,
    'BINGLEY': 0,
    'BINGMAN': 0,
    'BINGO': 0,
    'BINI': 0,
    'BINIECKI': 0,
    'BINIEK': 0,
    'BINIENDA': 0,
    'BINION': 0,
    'BINK': 0,
    'BINKER': 0,
    'BINKERD': 0,
    'BINKLEY': 0,
    'BINKO': 0,
    'BINKOSKI': 0,
    'BINKOWSKI': 0,
    'BINKS': 0,
    'BINLEY': 0,
    'BINN': 0,
    'BINNALL': 0,
    'BINNEBOSE': 0,
    'BINNER': 0,
    'BINNEY': 0,
    'BINNICKER': 0,
    'BINNIE': 0,
    'BINNING': 0,
    'BINNINGER': 0,
    'BINNION': 0,
    'BINNIX': 0,
    'BINNS': 0,
    'BINO': 0,
    'BINOTTO': 0,
    'BINS': 0,
    'BINSCHUS': 0,
    'BINSFELD': 0,
    'BINSON': 0,
    'BINSTOCK': 0,
    'BINSWANGER': 0,
    'BINTER': 0,
    'BINTLIFF': 0,
    'BINTNER': 0,
    'BINTRIM': 0,
    'BINTZ': 0,
    'BINUYA': 0,
    'BINVERSIE': 0,
    'BINYARD': 0,
    'BINYON': 0,
    'BINZ': 0,
    'BINZER': 0,
    'BIO': 0,
    'BIOLSI': 0,
    'BIONDI': 0,
    'BIONDICH': 0,
    'BIONDO': 0,
    'BIONDOLILLO': 0,
    'BIORDI': 0,
    'BIORN': 0,
    'BIOSS': 0,
    'BIPES': 0,
    'BIPPERT': 0,
    'BIPPES': 0,
    'BIPPUS': 0,
    'BIR': 0,
    'BIRA': 0,
    'BIRAM': 0,
    'BIRBECK': 0,
    'BIRCH': 0,
    'BIRCHALL': 0,
    'BIRCHARD': 0,
    'BIRCHEAT': 0,
    'BIRCHELL': 0,
    'BIRCHEM': 0,
    'BIRCHENOUGH': 0,
    'BIRCHER': 0,
    'BIRCHETT': 0,
    'BIRCHETTE': 0,
    'BIRCHFIELD': 0,
    'BIRCHLER': 0,
    'BIRCHMAN': 0,
    'BIRCHMEIER': 0,
    'BIRCHMIER': 0,
    'BIRCHMORE': 0,
    'BIRCHUM': 0,
    'BIRCK': 0,
    'BIRCKBICHLER': 0,
    'BIRCKHEAD': 0,
    'BIRD': 0,
    'BIRDEN': 0,
    'BIRDIE': 1,
    'BIRDINE': 0,
    'BIRDINGROUND': 0,
    'BIRDOW': 0,
    'BIRDSALL': 0,
    'BIRDSELL': 0,
    'BIRDSEY': 0,
    'BIRDSEYE': 0,
    'BIRDSILL': 0,
    'BIRDSLEY': 0,
    'BIRDSONG': 0,
    'BIRDTAIL': 0,
    'BIRDWELL': 0,
    'BIRDYSHAW': 0,
    'BIRELEY': 0,
    'BIRELY': 0,
    'BIREN': 0,
    'BIRENBAUM': 0,
    'BIRES': 0,
    'BIRGE': 0,
    'BIRGEL': 0,
    'BIRGEN': 0,
    'BIRGER': 0,
    'BIRGIT': 1,
    'BIRGY': 0,
    'BIRI': 0,
    'BIRINGER': 0,
    'BIRK': 0,
    'BIRKBECK': 0,
    'BIRKBY': 0,
    'BIRKE': 0,
    'BIRKEL': 0,
    'BIRKELAND': 0,
    'BIRKELBACH': 0,
    'BIRKEMEIER': 0,
    'BIRKEN': 0,
    'BIRKENBACH': 0,
    'BIRKENFELD': 0,
    'BIRKENHAUER': 0,
    'BIRKENHOLZ': 0,
    'BIRKENMEIER': 0,
    'BIRKENSTOCK': 0,
    'BIRKES': 0,
    'BIRKETT': 0,
    'BIRKEY': 0,
    'BIRKHEAD': 0,
    'BIRKHIMER': 0,
    'BIRKHOFER': 0,
    'BIRKHOFF': 0,
    'BIRKHOLD': 0,
    'BIRKHOLZ': 0,
    'BIRKINBINE': 0,
    'BIRKLA': 0,
    'BIRKLAND': 0,
    'BIRKLE': 0,
    'BIRKLEY': 0,
    'BIRKMAIER': 0,
    'BIRKMAN': 0,
    'BIRKMANN': 0,
    'BIRKMEYER': 0,
    'BIRKMIRE': 0,
    'BIRKNER': 0,
    'BIRKS': 0,
    'BIRKY': 0,
    'BIRL': 0,
    'BIRLEW': 0,
    'BIRLEY': 0,
    'BIRLING': 0,
    'BIRMAN': 0,
    'BIRMINGHAM': 0,
    'BIRN': 0,
    'BIRNBACH': 0,
    'BIRNBAUM': 0,
    'BIRNBERG': 0,
    'BIRNEL': 0,
    'BIRNELL': 0,
    'BIRNER': 0,
    'BIRNEY': 0,
    'BIRNIE': 0,
    'BIRNS': 0,
    'BIRO': 0,
    'BIRON': 0,
    'BIROS': 0,
    'BIRR': 0,
    'BIRRELL': 0,
    'BIRRENKOTT': 0,
    'BIRRER': 0,
    'BIRRIEL': 0,
    'BIRRUETA': 0,
    'BIRRUETE': 0,
    'BIRSA': 0,
    'BIRSCHBACH': 0,
    'BIRSE': 0,
    'BIRSNER': 0,
    'BIRT': 0,
    'BIRTCH': 0,
    'BIRTCHER': 0,
    'BIRTELL': 0,
    'BIRTH': 0,
    'BIRTHWRIGHT': 0,
    'BIRTLES': 0,
    'BIRTLEY': 0,
    'BIRTON': 0,
    'BIRTS': 0,
    'BIRTWELL': 0,
    'BIRTWISTLE': 0,
    'BIRZER': 0,
    'BIS': 0,
    'BISACCIA': 0,
    'BISAHA': 0,
    'BISAILLON': 0,
    'BISANZ': 0,
    'BISARD': 0,
    'BISBAL': 0,
    'BISBANO': 0,
    'BISBEE': 0,
    'BISBEY': 0,
    'BISBIKIS': 0,
    'BISBING': 0,
    'BISBY': 0,
    'BISCAINO': 0,
    'BISCAMP': 0,
    'BISCAN': 0,
    'BISCARDI': 0,
    'BISCEGLIA': 0,
    'BISCEGLIE': 0,
    'BISCH': 0,
    'BISCHAK': 0,
    'BISCHEL': 0,
    'BISCHER': 0,
    'BISCHOF': 0,
    'BISCHOFF': 0,
    'BISCIOTTI': 0,
    'BISCO': 0,
    'BISCOCHO': 0,
    'BISCOE': 0,
    'BISCONER': 0,
    'BISCONTI': 0,
    'BISCOTTI': 0,
    'BISCOTTO': 0,
    'BISDORF': 0,
    'BISE': 0,
    'BISEK': 0,
    'BISEL': 0,
    'BISENIUS': 0,
    'BISER': 0,
    'BISESI': 0,
    'BISGAARD': 0,
    'BISGARD': 0,
    'BISGROVE': 0,
    'BISH': 0,
    'BISHAI': 0,
    'BISHARA': 0,
    'BISHARAT': 0,
    'BISHARD': 0,
    'BISHAW': 0,
    'BISHAY': 0,
    'BISHEL': 0,
    'BISHER': 0,
    'BISHIP': 0,
    'BISHIR': 0,
    'BISHMAN': 0,
    'BISHO': 0,
    'BISHOFF': 0,
    'BISHOP': 0,
    'BISHOPP': 0,
    'BISHTON': 0,
    'BISHUN': 0,
    'BISI': 0,
    'BISIG': 0,
    'BISIGNANI': 0,
    'BISIGNANO': 0,
    'BISINGER': 0,
    'BISIO': 0,
    'BISKER': 0,
    'BISKEY': 0,
    'BISKING': 0,
    'BISKNER': 0,
    'BISKUP': 0,
    'BISKUPSKI': 0,
    'BISLAND': 0,
    'BISMARK': 0,
    'BISNAUTH': 0,
    'BISNER': 0,
    'BISNETT': 0,
    'BISNETTE': 0,
    'BISOGNO': 0,
    'BISON': 0,
    'BISONO': 0,
    'BISORDI': 0,
    'BISPHAM': 0,
    'BISPING': 0,
    'BISPO': 0,
    'BISQUERA': 0,
    'BISRAM': 0,
    'BISS': 0,
    'BISSAILLON': 0,
    'BISSAINTHE': 0,
    'BISSEGGER': 0,
    'BISSEL': 0,
    'BISSELL': 0,
    'BISSEN': 0,
    'BISSESSAR': 0,
    'BISSET': 0,
    'BISSETT': 0,
    'BISSETTE': 0,
    'BISSEY': 0,
    'BISSIG': 0,
    'BISSING': 0,
    'BISSINGER': 0,
    'BISSLER': 0,
    'BISSMEYER': 0,
    'BISSO': 0,
    'BISSON': 0,
    'BISSONETTE': 0,
    'BISSONNETTE': 0,
    'BISSOON': 0,
    'BIST': 0,
    'BISTA': 0,
    'BISTANY': 0,
    'BISTARKEY': 0,
    'BISTER': 0,
    'BISTLINE': 0,
    'BISTODEAU': 0,
    'BISTON': 0,
    'BISULCA': 0,
    'BISWAS': 0,
    'BISWELL': 0,
    'BITANGA': 0,
    'BITAR': 0,
    'BITEL': 0,
    'BITELY': 0,
    'BITER': 0,
    'BITETTI': 0,
    'BITETTO': 0,
    'BITGOOD': 0,
    'BITHELL': 0,
    'BITHER': 0,
    'BITIKOFER': 0,
    'BITKER': 0,
    'BITLER': 0,
    'BITMAN': 0,
    'BITNER': 0,
    'BITNEY': 0,
    'BITO': 0,
    'BITON': 0,
    'BITONDO': 0,
    'BITONTI': 0,
    'BITSIE': 0,
    'BITSILLY': 0,
    'BITSKO': 0,
    'BITSON': 0,
    'BITSUE': 0,
    'BITSUI': 0,
    'BITSUIE': 0,
    'BITTAR': 0,
    'BITTEL': 0,
    'BITTEN': 0,
    'BITTENBENDER': 0,
    'BITTER': 0,
    'BITTERLY': 0,
    'BITTERMAN': 0,
    'BITTERMANN': 0,
    'BITTERS': 0,
    'BITTICK': 0,
    'BITTING': 0,
    'BITTINGER': 0,
    'BITTLE': 0,
    'BITTLER': 0,
    'BITTLES': 0,
    'BITTMAN': 0,
    'BITTMANN': 0,
    'BITTNER': 0,
    'BITTO': 0,
    'BITTON': 0,
    'BITTORF': 0,
    'BITTS': 0,
    'BITUIN': 0,
    'BITZ': 0,
    'BITZAN': 0,
    'BITZEL': 0,
    'BITZER': 0,
    'BIUNDO': 0,
    'BIUS': 0,
    'BIUSO': 0,
    'BIVANS': 0,
    'BIVE': 0,
    'BIVEN': 0,
    'BIVENS': 0,
    'BIVER': 0,
    'BIVIANO': 0,
    'BIVIN': 0,
    'BIVINES': 0,
    'BIVINGS': 0,
    'BIVINS': 0,
    'BIVONA': 0,
    'BIWER': 0,
    'BIX': 0,
    'BIXBY': 0,
    'BIXEL': 0,
    'BIXENMAN': 0,
    'BIXLER': 0,
    'BIZA': 0,
    'BIZAL': 0,
    'BIZARRO': 0,
    'BIZEAU': 0,
    'BIZEK': 0,
    'BIZER': 0,
    'BIZETTE': 0,
    'BIZIER': 0,
    'BIZIK': 0,
    'BIZJAK': 0,
    'BIZON': 0,
    'BIZUB': 0,
    'BIZZARO': 0,
    'BIZZARRI': 0,
    'BIZZARRO': 0,
    'BIZZELL': 0,
    'BIZZLE': 0,
    'BIZZOCO': 0,
    'BIZZOTTO': 0,
    'BJARNASON': 0,
    'BJARNSON': 0,
    'BJELKE': 0,
    'BJELLA': 0,
    'BJELLAND': 0,
    'BJERK': 0,
    'BJERKE': 0,
    'BJERKEN': 0,
    'BJERKNESS': 0,
    'BJERREGAARD': 0,
    'BJORDAHL': 0,
    'BJORGAARD': 0,
    'BJORGE': 0,
    'BJORGO': 0,
    'BJORGUM': 0,
    'BJORK': 0,
    'BJORKE': 0,
    'BJORKLAND': 0,
    'BJORKLUND': 0,
    'BJORKMAN': 0,
    'BJORKQUIST': 0,
    'BJORLIN': 0,
    'BJORLING': 0,
    'BJORN': 0,
    'BJORNBERG': 0,
    'BJORNDAHL': 0,
    'BJORNDAL': 0,
    'BJORNSEN': 0,
    'BJORNSON': 0,
    'BJORNSTAD': 0,
    'BJUGSTAD': 0,
    'BJUR': 0,
    'BJURSTROM': 0,
    'BLAAUW': 0,
    'BLABER': 0,
    'BLACH': 0,
    'BLACHA': 0,
    'BLACHE': 0,
    'BLACHER': 0,
    'BLACHFORD': 0,
    'BLACHLY': 0,
    'BLACHMAN': 0,
    'BLACHOWICZ': 0,
    'BLACHOWSKI': 0,
    'BLACK': 0,
    'BLACKABY': 0,
    'BLACKADAR': 0,
    'BLACKALL': 0,
    'BLACKARD': 0,
    'BLACKBEAR': 0,
    'BLACKBIRD': 0,
    'BLACKBOURN': 0,
    'BLACKBURN': 0,
    'BLACKBURNE': 0,
    'BLACKDEER': 0,
    'BLACKE': 0,
    'BLACKEAGLE': 0,
    'BLACKELK': 0,
    'BLACKEN': 0,
    'BLACKER': 0,
    'BLACKERBY': 0,
    'BLACKERT': 0,
    'BLACKETER': 0,
    'BLACKETT': 0,
    'BLACKETTER': 0,
    'BLACKEY': 0,
    'BLACKFORD': 0,
    'BLACKFOX': 0,
    'BLACKGOAT': 0,
    'BLACKHALL': 0,
    'BLACKHAM': 0,
    'BLACKHAWK': 0,
    'BLACKHORSE': 0,
    'BLACKHURST': 0,
    'BLACKIE': 0,
    'BLACKINGTON': 0,
    'BLACKINTON': 0,
    'BLACKISTON': 0,
    'BLACKKETTER': 0,
    'BLACKLEDGE': 0,
    'BLACKLER': 0,
    'BLACKLEY': 0,
    'BLACKLIDGE': 0,
    'BLACKLOCK': 0,
    'BLACKMAN': 0,
    'BLACKMAR': 0,
    'BLACKMER': 0,
    'BLACKMON': 0,
    'BLACKMOND': 0,
    'BLACKMORE': 0,
    'BLACKMUN': 0,
    'BLACKNALL': 0,
    'BLACKNELL': 0,
    'BLACKNER': 0,
    'BLACKNEY': 0,
    'BLACKORBY': 0,
    'BLACKS': 0,
    'BLACKSHAW': 0,
    'BLACKSHEAR': 0,
    'BLACKSHER': 0,
    'BLACKSHERE': 0,
    'BLACKSHIRE': 0,
    'BLACKSMITH': 0,
    'BLACKSON': 0,
    'BLACKSTAD': 0,
    'BLACKSTEN': 0,
    'BLACKSTOCK': 0,
    'BLACKSTON': 0,
    'BLACKSTONE': 0,
    'BLACKTON': 0,
    'BLACKWATER': 0,
    'BLACKWELDER': 0,
    'BLACKWELL': 0,
    'BLACKWILL': 0,
    'BLACKWOLF': 0,
    'BLACKWOOD': 0,
    'BLAD': 0,
    'BLADA': 0,
    'BLADE': 0,
    'BLADECKI': 0,
    'BLADEK': 0,
    'BLADEL': 0,
    'BLADEN': 0,
    'BLADER': 0,
    'BLADES': 0,
    'BLADO': 0,
    'BLADOW': 0,
    'BLADT': 0,
    'BLADY': 0,
    'BLAES': 0,
    'BLAESER': 0,
    'BLAESING': 0,
    'BLAESS': 0,
    'BLAGA': 0,
    'BLAGBURN': 0,
    'BLAGDEN': 0,
    'BLAGDON': 0,
    'BLAGG': 0,
    'BLAGMON': 0,
    'BLAGOJEVIC': 0,
    'BLAGRAVE': 0,
    'BLAGROVE': 0,
    'BLAHA': 0,
    'BLAHNIK': 0,
    'BLAHO': 0,
    'BLAHUT': 0,
    'BLAHUTA': 0,
    'BLAICH': 0,
    'BLAIES': 0,
    'BLAIKIE': 0,
    'BLAILOCK': 0,
    'BLAIN': 0,
    'BLAINE': 0.8685581933989577,
    'BLAIR': 0.31823745410036725,
    'BLAIRE': 0,
    'BLAIS': 0,
    'BLAISDELL': 0,
    'BLAISE': 0,
    'BLAISING': 0,
    'BLAISURE': 0,
    'BLAIZE': 0,
    'BLAKE': 0.5902999361837906,
    'BLAKELEY': 0,
    'BLAKELOCK': 0,
    'BLAKELY': 0,
    'BLAKEMAN': 0,
    'BLAKEMORE': 0,
    'BLAKENEY': 0,
    'BLAKENSHIP': 0,
    'BLAKER': 0,
    'BLAKES': 0,
    'BLAKESLEE': 0,
    'BLAKESLEY': 0,
    'BLAKEWAY': 0,
    'BLAKEWOOD': 0,
    'BLAKEY': 0,
    'BLAKLEY': 0,
    'BLAKNEY': 0,
    'BLAKSLEE': 0,
    'BLALACK': 0,
    'BLALARK': 0,
    'BLALOCK': 0,
    'BLAMBLE': 0,
    'BLAMER': 0,
    'BLAMEY': 0,
    'BLAMIRES': 0,
    'BLAN': 0,
    'BLANAR': 0,
    'BLANAS': 0,
    'BLANC': 0,
    'BLANCA': 0.9956289460903351,
    'BLANCAFLOR': 0,
    'BLANCARTE': 0,
    'BLANCAS': 0,
    'BLANCATO': 0,
    'BLANCETT': 0,
    'BLANCH': 0.8791208791208792,
    'BLANCHAR': 0,
    'BLANCHARD': 0,
    'BLANCHAT': 0,
    'BLANCHE': 0.9922424679776294,
    'BLANCHER': 0,
    'BLANCHET': 0,
    'BLANCHETT': 0,
    'BLANCHETTE': 0,
    'BLANCHFIELD': 0,
    'BLANCK': 0,
    'BLANCKE': 0,
    'BLANCO': 0,
    'BLAND': 0,
    'BLANDA': 0,
    'BLANDEN': 0,
    'BLANDER': 0,
    'BLANDFORD': 0,
    'BLANDI': 0,
    'BLANDIN': 0,
    'BLANDING': 0,
    'BLANDINO': 0,
    'BLANDO': 0,
    'BLANDON': 0,
    'BLANDY': 0,
    'BLANE': 0,
    'BLANER': 0,
    'BLANEY': 0,
    'BLANFORD': 0,
    'BLANGO': 0,
    'BLANK': 0,
    'BLANKE': 0,
    'BLANKEMEYER': 0,
    'BLANKEN': 0,
    'BLANKENBAKER': 0,
    'BLANKENBECKLER': 0,
    'BLANKENBEKER': 0,
    'BLANKENBERG': 0,
    'BLANKENBERGER': 0,
    'BLANKENBILLER': 0,
    'BLANKENBURG': 0,
    'BLANKENFELD': 0,
    'BLANKENHEIM': 0,
    'BLANKENHORN': 0,
    'BLANKENSHIP': 0,
    'BLANKENSTEIN': 0,
    'BLANKER': 0,
    'BLANKERS': 0,
    'BLANKESPOOR': 0,
    'BLANKINSHIP': 0,
    'BLANKLEY': 0,
    'BLANKMAN': 0,
    'BLANKS': 0,
    'BLANKSHIP': 0,
    'BLANKSON': 0,
    'BLANKSTEIN': 0,
    'BLANN': 0,
    'BLANNER': 0,
    'BLANSCET': 0,
    'BLANSET': 0,
    'BLANSETT': 0,
    'BLANSFIELD': 0,
    'BLANSHAN': 0,
    'BLANSIT': 0,
    'BLANSON': 0,
    'BLANTON': 0,
    'BLANTZ': 0,
    'BLANZ': 0,
    'BLANZY': 0,
    'BLAQUIERE': 0,
    'BLARE': 0,
    'BLAS': 0,
    'BLASBERG': 0,
    'BLASCAK': 0,
    'BLASCH': 0,
    'BLASCHAK': 0,
    'BLASCHKA': 0,
    'BLASCHKE': 0,
    'BLASCHKO': 0,
    'BLASCO': 0,
    'BLASCZYK': 0,
    'BLASDEL': 0,
    'BLASDELL': 0,
    'BLASE': 0,
    'BLASEN': 0,
    'BLASER': 0,
    'BLASETTI': 0,
    'BLASEY': 0,
    'BLASH': 0,
    'BLASHILL': 0,
    'BLASHKA': 0,
    'BLASI': 0,
    'BLASIAK': 0,
    'BLASIER': 0,
    'BLASIMAN': 0,
    'BLASING': 0,
    'BLASINGAME': 0,
    'BLASINGIM': 0,
    'BLASINI': 0,
    'BLASIO': 0,
    'BLASIOLI': 0,
    'BLASIUS': 0,
    'BLASK': 0,
    'BLASKA': 0,
    'BLASKE': 0,
    'BLASKEY': 0,
    'BLASKI': 0,
    'BLASKIE': 0,
    'BLASKO': 0,
    'BLASKOVICH': 0,
    'BLASKOWSKI': 0,
    'BLASKY': 0,
    'BLASQUEZ': 0,
    'BLASS': 0,
    'BLASSER': 0,
    'BLASSINGAME': 0,
    'BLASUCCI': 0,
    'BLASY': 0,
    'BLASZAK': 0,
    'BLASZCZAK': 0,
    'BLASZCZYK': 0,
    'BLASZKIEWICZ': 0,
    'BLASZKOWSKI': 0,
    'BLASZYK': 0,
    'BLATCH': 0,
    'BLATCHER': 0,
    'BLATCHFORD': 0,
    'BLATCHLEY': 0,
    'BLATE': 0,
    'BLATHERS': 0,
    'BLATNER': 0,
    'BLATNICK': 0,
    'BLATNIK': 0,
    'BLATON': 0,
    'BLATT': 0,
    'BLATTEL': 0,
    'BLATTENBERGER': 0,
    'BLATTER': 0,
    'BLATTI': 0,
    'BLATTLER': 0,
    'BLATTMAN': 0,
    'BLATTNER': 0,
    'BLATZ': 0,
    'BLAU': 0,
    'BLAUBACH': 0,
    'BLAUCH': 0,
    'BLAUE': 0,
    'BLAUER': 0,
    'BLAUERT': 0,
    'BLAUFUSS': 0,
    'BLAUL': 0,
    'BLAUM': 0,
    'BLAUNER': 0,
    'BLAUROCK': 0,
    'BLAUSER': 0,
    'BLAUSEY': 0,
    'BLAUSTEIN': 0,
    'BLAUT': 0,
    'BLAUTH': 0,
    'BLAUVELT': 0,
    'BLAUW': 0,
    'BLAUWKAMP': 0,
    'BLAWAT': 0,
    'BLAXTON': 0,
    'BLAY': 0,
    'BLAYDES': 0,
    'BLAYER': 0,
    'BLAYLOCK': 0,
    'BLAYNEY': 0,
    'BLAZ': 0,
    'BLAZAK': 0,
    'BLAZE': 0,
    'BLAZEJAK': 0,
    'BLAZEJEWSKI': 0,
    'BLAZEK': 0,
    'BLAZER': 0,
    'BLAZEVIC': 0,
    'BLAZEVICH': 0,
    'BLAZEWICZ': 0,
    'BLAZEY': 0,
    'BLAZI': 0,
    'BLAZIC': 0,
    'BLAZICH': 0,
    'BLAZICK': 0,
    'BLAZIER': 0,
    'BLAZINA': 0,
    'BLAZO': 0,
    'BLAZON': 0,
    'BLAZQUEZ': 0,
    'BLEA': 0,
    'BLEACH': 0,
    'BLEACHER': 0,
    'BLEAK': 0,
    'BLEAKLEY': 0,
    'BLEAKNEY': 0,
    'BLEAM': 0,
    'BLEAN': 0,
    'BLEASDALE': 0,
    'BLEASE': 0,
    'BLEAU': 0,
    'BLEAZARD': 0,
    'BLECH': 0,
    'BLECHA': 0,
    'BLECHER': 0,
    'BLECHINGER': 0,
    'BLECHLE': 0,
    'BLECHMAN': 0,
    'BLECHNER': 0,
    'BLECHSCHMIDT': 0,
    'BLECK': 0,
    'BLECKE': 0,
    'BLECKER': 0,
    'BLECKLEY': 0,
    'BLECKMAN': 0,
    'BLEDSAW': 0,
    'BLEDSOE': 0,
    'BLEDSOLE': 0,
    'BLEE': 0,
    'BLEECHER': 0,
    'BLEECKER': 0,
    'BLEEKE': 0,
    'BLEEKER': 0,
    'BLEEM': 0,
    'BLEEMEL': 0,
    'BLEES': 0,
    'BLEESS': 0,
    'BLEGEN': 0,
    'BLEGGI': 0,
    'BLEHM': 0,
    'BLEI': 0,
    'BLEIBERG': 0,
    'BLEICH': 0,
    'BLEICHER': 0,
    'BLEICHNER': 0,
    'BLEICK': 0,
    'BLEIER': 0,
    'BLEIGH': 0,
    'BLEIL': 0,
    'BLEILE': 0,
    'BLEILER': 0,
    'BLEISCH': 0,
    'BLEISTEIN': 0,
    'BLEIWEISS': 0,
    'BLEKE': 0,
    'BLEM': 0,
    'BLEMKER': 0,
    'BLENCOWE': 0,
    'BLEND': 0,
    'BLENDEN': 0,
    'BLENDER': 0,
    'BLENDOWSKI': 0,
    'BLENIS': 0,
    'BLENK': 0,
    'BLENKER': 0,
    'BLENKHORN': 0,
    'BLENKUSH': 0,
    'BLENMAN': 0,
    'BLENNER': 0,
    'BLES': 0,
    'BLESCH': 0,
    'BLESENER': 0,
    'BLESER': 0,
    'BLESH': 0,
    'BLESI': 0,
    'BLESKE': 0,
    'BLESS': 0,
    'BLESSE': 0,
    'BLESSEN': 0,
    'BLESSETT': 0,
    'BLESSING': 0,
    'BLESSINGER': 0,
    'BLESSINGTON': 0,
    'BLESSITT': 0,
    'BLESSMAN': 0,
    'BLESSUM': 0,
    'BLEST': 0,
    'BLETCHER': 0,
    'BLETH': 0,
    'BLETHEN': 0,
    'BLETSCH': 0,
    'BLETZ': 0,
    'BLEUEL': 0,
    'BLEUER': 0,
    'BLEVENS': 0,
    'BLEVIN': 0,
    'BLEVINS': 0,
    'BLEW': 0,
    'BLEWER': 0,
    'BLEWETT': 0,
    'BLEWITT': 0,
    'BLEWS': 0,
    'BLEY': 0,
    'BLEYENBERG': 0,
    'BLEYER': 0,
    'BLEYL': 0,
    'BLEYLE': 0,
    'BLEYTHING': 0,
    'BLICE': 0,
    'BLICHARZ': 0,
    'BLICK': 0,
    'BLICKENSDERFER': 0,
    'BLICKENSTAFF': 0,
    'BLICKHAN': 0,
    'BLICKLE': 0,
    'BLICKLEY': 0,
    'BLIDE': 0,
    'BLIEK': 0,
    'BLIEMEISTER': 0,
    'BLIER': 0,
    'BLIESE': 0,
    'BLIESENER': 0,
    'BLIESNER': 0,
    'BLIETZ': 0,
    'BLIGE': 0,
    'BLIGEN': 0,
    'BLIGH': 0,
    'BLIGHT': 0,
    'BLILER': 0,
    'BLILEY': 0,
    'BLILIE': 0,
    'BLIM': 0,
    'BLIMLINE': 0,
    'BLINCO': 0,
    'BLINCOE': 0,
    'BLIND': 0,
    'BLINDAUER': 0,
    'BLINDER': 0,
    'BLINDERMAN': 0,
    'BLINDT': 0,
    'BLINE': 0,
    'BLINK': 0,
    'BLINKA': 0,
    'BLINKHORN': 0,
    'BLINN': 0,
    'BLINSON': 0,
    'BLINSTRUB': 0,
    'BLINT': 0,
    'BLINZLER': 0,
    'BLISARD': 0,
    'BLISH': 0,
    'BLISS': 0,
    'BLISSARD': 0,
    'BLISSENBACH': 0,
    'BLISSETT': 0,
    'BLISSIT': 0,
    'BLISSITT': 0,
    'BLITCH': 0,
    'BLITCHINGTON': 0,
    'BLITHE': 0,
    'BLITON': 0,
    'BLITSTEIN': 0,
    'BLITZ': 0,
    'BLITZER': 0,
    'BLIVEN': 0,
    'BLIX': 0,
    'BLIXT': 0,
    'BLIZARD': 0,
    'BLIZMAN': 0,
    'BLIZZARD': 0,
    'BLOBAUM': 0,
    'BLOCH': 0,
    'BLOCHER': 0,
    'BLOCHLINGER': 0,
    'BLOCK': 0,
    'BLOCKER': 0,
    'BLOCKETT': 0,
    'BLOCKHUS': 0,
    'BLOCKINGER': 0,
    'BLOCKMON': 0,
    'BLOCKSOM': 0,
    'BLOCKSON': 0,
    'BLOCKTON': 0,
    'BLOCZYNSKI': 0,
    'BLODGET': 0,
    'BLODGETT': 0,
    'BLOEBAUM': 0,
    'BLOECHER': 0,
    'BLOECHL': 0,
    'BLOEDE': 0,
    'BLOEDEL': 0,
    'BLOEDORN': 0,
    'BLOEDOW': 0,
    'BLOEM': 0,
    'BLOEMENDAAL': 0,
    'BLOEMER': 0,
    'BLOEMERS': 0,
    'BLOEMKE': 0,
    'BLOEMKER': 0,
    'BLOESCH': 0,
    'BLOESER': 0,
    'BLOGG': 0,
    'BLOHM': 0,
    'BLOHOWIAK': 0,
    'BLOINK': 0,
    'BLOIS': 0,
    'BLOISE': 0,
    'BLOK': 0,
    'BLOKER': 0,
    'BLOKZYL': 0,
    'BLOM': 0,
    'BLOMBERG': 0,
    'BLOMDAHL': 0,
    'BLOME': 0,
    'BLOMEKE': 0,
    'BLOMELEY': 0,
    'BLOMENKAMP': 0,
    'BLOMER': 0,
    'BLOMGREN': 0,
    'BLOMKER': 0,
    'BLOMME': 0,
    'BLOMMEL': 0,
    'BLOMMER': 0,
    'BLOMQUIST': 0,
    'BLOMS': 0,
    'BLOMSTEDT': 0,
    'BLOMSTER': 0,
    'BLOMSTROM': 0,
    'BLON': 0,
    'BLOND': 0,
    'BLONDE': 0,
    'BLONDEAU': 0,
    'BLONDELL': 0.8620689655172414,
    'BLONDER': 0,
    'BLONDET': 0,
    'BLONDHEIM': 0,
    'BLONDIN': 0,
    'BLONDO': 0,
    'BLONG': 0,
    'BLONIARZ': 0,
    'BLONIGEN': 0,
    'BLONQUIST': 0,
    'BLONSHINE': 0,
    'BLONSKI': 0,
    'BLONSKY': 0,
    'BLOOD': 0,
    'BLOODGOOD': 0,
    'BLOODSAW': 0,
    'BLOODSWORTH': 0,
    'BLOODWORTH': 0,
    'BLOOM': 0,
    'BLOOMBERG': 0,
    'BLOOME': 0,
    'BLOOMER': 0,
    'BLOOMFIELD': 0,
    'BLOOMGARDEN': 0,
    'BLOOMGREN': 0,
    'BLOOMINGBURG': 0,
    'BLOOMINGDALE': 0,
    'BLOOMQUIST': 0,
    'BLOOMSTROM': 0,
    'BLOOR': 0,
    'BLORE': 0,
    'BLOSCH': 0,
    'BLOSE': 0,
    'BLOSER': 0,
    'BLOSS': 0,
    'BLOSSER': 0,
    'BLOSSEY': 0,
    'BLOSSMAN': 0,
    'BLOSSOM': 0.5988023952095809,
    'BLOT': 0,
    'BLOTKAMP': 0,
    'BLOTNER': 0,
    'BLOTSKY': 0,
    'BLOTT': 0,
    'BLOTTER': 0,
    'BLOTZ': 0,
    'BLOTZER': 0,
    'BLOUCH': 0,
    'BLOUGH': 0,
    'BLOUIN': 0,
    'BLOUIR': 0,
    'BLOUNT': 0,
    'BLOUSE': 0,
    'BLOUT': 0,
    'BLOW': 0,
    'BLOWE': 0,
    'BLOWER': 0,
    'BLOWERS': 0,
    'BLOWN': 0,
    'BLOXHAM': 0,
    'BLOXOM': 0,
    'BLOXSOM': 0,
    'BLOXSON': 0,
    'BLOXTON': 0,
    'BLOY': 0,
    'BLOYD': 0,
    'BLOYED': 0,
    'BLOYER': 0,
    'BLUBAUGH': 0,
    'BLUCHER': 0,
    'BLUCK': 0,
    'BLUCKER': 0,
    'BLUDAU': 0,
    'BLUDSWORTH': 0,
    'BLUDWORTH': 0,
    'BLUE': 0,
    'BLUEBIRD': 0,
    'BLUEDORN': 0,
    'BLUEEYES': 0,
    'BLUEFORD': 0,
    'BLUEITT': 0,
    'BLUEL': 0,
    'BLUEM': 0,
    'BLUEMEL': 0,
    'BLUEMER': 0,
    'BLUEMKE': 0,
    'BLUESTEIN': 0,
    'BLUESTONE': 0,
    'BLUETT': 0,
    'BLUFF': 0,
    'BLUFORD': 0,
    'BLUHM': 0,
    'BLUITT': 0,
    'BLUM': 0,
    'BLUMA': 0,
    'BLUMAN': 0,
    'BLUMBERG': 0,
    'BLUME': 0,
    'BLUMEL': 0,
    'BLUMEN': 0,
    'BLUMENAUER': 0,
    'BLUMENBERG': 0,
    'BLUMENFELD': 0,
    'BLUMENKRANTZ': 0,
    'BLUMENSCHEIN': 0,
    'BLUMENSHINE': 0,
    'BLUMENSTEIN': 0,
    'BLUMENSTOCK': 0,
    'BLUMENTHAL': 0,
    'BLUMENTRITT': 0,
    'BLUMER': 0,
    'BLUMETTI': 0,
    'BLUMEYER': 0,
    'BLUMHAGEN': 0,
    'BLUMHARDT': 0,
    'BLUMHORST': 0,
    'BLUMKE': 0,
    'BLUMKIN': 0,
    'BLUML': 0,
    'BLUMLING': 0,
    'BLUMM': 0,
    'BLUMMER': 0,
    'BLUMREICH': 0,
    'BLUMSTEIN': 0,
    'BLUNCK': 0,
    'BLUNDELL': 0,
    'BLUNDEN': 0,
    'BLUNDO': 0,
    'BLUNDON': 0,
    'BLUNDY': 0,
    'BLUNIER': 0,
    'BLUNK': 0,
    'BLUNKALL': 0,
    'BLUNT': 0,
    'BLUNTSON': 0,
    'BLURTON': 0,
    'BLUSH': 0,
    'BLUSKE': 0,
    'BLUST': 0,
    'BLUSTEIN': 0,
    'BLUTCHER': 0,
    'BLUTE': 0,
    'BLUTH': 0,
    'BLUTHARDT': 0,
    'BLUTO': 0,
    'BLY': 0,
    'BLYDEN': 0,
    'BLYDENBURGH': 0,
    'BLYE': 0,
    'BLYER': 0,
    'BLYLER': 0,
    'BLYMILLER': 0,
    'BLYMIRE': 0,
    'BLYMYER': 0,
    'BLYNN': 0,
    'BLYSKAL': 0,
    'BLYSTONE': 0,
    'BLYTH': 0,
    'BLYTHE': 0.4081632653061225,
    'BLYTHER': 0,
    'BO': 0.9380863039399625,
    'BOA': 0,
    'BOADA': 0,
    'BOADO': 0,
    'BOADU': 0,
    'BOADWAY': 0,
    'BOAG': 0,
    'BOAGNI': 0,
    'BOAK': 0,
    'BOAKYE': 0,
    'BOAL': 0,
    'BOALES': 0,
    'BOALS': 0,
    'BOAM': 0,
    'BOAMAH': 0,
    'BOAN': 0,
    'BOARD': 0,
    'BOARDLEY': 0,
    'BOARDMAN': 0,
    'BOARDS': 0,
    'BOARDWAY': 0,
    'BOARDWINE': 0,
    'BOARMAN': 0,
    'BOARTS': 0,
    'BOAS': 0,
    'BOASE': 0,
    'BOAST': 0,
    'BOAT': 0,
    'BOATENG': 0,
    'BOATFIELD': 0,
    'BOATMAN': 0,
    'BOATNER': 0,
    'BOATRIGHT': 0,
    'BOATSWAIN': 0,
    'BOATWRIGHT': 0,
    'BOAZ': 0,
    'BOAZE': 0,
    'BOAZMAN': 0,
    'BOB': 0.991705733862243,
    'BOBA': 0,
    'BOBACK': 0,
    'BOBADILLA': 0,
    'BOBAK': 0,
    'BOBAL': 0,
    'BOBALIK': 0,
    'BOBAN': 0,
    'BOBAR': 0,
    'BOBAY': 0,
    'BOBB': 0,
    'BOBBA': 0,
    'BOBBE': 0,
    'BOBBER': 0,
    'BOBBERT': 0,
    'BOBBETT': 0,
    'BOBBI': 1,
    'BOBBIE': 0.9986684420772304,
    'BOBBIN': 0,
    'BOBBINS': 0,
    'BOBBIT': 0,
    'BOBBITT': 0,
    'BOBBS': 0,
    'BOBBY': 0.9984439834024896,
    'BOBBYE': 1,
    'BOBE': 0,
    'BOBECK': 0,
    'BOBEK': 0,
    'BOBEL': 0,
    'BOBELU': 0,
    'BOBEN': 0,
    'BOBENRIETH': 0,
    'BOBER': 0,
    'BOBERG': 0,
    'BOBET': 0,
    'BOBETTE': 1,
    'BOBHOLZ': 0,
    'BOBIAN': 0,
    'BOBIC': 0,
    'BOBICH': 0,
    'BOBICK': 0,
    'BOBIER': 0,
    'BOBIK': 0,
    'BOBIN': 0,
    'BOBINGER': 0,
    'BOBINO': 0,
    'BOBINSKI': 0,
    'BOBIS': 0,
    'BOBISH': 0,
    'BOBKA': 0,
    'BOBKO': 0,
    'BOBLETT': 0,
    'BOBLITT': 0,
    'BOBLITZ': 0,
    'BOBO': 0,
    'BOBOLA': 0,
    'BOBOWICZ': 0,
    'BOBOWSKI': 0,
    'BOBRICK': 0,
    'BOBROFF': 0,
    'BOBROW': 0,
    'BOBROWICZ': 0,
    'BOBROWSKI': 0,
    'BOBROWSKY': 0,
    'BOBSON': 0,
    'BOBST': 0,
    'BOBULA': 0,
    'BOBZIEN': 0,
    'BOBZIN': 0,
    'BOC': 0,
    'BOCA': 0,
    'BOCAGE': 0,
    'BOCAN': 0,
    'BOCANEGRA': 0,
    'BOCARDO': 0,
    'BOCASH': 0,
    'BOCCA': 0,
    'BOCCABELLA': 0,
    'BOCCACCIO': 0,
    'BOCCANFUSO': 0,
    'BOCCARD': 0,
    'BOCCARDI': 0,
    'BOCCARDO': 0,
    'BOCCELLA': 0,
    'BOCCELLI': 0,
    'BOCCHETTI': 0,
    'BOCCHI': 0,
    'BOCCHICCHIO': 0,
    'BOCCHIERI': 0,
    'BOCCHINI': 0,
    'BOCCHINO': 0,
    'BOCCI': 0,
    'BOCCIA': 0,
    'BOCCIO': 0,
    'BOCCO': 0,
    'BOCCUTI': 0,
    'BOCCUZZI': 0,
    'BOCEK': 0,
    'BOCH': 0,
    'BOCHANTIN': 0,
    'BOCHART': 0,
    'BOCHAT': 0,
    'BOCHE': 0,
    'BOCHENEK': 0,
    'BOCHENSKI': 0,
    'BOCHER': 0,
    'BOCHERT': 0,
    'BOCHETTE': 0,
    'BOCHICCHIO': 0,
    'BOCHINSKI': 0,
    'BOCHMAN': 0,
    'BOCHMANN': 0,
    'BOCHNAK': 0,
    'BOCHNER': 0,
    'BOCHNIAK': 0,
    'BOCHSLER': 0,
    'BOCIAN': 0,
    'BOCK': 0,
    'BOCKBRADER': 0,
    'BOCKELMAN': 0,
    'BOCKELMANN': 0,
    'BOCKENSTEDT': 0,
    'BOCKER': 0,
    'BOCKERT': 0,
    'BOCKES': 0,
    'BOCKEY': 0,
    'BOCKHEIM': 0,
    'BOCKHOLD': 0,
    'BOCKHOLT': 0,
    'BOCKHOP': 0,
    'BOCKHORN': 0,
    'BOCKHORST': 0,
    'BOCKIUS': 0,
    'BOCKLAGE': 0,
    'BOCKMAN': 0,
    'BOCKMANN': 0,
    'BOCKMON': 0,
    'BOCKO': 0,
    'BOCKOVEN': 0,
    'BOCKOVER': 0,
    'BOCKRATH': 0,
    'BOCKS': 0,
    'BOCKSNICK': 0,
    'BOCKSTAHLER': 0,
    'BOCKTING': 0,
    'BOCKUS': 0,
    'BOCKWOLDT': 0,
    'BOCLAIR': 0,
    'BOCOCK': 0,
    'BOCOOK': 0,
    'BOCOX': 0,
    'BOCTOR': 0,
    'BOCZAR': 0,
    'BOCZEK': 0,
    'BOCZKOWSKI': 0,
    'BOCZON': 0,
    'BODA': 0,
    'BODAH': 0,
    'BODAK': 0,
    'BODAMER': 0,
    'BODAN': 0,
    'BODART': 0,
    'BODARY': 0,
    'BODAS': 0,
    'BODAY': 0,
    'BODDE': 0,
    'BODDEN': 0,
    'BODDICKER': 0,
    'BODDIE': 0,
    'BODDY': 0,
    'BODE': 0,
    'BODEAU': 0,
    'BODECKER': 0,
    'BODEEN': 0,
    'BODEK': 0,
    'BODEKER': 0,
    'BODELL': 0,
    'BODEM': 0,
    'BODEMAN': 0,
    'BODEMANN': 0,
    'BODEMER': 0,
    'BODEN': 0,
    'BODENBACH': 0,
    'BODENBENDER': 0,
    'BODENDORFER': 0,
    'BODENHAMER': 0,
    'BODENHEIMER': 0,
    'BODENHORN': 0,
    'BODENMILLER': 0,
    'BODENSCHATZ': 0,
    'BODENSTAB': 0,
    'BODENSTEIN': 0,
    'BODENSTEINER': 0,
    'BODER': 0,
    'BODET': 0,
    'BODETTE': 0,
    'BODEY': 0,
    'BODFIELD': 0,
    'BODFISH': 0,
    'BODFORD': 0,
    'BODGE': 0,
    'BODGER': 0,
    'BODHAINE': 0,
    'BODI': 0,
    'BODICK': 0,
    'BODIE': 0,
    'BODIEN': 0,
    'BODIFORD': 0,
    'BODIKER': 0,
    'BODILY': 0,
    'BODIN': 0,
    'BODINE': 0,
    'BODIS': 0,
    'BODISH': 0,
    'BODISON': 0,
    'BODKER': 0,
    'BODKIN': 0,
    'BODKINS': 0,
    'BODLE': 0,
    'BODLEY': 0,
    'BODMAN': 0,
    'BODMER': 0,
    'BODNAR': 0,
    'BODNARCHUK': 0,
    'BODNER': 0,
    'BODO': 0,
    'BODOH': 0,
    'BODON': 0,
    'BODOR': 0,
    'BODRERO': 0,
    'BODREY': 0,
    'BODRICK': 0,
    'BODRIE': 0,
    'BODSFORD': 0,
    'BODTKE': 0,
    'BODTMANN': 0,
    'BODUCH': 0,
    'BODURTHA': 0,
    'BODWAY': 0,
    'BODWELL': 0,
    'BODWIN': 0,
    'BODY': 0,
    'BODZIAK': 0,
    'BODZIN': 0,
    'BODZIONY': 0,
    'BOE': 0,
    'BOEBEL': 0,
    'BOECHER': 0,
    'BOECHLER': 0,
    'BOECK': 0,
    'BOECKEL': 0,
    'BOECKENSTEDT': 0,
    'BOECKER': 0,
    'BOECKERMANN': 0,
    'BOECKHOLT': 0,
    'BOECKMAN': 0,
    'BOECKMANN': 0,
    'BOECKNER': 0,
    'BOEDDEKER': 0,
    'BOEDECKER': 0,
    'BOEDEKER': 0,
    'BOEDER': 0,
    'BOEDICKER': 0,
    'BOEDIGHEIMER': 0,
    'BOEDING': 0,
    'BOEGE': 0,
    'BOEGEL': 0,
    'BOEGEMAN': 0,
    'BOEGER': 0,
    'BOEGGEMAN': 0,
    'BOEGLER': 0,
    'BOEGLI': 0,
    'BOEGLIN': 0,
    'BOEGNER': 0,
    'BOEH': 0,
    'BOEHL': 0,
    'BOEHLE': 0,
    'BOEHLER': 0,
    'BOEHLERT': 0,
    'BOEHLING': 0,
    'BOEHLKE': 0,
    'BOEHM': 0,
    'BOEHMAN': 0,
    'BOEHME': 0,
    'BOEHMER': 0,
    'BOEHMKE': 0,
    'BOEHMLER': 0,
    'BOEHMS': 0,
    'BOEHN': 0,
    'BOEHNE': 0,
    'BOEHNEN': 0,
    'BOEHNER': 0,
    'BOEHNING': 0,
    'BOEHNKE': 0,
    'BOEHNLEIN': 0,
    'BOEHR': 0,
    'BOEHRER': 0,
    'BOEHRINGER': 0,
    'BOEHS': 0,
    'BOEING': 0,
    'BOEK': 0,
    'BOEKE': 0,
    'BOEKELOO': 0,
    'BOEKER': 0,
    'BOEKHOFF': 0,
    'BOEKHOUT': 0,
    'BOEL': 0,
    'BOELDT': 0,
    'BOELENS': 0,
    'BOELK': 0,
    'BOELKE': 0,
    'BOELL': 0,
    'BOELMAN': 0,
    'BOELTE': 0,
    'BOELTER': 0,
    'BOEMER': 0,
    'BOEN': 0,
    'BOENDER': 0,
    'BOENIG': 0,
    'BOENING': 0,
    'BOENISCH': 0,
    'BOENKER': 0,
    'BOENSCH': 0,
    'BOEPPLE': 0,
    'BOER': 0,
    'BOERBOOM': 0,
    'BOERCKEL': 0,
    'BOEREMA': 0,
    'BOERGER': 0,
    'BOERI': 0,
    'BOERIO': 0,
    'BOERJAN': 0,
    'BOERMA': 0,
    'BOERMAN': 0,
    'BOERNER': 0,
    'BOERO': 0,
    'BOERS': 0,
    'BOERSEMA': 0,
    'BOERSEN': 0,
    'BOERSMA': 0,
    'BOERST': 0,
    'BOERSTLER': 0,
    'BOERUM': 0,
    'BOES': 0,
    'BOESCH': 0,
    'BOESCHE': 0,
    'BOESCHEN': 0,
    'BOESE': 0,
    'BOESEL': 0,
    'BOESEN': 0,
    'BOESENBERG': 0,
    'BOESER': 0,
    'BOESHANS': 0,
    'BOESHART': 0,
    'BOESHORE': 0,
    'BOESIGER': 0,
    'BOESKOOL': 0,
    'BOESL': 0,
    'BOESPFLUG': 0,
    'BOESSEN': 0,
    'BOESTER': 0,
    'BOETCHER': 0,
    'BOETEL': 0,
    'BOETGER': 0,
    'BOETTCHER': 0,
    'BOETTGER': 0,
    'BOETTICHER': 0,
    'BOETTIGER': 0,
    'BOETTINGER': 0,
    'BOETTLER': 0,
    'BOETTNER': 0,
    'BOEVE': 0,
    'BOEVER': 0,
    'BOEVERS': 0,
    'BOEVING': 0,
    'BOEY': 0,
    'BOFENKAMP': 0,
    'BOFF': 0,
    'BOFFA': 0,
    'BOFFI': 0,
    'BOFFMAN': 0,
    'BOFFO': 0,
    'BOFILL': 0,
    'BOFINGER': 0,
    'BOGA': 0,
    'BOGAARD': 0,
    'BOGACKI': 0,
    'BOGACZ': 0,
    'BOGACZYK': 0,
    'BOGAERT': 0,
    'BOGALE': 0,
    'BOGAN': 0,
    'BOGANS': 0,
    'BOGANY': 0,
    'BOGAR': 0,
    'BOGARD': 0,
    'BOGARDUS': 0,
    'BOGARIN': 0,
    'BOGART': 0,
    'BOGASH': 0,
    'BOGASKI': 0,
    'BOGATAY': 0,
    'BOGATZ': 0,
    'BOGDA': 0,
    'BOGDAN': 0,
    'BOGDANICH': 0,
    'BOGDANOFF': 0,
    'BOGDANOV': 0,
    'BOGDANOVIC': 0,
    'BOGDANOVICH': 0,
    'BOGDANOWICZ': 0,
    'BOGDANSKI': 0,
    'BOGDEN': 0,
    'BOGDON': 0,
    'BOGDONOFF': 0,
    'BOGE': 0,
    'BOGEDAIN': 0,
    'BOGEL': 0,
    'BOGEMA': 0,
    'BOGEN': 0,
    'BOGENHAGEN': 0,
    'BOGENREIF': 0,
    'BOGENRIEF': 0,
    'BOGENSCHUTZ': 0,
    'BOGER': 0,
    'BOGERS': 0,
    'BOGERT': 0,
    'BOGETTI': 0,
    'BOGG': 0,
    'BOGGAN': 0,
    'BOGGES': 0,
    'BOGGESS': 0,
    'BOGGI': 0,
    'BOGGIA': 0,
    'BOGGIANO': 0,
    'BOGGIE': 0,
    'BOGGIO': 0,
    'BOGGIS': 0,
    'BOGGS': 0,
    'BOGGUS': 0,
    'BOGH': 0,
    'BOGHOSIAN': 0,
    'BOGHOSSIAN': 0,
    'BOGIE': 0,
    'BOGIN': 0,
    'BOGLE': 0,
    'BOGLER': 0,
    'BOGLEY': 0,
    'BOGLIN': 0,
    'BOGLIOLI': 0,
    'BOGNANNO': 0,
    'BOGNAR': 0,
    'BOGNER': 0,
    'BOGNOT': 0,
    'BOGO': 0,
    'BOGOLIN': 0,
    'BOGORAD': 0,
    'BOGOS': 0,
    'BOGOSIAN': 0,
    'BOGOVICH': 0,
    'BOGRAD': 0,
    'BOGRAN': 0,
    'BOGREN': 0,
    'BOGS': 0,
    'BOGUCKI': 0,
    'BOGUE': 0,
    'BOGUES': 0,
    'BOGUMIL': 0,
    'BOGUS': 0,
    'BOGUSCH': 0,
    'BOGUSH': 0,
    'BOGUSKI': 0,
    'BOGUSKY': 0,
    'BOGUSLAVSKY': 0,
    'BOGUSLAWSKI': 0,
    'BOGUSZ': 0,
    'BOGUSZEWSKI': 0,
    'BOGY': 0,
    'BOH': 0,
    'BOHAC': 0,
    'BOHACEK': 0,
    'BOHACH': 0,
    'BOHALL': 0,
    'BOHAM': 0,
    'BOHAN': 0,
    'BOHANAN': 0,
    'BOHANNA': 0,
    'BOHANNAN': 0,
    'BOHANNON': 0,
    'BOHANON': 0,
    'BOHARA': 0,
    'BOHART': 0,
    'BOHATCH': 0,
    'BOHATY': 0,
    'BOHDAN': 0,
    'BOHDE': 0,
    'BOHELER': 0,
    'BOHEN': 0,
    'BOHENEK': 0,
    'BOHENSKY': 0,
    'BOHI': 0,
    'BOHIGIAN': 0,
    'BOHIN': 0,
    'BOHINSKI': 0,
    'BOHL': 0,
    'BOHLAND': 0,
    'BOHLANDER': 0,
    'BOHLE': 0,
    'BOHLEN': 0,
    'BOHLENDER': 0,
    'BOHLER': 0,
    'BOHLEY': 0,
    'BOHLIG': 0,
    'BOHLIN': 0,
    'BOHLING': 0,
    'BOHLINGER': 0,
    'BOHLKE': 0,
    'BOHLKEN': 0,
    'BOHLMAN': 0,
    'BOHLMANN': 0,
    'BOHLS': 0,
    'BOHLSEN': 0,
    'BOHM': 0,
    'BOHMAN': 0,
    'BOHMANN': 0,
    'BOHMBACH': 0,
    'BOHME': 0,
    'BOHMER': 0,
    'BOHMS': 0,
    'BOHN': 0,
    'BOHNA': 0,
    'BOHNE': 0,
    'BOHNEN': 0,
    'BOHNENBERGER': 0,
    'BOHNENBLUST': 0,
    'BOHNENKAMP': 0,
    'BOHNENSTIEHL': 0,
    'BOHNER': 0,
    'BOHNERT': 0,
    'BOHNET': 0,
    'BOHNETT': 0,
    'BOHNHOFF': 0,
    'BOHNING': 0,
    'BOHNKE': 0,
    'BOHNSACK': 0,
    'BOHNSTEDT': 0,
    'BOHO': 0,
    'BOHOL': 0,
    'BOHON': 0,
    'BOHORQUEZ': 0,
    'BOHOT': 0,
    'BOHR': 0,
    'BOHREN': 0,
    'BOHRER': 0,
    'BOHRINGER': 0,
    'BOHRMAN': 0,
    'BOHRN': 0,
    'BOHS': 0,
    'BOHTE': 0,
    'BOHUS': 0,
    'BOHUSLAV': 0,
    'BOHY': 0,
    'BOI': 0,
    'BOIAN': 0,
    'BOIANO': 0,
    'BOICE': 0,
    'BOICH': 0,
    'BOICOURT': 0,
    'BOID': 0,
    'BOIE': 0,
    'BOIES': 0,
    'BOIK': 0,
    'BOIKE': 0,
    'BOIKO': 0,
    'BOILARD': 0,
    'BOILEAU': 0,
    'BOILES': 0,
    'BOILLAT': 0,
    'BOILLOT': 0,
    'BOILS': 0,
    'BOILY': 0,
    'BOIN': 0,
    'BOINSKI': 0,
    'BOIRE': 0,
    'BOIS': 0,
    'BOISCLAIR': 0,
    'BOISE': 0,
    'BOISEN': 0,
    'BOISJOLIE': 0,
    'BOISMIER': 0,
    'BOISSE': 0,
    'BOISSEAU': 0,
    'BOISSELLE': 0,
    'BOISSIERE': 0,
    'BOISSON': 0,
    'BOISSONEAU': 0,
    'BOISSONNAULT': 0,
    'BOISSONNEAULT': 0,
    'BOISSY': 0,
    'BOISVERT': 0,
    'BOIT': 0,
    'BOITANO': 0,
    'BOITEAU': 0,
    'BOITEL': 0,
    'BOITER': 0,
    'BOITES': 0,
    'BOITNOTT': 0,
    'BOIVIN': 0,
    'BOJAN': 0,
    'BOJANOWSKI': 0,
    'BOJAR': 0,
    'BOJARSKI': 0,
    'BOJCZUK': 0,
    'BOJE': 0,
    'BOJIC': 0,
    'BOJKO': 0,
    'BOJORGE': 0,
    'BOJORGUEZ': 0,
    'BOJORQUES': 0,
    'BOJORQUEZ': 0,
    'BOJOVIC': 0,
    'BOJRAB': 0,
    'BOK': 0.8196721311475409,
    'BOKA': 0,
    'BOKAN': 0,
    'BOKAR': 0,
    'BOKELMAN': 0,
    'BOKEN': 0,
    'BOKER': 0,
    'BOKERN': 0,
    'BOKHARI': 0,
    'BOKMA': 0,
    'BOKMAN': 0,
    'BOKOR': 0,
    'BOKOVOY': 0,
    'BOKOWSKI': 0,
    'BOKROS': 0,
    'BOKSA': 0,
    'BOKUNIEWICZ': 0,
    'BOL': 0,
    'BOLA': 0,
    'BOLACK': 0,
    'BOLADO': 0,
    'BOLAM': 0,
    'BOLAN': 0,
    'BOLAND': 0,
    'BOLANDER': 0,
    'BOLANO': 0,
    'BOLANOS': 0,
    'BOLANOWSKI': 0,
    'BOLANTE': 0,
    'BOLAR': 0,
    'BOLARINHO': 0,
    'BOLAS': 0,
    'BOLASH': 0,
    'BOLAY': 0,
    'BOLCAR': 0,
    'BOLCH': 0,
    'BOLD': 0,
    'BOLDA': 0,
    'BOLDE': 0,
    'BOLDEN': 0,
    'BOLDENOW': 0,
    'BOLDER': 0,
    'BOLDERY': 0,
    'BOLDIN': 0,
    'BOLDING': 0,
    'BOLDIZAR': 0,
    'BOLDIZSAR': 0,
    'BOLDMAN': 0,
    'BOLDON': 0,
    'BOLDOSSER': 0,
    'BOLDRA': 0,
    'BOLDREY': 0,
    'BOLDRICK': 0,
    'BOLDRIDGE': 0,
    'BOLDS': 0,
    'BOLDT': 0,
    'BOLDUAN': 0,
    'BOLDUC': 0,
    'BOLE': 0,
    'BOLEA': 0,
    'BOLEEN': 0,
    'BOLEJACK': 0,
    'BOLEK': 0,
    'BOLEMAN': 0,
    'BOLEN': 0,
    'BOLENBAUGH': 0,
    'BOLENDER': 0,
    'BOLER': 0,
    'BOLERJACK': 0,
    'BOLES': 0,
    'BOLESTA': 0,
    'BOLEWARE': 0,
    'BOLEY': 0,
    'BOLEYJACK': 0,
    'BOLEYN': 0,
    'BOLF': 0,
    'BOLFING': 0,
    'BOLGER': 0,
    'BOLGIANO': 0,
    'BOLHUIS': 0,
    'BOLIA': 0,
    'BOLIAN': 0,
    'BOLIBOL': 0,
    'BOLICH': 0,
    'BOLICK': 0,
    'BOLIEK': 0,
    'BOLIEU': 0,
    'BOLIG': 0,
    'BOLIN': 0,
    'BOLINDER': 0,
    'BOLINE': 0,
    'BOLING': 0,
    'BOLINGBROKE': 0,
    'BOLINGER': 0,
    'BOLINO': 0,
    'BOLINSKI': 0,
    'BOLINSKY': 0,
    'BOLIO': 0,
    'BOLIS': 0,
    'BOLISH': 0,
    'BOLITHO': 0,
    'BOLIVAR': 0,
    'BOLIVER': 0,
    'BOLK': 0,
    'BOLKA': 0,
    'BOLKE': 0,
    'BOLKEMA': 0,
    'BOLKS': 0,
    'BOLL': 0,
    'BOLLA': 0,
    'BOLLACK': 0,
    'BOLLACKER': 0,
    'BOLLAERT': 0,
    'BOLLAND': 0,
    'BOLLAR': 0,
    'BOLLARD': 0,
    'BOLLAS': 0,
    'BOLLE': 0,
    'BOLLEN': 0,
    'BOLLENBACH': 0,
    'BOLLENBACHER': 0,
    'BOLLENDORF': 0,
    'BOLLER': 0,
    'BOLLERMAN': 0,
    'BOLLERS': 0,
    'BOLLERUD': 0,
    'BOLLES': 0,
    'BOLLEY': 0,
    'BOLLHEIMER': 0,
    'BOLLHOEFER': 0,
    'BOLLHORST': 0,
    'BOLLI': 0,
    'BOLLICH': 0,
    'BOLLIER': 0,
    'BOLLIG': 0,
    'BOLLIGER': 0,
    'BOLLIN': 0,
    'BOLLING': 0,
    'BOLLINGER': 0,
    'BOLLINI': 0,
    'BOLLIS': 0,
    'BOLLMAN': 0,
    'BOLLMANN': 0,
    'BOLLMER': 0,
    'BOLLMEYER': 0,
    'BOLLO': 0,
    'BOLLOCK': 0,
    'BOLLOM': 0,
    'BOLLON': 0,
    'BOLLS': 0,
    'BOLLSCHWEILER': 0,
    'BOLLUM': 0,
    'BOLLWEG': 0,
    'BOLLY': 0,
    'BOLM': 0,
    'BOLMAN': 0,
    'BOLME': 0,
    'BOLMER': 0,
    'BOLNER': 0,
    'BOLNICK': 0,
    'BOLOCK': 0,
    'BOLOGNA': 0,
    'BOLOGNESE': 0,
    'BOLOGNINI': 0,
    'BOLON': 0,
    'BOLORIN': 0,
    'BOLOS': 0,
    'BOLOSAN': 0,
    'BOLOTIN': 0,
    'BOLOTTE': 0,
    'BOLSEN': 0,
    'BOLSER': 0,
    'BOLSINGER': 0,
    'BOLSON': 0,
    'BOLSTAD': 0,
    'BOLSTER': 0,
    'BOLSTON': 0,
    'BOLSTRIDGE': 0,
    'BOLT': 0,
    'BOLTA': 0,
    'BOLTE': 0,
    'BOLTEN': 0,
    'BOLTER': 0,
    'BOLTHOUSE': 0,
    'BOLTIN': 0,
    'BOLTINGHOUSE': 0,
    'BOLTJES': 0,
    'BOLTON': 0,
    'BOLTS': 0,
    'BOLTZ': 0,
    'BOLTZE': 0,
    'BOLUS': 0,
    'BOLVIN': 0,
    'BOLWERK': 0,
    'BOLYARD': 0,
    'BOLYER': 0,
    'BOLZ': 0,
    'BOLZE': 0,
    'BOLZMAN': 0,
    'BOM': 0,
    'BOMAN': 0,
    'BOMAR': 0,
    'BOMBA': 0,
    'BOMBACE': 0,
    'BOMBACH': 0,
    'BOMBACI': 0,
    'BOMBACK': 0,
    'BOMBARA': 0,
    'BOMBARD': 0,
    'BOMBARDIER': 0,
    'BOMBARDIERE': 0,
    'BOMBARDO': 0,
    'BOMBAY': 0,
    'BOMBECK': 0,
    'BOMBELA': 0,
    'BOMBER': 0,
    'BOMBERG': 0,
    'BOMBERGER': 0,
    'BOMBERRY': 0,
    'BOMBICH': 0,
    'BOMBINO': 0,
    'BOMBOY': 0,
    'BOMER': 0,
    'BOMGAARS': 0,
    'BOMGARDNER': 0,
    'BOMHOFF': 0,
    'BOMIA': 0,
    'BOMKAMP': 0,
    'BOMMARITO': 0,
    'BOMMER': 0,
    'BOMMERSBACH': 0,
    'BOMSTAD': 0,
    'BON': 0,
    'BONA': 0,
    'BONACCI': 0,
    'BONACCORSI': 0,
    'BONACCORSO': 0,
    'BONACHEA': 0,
    'BONACK': 0,
    'BONACKER': 0,
    'BONACORSI': 0,
    'BONACORSO': 0,
    'BONACQUISTI': 0,
    'BONADIE': 0,
    'BONADIES': 0,
    'BONADIO': 0,
    'BONADONA': 0,
    'BONADONNA': 0,
    'BONADUCE': 0,
    'BONAFEDE': 0,
    'BONAFIDE': 0,
    'BONAGURA': 0,
    'BONAGURO': 0,
    'BONAHOOM': 0,
    'BONAIUTO': 0,
    'BONALDI': 0,
    'BONALES': 0,
    'BONAM': 0,
    'BONAMICO': 0,
    'BONAMINIO': 0,
    'BONAMO': 0,
    'BONAN': 0,
    'BONANDER': 0,
    'BONANNI': 0,
    'BONANNO': 0,
    'BONANO': 0,
    'BONANZA': 0,
    'BONAPART': 0,
    'BONAPARTE': 0,
    'BONAR': 0,
    'BONARD': 0,
    'BONARDI': 0,
    'BONARRIGO': 0,
    'BONAS': 0,
    'BONASERA': 0,
    'BONASIA': 0,
    'BONASSO': 0,
    'BONATI': 0,
    'BONATO': 0,
    'BONAVENTURA': 0,
    'BONAVENTURE': 0,
    'BONAVIA': 0,
    'BONAVITA': 0,
    'BONAVITO': 0,
    'BONAWITZ': 0,
    'BONAZZA': 0,
    'BONCEK': 0,
    'BONCHER': 0,
    'BONCI': 0,
    'BONCK': 0,
    'BONCORE': 0,
    'BONCZEK': 0,
    'BONCZKOWSKI': 0,
    'BONCZYK': 0,
    'BOND': 0,
    'BONDA': 0,
    'BONDAD': 0,
    'BONDANZA': 0,
    'BONDAR': 0,
    'BONDARCHUK': 0,
    'BONDARENKO': 0,
    'BONDARUK': 0,
    'BONDE': 0,
    'BONDER': 0,
    'BONDERER': 0,
    'BONDERSON': 0,
    'BONDESON': 0,
    'BONDHUS': 0,
    'BONDI': 0,
    'BONDIE': 0,
    'BONDOC': 0,
    'BONDON': 0,
    'BONDRA': 0,
    'BONDS': 0,
    'BONDURA': 0,
    'BONDURANT': 0,
    'BONDY': 0,
    'BONE': 0,
    'BONEBRAKE': 0,
    'BONEBRIGHT': 0,
    'BONECK': 0,
    'BONECUTTER': 0,
    'BONEE': 0,
    'BONEFAS': 0,
    'BONELL': 0,
    'BONELLA': 0,
    'BONELLI': 0,
    'BONELLO': 0,
    'BONEN': 0,
    'BONENBERGER': 0,
    'BONENFANT': 0,
    'BONEPARTE': 0,
    'BONER': 0,
    'BONERT': 0,
    'BONES': 0,
    'BONESS': 0,
    'BONESTEEL': 0,
    'BONESTROO': 0,
    'BONET': 0,
    'BONETA': 0,
    'BONETT': 0,
    'BONETTI': 0,
    'BONETTO': 0,
    'BONEWELL': 0,
    'BONEWITZ': 0,
    'BONEY': 0,
    'BONFANTE': 0,
    'BONFANTI': 0,
    'BONFIELD': 0,
    'BONFIG': 0,
    'BONFIGLIO': 0,
    'BONFIL': 0,
    'BONFILIO': 0,
    'BONFOEY': 0,
    'BONG': 0.7194244604316546,
    'BONGA': 0,
    'BONGARD': 0,
    'BONGARTZ': 0,
    'BONGARZONE': 0,
    'BONGE': 0,
    'BONGERS': 0,
    'BONGIORNI': 0,
    'BONGIORNO': 0,
    'BONGIOVANNI': 0,
    'BONGIOVI': 0,
    'BONGO': 0,
    'BONGOLAN': 0,
    'BONHAM': 0,
    'BONHEUR': 0,
    'BONHOMME': 0,
    'BONI': 0,
    'BONIA': 0,
    'BONICA': 0,
    'BONICELLI': 0,
    'BONICH': 0,
    'BONICK': 0,
    'BONIE': 0,
    'BONIECKI': 0,
    'BONIELLO': 0,
    'BONIER': 0,
    'BONIFACE': 0,
    'BONIFACIO': 0,
    'BONIFANT': 0,
    'BONIFAS': 0,
    'BONIFAY': 0,
    'BONIFAZ': 0,
    'BONIFAZI': 0,
    'BONIFER': 0,
    'BONIFIELD': 0,
    'BONIKOWSKE': 0,
    'BONILLA': 0,
    'BONILLAS': 0,
    'BONILLO': 0,
    'BONIN': 0,
    'BONINA': 0,
    'BONINE': 0,
    'BONINI': 0,
    'BONINO': 0,
    'BONIOL': 0,
    'BONIOR': 0,
    'BONIS': 0,
    'BONITA': 0.9961685823754788,
    'BONITATI': 0,
    'BONITATIBUS': 0,
    'BONITO': 0,
    'BONITTO': 0,
    'BONITZ': 0,
    'BONJEAN': 0,
    'BONJOUR': 0,
    'BONK': 0,
    'BONKE': 0,
    'BONKER': 0,
    'BONKOSKI': 0,
    'BONKOWSKI': 0,
    'BONLENDER': 0,
    'BONMAN': 0,
    'BONN': 0,
    'BONNAR': 0,
    'BONNE': 0,
    'BONNEAU': 0,
    'BONNEE': 0,
    'BONNEL': 0,
    'BONNELL': 0,
    'BONNEMA': 0,
    'BONNEN': 0,
    'BONNER': 0,
    'BONNES': 0,
    'BONNESEN': 0,
    'BONNESS': 0,
    'BONNET': 0,
    'BONNETT': 0,
    'BONNETTE': 0,
    'BONNEVIE': 0,
    'BONNEVILLE': 0,
    'BONNEWELL': 0,
    'BONNEY': 0,
    'BONNICHSEN': 0,
    'BONNICI': 0,
    'BONNICK': 0,
    'BONNIE': 0.998432952764719,
    'BONNIER': 0,
    'BONNIN': 0,
    'BONNING': 0,
    'BONNIVILLE': 0,
    'BONNIWELL': 0,
    'BONNO': 0,
    'BONNOT': 0,
    'BONNSTETTER': 0,
    'BONNY': 0.9523809523809523,
    'BONO': 0,
    'BONOAN': 0,
    'BONOFIGLIO': 0,
    'BONOGOFSKY': 0,
    'BONOLA': 0,
    'BONOMI': 0,
    'BONOMINI': 0,
    'BONOMO': 0,
    'BONOMOLO': 0,
    'BONORA': 0,
    'BONORDEN': 0,
    'BONOVICH': 0,
    'BONOW': 0,
    'BONS': 0,
    'BONSACK': 0,
    'BONSAL': 0,
    'BONSALL': 0,
    'BONSE': 0,
    'BONSELL': 0,
    'BONSER': 0,
    'BONSEY': 0,
    'BONSIGNORE': 0,
    'BONSON': 0,
    'BONSTEEL': 0,
    'BONSTEIN': 0,
    'BONSU': 0,
    'BONT': 0,
    'BONTA': 0,
    'BONTE': 0,
    'BONTEMPI': 0,
    'BONTEMPO': 0,
    'BONTEMPS': 0,
    'BONTER': 0,
    'BONTJES': 0,
    'BONTON': 0,
    'BONTRAGER': 0,
    'BONTZ': 0,
    'BONUGLI': 0,
    'BONURA': 0,
    'BONUS': 0,
    'BONVENTRE': 0,
    'BONVILLAIN': 0,
    'BONVILLE': 0,
    'BONVILLIAN': 0,
    'BONVINO': 0,
    'BONVISSUTO': 0,
    'BONVOULOIR': 0,
    'BONWELL': 0,
    'BONY': 0,
    'BONZANI': 0,
    'BONZER': 0,
    'BONZO': 0,
    'BOO': 0,
    'BOOB': 0,
    'BOOBAR': 0,
    'BOOBER': 0,
    'BOOCHER': 0,
    'BOOCK': 0,
    'BOOCKS': 0,
    'BOOD': 0,
    'BOODHOO': 0,
    'BOODOO': 0,
    'BOODRAM': 0,
    'BOODRY': 0,
    'BOODT': 0,
    'BOODY': 0,
    'BOOE': 0,
    'BOOFER': 0,
    'BOOG': 0,
    'BOOGAARD': 0,
    'BOOGREN': 0,
    'BOOHER': 0,
    'BOOK': 0,
    'BOOKAMER': 0,
    'BOOKARD': 0,
    'BOOKBINDER': 0,
    'BOOKE': 0,
    'BOOKER': 0.38077106139933364,
    'BOOKERT': 0,
    'BOOKEY': 0,
    'BOOKHAMER': 0,
    'BOOKHAMMER': 0,
    'BOOKHARDT': 0,
    'BOOKHART': 0,
    'BOOKHEIMER': 0,
    'BOOKHOUT': 0,
    'BOOKLESS': 0,
    'BOOKMAN': 0,
    'BOOKMILLER': 0,
    'BOOKMYER': 0,
    'BOOKOUT': 0,
    'BOOKS': 0,
    'BOOKSTAVER': 0,
    'BOOKSTEIN': 0,
    'BOOKTER': 0,
    'BOOKWALTER': 0,
    'BOOL': 0,
    'BOOLE': 0,
    'BOOM': 0,
    'BOOME': 0,
    'BOOMER': 0,
    'BOOMERSHINE': 0,
    'BOOMGAARD': 0,
    'BOOMGAARDEN': 0,
    'BOOMGARDEN': 0,
    'BOOMHOWER': 0,
    'BOOMS': 0,
    'BOOMSMA': 0,
    'BOON': 0,
    'BOONE': 0,
    'BOONIE': 0,
    'BOONSTRA': 0,
    'BOOP': 0,
    'BOOR': 0,
    'BOORAS': 0,
    'BOORD': 0,
    'BOORE': 0,
    'BOORMAN': 0,
    'BOORN': 0,
    'BOORNAZIAN': 0,
    'BOOROM': 0,
    'BOORSE': 0,
    'BOORSMA': 0,
    'BOORSTEIN': 0,
    'BOORTZ': 0,
    'BOOS': 0,
    'BOOSALIS': 0,
    'BOOSE': 0,
    'BOOSER': 0,
    'BOOSINGER': 0,
    'BOOSKA': 0,
    'BOOSTROM': 0,
    'BOOT': 0,
    'BOOTE': 0,
    'BOOTEN': 0,
    'BOOTERBAUGH': 0,
    'BOOTES': 0,
    'BOOTH': 0,
    'BOOTHBY': 0,
    'BOOTHE': 0,
    'BOOTHMAN': 0,
    'BOOTHROYD': 0,
    'BOOTMAN': 0,
    'BOOTON': 0,
    'BOOTS': 0,
    'BOOTSMA': 0,
    'BOOTY': 0,
    'BOOTZ': 0,
    'BOOZ': 0,
    'BOOZE': 0,
    'BOOZEL': 0,
    'BOOZELL': 0,
    'BOOZER': 0,
    'BOPARAI': 0,
    'BOPE': 0,
    'BOPP': 0,
    'BOPPRE': 0,
    'BOPST': 0,
    'BOQUET': 0,
    'BOQUIN': 0,
    'BOQUIREN': 0,
    'BOQUIST': 0,
    'BOR': 0,
    'BORA': 0,
    'BORAAS': 0,
    'BORACK': 0,
    'BORAGINE': 0,
    'BORAH': 0,
    'BORAK': 0,
    'BORAM': 0,
    'BORAN': 0,
    'BORANIAN': 0,
    'BORAS': 0,
    'BORASH': 0,
    'BORASKI': 0,
    'BORAWSKI': 0,
    'BORBA': 0,
    'BORBAS': 0,
    'BORBELY': 0,
    'BORBOA': 0,
    'BORBOLLA': 0,
    'BORBON': 0,
    'BORBOR': 0,
    'BORCH': 0,
    'BORCHARD': 0,
    'BORCHARDT': 0,
    'BORCHART': 0,
    'BORCHELT': 0,
    'BORCHER': 0,
    'BORCHERDING': 0,
    'BORCHERS': 0,
    'BORCHERT': 0,
    'BORCK': 0,
    'BORCKY': 0,
    'BORD': 0,
    'BORDA': 0,
    'BORDALLO': 0,
    'BORDAS': 0,
    'BORDASH': 0,
    'BORDAYO': 0,
    'BORDE': 0,
    'BORDEAU': 0,
    'BORDEAUX': 0,
    'BORDELEAU': 0,
    'BORDELL': 0,
    'BORDELON': 0,
    'BORDEN': 0,
    'BORDENAVE': 0,
    'BORDENET': 0,
    'BORDENKIRCHER': 0,
    'BORDER': 0,
    'BORDERS': 0,
    'BORDES': 0,
    'BORDESSA': 0,
    'BORDEWICK': 0,
    'BORDEWYK': 0,
    'BORDI': 0,
    'BORDIERI': 0,
    'BORDIN': 0,
    'BORDINE': 0,
    'BORDLEY': 0,
    'BORDMAN': 0,
    'BORDNER': 0,
    'BORDO': 0,
    'BORDOGNA': 0,
    'BORDON': 0,
    'BORDONARD': 0,
    'BORDONARO': 0,
    'BORDONE': 0,
    'BORDONI': 0,
    'BORDOVSKY': 0,
    'BORDOY': 0,
    'BORDSON': 0,
    'BORDT': 0,
    'BORDWELL': 0,
    'BORDWINE': 0,
    'BORDY': 0,
    'BORE': 0,
    'BORECKI': 0,
    'BORECKY': 0,
    'BOREEN': 0,
    'BOREHAM': 0,
    'BOREK': 0,
    'BOREL': 0,
    'BORELAND': 0,
    'BORELL': 0,
    'BORELLA': 0,
    'BORELLI': 0,
    'BORELLO': 0,
    'BOREM': 0,
    'BOREMAN': 0,
    'BOREN': 0,
    'BORENGASSER': 0,
    'BORENS': 0,
    'BORENSTEIN': 0,
    'BORER': 0,
    'BORES': 0,
    'BORESON': 0,
    'BORETSKY': 0,
    'BORETTI': 0,
    'BOREY': 0,
    'BORG': 0,
    'BORGA': 0,
    'BORGAN': 0,
    'BORGARD': 0,
    'BORGARDT': 0,
    'BORGAS': 0,
    'BORGATTI': 0,
    'BORGE': 0,
    'BORGELLA': 0,
    'BORGELT': 0,
    'BORGEMENKE': 0,
    'BORGEN': 0,
    'BORGENS': 0,
    'BORGER': 0,
    'BORGERDING': 0,
    'BORGERS': 0,
    'BORGERSEN': 0,
    'BORGERSON': 0,
    'BORGERT': 0,
    'BORGES': 0,
    'BORGESE': 0,
    'BORGESON': 0,
    'BORGESS': 0,
    'BORGFELD': 0,
    'BORGH': 0,
    'BORGHESE': 0,
    'BORGHESI': 0,
    'BORGHI': 0,
    'BORGIA': 0,
    'BORGLUM': 0,
    'BORGMAN': 0,
    'BORGMANN': 0,
    'BORGMEYER': 0,
    'BORGNA': 0,
    'BORGO': 0,
    'BORGOGNONI': 0,
    'BORGOS': 0,
    'BORGSTADT': 0,
    'BORGSTEDE': 0,
    'BORGSTROM': 0,
    'BORGWARDT': 0,
    'BORHAM': 0,
    'BORHO': 0,
    'BORI': 0,
    'BORIA': 0,
    'BORIACK': 0,
    'BORICH': 0,
    'BORICK': 0,
    'BORIE': 0,
    'BORIK': 0,
    'BORILLO': 0,
    'BORIN': 0,
    'BORING': 0,
    'BORINO': 0,
    'BORIO': 0,
    'BORIS': 0.860832137733142,
    'BORISCH': 0,
    'BORISENKO': 0,
    'BORISH': 0,
    'BORISOV': 0,
    'BORISOVA': 0,
    'BORITZ': 0,
    'BORJA': 0,
    'BORJAS': 0,
    'BORJON': 0,
    'BORK': 0,
    'BORKA': 0,
    'BORKE': 0,
    'BORKENHAGEN': 0,
    'BORKEY': 0,
    'BORKHOLDER': 0,
    'BORKIN': 0,
    'BORKMAN': 0,
    'BORKO': 0,
    'BORKOSKI': 0,
    'BORKOSKY': 0,
    'BORKOVEC': 0,
    'BORKOVICH': 0,
    'BORKOWICZ': 0,
    'BORKOWSKI': 0,
    'BORLA': 0,
    'BORLAND': 0,
    'BORLAUG': 0,
    'BORLEY': 0,
    'BORLIE': 0,
    'BORLIK': 0,
    'BORLING': 0,
    'BORM': 0,
    'BORMAN': 0,
    'BORMANN': 0,
    'BORMET': 0,
    'BORMUTH': 0,
    'BORN': 0,
    'BORNE': 0,
    'BORNEMAN': 0,
    'BORNEMANN': 0,
    'BORNEMEIER': 0,
    'BORNEO': 0,
    'BORNER': 0,
    'BORNES': 0,
    'BORNFLETH': 0,
    'BORNGESSER': 0,
    'BORNHAUSER': 0,
    'BORNHEIM': 0,
    'BORNHEIMER': 0,
    'BORNHOEFT': 0,
    'BORNHOFT': 0,
    'BORNHOLDT': 0,
    'BORNHORST': 0,
    'BORNICK': 0,
    'BORNMAN': 0,
    'BORNMANN': 0,
    'BORNO': 0,
    'BORNS': 0,
    'BORNSCHEIN': 0,
    'BORNSTEIN': 0,
    'BORNT': 0,
    'BORNTRAGER': 0,
    'BORNTREGER': 0,
    'BORO': 0,
    'BORODIN': 0,
    'BORODKIN': 0,
    'BOROFF': 0,
    'BOROFSKY': 0,
    'BOROK': 0,
    'BOROM': 0,
    'BORON': 0,
    'BOROR': 0,
    'BOROS': 0,
    'BOROSKI': 0,
    'BOROSKY': 0,
    'BOROTA': 0,
    'BOROUGH': 0,
    'BOROUGHS': 0,
    'BOROUMAND': 0,
    'BOROVICH': 0,
    'BOROVICKA': 0,
    'BOROVSKY': 0,
    'BOROW': 0,
    'BOROWCZYK': 0,
    'BOROWIAK': 0,
    'BOROWICK': 0,
    'BOROWICZ': 0,
    'BOROWIEC': 0,
    'BOROWITZ': 0,
    'BOROWSKI': 0,
    'BOROWSKY': 0,
    'BOROWY': 0,
    'BORQUE': 0,
    'BORQUEZ': 0,
    'BORQUIST': 0,
    'BORR': 0,
    'BORRA': 0,
    'BORRAS': 0,
    'BORRAYO': 0,
    'BORRE': 0,
    'BORREGGINE': 0,
    'BORREGO': 0,
    'BORRELL': 0,
    'BORRELLI': 0,
    'BORRELLO': 0,
    'BORREMANS': 0,
    'BORRENPOHL': 0,
    'BORRERO': 0,
    'BORRES': 0,
    'BORRESEN': 0,
    'BORRESON': 0,
    'BORRETT': 0,
    'BORRI': 0,
    'BORRIELLO': 0,
    'BORRIES': 0,
    'BORRIS': 0,
    'BORRMANN': 0,
    'BORRO': 0,
    'BORROEL': 0,
    'BORROMEO': 0,
    'BORRON': 0,
    'BORROR': 0,
    'BORROTO': 0,
    'BORROW': 0,
    'BORROWMAN': 0,
    'BORROWS': 0,
    'BORRUEL': 0,
    'BORRUSO': 0,
    'BORS': 0,
    'BORSA': 0,
    'BORSARI': 0,
    'BORSCH': 0,
    'BORSCHEL': 0,
    'BORSE': 0,
    'BORSELLA': 0,
    'BORSELLINO': 0,
    'BORSETH': 0,
    'BORSH': 0,
    'BORSHEIM': 0,
    'BORSKE': 0,
    'BORSKEY': 0,
    'BORSKI': 0,
    'BORSKY': 0,
    'BORSO': 0,
    'BORSODI': 0,
    'BORSON': 0,
    'BORSOS': 0,
    'BORST': 0,
    'BORSTAD': 0,
    'BORSUK': 0,
    'BORT': 0,
    'BORTA': 0,
    'BORTEL': 0,
    'BORTELL': 0,
    'BORTER': 0,
    'BORTH': 0,
    'BORTHS': 0,
    'BORTHWICK': 0,
    'BORTIS': 0,
    'BORTLE': 0,
    'BORTLES': 0,
    'BORTMAN': 0,
    'BORTMAS': 0,
    'BORTNEM': 0,
    'BORTNER': 0,
    'BORTNICK': 0,
    'BORTNIK': 0,
    'BORTOLI': 0,
    'BORTOLOTTI': 0,
    'BORTOLUSSI': 0,
    'BORTON': 0,
    'BORTONE': 0,
    'BORTREE': 0,
    'BORTS': 0,
    'BORTSCHELLER': 0,
    'BORTZ': 0,
    'BORTZFIELD': 0,
    'BORUCH': 0,
    'BORUCKI': 0,
    'BORUD': 0,
    'BORUFF': 0,
    'BORUKHOV': 0,
    'BORUM': 0,
    'BORUNDA': 0,
    'BORUP': 0,
    'BORUS': 0,
    'BORUTA': 0,
    'BORWICK': 0,
    'BORY': 0,
    'BORYK': 0,
    'BORYS': 0,
    'BORYSEWICZ': 0,
    'BORYSZEWSKI': 0,
    'BORZA': 0,
    'BORZI': 0,
    'BORZICK': 0,
    'BORZILLERI': 0,
    'BORZILLO': 0,
    'BOS': 0,
    'BOSA': 0,
    'BOSACK': 0,
    'BOSACKER': 0,
    'BOSAK': 0,
    'BOSANAC': 0,
    'BOSANKO': 0,
    'BOSARGE': 0,
    'BOSAW': 0,
    'BOSBY': 0,
    'BOSCA': 0,
    'BOSCACCI': 0,
    'BOSCAINO': 0,
    'BOSCAMP': 0,
    'BOSCARDIN': 0,
    'BOSCARINO': 0,
    'BOSCH': 0,
    'BOSCHE': 0,
    'BOSCHEE': 0,
    'BOSCHEN': 0,
    'BOSCHERT': 0,
    'BOSCHETTI': 0,
    'BOSCHETTO': 0,
    'BOSCHI': 0,
    'BOSCHMA': 0,
    'BOSCIA': 0,
    'BOSCO': 0,
    'BOSCOE': 0,
    'BOSE': 0,
    'BOSECK': 0,
    'BOSECKER': 0,
    'BOSEK': 0,
    'BOSEL': 0,
    'BOSELA': 0,
    'BOSELL': 0,
    'BOSELLI': 0,
    'BOSELY': 0,
    'BOSEMAN': 0,
    'BOSEN': 0,
    'BOSER': 0,
    'BOSETTI': 0,
    'BOSH': 0,
    'BOSHARD': 0,
    'BOSHART': 0,
    'BOSHAW': 0,
    'BOSHEARS': 0,
    'BOSHELL': 0,
    'BOSHER': 0,
    'BOSHERS': 0,
    'BOSHOVEN': 0,
    'BOSI': 0,
    'BOSIACKI': 0,
    'BOSICK': 0,
    'BOSIER': 0,
    'BOSILJEVAC': 0,
    'BOSIN': 0,
    'BOSIO': 0,
    'BOSKA': 0,
    'BOSKE': 0,
    'BOSKER': 0,
    'BOSKET': 0,
    'BOSKEY': 0,
    'BOSKO': 0,
    'BOSKOVIC': 0,
    'BOSKOVICH': 0,
    'BOSLAND': 0,
    'BOSLER': 0,
    'BOSLET': 0,
    'BOSLEY': 0,
    'BOSMA': 0,
    'BOSMAN': 0,
    'BOSMANS': 0,
    'BOSNAK': 0,
    'BOSNIC': 0,
    'BOSNICH': 0,
    'BOSNJAK': 0,
    'BOSNYAK': 0,
    'BOSO': 0,
    'BOSOLD': 0,
    'BOSON': 0,
    'BOSQUE': 0,
    'BOSQUES': 0,
    'BOSQUET': 0,
    'BOSQUEZ': 0,
    'BOSS': 0,
    'BOSSA': 0,
    'BOSSALLER': 0,
    'BOSSARD': 0,
    'BOSSART': 0,
    'BOSSCHER': 0,
    'BOSSE': 0,
    'BOSSELL': 0,
    'BOSSELMAN': 0,
    'BOSSEN': 0,
    'BOSSENBROEK': 0,
    'BOSSER': 0,
    'BOSSERMAN': 0,
    'BOSSERT': 0,
    'BOSSETT': 0,
    'BOSSHARD': 0,
    'BOSSHARDT': 0,
    'BOSSHART': 0,
    'BOSSI': 0,
    'BOSSICK': 0,
    'BOSSIE': 0,
    'BOSSIER': 0,
    'BOSSINGER': 0,
    'BOSSINGHAM': 0,
    'BOSSIO': 0,
    'BOSSLER': 0,
    'BOSSLEY': 0,
    'BOSSMAN': 0,
    'BOSSO': 0,
    'BOSSOM': 0,
    'BOSSON': 0,
    'BOSSONE': 0,
    'BOSSONG': 0,
    'BOSSOW': 0,
    'BOSSUNG': 0,
    'BOST': 0,
    'BOSTAIN': 0,
    'BOSTAPH': 0,
    'BOSTATER': 0,
    'BOSTEDER': 0,
    'BOSTEDT': 0,
    'BOSTELMAN': 0,
    'BOSTER': 0,
    'BOSTIAN': 0,
    'BOSTIC': 0,
    'BOSTICK': 0,
    'BOSTOCK': 0,
    'BOSTON': 0,
    'BOSTROM': 0,
    'BOSTRON': 0,
    'BOSTWICK': 0,
    'BOSWELL': 0,
    'BOSWORTH': 0,
    'BOSZE': 0,
    'BOT': 0,
    'BOTA': 0,
    'BOTANA': 0,
    'BOTAS': 0,
    'BOTBYL': 0,
    'BOTCH': 0,
    'BOTCHER': 0,
    'BOTCHWAY': 0,
    'BOTDORF': 0,
    'BOTE': 0,
    'BOTEILHO': 0,
    'BOTEK': 0,
    'BOTEL': 0,
    'BOTELER': 0,
    'BOTELHO': 0,
    'BOTELLA': 0,
    'BOTELLO': 0,
    'BOTEN': 0,
    'BOTEO': 0,
    'BOTERO': 0,
    'BOTH': 0,
    'BOTHA': 0,
    'BOTHAM': 0,
    'BOTHE': 0,
    'BOTHEL': 0,
    'BOTHELL': 0,
    'BOTHMAN': 0,
    'BOTHNER': 0,
    'BOTHOF': 0,
    'BOTHUM': 0,
    'BOTHUN': 0,
    'BOTHWELL': 0,
    'BOTIC': 0,
    'BOTICA': 0,
    'BOTIMER': 0,
    'BOTKA': 0,
    'BOTKIN': 0,
    'BOTKINS': 0,
    'BOTLER': 0,
    'BOTLEY': 0,
    'BOTNER': 0,
    'BOTNICK': 0,
    'BOTOS': 0,
    'BOTROS': 0,
    'BOTSCH': 0,
    'BOTSFORD': 0,
    'BOTSKO': 0,
    'BOTSON': 0,
    'BOTT': 0,
    'BOTTA': 0,
    'BOTTALICO': 0,
    'BOTTARI': 0,
    'BOTTARINI': 0,
    'BOTTARO': 0,
    'BOTTAZZI': 0,
    'BOTTCHER': 0,
    'BOTTE': 0,
    'BOTTEICHER': 0,
    'BOTTEMA': 0,
    'BOTTEMILLER': 0,
    'BOTTEN': 0,
    'BOTTENBERG': 0,
    'BOTTENFIELD': 0,
    'BOTTER': 0,
    'BOTTERBUSCH': 0,
    'BOTTERON': 0,
    'BOTTEX': 0,
    'BOTTGER': 0,
    'BOTTI': 0,
    'BOTTICELLI': 0,
    'BOTTICELLO': 0,
    'BOTTIGER': 0,
    'BOTTIGLIERI': 0,
    'BOTTIN': 0,
    'BOTTINELLI': 0,
    'BOTTING': 0,
    'BOTTINI': 0,
    'BOTTINO': 0,
    'BOTTJEN': 0,
    'BOTTJER': 0,
    'BOTTKE': 0,
    'BOTTLE': 0,
    'BOTTLES': 0,
    'BOTTLEY': 0,
    'BOTTNER': 0,
    'BOTTO': 0,
    'BOTTOLFSON': 0,
    'BOTTOM': 0,
    'BOTTOMLEE': 0,
    'BOTTOMLEY': 0,
    'BOTTOMLY': 0,
    'BOTTOMS': 0,
    'BOTTON': 0,
    'BOTTONE': 0,
    'BOTTONI': 0,
    'BOTTORF': 0,
    'BOTTORFF': 0,
    'BOTTOS': 0,
    'BOTTRELL': 0,
    'BOTTS': 0,
    'BOTTUM': 0,
    'BOTWIN': 0,
    'BOTWINICK': 0,
    'BOTWRIGHT': 0,
    'BOTZ': 0,
    'BOTZET': 0,
    'BOU': 0,
    'BOUBEL': 0,
    'BOUC': 0,
    'BOUCARD': 0,
    'BOUCEK': 0,
    'BOUCH': 0,
    'BOUCHA': 0,
    'BOUCHARD': 0,
    'BOUCHAT': 0,
    'BOUCHE': 0,
    'BOUCHELLE': 0,
    'BOUCHER': 0,
    'BOUCHEREAU': 0,
    'BOUCHET': 0,
    'BOUCHEY': 0,
    'BOUCHEZ': 0,
    'BOUCHIE': 0,
    'BOUCHIER': 0,
    'BOUCHILLON': 0,
    'BOUCK': 0,
    'BOUCKAERT': 0,
    'BOUD': 0,
    'BOUDAH': 0,
    'BOUDER': 0,
    'BOUDET': 0,
    'BOUDIN': 0,
    'BOUDINOT': 0,
    'BOUDLE': 0,
    'BOUDMAN': 0,
    'BOUDOIN': 0,
    'BOUDOURIS': 0,
    'BOUDREAU': 0,
    'BOUDREAULT': 0,
    'BOUDREAUX': 0,
    'BOUDRIE': 0,
    'BOUDRO': 0,
    'BOUDROT': 0,
    'BOUDROW': 0,
    'BOUDWIN': 0,
    'BOUER': 0,
    'BOUEY': 0,
    'BOUFFARD': 0,
    'BOUFFORD': 0,
    'BOUGARD': 0,
    'BOUGAS': 0,
    'BOUGE': 0,
    'BOUGERE': 0,
    'BOUGH': 0,
    'BOUGHAN': 0,
    'BOUGHER': 0,
    'BOUGHEY': 0,
    'BOUGHMAN': 0,
    'BOUGHNER': 0,
    'BOUGHTER': 0,
    'BOUGHTON': 0,
    'BOUGIE': 0,
    'BOUIE': 0,
    'BOUILLION': 0,
    'BOUILLON': 0,
    'BOUKER': 0,
    'BOUKNIGHT': 0,
    'BOUL': 0,
    'BOULA': 0,
    'BOULAIS': 0,
    'BOULAND': 0,
    'BOULANGER': 0,
    'BOULAS': 0,
    'BOULAY': 0,
    'BOULD': 0,
    'BOULDEN': 0,
    'BOULDIN': 0,
    'BOULDING': 0,
    'BOULDS': 0,
    'BOULE': 0,
    'BOULER': 0,
    'BOULERICE': 0,
    'BOULES': 0,
    'BOULET': 0,
    'BOULETTE': 0,
    'BOULEY': 0,
    'BOULGER': 0,
    'BOULIER': 0,
    'BOULIGNY': 0,
    'BOULIN': 0,
    'BOULINEAU': 0,
    'BOULIS': 0,
    'BOULLION': 0,
    'BOULOM': 0,
    'BOULOS': 0,
    'BOULT': 0,
    'BOULTER': 0,
    'BOULTINGHOUSE': 0,
    'BOULTON': 0,
    'BOULWARE': 0,
    'BOUMA': 0,
    'BOUMAN': 0,
    'BOUN': 0,
    'BOUND': 0,
    'BOUNDS': 0,
    'BOUNDY': 0,
    'BOUNOUS': 0,
    'BOUNYAVONG': 0,
    'BOUQUET': 0,
    'BOUQUIN': 0,
    'BOUR': 0,
    'BOURAS': 0,
    'BOURASSA': 0,
    'BOURAY': 0,
    'BOURBEAU': 0,
    'BOURBINA': 0,
    'BOURBON': 0,
    'BOURBONNAIS': 0,
    'BOURCIER': 0,
    'BOURCY': 0,
    'BOURDA': 0,
    'BOURDAGE': 0,
    'BOURDEAU': 0,
    'BOURDEAUX': 0,
    'BOURDELAIS': 0,
    'BOURDET': 0,
    'BOURDETTE': 0,
    'BOURDIER': 0,
    'BOURDO': 0,
    'BOURDON': 0,
    'BOURELL': 0,
    'BOURELLE': 0,
    'BOUREN': 0,
    'BOURESSA': 0,
    'BOURET': 0,
    'BOUREY': 0,
    'BOURFF': 0,
    'BOURG': 0,
    'BOURGAULT': 0,
    'BOURGE': 0,
    'BOURGEAU': 0,
    'BOURGEAULT': 0,
    'BOURGEOIS': 0,
    'BOURGET': 0,
    'BOURGETTE': 0,
    'BOURGOIN': 0,
    'BOURGOINE': 0,
    'BOURGOIS': 0,
    'BOURGON': 0,
    'BOURGOYNE': 0,
    'BOURGUE': 0,
    'BOURGUIGNON': 0,
    'BOURIS': 0,
    'BOURISAW': 0,
    'BOURK': 0,
    'BOURKE': 0,
    'BOURLAND': 0,
    'BOURLIER': 0,
    'BOURN': 0,
    'BOURNE': 0,
    'BOURNES': 0,
    'BOURNIAS': 0,
    'BOURNIQUE': 0,
    'BOURNIVAL': 0,
    'BOURNS': 0,
    'BOURQUE': 0,
    'BOURQUIN': 0,
    'BOURRAGE': 0,
    'BOURRET': 0,
    'BOURSAW': 0,
    'BOURSIQUOT': 0,
    'BOURY': 0,
    'BOUSCHER': 0,
    'BOUSCHOR': 0,
    'BOUSE': 0,
    'BOUSFIELD': 0,
    'BOUSH': 0,
    'BOUSHEE': 0,
    'BOUSHELL': 0,
    'BOUSHEY': 0,
    'BOUSHIE': 0,
    'BOUSKA': 0,
    'BOUSLAUGH': 0,
    'BOUSLEY': 0,
    'BOUSLOG': 0,
    'BOUSMAN': 0,
    'BOUSQUET': 0,
    'BOUSSON': 0,
    'BOUSTANI': 0,
    'BOUSTANY': 0,
    'BOUSTEAD': 0,
    'BOUSUM': 0,
    'BOUT': 0,
    'BOUTAIN': 0,
    'BOUTCHER': 0,
    'BOUTCHYARD': 0,
    'BOUTEILLER': 0,
    'BOUTELIE': 0,
    'BOUTELL': 0,
    'BOUTELLE': 0,
    'BOUTEN': 0,
    'BOUTERSE': 0,
    'BOUTET': 0,
    'BOUTHIETTE': 0,
    'BOUTHILLER': 0,
    'BOUTHILLETTE': 0,
    'BOUTHILLIER': 0,
    'BOUTHOT': 0,
    'BOUTIETTE': 0,
    'BOUTILIER': 0,
    'BOUTILLIER': 0,
    'BOUTIN': 0,
    'BOUTON': 0,
    'BOUTOT': 0,
    'BOUTROS': 0,
    'BOUTS': 0,
    'BOUTTE': 0,
    'BOUTWELL': 0,
    'BOUTZ': 0,
    'BOUVET': 0,
    'BOUVETTE': 0,
    'BOUVIA': 0,
    'BOUVIER': 0,
    'BOUVY': 0,
    'BOUWENS': 0,
    'BOUWER': 0,
    'BOUWHUIS': 0,
    'BOUWKAMP': 0,
    'BOUWMAN': 0,
    'BOUY': 0,
    'BOUYE': 0,
    'BOUYEA': 0,
    'BOUYER': 0,
    'BOUZA': 0,
    'BOUZAS': 0,
    'BOUZEK': 0,
    'BOUZIDEN': 0,
    'BOVA': 0,
    'BOVAIN': 0,
    'BOVAIR': 0,
    'BOVAIRD': 0,
    'BOVAN': 0,
    'BOVARD': 0,
    'BOVAT': 0,
    'BOVAY': 0,
    'BOVE': 0,
    'BOVEE': 0,
    'BOVELL': 0,
    'BOVEN': 0,
    'BOVENDER': 0,
    'BOVENKAMP': 0,
    'BOVENZI': 0,
    'BOVER': 0,
    'BOVEY': 0,
    'BOVI': 0,
    'BOVIA': 0,
    'BOVIAN': 0,
    'BOVICH': 0,
    'BOVIE': 0,
    'BOVIER': 0,
    'BOVILL': 0,
    'BOVINO': 0,
    'BOVIO': 0,
    'BOVIS': 0,
    'BOVITZ': 0,
    'BOVO': 0,
    'BOVY': 0,
    'BOW': 0,
    'BOWAN': 0,
    'BOWAR': 0,
    'BOWARD': 0,
    'BOWCOCK': 0,
    'BOWCUT': 0,
    'BOWCUTT': 0,
    'BOWDEN': 0,
    'BOWDER': 0,
    'BOWDERS': 0,
    'BOWDERY': 0,
    'BOWDISH': 0,
    'BOWDITCH': 0,
    'BOWDLE': 0,
    'BOWDLER': 0,
    'BOWDOIN': 0,
    'BOWDON': 0,
    'BOWDRE': 0,
    'BOWDREN': 0,
    'BOWDRY': 0,
    'BOWDY': 0,
    'BOWE': 0,
    'BOWELL': 0,
    'BOWELS': 0,
    'BOWEN': 0,
    'BOWENS': 0,
    'BOWER': 0,
    'BOWERBANK': 0,
    'BOWERING': 0,
    'BOWERMAN': 0,
    'BOWERMASTER': 0,
    'BOWERS': 0,
    'BOWERSMITH': 0,
    'BOWERSOCK': 0,
    'BOWERSOX': 0,
    'BOWERY': 0,
    'BOWES': 0,
    'BOWEY': 0,
    'BOWHALL': 0,
    'BOWHAY': 0,
    'BOWICK': 0,
    'BOWIE': 0,
    'BOWIN': 0,
    'BOWINS': 0,
    'BOWKER': 0,
    'BOWLAN': 0,
    'BOWLAND': 0,
    'BOWLBY': 0,
    'BOWLDEN': 0,
    'BOWLDING': 0,
    'BOWLDS': 0,
    'BOWLEN': 0,
    'BOWLER': 0,
    'BOWLES': 0,
    'BOWLEY': 0,
    'BOWLIN': 0,
    'BOWLINE': 0,
    'BOWLING': 0,
    'BOWLS': 0,
    'BOWLSBY': 0,
    'BOWLUS': 0,
    'BOWMAN': 0,
    'BOWMAR': 0,
    'BOWMASTER': 0,
    'BOWMEN': 0,
    'BOWMER': 0,
    'BOWN': 0,
    'BOWNDS': 0,
    'BOWNE': 0,
    'BOWNES': 0,
    'BOWNESS': 0,
    'BOWNS': 0,
    'BOWREN': 0,
    'BOWRING': 0,
    'BOWRON': 0,
    'BOWRY': 0,
    'BOWS': 0,
    'BOWSER': 0,
    'BOWSHER': 0,
    'BOWSHIER': 0,
    'BOWSKY': 0,
    'BOWSMAN': 0,
    'BOWTHORPE': 0,
    'BOWTON': 0,
    'BOWYER': 0,
    'BOWZER': 0,
    'BOX': 0,
    'BOXALL': 0,
    'BOXBERGER': 0,
    'BOXDORFER': 0,
    'BOXELL': 0,
    'BOXER': 0,
    'BOXIE': 0,
    'BOXILL': 0,
    'BOXLEITNER': 0,
    'BOXLER': 0,
    'BOXLEY': 0,
    'BOXMAN': 0,
    'BOXRUD': 0,
    'BOXTON': 0,
    'BOXWELL': 0,
    'BOXX': 0,
    'BOY': 0,
    'BOYA': 0,
    'BOYACK': 0,
    'BOYADJIAN': 0,
    'BOYADZHYAN': 0,
    'BOYAJIAN': 0,
    'BOYAN': 0,
    'BOYANCE': 0,
    'BOYANOWSKI': 0,
    'BOYANTON': 0,
    'BOYAR': 0,
    'BOYARSKI': 0,
    'BOYARSKY': 0,
    'BOYAS': 0,
    'BOYATT': 0,
    'BOYCE': 0.2915451895043732,
    'BOYCHUCK': 0,
    'BOYCHUK': 0,
    'BOYD': 0.25534202392151595,
    'BOYDE': 0,
    'BOYDEN': 0,
    'BOYDSTON': 0,
    'BOYDSTUN': 0,
    'BOYE': 0,
    'BOYEA': 0,
    'BOYED': 0,
    'BOYENGA': 0,
    'BOYENS': 0,
    'BOYER': 0,
    'BOYERS': 0,
    'BOYES': 0,
    'BOYET': 0,
    'BOYETT': 0,
    'BOYETTE': 0,
    'BOYHAN': 0,
    'BOYHER': 0,
    'BOYINGTON': 0,
    'BOYK': 0,
    'BOYKE': 0,
    'BOYKEN': 0,
    'BOYKIN': 0,
    'BOYKINS': 0,
    'BOYKO': 0,
    'BOYL': 0,
    'BOYLAN': 0,
    'BOYLAND': 0,
    'BOYLE': 0,
    'BOYLEN': 0,
    'BOYLER': 0,
    'BOYLES': 0,
    'BOYLL': 0,
    'BOYLSTON': 0,
    'BOYNE': 0,
    'BOYNES': 0,
    'BOYNTON': 0,
    'BOYS': 0,
    'BOYSAW': 0,
    'BOYSE': 0,
    'BOYSEL': 0,
    'BOYSEN': 0,
    'BOYSON': 0,
    'BOYSTER': 0,
    'BOYT': 0,
    'BOYTE': 0,
    'BOYTER': 0,
    'BOYTIM': 0,
    'BOYTON': 0,
    'BOYTS': 0,
    'BOYUM': 0,
    'BOYZO': 0,
    'BOZ': 0,
    'BOZA': 0,
    'BOZAK': 0,
    'BOZAN': 0,
    'BOZANICH': 0,
    'BOZANT': 0,
    'BOZARD': 0,
    'BOZART': 0,
    'BOZARTH': 0,
    'BOZE': 0,
    'BOZEK': 0,
    'BOZELL': 0,
    'BOZEMAN': 0,
    'BOZER': 0,
    'BOZIC': 0,
    'BOZICEVICH': 0,
    'BOZICH': 0,
    'BOZICK': 0,
    'BOZIER': 0,
    'BOZIK': 0,
    'BOZIN': 0,
    'BOZKURT': 0,
    'BOZMAN': 0,
    'BOZO': 0,
    'BOZONE': 0,
    'BOZOVICH': 0,
    'BOZUNG': 0,
    'BOZYK': 0,
    'BOZYNSKI': 0,
    'BOZZA': 0,
    'BOZZELLI': 0,
    'BOZZI': 0,
    'BOZZINI': 0,
    'BOZZO': 0,
    'BOZZONE': 0,
    'BOZZUTO': 0,
    'BR': 0,
    'BRAA': 0,
    'BRAACK': 0,
    'BRAAK': 0,
    'BRAAKSMA': 0,
    'BRAAM': 0,
    'BRAASCH': 0,
    'BRAAT': 0,
    'BRAATEN': 0,
    'BRAATHEN': 0,
    'BRAATZ': 0,
    'BRABAND': 0,
    'BRABANDER': 0,
    'BRABANDT': 0,
    'BRABANT': 0,
    'BRABAW': 0,
    'BRABAZON': 0,
    'BRABB': 0,
    'BRABBLE': 0,
    'BRABBS': 0,
    'BRABEC': 0,
    'BRABECK': 0,
    'BRABENDER': 0,
    'BRABHAM': 0,
    'BRABO': 0,
    'BRABON': 0,
    'BRABOY': 0,
    'BRABSON': 0,
    'BRABSTON': 0,
    'BRABY': 0,
    'BRACA': 0,
    'BRACAGLIA': 0,
    'BRACALE': 0,
    'BRACAMONTE': 0,
    'BRACAMONTES': 0,
    'BRACCHI': 0,
    'BRACCI': 0,
    'BRACCIA': 0,
    'BRACCIALE': 0,
    'BRACCINI': 0,
    'BRACCIO': 0,
    'BRACCO': 0,
    'BRACE': 0,
    'BRACELIN': 0,
    'BRACERO': 0,
    'BRACEROS': 0,
    'BRACEWELL': 0,
    'BRACEY': 0,
    'BRACH': 0,
    'BRACHA': 0,
    'BRACHE': 0,
    'BRACHER': 0,
    'BRACHFELD': 0,
    'BRACHMAN': 0,
    'BRACHMANN': 0,
    'BRACHO': 0,
    'BRACHT': 0,
    'BRACK': 0,
    'BRACKBILL': 0,
    'BRACKE': 0,
    'BRACKEEN': 0,
    'BRACKEN': 0,
    'BRACKENBURY': 0,
    'BRACKENRICH': 0,
    'BRACKENRIDGE': 0,
    'BRACKENS': 0,
    'BRACKER': 0,
    'BRACKET': 0,
    'BRACKETT': 0,
    'BRACKEY': 0,
    'BRACKIN': 0,
    'BRACKINS': 0,
    'BRACKLEY': 0,
    'BRACKMAN': 0,
    'BRACKMANN': 0,
    'BRACKNELL': 0,
    'BRACKNER': 0,
    'BRACKNEY': 0,
    'BRACONE': 0,
    'BRACY': 0,
    'BRAD': 0.9982223437713661,
    'BRADA': 0,
    'BRADAC': 0,
    'BRADACH': 0,
    'BRADBERRY': 0,
    'BRADBERY': 0,
    'BRADBURN': 0,
    'BRADBURRY': 0,
    'BRADBURY': 0,
    'BRADBY': 0,
    'BRADD': 0,
    'BRADDICK': 0,
    'BRADDOCK': 0,
    'BRADDON': 0,
    'BRADDS': 0,
    'BRADDY': 0,
    'BRADE': 0,
    'BRADEEN': 0,
    'BRADEL': 0,
    'BRADELY': 0,
    'BRADEN': 0,
    'BRADER': 0,
    'BRADEY': 0,
    'BRADFIELD': 0,
    'BRADFORD': 0.5227781926811053,
    'BRADFUTE': 0,
    'BRADHAM': 0,
    'BRADIGAN': 0,
    'BRADIN': 0,
    'BRADING': 0,
    'BRADISH': 0,
    'BRADKE': 0,
    'BRADLE': 0,
    'BRADLEE': 0,
    'BRADLEY': 0.7656377907256706,
    'BRADLY': 0.9541984732824428,
    'BRADMAN': 0,
    'BRADNER': 0,
    'BRADNEY': 0,
    'BRADO': 0,
    'BRADON': 0,
    'BRADOW': 0,
    'BRADRICK': 0,
    'BRADSHAW': 0,
    'BRADSHER': 0,
    'BRADSTOCK': 0,
    'BRADSTREET': 0,
    'BRADT': 0,
    'BRADTKE': 0,
    'BRADTMUELLER': 0,
    'BRADWAY': 0,
    'BRADWELL': 0,
    'BRADY': 0.3467062902426944,
    'BRAEGELMANN': 0,
    'BRAEGER': 0,
    'BRAEGGER': 0,
    'BRAEM': 0,
    'BRAEMER': 0,
    'BRAENDLE': 0,
    'BRAESCH': 0,
    'BRAESE': 0,
    'BRAET': 0,
    'BRAEUTIGAM': 0,
    'BRAFF': 0,
    'BRAFFORD': 0,
    'BRAFMAN': 0,
    'BRAFORD': 0,
    'BRAGA': 0,
    'BRAGADO': 0,
    'BRAGALONE': 0,
    'BRAGAN': 0,
    'BRAGANCA': 0,
    'BRAGANZA': 0,
    'BRAGDON': 0,
    'BRAGE': 0,
    'BRAGER': 0,
    'BRAGET': 0,
    'BRAGG': 0,
    'BRAGGER': 0,
    'BRAGGS': 0,
    'BRAGIEL': 0,
    'BRAGIN': 0,
    'BRAGINSKY': 0,
    'BRAGLIA': 0,
    'BRAGLIN': 0,
    'BRAGMAN': 0,
    'BRAGUE': 0,
    'BRAGUNIER': 0,
    'BRAGWELL': 0,
    'BRAHA': 0,
    'BRAHAM': 0,
    'BRAHAN': 0,
    'BRAHIER': 0,
    'BRAHIM': 0,
    'BRAHIMI': 0,
    'BRAHLER': 0,
    'BRAHM': 0,
    'BRAHMBHATT': 0,
    'BRAHMER': 0,
    'BRAHMS': 0,
    'BRAHS': 0,
    'BRAICA': 0,
    'BRAICH': 0,
    'BRAID': 0,
    'BRAIDA': 0,
    'BRAIDWOOD': 0,
    'BRAIG': 0,
    'BRAIL': 0,
    'BRAILE': 0,
    'BRAILEY': 0,
    'BRAILSFORD': 0,
    'BRAIM': 0,
    'BRAIMAN': 0,
    'BRAIN': 0.9608277900960829,
    'BRAINARD': 0,
    'BRAINE': 0,
    'BRAINERD': 0,
    'BRAININ': 0,
    'BRAIS': 0,
    'BRAISTED': 0,
    'BRAITH': 0,
    'BRAITHWAIT': 0,
    'BRAITHWAITE': 0,
    'BRAJKOVICH': 0,
    'BRAKE': 0,
    'BRAKEALL': 0,
    'BRAKEBILL': 0,
    'BRAKEFIELD': 0,
    'BRAKEL': 0,
    'BRAKEMAN': 0,
    'BRAKENSIEK': 0,
    'BRAKER': 0,
    'BRAKEY': 0,
    'BRAKHAGE': 0,
    'BRAKKE': 0,
    'BRAL': 0,
    'BRALEY': 0,
    'BRALLEY': 0,
    'BRALLIER': 0,
    'BRALY': 0,
    'BRAM': 0,
    'BRAMALL': 0,
    'BRAMAN': 0,
    'BRAMANTE': 0,
    'BRAMASCO': 0,
    'BRAMBILA': 0,
    'BRAMBILLA': 0,
    'BRAMBLE': 0,
    'BRAMBLETT': 0,
    'BRAMBLEY': 0,
    'BRAMBRINK': 0,
    'BRAME': 0,
    'BRAMEL': 0,
    'BRAMELL': 0,
    'BRAMER': 0,
    'BRAMES': 0,
    'BRAMHALL': 0,
    'BRAMHAM': 0,
    'BRAMLAGE': 0,
    'BRAMLET': 0,
    'BRAMLETT': 0,
    'BRAMLETTE': 0,
    'BRAMLEY': 0,
    'BRAMLITT': 0,
    'BRAMM': 0,
    'BRAMMEIER': 0,
    'BRAMMELL': 0,
    'BRAMMER': 0,
    'BRAMON': 0,
    'BRAMS': 0,
    'BRAMSEN': 0,
    'BRAMSON': 0,
    'BRAMSTEDT': 0,
    'BRAMUCCI': 0,
    'BRAMWELL': 0,
    'BRAN': 0,
    'BRANA': 0,
    'BRANAGAN': 0,
    'BRANAGH': 0,
    'BRANAM': 0,
    'BRANAMAN': 0,
    'BRANAN': 0,
    'BRANAS': 0,
    'BRANAUGH': 0,
    'BRANCA': 0,
    'BRANCACCIO': 0,
    'BRANCALEONE': 0,
    'BRANCATI': 0,
    'BRANCATO': 0,
    'BRANCAZIO': 0,
    'BRANCH': 0,
    'BRANCHAUD': 0,
    'BRANCHCOMB': 0,
    'BRANCHE': 0,
    'BRANCHEAU': 0,
    'BRANCHINI': 0,
    'BRANCIFORTE': 0,
    'BRANCO': 0,
    'BRAND': 0,
    'BRANDA': 0.9132420091324202,
    'BRANDAL': 0,
    'BRANDAN': 0,
    'BRANDANO': 0,
    'BRANDAO': 0,
    'BRANDAU': 0,
    'BRANDE': 0.8849557522123894,
    'BRANDEBERRY': 0,
    'BRANDEBURG': 0,
    'BRANDEE': 1,
    'BRANDEIS': 0,
    'BRANDEL': 0,
    'BRANDELL': 0,
    'BRANDEN': 0.98159509202454,
    'BRANDENBERG': 0,
    'BRANDENBERGER': 0,
    'BRANDENBURG': 0,
    'BRANDENBURGER': 0,
    'BRANDENBURGH': 0,
    'BRANDENSTEIN': 0,
    'BRANDER': 0,
    'BRANDERHORST': 0,
    'BRANDES': 0,
    'BRANDEWIE': 0,
    'BRANDFORD': 0,
    'BRANDHORST': 0,
    'BRANDI': 0.9945750452079567,
    'BRANDIE': 1,
    'BRANDIES': 0,
    'BRANDIMARTE': 0,
    'BRANDIMORE': 0,
    'BRANDIN': 0,
    'BRANDIS': 0,
    'BRANDKAMP': 0,
    'BRANDL': 0,
    'BRANDLE': 0,
    'BRANDLER': 0,
    'BRANDLEY': 0,
    'BRANDLI': 0,
    'BRANDLY': 0,
    'BRANDMAN': 0,
    'BRANDMEYER': 0,
    'BRANDNER': 0,
    'BRANDO': 0,
    'BRANDOLINI': 0,
    'BRANDOLINO': 0,
    'BRANDOM': 0,
    'BRANDON': 0.9650447530295775,
    'BRANDONISIO': 0,
    'BRANDOW': 0,
    'BRANDRETH': 0,
    'BRANDRIFF': 0,
    'BRANDS': 0,
    'BRANDSEN': 0,
    'BRANDSMA': 0,
    'BRANDSTATTER': 0,
    'BRANDSTETTER': 0,
    'BRANDSTROM': 0,
    'BRANDT': 0,
    'BRANDTS': 0,
    'BRANDVOLD': 0,
    'BRANDWEIN': 0,
    'BRANDY': 0.9929078014184397,
    'BRANDYBERRY': 0,
    'BRANDYBURG': 0,
    'BRANDYS': 0,
    'BRANE': 0,
    'BRANEFF': 0,
    'BRANEN': 0,
    'BRANER': 0,
    'BRANES': 0,
    'BRANFORD': 0,
    'BRANG': 0,
    'BRANGAN': 0,
    'BRANGER': 0,
    'BRANGERS': 0,
    'BRANHAM': 0,
    'BRANHAN': 0,
    'BRANICK': 0,
    'BRANIFF': 0,
    'BRANIGAN': 0,
    'BRANIM': 0,
    'BRANIN': 0,
    'BRANINE': 0,
    'BRANK': 0,
    'BRANKA': 0,
    'BRANKER': 0,
    'BRANKIN': 0,
    'BRANKLEY': 0,
    'BRANKS': 0,
    'BRANLEY': 0,
    'BRANN': 0,
    'BRANNAGAN': 0,
    'BRANNAM': 0,
    'BRANNAN': 0,
    'BRANNEN': 0,
    'BRANNER': 0,
    'BRANNICK': 0,
    'BRANNIGAN': 0,
    'BRANNIN': 0,
    'BRANNING': 0,
    'BRANNOCK': 0,
    'BRANNON': 0,
    'BRANNUM': 0,
    'BRANOFF': 0,
    'BRANOM': 0,
    'BRANON': 0,
    'BRANS': 0,
    'BRANSCOM': 0,
    'BRANSCOMB': 0,
    'BRANSCOMBE': 0,
    'BRANSCOME': 0,
    'BRANSCUM': 0,
    'BRANSFIELD': 0,
    'BRANSFORD': 0,
    'BRANSHAW': 0,
    'BRANSKI': 0,
    'BRANSKY': 0,
    'BRANSOM': 0,
    'BRANSON': 0,
    'BRANSTAD': 0,
    'BRANSTETTER': 0,
    'BRANSTITER': 0,
    'BRANSTNER': 0,
    'BRANSTON': 0,
    'BRANSTROM': 0,
    'BRANT': 0.6097560975609756,
    'BRANTHOOVER': 0,
    'BRANTING': 0,
    'BRANTINGHAM': 0,
    'BRANTL': 0,
    'BRANTLEY': 0,
    'BRANTLY': 0,
    'BRANTMAN': 0,
    'BRANTMEIER': 0,
    'BRANTNER': 0,
    'BRANTON': 0,
    'BRANTZ': 0,
    'BRANUM': 0,
    'BRANYAN': 0,
    'BRANYON': 0,
    'BRANZ': 0,
    'BRAQUET': 0,
    'BRAR': 0,
    'BRAREN': 0,
    'BRAS': 0,
    'BRASCH': 0,
    'BRASCHLER': 0,
    'BRASCO': 0,
    'BRASE': 0,
    'BRASEL': 0,
    'BRASELL': 0,
    'BRASELTON': 0,
    'BRASETH': 0,
    'BRASFIELD': 0,
    'BRASH': 0,
    'BRASHARES': 0,
    'BRASHAW': 0,
    'BRASHEAR': 0,
    'BRASHEARS': 0,
    'BRASHER': 0,
    'BRASHERS': 0,
    'BRASHIER': 0,
    'BRASIE': 0,
    'BRASIEL': 0,
    'BRASIER': 0,
    'BRASIL': 0,
    'BRASILE': 0,
    'BRASINGTON': 0,
    'BRASK': 0,
    'BRASKET': 0,
    'BRASKETT': 0,
    'BRASKI': 0,
    'BRASKO': 0,
    'BRASLEY': 0,
    'BRASLOW': 0,
    'BRASMER': 0,
    'BRASS': 0,
    'BRASSARD': 0,
    'BRASSART': 0,
    'BRASSE': 0,
    'BRASSEAUX': 0,
    'BRASSEL': 0,
    'BRASSELL': 0,
    'BRASSER': 0,
    'BRASSETTE': 0,
    'BRASSEUR': 0,
    'BRASSFIELD': 0,
    'BRASSIL': 0,
    'BRASSINGTON': 0,
    'BRAST': 0,
    'BRASTAD': 0,
    'BRASTED': 0,
    'BRASUELL': 0,
    'BRASURE': 0,
    'BRASWELL': 0,
    'BRATCHER': 0,
    'BRATE': 0,
    'BRATEK': 0,
    'BRATEN': 0,
    'BRATENG': 0,
    'BRATH': 0,
    'BRATHWAITE': 0,
    'BRATIC': 0,
    'BRATINA': 0,
    'BRATKA': 0,
    'BRATKO': 0,
    'BRATKOWSKI': 0,
    'BRATLAND': 0,
    'BRATLEY': 0,
    'BRATLIE': 0,
    'BRATLIEN': 0,
    'BRATMAN': 0,
    'BRATON': 0,
    'BRATRUD': 0,
    'BRATSCH': 0,
    'BRATSCHI': 0,
    'BRATT': 0,
    'BRATTA': 0,
    'BRATTAIN': 0,
    'BRATTEN': 0,
    'BRATTER': 0,
    'BRATTIN': 0,
    'BRATTOLI': 0,
    'BRATTON': 0,
    'BRATU': 0,
    'BRATVOLD': 0,
    'BRATZ': 0,
    'BRAU': 0,
    'BRAUCH': 0,
    'BRAUCHER': 0,
    'BRAUCHLE': 0,
    'BRAUCHLER': 0,
    'BRAUCHT': 0,
    'BRAUD': 0,
    'BRAUDAWAY': 0,
    'BRAUDE': 0,
    'BRAUDIS': 0,
    'BRAUDRICK': 0,
    'BRAUEN': 0,
    'BRAUER': 0,
    'BRAUGHLER': 0,
    'BRAUGHT': 0,
    'BRAUGHTON': 0,
    'BRAULICK': 0,
    'BRAULT': 0,
    'BRAUM': 0,
    'BRAUN': 0,
    'BRAUNAGEL': 0,
    'BRAUNBECK': 0,
    'BRAUNBERGER': 0,
    'BRAUND': 0,
    'BRAUNE': 0,
    'BRAUNECKER': 0,
    'BRAUNEIS': 0,
    'BRAUNER': 0,
    'BRAUNFELD': 0,
    'BRAUNGER': 0,
    'BRAUNING': 0,
    'BRAUNINGER': 0,
    'BRAUNLICH': 0,
    'BRAUNREITER': 0,
    'BRAUNS': 0,
    'BRAUNSCHEIDEL': 0,
    'BRAUNSCHWEIG': 0,
    'BRAUNSCHWEIGER': 0,
    'BRAUNSDORF': 0,
    'BRAUNSTEIN': 0,
    'BRAUNWORTH': 0,
    'BRAUS': 0,
    'BRAUSCH': 0,
    'BRAUSE': 0,
    'BRAUSEN': 0,
    'BRAUSER': 0,
    'BRAUTIGAM': 0,
    'BRAUTIGAN': 0,
    'BRAVARD': 0,
    'BRAVATA': 0,
    'BRAVE': 0,
    'BRAVEMAN': 0,
    'BRAVENDER': 0,
    'BRAVENEC': 0,
    'BRAVER': 0,
    'BRAVERMAN': 0,
    'BRAVIN': 0,
    'BRAVO': 0,
    'BRAVOS': 0,
    'BRAWAND': 0,
    'BRAWDY': 0,
    'BRAWER': 0,
    'BRAWLEY': 0,
    'BRAWN': 0,
    'BRAWNER': 0,
    'BRAXTON': 0,
    'BRAY': 0,
    'BRAYALL': 0,
    'BRAYBOY': 0,
    'BRAYDEN': 0,
    'BRAYE': 0,
    'BRAYER': 0,
    'BRAYFIELD': 0,
    'BRAYLEY': 0,
    'BRAYLOCK': 0,
    'BRAYMAN': 0,
    'BRAYMEN': 0,
    'BRAYMER': 0,
    'BRAYMILLER': 0,
    'BRAYSHAW': 0,
    'BRAYTON': 0,
    'BRAZ': 0,
    'BRAZA': 0,
    'BRAZAITIS': 0,
    'BRAZAN': 0,
    'BRAZAS': 0,
    'BRAZAUSKAS': 0,
    'BRAZDA': 0,
    'BRAZE': 0,
    'BRAZEAL': 0,
    'BRAZEALE': 0,
    'BRAZEAU': 0,
    'BRAZEE': 0,
    'BRAZEEL': 0,
    'BRAZEL': 0,
    'BRAZELL': 0,
    'BRAZELTON': 0,
    'BRAZEN': 0,
    'BRAZER': 0,
    'BRAZIE': 0,
    'BRAZIEL': 0,
    'BRAZIER': 0,
    'BRAZIL': 0,
    'BRAZILE': 0,
    'BRAZILL': 0,
    'BRAZILLE': 0,
    'BRAZINA': 0,
    'BRAZINGTON': 0,
    'BRAZINSKI': 0,
    'BRAZIS': 0,
    'BRAZLE': 0,
    'BRAZLEY': 0,
    'BRAZO': 0,
    'BRAZWELL': 0,
    'BRAZZALE': 0,
    'BRAZZEAL': 0,
    'BRAZZEL': 0,
    'BRAZZELL': 0,
    'BRAZZIL': 0,
    'BRAZZLE': 0,
    'BRDA': 0,
    'BRDAR': 0,
    'BREA': 0,
    'BREACH': 0,
    'BREAD': 0,
    'BREADEN': 0,
    'BREADON': 0,
    'BREADY': 0,
    'BREAK': 0,
    'BREAKALL': 0,
    'BREAKELL': 0,
    'BREAKER': 0,
    'BREAKEY': 0,
    'BREAKFIELD': 0,
    'BREAKIRON': 0,
    'BREAKSTONE': 0,
    'BREAM': 0,
    'BREAN': 0,
    'BREANA': 1,
    'BREANN': 1,
    'BREANNA': 1,
    'BREANNE': 1,
    'BREAR': 0,
    'BREARD': 0,
    'BREARLEY': 0,
    'BREARTON': 0,
    'BREASHEARS': 0,
    'BREATH': 0,
    'BREAU': 0,
    'BREAUD': 0,
    'BREAULT': 0,
    'BREAUX': 0,
    'BREAZEAL': 0,
    'BREAZEALE': 0,
    'BREAZILE': 0,
    'BREBNER': 0,
    'BRECEDA': 0,
    'BRECH': 0,
    'BRECHBIEL': 0,
    'BRECHBILL': 0,
    'BRECHEEN': 0,
    'BRECHEISEN': 0,
    'BRECHER': 0,
    'BRECHIN': 0,
    'BRECHLER': 0,
    'BRECHLIN': 0,
    'BRECHNER': 0,
    'BRECHT': 0,
    'BRECHTEL': 0,
    'BRECHTELSBAUER': 0,
    'BRECHTING': 0,
    'BRECK': 0,
    'BRECKA': 0,
    'BRECKE': 0,
    'BRECKEL': 0,
    'BRECKENRIDGE': 0,
    'BRECKER': 0,
    'BRECKHEIMER': 0,
    'BRECKINRIDGE': 0,
    'BRECKLER': 0,
    'BRECKLEY': 0,
    'BRECKLIN': 0,
    'BRECKNER': 0,
    'BRECKON': 0,
    'BREDA': 0,
    'BREDAHL': 0,
    'BREDBENNER': 0,
    'BREDBERG': 0,
    'BREDE': 0,
    'BREDEHOEFT': 0,
    'BREDEHOFT': 0,
    'BREDELL': 0,
    'BREDEMANN': 0,
    'BREDEMEIER': 0,
    'BREDEMEYER': 0,
    'BREDEN': 0,
    'BREDENBERG': 0,
    'BREDENKAMP': 0,
    'BREDENSTEINER': 0,
    'BREDER': 0,
    'BREDESEN': 0,
    'BREDESON': 0,
    'BREDEWEG': 0,
    'BREDICE': 0,
    'BREDIN': 0,
    'BREDING': 0,
    'BREDL': 0,
    'BREDLAU': 0,
    'BREDLOW': 0,
    'BREDOW': 0,
    'BREDTHAUER': 0,
    'BREDWELL': 0,
    'BREDY': 0,
    'BREE': 0.9259259259259259,
    'BREECE': 0,
    'BREECH': 0,
    'BREECHER': 0,
    'BREED': 0,
    'BREEDEN': 0,
    'BREEDING': 0,
    'BREEDLOVE': 0,
    'BREEDON': 0,
    'BREEDWELL': 0,
    'BREEDY': 0,
    'BREEGGEMANN': 0,
    'BREEGLE': 0,
    'BREEHL': 0,
    'BREELAND': 0,
    'BREEMAN': 0,
    'BREEMS': 0,
    'BREEN': 0,
    'BREENE': 0,
    'BREER': 0,
    'BREES': 0,
    'BREESE': 0,
    'BREEST': 0,
    'BREEZE': 0,
    'BREEZEE': 0,
    'BREFELD': 0,
    'BREFKA': 0,
    'BREGANTE': 0,
    'BREGAR': 0,
    'BREGE': 0,
    'BREGEL': 0,
    'BREGENZER': 0,
    'BREGER': 0,
    'BREGG': 0,
    'BREGLIA': 0,
    'BREGMAN': 0,
    'BREGOLI': 0,
    'BREHAUT': 0,
    'BREHEIM': 0,
    'BREHENY': 0,
    'BREHL': 0,
    'BREHM': 0,
    'BREHMER': 0,
    'BREHON': 0,
    'BREI': 0,
    'BREID': 0,
    'BREIDEL': 0,
    'BREIDENBACH': 0,
    'BREIDENBAUGH': 0,
    'BREIDENSTEIN': 0,
    'BREIDENTHAL': 0,
    'BREIDER': 0,
    'BREIDIGAN': 0,
    'BREIDING': 0,
    'BREIDINGER': 0,
    'BREIER': 0,
    'BREIG': 0,
    'BREIGHNER': 0,
    'BREIHAN': 0,
    'BREIL': 0,
    'BREILAND': 0,
    'BREILING': 0,
    'BREIMON': 0,
    'BREINDEL': 0,
    'BREINER': 0,
    'BREINES': 0,
    'BREINHOLT': 0,
    'BREINICH': 0,
    'BREINIG': 0,
    'BREINING': 0,
    'BREININGER': 0,
    'BREISACHER': 0,
    'BREISCH': 0,
    'BREISH': 0,
    'BREISINGER': 0,
    'BREISTER': 0,
    'BREIT': 0,
    'BREITBACH': 0,
    'BREITBART': 0,
    'BREITBARTH': 0,
    'BREITE': 0,
    'BREITEN': 0,
    'BREITENBACH': 0,
    'BREITENBUCHER': 0,
    'BREITENFELD': 0,
    'BREITENFELDT': 0,
    'BREITENSTEIN': 0,
    'BREITER': 0,
    'BREITFELDER': 0,
    'BREITFELLER': 0,
    'BREITHAUPT': 0,
    'BREITIGAM': 0,
    'BREITIGAN': 0,
    'BREITINGER': 0,
    'BREITKREUTZ': 0,
    'BREITLING': 0,
    'BREITMAN': 0,
    'BREITMEYER': 0,
    'BREITNER': 0,
    'BREITRICK': 0,
    'BREITSPRECHER': 0,
    'BREITSTEIN': 0,
    'BREITUNG': 0,
    'BREITWEISER': 0,
    'BREITWIESER': 0,
    'BREITZMAN': 0,
    'BREIVIK': 0,
    'BREIVOGEL': 0,
    'BREJCHA': 0,
    'BREKHUS': 0,
    'BREKKE': 0,
    'BREKKEN': 0,
    'BRELAND': 0,
    'BRELJE': 0,
    'BRELL': 0,
    'BRELLENTHIN': 0,
    'BRELSFORD': 0,
    'BREM': 0,
    'BREMAN': 0,
    'BREMBY': 0,
    'BREMEN': 0,
    'BREMENKAMP': 0,
    'BREMER': 0,
    'BREMERMAN': 0,
    'BREMILLER': 0,
    'BREMMER': 0,
    'BREMNER': 0,
    'BREMS': 0,
    'BREMSER': 0,
    'BREMSETH': 0,
    'BREN': 0,
    'BRENA': 0,
    'BRENAMAN': 0,
    'BRENAN': 0,
    'BRENCE': 0,
    'BRENCHLEY': 0,
    'BRENCKLE': 0,
    'BREND': 0,
    'BRENDA': 0.9997363332747408,
    'BRENDAL': 0,
    'BRENDAN': 1,
    'BRENDE': 0,
    'BRENDEL': 0,
    'BRENDEMUEHL': 0,
    'BRENDEN': 0,
    'BRENDER': 0,
    'BRENDLE': 0,
    'BRENDLER': 0,
    'BRENDLINGER': 0,
    'BRENDON': 0.992063492063492,
    'BRENEK': 0,
    'BRENEMAN': 0,
    'BRENENSTUHL': 0,
    'BRENER': 0,
    'BRENES': 0,
    'BRENGEL': 0,
    'BRENGLE': 0,
    'BRENGMAN': 0,
    'BRENING': 0,
    'BRENISER': 0,
    'BRENIZE': 0,
    'BRENIZER': 0,
    'BRENK': 0,
    'BRENKE': 0,
    'BRENKUS': 0,
    'BRENMAN': 0,
    'BRENN': 0,
    'BRENNA': 0.9560229445506692,
    'BRENNAMAN': 0,
    'BRENNAN': 0,
    'BRENNECKE': 0,
    'BRENNEIS': 0,
    'BRENNEISE': 0,
    'BRENNEISEN': 0,
    'BRENNEKE': 0,
    'BRENNEMAN': 0,
    'BRENNEN': 0,
    'BRENNER': 0,
    'BRENNFLECK': 0,
    'BRENNICK': 0,
    'BRENNING': 0,
    'BRENNO': 0,
    'BRENNON': 0,
    'BRENNY': 0,
    'BRENO': 0,
    'BRENON': 0,
    'BRENOT': 0,
    'BRENS': 0,
    'BRENSINGER': 0,
    'BRENSON': 0,
    'BRENT': 0.9702457956015523,
    'BRENTANO': 0,
    'BRENTLEY': 0,
    'BRENTLINGER': 0,
    'BRENTNALL': 0,
    'BRENTON': 0.8955223880597015,
    'BRENTS': 0,
    'BRENTZEL': 0,
    'BRENZ': 0,
    'BRENZA': 0,
    'BRENZEL': 0,
    'BREON': 0,
    'BRERETON': 0,
    'BRES': 0,
    'BRESCH': 0,
    'BRESCHER': 0,
    'BRESCHINI': 0,
    'BRESCIA': 0,
    'BRESCIANI': 0,
    'BRESE': 0,
    'BRESEE': 0,
    'BRESEMAN': 0,
    'BRESETT': 0,
    'BRESETTE': 0,
    'BRESHEARS': 0,
    'BRESHERS': 0,
    'BRESIN': 0,
    'BRESINA': 0,
    'BRESKA': 0,
    'BRESKE': 0,
    'BRESKI': 0,
    'BRESKIN': 0,
    'BRESKO': 0,
    'BRESKY': 0,
    'BRESLAU': 0,
    'BRESLAUER': 0,
    'BRESLAW': 0,
    'BRESLER': 0,
    'BRESLEY': 0,
    'BRESLIN': 0,
    'BRESLOW': 0,
    'BRESNAHAN': 0,
    'BRESNAN': 0,
    'BRESNEN': 0,
    'BRESNICK': 0,
    'BRESS': 0,
    'BRESSAN': 0,
    'BRESSE': 0,
    'BRESSER': 0,
    'BRESSETTE': 0,
    'BRESSI': 0,
    'BRESSIE': 0,
    'BRESSLER': 0,
    'BRESSMAN': 0,
    'BRESSNER': 0,
    'BRESSON': 0,
    'BREST': 0,
    'BRESTEL': 0,
    'BRESTER': 0,
    'BRET': 0.9972299168975068,
    'BRETADO': 0,
    'BRETANA': 0,
    'BRETCHES': 0,
    'BRETER': 0,
    'BRETEY': 0,
    'BRETH': 0,
    'BRETHAUER': 0,
    'BRETHERICK': 0,
    'BRETHERTON': 0,
    'BRETHORST': 0,
    'BRETHOUR': 0,
    'BRETHOUWER': 0,
    'BRETL': 0,
    'BRETO': 0,
    'BRETON': 0,
    'BRETSCH': 0,
    'BRETSCHER': 0,
    'BRETSCHNEIDER': 0,
    'BRETT': 0.9769303201506591,
    'BRETTELL': 0,
    'BRETTHAUER': 0,
    'BRETTIN': 0,
    'BRETTING': 0,
    'BRETTINGEN': 0,
    'BRETTMANN': 0,
    'BRETTON': 0,
    'BRETTSCHNEIDER': 0,
    'BRETZ': 0,
    'BRETZKE': 0,
    'BRETZMAN': 0,
    'BREU': 0,
    'BREUER': 0,
    'BREUKER': 0,
    'BREUKLANDER': 0,
    'BREUNIG': 0,
    'BREUNING': 0,
    'BREUNINGER': 0,
    'BREVARD': 0,
    'BREVELLE': 0,
    'BREVER': 0,
    'BREVETTI': 0,
    'BREVICK': 0,
    'BREVIG': 0,
    'BREVIK': 0,
    'BREVIL': 0,
    'BREVOORT': 0,
    'BREW': 0,
    'BREWBAKER': 0,
    'BREWEN': 0,
    'BREWER': 0,
    'BREWERS': 0,
    'BREWERTON': 0,
    'BREWIN': 0,
    'BREWINGTON': 0,
    'BREWIS': 0,
    'BREWSAUGH': 0,
    'BREWSTER': 0,
    'BREWTON': 0,
    'BREY': 0,
    'BREYER': 0,
    'BREYETTE': 0,
    'BREYFOGLE': 0,
    'BREYLEY': 0,
    'BREYMAN': 0,
    'BREYMEYER': 0,
    'BREZA': 0,
    'BREZEALE': 0,
    'BREZEE': 0,
    'BREZENSKI': 0,
    'BREZINA': 0,
    'BREZINKA': 0,
    'BREZINSKI': 0,
    'BREZINSKY': 0,
    'BREZLER': 0,
    'BREZNAI': 0,
    'BREZNAK': 0,
    'BREZNAY': 0,
    'BREZNIK': 0,
    'BREZOVSKY': 0,
    'BRHEL': 0,
    'BRIA': 0,
    'BRIAGAS': 0,
    'BRIAN': 0.9979012930742671,
    'BRIANA': 0.9940357852882704,
    'BRIAND': 0,
    'BRIANNA': 1,
    'BRIANNE': 1,
    'BRIANO': 0,
    'BRIANS': 0,
    'BRIANT': 0,
    'BRIANTE': 0,
    'BRIAR': 0,
    'BRIARD': 0,
    'BRIBIESCA': 0,
    'BRIBIESCAS': 0,
    'BRICAULT': 0,
    'BRICCA': 0,
    'BRICCO': 0,
    'BRICE': 0.547645125958379,
    'BRICELAND': 0,
    'BRICENO': 0,
    'BRICH': 0,
    'BRICHACEK': 0,
    'BRICHER': 0,
    'BRICHETTO': 0,
    'BRICHTA': 0,
    'BRICK': 0,
    'BRICKA': 0,
    'BRICKEL': 0,
    'BRICKELL': 0,
    'BRICKEN': 0,
    'BRICKER': 0,
    'BRICKERT': 0,
    'BRICKETT': 0,
    'BRICKEY': 0,
    'BRICKHOUSE': 0,
    'BRICKING': 0,
    'BRICKL': 0,
    'BRICKLE': 0,
    'BRICKLER': 0,
    'BRICKLES': 0,
    'BRICKLEY': 0,
    'BRICKMAN': 0,
    'BRICKNELL': 0,
    'BRICKNER': 0,
    'BRICKS': 0,
    'BRICKSON': 0,
    'BRICKUS': 0,
    'BRICKWEG': 0,
    'BRIDA': 0,
    'BRIDDELL': 0,
    'BRIDDICK': 0,
    'BRIDDLE': 0,
    'BRIDE': 0,
    'BRIDEAU': 0,
    'BRIDEGAM': 0,
    'BRIDEGROOM': 0,
    'BRIDEN': 0,
    'BRIDENBAKER': 0,
    'BRIDENBAUGH': 0,
    'BRIDENSTINE': 0,
    'BRIDENTHAL': 0,
    'BRIDER': 0,
    'BRIDES': 0,
    'BRIDEWELL': 0,
    'BRIDGE': 0,
    'BRIDGEFORD': 0,
    'BRIDGEFORTH': 0,
    'BRIDGEMAN': 0,
    'BRIDGEMOHAN': 0,
    'BRIDGEN': 0,
    'BRIDGENS': 0,
    'BRIDGER': 0,
    'BRIDGERS': 0,
    'BRIDGES': 0,
    'BRIDGET': 0.9975615162935048,
    'BRIDGETT': 0.9656652360515022,
    'BRIDGETTE': 0.9966777408637872,
    'BRIDGEWATER': 0,
    'BRIDGEWATERS': 0,
    'BRIDGFORD': 0,
    'BRIDGFORTH': 0,
    'BRIDGHAM': 0,
    'BRIDGMAN': 0,
    'BRIDGMON': 0,
    'BRIDGWATER': 0,
    'BRIDGWOOD': 0,
    'BRIDLE': 0,
    'BRIDLEY': 0,
    'BRIDSON': 0,
    'BRIDWELL': 0,
    'BRIDY': 0,
    'BRIE': 0,
    'BRIED': 0,
    'BRIEDE': 0,
    'BRIEDEN': 0,
    'BRIEDIS': 0,
    'BRIEF': 0,
    'BRIEGEL': 0,
    'BRIEGER': 0,
    'BRIEL': 0,
    'BRIELMAIER': 0,
    'BRIEN': 0,
    'BRIENEN': 0,
    'BRIENO': 0,
    'BRIENZA': 0,
    'BRIENZO': 0,
    'BRIER': 0,
    'BRIERE': 0,
    'BRIERLEY': 0,
    'BRIERLY': 0,
    'BRIERRE': 0,
    'BRIERS': 0,
    'BRIERTON': 0,
    'BRIERY': 0,
    'BRIES': 0,
    'BRIESACHER': 0,
    'BRIESCH': 0,
    'BRIESCHKE': 0,
    'BRIESE': 0,
    'BRIESEMEISTER': 0,
    'BRIESKE': 0,
    'BRIEST': 0,
    'BRIETZKE': 0,
    'BRIEVA': 0,
    'BRIFFA': 0,
    'BRIGANCE': 0,
    'BRIGANDI': 0,
    'BRIGANTE': 0,
    'BRIGANTI': 0,
    'BRIGATI': 0,
    'BRIGDEN': 0,
    'BRIGDON': 0,
    'BRIGES': 0,
    'BRIGETTE': 1,
    'BRIGG': 0,
    'BRIGGEMAN': 0,
    'BRIGGER': 0,
    'BRIGGINS': 0,
    'BRIGGLE': 0,
    'BRIGGMAN': 0,
    'BRIGGS': 0,
    'BRIGHAM': 0,
    'BRIGHENTI': 0,
    'BRIGHT': 0,
    'BRIGHTBILL': 0,
    'BRIGHTFUL': 0,
    'BRIGHTLY': 0,
    'BRIGHTMAN': 0,
    'BRIGHTMON': 0,
    'BRIGHTON': 0,
    'BRIGHTWELL': 0,
    'BRIGID': 1,
    'BRIGIDA': 0.9708737864077669,
    'BRIGITTE': 1,
    'BRIGLIA': 0,
    'BRIGLIO': 0,
    'BRIGMAN': 0,
    'BRIGMON': 0,
    'BRIGMOND': 0,
    'BRIGNAC': 0,
    'BRIGNER': 0,
    'BRIGNOLA': 0,
    'BRIGNONI': 0,
    'BRIGUGLIO': 0,
    'BRIJLALL': 0,
    'BRIJMOHAN': 0,
    'BRIK': 0,
    'BRIKHO': 0,
    'BRIL': 0,
    'BRILES': 0,
    'BRILEY': 0,
    'BRILHANTE': 0,
    'BRILHART': 0,
    'BRILL': 0,
    'BRILLA': 0,
    'BRILLANT': 0,
    'BRILLANTE': 0,
    'BRILLANTES': 0,
    'BRILLER': 0,
    'BRILLHART': 0,
    'BRILLIANT': 0,
    'BRILLO': 0,
    'BRILLON': 0,
    'BRILZ': 0,
    'BRIM': 0,
    'BRIMACOMBE': 0,
    'BRIMAGE': 0,
    'BRIMBERRY': 0,
    'BRIMER': 0,
    'BRIMEYER': 0,
    'BRIMFIELD': 0,
    'BRIMHALL': 0,
    'BRIMLEY': 0,
    'BRIMLOW': 0,
    'BRIMM': 0,
    'BRIMMAGE': 0,
    'BRIMMER': 0,
    'BRIN': 0,
    'BRINCAT': 0,
    'BRINCEFIELD': 0,
    'BRINCK': 0,
    'BRINCKERHOFF': 0,
    'BRINCKMAN': 0,
    'BRINCKS': 0,
    'BRINDA': 0.9615384615384616,
    'BRINDAMOUR': 0,
    'BRINDEL': 0,
    'BRINDIS': 0,
    'BRINDISI': 0,
    'BRINDLE': 0,
    'BRINDLEY': 0,
    'BRINDZA': 0,
    'BRINE': 0,
    'BRINEGAR': 0,
    'BRINER': 0,
    'BRINES': 0,
    'BRINEY': 0,
    'BRING': 0,
    'BRINGARD': 0,
    'BRINGARDNER': 0,
    'BRINGAS': 0,
    'BRINGE': 0,
    'BRINGER': 0,
    'BRINGHAM': 0,
    'BRINGHURST': 0,
    'BRINGLE': 0,
    'BRINGMAN': 0,
    'BRINGS': 0,
    'BRINICH': 0,
    'BRINING': 0,
    'BRININGER': 0,
    'BRININSTOOL': 0,
    'BRINK': 0,
    'BRINKER': 0,
    'BRINKERHOFF': 0,
    'BRINKERT': 0,
    'BRINKHAUS': 0,
    'BRINKHOFF': 0,
    'BRINKLEY': 0,
    'BRINKLOW': 0,
    'BRINKMAN': 0,
    'BRINKMANN': 0,
    'BRINKMEIER': 0,
    'BRINKMEYER': 0,
    'BRINKOETTER': 0,
    'BRINKS': 0,
    'BRINKWORTH': 0,
    'BRINLEE': 0,
    'BRINLEY': 0,
    'BRINN': 0,
    'BRINNEMAN': 0,
    'BRINNER': 0,
    'BRINNING': 0,
    'BRINNON': 0,
    'BRINO': 0,
    'BRINSER': 0,
    'BRINSFIELD': 0,
    'BRINSKO': 0,
    'BRINSON': 0,
    'BRINSTER': 0,
    'BRINSTON': 0,
    'BRINT': 0,
    'BRINTLE': 0,
    'BRINTLEY': 0,
    'BRINTNALL': 0,
    'BRINTON': 0,
    'BRINZA': 0,
    'BRIODY': 0,
    'BRIOLAT': 0,
    'BRION': 0,
    'BRIONES': 0,
    'BRIONEZ': 0,
    'BRIOSO': 0,
    'BRISARD': 0,
    'BRISBANE': 0,
    'BRISBIN': 0,
    'BRISBINE': 0,
    'BRISBOIS': 0,
    'BRISBON': 0,
    'BRISBY': 0,
    'BRISCH': 0,
    'BRISCO': 0,
    'BRISCOE': 0,
    'BRISEBOIS': 0,
    'BRISENDINE': 0,
    'BRISENO': 0,
    'BRISENTINE': 0,
    'BRISITA': 0,
    'BRISK': 0,
    'BRISKE': 0,
    'BRISKER': 0,
    'BRISKEY': 0,
    'BRISKI': 0,
    'BRISKIE': 0,
    'BRISKIN': 0,
    'BRISKMAN': 0,
    'BRISKY': 0,
    'BRISLAWN': 0,
    'BRISLEY': 0,
    'BRISLIN': 0,
    'BRISMAN': 0,
    'BRISON': 0,
    'BRISS': 0,
    'BRISSENDEN': 0,
    'BRISSETT': 0,
    'BRISSETTE': 0,
    'BRISSEY': 0,
    'BRISSON': 0,
    'BRIST': 0,
    'BRISTER': 0,
    'BRISTLE': 0,
    'BRISTLIN': 0,
    'BRISTO': 0,
    'BRISTOL': 0,
    'BRISTOLL': 0,
    'BRISTON': 0,
    'BRISTOR': 0,
    'BRISTOW': 0,
    'BRITA': 0,
    'BRITAIN': 0,
    'BRITANY': 1,
    'BRITCH': 0,
    'BRITCHER': 0,
    'BRITE': 0,
    'BRITES': 0,
    'BRITFORD': 0,
    'BRITLAND': 0,
    'BRITNELL': 0,
    'BRITNER': 0,
    'BRITNEY': 1,
    'BRITNI': 1,
    'BRITO': 0,
    'BRITON': 0,
    'BRITOS': 0,
    'BRITSCH': 0,
    'BRITSCHGI': 0,
    'BRITSON': 0,
    'BRITT': 0.38461538461538464,
    'BRITTA': 1,
    'BRITTAIN': 0,
    'BRITTAN': 0,
    'BRITTANEY': 1,
    'BRITTANI': 1,
    'BRITTANIE': 1,
    'BRITTANY': 0.999487442337263,
    'BRITTELL': 0,
    'BRITTEN': 0,
    'BRITTENHAM': 0,
    'BRITTENUM': 0,
    'BRITTENY': 1,
    'BRITTIAN': 0,
    'BRITTIN': 0,
    'BRITTING': 0,
    'BRITTINGHAM': 0,
    'BRITTLE': 0,
    'BRITTMAN': 0,
    'BRITTNER': 0,
    'BRITTNEY': 1,
    'BRITTNI': 1,
    'BRITTNY': 1,
    'BRITTO': 0,
    'BRITTON': 0,
    'BRITTS': 0,
    'BRITTSAN': 0,
    'BRITZ': 0,
    'BRITZIUS': 0,
    'BRITZMAN': 0,
    'BRIX': 0,
    'BRIXEY': 0,
    'BRIXIE': 0,
    'BRIXIUS': 0,
    'BRIZ': 0,
    'BRIZAN': 0,
    'BRIZARD': 0,
    'BRIZENDINE': 0,
    'BRIZUELA': 0,
    'BRIZZEE': 0,
    'BRIZZI': 0,
    'BRIZZOLARA': 0,
    'BRKIC': 0,
    'BRKICH': 0,
    'BRKOVIC': 0,
    'BRLETIC': 0,
    'BRLETICH': 0,
    'BRNA': 0,
    'BRO': 0,
    'BROACH': 0,
    'BROAD': 0,
    'BROADAWAY': 0,
    'BROADBELT': 0,
    'BROADBENT': 0,
    'BROADBRIDGE': 0,
    'BROADDRICK': 0,
    'BROADDUS': 0,
    'BROADEN': 0,
    'BROADERS': 0,
    'BROADFIELD': 0,
    'BROADFOOT': 0,
    'BROADHEAD': 0,
    'BROADHURST': 0,
    'BROADIE': 0,
    'BROADLEY': 0,
    'BROADMAN': 0,
    'BROADNAX': 0,
    'BROADRICK': 0,
    'BROADSTOCK': 0,
    'BROADSTONE': 0,
    'BROADSTREET': 0,
    'BROADT': 0,
    'BROADUS': 0,
    'BROADWATER': 0,
    'BROADWAY': 0,
    'BROADWELL': 0,
    'BROADY': 0,
    'BROAS': 0,
    'BROBBEY': 0,
    'BROBECK': 0,
    'BROBERG': 0,
    'BROBST': 0,
    'BROBSTON': 0,
    'BROCATO': 0,
    'BROCCARDO': 0,
    'BROCCHINI': 0,
    'BROCCO': 0,
    'BROCCOLI': 0,
    'BROCCOLO': 0,
    'BROCE': 0,
    'BROCH': 0,
    'BROCHARD': 0,
    'BROCHE': 0,
    'BROCHETTI': 0,
    'BROCHIN': 0,
    'BROCHTRUP': 0,
    'BROCHU': 0,
    'BROCIOUS': 0,
    'BROCK': 0.28920308483290486,
    'BROCKAMP': 0,
    'BROCKBANK': 0,
    'BROCKBERG': 0,
    'BROCKE': 0,
    'BROCKEL': 0,
    'BROCKELBANK': 0,
    'BROCKELMAN': 0,
    'BROCKELSBY': 0,
    'BROCKENBERRY': 0,
    'BROCKENBROUGH': 0,
    'BROCKER': 0,
    'BROCKERT': 0,
    'BROCKETT': 0,
    'BROCKETTE': 0,
    'BROCKEY': 0,
    'BROCKHAUS': 0,
    'BROCKHOEFT': 0,
    'BROCKHOFF': 0,
    'BROCKHOUSE': 0,
    'BROCKI': 0,
    'BROCKIE': 0,
    'BROCKINGTON': 0,
    'BROCKINTON': 0,
    'BROCKLEBANK': 0,
    'BROCKLEHURST': 0,
    'BROCKLESBY': 0,
    'BROCKLEY': 0,
    'BROCKMAN': 0,
    'BROCKMANN': 0,
    'BROCKMEIER': 0,
    'BROCKMEYER': 0,
    'BROCKMILLER': 0,
    'BROCKNER': 0,
    'BROCKS': 0,
    'BROCKSCHMIDT': 0,
    'BROCKSMITH': 0,
    'BROCKUS': 0,
    'BROCKWAY': 0,
    'BROCKWELL': 0,
    'BROD': 0,
    'BRODA': 0,
    'BRODAHL': 0,
    'BRODBECK': 0,
    'BRODD': 0,
    'BRODE': 0,
    'BRODEEN': 0,
    'BRODEHL': 0,
    'BRODELL': 0,
    'BRODEN': 0,
    'BRODER': 0,
    'BRODERICK': 0.5154639175257733,
    'BRODERS': 0,
    'BRODERSEN': 0,
    'BRODERSON': 0,
    'BRODEUR': 0,
    'BRODEY': 0,
    'BRODFUEHRER': 0,
    'BRODHAGEN': 0,
    'BRODHEAD': 0,
    'BRODIE': 0,
    'BRODIGAN': 0,
    'BRODIN': 0,
    'BRODINE': 0,
    'BRODISH': 0,
    'BRODKA': 0,
    'BRODKIN': 0,
    'BRODKORB': 0,
    'BRODMAN': 0,
    'BRODMERKEL': 0,
    'BRODNAX': 0,
    'BRODNER': 0,
    'BRODNICK': 0,
    'BRODNICKI': 0,
    'BRODNIK': 0,
    'BRODOCK': 0,
    'BRODOWSKI': 0,
    'BRODRICK': 0,
    'BRODSKAYA': 0,
    'BRODSKY': 0,
    'BRODT': 0,
    'BRODUS': 0,
    'BRODY': 0,
    'BRODZELLER': 0,
    'BRODZIK': 0,
    'BRODZINSKI': 0,
    'BROE': 0,
    'BROECKEL': 0,
    'BROECKER': 0,
    'BROEDEL': 0,
    'BROEDER': 0,
    'BROEGE': 0,
    'BROEHL': 0,
    'BROEHM': 0,
    'BROEK': 0,
    'BROEKEMA': 0,
    'BROEKEMEIER': 0,
    'BROEKER': 0,
    'BROEKHUIZEN': 0,
    'BROEN': 0,
    'BROER': 0,
    'BROERE': 0,
    'BROEREN': 0,
    'BROERING': 0,
    'BROERMAN': 0,
    'BROERMANN': 0,
    'BROERS': 0,
    'BROERSMA': 0,
    'BROESCH': 0,
    'BROESCHE': 0,
    'BROESDER': 0,
    'BROESKE': 0,
    'BROFFMAN': 0,
    'BROFFORD': 0,
    'BROFMAN': 0,
    'BROG': 0,
    'BROGA': 0,
    'BROGAN': 0,
    'BROGDEN': 0,
    'BROGDON': 0,
    'BROGE': 0,
    'BROGEN': 0,
    'BROGGER': 0,
    'BROGGI': 0,
    'BROGHAMMER': 0,
    'BROGLE': 0,
    'BROGLEY': 0,
    'BROGLI': 0,
    'BROGLIE': 0,
    'BROGLIN': 0,
    'BROGLIO': 0,
    'BROGNA': 0,
    'BROGNO': 0,
    'BROGREN': 0,
    'BROHARD': 0,
    'BROHAWN': 0,
    'BROHL': 0,
    'BROHM': 0,
    'BROHMAN': 0,
    'BROICH': 0,
    'BROIDA': 0,
    'BROILES': 0,
    'BROIN': 0,
    'BROITMAN': 0,
    'BROKAMP': 0,
    'BROKATE': 0,
    'BROKAW': 0,
    'BROKENBOROUGH': 0,
    'BROKENSHIRE': 0,
    'BROKER': 0,
    'BROKING': 0,
    'BROKKE': 0,
    'BROKKEN': 0,
    'BROKOS': 0,
    'BROKUS': 0,
    'BROLIN': 0,
    'BROLL': 0,
    'BROLLEY': 0,
    'BROLLIAR': 0,
    'BROLLIER': 0,
    'BROLLY': 0,
    'BROLSMA': 0,
    'BROM': 0,
    'BROMAGEN': 0,
    'BROMAN': 0,
    'BROMBACH': 0,
    'BROMBACHER': 0,
    'BROMBEREK': 0,
    'BROMBERG': 0,
    'BROMBERGER': 0,
    'BROME': 0,
    'BROMELL': 0,
    'BROMEN': 0,
    'BROMENSCHENKEL': 0,
    'BROMER': 0,
    'BROMFIELD': 0,
    'BROMILEY': 0,
    'BROMLEY': 0,
    'BROMLOW': 0,
    'BROMM': 0,
    'BROMMEL': 0,
    'BROMMER': 0,
    'BROMS': 0,
    'BROMUND': 0,
    'BROMWELL': 0,
    'BROMWICH': 0,
    'BRON': 0,
    'BRONAUGH': 0,
    'BRONCHEAU': 0,
    'BRONCHO': 0,
    'BRONCO': 0,
    'BRONDEL': 0,
    'BRONDER': 0,
    'BRONDO': 0,
    'BRONDUM': 0,
    'BRONDYKE': 0,
    'BRONE': 0,
    'BRONER': 0,
    'BRONES': 0,
    'BRONFMAN': 0,
    'BRONG': 0,
    'BRONGER': 0,
    'BRONGIEL': 0,
    'BRONGO': 0,
    'BRONIKOWSKI': 0,
    'BRONISZEWSKI': 0,
    'BRONK': 0,
    'BRONKE': 0,
    'BRONKEMA': 0,
    'BRONKHORST': 0,
    'BRONN': 0,
    'BRONNENBERG': 0,
    'BRONNER': 0,
    'BRONOWICZ': 0,
    'BRONOWSKI': 0,
    'BRONS': 0,
    'BRONSHTEYN': 0,
    'BRONSINK': 0,
    'BRONSKI': 0,
    'BRONSON': 0,
    'BRONSTAD': 0,
    'BRONSTEIN': 0,
    'BRONSTON': 0,
    'BRONTE': 0,
    'BRONWYN': 1,
    'BRONZO': 0,
    'BROOCKS': 0,
    'BROOD': 0,
    'BROOK': 0.7079646017699115,
    'BROOKBANK': 0,
    'BROOKE': 0.9570552147239264,
    'BROOKENS': 0,
    'BROOKER': 0,
    'BROOKES': 0,
    'BROOKEY': 0,
    'BROOKFIELD': 0,
    'BROOKHART': 0,
    'BROOKHOUSE': 0,
    'BROOKHOUSER': 0,
    'BROOKING': 0,
    'BROOKINGS': 0,
    'BROOKINS': 0,
    'BROOKMAN': 0,
    'BROOKNER': 0,
    'BROOKOVER': 0,
    'BROOKS': 0.07272727272727274,
    'BROOKSBANK': 0,
    'BROOKSBY': 0,
    'BROOKSHAW': 0,
    'BROOKSHEAR': 0,
    'BROOKSHER': 0,
    'BROOKSHIER': 0,
    'BROOKSHIRE': 0,
    'BROOKSTEIN': 0,
    'BROOM': 0,
    'BROOMALL': 0,
    'BROOME': 0,
    'BROOMELL': 0,
    'BROOMER': 0,
    'BROOMES': 0,
    'BROOMFIELD': 0,
    'BROOMHALL': 0,
    'BROOMHEAD': 0,
    'BROOMS': 0,
    'BROONER': 0,
    'BROOS': 0,
    'BROPHY': 0,
    'BRORBY': 0,
    'BROS': 0,
    'BROSAM': 0,
    'BROSAMER': 0,
    'BROSCH': 0,
    'BROSCHART': 0,
    'BROSCHE': 0,
    'BROSCIOUS': 0,
    'BROSCO': 0,
    'BROSE': 0,
    'BROSEKER': 0,
    'BROSEMER': 0,
    'BROSEY': 0,
    'BROSH': 0,
    'BROSHAR': 0,
    'BROSHEARS': 0,
    'BROSHOUS': 0,
    'BROSI': 0,
    'BROSIER': 0,
    'BROSIG': 0,
    'BROSIOUS': 0,
    'BROSIUS': 0,
    'BROSKA': 0,
    'BROSKE': 0,
    'BROSKEY': 0,
    'BROSKI': 0,
    'BROSKIE': 0,
    'BROSKO': 0,
    'BROSKY': 0,
    'BROSMAN': 0,
    'BROSMER': 0,
    'BROSNAHAN': 0,
    'BROSNAN': 0,
    'BROSNIHAN': 0,
    'BROSS': 0,
    'BROSSARD': 0,
    'BROSSART': 0,
    'BROSSEAU': 0,
    'BROSSETT': 0,
    'BROSSETTE': 0,
    'BROSSIA': 0,
    'BROSSMAN': 0,
    'BROSSOIT': 0,
    'BROST': 0,
    'BROSTEK': 0,
    'BROSTOFF': 0,
    'BROSTROM': 0,
    'BROSZ': 0,
    'BROTEMARKLE': 0,
    'BROTEN': 0,
    'BROTHEN': 0,
    'BROTHER': 0,
    'BROTHERS': 0,
    'BROTHERSON': 0,
    'BROTHERTON': 0,
    'BROTHMAN': 0,
    'BROTHWELL': 0,
    'BROTMAN': 0,
    'BROTON': 0,
    'BROTSKY': 0,
    'BROTT': 0,
    'BROTTON': 0,
    'BROTZ': 0,
    'BROTZGE': 0,
    'BROTZMAN': 0,
    'BROU': 0,
    'BROUARD': 0,
    'BROUCEK': 0,
    'BROUDE': 0,
    'BROUDER': 0,
    'BROUDY': 0,
    'BROUGH': 0,
    'BROUGHAM': 0,
    'BROUGHAN': 0,
    'BROUGHER': 0,
    'BROUGHMAN': 0,
    'BROUGHT': 0,
    'BROUGHTON': 0,
    'BROUHARD': 0,
    'BROUILLARD': 0,
    'BROUILLET': 0,
    'BROUILLETTE': 0,
    'BROUK': 0,
    'BROUMLEY': 0,
    'BROUN': 0,
    'BROUNSTEIN': 0,
    'BROUS': 0,
    'BROUSARD': 0,
    'BROUSE': 0,
    'BROUSSARD': 0,
    'BROUSSEAU': 0,
    'BROUWER': 0,
    'BROUWERS': 0,
    'BROVELLI': 0,
    'BROVIAK': 0,
    'BROVOLD': 0,
    'BROVONT': 0,
    'BROW': 0,
    'BROWAND': 0,
    'BROWARD': 0,
    'BROWDER': 0,
    'BROWDY': 0,
    'BROWE': 0,
    'BROWELL': 0,
    'BROWEN': 0,
    'BROWER': 0,
    'BROWERS': 0,
    'BROWING': 0,
    'BROWLEY': 0,
    'BROWMAN': 0,
    'BROWN': 0,
    'BROWNAWELL': 0,
    'BROWNBACK': 0,
    'BROWNE': 0,
    'BROWNELL': 0,
    'BROWNEN': 0,
    'BROWNER': 0,
    'BROWNEWELL': 0,
    'BROWNFIELD': 0,
    'BROWNHILL': 0,
    'BROWNIE': 0,
    'BROWNING': 0,
    'BROWNJUNIOR': 0,
    'BROWNLEE': 0,
    'BROWNLEY': 0,
    'BROWNLIE': 0,
    'BROWNLOW': 0,
    'BROWNMILLER': 0,
    'BROWNRIDGE': 0,
    'BROWNRIGG': 0,
    'BROWNSBERGER': 0,
    'BROWNSMITH': 0,
    'BROWNSON': 0,
    'BROWNSTEIN': 0,
    'BROWNSTONE': 0,
    'BROWNSWORD': 0,
    'BROWNWOOD': 0,
    'BROWNYARD': 0,
    'BROWSKI': 0,
    'BROX': 0,
    'BROXMEYER': 0,
    'BROXSON': 0,
    'BROXTERMAN': 0,
    'BROXTON': 0,
    'BROY': 0,
    'BROYAN': 0,
    'BROYARD': 0,
    'BROYER': 0,
    'BROYHILL': 0,
    'BROYLES': 0,
    'BROZ': 0,
    'BROZAK': 0,
    'BROZE': 0,
    'BROZEK': 0,
    'BROZENA': 0,
    'BROZIK': 0,
    'BROZMAN': 0,
    'BROZO': 0,
    'BROZOSKI': 0,
    'BROZOVIC': 0,
    'BROZOVICH': 0,
    'BROZOWSKI': 0,
    'BROZYNA': 0,
    'BRU': 0,
    'BRUA': 0,
    'BRUAN': 0,
    'BRUBACH': 0,
    'BRUBACHER': 0,
    'BRUBACKER': 0,
    'BRUBAKER': 0,
    'BRUBECK': 0,
    'BRUCATO': 0,
    'BRUCCOLERI': 0,
    'BRUCCULERI': 0,
    'BRUCE': 0.931699022247414,
    'BRUCH': 0,
    'BRUCHER': 0,
    'BRUCHEY': 0,
    'BRUCHMAN': 0,
    'BRUCIA': 0,
    'BRUCK': 0,
    'BRUCKART': 0,
    'BRUCKBAUER': 0,
    'BRUCKE': 0,
    'BRUCKELMYER': 0,
    'BRUCKEN': 0,
    'BRUCKER': 0,
    'BRUCKERHOFF': 0,
    'BRUCKERT': 0,
    'BRUCKI': 0,
    'BRUCKLER': 0,
    'BRUCKMAN': 0,
    'BRUCKMANN': 0,
    'BRUCKNER': 0,
    'BRUCKS': 0,
    'BRUCKSCHEN': 0,
    'BRUDER': 0,
    'BRUDERER': 0,
    'BRUDI': 0,
    'BRUDNICKI': 0,
    'BRUDOS': 0,
    'BRUDVIG': 0,
    'BRUDZINSKI': 0,
    'BRUE': 0,
    'BRUECHERT': 0,
    'BRUECK': 0,
    'BRUECKER': 0,
    'BRUECKMAN': 0,
    'BRUECKMANN': 0,
    'BRUECKNER': 0,
    'BRUEGGE': 0,
    'BRUEGGEMAN': 0,
    'BRUEGGEMANN': 0,
    'BRUEGGEN': 0,
    'BRUEGGER': 0,
    'BRUEGMAN': 0,
    'BRUEHL': 0,
    'BRUELL': 0,
    'BRUEMMER': 0,
    'BRUEN': 0,
    'BRUENDERMAN': 0,
    'BRUENE': 0,
    'BRUENER': 0,
    'BRUENGER': 0,
    'BRUENING': 0,
    'BRUENN': 0,
    'BRUENNING': 0,
    'BRUENS': 0,
    'BRUER': 0,
    'BRUESCH': 0,
    'BRUESEWITZ': 0,
    'BRUESHABER': 0,
    'BRUESKE': 0,
    'BRUESS': 0,
    'BRUESTLE': 0,
    'BRUETT': 0,
    'BRUETTE': 0,
    'BRUEWER': 0,
    'BRUEY': 0,
    'BRUFF': 0,
    'BRUFFETT': 0,
    'BRUFFEY': 0,
    'BRUFFY': 0,
    'BRUFLAT': 0,
    'BRUG': 0,
    'BRUGGE': 0,
    'BRUGGEMAN': 0,
    'BRUGGEMANN': 0,
    'BRUGGER': 0,
    'BRUGGINK': 0,
    'BRUGGMAN': 0,
    'BRUGH': 0,
    'BRUGIONI': 0,
    'BRUGLER': 0,
    'BRUGMAN': 0,
    'BRUGMANN': 0,
    'BRUGNOLI': 0,
    'BRUGUIER': 0,
    'BRUHA': 0,
    'BRUHL': 0,
    'BRUHN': 0,
    'BRUHNKE': 0,
    'BRUHNS': 0,
    'BRUICK': 0,
    'BRUIN': 0,
    'BRUINGTON': 0,
    'BRUINING': 0,
    'BRUINS': 0,
    'BRUINSMA': 0,
    'BRUK': 0,
    'BRUKER': 0,
    'BRULAND': 0,
    'BRULE': 0,
    'BRULEY': 0,
    'BRULL': 0,
    'BRULOTTE': 0,
    'BRUM': 0,
    'BRUMAGE': 0,
    'BRUMAGEN': 0,
    'BRUMAGIN': 0,
    'BRUMAN': 0,
    'BRUMBACH': 0,
    'BRUMBACK': 0,
    'BRUMBALOW': 0,
    'BRUMBAUGH': 0,
    'BRUMBELOE': 0,
    'BRUMBELOW': 0,
    'BRUMBERG': 0,
    'BRUMBLE': 0,
    'BRUMBLES': 0,
    'BRUMBLEY': 0,
    'BRUMBY': 0,
    'BRUMER': 0,
    'BRUMETT': 0,
    'BRUMFIEL': 0,
    'BRUMFIELD': 0,
    'BRUMGARD': 0,
    'BRUMIT': 0,
    'BRUMITT': 0,
    'BRUMLEVE': 0,
    'BRUMLEY': 0,
    'BRUMLOW': 0,
    'BRUMM': 0,
    'BRUMMAGE': 0,
    'BRUMME': 0,
    'BRUMMEL': 0,
    'BRUMMELL': 0,
    'BRUMMELS': 0,
    'BRUMMER': 0,
    'BRUMMET': 0,
    'BRUMMETT': 0,
    'BRUMMETTE': 0,
    'BRUMMITT': 0,
    'BRUMMOND': 0,
    'BRUMMUND': 0,
    'BRUMSEY': 0,
    'BRUMWELL': 0,
    'BRUN': 0,
    'BRUNA': 0.8547008547008547,
    'BRUNACHE': 0,
    'BRUNCK': 0,
    'BRUNCKHORST': 0,
    'BRUNDAGE': 0,
    'BRUNDEGE': 0,
    'BRUNDICK': 0,
    'BRUNDIDGE': 0,
    'BRUNDIGE': 0,
    'BRUNDIN': 0,
    'BRUNDLE': 0,
    'BRUNDRETT': 0,
    'BRUNDRIDGE': 0,
    'BRUNDY': 0,
    'BRUNE': 0,
    'BRUNEAU': 0,
    'BRUNECZ': 0,
    'BRUNEEL': 0,
    'BRUNEL': 0,
    'BRUNELL': 0,
    'BRUNELLE': 0,
    'BRUNELLI': 0,
    'BRUNELLO': 0,
    'BRUNER': 0,
    'BRUNES': 0,
    'BRUNET': 0,
    'BRUNETT': 0,
    'BRUNETTA': 0,
    'BRUNETTE': 0,
    'BRUNETTI': 0,
    'BRUNETTO': 0,
    'BRUNEY': 0,
    'BRUNGARD': 0,
    'BRUNGARDT': 0,
    'BRUNGART': 0,
    'BRUNGER': 0,
    'BRUNGES': 0,
    'BRUNGS': 0,
    'BRUNI': 0,
    'BRUNICARDI': 0,
    'BRUNICK': 0,
    'BRUNIE': 0,
    'BRUNILDA': 1,
    'BRUNING': 0,
    'BRUNJES': 0,
    'BRUNK': 0,
    'BRUNKE': 0,
    'BRUNKEN': 0,
    'BRUNKER': 0,
    'BRUNKHORST': 0,
    'BRUNKO': 0,
    'BRUNKOW': 0,
    'BRUNMEIER': 0,
    'BRUNN': 0,
    'BRUNNEMER': 0,
    'BRUNNER': 0,
    'BRUNNERT': 0,
    'BRUNNETT': 0,
    'BRUNNING': 0,
    'BRUNO': 0.48426150121065376,
    'BRUNORI': 0,
    'BRUNOT': 0,
    'BRUNOTTE': 0,
    'BRUNOW': 0,
    'BRUNOZZI': 0,
    'BRUNS': 0,
    'BRUNSELL': 0,
    'BRUNSKILL': 0,
    'BRUNSMAN': 0,
    'BRUNSON': 0,
    'BRUNSSEN': 0,
    'BRUNST': 0,
    'BRUNSTAD': 0,
    'BRUNSTEIN': 0,
    'BRUNSTETTER': 0,
    'BRUNSTING': 0,
    'BRUNSTON': 0,
    'BRUNSVOLD': 0,
    'BRUNSWICK': 0,
    'BRUNSWIG': 0,
    'BRUNT': 0,
    'BRUNTMYER': 0,
    'BRUNTON': 0,
    'BRUNTY': 0,
    'BRUNTZ': 0,
    'BRUNY': 0,
    'BRUNZ': 0,
    'BRUNZELL': 0,
    'BRUPBACHER': 0,
    'BRUS': 0,
    'BRUSA': 0,
    'BRUSATI': 0,
    'BRUSCA': 0,
    'BRUSCATO': 0,
    'BRUSCH': 0,
    'BRUSCHI': 0,
    'BRUSCIA': 0,
    'BRUSCINO': 0,
    'BRUSCO': 0,
    'BRUSE': 0,
    'BRUSER': 0,
    'BRUSEWITZ': 0,
    'BRUSH': 0,
    'BRUSHABER': 0,
    'BRUSHWOOD': 0,
    'BRUSIE': 0,
    'BRUSKE': 0,
    'BRUSKI': 0,
    'BRUSKIN': 0,
    'BRUSKO': 0,
    'BRUSKOTTER': 0,
    'BRUSKY': 0,
    'BRUSO': 0,
    'BRUSOE': 0,
    'BRUSS': 0,
    'BRUSSARD': 0,
    'BRUSSE': 0,
    'BRUSSEAU': 0,
    'BRUSSEL': 0,
    'BRUSSELL': 0,
    'BRUSSO': 0,
    'BRUSSOW': 0,
    'BRUST': 0,
    'BRUSTAD': 0,
    'BRUSTEIN': 0,
    'BRUSTER': 0,
    'BRUSTKERN': 0,
    'BRUSTMAN': 0,
    'BRUSUELAS': 0,
    'BRUSVEN': 0,
    'BRUTCHER': 0,
    'BRUTGER': 0,
    'BRUTLAG': 0,
    'BRUTON': 0,
    'BRUTSCHE': 0,
    'BRUTSCHER': 0,
    'BRUTSMAN': 0,
    'BRUTTO': 0,
    'BRUTTON': 0,
    'BRUTUS': 0,
    'BRUUN': 0,
    'BRUURSEMA': 0,
    'BRUX': 0,
    'BRUXVOORT': 0,
    'BRUYERE': 0,
    'BRUYETTE': 0,
    'BRUYN': 0,
    'BRUYNEEL': 0,
    'BRUZA': 0,
    'BRUZAS': 0,
    'BRUZDA': 0,
    'BRUZDZINSKI': 0,
    'BRUZEK': 0,
    'BRUZZESE': 0,
    'BRUZZI': 0,
    'BRUZZO': 0,
    'BRUZZONE': 0,
    'BRWON': 0,
    'BRY': 0,
    'BRYA': 0,
    'BRYAN': 0.902655708109649,
    'BRYAND': 0,
    'BRYANNA': 1,
    'BRYANS': 0,
    'BRYANT': 0.2762430939226519,
    'BRYAR': 0,
    'BRYARLY': 0,
    'BRYARS': 0,
    'BRYCE': 0.9060022650056625,
    'BRYCH': 0,
    'BRYCHTA': 0,
    'BRYD': 0,
    'BRYDA': 0,
    'BRYDE': 0,
    'BRYDEN': 0,
    'BRYDGES': 0,
    'BRYDIE': 0,
    'BRYDON': 0,
    'BRYDSON': 0,
    'BRYE': 0,
    'BRYEANS': 0,
    'BRYEN': 0,
    'BRYER': 0,
    'BRYERS': 0,
    'BRYERTON': 0,
    'BRYFOGLE': 0,
    'BRYINGTON': 0,
    'BRYJA': 0,
    'BRYK': 0,
    'BRYL': 0,
    'BRYLA': 0,
    'BRYLES': 0,
    'BRYLSKI': 0,
    'BRYMER': 0,
    'BRYN': 0,
    'BRYNDA': 0,
    'BRYNE': 0,
    'BRYNER': 0,
    'BRYNES': 0,
    'BRYNGELSON': 0,
    'BRYNIARSKI': 0,
    'BRYNILDSEN': 0,
    'BRYNN': 1,
    'BRYNT': 0,
    'BRYNTESON': 0,
    'BRYON': 0.9892827699917559,
    'BRYS': 0,
    'BRYSCH': 0,
    'BRYSKI': 0,
    'BRYSON': 0,
    'BRYTE': 0,
    'BRZESKI': 0,
    'BRZEZICKI': 0,
    'BRZEZINSKI': 0,
    'BRZEZNIAK': 0,
    'BRZEZOWSKI': 0,
    'BRZOSKA': 0,
    'BRZOSTEK': 0,
    'BRZOSTOWSKI': 0,
    'BRZOZA': 0,
    'BRZOZOWSKI': 0,
    'BRZUCHALSKI': 0,
    'BRZYCKI': 0,
    'BRZYSKI': 0,
    'BU': 0,
    'BUA': 0,
    'BUAN': 0,
    'BUATTE': 0,
    'BUATTI': 0,
    'BUB': 0,
    'BUBA': 0,
    'BUBACK': 0,
    'BUBACZ': 0,
    'BUBAK': 0,
    'BUBALO': 0,
    'BUBAN': 0,
    'BUBAR': 0,
    'BUBASH': 0,
    'BUBB': 0,
    'BUBBA': 0,
    'BUBE': 0,
    'BUBECK': 0,
    'BUBEL': 0,
    'BUBELA': 0,
    'BUBEN': 0,
    'BUBENIK': 0,
    'BUBER': 0,
    'BUBERT': 0,
    'BUBIER': 0,
    'BUBIS': 0,
    'BUBLIK': 0,
    'BUBLITZ': 0,
    'BUBNIAK': 0,
    'BUBNICK': 0,
    'BUBNIS': 0,
    'BUBOLTZ': 0,
    'BUBOLZ': 0,
    'BUBON': 0,
    'BUBP': 0,
    'BUC': 0,
    'BUCALO': 0,
    'BUCAO': 0,
    'BUCAR': 0,
    'BUCARIA': 0,
    'BUCARO': 0,
    'BUCASAS': 0,
    'BUCCA': 0,
    'BUCCAT': 0,
    'BUCCELLA': 0,
    'BUCCELLATO': 0,
    'BUCCELLI': 0,
    'BUCCERI': 0,
    'BUCCHERI': 0,
    'BUCCHI': 0,
    'BUCCHIERI': 0,
    'BUCCHINO': 0,
    'BUCCI': 0,
    'BUCCIARELLI': 0,
    'BUCCIERI': 0,
    'BUCCIERO': 0,
    'BUCCIGROSSI': 0,
    'BUCCILLI': 0,
    'BUCCINI': 0,
    'BUCCINO': 0,
    'BUCCO': 0,
    'BUCCOLA': 0,
    'BUCE': 0,
    'BUCEK': 0,
    'BUCEY': 0,
    'BUCH': 0,
    'BUCHA': 0,
    'BUCHAK': 0,
    'BUCHALSKI': 0,
    'BUCHALTER': 0,
    'BUCHAN': 0,
    'BUCHANA': 0,
    'BUCHANAN': 0,
    'BUCHANN': 0,
    'BUCHANNAN': 0,
    'BUCHANNON': 0,
    'BUCHANON': 0,
    'BUCHAR': 0,
    'BUCHBERGER': 0,
    'BUCHBINDER': 0,
    'BUCHE': 0,
    'BUCHEGER': 0,
    'BUCHEIT': 0,
    'BUCHEK': 0,
    'BUCHEL': 0,
    'BUCHELE': 0,
    'BUCHELI': 0,
    'BUCHEN': 0,
    'BUCHENROTH': 0,
    'BUCHER': 0,
    'BUCHERT': 0,
    'BUCHHEIM': 0,
    'BUCHHEISTER': 0,
    'BUCHHEIT': 0,
    'BUCHHOLTZ': 0,
    'BUCHHOLZ': 0,
    'BUCHHOP': 0,
    'BUCHHORN': 0,
    'BUCHI': 0,
    'BUCHIGNANI': 0,
    'BUCHIN': 0,
    'BUCHINGER': 0,
    'BUCHINO': 0,
    'BUCHINSKI': 0,
    'BUCHINSKY': 0,
    'BUCHITE': 0,
    'BUCHKO': 0,
    'BUCHKOWSKI': 0,
    'BUCHLER': 0,
    'BUCHLI': 0,
    'BUCHMAN': 0,
    'BUCHMANN': 0,
    'BUCHMEIER': 0,
    'BUCHMILLER': 0,
    'BUCHNER': 0,
    'BUCHOLTZ': 0,
    'BUCHOLZ': 0,
    'BUCHS': 0,
    'BUCHSBAUM': 0,
    'BUCHSER': 0,
    'BUCHTA': 0,
    'BUCHTEL': 0,
    'BUCHTER': 0,
    'BUCHWALD': 0,
    'BUCHWALTER': 0,
    'BUCHWEITZ': 0,
    'BUCHWITZ': 0,
    'BUCHY': 0,
    'BUCIO': 0,
    'BUCIOR': 0,
    'BUCK': 0.20273694880892043,
    'BUCKALEW': 0,
    'BUCKALLEW': 0,
    'BUCKALOO': 0,
    'BUCKBEE': 0,
    'BUCKEL': 0,
    'BUCKELEW': 0,
    'BUCKELS': 0,
    'BUCKENBERGER': 0,
    'BUCKENDAHL': 0,
    'BUCKENDORF': 0,
    'BUCKENMEYER': 0,
    'BUCKENTIN': 0,
    'BUCKER': 0,
    'BUCKERIDGE': 0,
    'BUCKERT': 0,
    'BUCKETT': 0,
    'BUCKEY': 0,
    'BUCKEYE': 0,
    'BUCKHALTER': 0,
    'BUCKHAM': 0,
    'BUCKHANAN': 0,
    'BUCKHANNON': 0,
    'BUCKHANON': 0,
    'BUCKHEISTER': 0,
    'BUCKHEIT': 0,
    'BUCKHOLDT': 0,
    'BUCKHOLT': 0,
    'BUCKHOLTS': 0,
    'BUCKHOLTZ': 0,
    'BUCKHOLZ': 0,
    'BUCKHORN': 0,
    'BUCKHOUSE': 0,
    'BUCKHOUT': 0,
    'BUCKI': 0,
    'BUCKINGHAM': 0,
    'BUCKINS': 0,
    'BUCKIRY': 0,
    'BUCKIUS': 0,
    'BUCKLAND': 0,
    'BUCKLE': 0,
    'BUCKLEN': 0,
    'BUCKLER': 0,
    'BUCKLES': 0,
    'BUCKLESS': 0,
    'BUCKLEW': 0,
    'BUCKLEY': 0,
    'BUCKLIN': 0,
    'BUCKMAN': 0,
    'BUCKMANN': 0,
    'BUCKMASTER': 0,
    'BUCKMEIER': 0,
    'BUCKMILLER': 0,
    'BUCKMINSTER': 0,
    'BUCKMIRE': 0,
    'BUCKMON': 0,
    'BUCKNALL': 0,
    'BUCKNAM': 0,
    'BUCKNELL': 0,
    'BUCKNER': 0,
    'BUCKNOR': 0,
    'BUCKNUM': 0,
    'BUCKO': 0,
    'BUCKRIDGE': 0,
    'BUCKS': 0,
    'BUCKSHAW': 0,
    'BUCKSON': 0,
    'BUCKWALD': 0,
    'BUCKWALTER': 0,
    'BUCKWAY': 0,
    'BUCKWELL': 0,
    'BUCKWORTH': 0,
    'BUCO': 0,
    'BUCOLO': 0,
    'BUCSIT': 0,
    'BUCUR': 0,
    'BUCY': 0,
    'BUCZAK': 0,
    'BUCZEK': 0,
    'BUCZKO': 0,
    'BUCZKOWSKI': 0,
    'BUCZYNSKI': 0,
    'BUD': 0.9900990099009901,
    'BUDA': 0,
    'BUDACH': 0,
    'BUDAHN': 0,
    'BUDAI': 0,
    'BUDAK': 0,
    'BUDAY': 0,
    'BUDD': 0,
    'BUDDE': 0,
    'BUDDEMEYER': 0,
    'BUDDEN': 0,
    'BUDDENBERG': 0,
    'BUDDENHAGEN': 0,
    'BUDDIE': 0,
    'BUDDIN': 0,
    'BUDDING': 0,
    'BUDDINGTON': 0,
    'BUDDLE': 0,
    'BUDDS': 0,
    'BUDDY': 0.9950248756218906,
    'BUDEK': 0,
    'BUDELL': 0,
    'BUDENSIEK': 0,
    'BUDER': 0,
    'BUDERUS': 0,
    'BUDESA': 0,
    'BUDETTI': 0,
    'BUDGE': 0,
    'BUDGETT': 0,
    'BUDHAI': 0,
    'BUDHAN': 0,
    'BUDHOO': 0,
    'BUDHRAM': 0,
    'BUDHU': 0,
    'BUDHWANI': 0,
    'BUDIG': 0,
    'BUDIMAN': 0,
    'BUDIMIR': 0,
    'BUDIN': 0,
    'BUDINE': 0,
    'BUDINGER': 0,
    'BUDINICH': 0,
    'BUDINSKY': 0,
    'BUDISH': 0,
    'BUDKA': 0,
    'BUDKE': 0,
    'BUDLER': 0,
    'BUDLONG': 0,
    'BUDMAN': 0,
    'BUDNER': 0,
    'BUDNEY': 0,
    'BUDNICK': 0,
    'BUDNIEWSKI': 0,
    'BUDNIK': 0,
    'BUDNY': 0,
    'BUDOFF': 0,
    'BUDREAU': 0,
    'BUDRICK': 0,
    'BUDRIS': 0,
    'BUDRO': 0,
    'BUDROW': 0,
    'BUDWAY': 0,
    'BUDWICK': 0,
    'BUDWINE': 0,
    'BUDWORTH': 0,
    'BUDY': 0,
    'BUDZ': 0,
    'BUDZAK': 0,
    'BUDZIAK': 0,
    'BUDZIEN': 0,
    'BUDZIK': 0,
    'BUDZINSKI': 0,
    'BUDZISZ': 0,
    'BUDZISZEWSKI': 0,
    'BUDZYN': 0,
    'BUDZYNSKI': 0,
    'BUE': 0,
    'BUECHE': 0,
    'BUECHEL': 0,
    'BUECHELE': 0,
    'BUECHER': 0,
    'BUECHLEIN': 0,
    'BUECHLER': 0,
    'BUECHNER': 0,
    'BUECHTER': 0,
    'BUECKER': 0,
    'BUECKERS': 0,
    'BUEDEL': 0,
    'BUEGE': 0,
    'BUEHL': 0,
    'BUEHLER': 0,
    'BUEHLMAN': 0,
    'BUEHNE': 0,
    'BUEHNER': 0,
    'BUEHRE': 0,
    'BUEHRER': 0,
    'BUEHRIG': 0,
    'BUEHRING': 0,
    'BUEHRLE': 0,
    'BUEKER': 0,
    'BUEL': 0,
    'BUELER': 0,
    'BUELIN': 0,
    'BUELL': 0,
    'BUELNA': 0,
    'BUELOW': 0,
    'BUELT': 0,
    'BUELTEL': 0,
    'BUELTMANN': 0,
    'BUELVAS': 0,
    'BUEMI': 0,
    'BUEN': 0,
    'BUENA': 0.9174311926605505,
    'BUENAFE': 0,
    'BUENAFLOR': 0,
    'BUENAVENTURA': 0,
    'BUENAVISTA': 0,
    'BUENCAMINO': 0,
    'BUENCONSEJO': 0,
    'BUENDIA': 0,
    'BUENFIL': 0,
    'BUENGER': 0,
    'BUENING': 0,
    'BUENNING': 0,
    'BUENO': 0,
    'BUENROSTRO': 0,
    'BUENRROSTRO': 0,
    'BUENSUCESO': 0,
    'BUENTE': 0,
    'BUENTELLO': 0,
    'BUENTING': 0,
    'BUENVIAJE': 0,
    'BUENZOW': 0,
    'BUER': 0,
    'BUERCK': 0,
    'BUERER': 0,
    'BUERGE': 0,
    'BUERGER': 0,
    'BUERGLER': 0,
    'BUERK': 0,
    'BUERKE': 0,
    'BUERKLE': 0,
    'BUERKLEY': 0,
    'BUERMAN': 0,
    'BUERMANN': 0,
    'BUERSTER': 0,
    'BUESCH': 0,
    'BUESCHEL': 0,
    'BUESCHER': 0,
    'BUESE': 0,
    'BUESGENS': 0,
    'BUESING': 0,
    'BUESKING': 0,
    'BUESO': 0,
    'BUESS': 0,
    'BUESSER': 0,
    'BUESTAN': 0,
    'BUETER': 0,
    'BUETHE': 0,
    'BUETI': 0,
    'BUETOW': 0,
    'BUETTGENBACH': 0,
    'BUETTNER': 0,
    'BUEZO': 0,
    'BUFALINI': 0,
    'BUFALINO': 0,
    'BUFALO': 0,
    'BUFANO': 0,
    'BUFE': 0,
    'BUFF': 0,
    'BUFFA': 0,
    'BUFFALINO': 0,
    'BUFFALO': 0,
    'BUFFALOE': 0,
    'BUFFALOHEAD': 0,
    'BUFFALOW': 0,
    'BUFFARDI': 0,
    'BUFFENBARGER': 0,
    'BUFFER': 0,
    'BUFFETT': 0,
    'BUFFEY': 0,
    'BUFFHAM': 0,
    'BUFFI': 0,
    'BUFFIN': 0,
    'BUFFINGTON': 0,
    'BUFFINTON': 0,
    'BUFFKIN': 0,
    'BUFFMAN': 0,
    'BUFFO': 0,
    'BUFFOLINO': 0,
    'BUFFONE': 0,
    'BUFFORD': 0,
    'BUFFUM': 0,
    'BUFFY': 1,
    'BUFKA': 0,
    'BUFKIN': 0,
    'BUFORD': 0.7117437722419929,
    'BUFTON': 0,
    'BUGA': 0,
    'BUGAI': 0,
    'BUGAJ': 0,
    'BUGAJSKI': 0,
    'BUGANSKI': 0,
    'BUGAR': 0,
    'BUGARA': 0,
    'BUGARIN': 0,
    'BUGAY': 0,
    'BUGAYONG': 0,
    'BUGBEE': 0,
    'BUGDEN': 0,
    'BUGEJA': 0,
    'BUGEL': 0,
    'BUGENHAGEN': 0,
    'BUGG': 0,
    'BUGGAGE': 0,
    'BUGGE': 0,
    'BUGGER': 0,
    'BUGGEY': 0,
    'BUGGIE': 0,
    'BUGGS': 0,
    'BUGGY': 0,
    'BUGH': 0,
    'BUGHER': 0,
    'BUGIELSKI': 0,
    'BUGLER': 0,
    'BUGLINO': 0,
    'BUGLIO': 0,
    'BUGLIONE': 0,
    'BUGNA': 0,
    'BUGNACKI': 0,
    'BUGNER': 0,
    'BUGNI': 0,
    'BUGNO': 0,
    'BUGOS': 0,
    'BUGOSH': 0,
    'BUHAGIAR': 0,
    'BUHAIN': 0,
    'BUHAY': 0,
    'BUHER': 0,
    'BUHITE': 0,
    'BUHL': 0,
    'BUHLE': 0,
    'BUHLER': 0,
    'BUHLIG': 0,
    'BUHLINGER': 0,
    'BUHLMAN': 0,
    'BUHMAN': 0,
    'BUHMANN': 0,
    'BUHR': 0,
    'BUHRER': 0,
    'BUHRING': 0,
    'BUHRKE': 0,
    'BUHRLE': 0,
    'BUHRMAN': 0,
    'BUHRMANN': 0,
    'BUHRMASTER': 0,
    'BUHRMESTER': 0,
    'BUHROW': 0,
    'BUHS': 0,
    'BUHSE': 0,
    'BUI': 0,
    'BUICE': 0,
    'BUICK': 0,
    'BUIE': 0,
    'BUIKEMA': 0,
    'BUILES': 0,
    'BUILTA': 0,
    'BUIS': 0,
    'BUISMAN': 0,
    'BUISSERETH': 0,
    'BUISSON': 0,
    'BUIST': 0,
    'BUIT': 0,
    'BUITER': 0,
    'BUITRAGO': 0,
    'BUITRON': 0,
    'BUJAK': 0,
    'BUJALSKI': 0,
    'BUJAN': 0,
    'BUJANDA': 0,
    'BUJANOWSKI': 0,
    'BUJARSKI': 0,
    'BUJNAK': 0,
    'BUJNOCH': 0,
    'BUJNOWSKI': 0,
    'BUJOL': 0,
    'BUJOLD': 0,
    'BUKACEK': 0,
    'BUKALA': 0,
    'BUKATA': 0,
    'BUKATY': 0,
    'BUKER': 0,
    'BUKHARI': 0,
    'BUKOSKEY': 0,
    'BUKOSKI': 0,
    'BUKOSKY': 0,
    'BUKOVAC': 0,
    'BUKOVEC': 0,
    'BUKOVICH': 0,
    'BUKOVINSKY': 0,
    'BUKOVSKY': 0,
    'BUKOWSKI': 0,
    'BUKOWSKY': 0,
    'BUKSA': 0,
    'BUKSAR': 0,
    'BUKSH': 0,
    'BULA': 0.8264462809917356,
    'BULACH': 0,
    'BULAH': 1,
    'BULAK': 0,
    'BULAN': 0,
    'BULAND': 0,
    'BULANDA': 0,
    'BULANEK': 0,
    'BULAON': 0,
    'BULAS': 0,
    'BULAT': 0,
    'BULATAO': 0,
    'BULAU': 0,
    'BULAWA': 0,
    'BULCHER': 0,
    'BULDO': 0,
    'BULE': 0,
    'BULEN': 0,
    'BULES': 0,
    'BULEY': 0,
    'BULFER': 0,
    'BULFIN': 0,
    'BULFORD': 0,
    'BULGARELLI': 0,
    'BULGER': 0,
    'BULGIN': 0,
    'BULGRIN': 0,
    'BULICH': 0,
    'BULICK': 0,
    'BULIFANT': 0,
    'BULIK': 0,
    'BULIN': 0,
    'BULINGTON': 0,
    'BULINSKI': 0,
    'BULIS': 0,
    'BULJUBASIC': 0,
    'BULK': 0,
    'BULKA': 0,
    'BULKELEY': 0,
    'BULKIN': 0,
    'BULKLEY': 0,
    'BULKO': 0,
    'BULKOWSKI': 0,
    'BULL': 0,
    'BULLA': 0,
    'BULLARD': 0,
    'BULLARO': 0,
    'BULLBEAR': 0,
    'BULLE': 0,
    'BULLEIT': 0,
    'BULLEN': 0,
    'BULLENS': 0,
    'BULLER': 0,
    'BULLERDICK': 0,
    'BULLERI': 0,
    'BULLERMAN': 0,
    'BULLERS': 0,
    'BULLERT': 0,
    'BULLERWELL': 0,
    'BULLETT': 0,
    'BULLEY': 0,
    'BULLICK': 0,
    'BULLIN': 0,
    'BULLINER': 0,
    'BULLING': 0,
    'BULLINGER': 0,
    'BULLINGTON': 0,
    'BULLINS': 0,
    'BULLION': 0,
    'BULLIS': 0,
    'BULLITT': 0,
    'BULLIVANT': 0,
    'BULLMAN': 0,
    'BULLO': 0,
    'BULLOCH': 0,
    'BULLOCK': 0,
    'BULLOCKS': 0,
    'BULLON': 0,
    'BULLOUGH': 0,
    'BULLS': 0,
    'BULLUCK': 0,
    'BULLWINKEL': 0,
    'BULLY': 0,
    'BULMAHN': 0,
    'BULMAN': 0,
    'BULMASH': 0,
    'BULMER': 0,
    'BULNES': 0,
    'BULOCK': 0,
    'BULONE': 0,
    'BULOS': 0,
    'BULOSAN': 0,
    'BULOT': 0,
    'BULOW': 0,
    'BULS': 0,
    'BULSARA': 0,
    'BULSON': 0,
    'BULT': 0,
    'BULTEMA': 0,
    'BULTEMEIER': 0,
    'BULTENA': 0,
    'BULTHUIS': 0,
    'BULTINCK': 0,
    'BULTJE': 0,
    'BULTMAN': 0,
    'BULTMANN': 0,
    'BULTRON': 0,
    'BULTSMA': 0,
    'BULZOMI': 0,
    'BUMA': 0,
    'BUMAGAT': 0,
    'BUMAN': 0,
    'BUMANGLAG': 0,
    'BUMANLAG': 0,
    'BUMANN': 0,
    'BUMATAY': 0,
    'BUMB': 0,
    'BUMBA': 0,
    'BUMBACA': 0,
    'BUMBALOUGH': 0,
    'BUMBARGER': 0,
    'BUMBAUGH': 0,
    'BUMBERA': 0,
    'BUMBRAY': 0,
    'BUMBREY': 0,
    'BUMBY': 0,
    'BUMFORD': 0,
    'BUMGARDNER': 0,
    'BUMGARNER': 0,
    'BUMILLER': 0,
    'BUMM': 0,
    'BUMMER': 0,
    'BUMP': 0,
    'BUMPAS': 0,
    'BUMPASS': 0,
    'BUMPERS': 0,
    'BUMPHUS': 0,
    'BUMPOUS': 0,
    'BUMPS': 0,
    'BUMPUS': 0,
    'BUMSTEAD': 0,
    'BUMSTED': 0,
    'BUN': 0,
    'BUNA': 0,
    'BUNAG': 0,
    'BUNBURY': 0,
    'BUNCE': 0,
    'BUNCH': 0,
    'BUNCHE': 0,
    'BUNCHER': 0,
    'BUNCK': 0,
    'BUND': 0,
    'BUNDA': 0,
    'BUNDAGE': 0,
    'BUNDALIAN': 0,
    'BUNDAY': 0,
    'BUNDE': 0,
    'BUNDERSON': 0,
    'BUNDESEN': 0,
    'BUNDICK': 0,
    'BUNDOCK': 0,
    'BUNDRA': 0,
    'BUNDRAGE': 0,
    'BUNDRANT': 0,
    'BUNDREN': 0,
    'BUNDRICK': 0,
    'BUNDRIDGE': 0,
    'BUNDROCK': 0,
    'BUNDRUM': 0,
    'BUNDSCHUH': 0,
    'BUNDT': 0,
    'BUNDY': 0,
    'BUNE': 0,
    'BUNES': 0,
    'BUNETA': 0,
    'BUNFILL': 0,
    'BUNGARD': 0,
    'BUNGART': 0,
    'BUNGAY': 0,
    'BUNGCAYAO': 0,
    'BUNGE': 0,
    'BUNGER': 0,
    'BUNGERT': 0,
    'BUNGO': 0,
    'BUNIAK': 0,
    'BUNIN': 0,
    'BUNING': 0,
    'BUNION': 0,
    'BUNIS': 0,
    'BUNK': 0,
    'BUNKE': 0,
    'BUNKELMAN': 0,
    'BUNKER': 0,
    'BUNKERS': 0,
    'BUNKLEY': 0,
    'BUNN': 0,
    'BUNNAG': 0,
    'BUNNELL': 0,
    'BUNNER': 0,
    'BUNNEY': 0,
    'BUNNING': 0,
    'BUNNS': 0,
    'BUNNY': 0.9433962264150944,
    'BUNO': 0,
    'BUNS': 0,
    'BUNSE': 0,
    'BUNSELMEYER': 0,
    'BUNT': 0,
    'BUNTAIN': 0,
    'BUNTE': 0,
    'BUNTEN': 0,
    'BUNTIN': 0,
    'BUNTING': 0,
    'BUNTJER': 0,
    'BUNTLEY': 0,
    'BUNTON': 0,
    'BUNTROCK': 0,
    'BUNTS': 0,
    'BUNTY': 0,
    'BUNTYN': 0,
    'BUNTZ': 0,
    'BUNYAK': 0,
    'BUNYAN': 0,
    'BUNYARD': 0,
    'BUNYEA': 0,
    'BUNYON': 0,
    'BUNZ': 0,
    'BUNZEL': 0,
    'BUNZEY': 0,
    'BUOB': 0,
    'BUOL': 0,
    'BUONADONNA': 0,
    'BUONAIUTO': 0,
    'BUONAMICI': 0,
    'BUONANNO': 0,
    'BUONAURO': 0,
    'BUONFIGLIO': 0,
    'BUONGIORNO': 0,
    'BUONI': 0,
    'BUONICONTI': 0,
    'BUONINCONTRI': 0,
    'BUONO': 0,
    'BUONOCORE': 0,
    'BUONOMO': 0,
    'BUONOPANE': 0,
    'BUONPANE': 0,
    'BUONPASTORE': 0,
    'BUONTEMPO': 0,
    'BUOTE': 0,
    'BUOTTE': 0,
    'BUOY': 0,
    'BUPP': 0,
    'BUQUET': 0,
    'BUQUOI': 0,
    'BUR': 0,
    'BURA': 0,
    'BURACK': 0,
    'BURACKER': 0,
    'BURAGE': 0,
    'BURAK': 0,
    'BURAKOWSKI': 0,
    'BURAL': 0,
    'BURALL': 0,
    'BURAN': 0,
    'BURANDT': 0,
    'BURANEN': 0,
    'BURANICH': 0,
    'BURANT': 0,
    'BURAS': 0,
    'BURATTI': 0,
    'BURATTO': 0,
    'BURAU': 0,
    'BURBA': 0,
    'BURBACH': 0,
    'BURBACK': 0,
    'BURBAGE': 0,
    'BURBAN': 0,
    'BURBANK': 0,
    'BURBANO': 0,
    'BURBECK': 0,
    'BURBEE': 0,
    'BURBEY': 0,
    'BURBICK': 0,
    'BURBIDGE': 0,
    'BURBINE': 0,
    'BURBO': 0,
    'BURBOA': 0,
    'BURBRIDGE': 0,
    'BURBRINK': 0,
    'BURBY': 0,
    'BURCAR': 0,
    'BURCAW': 0,
    'BURCE': 0,
    'BURCH': 0,
    'BURCHAM': 0,
    'BURCHARD': 0,
    'BURCHARDT': 0,
    'BURCHART': 0,
    'BURCHELL': 0,
    'BURCHER': 0,
    'BURCHETT': 0,
    'BURCHETTE': 0,
    'BURCHFIEL': 0,
    'BURCHFIELD': 0,
    'BURCHILL': 0,
    'BURCHINAL': 0,
    'BURCHWELL': 0,
    'BURCIAGA': 0,
    'BURCIN': 0,
    'BURCK': 0,
    'BURCKER': 0,
    'BURCKHALTER': 0,
    'BURCKHARD': 0,
    'BURCKHARDT': 0,
    'BURCKLE': 0,
    'BURCROFF': 0,
    'BURCZYK': 0,
    'BURD': 0,
    'BURDA': 0,
    'BURDAN': 0,
    'BURDE': 0,
    'BURDEAU': 0,
    'BURDEAUX': 0,
    'BURDELL': 0,
    'BURDEN': 0,
    'BURDESHAW': 0,
    'BURDESS': 0,
    'BURDETT': 0,
    'BURDETTE': 0,
    'BURDG': 0,
    'BURDGE': 0,
    'BURDI': 0,
    'BURDIC': 0,
    'BURDICK': 0,
    'BURDIER': 0,
    'BURDIN': 0,
    'BURDINE': 0,
    'BURDIS': 0,
    'BURDISS': 0,
    'BURDITT': 0,
    'BURDMAN': 0,
    'BURDO': 0,
    'BURDOCK': 0,
    'BURDON': 0,
    'BURDORF': 0,
    'BURDS': 0,
    'BURDSAL': 0,
    'BURDSALL': 0,
    'BURDT': 0,
    'BURDUE': 0,
    'BURDULIS': 0,
    'BURDZY': 0,
    'BURE': 0,
    'BUREAU': 0,
    'BUREK': 0,
    'BUREL': 0,
    'BURELL': 0,
    'BURELLE': 0,
    'BUREN': 0,
    'BURENHEIDE': 0,
    'BURES': 0,
    'BURESCH': 0,
    'BURESH': 0,
    'BURESS': 0,
    'BURETTA': 0,
    'BUREY': 0,
    'BURFEIND': 0,
    'BURFIELD': 0,
    'BURFIEND': 0,
    'BURFITT': 0,
    'BURFOOT': 0,
    'BURFORD': 0,
    'BURG': 0,
    'BURGA': 0,
    'BURGAMY': 0,
    'BURGAN': 0,
    'BURGANS': 0,
    'BURGARA': 0,
    'BURGARD': 0,
    'BURGARDT': 0,
    'BURGART': 0,
    'BURGASSER': 0,
    'BURGBACHER': 0,
    'BURGDORF': 0,
    'BURGE': 0,
    'BURGEE': 0,
    'BURGEI': 0,
    'BURGEN': 0,
    'BURGENER': 0,
    'BURGER': 0,
    'BURGERMEISTER': 0,
    'BURGERS': 0,
    'BURGERT': 0,
    'BURGES': 0,
    'BURGESON': 0,
    'BURGESS': 0,
    'BURGEST': 0,
    'BURGET': 0,
    'BURGETT': 0,
    'BURGETTE': 0,
    'BURGEY': 0,
    'BURGGRAAF': 0,
    'BURGGRAF': 0,
    'BURGGRAFF': 0,
    'BURGH': 0,
    'BURGHARD': 0,
    'BURGHARDT': 0,
    'BURGHART': 0,
    'BURGHER': 0,
    'BURGHOLZER': 0,
    'BURGHY': 0,
    'BURGI': 0,
    'BURGIE': 0,
    'BURGIN': 0,
    'BURGINS': 0,
    'BURGIO': 0,
    'BURGIS': 0,
    'BURGMAN': 0,
    'BURGMEIER': 0,
    'BURGNER': 0,
    'BURGO': 0,
    'BURGOA': 0,
    'BURGON': 0,
    'BURGOON': 0,
    'BURGOS': 0,
    'BURGOYNE': 0,
    'BURGRAFF': 0,
    'BURGREEN': 0,
    'BURGS': 0,
    'BURGSTAHLER': 0,
    'BURGTORF': 0,
    'BURGUENO': 0,
    'BURGUESS': 0,
    'BURGUN': 0,
    'BURGUNDER': 0,
    'BURGUS': 0,
    'BURGUSS': 0,
    'BURGWALD': 0,
    'BURGWIN': 0,
    'BURGY': 0,
    'BURHAM': 0,
    'BURHANS': 0,
    'BURHART': 0,
    'BURHENN': 0,
    'BURHOE': 0,
    'BURHOP': 0,
    'BURI': 0,
    'BURIA': 0,
    'BURIAK': 0,
    'BURIAN': 0,
    'BURIANEK': 0,
    'BURIC': 0,
    'BURICH': 0,
    'BURICK': 0,
    'BURIK': 0,
    'BURIN': 0,
    'BURING': 0,
    'BURINGTON': 0,
    'BURIS': 0,
    'BURISH': 0,
    'BURITICA': 0,
    'BURJA': 0,
    'BURK': 0,
    'BURKA': 0,
    'BURKARD': 0,
    'BURKARDT': 0,
    'BURKART': 0,
    'BURKDOLL': 0,
    'BURKE': 0,
    'BURKEE': 0,
    'BURKEEN': 0,
    'BURKEL': 0,
    'BURKEMPER': 0,
    'BURKEN': 0,
    'BURKEPILE': 0,
    'BURKER': 0,
    'BURKERT': 0,
    'BURKES': 0,
    'BURKET': 0,
    'BURKETT': 0,
    'BURKETTE': 0,
    'BURKEY': 0,
    'BURKHALTER': 0,
    'BURKHAM': 0,
    'BURKHAMER': 0,
    'BURKHAMMER': 0,
    'BURKHARD': 0,
    'BURKHARDT': 0,
    'BURKHART': 0,
    'BURKHEAD': 0,
    'BURKHEIMER': 0,
    'BURKHOLDER': 0,
    'BURKHOUSE': 0,
    'BURKI': 0,
    'BURKIN': 0,
    'BURKINS': 0,
    'BURKINSHAW': 0,
    'BURKITT': 0,
    'BURKLAND': 0,
    'BURKLE': 0,
    'BURKLEY': 0,
    'BURKLIN': 0,
    'BURKLOW': 0,
    'BURKLUND': 0,
    'BURKMAN': 0,
    'BURKO': 0,
    'BURKOWSKI': 0,
    'BURKS': 0,
    'BURKUM': 0,
    'BURKUS': 0,
    'BURKY': 0,
    'BURL': 0.9433962264150944,
    'BURLAGE': 0,
    'BURLAND': 0,
    'BURLE': 0,
    'BURLEIGH': 0,
    'BURLESON': 0,
    'BURLETT': 0,
    'BURLETTE': 0,
    'BURLEW': 0,
    'BURLEY': 0,
    'BURLEYSON': 0,
    'BURLILE': 0,
    'BURLIN': 0,
    'BURLING': 0,
    'BURLINGAME': 0,
    'BURLINGHAM': 0,
    'BURLINGTON': 0,
    'BURLISON': 0,
    'BURLOCK': 0,
    'BURM': 0,
    'BURMA': 0.9345794392523364,
    'BURMAN': 0,
    'BURMANN': 0,
    'BURMASTER': 0,
    'BURMEISTER': 0,
    'BURMESTER': 0,
    'BURMINGHAM': 0,
    'BURMOOD': 0,
    'BURN': 0,
    'BURNAM': 0,
    'BURNAMAN': 0,
    'BURNAP': 0,
    'BURNARD': 0,
    'BURNASH': 0,
    'BURNAU': 0,
    'BURNAUGH': 0,
    'BURNE': 0,
    'BURNELL': 0,
    'BURNEM': 0,
    'BURNER': 0,
    'BURNES': 0,
    'BURNESS': 0,
    'BURNET': 0,
    'BURNETT': 0,
    'BURNETTE': 0,
    'BURNEY': 0,
    'BURNFIELD': 0,
    'BURNHAM': 0,
    'BURNHEIMER': 0,
    'BURNIAS': 0,
    'BURNIE': 0,
    'BURNIGHT': 0,
    'BURNINGHAM': 0,
    'BURNISON': 0,
    'BURNISTON': 0,
    'BURNITT': 0,
    'BURNLEY': 0,
    'BURNO': 0,
    'BURNOR': 0,
    'BURNS': 0,
    'BURNSED': 0,
    'BURNSIDE': 0,
    'BURNSIDES': 0,
    'BURNSON': 0,
    'BURNSTEIN': 0,
    'BURNSWORTH': 0,
    'BURNUM': 0,
    'BURNUP': 0,
    'BURNWORTH': 0,
    'BURO': 0,
    'BUROKER': 0,
    'BURON': 0,
    'BUROS': 0,
    'BUROW': 0,
    'BURPEE': 0,
    'BURPO': 0,
    'BURQUEZ': 0,
    'BURR': 0,
    'BURRACK': 0,
    'BURRAGE': 0,
    'BURRALL': 0,
    'BURRAN': 0,
    'BURRAS': 0,
    'BURRASTON': 0,
    'BURRE': 0,
    'BURREL': 0,
    'BURRELL': 0,
    'BURRELLI': 0,
    'BURRER': 0,
    'BURRES': 0,
    'BURRESON': 0,
    'BURRESS': 0,
    'BURRETT': 0,
    'BURREY': 0,
    'BURRI': 0,
    'BURRICHTER': 0,
    'BURRIDGE': 0,
    'BURRIE': 0,
    'BURRIER': 0,
    'BURRIES': 0,
    'BURRIESCI': 0,
    'BURRIGHT': 0,
    'BURRIL': 0,
    'BURRILL': 0,
    'BURRINGTON': 0,
    'BURRIOLA': 0,
    'BURRIS': 0,
    'BURRISON': 0,
    'BURRISS': 0,
    'BURRITT': 0,
    'BURROLA': 0,
    'BURROS': 0,
    'BURROSS': 0,
    'BURROUGH': 0,
    'BURROUGHS': 0,
    'BURROUS': 0,
    'BURROW': 0,
    'BURROWES': 0,
    'BURROWS': 0,
    'BURRS': 0,
    'BURRUANO': 0,
    'BURRUEL': 0,
    'BURRUP': 0,
    'BURRUS': 0,
    'BURRUSS': 0,
    'BURRY': 0,
    'BURSAC': 0,
    'BURSACK': 0,
    'BURSAW': 0,
    'BURSCH': 0,
    'BURSE': 0,
    'BURSELL': 0,
    'BURSEY': 0,
    'BURSHTEYN': 0,
    'BURSI': 0,
    'BURSICK': 0,
    'BURSIK': 0,
    'BURSKEY': 0,
    'BURSKI': 0,
    'BURSLEY': 0,
    'BURSON': 0,
    'BURST': 0,
    'BURSTEIN': 0,
    'BURSTON': 0,
    'BURSTYN': 0,
    'BURSZTYN': 0,
    'BURT': 0.3868471953578337,
    'BURTCH': 0,
    'BURTCHAELL': 0,
    'BURTCHELL': 0,
    'BURTCHETT': 0,
    'BURTENSHAW': 0,
    'BURTH': 0,
    'BURTIN': 0,
    'BURTIS': 0,
    'BURTLE': 0,
    'BURTLEY': 0,
    'BURTLOW': 0,
    'BURTMAN': 0,
    'BURTNER': 0,
    'BURTNESS': 0,
    'BURTNETT': 0,
    'BURTOFT': 0,
    'BURTON': 0.2606105733432614,
    'BURTRAM': 0,
    'BURTRUM': 0,
    'BURTS': 0,
    'BURTSCHER': 0,
    'BURTSFIELD': 0,
    'BURTT': 0,
    'BURTTRAM': 0,
    'BURTZ': 0,
    'BURTZLAFF': 0,
    'BURUATO': 0,
    'BURUCA': 0,
    'BURUD': 0,
    'BURUM': 0,
    'BURUS': 0,
    'BURWELL': 0,
    'BURWICK': 0,
    'BURWINKEL': 0,
    'BURWOOD': 0,
    'BURY': 0,
    'BURZA': 0,
    'BURZAWA': 0,
    'BURZINSKI': 0,
    'BURZLAFF': 0,
    'BURZO': 0,
    'BURZYCKI': 0,
    'BURZYNSKI': 0,
    'BUS': 0,
    'BUSA': 0,
    'BUSACCA': 0,
    'BUSACK': 0,
    'BUSACKER': 0,
    'BUSALACCHI': 0,
    'BUSAM': 0,
    'BUSARD': 0,
    'BUSATH': 0,
    'BUSBEA': 0,
    'BUSBEE': 0,
    'BUSBEY': 0,
    'BUSBIN': 0,
    'BUSBOOM': 0,
    'BUSBY': 0,
    'BUSCAGLIA': 0,
    'BUSCAINO': 0,
    'BUSCARINO': 0,
    'BUSCEMA': 0,
    'BUSCEMI': 0,
    'BUSCH': 0,
    'BUSCHBACHER': 0,
    'BUSCHE': 0,
    'BUSCHEL': 0,
    'BUSCHELMAN': 0,
    'BUSCHER': 0,
    'BUSCHING': 0,
    'BUSCHINI': 0,
    'BUSCHJOST': 0,
    'BUSCHKE': 0,
    'BUSCHKOETTER': 0,
    'BUSCHLE': 0,
    'BUSCHMAN': 0,
    'BUSCHMANN': 0,
    'BUSCHO': 0,
    'BUSCHOR': 0,
    'BUSCHOW': 0,
    'BUSCHUR': 0,
    'BUSCIGLIO': 0,
    'BUSCO': 0,
    'BUSE': 0,
    'BUSECK': 0,
    'BUSEK': 0,
    'BUSEMAN': 0,
    'BUSEN': 0,
    'BUSENBARK': 0,
    'BUSENITZ': 0,
    'BUSENLEHNER': 0,
    'BUSER': 0,
    'BUSEY': 0,
    'BUSFIELD': 0,
    'BUSH': 0,
    'BUSHA': 0,
    'BUSHAR': 0,
    'BUSHARD': 0,
    'BUSHART': 0,
    'BUSHATZ': 0,
    'BUSHAW': 0,
    'BUSHBAUM': 0,
    'BUSHBY': 0,
    'BUSHE': 0,
    'BUSHEE': 0,
    'BUSHEK': 0,
    'BUSHELL': 0,
    'BUSHELMAN': 0,
    'BUSHEN': 0,
    'BUSHER': 0,
    'BUSHEY': 0,
    'BUSHFIELD': 0,
    'BUSHI': 0,
    'BUSHIE': 0,
    'BUSHING': 0,
    'BUSHINSKI': 0,
    'BUSHKO': 0,
    'BUSHLEY': 0,
    'BUSHMAKER': 0,
    'BUSHMAN': 0,
    'BUSHMIRE': 0,
    'BUSHNELL': 0,
    'BUSHNER': 0,
    'BUSHON': 0,
    'BUSHONG': 0,
    'BUSHOR': 0,
    'BUSHORE': 0,
    'BUSHOUSE': 0,
    'BUSHRE': 0,
    'BUSHROD': 0,
    'BUSHROE': 0,
    'BUSHUE': 0,
    'BUSHUR': 0,
    'BUSHWAY': 0,
    'BUSHY': 0,
    'BUSHYHEAD': 0,
    'BUSI': 0,
    'BUSIC': 0,
    'BUSICK': 0,
    'BUSILLO': 0,
    'BUSINELLE': 0,
    'BUSINESS': 0,
    'BUSING': 0,
    'BUSINGER': 0,
    'BUSIO': 0,
    'BUSJAHN': 0,
    'BUSK': 0,
    'BUSKA': 0,
    'BUSKE': 0,
    'BUSKEN': 0,
    'BUSKER': 0,
    'BUSKEY': 0,
    'BUSKILL': 0,
    'BUSKIRK': 0,
    'BUSKO': 0,
    'BUSKOHL': 0,
    'BUSLER': 0,
    'BUSMAN': 0,
    'BUSNARDO': 0,
    'BUSO': 0,
    'BUSQUE': 0,
    'BUSS': 0,
    'BUSSA': 0,
    'BUSSAN': 0,
    'BUSSANICH': 0,
    'BUSSARD': 0,
    'BUSSART': 0,
    'BUSSCHER': 0,
    'BUSSE': 0,
    'BUSSEL': 0,
    'BUSSELL': 0,
    'BUSSELLE': 0,
    'BUSSELMAN': 0,
    'BUSSEN': 0,
    'BUSSER': 0,
    'BUSSERT': 0,
    'BUSSEY': 0,
    'BUSSI': 0,
    'BUSSIAN': 0,
    'BUSSIE': 0,
    'BUSSIERE': 0,
    'BUSSING': 0,
    'BUSSINGER': 0,
    'BUSSKOHL': 0,
    'BUSSLER': 0,
    'BUSSMAN': 0,
    'BUSSMANN': 0,
    'BUSSO': 0,
    'BUSSOM': 0,
    'BUSSON': 0,
    'BUSSONE': 0,
    'BUSSY': 0,
    'BUSTA': 0,
    'BUSTAD': 0,
    'BUSTAMANTE': 0,
    'BUSTAMANTES': 0,
    'BUSTAMENTE': 0,
    'BUSTAMONTE': 0,
    'BUSTARD': 0,
    'BUSTEED': 0,
    'BUSTER': 0.78125,
    'BUSTETTER': 0,
    'BUSTILLO': 0,
    'BUSTILLOS': 0,
    'BUSTIN': 0,
    'BUSTINZA': 0,
    'BUSTLE': 0,
    'BUSTO': 0,
    'BUSTON': 0,
    'BUSTOS': 0,
    'BUSTRAAN': 0,
    'BUSUTTIL': 0,
    'BUSWELL': 0,
    'BUSZ': 0,
    'BUSZKA': 0,
    'BUT': 0,
    'BUTA': 0,
    'BUTAC': 0,
    'BUTALA': 0,
    'BUTALLA': 0,
    'BUTANDA': 0,
    'BUTANI': 0,
    'BUTASH': 0,
    'BUTAUD': 0,
    'BUTAY': 0,
    'BUTCH': 0,
    'BUTCHART': 0,
    'BUTCHEE': 0,
    'BUTCHER': 0,
    'BUTCHINO': 0,
    'BUTCHKO': 0,
    'BUTE': 0,
    'BUTEAU': 0,
    'BUTEAUX': 0,
    'BUTEL': 0,
    'BUTEN': 0,
    'BUTENHOFF': 0,
    'BUTENKO': 0,
    'BUTENSCHOEN': 0,
    'BUTENSKY': 0,
    'BUTER': 0,
    'BUTERA': 0,
    'BUTERBAUGH': 0,
    'BUTEYN': 0,
    'BUTGEREIT': 0,
    'BUTH': 0,
    'BUTHER': 0,
    'BUTHERUS': 0,
    'BUTHMAN': 0,
    'BUTI': 0,
    'BUTIKOFER': 0,
    'BUTIN': 0,
    'BUTINA': 0,
    'BUTKA': 0,
    'BUTKE': 0,
    'BUTKEVICH': 0,
    'BUTKIEWICZ': 0,
    'BUTKO': 0,
    'BUTKOVIC': 0,
    'BUTKOVICH': 0,
    'BUTKOWSKI': 0,
    'BUTKUS': 0,
    'BUTLAND': 0,
    'BUTLER': 0,
    'BUTLIN': 0,
    'BUTMAN': 0,
    'BUTNER': 0,
    'BUTO': 0,
    'BUTORAC': 0,
    'BUTOW': 0,
    'BUTRAM': 0,
    'BUTRICK': 0,
    'BUTRICO': 0,
    'BUTRIM': 0,
    'BUTRON': 0,
    'BUTROS': 0,
    'BUTRUM': 0,
    'BUTRY': 0,
    'BUTRYM': 0,
    'BUTRYMOWICZ': 0,
    'BUTRYN': 0,
    'BUTSCH': 0,
    'BUTSCHEK': 0,
    'BUTSCHER': 0,
    'BUTSKO': 0,
    'BUTSON': 0,
    'BUTT': 0,
    'BUTTA': 0,
    'BUTTACAVOLI': 0,
    'BUTTAFUOCO': 0,
    'BUTTAR': 0,
    'BUTTARI': 0,
    'BUTTARO': 0,
    'BUTTARS': 0,
    'BUTTE': 0,
    'BUTTEL': 0,
    'BUTTELL': 0,
    'BUTTENHOFF': 0,
    'BUTTER': 0,
    'BUTTERBAUGH': 0,
    'BUTTERBRODT': 0,
    'BUTTERFIELD': 0,
    'BUTTERFLY': 0,
    'BUTTERICK': 0,
    'BUTTERIS': 0,
    'BUTTERLY': 0,
    'BUTTERMAN': 0,
    'BUTTERMORE': 0,
    'BUTTERS': 0,
    'BUTTERWICK': 0,
    'BUTTERWORTH': 0,
    'BUTTERY': 0,
    'BUTTI': 0,
    'BUTTICE': 0,
    'BUTTIGIEG': 0,
    'BUTTIGLIERI': 0,
    'BUTTIMER': 0,
    'BUTTINO': 0,
    'BUTTITTA': 0,
    'BUTTKE': 0,
    'BUTTLE': 0,
    'BUTTLEMAN': 0,
    'BUTTLER': 0,
    'BUTTLES': 0,
    'BUTTNER': 0,
    'BUTTO': 0,
    'BUTTOLPH': 0,
    'BUTTON': 0,
    'BUTTORFF': 0,
    'BUTTRAM': 0,
    'BUTTRESS': 0,
    'BUTTREY': 0,
    'BUTTRICK': 0,
    'BUTTRILL': 0,
    'BUTTRUM': 0,
    'BUTTRY': 0,
    'BUTTS': 0,
    'BUTTWEILER': 0,
    'BUTTZ': 0,
    'BUTURLA': 0,
    'BUTWIN': 0,
    'BUTYNSKI': 0,
    'BUTZ': 0,
    'BUTZBACH': 0,
    'BUTZEN': 0,
    'BUTZER': 0,
    'BUTZIN': 0,
    'BUTZINE': 0,
    'BUTZKE': 0,
    'BUTZLAFF': 0,
    'BUTZLER': 0,
    'BUTZOW': 0,
    'BUU': 0,
    'BUUCK': 0,
    'BUUM': 0,
    'BUURMA': 0,
    'BUURSMA': 0,
    'BUUS': 0,
    'BUWALDA': 0,
    'BUX': 0,
    'BUXBAUM': 0,
    'BUXKEMPER': 0,
    'BUXMAN': 0,
    'BUXTON': 0,
    'BUY': 0,
    'BUYAK': 0,
    'BUYCE': 0,
    'BUYCK': 0,
    'BUYCKS': 0,
    'BUYEA': 0,
    'BUYER': 0,
    'BUYERS': 0,
    'BUYNAK': 0,
    'BUYS': 0,
    'BUYSSE': 0,
    'BUZA': 0,
    'BUZALSKI': 0,
    'BUZAN': 0,
    'BUZARD': 0,
    'BUZAS': 0,
    'BUZBEE': 0,
    'BUZBY': 0,
    'BUZEK': 0,
    'BUZHARDT': 0,
    'BUZIAK': 0,
    'BUZICK': 0,
    'BUZIN': 0,
    'BUZINSKI': 0,
    'BUZO': 0,
    'BUZON': 0,
    'BUZZA': 0,
    'BUZZANCA': 0,
    'BUZZARD': 0,
    'BUZZELL': 0,
    'BUZZELLI': 0,
    'BUZZEO': 0,
    'BUZZERIO': 0,
    'BUZZETTA': 0,
    'BUZZETTI': 0,
    'BUZZI': 0,
    'BUZZINI': 0,
    'BUZZO': 0,
    'BY': 0,
    'BYAL': 0,
    'BYALL': 0,
    'BYAM': 0,
    'BYAN': 0,
    'BYAR': 0,
    'BYARD': 0,
    'BYARS': 0,
    'BYAS': 0,
    'BYASSEE': 0,
    'BYBEE': 0,
    'BYBEL': 0,
    'BYBERG': 0,
    'BYCE': 0,
    'BYCHOWSKI': 0,
    'BYCK': 0,
    'BYCROFT': 0,
    'BYCZEK': 0,
    'BYCZKOWSKI': 0,
    'BYCZYNSKI': 0,
    'BYDALEK': 0,
    'BYE': 0,
    'BYER': 0,
    'BYERLEY': 0,
    'BYERLY': 0,
    'BYERS': 0,
    'BYES': 0,
    'BYESS': 0,
    'BYFIELD': 0,
    'BYFORD': 0,
    'BYGRAVE': 0,
    'BYHAM': 0,
    'BYINGTON': 0,
    'BYK': 0,
    'BYKER': 0,
    'BYKERK': 0,
    'BYKONEN': 0,
    'BYKOV': 0,
    'BYKOWSKI': 0,
    'BYL': 0,
    'BYLAND': 0,
    'BYLANDER': 0,
    'BYLE': 0,
    'BYLER': 0,
    'BYLES': 0,
    'BYLIN': 0,
    'BYLINA': 0,
    'BYLO': 0,
    'BYLOW': 0,
    'BYLSMA': 0,
    'BYLUND': 0,
    'BYMA': 0,
    'BYMAN': 0,
    'BYMASTER': 0,
    'BYMERS': 0,
    'BYNAKER': 0,
    'BYNAM': 0,
    'BYNDOM': 0,
    'BYNER': 0,
    'BYNES': 0,
    'BYNG': 0,
    'BYNOE': 0,
    'BYNOG': 0,
    'BYNON': 0,
    'BYNUM': 0,
    'BYOM': 0,
    'BYON': 0,
    'BYOUS': 0,
    'BYRA': 0,
    'BYRAM': 0,
    'BYRAMS': 0,
    'BYRAN': 0,
    'BYRD': 0,
    'BYRDSONG': 0,
    'BYRE': 0,
    'BYRER': 0,
    'BYRES': 0,
    'BYRGE': 0,
    'BYRKET': 0,
    'BYRKIT': 0,
    'BYRLEY': 0,
    'BYRN': 0,
    'BYRNE': 0,
    'BYRNES': 0,
    'BYRNS': 0,
    'BYRNSIDE': 0,
    'BYRO': 0,
    'BYROM': 0,
    'BYRON': 0.9543035419342999,
    'BYRUM': 0,
    'BYS': 0,
    'BYSE': 0,
    'BYSTEDT': 0,
    'BYSTRAK': 0,
    'BYSTROM': 0,
    'BYSTRY': 0,
    'BYTHER': 0,
    'BYTHEWAY': 0,
    'BYTHEWOOD': 0,
    'BYTHROW': 0,
    'BYTHWOOD': 0,
    'BYTNAR': 0,
    'BYUN': 0,
    'BYUS': 0,
    'BYWATER': 0,
    'BYWATERS': 0,
    'BYXBE': 0,
    'BYZEWSKI': 0,
    'BZDOK': 0,
    'BZURA': 0,
    'CAAL': 0,
    'CAAMAL': 0,
    'CAAMANO': 0,
    'CAAN': 0,
    'CAASI': 0,
    'CAAUWE': 0,
    'CABA': 0,
    'CABACCANG': 0,
    'CABACUNGAN': 0,
    'CABADA': 0,
    'CABADAS': 0,
    'CABADING': 0,
    'CABAEL': 0,
    'CABAGE': 0,
    'CABAHUG': 0,
    'CABAJ': 0,
    'CABAL': 0,
    'CABALA': 0,
    'CABALAR': 0,
    'CABALES': 0,
    'CABALLERO': 0,
    'CABALLEROS': 0,
    'CABALLES': 0,
    'CABALLO': 0,
    'CABALO': 0,
    'CABAN': 0,
    'CABANA': 0,
    'CABANAS': 0,
    'CABANAW': 0,
    'CABANAYAN': 0,
    'CABANBAN': 0,
    'CABANERO': 0,
    'CABANILLA': 0,
    'CABANILLAS': 0,
    'CABANISS': 0,
    'CABANO': 0,
    'CABANSAG': 0,
    'CABANTING': 0,
    'CABARCAS': 0,
    'CABARRUS': 0,
    'CABASSA': 0,
    'CABATIC': 0,
    'CABATINGAN': 0,
    'CABATO': 0,
    'CABATU': 0,
    'CABAY': 0,
    'CABAZOS': 0,
    'CABBAGE': 0,
    'CABBAGESTALK': 0,
    'CABBELL': 0,
    'CABBIL': 0,
    'CABBLE': 0,
    'CABE': 0,
    'CABEBE': 0,
    'CABECEIRAS': 0,
    'CABEEN': 0,
    'CABEL': 0,
    'CABELL': 0,
    'CABELLERO': 0,
    'CABELLO': 0,
    'CABELLON': 0,
    'CABELLOS': 0,
    'CABER': 0,
    'CABERA': 0,
    'CABERO': 0,
    'CABERTO': 0,
    'CABEY': 0,
    'CABEZA': 0,
    'CABEZAS': 0,
    'CABEZUDO': 0,
    'CABEZUELA': 0,
    'CABIBBO': 0,
    'CABIBI': 0,
    'CABICO': 0,
    'CABIGAS': 0,
    'CABIL': 0,
    'CABILDO': 0,
    'CABILES': 0,
    'CABIN': 0,
    'CABINESS': 0,
    'CABLAY': 0,
    'CABLAYAN': 0,
    'CABLE': 0,
    'CABLER': 0,
    'CABLES': 0,
    'CABO': 0,
    'CABOT': 0,
    'CABOTAJE': 0,
    'CABRA': 0,
    'CABRADILLA': 0,
    'CABRAL': 0,
    'CABRALES': 0,
    'CABRARA': 0,
    'CABREJA': 0,
    'CABREJOS': 0,
    'CABRERA': 0,
    'CABRERO': 0,
    'CABREROS': 0,
    'CABRERRA': 0,
    'CABREY': 0,
    'CABRIALES': 0,
    'CABROL': 0,
    'CABUCO': 0,
    'CABUDOL': 0,
    'CABUNOC': 0,
    'CABUS': 0,
    'CABUTO': 0,
    'CABY': 0,
    'CACACE': 0,
    'CACAL': 0,
    'CACANINDIN': 0,
    'CACATIAN': 0,
    'CACCAMISE': 0,
    'CACCAMO': 0,
    'CACCAVALE': 0,
    'CACCAVO': 0,
    'CACCESE': 0,
    'CACCHIO': 0,
    'CACCHIONE': 0,
    'CACCIA': 0,
    'CACCIAPAGLIA': 0,
    'CACCIATO': 0,
    'CACCIATORE': 0,
    'CACCIOLA': 0,
    'CACCIOPPOLI': 0,
    'CACCIOTTI': 0,
    'CACEDA': 0,
    'CACEK': 0,
    'CACERES': 0,
    'CACH': 0,
    'CACHAT': 0,
    'CACHERO': 0,
    'CACHIA': 0,
    'CACHO': 0,
    'CACHOLA': 0,
    'CACHU': 0,
    'CACHUELA': 0,
    'CACI': 0,
    'CACIA': 0,
    'CACIC': 0,
    'CACIOPPO': 0,
    'CACIQUE': 0,
    'CACKA': 0,
    'CACKLER': 0,
    'CACKOWSKI': 0,
    'CACY': 0,
    'CAD': 0,
    'CADA': 0,
    'CADARET': 0,
    'CADARETTE': 0,
    'CADAVID': 0,
    'CADAVONA': 0,
    'CADAY': 0,
    'CADD': 0,
    'CADDEL': 0,
    'CADDELL': 0,
    'CADDEN': 0,
    'CADDICK': 0,
    'CADDIGAN': 0,
    'CADDLE': 0,
    'CADDO': 0,
    'CADDY': 0,
    'CADE': 0,
    'CADEAU': 0,
    'CADEK': 0,
    'CADELINA': 0,
    'CADELL': 0,
    'CADEMARTORI': 0,
    'CADEN': 0,
    'CADENA': 0,
    'CADENAS': 0,
    'CADENGO': 0,
    'CADENHEAD': 0,
    'CADER': 0,
    'CADET': 0,
    'CADETTE': 0,
    'CADEZ': 0,
    'CADIENTE': 0,
    'CADIERE': 0,
    'CADIEU': 0,
    'CADIEUX': 0,
    'CADIGAN': 0,
    'CADILE': 0,
    'CADILLO': 0,
    'CADIZ': 0,
    'CADLE': 0,
    'CADMAN': 0,
    'CADMUS': 0,
    'CADO': 0,
    'CADOGAN': 0,
    'CADOR': 0,
    'CADORE': 0,
    'CADORET': 0,
    'CADORETTE': 0,
    'CADOTTE': 0,
    'CADREAU': 0,
    'CADRETTE': 0,
    'CADRIEL': 0,
    'CADRIN': 0,
    'CADWALADER': 0,
    'CADWALLADER': 0,
    'CADWELL': 0,
    'CADY': 0,
    'CADZOW': 0,
    'CAEL': 0,
    'CAELWAERTS': 0,
    'CAESAR': 0,
    'CAETANO': 0,
    'CAETTA': 0,
    'CAEZ': 0,
    'CAFARELLA': 0,
    'CAFARELLI': 0,
    'CAFARO': 0,
    'CAFASSO': 0,
    'CAFFALL': 0,
    'CAFFAREL': 0,
    'CAFFARELLA': 0,
    'CAFFARELLI': 0,
    'CAFFEE': 0,
    'CAFFERATA': 0,
    'CAFFERKY': 0,
    'CAFFERTY': 0,
    'CAFFERY': 0,
    'CAFFEY': 0,
    'CAFFIE': 0,
    'CAFFO': 0,
    'CAFFREY': 0,
    'CAFIERO': 0,
    'CAFISO': 0,
    'CAFLISCH': 0,
    'CAFONE': 0,
    'CAFORIO': 0,
    'CAGAN': 0,
    'CAGE': 0,
    'CAGEL': 0,
    'CAGER': 0,
    'CAGG': 0,
    'CAGGIANO': 0,
    'CAGIE': 0,
    'CAGIGAS': 0,
    'CAGLE': 0,
    'CAGLEY': 0,
    'CAGLIA': 0,
    'CAGLIOSTRO': 0,
    'CAGNEY': 0,
    'CAGNINA': 0,
    'CAGNO': 0,
    'CAGNOLATTI': 0,
    'CAGNON': 0,
    'CAGUIAT': 0,
    'CAGUIOA': 0,
    'CAGWIN': 0,
    'CAHA': 0,
    'CAHAK': 0,
    'CAHAL': 0,
    'CAHALAN': 0,
    'CAHALANE': 0,
    'CAHALIN': 0,
    'CAHALL': 0,
    'CAHAN': 0,
    'CAHANIN': 0,
    'CAHEE': 0,
    'CAHELA': 0,
    'CAHEN': 0,
    'CAHILL': 0,
    'CAHILLANE': 0,
    'CAHIR': 0,
    'CAHN': 0,
    'CAHO': 0,
    'CAHOE': 0,
    'CAHOON': 0,
    'CAHOONE': 0,
    'CAHOW': 0,
    'CAHOY': 0,
    'CAHUANTZI': 0,
    'CAHUE': 0,
    'CAI': 0,
    'CAIAFA': 0,
    'CAIATI': 0,
    'CAIAZZA': 0,
    'CAIAZZO': 0,
    'CAICEDO': 0,
    'CAICO': 0,
    'CAID': 0,
    'CAIDERON': 0,
    'CAIDWELL': 0,
    'CAII': 0,
    'CAIL': 0,
    'CAILLET': 0,
    'CAILLIER': 0,
    'CAILLOUET': 0,
    'CAILLOUETTE': 0,
    'CAIMANO': 0,
    'CAIMI': 0,
    'CAIN': 0,
    'CAINAS': 0,
    'CAINE': 0,
    'CAINES': 0,
    'CAINION': 0,
    'CAINS': 0,
    'CAIOLA': 0,
    'CAIOZZO': 0,
    'CAIRA': 0,
    'CAIRD': 0,
    'CAIRE': 0,
    'CAIRES': 0,
    'CAIRL': 0,
    'CAIRNCROSS': 0,
    'CAIRNES': 0,
    'CAIRNEY': 0,
    'CAIRNS': 0,
    'CAIRO': 0,
    'CAIRONE': 0,
    'CAIRY': 0,
    'CAISE': 0,
    'CAISON': 0,
    'CAISSE': 0,
    'CAISSIE': 0,
    'CAITLIN': 1,
    'CAITLYN': 1,
    'CAITO': 0,
    'CAIVANO': 0,
    'CAJA': 0,
    'CAJAMARCA': 0,
    'CAJAS': 0,
    'CAJERO': 0,
    'CAJIGAL': 0,
    'CAJIGAS': 0,
    'CAJINA': 0,
    'CAJKA': 0,
    'CAJUCOM': 0,
    'CAJUSTE': 0,
    'CAKA': 0,
    'CAKE': 0,
    'CAKEBREAD': 0,
    'CAKIR': 0,
    'CAL': 0,
    'CALA': 0,
    'CALABAZA': 0,
    'CALABRESE': 0,
    'CALABRETTA': 0,
    'CALABRIA': 0,
    'CALABRO': 0,
    'CALADO': 0,
    'CALAFIORE': 0,
    'CALAGNA': 0,
    'CALAGUAS': 0,
    'CALAHAN': 0,
    'CALAIS': 0,
    'CALALANG': 0,
    'CALAMACO': 0,
    'CALAMAN': 0,
    'CALAMARI': 0,
    'CALAME': 0,
    'CALAMIA': 0,
    'CALAMITA': 0,
    'CALAMUSA': 0,
    'CALANCHE': 0,
    'CALANDER': 0,
    'CALANDRA': 0.617283950617284,
    'CALANDRELLA': 0,
    'CALANDRELLI': 0,
    'CALANDRIELLO': 0,
    'CALANDRILLO': 0,
    'CALANDRINO': 0,
    'CALANDRO': 0,
    'CALANNI': 0,
    'CALANO': 0,
    'CALANTONI': 0,
    'CALARA': 0,
    'CALARCO': 0,
    'CALARESE': 0,
    'CALARO': 0,
    'CALAS': 0,
    'CALASCIBETTA': 0,
    'CALASCIONE': 0,
    'CALATA': 0,
    'CALATAYUD': 0,
    'CALATO': 0,
    'CALAUNAN': 0,
    'CALAUTTI': 0,
    'CALAVAN': 0,
    'CALAWAY': 0,
    'CALAYAG': 0,
    'CALBERT': 0,
    'CALBI': 0,
    'CALBILLO': 0,
    'CALBO': 0,
    'CALBREATH': 0,
    'CALCAGNI': 0,
    'CALCAGNO': 0,
    'CALCANO': 0,
    'CALCARA': 0,
    'CALCATERRA': 0,
    'CALCEDO': 0,
    'CALCIANO': 0,
    'CALCOTE': 0,
    'CALCOTT': 0,
    'CALCUTT': 0,
    'CALD': 0,
    'CALDARA': 0,
    'CALDARARO': 0,
    'CALDARELLA': 0,
    'CALDARELLI': 0,
    'CALDARERA': 0,
    'CALDAROLA': 0,
    'CALDARONE': 0,
    'CALDAS': 0,
    'CALDBECK': 0,
    'CALDEIRA': 0,
    'CALDEN': 0,
    'CALDER': 0,
    'CALDERA': 0,
    'CALDERARA': 0,
    'CALDERARO': 0,
    'CALDERAS': 0,
    'CALDERAZZO': 0,
    'CALDERBANK': 0,
    'CALDERHEAD': 0,
    'CALDERILLA': 0,
    'CALDERIN': 0,
    'CALDERO': 0,
    'CALDERON': 0,
    'CALDERONE': 0,
    'CALDERONI': 0,
    'CALDERWOOD': 0,
    'CALDIE': 0,
    'CALDIERO': 0,
    'CALDON': 0,
    'CALDRON': 0,
    'CALDRONE': 0,
    'CALDWELL': 0,
    'CALE': 0,
    'CALEB': 0.9896729776247848,
    'CALECA': 0,
    'CALEF': 0,
    'CALEGARI': 0,
    'CALEL': 0,
    'CALELLO': 0,
    'CALENDA': 0,
    'CALENDAR': 0,
    'CALENDER': 0,
    'CALENDINE': 0,
    'CALENTINE': 0,
    'CALENZO': 0,
    'CALER': 0,
    'CALERO': 0,
    'CALES': 0,
    'CALEY': 0,
    'CALFA': 0,
    'CALFEE': 0,
    'CALFO': 0,
    'CALFY': 0,
    'CALGARO': 0,
    'CALHOON': 0,
    'CALHOUN': 0,
    'CALHOUNE': 0,
    'CALI': 0,
    'CALIA': 0,
    'CALIBOSO': 0,
    'CALICA': 0,
    'CALICCHIA': 0,
    'CALICCHIO': 0,
    'CALICE': 0,
    'CALICO': 0,
    'CALICOTT': 0,
    'CALICUTT': 0,
    'CALIENDO': 0,
    'CALIFAND': 0,
    'CALIFANO': 0,
    'CALIFF': 0,
    'CALIGIURI': 0,
    'CALIGUIRE': 0,
    'CALIGUIRI': 0,
    'CALIGURI': 0,
    'CALIHAN': 0,
    'CALILUNG': 0,
    'CALIMAN': 0,
    'CALIMANO': 0,
    'CALIMER': 0,
    'CALIMLIM': 0,
    'CALIN': 0,
    'CALINGO': 0,
    'CALIO': 0,
    'CALIP': 0,
    'CALIRI': 0,
    'CALIS': 0,
    'CALISE': 0,
    'CALISI': 0,
    'CALISTA': 1,
    'CALISTE': 0,
    'CALISTI': 0,
    'CALISTO': 0,
    'CALISTRO': 0,
    'CALITO': 0,
    'CALITRI': 0,
    'CALIVA': 0,
    'CALIX': 0,
    'CALIXTE': 0,
    'CALIXTO': 0,
    'CALIXTRO': 0,
    'CALIZ': 0,
    'CALK': 0,
    'CALKA': 0,
    'CALKIN': 0,
    'CALKINS': 0,
    'CALL': 0,
    'CALLA': 0,
    'CALLADINE': 0,
    'CALLADO': 0,
    'CALLAGHAN': 0,
    'CALLAGY': 0,
    'CALLAHAM': 0,
    'CALLAHAN': 0,
    'CALLAIS': 0,
    'CALLAM': 0,
    'CALLAN': 0,
    'CALLANAN': 0,
    'CALLAND': 0,
    'CALLANDER': 0,
    'CALLANDS': 0,
    'CALLANS': 0,
    'CALLANTA': 0,
    'CALLANTINE': 0,
    'CALLARD': 0,
    'CALLARI': 0,
    'CALLARMAN': 0,
    'CALLAS': 0,
    'CALLAWAY': 0,
    'CALLE': 0,
    'CALLEA': 0,
    'CALLEAR': 0,
    'CALLEBS': 0,
    'CALLEGAN': 0,
    'CALLEGARI': 0,
    'CALLEJA': 0,
    'CALLEJAS': 0,
    'CALLEJO': 0,
    'CALLEN': 0,
    'CALLENDAR': 0,
    'CALLENDER': 0,
    'CALLENS': 0,
    'CALLEO': 0,
    'CALLER': 0,
    'CALLERI': 0,
    'CALLERO': 0,
    'CALLEROS': 0,
    'CALLERY': 0,
    'CALLES': 0,
    'CALLESEN': 0,
    'CALLETANO': 0,
    'CALLEWAERT': 0,
    'CALLEY': 0,
    'CALLHAN': 0,
    'CALLI': 0,
    'CALLICOAT': 0,
    'CALLICOTT': 0,
    'CALLICOTTE': 0,
    'CALLICUTT': 0,
    'CALLIE': 0.997506234413965,
    'CALLIER': 0,
    'CALLIES': 0,
    'CALLIGAN': 0,
    'CALLIHAM': 0,
    'CALLIHAN': 0,
    'CALLIN': 0,
    'CALLINAN': 0,
    'CALLINS': 0,
    'CALLION': 0,
    'CALLIRGOS': 0,
    'CALLIS': 0,
    'CALLISON': 0,
    'CALLISTE': 0,
    'CALLISTER': 0,
    'CALLISTO': 0,
    'CALLO': 0,
    'CALLON': 0,
    'CALLOS': 0,
    'CALLOW': 0,
    'CALLOWAY': 0,
    'CALLSEN': 0,
    'CALLUM': 0,
    'CALLWOOD': 0,
    'CALM': 0,
    'CALMA': 0,
    'CALMAN': 0,
    'CALMER': 0,
    'CALMES': 0,
    'CALMESE': 0,
    'CALMUS': 0,
    'CALNAN': 0,
    'CALNON': 0,
    'CALO': 0,
    'CALOCA': 0,
    'CALOGERO': 0,
    'CALOIA': 0,
    'CALOMINO': 0,
    'CALON': 0,
    'CALONE': 0,
    'CALONGE': 0,
    'CALONGNE': 0,
    'CALORE': 0,
    'CALOS': 0,
    'CALOURO': 0,
    'CALOVICH': 0,
    'CALOWAY': 0,
    'CALP': 0,
    'CALPIN': 0,
    'CALPITO': 0,
    'CALPO': 0,
    'CALRK': 0,
    'CALSADA': 0,
    'CALSYN': 0,
    'CALTA': 0,
    'CALTABIANO': 0,
    'CALTAGIRONE': 0,
    'CALTER': 0,
    'CALTON': 0,
    'CALTRIDER': 0,
    'CALUAG': 0,
    'CALUB': 0,
    'CALUORI': 0,
    'CALUS': 0,
    'CALUYA': 0,
    'CALUZA': 0,
    'CALVA': 0,
    'CALVACCA': 0,
    'CALVACHE': 0,
    'CALVAN': 0,
    'CALVANESE': 0,
    'CALVANI': 0,
    'CALVANICO': 0,
    'CALVANO': 0,
    'CALVAO': 0,
    'CALVARESE': 0,
    'CALVARESI': 0,
    'CALVARIO': 0,
    'CALVARUSO': 0,
    'CALVARY': 0,
    'CALVELAGE': 0,
    'CALVELLI': 0,
    'CALVELLO': 0,
    'CALVER': 0,
    'CALVERLEY': 0,
    'CALVERT': 0,
    'CALVERY': 0,
    'CALVET': 0,
    'CALVETTI': 0,
    'CALVEY': 0,
    'CALVI': 0,
    'CALVILLO': 0,
    'CALVIN': 0.9721048182586643,
    'CALVINO': 0,
    'CALVIT': 0,
    'CALVO': 0,
    'CALWAY': 0,
    'CALWELL': 0,
    'CALZADA': 0,
    'CALZADILLA': 0,
    'CALZADILLAS': 0,
    'CALZADO': 0,
    'CALZARETTA': 0,
    'CALZONE': 0,
    'CAM': 0,
    'CAMA': 0,
    'CAMAC': 0,
    'CAMACHO': 0,
    'CAMACK': 0,
    'CAMAIONI': 0,
    'CAMAJ': 0,
    'CAMAK': 0,
    'CAMAL': 0,
    'CAMANN': 0,
    'CAMANO': 0,
    'CAMARA': 0,
    'CAMARANO': 0,
    'CAMARATA': 0,
    'CAMARATO': 0,
    'CAMARCO': 0,
    'CAMARDA': 0,
    'CAMARDELLA': 0,
    'CAMARDELLE': 0,
    'CAMARDO': 0,
    'CAMARENA': 0,
    'CAMARENO': 0,
    'CAMARGO': 0,
    'CAMARILLO': 0,
    'CAMARIO': 0,
    'CAMARO': 0,
    'CAMAROTA': 0,
    'CAMAROTE': 0,
    'CAMARRA': 0,
    'CAMAS': 0,
    'CAMASTA': 0,
    'CAMASTRO': 0,
    'CAMAT': 0,
    'CAMBA': 0,
    'CAMBARA': 0,
    'CAMBARERI': 0,
    'CAMBAS': 0,
    'CAMBE': 0,
    'CAMBEL': 0,
    'CAMBER': 0,
    'CAMBERN': 0,
    'CAMBERO': 0,
    'CAMBEROS': 0,
    'CAMBIER': 0,
    'CAMBIO': 0,
    'CAMBLE': 0,
    'CAMBLIN': 0,
    'CAMBO': 0,
    'CAMBRA': 0,
    'CAMBRAY': 0,
    'CAMBRE': 0,
    'CAMBRELEN': 0,
    'CAMBRIA': 0,
    'CAMBRIC': 0,
    'CAMBRIDGE': 0,
    'CAMBRON': 0,
    'CAMBRONERO': 0,
    'CAMBURN': 0,
    'CAMBY': 0,
    'CAMDEN': 0,
    'CAME': 0,
    'CAMEAU': 0,
    'CAMEJO': 0,
    'CAMEL': 0,
    'CAMELI': 0,
    'CAMELIA': 1,
    'CAMELIO': 0,
    'CAMELL': 0,
    'CAMELLIA': 1,
    'CAMELLO': 0,
    'CAMELO': 0,
    'CAMEN': 0,
    'CAMENISCH': 0,
    'CAMENZIND': 0,
    'CAMERA': 0,
    'CAMERANO': 0,
    'CAMERATO': 0,
    'CAMERER': 0,
    'CAMERINO': 0,
    'CAMERLENGO': 0,
    'CAMERLIN': 0,
    'CAMERO': 0,
    'CAMERON': 0.6729475100942126,
    'CAMEROS': 0,
    'CAMEROTA': 0,
    'CAMERY': 0,
    'CAMEY': 0,
    'CAMFIELD': 0,
    'CAMHI': 0,
    'CAMI': 0.9836065573770493,
    'CAMIA': 0,
    'CAMIC': 0,
    'CAMIDGE': 0,
    'CAMIE': 1,
    'CAMIEL': 0,
    'CAMILA': 1,
    'CAMILD': 0,
    'CAMILLA': 1,
    'CAMILLE': 0.9897490279250618,
    'CAMILLERI': 0,
    'CAMILLETTI': 0,
    'CAMILLI': 0,
    'CAMILLIERI': 0,
    'CAMILLO': 0,
    'CAMILO': 0,
    'CAMIN': 0,
    'CAMINERO': 0,
    'CAMINITA': 0,
    'CAMINITI': 0,
    'CAMINO': 0,
    'CAMINOS': 0,
    'CAMIOLO': 0,
    'CAMIRAND': 0,
    'CAMIRE': 0,
    'CAMIS': 0,
    'CAMISA': 0,
    'CAMIT': 0,
    'CAMIZZI': 0,
    'CAMLEY': 0,
    'CAMLIN': 0,
    'CAMM': 0,
    'CAMMACK': 0,
    'CAMMANN': 0,
    'CAMMARAND': 0,
    'CAMMARANO': 0,
    'CAMMARATA': 0,
    'CAMMARN': 0,
    'CAMMAROTA': 0,
    'CAMMENGA': 0,
    'CAMMER': 0,
    'CAMMETT': 0,
    'CAMMIE': 1,
    'CAMMILLERI': 0,
    'CAMMISA': 0,
    'CAMMOCK': 0,
    'CAMMON': 0,
    'CAMMUSO': 0,
    'CAMMY': 1,
    'CAMODECA': 0,
    'CAMON': 0,
    'CAMORLINGA': 0,
    'CAMOU': 0,
    'CAMOZZI': 0,
    'CAMP': 0,
    'CAMPA': 0,
    'CAMPAGNA': 0,
    'CAMPAGNE': 0,
    'CAMPAGNOLA': 0,
    'CAMPAGNOLO': 0,
    'CAMPAGNONE': 0,
    'CAMPAIN': 0,
    'CAMPANA': 0,
    'CAMPANALE': 0,
    'CAMPANARD': 0,
    'CAMPANARO': 0,
    'CAMPANELLA': 0,
    'CAMPANELLI': 0,
    'CAMPANELLO': 0,
    'CAMPANIELLO': 0,
    'CAMPANILE': 0,
    'CAMPANINI': 0,
    'CAMPANO': 0,
    'CAMPANY': 0,
    'CAMPAS': 0,
    'CAMPAU': 0,
    'CAMPBEII': 0,
    'CAMPBEL': 0,
    'CAMPBELL': 0,
    'CAMPE': 0,
    'CAMPEAU': 0,
    'CAMPECHANO': 0,
    'CAMPELLONE': 0,
    'CAMPEN': 0,
    'CAMPER': 0,
    'CAMPERO': 0,
    'CAMPESE': 0,
    'CAMPESI': 0,
    'CAMPFIELD': 0,
    'CAMPHOR': 0,
    'CAMPHOUSE': 0,
    'CAMPI': 0,
    'CAMPIGLIA': 0,
    'CAMPILLO': 0,
    'CAMPING': 0,
    'CAMPION': 0,
    'CAMPIONE': 0,
    'CAMPIS': 0,
    'CAMPISANO': 0,
    'CAMPISE': 0,
    'CAMPISI': 0,
    'CAMPISTA': 0,
    'CAMPITELLI': 0,
    'CAMPLESE': 0,
    'CAMPLIN': 0,
    'CAMPMAN': 0,
    'CAMPNEY': 0,
    'CAMPO': 0,
    'CAMPOAMOR': 0,
    'CAMPOBASSO': 0,
    'CAMPOCHIARO': 0,
    'CAMPODONICO': 0,
    'CAMPOLA': 0,
    'CAMPOLI': 0,
    'CAMPOLO': 0,
    'CAMPOLONG': 0,
    'CAMPOLONGO': 0,
    'CAMPOMANES': 0,
    'CAMPOPIANO': 0,
    'CAMPORA': 0,
    'CAMPOREALE': 0,
    'CAMPOS': 0,
    'CAMPOSANO': 0,
    'CAMPOSECO': 0,
    'CAMPOVERDE': 0,
    'CAMPOY': 0,
    'CAMPOZANO': 0,
    'CAMPS': 0,
    'CAMPSEY': 0,
    'CAMPSHURE': 0,
    'CAMPTON': 0,
    'CAMPUS': 0,
    'CAMPUSANO': 0,
    'CAMPUZANO': 0,
    'CAMREN': 0,
    'CAMRON': 0,
    'CAMUNEZ': 0,
    'CAMUS': 0,
    'CAMUSO': 0,
    'CAMUTI': 0,
    'CAN': 0,
    'CANA': 0,
    'CANAAN': 0,
    'CANADA': 0,
    'CANADAS': 0,
    'CANADAY': 0,
    'CANADY': 0,
    'CANAFAX': 0,
    'CANAL': 0,
    'CANALE': 0,
    'CANALES': 0,
    'CANALEZ': 0,
    'CANALI': 0,
    'CANALS': 0,
    'CANAMAR': 0,
    'CANAMORE': 0,
    'CANAN': 0,
    'CANANT': 0,
    'CANAPP': 0,
    'CANAR': 0,
    'CANARD': 0,
    'CANARIO': 0,
    'CANARIS': 0,
    'CANARTE': 0,
    'CANARY': 0,
    'CANAS': 0,
    'CANASTRA': 0,
    'CANATELLA': 0,
    'CANATSEY': 0,
    'CANAVA': 0,
    'CANAVAN': 0,
    'CANAVERAL': 0,
    'CANBY': 0,
    'CANCEL': 0,
    'CANCELA': 0,
    'CANCELLI': 0,
    'CANCELLIERE': 0,
    'CANCELLIERI': 0,
    'CANCER': 0,
    'CANCHE': 0,
    'CANCHOLA': 0,
    'CANCIENNE': 0,
    'CANCILLA': 0,
    'CANCINO': 0,
    'CANCINOS': 0,
    'CANCIO': 0,
    'CANCRO': 0,
    'CAND': 0,
    'CANDA': 0,
    'CANDACE': 1,
    'CANDAGE': 0,
    'CANDAL': 0,
    'CANDANCE': 1,
    'CANDANEDO': 0,
    'CANDANOSA': 0,
    'CANDANOZA': 0,
    'CANDEA': 0,
    'CANDEE': 0,
    'CANDEL': 0,
    'CANDELA': 0,
    'CANDELARIA': 0.5997001499250376,
    'CANDELARIO': 0,
    'CANDELAS': 0,
    'CANDELL': 0,
    'CANDELLA': 0,
    'CANDELMO': 0,
    'CANDELORA': 0,
    'CANDELORI': 0,
    'CANDELORO': 0,
    'CANDI': 1,
    'CANDIA': 0,
    'CANDIANO': 0,
    'CANDICE': 1,
    'CANDIDA': 1,
    'CANDIDO': 0,
    'CANDIE': 1,
    'CANDIES': 0,
    'CANDIO': 0,
    'CANDIOTTI': 0,
    'CANDIS': 0.9836065573770493,
    'CANDITO': 0,
    'CANDLAND': 0,
    'CANDLE': 0,
    'CANDLER': 0,
    'CANDLISH': 0,
    'CANDO': 0,
    'CANDON': 0,
    'CANDOW': 0,
    'CANDRA': 1,
    'CANDRAY': 0,
    'CANDREVA': 0,
    'CANDY': 0.9808292465448061,
    'CANDYCE': 1,
    'CANE': 0,
    'CANEDA': 0,
    'CANEDO': 0,
    'CANEDY': 0,
    'CANEER': 0,
    'CANEL': 0,
    'CANELA': 0,
    'CANELAS': 0,
    'CANELL': 0,
    'CANELLA': 0,
    'CANELLAS': 0,
    'CANELLI': 0,
    'CANELO': 0,
    'CANEN': 0,
    'CANENGUEZ': 0,
    'CANEPA': 0,
    'CANER': 0,
    'CANERDAY': 0,
    'CANERO': 0,
    'CANES': 0,
    'CANESSA': 0,
    'CANESTRARI': 0,
    'CANESTRARO': 0,
    'CANET': 0,
    'CANETE': 0,
    'CANETTI': 0,
    'CANEVARI': 0,
    'CANEY': 0,
    'CANEZ': 0,
    'CANFIELD': 0,
    'CANFORA': 0,
    'CANG': 0,
    'CANGAS': 0,
    'CANGE': 0,
    'CANGELOSI': 0,
    'CANGEMI': 0,
    'CANGIALOSI': 0,
    'CANGIANO': 0,
    'CANGRO': 0,
    'CANHA': 0,
    'CANHAM': 0,
    'CANI': 0,
    'CANIANO': 0,
    'CANIDA': 0,
    'CANIDATE': 0,
    'CANIFF': 0,
    'CANIGLIA': 0,
    'CANIK': 0,
    'CANILAO': 0,
    'CANINE': 0,
    'CANINI': 0,
    'CANINO': 0,
    'CANION': 0,
    'CANIPE': 0,
    'CANIS': 0,
    'CANISALES': 0,
    'CANIZALES': 0,
    'CANIZALEZ': 0,
    'CANIZARES': 0,
    'CANIZARO': 0,
    'CANJURA': 0,
    'CANLAS': 0,
    'CANLER': 0,
    'CANLEY': 0,
    'CANN': 0,
    'CANNA': 0,
    'CANNADA': 0,
    'CANNADAY': 0,
    'CANNADY': 0,
    'CANNAMELA': 0,
    'CANNAN': 0,
    'CANNARD': 0,
    'CANNARELLA': 0,
    'CANNARIATO': 0,
    'CANNAROZZI': 0,
    'CANNAROZZO': 0,
    'CANNATA': 0,
    'CANNATARO': 0,
    'CANNATELLA': 0,
    'CANNATELLI': 0,
    'CANNAVA': 0,
    'CANNAVINO': 0,
    'CANNAVO': 0,
    'CANNE': 0,
    'CANNEDY': 0,
    'CANNEFAX': 0,
    'CANNELL': 0,
    'CANNELLA': 0,
    'CANNER': 0,
    'CANNESTRA': 0,
    'CANNEY': 0,
    'CANNICI': 0,
    'CANNIDA': 0,
    'CANNIE': 0,
    'CANNIFF': 0,
    'CANNING': 0,
    'CANNINGTON': 0,
    'CANNINO': 0,
    'CANNISTRA': 0,
    'CANNISTRACI': 0,
    'CANNISTRARO': 0,
    'CANNITO': 0,
    'CANNIZZARD': 0,
    'CANNIZZARO': 0,
    'CANNIZZO': 0,
    'CANNON': 0,
    'CANNONE': 0,
    'CANNONIER': 0,
    'CANNOVA': 0,
    'CANNOY': 0,
    'CANNULI': 0,
    'CANNY': 0,
    'CANO': 0,
    'CANODE': 0,
    'CANODY': 0,
    'CANOLE': 0,
    'CANOLES': 0,
    'CANON': 0,
    'CANONGO': 0,
    'CANONICA': 0,
    'CANONICO': 0,
    'CANONIZADO': 0,
    'CANOSA': 0,
    'CANOVA': 0,
    'CANOVAS': 0,
    'CANOY': 0,
    'CANPOS': 0,
    'CANRIGHT': 0,
    'CANSDALE': 0,
    'CANSECO': 0,
    'CANSINO': 0,
    'CANSLER': 0,
    'CANT': 0,
    'CANTA': 0,
    'CANTABRANA': 0,
    'CANTAFIO': 0,
    'CANTAGALLO': 0,
    'CANTALINI': 0,
    'CANTALUPO': 0,
    'CANTAMESSA': 0,
    'CANTANDO': 0,
    'CANTARA': 0,
    'CANTARELLA': 0,
    'CANTARERO': 0,
    'CANTATORE': 0,
    'CANTAVE': 0,
    'CANTE': 0,
    'CANTEEN': 0,
    'CANTELE': 0,
    'CANTELL': 0,
    'CANTELLA': 0,
    'CANTELLI': 0,
    'CANTELLO': 0,
    'CANTELMI': 0,
    'CANTELMO': 0,
    'CANTER': 0,
    'CANTERA': 0,
    'CANTERBERRY': 0,
    'CANTERBURY': 0,
    'CANTERINO': 0,
    'CANTERO': 0,
    'CANTEY': 0,
    'CANTIE': 0,
    'CANTIELLO': 0,
    'CANTIERI': 0,
    'CANTILLANO': 0,
    'CANTILLO': 0,
    'CANTILLON': 0,
    'CANTIN': 0,
    'CANTINE': 0,
    'CANTINI': 0,
    'CANTINO': 0,
    'CANTLER': 0,
    'CANTLEY': 0,
    'CANTLIN': 0,
    'CANTLON': 0,
    'CANTNER': 0,
    'CANTO': 0,
    'CANTON': 0,
    'CANTONE': 0,
    'CANTONI': 0,
    'CANTONWINE': 0,
    'CANTOR': 0,
    'CANTORAL': 0,
    'CANTORAN': 0,
    'CANTORE': 0,
    'CANTORNA': 0,
    'CANTOS': 0,
    'CANTRALL': 0,
    'CANTREL': 0,
    'CANTRELL': 0,
    'CANTRELLE': 0,
    'CANTRES': 0,
    'CANTRILL': 0,
    'CANTU': 0,
    'CANTUA': 0,
    'CANTWELL': 0,
    'CANTY': 0,
    'CANTZ': 0,
    'CANU': 0,
    'CANUEL': 0,
    'CANUL': 0,
    'CANULL': 0,
    'CANUP': 0,
    'CANUPP': 0,
    'CANUSO': 0,
    'CANUTE': 0,
    'CANUTO': 0,
    'CANYON': 0,
    'CANZANO': 0,
    'CANZATER': 0,
    'CANZIANI': 0,
    'CANZONA': 0,
    'CANZONE': 0,
    'CANZONERI': 0,
    'CAO': 0,
    'CAOILE': 0,
    'CAOILI': 0,
    'CAOLA': 0,
    'CAOUETTE': 0,
    'CAP': 0,
    'CAPA': 0,
    'CAPACCIO': 0,
    'CAPACI': 0,
    'CAPADONA': 0,
    'CAPALBO': 0,
    'CAPALDI': 0,
    'CAPALDO': 0,
    'CAPAN': 0,
    'CAPANNA': 0,
    'CAPANO': 0,
    'CAPARAS': 0,
    'CAPARCO': 0,
    'CAPARELLA': 0,
    'CAPARELLI': 0,
    'CAPARROS': 0,
    'CAPASSO': 0,
    'CAPATI': 0,
    'CAPAUL': 0,
    'CAPAZ': 0,
    'CAPDEVILA': 0,
    'CAPDEVILLE': 0,
    'CAPE': 0,
    'CAPECCI': 0,
    'CAPECE': 0,
    'CAPECI': 0,
    'CAPEHART': 0,
    'CAPEK': 0,
    'CAPEL': 0,
    'CAPELA': 0,
    'CAPELES': 0,
    'CAPELL': 0,
    'CAPELLA': 0,
    'CAPELLAN': 0,
    'CAPELLE': 0,
    'CAPELLI': 0,
    'CAPELLO': 0,
    'CAPELLUPO': 0,
    'CAPELO': 0,
    'CAPEN': 0,
    'CAPENER': 0,
    'CAPENTER': 0,
    'CAPER': 0,
    'CAPERNA': 0,
    'CAPERON': 0,
    'CAPERS': 0,
    'CAPERTON': 0,
    'CAPES': 0,
    'CAPESIUS': 0,
    'CAPESTANY': 0,
    'CAPETILLO': 0,
    'CAPETOLA': 0,
    'CAPEZIO': 0,
    'CAPEZZA': 0,
    'CAPEZZUTO': 0,
    'CAPI': 0,
    'CAPICOTTO': 0,
    'CAPIE': 0,
    'CAPIK': 0,
    'CAPILI': 0,
    'CAPILLA': 0,
    'CAPIN': 0,
    'CAPINPIN': 0,
    'CAPIRAL': 0,
    'CAPIRO': 0,
    'CAPISTRAN': 0,
    'CAPISTRANO': 0,
    'CAPISTRANT': 0,
    'CAPITAN': 0,
    'CAPITANI': 0,
    'CAPITANIO': 0,
    'CAPITANO': 0,
    'CAPITELLI': 0,
    'CAPITO': 0,
    'CAPIZ': 0,
    'CAPIZZANO': 0,
    'CAPIZZI': 0,
    'CAPIZZO': 0,
    'CAPKO': 0,
    'CAPLAN': 0,
    'CAPLE': 0,
    'CAPLER': 0,
    'CAPLES': 0,
    'CAPLETTE': 0,
    'CAPLEY': 0,
    'CAPLICE': 0,
    'CAPLIN': 0,
    'CAPLING': 0,
    'CAPLINGER': 0,
    'CAPLIS': 0,
    'CAPMAN': 0,
    'CAPO': 0,
    'CAPOBIANCO': 0,
    'CAPOCCI': 0,
    'CAPOCCIA': 0,
    'CAPODANNO': 0,
    'CAPODICE': 0,
    'CAPODILUPO': 0,
    'CAPOFERRI': 0,
    'CAPOGNA': 0,
    'CAPOLINO': 0,
    'CAPOLONGO': 0,
    'CAPOLUPO': 0,
    'CAPON': 0,
    'CAPONE': 0,
    'CAPONEGRO': 0,
    'CAPONERA': 0,
    'CAPONETTO': 0,
    'CAPONI': 0,
    'CAPONIGRO': 0,
    'CAPORAL': 0,
    'CAPORALE': 0,
    'CAPORALETTI': 0,
    'CAPORALI': 0,
    'CAPORASO': 0,
    'CAPORELLI': 0,
    'CAPORICCI': 0,
    'CAPORIZZO': 0,
    'CAPORUSCIO': 0,
    'CAPORUSSO': 0,
    'CAPOSSELA': 0,
    'CAPOTE': 0,
    'CAPOTOSTO': 0,
    'CAPOUCH': 0,
    'CAPOVILLA': 0,
    'CAPOZZA': 0,
    'CAPOZZI': 0,
    'CAPOZZIELLO': 0,
    'CAPOZZO': 0,
    'CAPOZZOLI': 0,
    'CAPOZZOLO': 0,
    'CAPP': 0,
    'CAPPA': 0,
    'CAPPABIANCA': 0,
    'CAPPADONA': 0,
    'CAPPADONIA': 0,
    'CAPPAERT': 0,
    'CAPPARELLI': 0,
    'CAPPAS': 0,
    'CAPPEL': 0,
    'CAPPELEN': 0,
    'CAPPELL': 0,
    'CAPPELLA': 0,
    'CAPPELLANO': 0,
    'CAPPELLETTI': 0,
    'CAPPELLETTY': 0,
    'CAPPELLI': 0,
    'CAPPELLINI': 0,
    'CAPPELLINO': 0,
    'CAPPELLO': 0,
    'CAPPELLUCCI': 0,
    'CAPPELLUTI': 0,
    'CAPPER': 0,
    'CAPPETTA': 0,
    'CAPPETTO': 0,
    'CAPPIELLO': 0,
    'CAPPITELLI': 0,
    'CAPPLEMAN': 0,
    'CAPPO': 0,
    'CAPPOLA': 0,
    'CAPPON': 0,
    'CAPPONI': 0,
    'CAPPS': 0,
    'CAPPUCCI': 0,
    'CAPPUCCILLI': 0,
    'CAPPUCCINO': 0,
    'CAPPUCCIO': 0,
    'CAPPY': 0,
    'CAPRA': 0,
    'CAPRANICA': 0,
    'CAPRARA': 0,
    'CAPRARD': 0,
    'CAPRARI': 0,
    'CAPRARO': 0,
    'CAPRETTA': 0,
    'CAPRETTI': 0,
    'CAPRI': 0,
    'CAPRIA': 0,
    'CAPRICE': 0.966183574879227,
    'CAPRIGLIONE': 0,
    'CAPRINO': 0,
    'CAPRIO': 0,
    'CAPRIOLA': 0,
    'CAPRIOLI': 0,
    'CAPRIOTTI': 0,
    'CAPRISTO': 0,
    'CAPRITTO': 0,
    'CAPRON': 0,
    'CAPRONI': 0,
    'CAPSHAW': 0,
    'CAPSON': 0,
    'CAPSTICK': 0,
    'CAPTAIN': 0,
    'CAPUA': 0,
    'CAPUANO': 0,
    'CAPUCHINO': 0,
    'CAPULE': 0,
    'CAPULIN': 0,
    'CAPULONG': 0,
    'CAPURRO': 0,
    'CAPURSO': 0,
    'CAPUTA': 0,
    'CAPUTI': 0,
    'CAPUTO': 0,
    'CAPUZZI': 0,
    'CAPUZZO': 0,
    'CAPWELL': 0,
    'CAQUELIN': 0,
    'CAQUIAS': 0,
    'CAR': 0,
    'CARA': 0.9873617693522906,
    'CARAANG': 0,
    'CARABAJAL': 0,
    'CARABAJO': 0,
    'CARABALLO': 0,
    'CARABANTES': 0,
    'CARABBA': 0,
    'CARABELLI': 0,
    'CARABELLO': 0,
    'CARABEO': 0,
    'CARABES': 0,
    'CARABETTA': 0,
    'CARABEZ': 0,
    'CARABIN': 0,
    'CARABINE': 0,
    'CARACAPPA': 0,
    'CARACCI': 0,
    'CARACCIA': 0,
    'CARACCIO': 0,
    'CARACCIOLD': 0,
    'CARACCIOLO': 0,
    'CARACHEO': 0,
    'CARACHURE': 0,
    'CARACO': 0,
    'CARACOZA': 0,
    'CARADINE': 0,
    'CARADONNA': 0,
    'CARAFA': 0,
    'CARAG': 0,
    'CARAGAN': 0,
    'CARAGHER': 0,
    'CARAHER': 0,
    'CARAKER': 0,
    'CARAM': 0,
    'CARAMAGNO': 0,
    'CARAMANICA': 0,
    'CARAMANICO': 0,
    'CARAMANNA': 0,
    'CARAMELLA': 0,
    'CARAMES': 0,
    'CARAMICO': 0,
    'CARAN': 0,
    'CARANCI': 0,
    'CARANDANG': 0,
    'CARANGELO': 0,
    'CARANGI': 0,
    'CARANI': 0,
    'CARANNANTE': 0,
    'CARANO': 0,
    'CARANTO': 0,
    'CARAPELLA': 0,
    'CARAPEZZA': 0,
    'CARAPIA': 0,
    'CARAS': 0,
    'CARASQUILLO': 0,
    'CARATACHEA': 0,
    'CARATHERS': 0,
    'CARATOZZOLO': 0,
    'CARATTINI': 0,
    'CARAVAGGIO': 0,
    'CARAVALHO': 0,
    'CARAVANA': 0,
    'CARAVANTES': 0,
    'CARAVELLA': 0,
    'CARAVELLI': 0,
    'CARAVELLO': 0,
    'CARAVEO': 0,
    'CARAVETTA': 0,
    'CARAWAN': 0,
    'CARAWAY': 0,
    'CARAZA': 0,
    'CARAZO': 0,
    'CARBAJAL': 0,
    'CARBAJO': 0,
    'CARBALLEIRA': 0,
    'CARBALLIDO': 0,
    'CARBALLO': 0,
    'CARBALLOSA': 0,
    'CARBARY': 0,
    'CARBAUGH': 0,
    'CARBEE': 0,
    'CARBER': 0,
    'CARBERRY': 0,
    'CARBERT': 0,
    'CARBERY': 0,
    'CARBIENER': 0,
    'CARBIN': 0,
    'CARBINE': 0,
    'CARBINO': 0,
    'CARBO': 0,
    'CARBON': 0,
    'CARBONA': 0,
    'CARBONARA': 0,
    'CARBONARI': 0,
    'CARBONARO': 0,
    'CARBONE': 0,
    'CARBONEAU': 0,
    'CARBONEL': 0,
    'CARBONELL': 0,
    'CARBONELLA': 0,
    'CARBONETTI': 0,
    'CARBONI': 0,
    'CARBONNEAU': 0,
    'CARBOY': 0,
    'CARBREY': 0,
    'CARBUCCIA': 0,
    'CARBULLIDO': 0,
    'CARBY': 0,
    'CARCACHE': 0,
    'CARCAMO': 0,
    'CARCANO': 0,
    'CARCELLI': 0,
    'CARCHEDI': 0,
    'CARCHI': 0,
    'CARCHIA': 0,
    'CARCHIDI': 0,
    'CARCIA': 0,
    'CARCICH': 0,
    'CARCIERI': 0,
    'CARCIONE': 0,
    'CARCIOPPOLO': 0,
    'CARCO': 0,
    'CARCONE': 0,
    'CARD': 0,
    'CARDA': 0,
    'CARDACI': 0,
    'CARDALL': 0,
    'CARDAMON': 0,
    'CARDAMONE': 0,
    'CARDANI': 0,
    'CARDANO': 0,
    'CARDARELLA': 0,
    'CARDARELLI': 0,
    'CARDAROPOLI': 0,
    'CARDE': 0,
    'CARDEA': 0,
    'CARDEL': 0,
    'CARDELL': 0,
    'CARDELLA': 0,
    'CARDELLE': 0,
    'CARDELLI': 0,
    'CARDELLO': 0,
    'CARDEN': 0,
    'CARDENA': 0,
    'CARDENAL': 0,
    'CARDENALES': 0,
    'CARDENAS': 0,
    'CARDENAZ': 0,
    'CARDENES': 0,
    'CARDENO': 0,
    'CARDENTE': 0,
    'CARDENTEY': 0,
    'CARDER': 0,
    'CARDERO': 0,
    'CARDERON': 0,
    'CARDET': 0,
    'CARDEW': 0,
    'CARDEY': 0,
    'CARDI': 0,
    'CARDIA': 0,
    'CARDIEL': 0,
    'CARDIELLO': 0,
    'CARDIFF': 0,
    'CARDILE': 0,
    'CARDILLO': 0,
    'CARDIN': 0,
    'CARDINA': 0,
    'CARDINAL': 0,
    'CARDINALE': 0,
    'CARDINALI': 0,
    'CARDINALLI': 0,
    'CARDINAS': 0,
    'CARDINE': 0,
    'CARDINELL': 0,
    'CARDINES': 0,
    'CARDINEZ': 0,
    'CARDINI': 0,
    'CARDINO': 0,
    'CARDIS': 0,
    'CARDNER': 0,
    'CARDO': 0,
    'CARDON': 0,
    'CARDONA': 0,
    'CARDONE': 0,
    'CARDONI': 0,
    'CARDONICK': 0,
    'CARDOSA': 0,
    'CARDOSI': 0,
    'CARDOSO': 0,
    'CARDOT': 0,
    'CARDOVA': 0,
    'CARDOZA': 0,
    'CARDOZO': 0,
    'CARDUCCI': 0,
    'CARDUFF': 0,
    'CARDULLO': 0,
    'CARDWELL': 0,
    'CARDY': 0,
    'CARE': 0,
    'CAREAGA': 0,
    'CAREATHERS': 0,
    'CARECCIA': 0,
    'CAREK': 0,
    'CAREL': 0,
    'CARELA': 0,
    'CARELL': 0,
    'CARELLA': 0,
    'CARELLI': 0,
    'CARELLO': 0,
    'CARELOCK': 0,
    'CARELS': 0,
    'CAREN': 0.9873060648801129,
    'CARENDER': 0,
    'CARENO': 0,
    'CARENZA': 0,
    'CARERA': 0,
    'CARERI': 0,
    'CARES': 0,
    'CARESS': 0,
    'CARESTIA': 0,
    'CARETHERS': 0,
    'CARETTI': 0,
    'CARETTO': 0,
    'CAREW': 0,
    'CAREY': 0.5193578847969782,
    'CARFAGNA': 0,
    'CARFAGNO': 0,
    'CARFI': 0,
    'CARFIELD': 0,
    'CARFORA': 0,
    'CARGAL': 0,
    'CARGIL': 0,
    'CARGILE': 0,
    'CARGILL': 0,
    'CARGIN': 0,
    'CARGLE': 0,
    'CARGO': 0,
    'CARHART': 0,
    'CARI': 0.9915014164305949,
    'CARIA': 0,
    'CARIAGA': 0,
    'CARIAS': 0,
    'CARIASO': 0,
    'CARICATO': 0,
    'CARICO': 0,
    'CARICOFE': 0,
    'CARIDAD': 0.9836065573770493,
    'CARIDDI': 0,
    'CARIDE': 0,
    'CARIDEO': 0,
    'CARIDI': 0,
    'CARIE': 0.9259259259259258,
    'CARIELLO': 0,
    'CARIER': 0,
    'CARIG': 0,
    'CARIGLIA': 0,
    'CARIGLIO': 0,
    'CARIGNAN': 0,
    'CARIK': 0,
    'CARIKER': 0,
    'CARILLI': 0,
    'CARILLO': 0,
    'CARIN': 0.9803921568627452,
    'CARINA': 1,
    'CARINCI': 0,
    'CARINE': 0,
    'CARINGAL': 0,
    'CARINGELLA': 0,
    'CARINGER': 0,
    'CARINGI': 0,
    'CARINI': 0,
    'CARINIO': 0,
    'CARINO': 0,
    'CARIO': 0,
    'CARIOLA': 0,
    'CARION': 0,
    'CARIOSCIA': 0,
    'CARIOTI': 0,
    'CARIS': 0,
    'CARISA': 1,
    'CARISSA': 1,
    'CARISSIMI': 0,
    'CARISTI': 0,
    'CARISTO': 0,
    'CARISTROM': 0,
    'CARITA': 0.9433962264150944,
    'CARITE': 0,
    'CARITHERS': 0,
    'CARITO': 0,
    'CARIUS': 0,
    'CARIVEAU': 0,
    'CARK': 0,
    'CARKEEK': 0,
    'CARKHUFF': 0,
    'CARKIN': 0,
    'CARKNER': 0,
    'CARL': 0.9873180696229467,
    'CARLA': 0.9994395665981693,
    'CARLAN': 0,
    'CARLAND': 0,
    'CARLANDER': 0,
    'CARLASCIO': 0,
    'CARLAT': 0,
    'CARLBERG': 0,
    'CARLBLOM': 0,
    'CARLE': 0,
    'CARLEE': 0.9009009009009009,
    'CARLEEN': 1,
    'CARLEN': 0,
    'CARLENA': 1,
    'CARLENE': 1,
    'CARLEO': 0,
    'CARLES': 0,
    'CARLESIMO': 0,
    'CARLESON': 0,
    'CARLESS': 0,
    'CARLETON': 0,
    'CARLETTA': 0.9708737864077669,
    'CARLETTI': 0,
    'CARLETTO': 0,
    'CARLEY': 0.5221932114882507,
    'CARLGREN': 0,
    'CARLI': 0.7751937984496124,
    'CARLIE': 0.9803921568627452,
    'CARLIER': 0,
    'CARLILE': 0,
    'CARLIN': 0,
    'CARLINE': 0.8849557522123894,
    'CARLING': 0,
    'CARLINGTON': 0,
    'CARLINI': 0,
    'CARLINO': 0,
    'CARLIS': 0,
    'CARLISE': 0,
    'CARLISI': 0,
    'CARLISLE': 0,
    'CARLITA': 1,
    'CARLL': 0,
    'CARLMAN': 0,
    'CARLO': 0.8729388942774007,
    'CARLOCK': 0,
    'CARLOMAGNO': 0,
    'CARLON': 0,
    'CARLONE': 0,
    'CARLONI': 0,
    'CARLOS': 0.9807684107287535,
    'CARLOSS': 0,
    'CARLOTA': 1,
    'CARLOTTA': 0.9828009828009829,
    'CARLOTTI': 0,
    'CARLOTTO': 0,
    'CARLOUGH': 0,
    'CARLOW': 0,
    'CARLOZZI': 0,
    'CARLQUIST': 0,
    'CARLS': 0,
    'CARLSEN': 0,
    'CARLSON': 0,
    'CARLSRUD': 0,
    'CARLSSON': 0,
    'CARLSTEDT': 0,
    'CARLSTEN': 0,
    'CARLSTON': 0,
    'CARLSTROM': 0,
    'CARLTON': 0.8281110116383169,
    'CARLUCCI': 0,
    'CARLUCCIO': 0,
    'CARLY': 0.9930486593843098,
    'CARLYLE': 0,
    'CARLYN': 1,
    'CARLYON': 0,
    'CARLYSLE': 0,
    'CARMA': 1,
    'CARMACK': 0,
    'CARMAIN': 0,
    'CARMAN': 0.49382716049382724,
    'CARMANY': 0,
    'CARMEAN': 0,
    'CARMEL': 0.9375000000000001,
    'CARMELA': 1,
    'CARMELIA': 1,
    'CARMELINA': 1,
    'CARMELITA': 1,
    'CARMELL': 0,
    'CARMELLA': 0.9950248756218906,
    'CARMELLO': 0,
    'CARMELO': 0.9879253567508233,
    'CARMEN': 0.9946405291873883,
    'CARMENA': 0,
    'CARMENATE': 0,
    'CARMENATTY': 0,
    'CARMER': 0,
    'CARMI': 0,
    'CARMICAL': 0,
    'CARMICHAEL': 0,
    'CARMICHEAL': 0,
    'CARMICHEL': 0,
    'CARMICKLE': 0,
    'CARMICLE': 0,
    'CARMIGNANI': 0,
    'CARMIN': 0,
    'CARMINA': 1,
    'CARMINATI': 0,
    'CARMINE': 0.9641873278236915,
    'CARMINES': 0,
    'CARMO': 0,
    'CARMODY': 0,
    'CARMON': 0.6802721088435374,
    'CARMONA': 0,
    'CARMONE': 0,
    'CARMONEY': 0,
    'CARMONY': 0,
    'CARMOSINO': 0,
    'CARMOUCHE': 0,
    'CARN': 0,
    'CARNABUCI': 0,
    'CARNAGEY': 0,
    'CARNAGGIO': 0,
    'CARNAGHI': 0,
    'CARNAHAN': 0,
    'CARNAL': 0,
    'CARNALL': 0,
    'CARNATE': 0,
    'CARNATHAN': 0,
    'CARNAZZA': 0,
    'CARNAZZO': 0,
    'CARNCROSS': 0,
    'CARNDUFF': 0,
    'CARNE': 0,
    'CARNEAL': 0,
    'CARNEFIX': 0,
    'CARNEGIE': 0,
    'CARNEIRO': 0,
    'CARNELL': 0,
    'CARNEMOLLA': 0,
    'CARNER': 0,
    'CARNERO': 0,
    'CARNES': 0,
    'CARNESI': 0,
    'CARNETT': 0,
    'CARNEVALE': 0,
    'CARNEVALI': 0,
    'CARNEY': 0,
    'CARNI': 0,
    'CARNICELLI': 0,
    'CARNICLE': 0,
    'CARNICOM': 0,
    'CARNIE': 0,
    'CARNIGLIA': 0,
    'CARNINE': 0,
    'CARNIVAL': 0,
    'CARNIVALE': 0,
    'CARNLEY': 0,
    'CARNLINE': 0,
    'CARNO': 0,
    'CARNOT': 0,
    'CARNOVALE': 0,
    'CARNRIGHT': 0,
    'CARNRIKE': 0,
    'CARNS': 0,
    'CARO': 0,
    'CAROCCI': 0,
    'CARODINE': 0,
    'CAROFANO': 0,
    'CAROL': 0.9989852689037405,
    'CAROLA': 0.8928571428571428,
    'CAROLAN': 0,
    'CAROLANN': 1,
    'CAROLE': 0.9987339991559995,
    'CAROLEE': 1,
    'CAROLEO': 0,
    'CAROLI': 0,
    'CAROLIN': 0.9090909090909091,
    'CAROLINA': 0.9840674789128397,
    'CAROLINE': 0.9982384028185555,
    'CAROLINO': 0,
    'CAROLL': 0.7751937984496124,
    'CAROLLA': 0,
    'CAROLLO': 0,
    'CAROLUS': 0,
    'CAROLYN': 0.9998441801277723,
    'CAROLYNE': 1,
    'CAROLYNN': 1,
    'CARON': 0.395778364116095,
    'CARONA': 0,
    'CARONE': 0,
    'CARONIA': 0,
    'CARONNA': 0,
    'CAROON': 0,
    'CAROPRESO': 0,
    'CAROSA': 0,
    'CAROSELLA': 0,
    'CAROSELLI': 0,
    'CAROSELLO': 0,
    'CAROSI': 0,
    'CAROSONE': 0,
    'CAROTA': 0,
    'CAROTENUTO': 0,
    'CAROTHERS': 0,
    'CAROUTHERS': 0,
    'CAROW': 0,
    'CAROWAY': 0,
    'CAROYLN': 1,
    'CAROZZA': 0,
    'CARP': 0,
    'CARPANZANO': 0,
    'CARPARELLI': 0,
    'CARPE': 0,
    'CARPEN': 0,
    'CARPENA': 0,
    'CARPENDER': 0,
    'CARPENETTI': 0,
    'CARPENITO': 0,
    'CARPENTAR': 0,
    'CARPENTER': 0,
    'CARPENTIER': 0,
    'CARPENTIERE': 0,
    'CARPENTIERI': 0,
    'CARPER': 0,
    'CARPIN': 0,
    'CARPINELLI': 0,
    'CARPINELLO': 0,
    'CARPINO': 0,
    'CARPINTERO': 0,
    'CARPINTEYRO': 0,
    'CARPIO': 0,
    'CARPO': 0,
    'CARR': 0,
    'CARRA': 0,
    'CARRABBA': 0,
    'CARRABINE': 0,
    'CARRABINO': 0,
    'CARRACINO': 0,
    'CARRADA': 0,
    'CARRADINE': 0,
    'CARRADO': 0,
    'CARRAGHER': 0,
    'CARRAHER': 0,
    'CARRAL': 0,
    'CARRALERO': 0,
    'CARRALES': 0,
    'CARRAMAN': 0,
    'CARRAN': 0,
    'CARRANCHO': 0,
    'CARRANCO': 0,
    'CARRANO': 0,
    'CARRANSA': 0,
    'CARRANZA': 0,
    'CARRAO': 0,
    'CARRARA': 0,
    'CARRARO': 0,
    'CARRAS': 0,
    'CARRASCO': 0,
    'CARRASQUILLA': 0,
    'CARRASQUILLO': 0,
    'CARRATALA': 0,
    'CARRATURA': 0,
    'CARRATURO': 0,
    'CARRAWAY': 0,
    'CARRAZANA': 0,
    'CARRAZCO': 0,
    'CARRDII': 0,
    'CARRE': 0,
    'CARREA': 0,
    'CARREATHERS': 0,
    'CARREAU': 0,
    'CARREE': 0,
    'CARREIRA': 0,
    'CARREIRO': 0,
    'CARREJO': 0,
    'CARREKER': 0,
    'CARREL': 0,
    'CARRELL': 0,
    'CARRELLI': 0,
    'CARRELLO': 0,
    'CARRENDER': 0,
    'CARRENO': 0,
    'CARREON': 0,
    'CARRER': 0,
    'CARRERA': 0,
    'CARRERAS': 0,
    'CARRERE': 0,
    'CARRERO': 0,
    'CARRETE': 0,
    'CARRETERO': 0,
    'CARRETHERS': 0,
    'CARRETO': 0,
    'CARRETTA': 0,
    'CARRETTE': 0,
    'CARRETTO': 0,
    'CARREY': 0,
    'CARRI': 0.9836065573770493,
    'CARRIAGA': 0,
    'CARRICATO': 0,
    'CARRICK': 0,
    'CARRICO': 0,
    'CARRIDO': 0,
    'CARRIE': 0.997957397140356,
    'CARRIEDO': 0,
    'CARRIEL': 0,
    'CARRIER': 0,
    'CARRIERA': 0,
    'CARRIERE': 0,
    'CARRIERI': 0,
    'CARRIERO': 0,
    'CARRIG': 0,
    'CARRIGAN': 0,
    'CARRIGER': 0,
    'CARRIGG': 0,
    'CARRIKER': 0,
    'CARRIL': 0,
    'CARRILES': 0,
    'CARRILLO': 0,
    'CARRILO': 0,
    'CARRIN': 0,
    'CARRINGER': 0,
    'CARRINGTON': 0,
    'CARRINO': 0,
    'CARRIO': 0,
    'CARRION': 0,
    'CARRIS': 0,
    'CARRISALES': 0,
    'CARRISALEZ': 0,
    'CARRISON': 0,
    'CARRISOZA': 0,
    'CARRITHERS': 0,
    'CARRIVEAU': 0,
    'CARRIZAL': 0,
    'CARRIZALES': 0,
    'CARRIZALEZ': 0,
    'CARRIZO': 0,
    'CARRIZOSA': 0,
    'CARRIZOZA': 0,
    'CARRO': 0,
    'CARROCCIA': 0,
    'CARROCCIO': 0,
    'CARROL': 0.9109311740890689,
    'CARROLA': 0,
    'CARROLL': 0.3971701625915353,
    'CARRON': 0,
    'CARRONE': 0,
    'CARROS': 0,
    'CARROTHERS': 0,
    'CARROW': 0,
    'CARROWAY': 0,
    'CARROZZA': 0,
    'CARROZZI': 0,
    'CARROZZO': 0,
    'CARRUBA': 0,
    'CARRUBBA': 0,
    'CARRUTH': 0,
    'CARRUTHERS': 0,
    'CARRY': 0.7518796992481203,
    'CARRYL': 0,
    'CARSCADDEN': 0,
    'CARSCALLEN': 0,
    'CARSE': 0,
    'CARSELLO': 0,
    'CARSEN': 0,
    'CARSEY': 0,
    'CARSIA': 0,
    'CARSILLO': 0,
    'CARSKADON': 0,
    'CARSLEY': 0,
    'CARSNER': 0,
    'CARSO': 0,
    'CARSON': 0.2788428023701638,
    'CARSRUD': 0,
    'CARSTAIRS': 0,
    'CARSTARPHEN': 0,
    'CARSTEN': 0,
    'CARSTENS': 0,
    'CARSTENSEN': 0,
    'CARSTON': 0,
    'CARSWELL': 0,
    'CART': 0,
    'CARTA': 0,
    'CARTAGENA': 0,
    'CARTAJENA': 0,
    'CARTAS': 0,
    'CARTAYA': 0,
    'CARTE': 0,
    'CARTEAUX': 0,
    'CARTEE': 0,
    'CARTEL': 0,
    'CARTELLI': 0,
    'CARTEN': 0,
    'CARTER': 0.06276150627615061,
    'CARTHAN': 0,
    'CARTHEL': 0,
    'CARTHEN': 0,
    'CARTHENS': 0,
    'CARTHEW': 0,
    'CARTHON': 0,
    'CARTHY': 0,
    'CARTIEDGE': 0,
    'CARTIER': 0,
    'CARTIN': 0,
    'CARTISANO': 0,
    'CARTLAND': 0,
    'CARTLEDGE': 0,
    'CARTLIDGE': 0,
    'CARTMAN': 0,
    'CARTMEL': 0,
    'CARTMELL': 0,
    'CARTMILL': 0,
    'CARTNER': 0,
    'CARTNEY': 0,
    'CARTO': 0,
    'CARTOLANO': 0,
    'CARTON': 0,
    'CARTRETTE': 0,
    'CARTRIGHT': 0,
    'CARTWRIGHT': 0,
    'CARTY': 0,
    'CARUANA': 0,
    'CARUBIA': 0,
    'CARUCCI': 0,
    'CARUFEL': 0,
    'CARULLI': 0,
    'CARULLO': 0,
    'CARUOLO': 0,
    'CARUS': 0,
    'CARUSI': 0,
    'CARUSILLO': 0,
    'CARUSO': 0,
    'CARUSONE': 0,
    'CARUTH': 0,
    'CARUTHERS': 0,
    'CARVAJAL': 0,
    'CARVALHO': 0,
    'CARVALLO': 0,
    'CARVANA': 0,
    'CARVEL': 0,
    'CARVELL': 0,
    'CARVELLI': 0,
    'CARVENTE': 0,
    'CARVER': 0,
    'CARVETH': 0,
    'CARVEY': 0,
    'CARVILL': 0,
    'CARVILLE': 0,
    'CARVIN': 0,
    'CARVO': 0,
    'CARWELL': 0,
    'CARWILE': 0,
    'CARWIN': 0,
    'CARWISE': 0,
    'CARY': 0.8378870673952641,
    'CARYL': 0.9546539379474941,
    'CARYLON': 1,
    'CARYN': 1,
    'CARZOLI': 0,
    'CAS': 0,
    'CASA': 0,
    'CASABAR': 0,
    'CASABIANCA': 0,
    'CASABLANCA': 0,
    'CASABONA': 0,
    'CASACCIO': 0,
    'CASACELI': 0,
    'CASAD': 0,
    'CASADA': 0,
    'CASADAY': 0,
    'CASADEI': 0,
    'CASADO': 0,
    'CASADONTE': 0,
    'CASADOS': 0,
    'CASADY': 0,
    'CASAGRANDA': 0,
    'CASAGRANDE': 0,
    'CASAIS': 0,
    'CASAL': 0,
    'CASALE': 0,
    'CASALEGNO': 0,
    'CASALENA': 0,
    'CASALES': 0,
    'CASALETTO': 0,
    'CASALI': 0,
    'CASALINI': 0,
    'CASALINO': 0,
    'CASALLAS': 0,
    'CASALS': 0,
    'CASAMASSA': 0,
    'CASAMASSIMA': 0,
    'CASAMAYOR': 0,
    'CASAMENTO': 0,
    'CASANA': 0,
    'CASANAS': 0,
    'CASANAVE': 0,
    'CASANDRA': 1,
    'CASANO': 0,
    'CASANOVA': 0,
    'CASANOVAS': 0,
    'CASANUEVA': 0,
    'CASAPULLA': 0,
    'CASAR': 0,
    'CASARELLA': 0,
    'CASARES': 0,
    'CASAREZ': 0,
    'CASARI': 0,
    'CASARIO': 0,
    'CASAROTTO': 0,
    'CASARRUBIAS': 0,
    'CASAS': 0,
    'CASASANTA': 0,
    'CASASANTO': 0,
    'CASASNOVAS': 0,
    'CASASOLA': 0,
    'CASASSA': 0,
    'CASATELLI': 0,
    'CASAUS': 0,
    'CASAVAN': 0,
    'CASAVANT': 0,
    'CASAVECCHIA': 0,
    'CASAZZA': 0,
    'CASBARRO': 0,
    'CASBEER': 0,
    'CASBON': 0,
    'CASBURN': 0,
    'CASBY': 0,
    'CASCADDEN': 0,
    'CASCADEN': 0,
    'CASCANTE': 0,
    'CASCARANO': 0,
    'CASCARDO': 0,
    'CASCARELLI': 0,
    'CASCELLA': 0,
    'CASCHERA': 0,
    'CASCI': 0,
    'CASCIA': 0,
    'CASCIANI': 0,
    'CASCIANO': 0,
    'CASCIARO': 0,
    'CASCIATO': 0,
    'CASCINO': 0,
    'CASCIO': 0,
    'CASCIOLA': 0,
    'CASCIOLI': 0,
    'CASCIONE': 0,
    'CASCIOTTI': 0,
    'CASCO': 0,
    'CASCONE': 0,
    'CASDORPH': 0,
    'CASE': 0,
    'CASEBEER': 0,
    'CASEBERE': 0,
    'CASEBIER': 0,
    'CASEBOLT': 0,
    'CASEL': 0,
    'CASELLA': 0,
    'CASELLAS': 0,
    'CASELLI': 0,
    'CASELLO': 0,
    'CASELMAN': 0,
    'CASELTON': 0,
    'CASEM': 0,
    'CASEMAN': 0,
    'CASEMENT': 0,
    'CASENHISER': 0,
    'CASERES': 0,
    'CASERIO': 0,
    'CASERO': 0,
    'CASERTA': 0,
    'CASERTANO': 0,
    'CASES': 0,
    'CASETTA': 0,
    'CASEY': 0.775483509296459,
    'CASH': 0,
    'CASHA': 0,
    'CASHATT': 0,
    'CASHAW': 0,
    'CASHDOLLAR': 0,
    'CASHEL': 0,
    'CASHELL': 0,
    'CASHEN': 0,
    'CASHER': 0,
    'CASHIER': 0,
    'CASHIN': 0,
    'CASHIO': 0,
    'CASHIOLA': 0,
    'CASHION': 0,
    'CASHMAN': 0,
    'CASHMER': 0,
    'CASHMERE': 0,
    'CASHMORE': 0,
    'CASHNER': 0,
    'CASHON': 0,
    'CASHWELL': 0,
    'CASIAN': 0,
    'CASIANO': 0,
    'CASIAS': 0,
    'CASIDA': 0,
    'CASIDAY': 0,
    'CASIE': 1,
    'CASIELLO': 0,
    'CASIL': 0,
    'CASILDO': 0,
    'CASILE': 0,
    'CASILIO': 0,
    'CASILLA': 0,
    'CASILLAS': 0,
    'CASILLI': 0,
    'CASILLO': 0,
    'CASIMERE': 0,
    'CASIMIR': 0,
    'CASIMIRA': 1,
    'CASIMIRO': 0,
    'CASINELLI': 0,
    'CASINGER': 0,
    'CASINI': 0,
    'CASINO': 0,
    'CASIO': 0,
    'CASIQUE': 0,
    'CASIS': 0,
    'CASKEY': 0,
    'CASKIE': 0,
    'CASLER': 0,
    'CASLEY': 0,
    'CASLIN': 0,
    'CASLOW': 0,
    'CASMER': 0,
    'CASNAVE': 0,
    'CASNER': 0,
    'CASO': 0,
    'CASOLA': 0,
    'CASOLARI': 0,
    'CASOLARO': 0,
    'CASOLI': 0,
    'CASON': 0,
    'CASORIA': 0,
    'CASPAR': 0,
    'CASPARI': 0,
    'CASPARIAN': 0,
    'CASPARY': 0,
    'CASPE': 0,
    'CASPER': 0,
    'CASPERS': 0,
    'CASPERSEN': 0,
    'CASPERSON': 0,
    'CASPI': 0,
    'CASS': 0,
    'CASSA': 0,
    'CASSADA': 0,
    'CASSADAY': 0,
    'CASSADY': 0,
    'CASSAGNE': 0,
    'CASSAGNOL': 0,
    'CASSAMAJOR': 0,
    'CASSAN': 0,
    'CASSANDRA': 0.9988901220865705,
    'CASSANELLI': 0,
    'CASSANI': 0,
    'CASSANO': 0,
    'CASSANOVA': 0,
    'CASSAR': 0,
    'CASSARA': 0,
    'CASSARD': 0,
    'CASSARINO': 0,
    'CASSARO': 0,
    'CASSAT': 0,
    'CASSATA': 0,
    'CASSATT': 0,
    'CASSAUNDRA': 1,
    'CASSAVANT': 0,
    'CASSAVAUGH': 0,
    'CASSE': 0,
    'CASSEDAY': 0,
    'CASSEDY': 0,
    'CASSEL': 0,
    'CASSELBERRY': 0,
    'CASSELBURY': 0,
    'CASSELL': 0,
    'CASSELLA': 0,
    'CASSELLI': 0,
    'CASSELLO': 0,
    'CASSELLS': 0,
    'CASSELMAN': 0,
    'CASSELS': 0,
    'CASSEM': 0,
    'CASSEN': 0,
    'CASSENS': 0,
    'CASSERA': 0,
    'CASSERINO': 0,
    'CASSERLY': 0,
    'CASSESE': 0,
    'CASSETT': 0,
    'CASSETTA': 0,
    'CASSETTE': 0,
    'CASSETTY': 0,
    'CASSEUS': 0,
    'CASSEY': 0.8928571428571428,
    'CASSI': 0.9523809523809523,
    'CASSIANI': 0,
    'CASSIANO': 0,
    'CASSICK': 0,
    'CASSIDA': 0,
    'CASSIDAY': 0,
    'CASSIDY': 0.23734177215189872,
    'CASSIE': 0.9930915371329878,
    'CASSIER': 0,
    'CASSIERE': 0,
    'CASSIL': 0,
    'CASSILL': 0,
    'CASSIM': 0,
    'CASSIMATIS': 0,
    'CASSIMERE': 0,
    'CASSIN': 0,
    'CASSINELLI': 0,
    'CASSINGHAM': 0,
    'CASSINI': 0,
    'CASSINO': 0,
    'CASSIO': 0,
    'CASSIS': 0,
    'CASSISE': 0,
    'CASSISI': 0,
    'CASSISTA': 0,
    'CASSITY': 0,
    'CASSLE': 0,
    'CASSLER': 0,
    'CASSMAN': 0,
    'CASSO': 0,
    'CASSOLA': 0,
    'CASSON': 0,
    'CASSONDRA': 1,
    'CASSONE': 0,
    'CASSTEVENS': 0,
    'CASSUTO': 0,
    'CASSY': 1,
    'CAST': 0,
    'CASTA': 0,
    'CASTAGNA': 0,
    'CASTAGNARO': 0,
    'CASTAGNE': 0,
    'CASTAGNETTO': 0,
    'CASTAGNO': 0,
    'CASTAGNOLA': 0,
    'CASTAGNOLI': 0,
    'CASTAIN': 0,
    'CASTAING': 0,
    'CASTALDI': 0,
    'CASTALDO': 0,
    'CASTAN': 0,
    'CASTANADA': 0,
    'CASTANARES': 0,
    'CASTANDA': 0,
    'CASTANEDA': 0,
    'CASTANEDO': 0,
    'CASTANEIRA': 0,
    'CASTANER': 0,
    'CASTANERA': 0,
    'CASTANHEIRA': 0,
    'CASTANIA': 0,
    'CASTANO': 0,
    'CASTANON': 0,
    'CASTANOS': 0,
    'CASTANUELA': 0,
    'CASTANZA': 0,
    'CASTATOR': 0,
    'CASTEEL': 0,
    'CASTEELE': 0,
    'CASTEEN': 0,
    'CASTEL': 0,
    'CASTELAN': 0,
    'CASTELANO': 0,
    'CASTELAR': 0,
    'CASTELBLANCO': 0,
    'CASTELEIN': 0,
    'CASTELL': 0,
    'CASTELLA': 0,
    'CASTELLAN': 0,
    'CASTELLANA': 0,
    'CASTELLANETA': 0,
    'CASTELLANI': 0,
    'CASTELLANO': 0,
    'CASTELLANOS': 0,
    'CASTELLAR': 0,
    'CASTELLAW': 0,
    'CASTELLI': 0,
    'CASTELLINI': 0,
    'CASTELLINO': 0,
    'CASTELLO': 0,
    'CASTELLOE': 0,
    'CASTELLON': 0,
    'CASTELLOW': 0,
    'CASTELLS': 0,
    'CASTELLUCCI': 0,
    'CASTELLUCCIO': 0,
    'CASTELO': 0,
    'CASTELOW': 0,
    'CASTEN': 0,
    'CASTENADA': 0,
    'CASTENEDA': 0,
    'CASTENS': 0,
    'CASTER': 0,
    'CASTERLIN': 0,
    'CASTERLINE': 0,
    'CASTERLOW': 0,
    'CASTERTON': 0,
    'CASTETTER': 0,
    'CASTEVENS': 0,
    'CASTIANO': 0,
    'CASTIBLANCO': 0,
    'CASTIE': 0,
    'CASTIELLO': 0,
    'CASTIGLIA': 0,
    'CASTIGLIONE': 0,
    'CASTIGLIONI': 0,
    'CASTILAW': 0,
    'CASTILE': 0,
    'CASTILL': 0,
    'CASTILLA': 0,
    'CASTILLANO': 0,
    'CASTILLE': 0,
    'CASTILLEJA': 0,
    'CASTILLEJO': 0,
    'CASTILLEJOS': 0,
    'CASTILLERO': 0,
    'CASTILLIO': 0,
    'CASTILLO': 0,
    'CASTILLOGARCIA': 0,
    'CASTILLON': 0,
    'CASTILO': 0,
    'CASTILOW': 0,
    'CASTIN': 0,
    'CASTINE': 0,
    'CASTINO': 0,
    'CASTIO': 0,
    'CASTLE': 0,
    'CASTLEBERRY': 0,
    'CASTLEBURY': 0,
    'CASTLEMAN': 0,
    'CASTLEN': 0,
    'CASTLES': 0,
    'CASTLETON': 0,
    'CASTNER': 0,
    'CASTO': 0,
    'CASTOE': 0,
    'CASTOIRE': 0,
    'CASTOLDI': 0,
    'CASTON': 0,
    'CASTONGUAY': 0,
    'CASTONIA': 0,
    'CASTOR': 0,
    'CASTORA': 0,
    'CASTORE': 0,
    'CASTORENA': 0,
    'CASTORENO': 0,
    'CASTORIA': 0,
    'CASTORINA': 0,
    'CASTORINO': 0,
    'CASTORO': 0,
    'CASTRACANE': 0,
    'CASTRANOVA': 0,
    'CASTREJON': 0,
    'CASTRELLON': 0,
    'CASTRENCE': 0,
    'CASTRICONE': 0,
    'CASTRILLO': 0,
    'CASTRILLON': 0,
    'CASTRIOTA': 0,
    'CASTRIOTTA': 0,
    'CASTRO': 0,
    'CASTRODALE': 0,
    'CASTROGIOVANNI': 0,
    'CASTROLOPEZ': 0,
    'CASTRONOVA': 0,
    'CASTRONOVO': 0,
    'CASTRONUOVO': 0,
    'CASTROVILLARI': 0,
    'CASTROVINCI': 0,
    'CASTRUCCI': 0,
    'CASTRUITA': 0,
    'CASUCCI': 0,
    'CASUCCIO': 0,
    'CASUGA': 0,
    'CASULA': 0,
    'CASULLO': 0,
    'CASWELL': 0,
    'CASZATT': 0,
    'CAT': 0,
    'CATA': 0,
    'CATABAY': 0,
    'CATACUTAN': 0,
    'CATAGNUS': 0,
    'CATALA': 0,
    'CATALAN': 0,
    'CATALANELLO': 0,
    'CATALANI': 0,
    'CATALANO': 0,
    'CATALANOTTO': 0,
    'CATALDI': 0,
    'CATALDO': 0,
    'CATALFAMO': 0,
    'CATALFANO': 0,
    'CATALINA': 0.9845288326300985,
    'CATALINE': 0,
    'CATALINI': 0,
    'CATALINO': 0,
    'CATALLO': 0,
    'CATALOGNA': 0,
    'CATALON': 0,
    'CATALONE': 0,
    'CATALONI': 0,
    'CATAN': 0,
    'CATANA': 0,
    'CATANACH': 0,
    'CATANEO': 0,
    'CATANESE': 0,
    'CATANI': 0,
    'CATANIA': 0,
    'CATANIO': 0,
    'CATANO': 0,
    'CATANZANO': 0,
    'CATANZARITE': 0,
    'CATANZARITI': 0,
    'CATANZARO': 0,
    'CATAPANG': 0,
    'CATAPANO': 0,
    'CATARINA': 1,
    'CATARINO': 0,
    'CATASUS': 0,
    'CATAUDELLA': 0,
    'CATBAGAN': 0,
    'CATCHER': 0,
    'CATCHING': 0,
    'CATCHINGS': 0,
    'CATCHOT': 0,
    'CATCHPOLE': 0,
    'CATE': 0,
    'CATECHIS': 0,
    'CATELLA': 0,
    'CATELLI': 0,
    'CATELLIER': 0,
    'CATELLO': 0,
    'CATEN': 0,
    'CATENA': 0,
    'CATENACCI': 0,
    'CATER': 0,
    'CATERINA': 0.9345794392523364,
    'CATERINO': 0,
    'CATERSON': 0,
    'CATES': 0,
    'CATEY': 0,
    'CATHA': 0,
    'CATHARINE': 1,
    'CATHCART': 0,
    'CATHELL': 0,
    'CATHER': 0,
    'CATHERALL': 0,
    'CATHERIN': 1,
    'CATHERINA': 1,
    'CATHERINE': 0.9996248057029533,
    'CATHERMAN': 0,
    'CATHERN': 1,
    'CATHERS': 0,
    'CATHERWOOD': 0,
    'CATHERYN': 1,
    'CATHEY': 0.38684719535783374,
    'CATHI': 1,
    'CATHIE': 1,
    'CATHLEEN': 1,
    'CATHRINE': 1,
    'CATHRO': 0,
    'CATHRYN': 1,
    'CATHY': 0.9988334791484398,
    'CATIC': 0,
    'CATIGNANI': 0,
    'CATILLO': 0,
    'CATINA': 0.99009900990099,
    'CATINELLA': 0,
    'CATINO': 0,
    'CATION': 0,
    'CATIPON': 0,
    'CATIVO': 0,
    'CATIZONE': 0,
    'CATLEDGE': 0,
    'CATLETT': 0,
    'CATLETTE': 0,
    'CATLEY': 0,
    'CATLIN': 0,
    'CATLING': 0,
    'CATLOW': 0,
    'CATMULL': 0,
    'CATNEY': 0,
    'CATO': 0,
    'CATOE': 0,
    'CATOGGIO': 0,
    'CATOIRE': 0,
    'CATOLICO': 0,
    'CATON': 0,
    'CATONA': 0,
    'CATONE': 0,
    'CATONI': 0,
    'CATOR': 0,
    'CATOZZI': 0,
    'CATRAMBONE': 0,
    'CATRELL': 0,
    'CATRETT': 0,
    'CATRICALA': 0,
    'CATRICE': 1,
    'CATRINA': 1,
    'CATRON': 0,
    'CATRONE': 0,
    'CATROW': 0,
    'CATT': 0,
    'CATTAN': 0,
    'CATTANACH': 0,
    'CATTANEO': 0,
    'CATTANI': 0,
    'CATTANO': 0,
    'CATTAU': 0,
    'CATTELL': 0,
    'CATTER': 0,
    'CATTERALL': 0,
    'CATTERLIN': 0,
    'CATTERSON': 0,
    'CATTERTON': 0,
    'CATTIE': 0,
    'CATTIN': 0,
    'CATTLE': 0,
    'CATTO': 0,
    'CATTON': 0,
    'CATTOOR': 0,
    'CATTOUSE': 0,
    'CATTRELL': 0,
    'CATTRON': 0,
    'CATTS': 0,
    'CATUBIG': 0,
    'CATUCCI': 0,
    'CATULLO': 0,
    'CATUOGNO': 0,
    'CATURANO': 0,
    'CATURIA': 0,
    'CATZ': 0,
    'CAU': 0,
    'CAUBLE': 0,
    'CAUCCI': 0,
    'CAUCHI': 0,
    'CAUCHON': 0,
    'CAUDEL': 0,
    'CAUDELL': 0,
    'CAUDILL': 0,
    'CAUDILLO': 0,
    'CAUDLE': 0,
    'CAUDRON': 0,
    'CAUDY': 0,
    'CAUFFMAN': 0,
    'CAUFIELD': 0,
    'CAUFMAN': 0,
    'CAUGHELL': 0,
    'CAUGHEY': 0,
    'CAUGHILL': 0,
    'CAUGHLAN': 0,
    'CAUGHLIN': 0,
    'CAUGHMAN': 0,
    'CAUGHORN': 0,
    'CAUGHRAN': 0,
    'CAUGHRON': 0,
    'CAUL': 0,
    'CAULDER': 0,
    'CAULDWELL': 0,
    'CAULEY': 0,
    'CAULFIELD': 0,
    'CAULK': 0,
    'CAULKINS': 0,
    'CAULLEY': 0,
    'CAULTON': 0,
    'CAUM': 0,
    'CAUPP': 0,
    'CAUSA': 0,
    'CAUSBY': 0,
    'CAUSE': 0,
    'CAUSER': 0,
    'CAUSEVIC': 0,
    'CAUSEY': 0,
    'CAUSGROVE': 0,
    'CAUSIN': 0,
    'CAUSLEY': 0,
    'CAUSOR': 0,
    'CAUSSEAUX': 0,
    'CAUTELA': 0,
    'CAUTHEN': 0,
    'CAUTHON': 0,
    'CAUTHORN': 0,
    'CAUTHORNE': 0,
    'CAUTHRON': 0,
    'CAUTILLO': 0,
    'CAUVEL': 0,
    'CAUVIN': 0,
    'CAUWELS': 0,
    'CAVA': 0,
    'CAVACINI': 0,
    'CAVACO': 0,
    'CAVADA': 0,
    'CAVADINI': 0,
    'CAVAGNARD': 0,
    'CAVAGNARO': 0,
    'CAVALCANTE': 0,
    'CAVALCANTI': 0,
    'CAVALERI': 0,
    'CAVALETTO': 0,
    'CAVALIER': 0,
    'CAVALIERE': 0,
    'CAVALIERI': 0,
    'CAVALIERO': 0,
    'CAVALLARI': 0,
    'CAVALLARO': 0,
    'CAVALLERO': 0,
    'CAVALLI': 0,
    'CAVALLIN': 0,
    'CAVALLINI': 0,
    'CAVALLINO': 0,
    'CAVALLO': 0,
    'CAVALLONE': 0,
    'CAVALLUCCI': 0,
    'CAVALLUZZI': 0,
    'CAVALUZZI': 0,
    'CAVAN': 0,
    'CAVANAGH': 0,
    'CAVANAH': 0,
    'CAVANAUGH': 0,
    'CAVANESS': 0,
    'CAVANNA': 0,
    'CAVANO': 0,
    'CAVARETTA': 0,
    'CAVARRETTA': 0,
    'CAVASOS': 0,
    'CAVATAIO': 0,
    'CAVAZOS': 0,
    'CAVE': 0,
    'CAVELL': 0,
    'CAVELLI': 0,
    'CAVELLO': 0,
    'CAVEN': 0,
    'CAVENAUGH': 0,
    'CAVENDER': 0,
    'CAVENDISH': 0,
    'CAVENEE': 0,
    'CAVENER': 0,
    'CAVENESS': 0,
    'CAVENEY': 0,
    'CAVENY': 0,
    'CAVER': 0,
    'CAVERA': 0,
    'CAVERLEY': 0,
    'CAVERLY': 0,
    'CAVERO': 0,
    'CAVERS': 0,
    'CAVES': 0,
    'CAVETT': 0,
    'CAVETTE': 0,
    'CAVEY': 0,
    'CAVEZZA': 0,
    'CAVICCHI': 0,
    'CAVICCHIA': 0,
    'CAVICCHIO': 0,
    'CAVICH': 0,
    'CAVIEDES': 0,
    'CAVIGLIA': 0,
    'CAVIL': 0,
    'CAVILEER': 0,
    'CAVILL': 0,
    'CAVIN': 0,
    'CAVINDER': 0,
    'CAVINEE': 0,
    'CAVINESS': 0,
    'CAVINS': 0,
    'CAVIS': 0,
    'CAVISTON': 0,
    'CAVITT': 0,
    'CAVNAR': 0,
    'CAVNER': 0,
    'CAVNESS': 0,
    'CAVO': 0,
    'CAVOLO': 0,
    'CAVOTO': 0,
    'CAVRERA': 0,
    'CAVUOTO': 0,
    'CAW': 0,
    'CAWARD': 0,
    'CAWEIN': 0,
    'CAWELTI': 0,
    'CAWLEY': 0,
    'CAWLFIELD': 0,
    'CAWOOD': 0,
    'CAWRSE': 0,
    'CAWTHERN': 0,
    'CAWTHON': 0,
    'CAWTHORN': 0,
    'CAWTHORNE': 0,
    'CAWTHRA': 0,
    'CAWTHRON': 0,
    'CAWVEY': 0,
    'CAWYER': 0,
    'CAY': 0,
    'CAYA': 0,
    'CAYABAN': 0,
    'CAYABYAB': 0,
    'CAYADITTO': 0,
    'CAYANAN': 0,
    'CAYCE': 0,
    'CAYCEDO': 0,
    'CAYE': 0,
    'CAYEA': 0,
    'CAYEMBERG': 0,
    'CAYEMITTE': 0,
    'CAYENNE': 0,
    'CAYER': 0,
    'CAYETAND': 0,
    'CAYETANO': 0,
    'CAYFORD': 0,
    'CAYLA': 1,
    'CAYLER': 0,
    'CAYLOR': 0,
    'CAYNE': 0,
    'CAYNOR': 0,
    'CAYO': 0,
    'CAYON': 0,
    'CAYOT': 0,
    'CAYOU': 0,
    'CAYOUETTE': 0,
    'CAYS': 0,
    'CAYSON': 0,
    'CAYTON': 0,
    'CAYWOOD': 0,
    'CAZA': 0,
    'CAZALAS': 0,
    'CAZALES': 0,
    'CAZAN': 0,
    'CAZARES': 0,
    'CAZAREZ': 0,
    'CAZARIN': 0,
    'CAZAUBON': 0,
    'CAZEAU': 0,
    'CAZEAULT': 0,
    'CAZEE': 0,
    'CAZEL': 0,
    'CAZENAVE': 0,
    'CAZER': 0,
    'CAZES': 0,
    'CAZIER': 0,
    'CAZIMERO': 0,
    'CAZIN': 0,
    'CAZORLA': 0,
    'CAZZELL': 0,
    'CAZZOLA': 0,
    'CCJTD': 0,
    'CDEBACA': 0,
    'CEA': 0,
    'CEARFOSS': 0,
    'CEARLEY': 0,
    'CEARLOCK': 0,
    'CEARNAL': 0,
    'CEARNS': 0,
    'CEASAR': 0,
    'CEASE': 0,
    'CEASER': 0,
    'CEASOR': 0,
    'CEBADA': 0,
    'CEBALLO': 0,
    'CEBALLOS': 0,
    'CEBOLLERO': 0,
    'CEBRERO': 0,
    'CEBREROS': 0,
    'CEBRIAN': 0,
    'CEBUHAR': 0,
    'CEBULA': 0,
    'CEBULLA': 0,
    'CEBULSKI': 0,
    'CECALA': 0,
    'CECCACCI': 0,
    'CECCARELLI': 0,
    'CECCARINI': 0,
    'CECCATO': 0,
    'CECCHETTI': 0,
    'CECCHETTINI': 0,
    'CECCHI': 0,
    'CECCHINI': 0,
    'CECCO': 0,
    'CECCOLI': 0,
    'CECCONI': 0,
    'CECE': 0,
    'CECELIA': 1,
    'CECENA': 0,
    'CECENAS': 0,
    'CECERE': 0,
    'CECERO': 0,
    'CECH': 0,
    'CECI': 0,
    'CECIL': 0.9500915750915752,
    'CECILA': 1,
    'CECILE': 0.9973753280839894,
    'CECILIA': 0.9983663096750772,
    'CECILIANO': 0,
    'CECILIO': 0,
    'CECILLE': 1,
    'CECILY': 1,
    'CECKA': 0,
    'CECRLE': 0,
    'CECUNJANIN': 0,
    'CEDANO': 0,
    'CEDAR': 0,
    'CEDARHOLM': 0,
    'CEDARS': 0,
    'CEDDIA': 0,
    'CEDENO': 0,
    'CEDER': 0,
    'CEDERBERG': 0,
    'CEDERBURG': 0,
    'CEDERGREN': 0,
    'CEDERHOLM': 0,
    'CEDERLUND': 0,
    'CEDERQUIST': 0,
    'CEDERSTROM': 0,
    'CEDILLO': 0,
    'CEDILLOS': 0,
    'CEDOR': 0,
    'CEDOTAL': 0,
    'CEDRE': 0,
    'CEDRIC': 1,
    'CEDRICK': 1,
    'CEDRO': 0,
    'CEDRONE': 0,
    'CEE': 0,
    'CEELY': 0,
    'CEESAY': 0,
    'CEFALI': 0,
    'CEFALO': 0,
    'CEFALU': 0,
    'CEFARATTI': 0,
    'CEFOLA': 0,
    'CEGELKA': 0,
    'CEGELSKI': 0,
    'CEGIELSKI': 0,
    'CEGLA': 0,
    'CEGLAREK': 0,
    'CEGLIA': 0,
    'CEGLIO': 0,
    'CEH': 0,
    'CEHIC': 0,
    'CEJA': 0,
    'CEJAS': 0,
    'CEJKA': 0,
    'CEJUDO': 0,
    'CEKADA': 0,
    'CEKALA': 0,
    'CEKANDER': 0,
    'CEKIC': 0,
    'CELA': 0,
    'CELADA': 0,
    'CELAJ': 0,
    'CELANDER': 0,
    'CELANI': 0,
    'CELANO': 0,
    'CELASCHI': 0,
    'CELATA': 0,
    'CELAURO': 0,
    'CELAYA': 0,
    'CELEBI': 0,
    'CELEBRE': 0,
    'CELEDON': 0,
    'CELENA': 1,
    'CELENDER': 0,
    'CELENTANO': 0,
    'CELENZA': 0,
    'CELESTA': 1,
    'CELESTAIN': 0,
    'CELESTE': 0.9819324430479183,
    'CELESTIAL': 0,
    'CELESTIN': 0,
    'CELESTINA': 1,
    'CELESTINE': 0.857843137254902,
    'CELESTINO': 0,
    'CELEY': 0,
    'CELI': 0,
    'CELIA': 0.9941256213285133,
    'CELIBERTI': 0,
    'CELIC': 0,
    'CELIK': 0,
    'CELIN': 0,
    'CELINA': 1,
    'CELINDA': 1,
    'CELINE': 1,
    'CELINO': 0,
    'CELINSKI': 0,
    'CELIO': 0,
    'CELIS': 0,
    'CELIUS': 0,
    'CELIZ': 0,
    'CELL': 0,
    'CELLA': 0,
    'CELLAN': 0,
    'CELLAR': 0,
    'CELLARS': 0,
    'CELLER': 0,
    'CELLERI': 0,
    'CELLERS': 0,
    'CELLETTI': 0,
    'CELLEY': 0,
    'CELLI': 0,
    'CELLINI': 0,
    'CELLITTI': 0,
    'CELLO': 0,
    'CELLUCCI': 0,
    'CELLURA': 0,
    'CELMER': 0,
    'CELONA': 0,
    'CELONE': 0,
    'CELOTTO': 0,
    'CELSA': 1,
    'CELSO': 0,
    'CELSOR': 0,
    'CELY': 0,
    'CEMAN': 0,
    'CEMER': 0,
    'CEN': 0,
    'CENA': 0,
    'CENAC': 0,
    'CENATIEMPO': 0,
    'CENATUS': 0,
    'CENCE': 0,
    'CENCI': 0,
    'CENDAN': 0,
    'CENDANA': 0,
    'CENDEJAS': 0,
    'CENDER': 0,
    'CENDROSKI': 0,
    'CENDROWSKI': 0,
    'CENEDELLA': 0,
    'CENICEROS': 0,
    'CENICOLA': 0,
    'CENISEROS': 0,
    'CENIZA': 0,
    'CENKNER': 0,
    'CENNAME': 0,
    'CENNAMO': 0,
    'CENSULLO': 0,
    'CENTA': 0,
    'CENTALA': 0,
    'CENTAMORE': 0,
    'CENTANNI': 0,
    'CENTEIO': 0,
    'CENTENO': 0,
    'CENTER': 0,
    'CENTERS': 0,
    'CENTI': 0,
    'CENTILLI': 0,
    'CENTINEO': 0,
    'CENTNER': 0,
    'CENTO': 0,
    'CENTOFANTE': 0,
    'CENTOFANTI': 0,
    'CENTOLA': 0,
    'CENTONI': 0,
    'CENTONZE': 0,
    'CENTORE': 0,
    'CENTRA': 0,
    'CENTRACCHIO': 0,
    'CENTRELLA': 0,
    'CENTRONE': 0,
    'CENTURION': 0,
    'CEO': 0,
    'CEOLA': 1,
    'CEPAK': 0,
    'CEPARANO': 0,
    'CEPEDA': 0,
    'CEPEK': 0,
    'CEPERO': 0,
    'CEPHAS': 0,
    'CEPHUS': 0,
    'CEPIN': 0,
    'CEPLECHA': 0,
    'CEPLINA': 0,
    'CEPRESS': 0,
    'CERA': 0,
    'CERAGIOLI': 0,
    'CERALDE': 0,
    'CERAME': 0,
    'CERAMI': 0,
    'CERAN': 0,
    'CERANO': 0,
    'CERANSKI': 0,
    'CERAOLO': 0,
    'CERAR': 0,
    'CERASANI': 0,
    'CERASI': 0,
    'CERASO': 0,
    'CERASOLI': 0,
    'CERASUOLO': 0,
    'CERATO': 0,
    'CERAVOLO': 0,
    'CERBANTES': 0,
    'CERBO': 0,
    'CERBONE': 0,
    'CERCADO': 0,
    'CERCE': 0,
    'CERCEO': 0,
    'CERCHIO': 0,
    'CERCIELLO': 0,
    'CERCONE': 0,
    'CERCY': 0,
    'CERDA': 0,
    'CERDAN': 0,
    'CERDAS': 0,
    'CERECEDES': 0,
    'CERECERES': 0,
    'CERECEREZ': 0,
    'CEREGHINO': 0,
    'CERELLI': 0,
    'CEREN': 0,
    'CERENZIA': 0,
    'CERES': 0,
    'CERESA': 0,
    'CERESINI': 0,
    'CERETTO': 0,
    'CEREZO': 0,
    'CERF': 0,
    'CERIANI': 0,
    'CERIC': 0,
    'CERICOLA': 0,
    'CERIELLO': 0,
    'CERILLI': 0,
    'CERILLO': 0,
    'CERIMELE': 0,
    'CERINI': 0,
    'CERINO': 0,
    'CERIO': 0,
    'CERISE': 0,
    'CERKA': 0,
    'CERMAK': 0,
    'CERMENO': 0,
    'CERMINARA': 0,
    'CERMINARO': 0,
    'CERNA': 0,
    'CERNAK': 0,
    'CERNANSKY': 0,
    'CERNAS': 0,
    'CERNE': 0,
    'CERNEK': 0,
    'CERNEY': 0,
    'CERNI': 0,
    'CERNICH': 0,
    'CERNICK': 0,
    'CERNIGLIA': 0,
    'CERNIK': 0,
    'CERNOCH': 0,
    'CERNOHOUS': 0,
    'CERNOSEK': 0,
    'CERNUDA': 0,
    'CERNUTO': 0,
    'CERNY': 0,
    'CERO': 0,
    'CERON': 0,
    'CERONE': 0,
    'CERPA': 0,
    'CERQUA': 0,
    'CERQUEIRA': 0,
    'CERRA': 0,
    'CERRATO': 0,
    'CERRETA': 0,
    'CERRETANI': 0,
    'CERRETO': 0,
    'CERRI': 0,
    'CERRILLO': 0,
    'CERRILLOS': 0,
    'CERRITELLI': 0,
    'CERRITENO': 0,
    'CERRITO': 0,
    'CERRITOS': 0,
    'CERRO': 0,
    'CERRONE': 0,
    'CERRONI': 0,
    'CERROS': 0,
    'CERRUTI': 0,
    'CERRUTO': 0,
    'CERSOSIMO': 0,
    'CERTA': 0,
    'CERTAIN': 0,
    'CERTEZA': 0,
    'CERTO': 0,
    'CERULLI': 0,
    'CERULLO': 0,
    'CERULO': 0,
    'CERUTI': 0,
    'CERUTTI': 0,
    'CERVA': 0,
    'CERVANTE': 0,
    'CERVANTES': 0,
    'CERVANTEZ': 0,
    'CERVASIO': 0,
    'CERVATES': 0,
    'CERVELLI': 0,
    'CERVEN': 0,
    'CERVENAK': 0,
    'CERVENKA': 0,
    'CERVENTES': 0,
    'CERVENY': 0,
    'CERVERA': 0,
    'CERVI': 0,
    'CERVIN': 0,
    'CERVINI': 0,
    'CERVINO': 0,
    'CERVO': 0,
    'CERVONE': 0,
    'CERVONI': 0,
    'CERWIN': 0,
    'CERWINSKE': 0,
    'CERZA': 0,
    'CESA': 0,
    'CESAIRE': 0,
    'CESAR': 0.9705966314587497,
    'CESARANO': 0,
    'CESARE': 0,
    'CESAREO': 0,
    'CESARETTI': 0,
    'CESARI': 0,
    'CESARINI': 0,
    'CESARIO': 0,
    'CESARO': 0,
    'CESARONE': 0,
    'CESARSKI': 0,
    'CESARZ': 0,
    'CESCA': 0,
    'CESENA': 0,
    'CESMAT': 0,
    'CESNIK': 0,
    'CESPEDES': 0,
    'CESSAC': 0,
    'CESSNA': 0,
    'CESSOR': 0,
    'CESSPOOCH': 0,
    'CESTA': 0,
    'CESTARE': 0,
    'CESTARI': 0,
    'CESTARO': 0,
    'CESTERO': 0,
    'CESTONE': 0,
    'CESTRA': 0,
    'CETERA': 0,
    'CETIN': 0,
    'CETINA': 0,
    'CETNAR': 0,
    'CETNAROWSKI': 0,
    'CETOLA': 0,
    'CETOUTE': 0,
    'CETRONE': 0,
    'CETRULO': 0,
    'CETTA': 0,
    'CETTI': 0,
    'CETTO': 0,
    'CEURVELS': 0,
    'CEUS': 0,
    'CEVALLOS': 0,
    'CEVASCO': 0,
    'CEYLAN': 0,
    'CEYNAR': 0,
    'CEZAR': 0,
    'CH': 0,
    'CHA': 0,
    'CHAABAN': 0,
    'CHAAPEL': 0,
    'CHAAR': 0,
    'CHABAK': 0,
    'CHABALA': 0,
    'CHABAN': 0,
    'CHABARRIA': 0,
    'CHABER': 0,
    'CHABERT': 0,
    'CHABES': 0,
    'CHABEZ': 0,
    'CHABLA': 0,
    'CHABLE': 0,
    'CHABOLLA': 0,
    'CHABOT': 0,
    'CHABOYA': 0,
    'CHABRA': 0,
    'CHABRE': 0,
    'CHABRIER': 0,
    'CHAC': 0,
    'CHACA': 0,
    'CHACE': 0,
    'CHACHA': 0,
    'CHACHERE': 0,
    'CHACHO': 0,
    'CHACIN': 0,
    'CHACK': 0,
    'CHACKO': 0,
    'CHACO': 0,
    'CHACON': 0,
    'CHACONA': 0,
    'CHACONAS': 0,
    'CHAD': 0.9989102796948783,
    'CHADA': 0,
    'CHADBOURNE': 0,
    'CHADBURN': 0,
    'CHADD': 0,
    'CHADDA': 0,
    'CHADDERDON': 0,
    'CHADDERTON': 0,
    'CHADDICK': 0,
    'CHADDOCK': 0,
    'CHADEE': 0,
    'CHADEK': 0,
    'CHADHA': 0,
    'CHADICK': 0,
    'CHADIMA': 0,
    'CHADMAN': 0,
    'CHADSEY': 0,
    'CHADWELL': 0,
    'CHADWICK': 0.5426356589147286,
    'CHAE': 0.5747126436781609,
    'CHAET': 0,
    'CHAFE': 0,
    'CHAFEE': 0,
    'CHAFER': 0,
    'CHAFETZ': 0,
    'CHAFEY': 0,
    'CHAFF': 0,
    'CHAFFE': 0,
    'CHAFFEE': 0,
    'CHAFFER': 0,
    'CHAFFEY': 0,
    'CHAFFIN': 0,
    'CHAFFINCH': 0,
    'CHAFFINO': 0,
    'CHAFFINS': 0,
    'CHAFFMAN': 0,
    'CHAFIN': 0,
    'CHAFINS': 0,
    'CHAGANI': 0,
    'CHAGARIS': 0,
    'CHAGAS': 0,
    'CHAGNON': 0,
    'CHAGOLIA': 0,
    'CHAGOLLA': 0,
    'CHAGOLLAN': 0,
    'CHAGOYA': 0,
    'CHAHAL': 0,
    'CHAHIN': 0,
    'CHAHINE': 0,
    'CHAI': 0,
    'CHAIDES': 0,
    'CHAIDEZ': 0,
    'CHAIFETZ': 0,
    'CHAIKA': 0,
    'CHAIKEN': 0,
    'CHAIKIN': 0,
    'CHAILLAND': 0,
    'CHAILLE': 0,
    'CHAIM': 0,
    'CHAIMOWITZ': 0,
    'CHAIN': 0,
    'CHAINANI': 0,
    'CHAINEY': 0,
    'CHAING': 0,
    'CHAIR': 0,
    'CHAIRA': 0,
    'CHAIRES': 0,
    'CHAIREZ': 0,
    'CHAIRS': 0,
    'CHAISON': 0,
    'CHAISSON': 0,
    'CHAIT': 0,
    'CHAIX': 0,
    'CHAJ': 0,
    'CHAJON': 0,
    'CHAK': 0,
    'CHAKA': 0,
    'CHAKERIAN': 0,
    'CHAKLOS': 0,
    'CHAKOS': 0,
    'CHAKRABARTI': 0,
    'CHAKRABARTY': 0,
    'CHAKRABORTY': 0,
    'CHAKRAVARTHY': 0,
    'CHAKRAVARTI': 0,
    'CHAKRAVARTY': 0,
    'CHAKRAVORTY': 0,
    'CHAKY': 0,
    'CHALA': 0,
    'CHALABI': 0,
    'CHALAS': 0,
    'CHALASANI': 0,
    'CHALBERG': 0,
    'CHALCO': 0,
    'CHALCRAFT': 0,
    'CHALE': 0,
    'CHALEFF': 0,
    'CHALEN': 0,
    'CHALET': 0,
    'CHALFANT': 0,
    'CHALFIN': 0,
    'CHALHOUB': 0,
    'CHALICH': 0,
    'CHALIFOUR': 0,
    'CHALIFOUX': 0,
    'CHALK': 0,
    'CHALKE': 0,
    'CHALKER': 0,
    'CHALKLEY': 0,
    'CHALKO': 0,
    'CHALL': 0,
    'CHALLA': 0,
    'CHALLACOMBE': 0,
    'CHALLE': 0,
    'CHALLEN': 0,
    'CHALLENDER': 0,
    'CHALLENGER': 0,
    'CHALLENOR': 0,
    'CHALLINGSWORTH': 0,
    'CHALLINOR': 0,
    'CHALLIS': 0,
    'CHALLMAN': 0,
    'CHALLONER': 0,
    'CHALLY': 0,
    'CHALMERS': 0,
    'CHALOUPKA': 0,
    'CHALOUX': 0,
    'CHALSTROM': 0,
    'CHALTRY': 0,
    'CHALUPA': 0,
    'CHALUPKA': 0,
    'CHALUPNIK': 0,
    'CHALUPSKY': 0,
    'CHALUS': 0,
    'CHALUT': 0,
    'CHAM': 0,
    'CHAMA': 0,
    'CHAMALE': 0,
    'CHAMAN': 0,
    'CHAMAS': 0,
    'CHAMBA': 0,
    'CHAMBER': 0,
    'CHAMBERLAIN': 0,
    'CHAMBERLAND': 0,
    'CHAMBERLIN': 0,
    'CHAMBERS': 0,
    'CHAMBLEE': 0,
    'CHAMBLESS': 0,
    'CHAMBLEY': 0,
    'CHAMBLIN': 0,
    'CHAMBLIS': 0,
    'CHAMBLISS': 0,
    'CHAMBON': 0,
    'CHAMES': 0,
    'CHAMI': 0,
    'CHAMIS': 0,
    'CHAMIZO': 0,
    'CHAMLEE': 0,
    'CHAMLEY': 0,
    'CHAMMAS': 0,
    'CHAMNESS': 0,
    'CHAMORRO': 0,
    'CHAMOUN': 0,
    'CHAMP': 0,
    'CHAMPA': 0,
    'CHAMPACO': 0,
    'CHAMPAGNE': 0,
    'CHAMPAGNIE': 0,
    'CHAMPAIGN': 0,
    'CHAMPAIGNE': 0,
    'CHAMPANERI': 0,
    'CHAMPE': 0,
    'CHAMPEAU': 0,
    'CHAMPER': 0,
    'CHAMPI': 0,
    'CHAMPIE': 0,
    'CHAMPIGNY': 0,
    'CHAMPINE': 0,
    'CHAMPION': 0,
    'CHAMPLAIN': 0,
    'CHAMPLEY': 0,
    'CHAMPLIN': 0,
    'CHAMPMAN': 0,
    'CHAMPNEY': 0,
    'CHAMPOUX': 0,
    'CHAMPY': 0,
    'CHAMU': 0,
    'CHAN': 0.039432176656151424,
    'CHANA': 0.9646302250803858,
    'CHANAY': 0,
    'CHANCE': 0.5813953488372093,
    'CHANCELLOR': 0,
    'CHANCELOR': 0,
    'CHANCEY': 0,
    'CHANCO': 0,
    'CHANCY': 0,
    'CHAND': 0,
    'CHANDA': 0.9546539379474941,
    'CHANDANAIS': 0,
    'CHANDAR': 0,
    'CHANDARA': 0,
    'CHANDER': 0,
    'CHANDHOK': 0,
    'CHANDI': 0,
    'CHANDIRAMANI': 0,
    'CHANDLEE': 0,
    'CHANDLER': 0,
    'CHANDLEY': 0,
    'CHANDO': 0,
    'CHANDONNET': 0,
    'CHANDRA': 0.9395973154362416,
    'CHANDRAMOULI': 0,
    'CHANDRAN': 0,
    'CHANDRASEKAR': 0,
    'CHANDRASEKARAN': 0,
    'CHANDRASEKHAR': 0,
    'CHANDRASHEKAR': 0,
    'CHANDY': 0,
    'CHANE': 0,
    'CHANEL': 0.9900990099009901,
    'CHANELL': 1,
    'CHANELLE': 1,
    'CHANES': 0,
    'CHANEY': 0,
    'CHANEZ': 0,
    'CHANG': 0.18832391713747648,
    'CHANGE': 0,
    'CHANGO': 0,
    'CHANIN': 0,
    'CHANLER': 0,
    'CHANLEY': 0,
    'CHANN': 0,
    'CHANNEL': 0,
    'CHANNELL': 0,
    'CHANNELS': 0,
    'CHANNER': 0,
    'CHANNEY': 0,
    'CHANNING': 0,
    'CHANNON': 0,
    'CHANOCUA': 0,
    'CHANON': 0,
    'CHANSKY': 0,
    'CHANSLER': 0,
    'CHANSLOR': 0,
    'CHANSON': 0,
    'CHANT': 0,
    'CHANTACA': 0,
    'CHANTAL': 1,
    'CHANTAY': 1,
    'CHANTE': 1,
    'CHANTEL': 1,
    'CHANTELL': 1,
    'CHANTELLE': 1,
    'CHANTHA': 0,
    'CHANTHALANGSY': 0,
    'CHANTHARATH': 0,
    'CHANTHAVISOUK': 0,
    'CHANTHAVONG': 0,
    'CHANTLER': 0,
    'CHANTRY': 0,
    'CHANZA': 0,
    'CHAO': 0,
    'CHAON': 0,
    'CHAP': 0,
    'CHAPA': 0,
    'CHAPARRO': 0,
    'CHAPAS': 0,
    'CHAPDELAINE': 0,
    'CHAPEK': 0,
    'CHAPEL': 0,
    'CHAPELL': 0,
    'CHAPELLE': 0,
    'CHAPERON': 0,
    'CHAPIN': 0,
    'CHAPITAL': 0,
    'CHAPKO': 0,
    'CHAPLA': 0,
    'CHAPLAIN': 0,
    'CHAPLE': 0,
    'CHAPLEAU': 0,
    'CHAPLES': 0,
    'CHAPLICK': 0,
    'CHAPLIK': 0,
    'CHAPLIN': 0,
    'CHAPLINE': 0,
    'CHAPLINSKI': 0,
    'CHAPMAN': 0,
    'CHAPMON': 0,
    'CHAPNICK': 0,
    'CHAPO': 0,
    'CHAPOTON': 0,
    'CHAPOY': 0,
    'CHAPP': 0,
    'CHAPPA': 0,
    'CHAPPEL': 0,
    'CHAPPELEAR': 0,
    'CHAPPELL': 0,
    'CHAPPELLE': 0,
    'CHAPPELOW': 0,
    'CHAPPIE': 0,
    'CHAPPIUS': 0,
    'CHAPPLE': 0,
    'CHAPPO': 0,
    'CHAPPUIS': 0,
    'CHAPSKI': 0,
    'CHAPUIS': 0,
    'CHAPUT': 0,
    'CHAR': 0,
    'CHARA': 0.9615384615384616,
    'CHARACTER': 0,
    'CHARALAMBOUS': 0,
    'CHARAN': 0,
    'CHARANIA': 0,
    'CHARANZA': 0,
    'CHARAPATA': 0,
    'CHARARA': 0,
    'CHARBENEAU': 0,
    'CHARBONEAU': 0,
    'CHARBONIER': 0,
    'CHARBONNEAU': 0,
    'CHARBONNET': 0,
    'CHARBONNIER': 0,
    'CHARCAS': 0,
    'CHARCO': 0,
    'CHARD': 0,
    'CHARDON': 0,
    'CHAREST': 0,
    'CHARETTE': 0,
    'CHAREZ': 0,
    'CHARFAUROS': 0,
    'CHARGIN': 0,
    'CHARGO': 0,
    'CHARGOIS': 0,
    'CHARGUALAF': 0,
    'CHARI': 0,
    'CHARIES': 0,
    'CHARIS': 1,
    'CHARISE': 1,
    'CHARISSA': 1,
    'CHARISSE': 1,
    'CHARITA': 1,
    'CHARITE': 0,
    'CHARITON': 0,
    'CHARITY': 0.9713977334052888,
    'CHARK': 0,
    'CHARLA': 1,
    'CHARLAND': 0,
    'CHARLE': 0,
    'CHARLEBOIS': 0,
    'CHARLEEN': 1,
    'CHARLEMAGNE': 0,
    'CHARLENA': 1,
    'CHARLENE': 1,
    'CHARLES': 0.9876622957173309,
    'CHARLESE': 0,
    'CHARLESETTA': 1,
    'CHARLESON': 0,
    'CHARLESPIERRE': 0,
    'CHARLESTON': 0,
    'CHARLESWORTH': 0,
    'CHARLET': 0,
    'CHARLETON': 0,
    'CHARLETTE': 1,
    'CHARLEVILLE': 0,
    'CHARLEY': 0.8687258687258687,
    'CHARLICK': 0,
    'CHARLIE': 0.9954375777685608,
    'CHARLIER': 0,
    'CHARLINE': 1,
    'CHARLO': 0,
    'CHARLOT': 0,
    'CHARLOTIN': 0,
    'CHARLOTT': 1,
    'CHARLOTTE': 0.9996450964154738,
    'CHARLOW': 0,
    'CHARLSIE': 1,
    'CHARLSON': 0,
    'CHARLSTON': 0,
    'CHARLTON': 0,
    'CHARLYN': 1,
    'CHARM': 0,
    'CHARMAIN': 1,
    'CHARMAINE': 1,
    'CHARMAN': 0,
    'CHARMOLI': 0,
    'CHARNAS': 0,
    'CHARNECO': 0,
    'CHARNES': 0,
    'CHARNESKI': 0,
    'CHARNESKY': 0,
    'CHARNETSKI': 0,
    'CHARNEY': 0,
    'CHARNICK': 0,
    'CHARNLEY': 0,
    'CHARNO': 0,
    'CHARNOCK': 0,
    'CHARNOW': 0,
    'CHARNY': 0,
    'CHARO': 0,
    'CHAROLETTE': 1,
    'CHARON': 0,
    'CHAROS': 0,
    'CHARPENTIER': 0,
    'CHARPIA': 0,
    'CHARPIE': 0,
    'CHARPING': 0,
    'CHARRAN': 0,
    'CHARRETTE': 0,
    'CHARRIER': 0,
    'CHARRIEZ': 0,
    'CHARRIS': 0,
    'CHARRON': 0,
    'CHARRY': 0,
    'CHART': 0,
    'CHARTER': 0,
    'CHARTERS': 0,
    'CHARTIER': 0,
    'CHARTOFF': 0,
    'CHARTON': 0,
    'CHARTRAND': 0,
    'CHARTRAW': 0,
    'CHARVAT': 0,
    'CHARVET': 0,
    'CHARY': 0,
    'CHAS': 1,
    'CHASAN': 0,
    'CHASAR': 0,
    'CHASCO': 0,
    'CHASE': 0.4595060310166571,
    'CHASEN': 0,
    'CHASEY': 0,
    'CHASIDY': 1,
    'CHASIN': 0,
    'CHASINGHAWK': 0,
    'CHASITY': 1,
    'CHASKIN': 0,
    'CHASKO': 0,
    'CHASMAR': 0,
    'CHASON': 0,
    'CHASSAGNE': 0,
    'CHASSE': 0,
    'CHASSER': 0,
    'CHASSEREAU': 0,
    'CHASSEY': 0,
    'CHASSIDY': 1,
    'CHASSIN': 0,
    'CHASSION': 0,
    'CHASSON': 0,
    'CHASTAIN': 0,
    'CHASTANG': 0,
    'CHASTANT': 0,
    'CHASTEEN': 0,
    'CHASTEK': 0,
    'CHASTEN': 0,
    'CHASTINE': 0,
    'CHASTITY': 1,
    'CHASTON': 0,
    'CHASZAR': 0,
    'CHATAGNIER': 0,
    'CHATBURN': 0,
    'CHATEAU': 0,
    'CHATEAUNEUF': 0,
    'CHATEL': 0,
    'CHATELAIN': 0,
    'CHATELLE': 0,
    'CHATELLIER': 0,
    'CHATER': 0,
    'CHATFIELD': 0,
    'CHATHA': 0,
    'CHATHAM': 0,
    'CHATIGNY': 0,
    'CHATILA': 0,
    'CHATLEY': 0,
    'CHATLIN': 0,
    'CHATLOS': 0,
    'CHATMAN': 0,
    'CHATMON': 0,
    'CHATT': 0,
    'CHATTAWAY': 0,
    'CHATTEN': 0,
    'CHATTERJEE': 0,
    'CHATTERJI': 0,
    'CHATTERLEY': 0,
    'CHATTERS': 0,
    'CHATTERSON': 0,
    'CHATTERTON': 0,
    'CHATTIN': 0,
    'CHATTMAN': 0,
    'CHATTO': 0,
    'CHATTOPADHYAY': 0,
    'CHATURVEDI': 0,
    'CHATWIN': 0,
    'CHATWOOD': 0,
    'CHAU': 0.28943560057887124,
    'CHAUCA': 0,
    'CHAUDARY': 0,
    'CHAUDHARI': 0,
    'CHAUDHARY': 0,
    'CHAUDHRI': 0,
    'CHAUDHRY': 0,
    'CHAUDHURI': 0,
    'CHAUDHURY': 0,
    'CHAUDOIN': 0,
    'CHAUDOIR': 0,
    'CHAUDRY': 0,
    'CHAUEZ': 0,
    'CHAUFFE': 0,
    'CHAUHAN': 0,
    'CHAULK': 0,
    'CHAULKLIN': 0,
    'CHAUMONT': 0,
    'CHAUNCEY': 0.9090909090909091,
    'CHAUNCY': 0,
    'CHAUNG': 0,
    'CHAUSSE': 0,
    'CHAUSSEE': 0,
    'CHAUTIN': 0,
    'CHAUVET': 0,
    'CHAUVETTE': 0,
    'CHAUVIN': 0,
    'CHAVAN': 0,
    'CHAVANA': 0,
    'CHAVANNE': 0,
    'CHAVANNES': 0,
    'CHAVARIA': 0,
    'CHAVARIN': 0,
    'CHAVARRI': 0,
    'CHAVARRIA': 0,
    'CHAVARRIAGA': 0,
    'CHAVARRY': 0,
    'CHAVAS': 0,
    'CHAVDA': 0,
    'CHAVE': 0,
    'CHAVEL': 0,
    'CHAVELAS': 0,
    'CHAVERA': 0,
    'CHAVERO': 0,
    'CHAVERRI': 0,
    'CHAVERRIA': 0,
    'CHAVERS': 0,
    'CHAVES': 0,
    'CHAVEY': 0,
    'CHAVEZ': 0,
    'CHAVEZGARCIA': 0,
    'CHAVEZLOPEZ': 0,
    'CHAVEZMARTINEZ': 0,
    'CHAVIANO': 0,
    'CHAVIERS': 0,
    'CHAVIES': 0,
    'CHAVIN': 0,
    'CHAVIOUS': 0,
    'CHAVIRA': 0,
    'CHAVIS': 0,
    'CHAVKIN': 0,
    'CHAVOLLA': 0,
    'CHAVOUS': 0,
    'CHAVOYA': 0,
    'CHAW': 0,
    'CHAWLA': 0,
    'CHAY': 0,
    'CHAYA': 0.9523809523809523,
    'CHAYER': 0,
    'CHAYKA': 0,
    'CHAYKIN': 0,
    'CHAYREZ': 0,
    'CHAZAN': 0,
    'CHAZARRETA': 0,
    'CHAZEN': 0,
    'CHAZIN': 0,
    'CHE': 0,
    'CHEA': 0,
    'CHEADIE': 0,
    'CHEADLE': 0,
    'CHEAH': 0,
    'CHEAIRS': 0,
    'CHEAK': 0,
    'CHEAL': 0,
    'CHEAM': 0,
    'CHEAN': 0,
    'CHEANEY': 0,
    'CHEANG': 0,
    'CHEAP': 0,
    'CHEARS': 0,
    'CHEATAM': 0,
    'CHEATEM': 0,
    'CHEATER': 0,
    'CHEATHAM': 0,
    'CHEATHEM': 0,
    'CHEATLE': 0,
    'CHEATOM': 0,
    'CHEATUM': 0,
    'CHEATWOOD': 0,
    'CHEAVES': 0,
    'CHEBAN': 0,
    'CHECA': 0,
    'CHECCA': 0,
    'CHECCHI': 0,
    'CHECCHIA': 0,
    'CHECCHIO': 0,
    'CHECCO': 0,
    'CHECHAK': 0,
    'CHECHILE': 0,
    'CHECK': 0,
    'CHECKETTS': 0,
    'CHECKI': 0,
    'CHECKLEY': 0,
    'CHECO': 0,
    'CHEDA': 0,
    'CHEDESTER': 0,
    'CHEDIAK': 0,
    'CHEDID': 0,
    'CHEDISTER': 0,
    'CHEE': 0,
    'CHEEK': 0,
    'CHEEKS': 0,
    'CHEELEY': 0,
    'CHEELY': 0,
    'CHEEMA': 0,
    'CHEENEY': 0,
    'CHEER': 0,
    'CHEERS': 0,
    'CHEESBRO': 0,
    'CHEESE': 0,
    'CHEESEBORO': 0,
    'CHEESEBOROUGH': 0,
    'CHEESEBREW': 0,
    'CHEESEBROUGH': 0,
    'CHEESEMAN': 0,
    'CHEESMAN': 0,
    'CHEETHAM': 0,
    'CHEEVER': 0,
    'CHEEVERS': 0,
    'CHEEVES': 0,
    'CHEEZUM': 0,
    'CHEFF': 0,
    'CHEFFER': 0,
    'CHEGE': 0,
    'CHEGWIDDEN': 0,
    'CHEHAB': 0,
    'CHEHADE': 0,
    'CHEIFETZ': 0,
    'CHEK': 0,
    'CHEKAN': 0,
    'CHELAK': 0,
    'CHELBERG': 0,
    'CHELEDNIK': 0,
    'CHELETTE': 0,
    'CHELF': 0,
    'CHELGREN': 0,
    'CHELI': 0,
    'CHELINI': 0,
    'CHELIUS': 0,
    'CHELL': 0,
    'CHELLBERG': 0,
    'CHELLEW': 0,
    'CHELLI': 0,
    'CHELLIAH': 0,
    'CHELLINO': 0,
    'CHELLIS': 0,
    'CHELLMAN': 0,
    'CHELSEA': 1,
    'CHELSEY': 1,
    'CHELSIE': 1,
    'CHELTON': 0,
    'CHEM': 0,
    'CHEMA': 0,
    'CHEMAN': 0,
    'CHEMIN': 0,
    'CHEMTOB': 0,
    'CHEN': 0,
    'CHENAIL': 0,
    'CHENAILLE': 0,
    'CHENARD': 0,
    'CHENAULT': 0,
    'CHENE': 0,
    'CHENEAU': 0,
    'CHENERY': 0,
    'CHENET': 0,
    'CHENETTE': 0,
    'CHENEVERT': 0,
    'CHENEVEY': 0,
    'CHENEY': 0,
    'CHENG': 0,
    'CHENH': 0,
    'CHENIER': 0,
    'CHENNAULT': 0,
    'CHENOT': 0,
    'CHENOWETH': 0,
    'CHENOWITH': 0,
    'CHEON': 0,
    'CHEONG': 0,
    'CHEPLICK': 0,
    'CHEPULIS': 0,
    'CHER': 0.9259259259259258,
    'CHERA': 0,
    'CHERAMIE': 0,
    'CHERBA': 0,
    'CHERE': 1,
    'CHEREE': 1,
    'CHEREK': 0,
    'CHERELLE': 1,
    'CHERELUS': 0,
    'CHERENFANT': 0,
    'CHERESTAL': 0,
    'CHERF': 0,
    'CHERI': 0.9972078181092939,
    'CHERIAN': 0,
    'CHERICO': 0,
    'CHERIE': 0.9981851179673321,
    'CHERIF': 0,
    'CHERILUS': 0,
    'CHERILYN': 1,
    'CHERIN': 0,
    'CHERINGTON': 0,
    'CHERIPKA': 0,
    'CHERISE': 1,
    'CHERISH': 1,
    'CHERIYAN': 0,
    'CHERKAS': 0,
    'CHERKIS': 0,
    'CHERLY': 1,
    'CHERLYN': 1,
    'CHERMACK': 0,
    'CHERMAK': 0,
    'CHERN': 0,
    'CHERNACK': 0,
    'CHERNAK': 0,
    'CHERNE': 0,
    'CHERNENKO': 0,
    'CHERNER': 0,
    'CHERNESKY': 0,
    'CHERNEY': 0,
    'CHERNG': 0,
    'CHERNI': 0,
    'CHERNIAK': 0,
    'CHERNICH': 0,
    'CHERNICK': 0,
    'CHERNICKY': 0,
    'CHERNIK': 0,
    'CHERNIKOFF': 0,
    'CHERNIN': 0,
    'CHERNIS': 0,
    'CHERNISKY': 0,
    'CHERNISS': 0,
    'CHERNOCK': 0,
    'CHERNOFF': 0,
    'CHERNOSKY': 0,
    'CHERNOV': 0,
    'CHERNOW': 0,
    'CHERNY': 0,
    'CHERNYAK': 0,
    'CHERNYAVSKAYA': 0,
    'CHERO': 0,
    'CHEROK': 0,
    'CHEROMIAH': 0,
    'CHERON': 0,
    'CHERONE': 0,
    'CHERPAK': 0,
    'CHERRI': 1,
    'CHERRICK': 0,
    'CHERRIE': 0.9803921568627452,
    'CHERRIER': 0,
    'CHERRINGTON': 0,
    'CHERRIX': 0,
    'CHERRY': 0.4122766834631241,
    'CHERRYHOLMES': 0,
    'CHERRYHOMES': 0,
    'CHERRYL': 1,
    'CHERTOFF': 0,
    'CHERTOK': 0,
    'CHERUBIN': 0,
    'CHERUBINI': 0,
    'CHERUBINO': 0,
    'CHERUKURI': 0,
    'CHERUP': 0,
    'CHERVEN': 0,
    'CHERVENAK': 0,
    'CHERVENKA': 0,
    'CHERVENY': 0,
    'CHERVIN': 0,
    'CHERWIN': 0,
    'CHERWINSKI': 0,
    'CHERY': 0.5181347150259067,
    'CHERYL': 1,
    'CHERYLE': 1,
    'CHERYLL': 1,
    'CHES': 0,
    'CHESAK': 0,
    'CHESBRO': 0,
    'CHESBROUGH': 0,
    'CHESEBRO': 0,
    'CHESEBROUGH': 0,
    'CHESEK': 0,
    'CHESELDINE': 0,
    'CHESER': 0,
    'CHESHER': 0,
    'CHESHIER': 0,
    'CHESHIRE': 0,
    'CHESKE': 0,
    'CHESKO': 0,
    'CHESKY': 0,
    'CHESLA': 0,
    'CHESLAK': 0,
    'CHESLER': 0,
    'CHESLEY': 0,
    'CHESLIK': 0,
    'CHESLOCK': 0,
    'CHESMORE': 0,
    'CHESNA': 0,
    'CHESNER': 0,
    'CHESNES': 0,
    'CHESNEY': 0,
    'CHESNICK': 0,
    'CHESNIK': 0,
    'CHESNUT': 0,
    'CHESNUTT': 0,
    'CHESONIS': 0,
    'CHESS': 0,
    'CHESSER': 0,
    'CHESSHER': 0,
    'CHESSHIR': 0,
    'CHESSHIRE': 0,
    'CHESSLER': 0,
    'CHESSMAN': 0,
    'CHESSMORE': 0,
    'CHESSON': 0,
    'CHESSOR': 0,
    'CHEST': 0,
    'CHESTANG': 0,
    'CHESTEEN': 0,
    'CHESTER': 0.935139671502218,
    'CHESTERFIELD': 0,
    'CHESTERMAN': 0,
    'CHESTERS': 0,
    'CHESTERTON': 0,
    'CHESTNEY': 0,
    'CHESTNUT': 0,
    'CHESTNUTT': 0,
    'CHESTON': 0,
    'CHESWICK': 0,
    'CHESWORTH': 0,
    'CHET': 0.9900990099009901,
    'CHETCUTI': 0,
    'CHETELAT': 0,
    'CHETNEY': 0,
    'CHETRAM': 0,
    'CHETRIT': 0,
    'CHETTA': 0,
    'CHETTY': 0,
    'CHETWOOD': 0,
    'CHETWYND': 0,
    'CHEU': 0,
    'CHEUK': 0,
    'CHEUN': 0,
    'CHEUNG': 0,
    'CHEUVRONT': 0,
    'CHEVAL': 0,
    'CHEVALIER': 0,
    'CHEVALLIER': 0,
    'CHEVANNES': 0,
    'CHEVER': 0,
    'CHEVERE': 0,
    'CHEVEREZ': 0,
    'CHEVERIE': 0,
    'CHEVES': 0,
    'CHEVEZ': 0,
    'CHEVIS': 0,
    'CHEVRETTE': 0,
    'CHEVRIER': 0,
    'CHEW': 0,
    'CHEWEY': 0,
    'CHEWNING': 0,
    'CHEY': 0,
    'CHEYENNE': 1,
    'CHEYNE': 0,
    'CHEYNEY': 0,
    'CHEZ': 0,
    'CHEZEM': 0,
    'CHEZIK': 0,
    'CHHABRA': 0,
    'CHHABRIA': 0,
    'CHHAN': 0,
    'CHHAY': 0,
    'CHHEANG': 0,
    'CHHEDA': 0,
    'CHHEM': 0,
    'CHHENG': 0,
    'CHHIM': 0,
    'CHHIN': 0,
    'CHHINA': 0,
    'CHHIT': 0,
    'CHHITH': 0,
    'CHHOEUN': 0,
    'CHHOEUNG': 0,
    'CHHOM': 0,
    'CHHOR': 0,
    'CHHOUN': 0,
    'CHHOUR': 0,
    'CHHUM': 0,
    'CHHUN': 0,
    'CHHUON': 0,
    'CHI': 0.7667031763417306,
    'CHIA': 0.6451612903225806,
    'CHIACCHIO': 0,
    'CHIADO': 0,
    'CHIAGO': 0,
    'CHIALASTRI': 0,
    'CHIAN': 0,
    'CHIANELLI': 0,
    'CHIANESE': 0,
    'CHIANG': 0,
    'CHIAO': 0,
    'CHIAPETTA': 0,
    'CHIAPPA': 0,
    'CHIAPPE': 0,
    'CHIAPPELLI': 0,
    'CHIAPPETTA': 0,
    'CHIAPPINELLI': 0,
    'CHIAPPINI': 0,
    'CHIAPPONE': 0,
    'CHIARA': 0,
    'CHIARADIO': 0,
    'CHIARADONNA': 0,
    'CHIARAMONTE': 0,
    'CHIARAPPA': 0,
    'CHIARAVALLE': 0,
    'CHIARAVALLOTI': 0,
    'CHIARELLA': 0,
    'CHIARELLI': 0,
    'CHIARELLO': 0,
    'CHIARENZA': 0,
    'CHIARI': 0,
    'CHIARIELLO': 0,
    'CHIARINI': 0,
    'CHIARITO': 0,
    'CHIARO': 0,
    'CHIARULLI': 0,
    'CHIASSON': 0,
    'CHIAVACCI': 0,
    'CHIAVAROLI': 0,
    'CHIAVELLI': 0,
    'CHIAVERINI': 0,
    'CHIAVETTA': 0,
    'CHIAZZA': 0,
    'CHIBA': 0,
    'CHIBBARO': 0,
    'CHIC': 0,
    'CHICA': 0,
    'CHICAIZA': 0,
    'CHICANO': 0,
    'CHICARELLI': 0,
    'CHICAS': 0,
    'CHICCA': 0,
    'CHICCO': 0,
    'CHICHESTER': 0,
    'CHICK': 0,
    'CHICKERING': 0,
    'CHICKEY': 0,
    'CHICKO': 0,
    'CHICLANA': 0,
    'CHICO': 0,
    'CHICOINE': 0,
    'CHICOLA': 0,
    'CHICON': 0,
    'CHICONE': 0,
    'CHICOS': 0,
    'CHICOSKY': 0,
    'CHIDA': 0,
    'CHIDAMBARAM': 0,
    'CHIDDISTER': 0,
    'CHIDDIX': 0,
    'CHIDESTER': 0,
    'CHIDIAC': 0,
    'CHIDLEY': 0,
    'CHIDSEY': 0,
    'CHIE': 0,
    'CHIECHI': 0,
    'CHIECO': 0,
    'CHIEF': 0,
    'CHIEFFO': 0,
    'CHIEKO': 1,
    'CHIELLO': 0,
    'CHIEM': 0,
    'CHIEN': 0,
    'CHIENG': 0,
    'CHIEPPA': 0,
    'CHIER': 0,
    'CHIERA': 0,
    'CHIERICI': 0,
    'CHIERO': 0,
    'CHIESA': 0,
    'CHIEU': 0,
    'CHIEVES': 0,
    'CHIGAS': 0,
    'CHIGER': 0,
    'CHIGHIZOLA': 0,
    'CHIH': 0,
    'CHIHAK': 0,
    'CHIHUAHUA': 0,
    'CHIK': 0,
    'CHIKE': 0,
    'CHILA': 0,
    'CHILBERG': 0,
    'CHILBERT': 0,
    'CHILCOAT': 0,
    'CHILCOTE': 0,
    'CHILCOTT': 0,
    'CHILCUTT': 0,
    'CHILD': 0,
    'CHILDERS': 0,
    'CHILDRE': 0,
    'CHILDREE': 0,
    'CHILDRES': 0,
    'CHILDRESS': 0,
    'CHILDREY': 0,
    'CHILDS': 0,
    'CHILE': 0,
    'CHILEK': 0,
    'CHILEL': 0,
    'CHILELLI': 0,
    'CHILES': 0,
    'CHILIAN': 0,
    'CHILIN': 0,
    'CHILINGARYAN': 0,
    'CHILINSKI': 0,
    'CHILL': 0,
    'CHILLA': 0,
    'CHILLE': 0,
    'CHILLEMI': 0,
    'CHILLIS': 0,
    'CHILLOUS': 0,
    'CHILLSON': 0,
    'CHILMAN': 0,
    'CHILOS': 0,
    'CHILSON': 0,
    'CHILSTROM': 0,
    'CHILTON': 0,
    'CHILUKURI': 0,
    'CHILVERS': 0,
    'CHIM': 0,
    'CHIMA': 0,
    'CHIMAL': 0,
    'CHIMBO': 0,
    'CHIMEL': 0,
    'CHIMELIS': 0,
    'CHIMENTI': 0,
    'CHIMENTO': 0,
    'CHIMERA': 0,
    'CHIMES': 0,
    'CHIMIENTI': 0,
    'CHIN': 0.17361111111111113,
    'CHINA': 0.78125,
    'CHINANA': 0,
    'CHINANDER': 0,
    'CHINAPPI': 0,
    'CHINAULT': 0,
    'CHINAVARE': 0,
    'CHINCHAR': 0,
    'CHINCHILLA': 0,
    'CHINDAVONG': 0,
    'CHINEA': 0,
    'CHINEN': 0,
    'CHINERY': 0,
    'CHING': 0.2808988764044944,
    'CHINI': 0,
    'CHINIGO': 0,
    'CHINITZ': 0,
    'CHINLOY': 0,
    'CHINN': 0,
    'CHINNERS': 0,
    'CHINNERY': 0,
    'CHINNI': 0,
    'CHINNICI': 0,
    'CHINNIS': 0,
    'CHINNOCK': 0,
    'CHINO': 0,
    'CHINQUEE': 0,
    'CHINSKI': 0,
    'CHINSKY': 0,
    'CHINTALA': 0,
    'CHIO': 0,
    'CHIOCCA': 0,
    'CHIOCCHI': 0,
    'CHIODI': 0,
    'CHIODINI': 0,
    'CHIODO': 0,
    'CHIOFALO': 0,
    'CHIOFOLO': 0,
    'CHIOLA': 0,
    'CHIONCHIO': 0,
    'CHIONG': 0,
    'CHIOTTI': 0,
    'CHIOU': 0,
    'CHIOVARO': 0,
    'CHIOVITTI': 0,
    'CHIP': 0,
    'CHIPCHASE': 0,
    'CHIPLEY': 0,
    'CHIPMAN': 0,
    'CHIPOURAS': 0,
    'CHIPP': 0,
    'CHIPPEAUX': 0,
    'CHIPPENDALE': 0,
    'CHIPPERFIELD': 0,
    'CHIPPEWA': 0,
    'CHIPPS': 0,
    'CHIPRES': 0,
    'CHIPREZ': 0,
    'CHIPS': 0,
    'CHIQUETE': 0,
    'CHIQUI': 0,
    'CHIQUILLO': 0,
    'CHIQUITA': 1,
    'CHIQUITO': 0,
    'CHIRA': 0,
    'CHIRAS': 0,
    'CHIRCHIRILLO': 0,
    'CHIRCO': 0,
    'CHIRDON': 0,
    'CHIRGWIN': 0,
    'CHIRHART': 0,
    'CHIRI': 0,
    'CHIRIBOGA': 0,
    'CHIRICHELLA': 0,
    'CHIRICHIELLO': 0,
    'CHIRICO': 0,
    'CHIRILLO': 0,
    'CHIRINO': 0,
    'CHIRINOS': 0,
    'CHIRO': 0,
    'CHIRPICH': 0,
    'CHIRRICK': 0,
    'CHIRUMBOLO': 0,
    'CHIS': 0,
    'CHISAM': 0,
    'CHISAMORE': 0,
    'CHISARI': 0,
    'CHISCHILLY': 0,
    'CHISEM': 0,
    'CHISENHALL': 0,
    'CHISESI': 0,
    'CHISHAM': 0,
    'CHISHOLM': 0,
    'CHISHTI': 0,
    'CHISLER': 0,
    'CHISLETT': 0,
    'CHISLEY': 0,
    'CHISLOM': 0,
    'CHISM': 0,
    'CHISMAN': 0,
    'CHISMAR': 0,
    'CHISNELL': 0,
    'CHISOLM': 0,
    'CHISOM': 0,
    'CHISUM': 0,
    'CHITESTER': 0,
    'CHITMAN': 0,
    'CHITNIS': 0,
    'CHITTENDEN': 0,
    'CHITTESTER': 0,
    'CHITTICK': 0,
    'CHITTIM': 0,
    'CHITTOCK': 0,
    'CHITTOM': 0,
    'CHITTUM': 0,
    'CHITTY': 0,
    'CHITWOOD': 0,
    'CHIU': 0,
    'CHIUCHIOLO': 0,
    'CHIULLI': 0,
    'CHIUMENTO': 0,
    'CHIUSANO': 0,
    'CHIV': 0,
    'CHIVERS': 0,
    'CHIVERTON': 0,
    'CHIVINGTON': 0,
    'CHIZ': 0,
    'CHIZEK': 0,
    'CHIZER': 0,
    'CHIZMADIA': 0,
    'CHIZMAR': 0,
    'CHLADEK': 0,
    'CHLAN': 0,
    'CHLARSON': 0,
    'CHLEBEK': 0,
    'CHLEBOWSKI': 0,
    'CHLIPALA': 0,
    'CHLOE': 1,
    'CHLOPECKI': 0,
    'CHLOPEK': 0,
    'CHLOUPEK': 0,
    'CHLUDZINSKI': 0,
    'CHMARA': 0,
    'CHMELA': 0,
    'CHMELAR': 0,
    'CHMELIK': 0,
    'CHMELKA': 0,
    'CHMIEL': 0,
    'CHMIELECKI': 0,
    'CHMIELESKI': 0,
    'CHMIELEWSKI': 0,
    'CHMIELINSKI': 0,
    'CHMIELOWIEC': 0,
    'CHMIELOWSKI': 0,
    'CHMIL': 0,
    'CHMURA': 0,
    'CHO': 0,
    'CHOA': 0,
    'CHOAT': 0,
    'CHOATE': 0,
    'CHOATES': 0,
    'CHOBAN': 0,
    'CHOBANIAN': 0,
    'CHOBOT': 0,
    'CHOC': 0,
    'CHOCK': 0,
    'CHOCKLETT': 0,
    'CHOCKLEY': 0,
    'CHOCOTECO': 0,
    'CHODAK': 0,
    'CHODKOWSKI': 0,
    'CHODNICKI': 0,
    'CHODOR': 0,
    'CHODOS': 0,
    'CHODOSH': 0,
    'CHOE': 0,
    'CHOEUN': 0,
    'CHOHAN': 0,
    'CHOI': 0,
    'CHOICE': 0,
    'CHOINA': 0,
    'CHOINIERE': 0,
    'CHOINSKI': 0,
    'CHOISSER': 0,
    'CHOITZ': 0,
    'CHOJECKI': 0,
    'CHOJNACKI': 0,
    'CHOJNICKI': 0,
    'CHOJNOWSKI': 0,
    'CHOKA': 0,
    'CHOKSHI': 0,
    'CHOKSI': 0,
    'CHOL': 0,
    'CHOLAGH': 0,
    'CHOLAK': 0,
    'CHOLAKIAN': 0,
    'CHOLETTE': 0,
    'CHOLEWA': 0,
    'CHOLEWINSKI': 0,
    'CHOLICO': 0,
    'CHOLLET': 0,
    'CHOLLETT': 0,
    'CHOLULA': 0,
    'CHOM': 0,
    'CHOMA': 0,
    'CHOMAS': 0,
    'CHOMIAK': 0,
    'CHOMICKI': 0,
    'CHOMICZ': 0,
    'CHOMKO': 0,
    'CHON': 0,
    'CHONA': 0,
    'CHONG': 0.6957621758380772,
    'CHONKA': 0,
    'CHONKO': 0,
    'CHONTOS': 0,
    'CHOO': 0,
    'CHOON': 0,
    'CHOONG': 0,
    'CHOP': 0,
    'CHOPE': 0,
    'CHOPELAS': 0,
    'CHOPIN': 0,
    'CHOPKO': 0,
    'CHOPLIN': 0,
    'CHOPP': 0,
    'CHOPPER': 0,
    'CHOPPIN': 0,
    'CHOPRA': 0,
    'CHOPYAK': 0,
    'CHOQUE': 0,
    'CHOQUETTE': 0,
    'CHOR': 0,
    'CHORA': 0,
    'CHORAK': 0,
    'CHORBA': 0,
    'CHORBAJIAN': 0,
    'CHORD': 0,
    'CHORDAS': 0,
    'CHOREY': 0,
    'CHORLEY': 0,
    'CHORLTON': 0,
    'CHORMAN': 0,
    'CHORN': 0,
    'CHORNEY': 0,
    'CHORNY': 0,
    'CHOROMANSKI': 0,
    'CHORPENNING': 0,
    'CHORY': 0,
    'CHORZEMPA': 0,
    'CHOSA': 0,
    'CHOSE': 0,
    'CHOSTNER': 0,
    'CHOT': 0,
    'CHOTE': 0,
    'CHOTINER': 0,
    'CHOTKOWSKI': 0,
    'CHOTO': 0,
    'CHOTT': 0,
    'CHOU': 0,
    'CHOUDARY': 0,
    'CHOUDHARY': 0,
    'CHOUDHRY': 0,
    'CHOUDHURY': 0,
    'CHOUDRY': 0,
    'CHOUEST': 0,
    'CHOUGH': 0,
    'CHOUINARD': 0,
    'CHOULES': 0,
    'CHOULOUTE': 0,
    'CHOUN': 0,
    'CHOUNARD': 0,
    'CHOUNG': 0,
    'CHOUNLAMANY': 0,
    'CHOUTE': 0,
    'CHOUTEAU': 0,
    'CHOVAN': 0,
    'CHOVANEC': 0,
    'CHOW': 0,
    'CHOWANEC': 0,
    'CHOWANIEC': 0,
    'CHOWDHARY': 0,
    'CHOWDHRY': 0,
    'CHOWDHURY': 0,
    'CHOWEN': 0,
    'CHOWN': 0,
    'CHOWNING': 0,
    'CHOY': 0,
    'CHOYCE': 0,
    'CHRANE': 0,
    'CHRANS': 0,
    'CHRASTIL': 0,
    'CHREENE': 0,
    'CHREST': 0,
    'CHRESTENSEN': 0,
    'CHRESTMAN': 0,
    'CHRETIEN': 0,
    'CHRIEST': 0,
    'CHRIESTENSON': 0,
    'CHRIETZBERG': 0,
    'CHRIN': 0,
    'CHRIS': 0.9983736899168776,
    'CHRISAWN': 0,
    'CHRISCO': 0,
    'CHRISCOE': 0,
    'CHRISENBERRY': 0,
    'CHRISINGER': 0,
    'CHRISLER': 0,
    'CHRISLEY': 0,
    'CHRISLIP': 0,
    'CHRISMAN': 0,
    'CHRISMER': 0,
    'CHRISMON': 0,
    'CHRISNER': 0,
    'CHRISOS': 0,
    'CHRISP': 0,
    'CHRISPELL': 0,
    'CHRISPEN': 0,
    'CHRISPIN': 0,
    'CHRISS': 0,
    'CHRISSY': 1,
    'CHRIST': 0,
    'CHRISTA': 0.9965337954939342,
    'CHRISTAIN': 0,
    'CHRISTAKIS': 0,
    'CHRISTAKOS': 0,
    'CHRISTAL': 0.975609756097561,
    'CHRISTALDI': 0,
    'CHRISTAN': 0,
    'CHRISTE': 0,
    'CHRISTEEN': 1,
    'CHRISTEL': 0.9433962264150944,
    'CHRISTEN': 0.8443908323281062,
    'CHRISTENA': 1,
    'CHRISTENBERRY': 0,
    'CHRISTENBURY': 0,
    'CHRISTENE': 1,
    'CHRISTENSEN': 0,
    'CHRISTENSON': 0,
    'CHRISTERSON': 0,
    'CHRISTESEN': 0,
    'CHRISTESON': 0,
    'CHRISTI': 0.9941520467836258,
    'CHRISTIA': 1,
    'CHRISTIAENS': 0,
    'CHRISTIAN': 0.7981270618282431,
    'CHRISTIANA': 0.9118541033434651,
    'CHRISTIANE': 1,
    'CHRISTIANI': 0,
    'CHRISTIANO': 0,
    'CHRISTIANS': 0,
    'CHRISTIANSEN': 0,
    'CHRISTIANSON': 0,
    'CHRISTIE': 0.839091806515301,
    'CHRISTIN': 0.9803921568627452,
    'CHRISTINA': 0.9983663096750771,
    'CHRISTINE': 0.9984056872533389,
    'CHRISTING': 0,
    'CHRISTINIA': 1,
    'CHRISTINO': 0,
    'CHRISTINSON': 0,
    'CHRISTION': 0,
    'CHRISTISON': 0,
    'CHRISTL': 0,
    'CHRISTLE': 0,
    'CHRISTLER': 0,
    'CHRISTLEY': 0,
    'CHRISTLIEB': 0,
    'CHRISTMAN': 0,
    'CHRISTMANN': 0,
    'CHRISTMAS': 0,
    'CHRISTMON': 0,
    'CHRISTNER': 0,
    'CHRISTO': 0,
    'CHRISTODOULOU': 0,
    'CHRISTOFANO': 0,
    'CHRISTOFARO': 0,
    'CHRISTOFERSON': 0,
    'CHRISTOFF': 0,
    'CHRISTOFFEL': 0,
    'CHRISTOFFER': 0,
    'CHRISTOFFERS': 0,
    'CHRISTOFFERSEN': 0,
    'CHRISTOFFERSON': 0,
    'CHRISTOFORO': 0,
    'CHRISTOFOROU': 0,
    'CHRISTOL': 0,
    'CHRISTON': 0,
    'CHRISTOPER': 1,
    'CHRISTOPH': 0,
    'CHRISTOPHE': 0,
    'CHRISTOPHEL': 0,
    'CHRISTOPHER': 0.9899290455481803,
    'CHRISTOPHERSEN': 0,
    'CHRISTOPHERSON': 0,
    'CHRISTOPOULOS': 0,
    'CHRISTOPULOS': 0,
    'CHRISTOS': 0,
    'CHRISTOU': 0,
    'CHRISTY': 0.9398266813133163,
    'CHRISWELL': 0,
    'CHRITTON': 0,
    'CHRIVIA': 0,
    'CHROBAK': 0,
    'CHROMEY': 0,
    'CHROMIAK': 0,
    'CHROMIK': 0,
    'CHROMY': 0,
    'CHRON': 0,
    'CHRONIC': 0,
    'CHRONINGER': 0,
    'CHRONIS': 0,
    'CHRONISTER': 0,
    'CHRONOPOULOS': 0,
    'CHRONOWSKI': 0,
    'CHROSNIAK': 0,
    'CHROSTOWSKI': 0,
    'CHRUPCALA': 0,
    'CHRUSCIEL': 0,
    'CHRYSLER': 0,
    'CHRYST': 0,
    'CHRYSTAL': 0.9812667261373774,
    'CHRZAN': 0,
    'CHRZANOWSKI': 0,
    'CHRZASZCZ': 0,
    'CHU': 0.09960159362549803,
    'CHUA': 0,
    'CHUAH': 0,
    'CHUAN': 0,
    'CHUANG': 0,
    'CHUBA': 0,
    'CHUBB': 0,
    'CHUBBS': 0,
    'CHUBBUCK': 0,
    'CHUC': 0,
    'CHUCA': 0,
    'CHUCK': 0.9785932721712538,
    'CHUCKRAN': 0,
    'CHUCULATE': 0,
    'CHUDACOFF': 0,
    'CHUDASAMA': 0,
    'CHUDEJ': 0,
    'CHUDIK': 0,
    'CHUDNOVSKY': 0,
    'CHUDNOW': 0,
    'CHUDOBA': 0,
    'CHUDY': 0,
    'CHUDYK': 0,
    'CHUDZIK': 0,
    'CHUDZINSKI': 0,
    'CHUE': 0,
    'CHUEN': 0,
    'CHUEY': 0,
    'CHUGANI': 0,
    'CHUGG': 0,
    'CHUGH': 0,
    'CHUGHTAI': 0,
    'CHUHA': 0,
    'CHUHRAN': 0,
    'CHUI': 0,
    'CHUK': 0,
    'CHUKES': 0,
    'CHUKWU': 0,
    'CHUKWUMA': 0,
    'CHULICK': 0,
    'CHUM': 0,
    'CHUMA': 0,
    'CHUMAN': 0,
    'CHUMAS': 0,
    'CHUMBLER': 0,
    'CHUMBLEY': 0,
    'CHUMCHAL': 0,
    'CHUMLEY': 0,
    'CHUMNEY': 0,
    'CHUMPITAZ': 0,
    'CHUN': 0.420757363253857,
    'CHUNG': 0.34146341463414637,
    'CHUNGA': 0,
    'CHUNKO': 0,
    'CHUNN': 0,
    'CHUON': 0,
    'CHUONG': 0,
    'CHUPA': 0,
    'CHUPIK': 0,
    'CHUPKA': 0,
    'CHUPP': 0,
    'CHURA': 0,
    'CHURAN': 0,
    'CHURCH': 0,
    'CHURCHES': 0,
    'CHURCHEY': 0,
    'CHURCHFIELD': 0,
    'CHURCHILL': 0,
    'CHURCHMAN': 0,
    'CHURCHVILLE': 0,
    'CHURCHWARD': 0,
    'CHURCHWELL': 0,
    'CHURGIN': 0,
    'CHURILLA': 0,
    'CHURLEY': 0,
    'CHURN': 0,
    'CHURNEY': 0,
    'CHUSID': 0,
    'CHUSTZ': 0,
    'CHUTE': 0,
    'CHUTZ': 0,
    'CHUY': 0,
    'CHVALA': 0,
    'CHVATAL': 0,
    'CHWALA': 0,
    'CHWALEK': 0,
    'CHY': 0,
    'CHYBOWSKI': 0,
    'CHYLE': 0,
    'CHYLINSKI': 0,
    'CHYNOWETH': 0,
    'CHYTIL': 0,
    'CHYTKA': 0,
    'CHZN': 0,
    'CI': 0,
    'CIA': 0,
    'CIABATTARI': 0,
    'CIABATTONI': 0,
    'CIABURRI': 0,
    'CIACCI': 0,
    'CIACCIA': 0,
    'CIACCIARELLI': 0,
    'CIACCIO': 0,
    'CIAFFONE': 0,
    'CIAGLIA': 0,
    'CIAK': 0,
    'CIALDELLA': 0,
    'CIALINI': 0,
    'CIALLELLA': 0,
    'CIALONE': 0,
    'CIAMBRIELLO': 0,
    'CIAMBRONE': 0,
    'CIAMILLO': 0,
    'CIAMPA': 0,
    'CIAMPAGLIA': 0,
    'CIAMPI': 0,
    'CIAMPOLI': 0,
    'CIANCA': 0,
    'CIANCAGLINI': 0,
    'CIANCANELLI': 0,
    'CIANCARELLI': 0,
    'CIANCHETTI': 0,
    'CIANCI': 0,
    'CIANCIA': 0,
    'CIANCIARULO': 0,
    'CIANCIMINO': 0,
    'CIANCIO': 0,
    'CIANCIOLA': 0,
    'CIANCIOLO': 0,
    'CIANCIOSI': 0,
    'CIANCIOTTO': 0,
    'CIANCIULLI': 0,
    'CIANELLI': 0,
    'CIANFAGLIONE': 0,
    'CIANFARANI': 0,
    'CIANFLONE': 0,
    'CIANFRANI': 0,
    'CIANFROCCA': 0,
    'CIANI': 0,
    'CIANNI': 0,
    'CIANO': 0,
    'CIAPPA': 0,
    'CIAPPETTA': 0,
    'CIARA': 0.986842105263158,
    'CIARAMELLA': 0,
    'CIARAMELLO': 0,
    'CIARAMITARO': 0,
    'CIARAVINO': 0,
    'CIARCIA': 0,
    'CIARDELLA': 0,
    'CIARDELLI': 0,
    'CIARDI': 0,
    'CIARDIELLO': 0,
    'CIARDO': 0,
    'CIARDULLO': 0,
    'CIARELLI': 0,
    'CIARKE': 0,
    'CIARKOWSKI': 0,
    'CIARLANTE': 0,
    'CIARLEGLIO': 0,
    'CIARLETTA': 0,
    'CIARLO': 0,
    'CIARLONE': 0,
    'CIARROCCA': 0,
    'CIARROCCHI': 0,
    'CIARY': 0,
    'CIASULLO': 0,
    'CIATTI': 0,
    'CIATTO': 0,
    'CIAVAGLIA': 0,
    'CIAVARELLA': 0,
    'CIAVARELLI': 0,
    'CIAVATTONE': 0,
    'CIAVOLA': 0,
    'CIBELLI': 0,
    'CIBIK': 0,
    'CIBOROWSKI': 0,
    'CIBOTTI': 0,
    'CIBRIAN': 0,
    'CIBULA': 0,
    'CIBULKA': 0,
    'CICAK': 0,
    'CICALA': 0,
    'CICALE': 0,
    'CICALESE': 0,
    'CICALO': 0,
    'CICARELLI': 0,
    'CICATELLI': 0,
    'CICATELLO': 0,
    'CICCAGLIONE': 0,
    'CICCARELLA': 0,
    'CICCARELLI': 0,
    'CICCARELLO': 0,
    'CICCARIELLO': 0,
    'CICCARONE': 0,
    'CICCHELLI': 0,
    'CICCHESE': 0,
    'CICCHETTI': 0,
    'CICCHINELLI': 0,
    'CICCHINI': 0,
    'CICCHINO': 0,
    'CICCI': 0,
    'CICCIA': 0,
    'CICCIARELLI': 0,
    'CICCIO': 0,
    'CICCO': 0,
    'CICCOLELLA': 0,
    'CICCOLINI': 0,
    'CICCOLO': 0,
    'CICCONE': 0,
    'CICCONETTI': 0,
    'CICCONI': 0,
    'CICCOTELLI': 0,
    'CICCOTTI': 0,
    'CICCOTTO': 0,
    'CICELY': 1,
    'CICERCHIA': 0,
    'CICERO': 0,
    'CICERON': 0,
    'CICERONE': 0,
    'CICH': 0,
    'CICHA': 0,
    'CICHANOWICZ': 0,
    'CICHANSKI': 0,
    'CICHETTI': 0,
    'CICHOCKI': 0,
    'CICHON': 0,
    'CICHONSKI': 0,
    'CICHORACKI': 0,
    'CICHOS': 0,
    'CICHOSKI': 0,
    'CICHOSZ': 0,
    'CICHOWICZ': 0,
    'CICHOWSKI': 0,
    'CICHY': 0,
    'CICI': 0,
    'CICIARELLI': 0,
    'CICILLINI': 0,
    'CICINELLI': 0,
    'CICIO': 0,
    'CICIONE': 0,
    'CICIORA': 0,
    'CICIRELLI': 0,
    'CICIRELLO': 0,
    'CICO': 0,
    'CICOGNA': 0,
    'CICON': 0,
    'CICONE': 0,
    'CICONTE': 0,
    'CICORA': 0,
    'CICORIA': 0,
    'CICOTTE': 0,
    'CID': 0,
    'CIECHANOWSKI': 0,
    'CIECIERSKI': 0,
    'CIECKO': 0,
    'CIELINSKI': 0,
    'CIELO': 0,
    'CIEMINSKI': 0,
    'CIENEGA': 0,
    'CIENFUEGOS': 0,
    'CIENIEWICZ': 0,
    'CIEPIELA': 0,
    'CIEPLIK': 0,
    'CIEPLINSKI': 0,
    'CIEPLY': 0,
    'CIERA': 1,
    'CIERI': 0,
    'CIERO': 0,
    'CIERPIAL': 0,
    'CIERRA': 0.9740259740259739,
    'CIERVO': 0,
    'CIESIELCZYK': 0,
    'CIESIELSKI': 0,
    'CIESINSKI': 0,
    'CIESIOLKA': 0,
    'CIESLA': 0,
    'CIESLAK': 0,
    'CIESLEWICZ': 0,
    'CIESLIK': 0,
    'CIESLINSKI': 0,
    'CIESLUK': 0,
    'CIESZYNSKI': 0,
    'CIEZKI': 0,
    'CIFALDI': 0,
    'CIFARELLI': 0,
    'CIFELLI': 0,
    'CIFERRI': 0,
    'CIFERS': 0,
    'CIFONE': 0,
    'CIFRA': 0,
    'CIFUENTES': 0,
    'CIFUNI': 0,
    'CIGAINERO': 0,
    'CIGALA': 0,
    'CIGAN': 0,
    'CIGANEK': 0,
    'CIGARROA': 0,
    'CIGELSKE': 0,
    'CIGICH': 0,
    'CIGLER': 0,
    'CIGLIANO': 0,
    'CIGNA': 0,
    'CIGNARELLA': 0,
    'CIGNETTI': 0,
    'CIHA': 0,
    'CIHAK': 0,
    'CIHAL': 0,
    'CIHLA': 0,
    'CIHLAR': 0,
    'CIHON': 0,
    'CIKA': 0,
    'CIKANEK': 0,
    'CIKO': 0,
    'CIKOWSKI': 0,
    'CILANO': 0,
    'CILEK': 0,
    'CILENTI': 0,
    'CILENTO': 0,
    'CILETTI': 0,
    'CILIA': 0,
    'CILIBERTI': 0,
    'CILIBERTO': 0,
    'CILIENTO': 0,
    'CILIO': 0,
    'CILLA': 0,
    'CILLEY': 0,
    'CILLI': 0,
    'CILLIS': 0,
    'CILLO': 0,
    'CILLUFFO': 0,
    'CILMI': 0,
    'CILUFFO': 0,
    'CIMA': 0,
    'CIMAGLIA': 0,
    'CIMARUSTI': 0,
    'CIMATO': 0,
    'CIMENT': 0,
    'CIMENTAL': 0,
    'CIMILLUCA': 0,
    'CIMINELLI': 0,
    'CIMINELLO': 0,
    'CIMINERA': 0,
    'CIMINI': 0,
    'CIMINO': 0,
    'CIMMARUSTI': 0,
    'CIMMINO': 0,
    'CIMO': 0,
    'CIMOCH': 0,
    'CIMOCHOWSKI': 0,
    'CIMON': 0,
    'CIMORELLI': 0,
    'CIMPERMAN': 0,
    'CIN': 0,
    'CINA': 0,
    'CINADER': 0,
    'CINADR': 0,
    'CINALLI': 0,
    'CINAR': 0,
    'CINCO': 0,
    'CINCOSKI': 0,
    'CINCOTTA': 0,
    'CINCOTTI': 0,
    'CINDA': 1,
    'CINDERELLA': 1,
    'CINDI': 1,
    'CINDIE': 1,
    'CINDRIC': 0,
    'CINDRICH': 0,
    'CINDY': 1,
    'CINE': 0,
    'CINEAS': 0,
    'CINELLI': 0,
    'CINER': 0,
    'CINEUS': 0,
    'CINGEL': 0,
    'CINGLE': 0,
    'CINGOLANI': 0,
    'CINI': 0,
    'CINICOLA': 0,
    'CINK': 0,
    'CINKO': 0,
    'CINNAMON': 0,
    'CINNAMOND': 0,
    'CINO': 0,
    'CINOTTI': 0,
    'CINOTTO': 0,
    'CINQMARS': 0,
    'CINQUE': 0,
    'CINQUEGRANA': 0,
    'CINQUEGRANI': 0,
    'CINQUEMANI': 0,
    'CINQUINI': 0,
    'CINQUINO': 0,
    'CINTAS': 0,
    'CINTHIA': 1,
    'CINTI': 0,
    'CINTO': 0,
    'CINTOLO': 0,
    'CINTORA': 0,
    'CINTORINO': 0,
    'CINTRA': 0,
    'CINTRON': 0,
    'CIOBANU': 0,
    'CIOCCA': 0,
    'CIOCCI': 0,
    'CIOCCO': 0,
    'CIOCH': 0,
    'CIOCHON': 0,
    'CIOCI': 0,
    'CIOCIOLA': 0,
    'CIOE': 0,
    'CIOFALO': 0,
    'CIOFANI': 0,
    'CIOFFI': 0,
    'CIOLEK': 0,
    'CIOLFI': 0,
    'CIOLINO': 0,
    'CIOLKOSZ': 0,
    'CIOLLI': 0,
    'CIONE': 0,
    'CIONGOLI': 0,
    'CIONI': 0,
    'CIOPPA': 0,
    'CIORCIARI': 0,
    'CIOSEK': 0,
    'CIOTOLA': 0,
    'CIOTOLI': 0,
    'CIOTTA': 0,
    'CIOTTI': 0,
    'CIPOLETTI': 0,
    'CIPOLLA': 0,
    'CIPOLLETTI': 0,
    'CIPOLLINA': 0,
    'CIPOLLINI': 0,
    'CIPOLLONE': 0,
    'CIPOLLONI': 0,
    'CIPPARONE': 0,
    'CIPPERLY': 0,
    'CIPPONERI': 0,
    'CIPRA': 0,
    'CIPRES': 0,
    'CIPRIAN': 0,
    'CIPRIANI': 0,
    'CIPRIANO': 0,
    'CIPRICH': 0,
    'CIPRO': 0,
    'CIPULLO': 0,
    'CIRA': 0.7936507936507936,
    'CIRACO': 0,
    'CIRALDO': 0,
    'CIRANNI': 0,
    'CIRAOLO': 0,
    'CIRAULO': 0,
    'CIRBO': 0,
    'CIRBUS': 0,
    'CIRCELLI': 0,
    'CIRCELLO': 0,
    'CIRCLE': 0,
    'CIRCO': 0,
    'CIRCOSTA': 0,
    'CIRELLA': 0,
    'CIRELLI': 0,
    'CIRELLO': 0,
    'CIRESI': 0,
    'CIRIACKS': 0,
    'CIRIACO': 0,
    'CIRIC': 0,
    'CIRIELLO': 0,
    'CIRIGLIANO': 0,
    'CIRIGNANO': 0,
    'CIRILLI': 0,
    'CIRILLO': 0,
    'CIRILO': 0,
    'CIRIMELE': 0,
    'CIRINCIONE': 0,
    'CIRINO': 0,
    'CIRKA': 0,
    'CIRKO': 0,
    'CIRKS': 0,
    'CIRLOS': 0,
    'CIRNE': 0,
    'CIRNIGLIARO': 0,
    'CIRO': 0,
    'CIROCCO': 0,
    'CIRONE': 0,
    'CIRRI': 0,
    'CIRRINCIONE': 0,
    'CIRRITO': 0,
    'CIRRONE': 0,
    'CIRULLI': 0,
    'CIRULLO': 0,
    'CISAR': 0,
    'CISARIK': 0,
    'CISCHKE': 0,
    'CISCO': 0,
    'CISEK': 0,
    'CISERO': 0,
    'CISEWSKI': 0,
    'CISKE': 0,
    'CISKOWSKI': 0,
    'CISLAK': 0,
    'CISLER': 0,
    'CISLO': 0,
    'CISNA': 0,
    'CISNE': 0,
    'CISNERO': 0,
    'CISNEROS': 0,
    'CISNEROZ': 0,
    'CISNEY': 0,
    'CISON': 0,
    'CISOWSKI': 0,
    'CISSE': 0,
    'CISSEL': 0,
    'CISSELL': 0,
    'CISSNA': 0,
    'CISSON': 0,
    'CISTARO': 0,
    'CISTERNINO': 0,
    'CISTONE': 0,
    'CISTRUNK': 0,
    'CISZAK': 0,
    'CISZEK': 0,
    'CISZEWSKI': 0,
    'CITAK': 0,
    'CITAL': 0,
    'CITARELLA': 0,
    'CITARELLI': 0,
    'CITERA': 0,
    'CITINO': 0,
    'CITIZEN': 0,
    'CITO': 0,
    'CITRANO': 0,
    'CITRIN': 0,
    'CITRINITI': 0,
    'CITRINO': 0,
    'CITRO': 0,
    'CITRON': 0,
    'CITRONE': 0,
    'CITROWSKE': 0,
    'CITTA': 0,
    'CITTADINO': 0,
    'CITTI': 0,
    'CITTY': 0,
    'CITY': 0,
    'CIUBA': 0,
    'CIUCCI': 0,
    'CIUFFETELLI': 0,
    'CIUFFO': 0,
    'CIUFO': 0,
    'CIULLA': 0,
    'CIULLO': 0,
    'CIUMMO': 0,
    'CIUS': 0,
    'CIVALE': 0,
    'CIVELLO': 0,
    'CIVETTA': 0,
    'CIVETTI': 0,
    'CIVIDANES': 0,
    'CIVIELLO': 0,
    'CIVIL': 0,
    'CIVILETTI': 0,
    'CIVILS': 0,
    'CIVITA': 0,
    'CIVITANO': 0,
    'CIVITARESE': 0,
    'CIVITELLA': 0,
    'CIVITELLO': 0,
    'CIVITILLO': 0,
    'CIZAUSKAS': 0,
    'CIZEK': 0,
    'CIZMAR': 0,
    'CLAAR': 0,
    'CLAAS': 0,
    'CLAASSEN': 0,
    'CLABAUGH': 0,
    'CLABBY': 0,
    'CLABEAUX': 0,
    'CLABO': 0,
    'CLABORN': 0,
    'CLABOTS': 0,
    'CLABOUGH': 0,
    'CLABURN': 0,
    'CLACK': 0,
    'CLACKLER': 0,
    'CLACKUM': 0,
    'CLADY': 0,
    'CLAERHOUT': 0,
    'CLAES': 0,
    'CLAESON': 0,
    'CLAESSENS': 0,
    'CLAESSON': 0,
    'CLAEYS': 0,
    'CLAFFEY': 0,
    'CLAFFY': 0,
    'CLAFLIN': 0,
    'CLAGETT': 0,
    'CLAGG': 0,
    'CLAGGETT': 0,
    'CLAGHORN': 0,
    'CLAGUE': 0,
    'CLAH': 0,
    'CLAIBORN': 0,
    'CLAIBORNE': 0,
    'CLAIBOURN': 0,
    'CLAIN': 0,
    'CLAIR': 0.8675078864353313,
    'CLAIRDAY': 0,
    'CLAIRE': 0.9933235629376322,
    'CLAIRMONT': 0,
    'CLAITT': 0,
    'CLAK': 0,
    'CLAKLEY': 0,
    'CLAMAN': 0,
    'CLAMON': 0,
    'CLAMP': 0,
    'CLAMPET': 0,
    'CLAMPETT': 0,
    'CLAMPIT': 0,
    'CLAMPITT': 0,
    'CLAN': 0,
    'CLANAHAN': 0,
    'CLANCE': 0,
    'CLANCEY': 0,
    'CLANCY': 0,
    'CLANEY': 0,
    'CLANG': 0,
    'CLANIN': 0,
    'CLANTON': 0,
    'CLAPHAM': 0,
    'CLAPHAN': 0,
    'CLAPP': 0,
    'CLAPPER': 0,
    'CLAPPERTON': 0,
    'CLAPPS': 0,
    'CLAPROOD': 0,
    'CLAPS': 0,
    'CLAPSADDLE': 0,
    'CLAPSADLE': 0,
    'CLAR': 0,
    'CLARA': 0.9974574613729709,
    'CLARAHAN': 0,
    'CLARAMITARO': 0,
    'CLARCK': 0,
    'CLARDY': 0,
    'CLARE': 0.8856088560885608,
    'CLARENCE': 0.99934386513905,
    'CLARETHA': 1,
    'CLARETT': 0,
    'CLARETTA': 1,
    'CLAREY': 0,
    'CLARIBEL': 1,
    'CLARICE': 1,
    'CLARIDA': 0,
    'CLARIDGE': 0,
    'CLARIDY': 0,
    'CLARIN': 0,
    'CLARINDA': 1,
    'CLARINE': 1,
    'CLARINGTON': 0,
    'CLARINO': 0,
    'CLARIS': 1,
    'CLARISA': 1,
    'CLARISSA': 1,
    'CLARITA': 1,
    'CLARITY': 0,
    'CLARIZIO': 0,
    'CLARK': 0.11339846475924634,
    'CLARKE': 0,
    'CLARKEN': 0,
    'CLARKIN': 0,
    'CLARKSON': 0,
    'CLARKSTON': 0,
    'CLARNO': 0,
    'CLARO': 0,
    'CLAROS': 0,
    'CLARR': 0,
    'CLARRIDGE': 0,
    'CLARRY': 0,
    'CLARSON': 0,
    'CLARY': 0,
    'CLAS': 0,
    'CLASBY': 0,
    'CLASE': 0,
    'CLASEMAN': 0,
    'CLASEN': 0,
    'CLASH': 0,
    'CLASING': 0,
    'CLASON': 0,
    'CLASPELL': 0,
    'CLASPILL': 0,
    'CLASS': 0,
    'CLASSEN': 0,
    'CLASSEY': 0,
    'CLASSI': 0,
    'CLASSIE': 1,
    'CLASSON': 0,
    'CLATER': 0,
    'CLATON': 0,
    'CLATT': 0,
    'CLATTENBURG': 0,
    'CLATTERBAUGH': 0,
    'CLATTERBUCK': 0,
    'CLATWORTHY': 0,
    'CLAUD': 0.9456264775413711,
    'CLAUDE': 0.9905254091300603,
    'CLAUDER': 0,
    'CLAUDETTE': 1,
    'CLAUDIA': 1,
    'CLAUDIE': 1,
    'CLAUDINE': 1,
    'CLAUDINO': 0,
    'CLAUDIO': 0.7547169811320754,
    'CLAUDY': 0,
    'CLAUER': 0,
    'CLAUGHTON': 0,
    'CLAUNCH': 0,
    'CLAURE': 0,
    'CLAUS': 0,
    'CLAUSE': 0,
    'CLAUSEL': 0,
    'CLAUSELL': 0,
    'CLAUSEN': 0,
    'CLAUSER': 0,
    'CLAUSI': 0,
    'CLAUSING': 0,
    'CLAUSIUS': 0,
    'CLAUSMAN': 0,
    'CLAUSNITZER': 0,
    'CLAUSON': 0,
    'CLAUSS': 0,
    'CLAUSSEN': 0,
    'CLAUSTRO': 0,
    'CLAVE': 0,
    'CLAVEAU': 0,
    'CLAVEL': 0,
    'CLAVELL': 0,
    'CLAVELLE': 0,
    'CLAVELLI': 0,
    'CLAVENNA': 0,
    'CLAVER': 0,
    'CLAVERIA': 0,
    'CLAVERIE': 0,
    'CLAVERO': 0,
    'CLAVET': 0,
    'CLAVETTE': 0,
    'CLAVEY': 0,
    'CLAVIER': 0,
    'CLAVIJO': 0,
    'CLAVIN': 0,
    'CLAVON': 0,
    'CLAW': 0,
    'CLAWGES': 0,
    'CLAWSON': 0,
    'CLAX': 0,
    'CLAXON': 0,
    'CLAXTON': 0,
    'CLAY': 0.5504587155963303,
    'CLAYBAUGH': 0,
    'CLAYBERG': 0,
    'CLAYBERGER': 0,
    'CLAYBON': 0,
    'CLAYBORN': 0,
    'CLAYBORNE': 0,
    'CLAYBOURN': 0,
    'CLAYBOURNE': 0,
    'CLAYBROOK': 0,
    'CLAYBROOKS': 0,
    'CLAYBURG': 0,
    'CLAYBURN': 0,
    'CLAYCAMP': 0,
    'CLAYCOMB': 0,
    'CLAYDON': 0,
    'CLAYMAN': 0,
    'CLAYMORE': 0,
    'CLAYPOLE': 0,
    'CLAYPOOL': 0,
    'CLAYPOOLE': 0,
    'CLAYS': 0,
    'CLAYSON': 0,
    'CLAYTER': 0,
    'CLAYTON': 0.7468259895444361,
    'CLAYTOR': 0,
    'CLAYVILLE': 0,
    'CLAYWELL': 0,
    'CLEA': 0,
    'CLEAR': 0,
    'CLEARE': 0,
    'CLEARFIELD': 0,
    'CLEARMAN': 0,
    'CLEARWATER': 0,
    'CLEARY': 0,
    'CLEASBY': 0,
    'CLEATON': 0,
    'CLEATOR': 0,
    'CLEAVE': 0,
    'CLEAVELAND': 0,
    'CLEAVENGER': 0,
    'CLEAVER': 0,
    'CLEAVES': 0,
    'CLEAVINGER': 0,
    'CLEAVLAND': 0,
    'CLECKIER': 0,
    'CLECKLER': 0,
    'CLECKLEY': 0,
    'CLECKNER': 0,
    'CLEE': 0,
    'CLEEK': 0,
    'CLEELAND': 0,
    'CLEER': 0,
    'CLEERE': 0,
    'CLEEREMAN': 0,
    'CLEES': 0,
    'CLEETON': 0,
    'CLEEVES': 0,
    'CLEGG': 0,
    'CLEGGETT': 0,
    'CLEGHORN': 0,
    'CLEIN': 0,
    'CLELAND': 0,
    'CLELIA': 1,
    'CLELLAND': 0,
    'CLEM': 0,
    'CLEMAN': 0,
    'CLEMANS': 0,
    'CLEMEN': 0,
    'CLEMENCE': 0,
    'CLEMENCIA': 1,
    'CLEMENS': 0,
    'CLEMENSEN': 0,
    'CLEMENSON': 0,
    'CLEMENT': 0.5373455131649651,
    'CLEMENTE': 0.591715976331361,
    'CLEMENTI': 0,
    'CLEMENTINA': 1,
    'CLEMENTINE': 1,
    'CLEMENTS': 0,
    'CLEMENTSON': 0,
    'CLEMENTZ': 0,
    'CLEMENZA': 0,
    'CLEMETSON': 0,
    'CLEMINS': 0,
    'CLEMM': 0,
    'CLEMMENS': 0,
    'CLEMMENSEN': 0,
    'CLEMMER': 0,
    'CLEMMIE': 1,
    'CLEMMONS': 0,
    'CLEMO': 0,
    'CLEMON': 0,
    'CLEMONS': 0,
    'CLEMONTS': 0,
    'CLEMSON': 0,
    'CLENDANIEL': 0,
    'CLENDENEN': 0,
    'CLENDENIN': 0,
    'CLENDENING': 0,
    'CLENDENNEN': 0,
    'CLENDENNING': 0,
    'CLENDENNY': 0,
    'CLENDENON': 0,
    'CLENNAN': 0,
    'CLENNEY': 0,
    'CLENNON': 0,
    'CLEO': 1,
    'CLEOPATRA': 1,
    'CLEOPHAT': 0,
    'CLEORA': 1,
    'CLEOTILDE': 1,
    'CLEPHANE': 0,
    'CLEPPE': 0,
    'CLEPPER': 0,
    'CLER': 0,
    'CLERC': 0,
    'CLERE': 0,
    'CLERGE': 0,
    'CLERGET': 0,
    'CLERICI': 0,
    'CLERICO': 0,
    'CLERK': 0,
    'CLERKIN': 0,
    'CLERKLEY': 0,
    'CLERMONT': 0,
    'CLERVEAUX': 0,
    'CLERVIL': 0,
    'CLERY': 0,
    'CLESI': 0,
    'CLESTER': 0,
    'CLETA': 1,
    'CLETO': 0,
    'CLETUS': 1,
    'CLEVE': 0,
    'CLEVELAND': 0.5880191106210951,
    'CLEVEN': 0,
    'CLEVENGER': 0,
    'CLEVENSTINE': 0,
    'CLEVER': 0,
    'CLEVERDON': 0,
    'CLEVERINGA': 0,
    'CLEVERLEY': 0,
    'CLEVERLY': 0,
    'CLEVES': 0,
    'CLEVIDENCE': 0,
    'CLEVINGER': 0,
    'CLEWELL': 0,
    'CLEWETT': 0,
    'CLEWIS': 0,
    'CLEWLEY': 0,
    'CLEWS': 0,
    'CLIATT': 0,
    'CLIBORNE': 0,
    'CLIBURN': 0,
    'CLICHE': 0,
    'CLICK': 0,
    'CLICKNER': 0,
    'CLIETT': 0,
    'CLIFF': 0.9316770186335402,
    'CLIFFE': 0,
    'CLIFFORD': 0.9378574151734655,
    'CLIFFT': 0,
    'CLIFFTON': 0,
    'CLIFT': 0,
    'CLIFTON': 0.8461668641056016,
    'CLIMACO': 0,
    'CLIME': 0,
    'CLIMENT': 0,
    'CLIMER': 0,
    'CLIMES': 0,
    'CLIMIE': 0,
    'CLIMO': 0,
    'CLINARD': 0,
    'CLINCH': 0,
    'CLINCY': 0,
    'CLINE': 0,
    'CLINEBELL': 0,
    'CLINEDINST': 0,
    'CLINEFELTER': 0,
    'CLINES': 0,
    'CLINESMITH': 0,
    'CLING': 0,
    'CLINGAMAN': 0,
    'CLINGAN': 0,
    'CLINGEN': 0,
    'CLINGENPEEL': 0,
    'CLINGER': 0,
    'CLINGERMAN': 0,
    'CLINGINGSMITH': 0,
    'CLINGMAN': 0,
    'CLINITE': 0,
    'CLINK': 0,
    'CLINKENBEARD': 0,
    'CLINKINBEARD': 0,
    'CLINKINGBEARD': 0,
    'CLINKSCALE': 0,
    'CLINKSCALES': 0,
    'CLINT': 0.9946125155408205,
    'CLINTON': 0.9176902442467881,
    'CLINTSMAN': 0,
    'CLIPNER': 0,
    'CLIPP': 0,
    'CLIPPARD': 0,
    'CLIPPER': 0,
    'CLIPPERT': 0,
    'CLIPPERTON': 0,
    'CLIPPINGER': 0,
    'CLIPSON': 0,
    'CLISBY': 0,
    'CLISE': 0,
    'CLISH': 0,
    'CLISHAM': 0,
    'CLISSOLD': 0,
    'CLITES': 0,
    'CLITHERO': 0,
    'CLITSO': 0,
    'CLIVE': 0,
    'CLIVER': 0,
    'CLIZBE': 0,
    'CLOAK': 0,
    'CLOANINGER': 0,
    'CLOAR': 0,
    'CLOBES': 0,
    'CLOCK': 0,
    'CLOCKER': 0,
    'CLOCKSIN': 0,
    'CLODFELDER': 0,
    'CLODFELTER': 0,
    'CLOE': 0,
    'CLOER': 0,
    'CLOETER': 0,
    'CLOGG': 0,
    'CLOGSTON': 0,
    'CLOHERTY': 0,
    'CLOHESSY': 0,
    'CLOKE': 0,
    'CLOKEY': 0,
    'CLOMAN': 0,
    'CLONAN': 0,
    'CLONCE': 0,
    'CLONCH': 0,
    'CLONE': 0,
    'CLONEY': 0,
    'CLONIGER': 0,
    'CLONINGER': 0,
    'CLONTS': 0,
    'CLONTZ': 0,
    'CLOONAN': 0,
    'CLOONEY': 0,
    'CLOOS': 0,
    'CLOPP': 0,
    'CLOPPER': 0,
    'CLOPTON': 0,
    'CLOR': 0,
    'CLORA': 1,
    'CLORAN': 0,
    'CLORE': 0,
    'CLORINDA': 1,
    'CLOS': 0,
    'CLOSE': 0,
    'CLOSEN': 0,
    'CLOSNER': 0,
    'CLOSS': 0,
    'CLOSSEN': 0,
    'CLOSSER': 0,
    'CLOSSEY': 0,
    'CLOSSIN': 0,
    'CLOSSON': 0,
    'CLOSTER': 0,
    'CLOSTERMAN': 0,
    'CLOSTIO': 0,
    'CLOTFELTER': 0,
    'CLOTHIER': 0,
    'CLOTILDE': 1,
    'CLOTT': 0,
    'CLOTTER': 0,
    'CLOTWORTHY': 0,
    'CLOUATRE': 0,
    'CLOUD': 0,
    'CLOUDE': 0,
    'CLOUDEN': 0,
    'CLOUDMAN': 0,
    'CLOUDT': 0,
    'CLOUDY': 0,
    'CLOUGH': 0,
    'CLOUGHER': 0,
    'CLOUGHERTY': 0,
    'CLOUGHLEY': 0,
    'CLOUS': 0,
    'CLOUSE': 0,
    'CLOUSER': 0,
    'CLOUSING': 0,
    'CLOUSTON': 0,
    'CLOUTHIER': 0,
    'CLOUTIER': 0,
    'CLOUTMAN': 0,
    'CLOVE': 0,
    'CLOVEN': 0,
    'CLOVER': 0,
    'CLOVIS': 0,
    'CLOW': 0,
    'CLOWARD': 0,
    'CLOWDIS': 0,
    'CLOWDUS': 0,
    'CLOWE': 0,
    'CLOWER': 0,
    'CLOWERS': 0,
    'CLOWES': 0,
    'CLOWN': 0,
    'CLOWNEY': 0,
    'CLOWSER': 0,
    'CLOY': 0,
    'CLOYD': 0,
    'CLOYED': 0,
    'CLOYES': 0,
    'CLUBB': 0,
    'CLUBBS': 0,
    'CLUBINE': 0,
    'CLUCAS': 0,
    'CLUCHEY': 0,
    'CLUCK': 0,
    'CLUCKEY': 0,
    'CLUETT': 0,
    'CLUFF': 0,
    'CLUGH': 0,
    'CLUGSTON': 0,
    'CLUKEY': 0,
    'CLULEY': 0,
    'CLUM': 0,
    'CLUMPNER': 0,
    'CLUNAN': 0,
    'CLUNE': 0,
    'CLUNEY': 0,
    'CLUNIE': 0,
    'CLUNIS': 0,
    'CLUNK': 0,
    'CLUNN': 0,
    'CLUPPER': 0,
    'CLURE': 0,
    'CLUSE': 0,
    'CLUSTER': 0,
    'CLUTE': 0,
    'CLUTS': 0,
    'CLUTTER': 0,
    'CLUTTS': 0,
    'CLUTZ': 0,
    'CLUVER': 0,
    'CLUXTON': 0,
    'CLY': 0,
    'CLYATT': 0,
    'CLYBORNE': 0,
    'CLYBURN': 0,
    'CLYDE': 0.987206608240153,
    'CLYDESDALE': 0,
    'CLYMA': 0,
    'CLYMAN': 0,
    'CLYMER': 0,
    'CLYMORE': 0,
    'CLYNCH': 0,
    'CLYNE': 0,
    'CLYNES': 0,
    'CMAR': 0,
    'CMIEL': 0,
    'CNOSSEN': 0,
    'CO': 0,
    'COA': 0,
    'COACH': 0,
    'COACHE': 0,
    'COACHMAN': 0,
    'COAD': 0,
    'COADY': 0,
    'COAHRAN': 0,
    'COAK': 0,
    'COAKER': 0,
    'COAKLEY': 0,
    'COALE': 0,
    'COALSON': 0,
    'COALTER': 0,
    'COALWELL': 0,
    'COAN': 0,
    'COANE': 0,
    'COAR': 0,
    'COARD': 0,
    'COARSEY': 0,
    'COASH': 0,
    'COAST': 0,
    'COASTER': 0,
    'COASTON': 0,
    'COATE': 0,
    'COATES': 0,
    'COATNEY': 0,
    'COATS': 0,
    'COATSWORTH': 0,
    'COATY': 0,
    'COAXUM': 0,
    'COBA': 0,
    'COBABE': 0,
    'COBAIN': 0,
    'COBAN': 0,
    'COBANE': 0,
    'COBAR': 0,
    'COBARRUBIA': 0,
    'COBARRUBIAS': 0,
    'COBARRUVIAS': 0,
    'COBARUBIAS': 0,
    'COBAS': 0,
    'COBAUGH': 0,
    'COBB': 0,
    'COBBAN': 0,
    'COBBE': 0,
    'COBBETT': 0,
    'COBBIN': 0,
    'COBBINS': 0,
    'COBBLE': 0,
    'COBBLER': 0,
    'COBBLEY': 0,
    'COBBS': 0,
    'COBE': 0,
    'COBEL': 0,
    'COBELL': 0,
    'COBEN': 0,
    'COBER': 0,
    'COBERLEY': 0,
    'COBERLY': 0,
    'COBERN': 0,
    'COBERT': 0,
    'COBEY': 0,
    'COBHAM': 0,
    'COBIA': 0,
    'COBIAN': 0,
    'COBIN': 0,
    'COBINE': 0,
    'COBLE': 0,
    'COBLEIGH': 0,
    'COBLENTZ': 0,
    'COBLER': 0,
    'COBLEY': 0,
    'COBO': 0,
    'COBORN': 0,
    'COBOS': 0,
    'COBOURN': 0,
    'COBUN': 0,
    'COBURN': 0,
    'COBUZZI': 0,
    'COBY': 0,
    'COCA': 0,
    'COCAGNE': 0,
    'COCANOUGHER': 0,
    'COCANOUR': 0,
    'COCCA': 0,
    'COCCAGNA': 0,
    'COCCARO': 0,
    'COCCHI': 0,
    'COCCHIA': 0,
    'COCCHIARA': 0,
    'COCCHIARELLA': 0,
    'COCCHIARO': 0,
    'COCCHIOLA': 0,
    'COCCI': 0,
    'COCCIA': 0,
    'COCCIMIGLIO': 0,
    'COCCIO': 0,
    'COCCIOLONE': 0,
    'COCCO': 0,
    'COCCOLI': 0,
    'COCH': 0,
    'COCHARD': 0,
    'COCHELL': 0,
    'COCHENOUR': 0,
    'COCHERELL': 0,
    'COCHLIN': 0,
    'COCHRAN': 0,
    'COCHRANE': 0,
    'COCHRELL': 0,
    'COCHREN': 0,
    'COCHRON': 0,
    'COCHRUM': 0,
    'COCHRUN': 0,
    'COCILOVA': 0,
    'COCIO': 0,
    'COCK': 0,
    'COCKAYNE': 0,
    'COCKBURN': 0,
    'COCKCROFT': 0,
    'COCKE': 0,
    'COCKER': 0,
    'COCKERAM': 0,
    'COCKEREL': 0,
    'COCKERELL': 0,
    'COCKERHAM': 0,
    'COCKERILL': 0,
    'COCKETT': 0,
    'COCKEY': 0,
    'COCKFIELD': 0,
    'COCKING': 0,
    'COCKLE': 0,
    'COCKLEY': 0,
    'COCKLIN': 0,
    'COCKMAN': 0,
    'COCKRAM': 0,
    'COCKRAN': 0,
    'COCKREHAM': 0,
    'COCKREL': 0,
    'COCKRELL': 0,
    'COCKRIEL': 0,
    'COCKRILL': 0,
    'COCKROFT': 0,
    'COCKRUM': 0,
    'COCKS': 0,
    'COCO': 0,
    'COCOLA': 0,
    'COCOZZA': 0,
    'COCROFT': 0,
    'COCUZZA': 0,
    'COCUZZI': 0,
    'COCUZZO': 0,
    'CODA': 0,
    'CODAY': 0,
    'CODD': 0,
    'CODDENS': 0,
    'CODDING': 0,
    'CODDINGTON': 0,
    'CODE': 0,
    'CODELLA': 0,
    'CODER': 0,
    'CODERE': 0,
    'CODERRE': 0,
    'CODEY': 0,
    'CODI': 1,
    'CODINA': 0,
    'CODINGTON': 0,
    'CODIO': 0,
    'CODISPOTI': 0,
    'CODLING': 0,
    'CODNER': 0,
    'CODRINGTON': 0,
    'CODUTI': 0,
    'CODUTO': 0,
    'CODY': 0.9029031809973608,
    'COE': 0,
    'COEBURN': 0,
    'COEFIELD': 0,
    'COEL': 0,
    'COELHO': 0,
    'COELLO': 0,
    'COEN': 0,
    'COENE': 0,
    'COENEN': 0,
    'COERPER': 0,
    'COERS': 0,
    'COERVER': 0,
    'COES': 0,
    'COESTER': 0,
    'COETZEE': 0,
    'COEY': 0,
    'COEYMAN': 0,
    'COFELL': 0,
    'COFER': 0,
    'COFF': 0,
    'COFFARD': 0,
    'COFFARO': 0,
    'COFFEE': 0,
    'COFFEEN': 0,
    'COFFEL': 0,
    'COFFELL': 0,
    'COFFELT': 0,
    'COFFEN': 0,
    'COFFER': 0,
    'COFFEY': 0,
    'COFFIE': 0,
    'COFFIELD': 0,
    'COFFILL': 0,
    'COFFIN': 0,
    'COFFINDAFFER': 0,
    'COFFING': 0,
    'COFFLAND': 0,
    'COFFMAN': 0,
    'COFFREN': 0,
    'COFFRIN': 0,
    'COFFY': 0,
    'COFIELD': 0,
    'COFIELL': 0,
    'COFINO': 0,
    'COFONE': 0,
    'COFRAN': 0,
    'COFRANCESCO': 0,
    'COFRESI': 0,
    'COFSKY': 0,
    'COGAN': 0,
    'COGAR': 0,
    'COGBILL': 0,
    'COGBURN': 0,
    'COGDELL': 0,
    'COGDILL': 0,
    'COGEN': 0,
    'COGER': 0,
    'COGGAN': 0,
    'COGGER': 0,
    'COGGESHALL': 0,
    'COGGIN': 0,
    'COGGINS': 0,
    'COGHILL': 0,
    'COGHLAN': 0,
    'COGHLIN': 0,
    'COGLE': 0,
    'COGLEY': 0,
    'COGLIANDRO': 0,
    'COGLIANESE': 0,
    'COGLIANO': 0,
    'COGMAN': 0,
    'COGNATA': 0,
    'COGNATO': 0,
    'COGNETTA': 0,
    'COGNETTI': 0,
    'COGNEVICH': 0,
    'COGO': 0,
    'COGSHELL': 0,
    'COGSWELL': 0,
    'COHAGAN': 0,
    'COHAGEN': 0,
    'COHAN': 0,
    'COHANE': 0,
    'COHEA': 0,
    'COHEE': 0,
    'COHEN': 0,
    'COHENOUR': 0,
    'COHENS': 0,
    'COHETERO': 0,
    'COHICK': 0,
    'COHILL': 0,
    'COHL': 0,
    'COHLER': 0,
    'COHLMIA': 0,
    'COHN': 0,
    'COHO': 0,
    'COHOE': 0,
    'COHON': 0,
    'COHOON': 0,
    'COHORN': 0,
    'COHORST': 0,
    'COHRAN': 0,
    'COHRON': 0,
    'COHRS': 0,
    'COIA': 0,
    'COICOU': 0,
    'COIL': 0,
    'COILE': 0,
    'COILEY': 0,
    'COIMBRA': 0,
    'COIN': 0,
    'COINE': 0,
    'COINER': 0,
    'COINS': 0,
    'COIRA': 0,
    'COIRD': 0,
    'COIRO': 0,
    'COISON': 0,
    'COIT': 0,
    'COITE': 0,
    'COITO': 0,
    'COJOCARU': 0,
    'COK': 0,
    'COKE': 0,
    'COKELEY': 0,
    'COKELY': 0,
    'COKER': 0,
    'COKES': 0,
    'COKINOS': 0,
    'COKLEY': 0,
    'COL': 0,
    'COLA': 0,
    'COLABELLA': 0,
    'COLABELLI': 0,
    'COLACCHIO': 0,
    'COLACE': 0,
    'COLACICCO': 0,
    'COLACINO': 0,
    'COLACION': 0,
    'COLACO': 0,
    'COLACURCIO': 0,
    'COLADO': 0,
    'COLADONATO': 0,
    'COLAFRANCESCO': 0,
    'COLAGIOVANNI': 0,
    'COLAGROSSI': 0,
    'COLAHAN': 0,
    'COLAIACOVO': 0,
    'COLAIANNI': 0,
    'COLAIZZI': 0,
    'COLAK': 0,
    'COLALILLO': 0,
    'COLALUCA': 0,
    'COLAMARINO': 0,
    'COLAN': 0,
    'COLANDER': 0,
    'COLANDO': 0,
    'COLANDREA': 0,
    'COLANDRO': 0,
    'COLANERI': 0,
    'COLANGELO': 0,
    'COLANNINO': 0,
    'COLANTINO': 0,
    'COLANTONI': 0,
    'COLANTONIO': 0,
    'COLANTUONI': 0,
    'COLANTUONO': 0,
    'COLAO': 0,
    'COLAPIETRO': 0,
    'COLAPINTO': 0,
    'COLAPRETE': 0,
    'COLAR': 0,
    'COLARDO': 0,
    'COLARIC': 0,
    'COLAROSSI': 0,
    'COLARTE': 0,
    'COLARUSSO': 0,
    'COLAS': 0,
    'COLASACCO': 0,
    'COLASANTE': 0,
    'COLASANTI': 0,
    'COLASANTO': 0,
    'COLASUONNO': 0,
    'COLASURDO': 0,
    'COLATO': 0,
    'COLATOSTI': 0,
    'COLATRELLA': 0,
    'COLATRUGLIO': 0,
    'COLAVECCHIO': 0,
    'COLAVITA': 0,
    'COLAVITO': 0,
    'COLAVOLPE': 0,
    'COLAW': 0,
    'COLAZO': 0,
    'COLBATH': 0,
    'COLBAUGH': 0,
    'COLBECK': 0,
    'COLBENSON': 0,
    'COLBERG': 0,
    'COLBERT': 0,
    'COLBETH': 0,
    'COLBORN': 0,
    'COLBORNE': 0,
    'COLBOURN': 0,
    'COLBOURNE': 0,
    'COLBRY': 0,
    'COLBURN': 0,
    'COLBY': 0.7097232079489,
    'COLCHADO': 0,
    'COLCHIN': 0,
    'COLCLASURE': 0,
    'COLCLAZIER': 0,
    'COLCLOUGH': 0,
    'COLCOL': 0,
    'COLCORD': 0,
    'COLD': 0,
    'COLDEN': 0,
    'COLDEWEY': 0,
    'COLDING': 0,
    'COLDIRON': 0,
    'COLDITZ': 0,
    'COLDREN': 0,
    'COLDSMITH': 0,
    'COLDSNOW': 0,
    'COLDWATER': 0,
    'COLDWELL': 0,
    'COLE': 0.12561236025624922,
    'COLEBANK': 0,
    'COLEBROOK': 0,
    'COLEBURN': 0,
    'COLECCHI': 0,
    'COLECCHIA': 0,
    'COLEE': 0,
    'COLEEN': 1,
    'COLEGATE': 0,
    'COLEGIO': 0,
    'COLEGROVE': 0,
    'COLEHOUR': 0,
    'COLELAY': 0,
    'COLELLA': 0,
    'COLELLI': 0,
    'COLELLO': 0,
    'COLEMAN': 0.07199424046076314,
    'COLEMEN': 0,
    'COLEMIRE': 0,
    'COLEMON': 0,
    'COLEN': 0,
    'COLENBURG': 0,
    'COLENE': 1,
    'COLER': 0,
    'COLERICK': 0,
    'COLES': 0,
    'COLESCOTT': 0,
    'COLESON': 0,
    'COLESTOCK': 0,
    'COLETTA': 0.7751937984496124,
    'COLETTE': 0.9945750452079566,
    'COLETTI': 0,
    'COLETTO': 0,
    'COLEY': 0,
    'COLF': 0,
    'COLFAX': 0,
    'COLFER': 0,
    'COLFLESH': 0,
    'COLFORD': 0,
    'COLGAN': 0,
    'COLGATE': 0,
    'COLGIN': 0,
    'COLGLAZIER': 0,
    'COLGROVE': 0,
    'COLHOFF': 0,
    'COLHOUN': 0,
    'COLHOUR': 0,
    'COLI': 0,
    'COLIANNI': 0,
    'COLIC': 0,
    'COLICCHIO': 0,
    'COLICCI': 0,
    'COLICH': 0,
    'COLIE': 0,
    'COLIER': 0,
    'COLIGAN': 0,
    'COLIMA': 0,
    'COLIMON': 0,
    'COLIN': 0.937405503477472,
    'COLINA': 0,
    'COLINDRES': 0,
    'COLINO': 0,
    'COLIO': 0,
    'COLIP': 0,
    'COLIS': 0,
    'COLKER': 0,
    'COLKITT': 0,
    'COLL': 0,
    'COLLA': 0,
    'COLLACO': 0,
    'COLLADA': 0,
    'COLLADO': 0,
    'COLLAMER': 0,
    'COLLAMORE': 0,
    'COLLANTES': 0,
    'COLLAO': 0,
    'COLLAR': 0,
    'COLLARD': 0,
    'COLLARI': 0,
    'COLLART': 0,
    'COLLAS': 0,
    'COLLASO': 0,
    'COLLATZ': 0,
    'COLLAZO': 0,
    'COLLAZOS': 0,
    'COLLE': 0,
    'COLLEA': 0,
    'COLLEARY': 0,
    'COLLEDGE': 0,
    'COLLEEN': 0.9995654063450673,
    'COLLEGE': 0,
    'COLLELO': 0,
    'COLLELUORI': 0,
    'COLLEN': 0.9009009009009009,
    'COLLENE': 1,
    'COLLENS': 0,
    'COLLENTINE': 0,
    'COLLER': 0,
    'COLLERAN': 0,
    'COLLES': 0,
    'COLLET': 0,
    'COLLETON': 0,
    'COLLETT': 0,
    'COLLETTA': 0,
    'COLLETTE': 0.7363770250368189,
    'COLLETTI': 0,
    'COLLETTO': 0,
    'COLLEY': 0,
    'COLLI': 0,
    'COLLIANDER': 0,
    'COLLIAS': 0,
    'COLLICA': 0,
    'COLLICHIO': 0,
    'COLLICK': 0,
    'COLLICOTT': 0,
    'COLLIE': 0,
    'COLLIEN': 0,
    'COLLIER': 0,
    'COLLIFLOWER': 0,
    'COLLIGAN': 0,
    'COLLIGNON': 0,
    'COLLIN': 0.89197224975223,
    'COLLINA': 0,
    'COLLING': 0,
    'COLLINGE': 0,
    'COLLINGHAM': 0,
    'COLLINGS': 0,
    'COLLINGSWORTH': 0,
    'COLLINGTON': 0,
    'COLLINGWOOD': 0,
    'COLLINI': 0,
    'COLLINS': 0,
    'COLLINSON': 0,
    'COLLINSWORTH': 0,
    'COLLIS': 0,
    'COLLISHAW': 0,
    'COLLISON': 0,
    'COLLISTER': 0,
    'COLLITON': 0,
    'COLLIVER': 0,
    'COLLMAN': 0,
    'COLLMAR': 0,
    'COLLMER': 0,
    'COLLO': 0,
    'COLLOM': 0,
    'COLLON': 0,
    'COLLOP': 0,
    'COLLOPY': 0,
    'COLLORA': 0,
    'COLLORD': 0,
    'COLLOTON': 0,
    'COLLOVA': 0,
    'COLLS': 0,
    'COLLUCCI': 0,
    'COLLUM': 0,
    'COLLUMS': 0,
    'COLLUPY': 0,
    'COLLURA': 0,
    'COLLVER': 0,
    'COLLY': 0,
    'COLLYAR': 0,
    'COLLYER': 0,
    'COLLYMORE': 0,
    'COLMAN': 0,
    'COLMEN': 0,
    'COLMENARES': 0,
    'COLMENAREZ': 0,
    'COLMENERO': 0,
    'COLMER': 0,
    'COLMERY': 0,
    'COLMON': 0,
    'COLMORE': 0,
    'COLN': 0,
    'COLNA': 0,
    'COLO': 0,
    'COLOBONG': 0,
    'COLOCHO': 0,
    'COLODNY': 0,
    'COLOGGI': 0,
    'COLOGNA': 0,
    'COLOGNE': 0,
    'COLOM': 0,
    'COLOMA': 0,
    'COLOMB': 0,
    'COLOMBANI': 0,
    'COLOMBE': 0,
    'COLOMBEL': 0,
    'COLOMBI': 0,
    'COLOMBINI': 0,
    'COLOMBO': 0,
    'COLOME': 0,
    'COLOMER': 0,
    'COLOMO': 0,
    'COLOMY': 0,
    'COLON': 0,
    'COLONA': 0,
    'COLONDRES': 0,
    'COLONE': 0,
    'COLONEL': 0,
    'COLONEY': 0,
    'COLONIA': 0,
    'COLONNA': 0,
    'COLONNESE': 0,
    'COLONY': 0,
    'COLOPY': 0,
    'COLORADO': 0,
    'COLORES': 0,
    'COLOSI': 0,
    'COLOSIMO': 0,
    'COLOSKY': 0,
    'COLOTTI': 0,
    'COLOVOS': 0,
    'COLOZZI': 0,
    'COLOZZO': 0,
    'COLP': 0,
    'COLPAERT': 0,
    'COLPEAN': 0,
    'COLPETZER': 0,
    'COLPITTS': 0,
    'COLPO': 0,
    'COLPOYS': 0,
    'COLQUETT': 0,
    'COLQUETTE': 0,
    'COLQUHOUN': 0,
    'COLQUITT': 0,
    'COLSCH': 0,
    'COLSON': 0,
    'COLSTON': 0,
    'COLT': 0,
    'COLTEN': 0,
    'COLTER': 0,
    'COLTEY': 0,
    'COLTHARP': 0,
    'COLTMAN': 0,
    'COLTON': 0.6309148264984228,
    'COLTRAIN': 0,
    'COLTRANE': 0,
    'COLTRIN': 0,
    'COLTS': 0,
    'COLUCCI': 0,
    'COLUCCIO': 0,
    'COLUMB': 0,
    'COLUMBER': 0,
    'COLUMBIA': 0,
    'COLUMBO': 0,
    'COLUMBUS': 0.8771929824561403,
    'COLUMNA': 0,
    'COLUNGA': 0,
    'COLUSSI': 0,
    'COLUZZI': 0,
    'COLVARD': 0,
    'COLVER': 0,
    'COLVERT': 0,
    'COLVETT': 0,
    'COLVILLE': 0,
    'COLVIN': 0,
    'COLVIS': 0,
    'COLWELL': 0,
    'COLWICK': 0,
    'COLWILL': 0,
    'COLYAR': 0,
    'COLYER': 0,
    'COLYN': 0,
    'COLYOTT': 0,
    'COLZIE': 0,
    'COMA': 0,
    'COMACHO': 0,
    'COMADURAN': 0,
    'COMAI': 0,
    'COMALANDER': 0,
    'COMAN': 0,
    'COMANCHE': 0,
    'COMANS': 0,
    'COMAR': 0,
    'COMARDELLE': 0,
    'COMAS': 0,
    'COMB': 0,
    'COMBA': 0,
    'COMBASS': 0,
    'COMBE': 0,
    'COMBEE': 0,
    'COMBEL': 0,
    'COMBER': 0,
    'COMBES': 0,
    'COMBEST': 0,
    'COMBIS': 0,
    'COMBO': 0,
    'COMBRINK': 0,
    'COMBS': 0,
    'COMBY': 0,
    'COMDEN': 0,
    'COME': 0,
    'COMEAU': 0,
    'COMEAUX': 0,
    'COMEFORD': 0,
    'COMEGYS': 0,
    'COMELLA': 0,
    'COMELLAS': 0,
    'COMELLO': 0,
    'COMEN': 0,
    'COMER': 0,
    'COMERFORD': 0,
    'COMERY': 0,
    'COMES': 0,
    'COMESANA': 0,
    'COMET': 0,
    'COMETA': 0,
    'COMEY': 0,
    'COMFORT': 0,
    'COMI': 0,
    'COMIA': 0,
    'COMIER': 0,
    'COMILANG': 0,
    'COMIN': 0,
    'COMINGORE': 0,
    'COMINGS': 0,
    'COMINI': 0,
    'COMINOS': 0,
    'COMINS': 0,
    'COMINSKY': 0,
    'COMIRE': 0,
    'COMIS': 0,
    'COMISH': 0,
    'COMISKEY': 0,
    'COMISKY': 0,
    'COMITO': 0,
    'COMITZ': 0,
    'COMLEY': 0,
    'COMLY': 0,
    'COMMANDER': 0,
    'COMMEAU': 0,
    'COMMENT': 0,
    'COMMER': 0,
    'COMMERFORD': 0,
    'COMMERS': 0,
    'COMMESSO': 0,
    'COMMET': 0,
    'COMMINGS': 0,
    'COMMINS': 0,
    'COMMISKEY': 0,
    'COMMISSIONG': 0,
    'COMMISSO': 0,
    'COMMO': 0,
    'COMMODORE': 0,
    'COMMON': 0,
    'COMMONS': 0,
    'COMNICK': 0,
    'COMO': 0,
    'COMOLLI': 0,
    'COMP': 0,
    'COMPAGNER': 0,
    'COMPAGNO': 0,
    'COMPAGNONE': 0,
    'COMPAGNONI': 0,
    'COMPANION': 0,
    'COMPANIONI': 0,
    'COMPANY': 0,
    'COMPARAN': 0,
    'COMPARATO': 0,
    'COMPARETTO': 0,
    'COMPAS': 0,
    'COMPASS': 0,
    'COMPAU': 0,
    'COMPEAN': 0,
    'COMPEAU': 0,
    'COMPERCHIO': 0,
    'COMPERE': 0,
    'COMPETIELLO': 0,
    'COMPHER': 0,
    'COMPIAN': 0,
    'COMPITELLO': 0,
    'COMPO': 0,
    'COMPOLI': 0,
    'COMPORT': 0,
    'COMPOSTO': 0,
    'COMPRES': 0,
    'COMPSON': 0,
    'COMPSTON': 0,
    'COMPTON': 0,
    'COMRIE': 0,
    'COMSTOCK': 0,
    'COMTE': 0,
    'COMTOIS': 0,
    'COMUNALE': 0,
    'COMYNS': 0,
    'CON': 0,
    'CONA': 0,
    'CONABOY': 0,
    'CONAGHAN': 0,
    'CONAHAN': 0,
    'CONAN': 0,
    'CONANAN': 0,
    'CONANT': 0,
    'CONARD': 0,
    'CONARROE': 0,
    'CONARY': 0,
    'CONAT': 0,
    'CONATSER': 0,
    'CONATY': 0,
    'CONAWAY': 0,
    'CONBOY': 0,
    'CONCA': 0,
    'CONCANNON': 0,
    'CONCEICAO': 0,
    'CONCEPCION': 0.8036739380022963,
    'CONCEPTION': 0.9174311926605505,
    'CONCETTA': 1,
    'CONCHA': 0.625,
    'CONCHAS': 0,
    'CONCHITA': 1,
    'CONCHO': 0,
    'CONCHOLA': 0,
    'CONCIALDI': 0,
    'CONCIENNE': 0,
    'CONCILIO': 0,
    'CONCKLIN': 0,
    'CONCORD': 0,
    'CONCORDIA': 0,
    'CONDA': 0,
    'CONDADO': 0,
    'CONDARCO': 0,
    'CONDE': 0,
    'CONDEE': 0,
    'CONDELL': 0,
    'CONDELLO': 0,
    'CONDER': 0,
    'CONDERMAN': 0,
    'CONDES': 0,
    'CONDI': 0,
    'CONDICT': 0,
    'CONDIE': 0,
    'CONDIFF': 0,
    'CONDINO': 0,
    'CONDIT': 0,
    'CONDITT': 0,
    'CONDLEY': 0,
    'CONDO': 0,
    'CONDOLUCI': 0,
    'CONDON': 0,
    'CONDOR': 0,
    'CONDORI': 0,
    'CONDOS': 0,
    'CONDRA': 0,
    'CONDRAN': 0,
    'CONDRAY': 0,
    'CONDREAY': 0,
    'CONDREN': 0,
    'CONDREY': 0,
    'CONDRON': 0,
    'CONDRY': 0,
    'CONDUFF': 0,
    'CONDY': 0,
    'CONE': 0,
    'CONEJO': 0,
    'CONELL': 0,
    'CONELLY': 0,
    'CONELY': 0,
    'CONEN': 0,
    'CONENNA': 0,
    'CONER': 0,
    'CONERLY': 0,
    'CONERS': 0,
    'CONERTY': 0,
    'CONERY': 0,
    'CONES': 0,
    'CONESA': 0,
    'CONETTA': 0,
    'CONEWAY': 0,
    'CONEY': 0,
    'CONEYS': 0,
    'CONFAIR': 0,
    'CONFALONE': 0,
    'CONFER': 0,
    'CONFESSORE': 0,
    'CONFIDENTIAL': 0,
    'CONFINO': 0,
    'CONFORTE': 0,
    'CONFORTI': 0,
    'CONFORTO': 0,
    'CONFREY': 0,
    'CONG': 0,
    'CONGDON': 0,
    'CONGELOSI': 0,
    'CONGEMI': 0,
    'CONGER': 0,
    'CONGLETON': 0,
    'CONGO': 0,
    'CONGRESS': 0,
    'CONGROVE': 0,
    'CONIBEAR': 0,
    'CONICELLI': 0,
    'CONIFF': 0,
    'CONIGLIARO': 0,
    'CONIGLIO': 0,
    'CONIGLIONE': 0,
    'CONINE': 0,
    'CONING': 0,
    'CONK': 0,
    'CONKEL': 0,
    'CONKEY': 0,
    'CONKIN': 0,
    'CONKLE': 0,
    'CONKLETON': 0,
    'CONKLIN': 0,
    'CONKLING': 0,
    'CONKRIGHT': 0,
    'CONKWRIGHT': 0,
    'CONLAN': 0,
    'CONLAY': 0,
    'CONLEE': 0,
    'CONLEN': 0,
    'CONLEY': 0,
    'CONLIFFE': 0,
    'CONLIN': 0,
    'CONLISK': 0,
    'CONLOGUE': 0,
    'CONLON': 0,
    'CONLOW': 0,
    'CONLY': 0,
    'CONMY': 0,
    'CONN': 0,
    'CONNACHER': 0,
    'CONNAGHAN': 0,
    'CONNAIR': 0,
    'CONNAL': 0,
    'CONNALLY': 0,
    'CONNARD': 0,
    'CONNATSER': 0,
    'CONNAUGHTON': 0,
    'CONNAWAY': 0,
    'CONNEALLY': 0,
    'CONNEALY': 0,
    'CONNEELY': 0,
    'CONNEEN': 0,
    'CONNEL': 0,
    'CONNELL': 0,
    'CONNELLA': 0,
    'CONNELLAN': 0,
    'CONNELLEY': 0,
    'CONNELLY': 0,
    'CONNELY': 0,
    'CONNER': 0,
    'CONNERLEY': 0,
    'CONNERLY': 0,
    'CONNERS': 0,
    'CONNERTON': 0,
    'CONNERTY': 0,
    'CONNERY': 0,
    'CONNESS': 0,
    'CONNET': 0,
    'CONNETT': 0,
    'CONNEY': 0,
    'CONNICK': 0,
    'CONNIE': 0.9994149765990641,
    'CONNIFF': 0,
    'CONNIN': 0,
    'CONNINGHAM': 0,
    'CONNINGTON': 0,
    'CONNLEY': 0,
    'CONNOLE': 0,
    'CONNOLLEY': 0,
    'CONNOLLY': 0,
    'CONNOLY': 0,
    'CONNON': 0,
    'CONNOR': 0,
    'CONNORS': 0,
    'CONNOT': 0,
    'CONNOUR': 0,
    'CONNOY': 0,
    'CONO': 0,
    'CONOBOY': 0,
    'CONOLEY': 0,
    'CONOLLY': 0,
    'CONOLY': 0,
    'CONOR': 0,
    'CONOSCENTI': 0,
    'CONOUR': 0,
    'CONOVER': 0,
    'CONOWAY': 0,
    'CONQUES': 0,
    'CONQUEST': 0,
    'CONRAD': 0.5966910767561704,
    'CONRADE': 0,
    'CONRADI': 0,
    'CONRADO': 0,
    'CONRADS': 0,
    'CONRADSON': 0,
    'CONRADT': 0,
    'CONRADY': 0,
    'CONRAN': 0,
    'CONRARDY': 0,
    'CONRATH': 0,
    'CONREY': 0,
    'CONRICK': 0,
    'CONRIQUE': 0,
    'CONRO': 0,
    'CONROD': 0,
    'CONROE': 0,
    'CONRON': 0,
    'CONROW': 0,
    'CONROY': 0,
    'CONRY': 0,
    'CONS': 0,
    'CONSALVI': 0,
    'CONSALVO': 0,
    'CONSANI': 0,
    'CONSAUL': 0,
    'CONSBRUCK': 0,
    'CONSENTINO': 0,
    'CONSER': 0,
    'CONSIDINE': 0,
    'CONSIGLI': 0,
    'CONSIGLIO': 0,
    'CONSLA': 0,
    'CONSOER': 0,
    'CONSOLACION': 0,
    'CONSOLAZIO': 0,
    'CONSOLE': 0,
    'CONSOLI': 0,
    'CONSOLINI': 0,
    'CONSOLINO': 0,
    'CONSOLO': 0,
    'CONSOLVER': 0,
    'CONSTABLE': 0,
    'CONSTAN': 0,
    'CONSTANCE': 0.9941009394800087,
    'CONSTANCIA': 0,
    'CONSTANCIO': 0,
    'CONSTANS': 0,
    'CONSTANT': 0,
    'CONSTANTE': 0,
    'CONSTANTIN': 0,
    'CONSTANTINE': 0,
    'CONSTANTINEAU': 0,
    'CONSTANTINESCU': 0,
    'CONSTANTINI': 0,
    'CONSTANTINIDES': 0,
    'CONSTANTINO': 0,
    'CONSTANTINOU': 0,
    'CONSTANZA': 0,
    'CONSTANZO': 0,
    'CONSTAS': 0,
    'CONSTIEN': 0,
    'CONSTINE': 0,
    'CONSTON': 0,
    'CONSUEGRA': 0,
    'CONSUELA': 1,
    'CONSUELO': 0.9968282736746715,
    'CONSUL': 0,
    'CONTA': 0,
    'CONTALDI': 0,
    'CONTANT': 0,
    'CONTARDI': 0,
    'CONTARDO': 0,
    'CONTARINO': 0,
    'CONTE': 0,
    'CONTEE': 0,
    'CONTEH': 0,
    'CONTENT': 0,
    'CONTENTE': 0,
    'CONTENTO': 0,
    'CONTER': 0,
    'CONTERO': 0,
    'CONTES': 0,
    'CONTESSA': 0.8928571428571428,
    'CONTESTABILE': 0,
    'CONTI': 0,
    'CONTICELLI': 0,
    'CONTILLO': 0,
    'CONTIN': 0,
    'CONTINI': 0,
    'CONTINO': 0,
    'CONTIS': 0,
    'CONTLA': 0,
    'CONTO': 0,
    'CONTOIS': 0,
    'CONTORNO': 0,
    'CONTOS': 0,
    'CONTRACTOR': 0,
    'CONTRADA': 0,
    'CONTRADES': 0,
    'CONTRARAS': 0,
    'CONTRARES': 0,
    'CONTRAS': 0,
    'CONTRATTO': 0,
    'CONTRERA': 0,
    'CONTRERAS': 0,
    'CONTRERAZ': 0,
    'CONTRERES': 0,
    'CONTRERRAS': 0,
    'CONTRES': 0,
    'CONTRI': 0,
    'CONTRINO': 0,
    'CONTRUCCI': 0,
    'CONTY': 0,
    'CONVENTO': 0,
    'CONVER': 0,
    'CONVERS': 0,
    'CONVERSE': 0,
    'CONVERSO': 0,
    'CONVERTINO': 0,
    'CONVERY': 0,
    'CONVEY': 0,
    'CONVILLE': 0,
    'CONVIS': 0,
    'CONWAY': 0,
    'CONWELL': 0,
    'CONWILL': 0,
    'CONWRIGHT': 0,
    'CONYER': 0,
    'CONYERS': 0,
    'CONZ': 0,
    'CONZA': 0,
    'CONZALEZ': 0,
    'CONZELMAN': 0,
    'CONZELMANN': 0,
    'CONZEMIUS': 0,
    'CONZETT': 0,
    'CONZO': 0,
    'COO': 0,
    'COOCH': 0,
    'COODE': 0,
    'COODY': 0,
    'COOEY': 0,
    'COOGAN': 0,
    'COOGLE': 0,
    'COOGLER': 0,
    'COOK': 0,
    'COOKE': 0,
    'COOKER': 0,
    'COOKERLY': 0,
    'COOKINGHAM': 0,
    'COOKINHAM': 0,
    'COOKLIN': 0,
    'COOKMAN': 0,
    'COOKS': 0,
    'COOKSEY': 0,
    'COOKSLEY': 0,
    'COOKSON': 0,
    'COOKSTON': 0,
    'COOKUS': 0,
    'COOL': 0,
    'COOLAHAN': 0,
    'COOLBAUGH': 0,
    'COOLBETH': 0,
    'COOLE': 0,
    'COOLEDGE': 0,
    'COOLEN': 0,
    'COOLER': 0,
    'COOLEY': 0,
    'COOLICAN': 0,
    'COOLIDGE': 0,
    'COOLING': 0,
    'COOLMAN': 0,
    'COOLONG': 0,
    'COOLS': 0,
    'COOMBE': 0,
    'COOMBER': 0,
    'COOMBES': 0,
    'COOMBS': 0,
    'COOMER': 0,
    'COOMES': 0,
    'COOMEY': 0,
    'COON': 0,
    'COONAN': 0,
    'COONCE': 0,
    'COONE': 0,
    'COONEN': 0,
    'COONER': 0,
    'COONES': 0,
    'COONEY': 0,
    'COONFARE': 0,
    'COONFIELD': 0,
    'COONLEY': 0,
    'COONRAD': 0,
    'COONRADT': 0,
    'COONROD': 0,
    'COONS': 0,
    'COONSE': 0,
    'COONTS': 0,
    'COONTZ': 0,
    'COOP': 0,
    'COOPE': 0,
    'COOPER': 0,
    'COOPERIDER': 0,
    'COOPERMAN': 0,
    'COOPERRIDER': 0,
    'COOPERSMITH': 0,
    'COOPERSTEIN': 0,
    'COOPERWOOD': 0,
    'COOPMAN': 0,
    'COOPRIDER': 0,
    'COOPWOOD': 0,
    'COOR': 0,
    'COORE': 0,
    'COORS': 0,
    'COOSE': 0,
    'COOTE': 0,
    'COOTER': 0,
    'COOTES': 0,
    'COOTS': 0,
    'COOTWARE': 0,
    'COOVER': 0,
    'COOVERT': 0,
    'COP': 0,
    'COPA': 0,
    'COPADO': 0,
    'COPAS': 0,
    'COPASS': 0,
    'COPE': 0,
    'COPELAN': 0,
    'COPELAND': 0,
    'COPELIN': 0,
    'COPELL': 0,
    'COPELLO': 0,
    'COPEMAN': 0,
    'COPEN': 0,
    'COPENHAGEN': 0,
    'COPENHAVER': 0,
    'COPENING': 0,
    'COPER': 0,
    'COPERTINO': 0,
    'COPES': 0,
    'COPESTICK': 0,
    'COPFER': 0,
    'COPHER': 0,
    'COPITHORNE': 0,
    'COPLAN': 0,
    'COPLAND': 0,
    'COPLEN': 0,
    'COPLEY': 0,
    'COPLIEN': 0,
    'COPLIN': 0,
    'COPLING': 0,
    'COPLON': 0,
    'COPNEY': 0,
    'COPONEN': 0,
    'COPP': 0,
    'COPPA': 0,
    'COPPAGE': 0,
    'COPPEDGE': 0,
    'COPPEL': 0,
    'COPPENBARGER': 0,
    'COPPENGER': 0,
    'COPPENRATH': 0,
    'COPPENS': 0,
    'COPPER': 0,
    'COPPERMAN': 0,
    'COPPERNOLL': 0,
    'COPPERSMITH': 0,
    'COPPERTHITE': 0,
    'COPPERWHEAT': 0,
    'COPPES': 0,
    'COPPESS': 0,
    'COPPI': 0,
    'COPPICK': 0,
    'COPPIN': 0,
    'COPPING': 0,
    'COPPINGER': 0,
    'COPPINI': 0,
    'COPPINS': 0,
    'COPPLE': 0,
    'COPPLER': 0,
    'COPPLEY': 0,
    'COPPO': 0,
    'COPPOCK': 0,
    'COPPOLA': 0,
    'COPPOLINO': 0,
    'COPPOLO': 0,
    'COPPOTELLI': 0,
    'COPPS': 0,
    'COPRICH': 0,
    'COPS': 0,
    'COPSEY': 0,
    'COPSON': 0,
    'COPUS': 0,
    'COQUIA': 0,
    'COQUILLARD': 0,
    'COR': 0,
    'CORA': 0.989423404981235,
    'CORACE': 0,
    'CORACI': 0,
    'CORADIN': 0,
    'CORADO': 0,
    'CORAGGIO': 0,
    'CORAH': 0,
    'CORAK': 0,
    'CORAL': 0.9389671361502347,
    'CORALEE': 1,
    'CORALES': 0,
    'CORALIC': 0,
    'CORALIE': 1,
    'CORALLO': 0,
    'CORAM': 0,
    'CORAN': 0,
    'CORAPI': 0,
    'CORASANITI': 0,
    'CORATHERS': 0,
    'CORAY': 0,
    'CORAZON': 1,
    'CORAZZA': 0,
    'CORAZZI': 0,
    'CORAZZINI': 0,
    'CORB': 0,
    'CORBA': 0,
    'CORBALEY': 0,
    'CORBALLY': 0,
    'CORBAN': 0,
    'CORBAT': 0,
    'CORBE': 0,
    'CORBEIL': 0,
    'CORBEILLE': 0,
    'CORBELL': 0,
    'CORBELLI': 0,
    'CORBELLO': 0,
    'CORBEN': 0,
    'CORBER': 0,
    'CORBERT': 0,
    'CORBET': 0,
    'CORBETT': 0,
    'CORBI': 0,
    'CORBIERE': 0,
    'CORBIN': 0,
    'CORBINE': 0,
    'CORBINO': 0,
    'CORBISHLEY': 0,
    'CORBISIERO': 0,
    'CORBIT': 0,
    'CORBITT': 0,
    'CORBLEY': 0,
    'CORBLY': 0,
    'CORBO': 0,
    'CORBOSIERO': 0,
    'CORBOY': 0,
    'CORBRAN': 0,
    'CORBRIDGE': 0,
    'CORBUS': 0,
    'CORBY': 0,
    'CORCHADO': 0,
    'CORCINO': 0,
    'CORCIONE': 0,
    'CORCOLES': 0,
    'CORCORAN': 0,
    'CORCORRAN': 0,
    'CORCUERA': 0,
    'CORD': 0,
    'CORDA': 0,
    'CORDANI': 0,
    'CORDANO': 0,
    'CORDARO': 0,
    'CORDAS': 0,
    'CORDASCO': 0,
    'CORDAWAY': 0,
    'CORDAY': 0,
    'CORDE': 0,
    'CORDEAU': 0,
    'CORDEIRA': 0,
    'CORDEIRO': 0,
    'CORDEL': 0,
    'CORDELIA': 1,
    'CORDELL': 0.5517241379310345,
    'CORDELLA': 0,
    'CORDEN': 0,
    'CORDER': 0,
    'CORDERA': 0,
    'CORDERMAN': 0,
    'CORDERO': 0,
    'CORDERY': 0,
    'CORDES': 0,
    'CORDI': 0,
    'CORDIA': 0.9090909090909091,
    'CORDIAL': 0,
    'CORDIANO': 0,
    'CORDICE': 0,
    'CORDIE': 0.966183574879227,
    'CORDIER': 0,
    'CORDILL': 0,
    'CORDIN': 0,
    'CORDINER': 0,
    'CORDING': 0,
    'CORDINGLEY': 0,
    'CORDINGLY': 0,
    'CORDIO': 0,
    'CORDIS': 0,
    'CORDISCO': 0,
    'CORDLE': 0,
    'CORDNER': 0,
    'CORDO': 0,
    'CORDOBA': 0,
    'CORDON': 0,
    'CORDONA': 0,
    'CORDONE': 0,
    'CORDONNIER': 0,
    'CORDOVA': 0,
    'CORDOVANO': 0,
    'CORDOVES': 0,
    'CORDOVEZ': 0,
    'CORDOVI': 0,
    'CORDOZA': 0,
    'CORDRAY': 0,
    'CORDREY': 0,
    'CORDRY': 0,
    'CORDS': 0,
    'CORDTS': 0,
    'CORDWELL': 0,
    'CORDY': 0,
    'CORE': 0,
    'COREA': 0,
    'COREANO': 0,
    'COREAS': 0,
    'COREEN': 1,
    'CORELL': 0,
    'CORELLA': 0,
    'CORELLI': 0,
    'COREN': 0,
    'CORENE': 1,
    'CORENO': 0,
    'CORES': 0,
    'CORESSEL': 0,
    'CORETTA': 1,
    'CORETTI': 0,
    'COREY': 0.9472135368769542,
    'CORFIELD': 0,
    'CORFMAN': 0,
    'CORGAN': 0,
    'CORGIAT': 0,
    'CORGILL': 0,
    'CORI': 0.9884678747940693,
    'CORIA': 0,
    'CORIALE': 0,
    'CORIANO': 0,
    'CORIATY': 0,
    'CORIC': 0,
    'CORICA': 0,
    'CORICH': 0,
    'CORIE': 0.9803921568627452,
    'CORIELL': 0,
    'CORIGLIANO': 0,
    'CORIN': 0,
    'CORINA': 0.9930486593843098,
    'CORINE': 1,
    'CORINNA': 1,
    'CORINNE': 1,
    'CORINO': 0,
    'CORIO': 0,
    'CORIOLAN': 0,
    'CORIROSSI': 0,
    'CORISH': 0,
    'CORIZ': 0,
    'CORK': 0,
    'CORKE': 0,
    'CORKEN': 0,
    'CORKER': 0,
    'CORKERN': 0,
    'CORKERY': 0,
    'CORKHILL': 0,
    'CORKILL': 0,
    'CORKIN': 0,
    'CORKINS': 0,
    'CORKLE': 0,
    'CORKRAN': 0,
    'CORKREAN': 0,
    'CORKREN': 0,
    'CORKUM': 0,
    'CORKWELL': 0,
    'CORL': 0,
    'CORLE': 0,
    'CORLEE': 0,
    'CORLESS': 0,
    'CORLETO': 0,
    'CORLETT': 0,
    'CORLETTE': 0,
    'CORLETTO': 0,
    'CORLEW': 0,
    'CORLEY': 0,
    'CORLIN': 0,
    'CORLIS': 0,
    'CORLISS': 0.6389776357827476,
    'CORLL': 0,
    'CORMACK': 0,
    'CORMAN': 0,
    'CORMANY': 0,
    'CORMENY': 0,
    'CORMICAN': 0,
    'CORMIE': 0,
    'CORMIER': 0,
    'CORN': 0,
    'CORNA': 0,
    'CORNABY': 0,
    'CORNACCHIA': 0,
    'CORNACCHIO': 0,
    'CORNACCHIONE': 0,
    'CORNADO': 0,
    'CORNAIRE': 0,
    'CORNATZER': 0,
    'CORNAY': 0,
    'CORNE': 0,
    'CORNEA': 0,
    'CORNEAL': 0,
    'CORNEAU': 0,
    'CORNEIL': 0,
    'CORNEILLE': 0,
    'CORNEJO': 0,
    'CORNEL': 0,
    'CORNELIA': 0.991407799074686,
    'CORNELIO': 0,
    'CORNELIOUS': 0,
    'CORNELIS': 0,
    'CORNELISON': 0,
    'CORNELISSE': 0,
    'CORNELISSEN': 0,
    'CORNELIUS': 0.7454739084132055,
    'CORNELIUSEN': 0,
    'CORNELIUSSEN': 0,
    'CORNELL': 0.5060088551549653,
    'CORNELLA': 0,
    'CORNELLIER': 0,
    'CORNELSEN': 0,
    'CORNELSON': 0,
    'CORNELY': 0,
    'CORNER': 0,
    'CORNERS': 0,
    'CORNES': 0,
    'CORNET': 0,
    'CORNETET': 0,
    'CORNETT': 0,
    'CORNETTA': 0,
    'CORNETTE': 0,
    'CORNETTO': 0,
    'CORNEY': 0,
    'CORNFIELD': 0,
    'CORNFORD': 0,
    'CORNFORTH': 0,
    'CORNIA': 0,
    'CORNICELLI': 0,
    'CORNICK': 0,
    'CORNIEL': 0,
    'CORNIELLE': 0,
    'CORNIER': 0,
    'CORNILLE': 0,
    'CORNILS': 0,
    'CORNINE': 0,
    'CORNING': 0,
    'CORNISH': 0,
    'CORNIST': 0,
    'CORNMAN': 0,
    'CORNMESSER': 0,
    'CORNN': 0,
    'CORNO': 0,
    'CORNOG': 0,
    'CORNS': 0,
    'CORNSTUBBLE': 0,
    'CORNTHWAITE': 0,
    'CORNUTT': 0,
    'CORNWALL': 0,
    'CORNWELL': 0,
    'CORNYN': 0,
    'CORO': 0,
    'COROLLA': 0,
    'COROMINAS': 0,
    'CORON': 0,
    'CORONA': 0,
    'CORONADO': 0,
    'CORONATO': 0,
    'CORONEL': 0,
    'CORONELL': 0,
    'CORONEOS': 0,
    'CORONILLA': 0,
    'CORONIS': 0,
    'COROTHERS': 0,
    'CORP': 0,
    'CORPE': 0,
    'CORPENING': 0,
    'CORPENO': 0,
    'CORPIER': 0,
    'CORPMAN': 0,
    'CORPORA': 0,
    'CORPORAL': 0,
    'CORPORAN': 0,
    'CORPORON': 0,
    'CORPREW': 0,
    'CORPRON': 0,
    'CORPSTEIN': 0,
    'CORPUS': 0,
    'CORPUZ': 0,
    'CORR': 0,
    'CORRA': 0,
    'CORRAD': 0,
    'CORRADETTI': 0,
    'CORRADI': 0,
    'CORRADINI': 0,
    'CORRADINO': 0,
    'CORRADO': 0,
    'CORRAL': 0,
    'CORRALEJO': 0,
    'CORRALES': 0,
    'CORRALEZ': 0,
    'CORRAO': 0,
    'CORRE': 0,
    'CORREA': 0,
    'CORREAL': 0,
    'CORREALE': 0,
    'CORREDOR': 0,
    'CORREIA': 0,
    'CORREIRA': 0,
    'CORRELA': 0,
    'CORRELL': 0,
    'CORREN': 0,
    'CORRENTE': 0,
    'CORRENTI': 0,
    'CORRERA': 0,
    'CORRERO': 0,
    'CORRES': 0,
    'CORRETJER': 0,
    'CORREY': 0,
    'CORRIA': 0,
    'CORRICE': 0,
    'CORRICK': 0,
    'CORRIDAN': 0,
    'CORRIDON': 0,
    'CORRIDONI': 0,
    'CORRIDORI': 0,
    'CORRIE': 0.9328358208955224,
    'CORRIEA': 0,
    'CORRIER': 0,
    'CORRIERE': 0,
    'CORRIERI': 0,
    'CORRIERO': 0,
    'CORRIGAN': 0,
    'CORRIHER': 0,
    'CORRILLO': 0,
    'CORRIN': 0.8620689655172414,
    'CORRINA': 1,
    'CORRINE': 1,
    'CORRINGTON': 0,
    'CORRINNE': 1,
    'CORRION': 0,
    'CORRIS': 0,
    'CORRISTON': 0,
    'CORRITORE': 0,
    'CORRIVEAU': 0,
    'CORRO': 0,
    'CORRON': 0,
    'CORROTHERS': 0,
    'CORROW': 0,
    'CORRY': 0,
    'CORS': 0,
    'CORSA': 0,
    'CORSALE': 0,
    'CORSARD': 0,
    'CORSARO': 0,
    'CORSAUT': 0,
    'CORSBIE': 0,
    'CORSE': 0,
    'CORSELLO': 0,
    'CORSENTINO': 0,
    'CORSER': 0,
    'CORSETTE': 0,
    'CORSETTI': 0,
    'CORSEY': 0,
    'CORSI': 0,
    'CORSIGLIA': 0,
    'CORSINI': 0,
    'CORSINO': 0,
    'CORSO': 0,
    'CORSON': 0,
    'CORSTEN': 0,
    'CORT': 0,
    'CORTADO': 0,
    'CORTAZAR': 0,
    'CORTAZZO': 0,
    'CORTE': 0,
    'CORTEL': 0,
    'CORTELL': 0,
    'CORTELLESSA': 0,
    'CORTELYOU': 0,
    'CORTER': 0,
    'CORTES': 0,
    'CORTESE': 0,
    'CORTESI': 0,
    'CORTEVILLE': 0,
    'CORTEZ': 0.12221203788573176,
    'CORTHELL': 0,
    'CORTI': 0,
    'CORTIJO': 0,
    'CORTINA': 0,
    'CORTINAS': 0,
    'CORTINES': 0,
    'CORTINEZ': 0,
    'CORTINO': 0,
    'CORTIS': 0,
    'CORTNER': 0,
    'CORTNEY': 0.9888751545117429,
    'CORTON': 0,
    'CORTOPASSI': 0,
    'CORTORREAL': 0,
    'CORTRIGHT': 0,
    'CORTS': 0,
    'CORTY': 0,
    'CORUJO': 0,
    'CORUM': 0,
    'CORVALAN': 0,
    'CORVELLI': 0,
    'CORVELLO': 0,
    'CORVERA': 0,
    'CORVESE': 0,
    'CORVI': 0,
    'CORVIN': 0,
    'CORVINO': 0,
    'CORVO': 0,
    'CORWELL': 0,
    'CORWIN': 0,
    'CORWINE': 0,
    'CORY': 0.9715288085278639,
    'CORYA': 0,
    'CORYEA': 0,
    'CORYELL': 0,
    'CORZA': 0,
    'CORZATT': 0,
    'CORZINE': 0,
    'CORZO': 0,
    'COS': 0,
    'COSAND': 0,
    'COSART': 0,
    'COSAY': 0,
    'COSBEY': 0,
    'COSBY': 0,
    'COSCA': 0,
    'COSCARELLI': 0,
    'COSCIA': 0,
    'COSCO': 0,
    'COSDEN': 0,
    'COSE': 0,
    'COSEN': 0,
    'COSENS': 0,
    'COSENTINO': 0,
    'COSENZA': 0,
    'COSEO': 0,
    'COSEY': 0,
    'COSGRAVE': 0,
    'COSGRAY': 0,
    'COSGRIFF': 0,
    'COSGRO': 0,
    'COSGROVE': 0,
    'COSH': 0,
    'COSHATT': 0,
    'COSHOW': 0,
    'COSIC': 0,
    'COSICO': 0,
    'COSIER': 0,
    'COSIMANO': 0,
    'COSINO': 0,
    'COSIO': 0,
    'COSKER': 0,
    'COSKEY': 0,
    'COSKUN': 0,
    'COSKY': 0,
    'COSLER': 0,
    'COSLET': 0,
    'COSLETT': 0,
    'COSLEY': 0,
    'COSLOW': 0,
    'COSMA': 0,
    'COSMAN': 0,
    'COSMANO': 0,
    'COSMAS': 0,
    'COSME': 0,
    'COSMO': 0,
    'COSMOS': 0,
    'COSNER': 0,
    'COSOM': 0,
    'COSPELICH': 0,
    'COSPER': 0,
    'COSPITO': 0,
    'COSS': 0,
    'COSSA': 0,
    'COSSABOOM': 0,
    'COSSABOON': 0,
    'COSSACK': 0,
    'COSSAIRT': 0,
    'COSSAR': 0,
    'COSSART': 0,
    'COSSE': 0,
    'COSSEBOOM': 0,
    'COSSEL': 0,
    'COSSELL': 0,
    'COSSELMAN': 0,
    'COSSENTINO': 0,
    'COSSETTE': 0,
    'COSSEY': 0,
    'COSSICK': 0,
    'COSSIN': 0,
    'COSSINS': 0,
    'COSSIO': 0,
    'COSSITT': 0,
    'COSSMAN': 0,
    'COSSON': 0,
    'COSSU': 0,
    'COSSYLEON': 0,
    'COST': 0,
    'COSTA': 0,
    'COSTABILE': 0,
    'COSTAGLIOLA': 0,
    'COSTAIN': 0,
    'COSTAKIS': 0,
    'COSTALES': 0,
    'COSTAN': 0,
    'COSTANTE': 0,
    'COSTANTINI': 0,
    'COSTANTINO': 0,
    'COSTANZA': 0,
    'COSTANZI': 0,
    'COSTANZO': 0,
    'COSTARELLA': 0,
    'COSTAS': 0,
    'COSTE': 0,
    'COSTEA': 0,
    'COSTEIRA': 0,
    'COSTELL': 0,
    'COSTELLA': 0,
    'COSTELLO': 0,
    'COSTELLOE': 0,
    'COSTELOW': 0,
    'COSTEN': 0,
    'COSTENBADER': 0,
    'COSTER': 0,
    'COSTES': 0,
    'COSTI': 0,
    'COSTIC': 0,
    'COSTICH': 0,
    'COSTICK': 0,
    'COSTIGAN': 0,
    'COSTILL': 0,
    'COSTILLA': 0,
    'COSTILLO': 0,
    'COSTILOW': 0,
    'COSTIN': 0,
    'COSTINE': 0,
    'COSTLEY': 0,
    'COSTLOW': 0,
    'COSTNER': 0,
    'COSTO': 0,
    'COSTOLO': 0,
    'COSTON': 0,
    'COSTOPOULOS': 0,
    'COT': 0,
    'COTA': 0,
    'COTANT': 0,
    'COTE': 0,
    'COTERA': 0,
    'COTERO': 0,
    'COTES': 0,
    'COTEY': 0,
    'COTHAM': 0,
    'COTHERMAN': 0,
    'COTHERN': 0,
    'COTHRAN': 0,
    'COTHREN': 0,
    'COTHRON': 0,
    'COTICCHIO': 0,
    'COTIE': 0,
    'COTIGNOLA': 0,
    'COTILLA': 0,
    'COTLER': 0,
    'COTMAN': 0,
    'COTNER': 0,
    'COTNEY': 0,
    'COTNOIR': 0,
    'COTO': 0,
    'COTOIA': 0,
    'COTON': 0,
    'COTONE': 0,
    'COTREAU': 0,
    'COTRELL': 0,
    'COTRINA': 0,
    'COTRONE': 0,
    'COTRONEO': 0,
    'COTT': 0,
    'COTTA': 0,
    'COTTAGE': 0,
    'COTTAM': 0,
    'COTTE': 0,
    'COTTEE': 0,
    'COTTELL': 0,
    'COTTEN': 0,
    'COTTENGIM': 0,
    'COTTER': 0,
    'COTTERELL': 0,
    'COTTERILL': 0,
    'COTTERMAN': 0,
    'COTTET': 0,
    'COTTEY': 0,
    'COTTI': 0,
    'COTTIER': 0,
    'COTTING': 0,
    'COTTINGHAM': 0,
    'COTTINGIM': 0,
    'COTTINGTON': 0,
    'COTTINI': 0,
    'COTTIS': 0,
    'COTTLE': 0,
    'COTTLES': 0,
    'COTTMAN': 0,
    'COTTNER': 0,
    'COTTO': 0,
    'COTTOM': 0,
    'COTTON': 0,
    'COTTONE': 0,
    'COTTONGIM': 0,
    'COTTONHAM': 0,
    'COTTREL': 0,
    'COTTRELL': 0,
    'COTTRILL': 0,
    'COTTS': 0,
    'COTTY': 0,
    'COTUGNO': 0,
    'COTY': 0,
    'COUCH': 0,
    'COUCHENOUR': 0,
    'COUCHMAN': 0,
    'COUCHON': 0,
    'COUCHOT': 0,
    'COUDEN': 0,
    'COUDRET': 0,
    'COUDRIET': 0,
    'COUDRON': 0,
    'COUEY': 0,
    'COUFAL': 0,
    'COUFFER': 0,
    'COUGER': 0,
    'COUGH': 0,
    'COUGHANOUR': 0,
    'COUGHENOUR': 0,
    'COUGHLAN': 0,
    'COUGHLIN': 0,
    'COUGHRAN': 0,
    'COUGHTRY': 0,
    'COUGILL': 0,
    'COUGLE': 0,
    'COUICK': 0,
    'COUILLARD': 0,
    'COUITT': 0,
    'COULAM': 0,
    'COULANGES': 0,
    'COULBOURN': 0,
    'COULBOURNE': 0,
    'COULES': 0,
    'COULIBALY': 0,
    'COULIER': 0,
    'COULL': 0,
    'COULLIETTE': 0,
    'COULMAN': 0,
    'COULOMBE': 0,
    'COULON': 0,
    'COULSON': 0,
    'COULSTON': 0,
    'COULT': 0,
    'COULTAS': 0,
    'COULTER': 0,
    'COULTHARD': 0,
    'COULTHURST': 0,
    'COULTON': 0,
    'COUMBE': 0,
    'COUNARD': 0,
    'COUNCE': 0,
    'COUNCELL': 0,
    'COUNCIL': 0,
    'COUNCILL': 0,
    'COUNCILMAN': 0,
    'COUNCILOR': 0,
    'COUNIHAN': 0,
    'COUNSEL': 0,
    'COUNSELL': 0,
    'COUNSELLER': 0,
    'COUNSELLOR': 0,
    'COUNSELMAN': 0,
    'COUNSIL': 0,
    'COUNT': 0,
    'COUNTEE': 0,
    'COUNTER': 0,
    'COUNTERMAN': 0,
    'COUNTESS': 0,
    'COUNTISS': 0,
    'COUNTRYMAN': 0,
    'COUNTS': 0,
    'COUNTY': 0,
    'COUNTZ': 0,
    'COUP': 0,
    'COUPAL': 0,
    'COUPE': 0,
    'COUPEL': 0,
    'COUPER': 0,
    'COUPET': 0,
    'COUPLAND': 0,
    'COUR': 0,
    'COURAGE': 0,
    'COURCELLE': 0,
    'COURCHAINE': 0,
    'COURCHENE': 0,
    'COURCHESNE': 0,
    'COURCY': 0,
    'COURET': 0,
    'COUREY': 0,
    'COURI': 0,
    'COURIE': 0,
    'COURIER': 0,
    'COURINGTON': 0,
    'COURIS': 0,
    'COURMIER': 0,
    'COURNEY': 0,
    'COURNEYA': 0,
    'COURNOYER': 0,
    'COURON': 0,
    'COURREGE': 0,
    'COURRIER': 0,
    'COURSE': 0,
    'COURSEN': 0,
    'COURSER': 0,
    'COURSEY': 0,
    'COURSIN': 0,
    'COURSON': 0,
    'COURT': 0,
    'COURTAD': 0,
    'COURTADE': 0,
    'COURTEAU': 0,
    'COURTEAUX': 0,
    'COURTEMANCHE': 0,
    'COURTENAY': 0,
    'COURTER': 0,
    'COURTIER': 0,
    'COURTIN': 0,
    'COURTIS': 0,
    'COURTLAND': 0,
    'COURTNEY': 0.9139176603707894,
    'COURTOIS': 0,
    'COURTRIGHT': 0,
    'COURTS': 0,
    'COURTWAY': 0,
    'COURTWRIGHT': 0,
    'COURVILLE': 0,
    'COURY': 0,
    'COUSAR': 0,
    'COUSART': 0,
    'COUSE': 0,
    'COUSENS': 0,
    'COUSER': 0,
    'COUSIN': 0,
    'COUSINEAU': 0,
    'COUSINO': 0,
    'COUSINS': 0,
    'COUSO': 0,
    'COUSSENS': 0,
    'COUTAIN': 0,
    'COUTANT': 0,
    'COUTCHER': 0,
    'COUTE': 0,
    'COUTEE': 0,
    'COUTERMARSH': 0,
    'COUTINHO': 0,
    'COUTINO': 0,
    'COUTO': 0,
    'COUTRE': 0,
    'COUTS': 0,
    'COUTTS': 0,
    'COUTU': 0,
    'COUTURE': 0,
    'COUTURIAUX': 0,
    'COUTURIER': 0,
    'COUTY': 0,
    'COUVERTIER': 0,
    'COUVILLIER': 0,
    'COUVILLION': 0,
    'COUVILLON': 0,
    'COUZENS': 0,
    'COVA': 0,
    'COVAIS': 0,
    'COVAL': 0,
    'COVALESKI': 0,
    'COVALT': 0,
    'COVAN': 0,
    'COVAR': 0,
    'COVARRUBIA': 0,
    'COVARRUBIAS': 0,
    'COVARRUBIO': 0,
    'COVARRUVIAS': 0,
    'COVARUBIAS': 0,
    'COVAS': 0,
    'COVAULT': 0,
    'COVE': 0,
    'COVEL': 0,
    'COVELESKI': 0,
    'COVELL': 0,
    'COVELLA': 0,
    'COVELLI': 0,
    'COVELLO': 0,
    'COVELY': 0,
    'COVEN': 0,
    'COVENEY': 0,
    'COVENTRY': 0,
    'COVENY': 0,
    'COVER': 0,
    'COVERDALE': 0,
    'COVERDELL': 0,
    'COVERDILL': 0,
    'COVERLY': 0,
    'COVERSON': 0,
    'COVERSTON': 0,
    'COVERSTONE': 0,
    'COVERT': 0,
    'COVEY': 0,
    'COVEYOU': 0,
    'COVI': 0,
    'COVIAN': 0,
    'COVIC': 0,
    'COVICH': 0,
    'COVIELIO': 0,
    'COVIELLO': 0,
    'COVIL': 0,
    'COVILL': 0,
    'COVILLE': 0,
    'COVIN': 0,
    'COVINGTON': 0,
    'COVINO': 0,
    'COVITZ': 0,
    'COVONE': 0,
    'COWAN': 0,
    'COWANS': 0,
    'COWARD': 0,
    'COWARDIN': 0,
    'COWART': 0,
    'COWBOY': 0,
    'COWBURN': 0,
    'COWDELL': 0,
    'COWDEN': 0,
    'COWDER': 0,
    'COWDERY': 0,
    'COWDIN': 0,
    'COWDREY': 0,
    'COWDRICK': 0,
    'COWE': 0,
    'COWEE': 0,
    'COWEL': 0,
    'COWELL': 0,
    'COWELS': 0,
    'COWEN': 0,
    'COWENS': 0,
    'COWER': 0,
    'COWETT': 0,
    'COWETTE': 0,
    'COWEY': 0,
    'COWFER': 0,
    'COWGER': 0,
    'COWGILL': 0,
    'COWHAM': 0,
    'COWHER': 0,
    'COWHERD': 0,
    'COWHEY': 0,
    'COWHICK': 0,
    'COWHIG': 0,
    'COWICK': 0,
    'COWIE': 0,
    'COWIN': 0,
    'COWING': 0,
    'COWINS': 0,
    'COWL': 0,
    'COWLE': 0,
    'COWLES': 0,
    'COWLEY': 0,
    'COWLIN': 0,
    'COWLING': 0,
    'COWLISHAW': 0,
    'COWMAN': 0,
    'COWN': 0,
    'COWNIE': 0,
    'COWPER': 0,
    'COWPERTHWAIT': 0,
    'COWPERTHWAITE': 0,
    'COWSER': 0,
    'COWSERT': 0,
    'COX': 0,
    'COXE': 0,
    'COXEN': 0,
    'COXEY': 0,
    'COXHEAD': 0,
    'COXON': 0,
    'COXSEY': 0,
    'COXSON': 0,
    'COXTON': 0,
    'COXWELL': 0,
    'COY': 0.6341154090044389,
    'COYA': 0,
    'COYAN': 0,
    'COYAZO': 0,
    'COYE': 0,
    'COYER': 0,
    'COYKENDALL': 0,
    'COYLE': 0,
    'COYMAN': 0,
    'COYNE': 0,
    'COYNER': 0,
    'COYOTE': 0,
    'COYOTL': 0,
    'COYOY': 0,
    'COYT': 0,
    'COYTE': 0,
    'COZ': 0,
    'COZAD': 0,
    'COZADD': 0,
    'COZART': 0,
    'COZBY': 0,
    'COZENS': 0,
    'COZIER': 0,
    'COZINE': 0,
    'COZORT': 0,
    'COZY': 0,
    'COZZA': 0,
    'COZZENS': 0,
    'COZZETTO': 0,
    'COZZI': 0,
    'COZZIE': 0,
    'COZZO': 0,
    'COZZOLINO': 0,
    'COZZONE': 0,
    'CR': 0,
    'CRABAUGH': 0,
    'CRABB': 0,
    'CRABBE': 0,
    'CRABBS': 0,
    'CRABILL': 0,
    'CRABLE': 0,
    'CRABTREE': 0,
    'CRABTREY': 0,
    'CRACCHIOLA': 0,
    'CRACCHIOLO': 0,
    'CRACCO': 0,
    'CRACE': 0,
    'CRACIUN': 0,
    'CRACKEL': 0,
    'CRACKNELL': 0,
    'CRACOLICI': 0,
    'CRACRAFT': 0,
    'CRADDICK': 0,
    'CRADDIETH': 0,
    'CRADDOCK': 0,
    'CRADDUCK': 0,
    'CRADER': 0,
    'CRADEUR': 0,
    'CRADIC': 0,
    'CRADICK': 0,
    'CRADIT': 0,
    'CRADLE': 0,
    'CRADOCK': 0,
    'CRADY': 0,
    'CRAEMER': 0,
    'CRAFA': 0,
    'CRAFF': 0,
    'CRAFFEY': 0,
    'CRAFFORD': 0,
    'CRAFORD': 0,
    'CRAFT': 0,
    'CRAFTER': 0,
    'CRAFTON': 0,
    'CRAFTS': 0,
    'CRAGAN': 0,
    'CRAGEN': 0,
    'CRAGER': 0,
    'CRAGG': 0,
    'CRAGGS': 0,
    'CRAGHEAD': 0,
    'CRAGIN': 0,
    'CRAGLE': 0,
    'CRAGO': 0,
    'CRAGUE': 0,
    'CRAGUN': 0,
    'CRAHAN': 0,
    'CRAIB': 0,
    'CRAIG': 0.861168011370762,
    'CRAIGE': 0,
    'CRAIGEN': 0,
    'CRAIGER': 0,
    'CRAIGG': 0,
    'CRAIGHEAD': 0,
    'CRAIGHILL': 0,
    'CRAIGHTON': 0,
    'CRAIGIE': 0,
    'CRAIGLOW': 0,
    'CRAIGMILE': 0,
    'CRAIGMILES': 0,
    'CRAIGMYLE': 0,
    'CRAIGO': 0,
    'CRAIGUE': 0,
    'CRAIK': 0,
    'CRAIL': 0,
    'CRAIN': 0,
    'CRAINE': 0,
    'CRAIS': 0,
    'CRAKE': 0,
    'CRAKER': 0,
    'CRALEY': 0,
    'CRALL': 0,
    'CRALLE': 0,
    'CRALLEY': 0,
    'CRAM': 0,
    'CRAMB': 0,
    'CRAMBLET': 0,
    'CRAMBLETT': 0,
    'CRAMBLIT': 0,
    'CRAMBLITT': 0,
    'CRAME': 0,
    'CRAMER': 0,
    'CRAMLET': 0,
    'CRAMM': 0,
    'CRAMMER': 0,
    'CRAMMOND': 0,
    'CRAMOND': 0,
    'CRAMP': 0,
    'CRAMPTON': 0,
    'CRAMSEY': 0,
    'CRAMSIE': 0,
    'CRAMTON': 0,
    'CRAN': 0,
    'CRANCE': 0,
    'CRANCER': 0,
    'CRANDAL': 0,
    'CRANDALL': 0,
    'CRANDELL': 0,
    'CRANDLE': 0,
    'CRANDOL': 0,
    'CRANDON': 0,
    'CRANE': 0,
    'CRANER': 0,
    'CRANEY': 0,
    'CRANFIELD': 0,
    'CRANFILL': 0,
    'CRANFORD': 0,
    'CRANGLE': 0,
    'CRANICK': 0,
    'CRANK': 0,
    'CRANKER': 0,
    'CRANKFIELD': 0,
    'CRANKSHAW': 0,
    'CRANLEY': 0,
    'CRANMER': 0,
    'CRANMORE': 0,
    'CRANN': 0,
    'CRANNELL': 0,
    'CRANNEY': 0,
    'CRANNY': 0,
    'CRANOR': 0,
    'CRANS': 0,
    'CRANSHAW': 0,
    'CRANSON': 0,
    'CRANSTON': 0,
    'CRANTON': 0,
    'CRANTZ': 0,
    'CRANWELL': 0,
    'CRANZ': 0,
    'CRAPANZANO': 0,
    'CRAPAROTTA': 0,
    'CRAPE': 0,
    'CRAPO': 0,
    'CRAPP': 0,
    'CRAPPELL': 0,
    'CRAPPS': 0,
    'CRAPS': 0,
    'CRAPSE': 0,
    'CRAPSER': 0,
    'CRAPSEY': 0,
    'CRARY': 0,
    'CRASE': 0,
    'CRASK': 0,
    'CRASS': 0,
    'CRAST': 0,
    'CRATCH': 0,
    'CRATE': 0,
    'CRATER': 0,
    'CRATES': 0,
    'CRATIC': 0,
    'CRATON': 0,
    'CRATSENBERG': 0,
    'CRATSLEY': 0,
    'CRATTY': 0,
    'CRAUMER': 0,
    'CRAUN': 0,
    'CRAUSE': 0,
    'CRAVALHO': 0,
    'CRAVATT': 0,
    'CRAVATTA': 0,
    'CRAVE': 0,
    'CRAVEIRO': 0,
    'CRAVEN': 0,
    'CRAVENER': 0,
    'CRAVENS': 0,
    'CRAVER': 0,
    'CRAVERO': 0,
    'CRAVEY': 0,
    'CRAVILLION': 0,
    'CRAVIN': 0,
    'CRAVO': 0,
    'CRAVOTTA': 0,
    'CRAVY': 0,
    'CRAW': 0,
    'CRAWFIS': 0,
    'CRAWFORD': 0,
    'CRAWHORN': 0,
    'CRAWL': 0,
    'CRAWLEY': 0,
    'CRAWMER': 0,
    'CRAWN': 0,
    'CRAWSHAW': 0,
    'CRAWSON': 0,
    'CRAY': 0,
    'CRAYCRAFT': 0,
    'CRAYCROFT': 0,
    'CRAYNE': 0,
    'CRAYON': 0,
    'CRAYS': 0,
    'CRAYTHORN': 0,
    'CRAYTON': 0,
    'CRAYTOR': 0,
    'CRAZE': 0,
    'CREA': 0,
    'CREACH': 0,
    'CREACY': 0,
    'CREAGAN': 0,
    'CREAGER': 0,
    'CREAGH': 0,
    'CREAL': 0,
    'CREAM': 0,
    'CREAMER': 0,
    'CREAN': 0,
    'CREANEY': 0,
    'CREAR': 0,
    'CREARY': 0,
    'CREASAP': 0,
    'CREASE': 0,
    'CREASER': 0,
    'CREASEY': 0,
    'CREASMAN': 0,
    'CREASON': 0,
    'CREASY': 0,
    'CREATH': 0,
    'CREAVEN': 0,
    'CREAZZO': 0,
    'CREBO': 0,
    'CREBS': 0,
    'CRECCA': 0,
    'CRECCO': 0,
    'CRECELIUS': 0,
    'CRECY': 0,
    'CREDE': 0,
    'CREDEUR': 0,
    'CREDILLE': 0,
    'CREDIT': 0,
    'CREDLE': 0,
    'CREDO': 0,
    'CREE': 0,
    'CREECH': 0,
    'CREECY': 0,
    'CREED': 0,
    'CREEDEN': 0,
    'CREEDON': 0,
    'CREEF': 0,
    'CREEGAN': 0,
    'CREEGER': 0,
    'CREEHAN': 0,
    'CREEK': 0,
    'CREEKBAUM': 0,
    'CREEKMORE': 0,
    'CREEKMUR': 0,
    'CREEKPAUM': 0,
    'CREEKS': 0,
    'CREEL': 0,
    'CREELEY': 0,
    'CREELMAN': 0,
    'CREELY': 0,
    'CREEN': 0,
    'CREER': 0,
    'CREERY': 0,
    'CREES': 0,
    'CREESE': 0,
    'CREEVY': 0,
    'CREGAN': 0,
    'CREGAR': 0,
    'CREGER': 0,
    'CREGG': 0,
    'CREGGER': 0,
    'CREGGETT': 0,
    'CREGIER': 0,
    'CREGO': 0,
    'CREGUT': 0,
    'CREHAN': 0,
    'CREIGH': 0,
    'CREIGHTON': 0,
    'CREITZ': 0,
    'CRELIA': 0,
    'CRELL': 0,
    'CRELLER': 0,
    'CRELLIN': 0,
    'CRELLY': 0,
    'CREMA': 0,
    'CREMEAN': 0,
    'CREMEANS': 0,
    'CREMEEN': 0,
    'CREMEENS': 0,
    'CREMEN': 0,
    'CREMENS': 0,
    'CREMER': 0,
    'CREMERS': 0,
    'CREMIN': 0,
    'CREMINS': 0,
    'CREMO': 0,
    'CREMONA': 0,
    'CREMONESE': 0,
    'CRENNAN': 0,
    'CRENSHAW': 0,
    'CRENWELGE': 0,
    'CREO': 0,
    'CREOLA': 1,
    'CREPEAU': 0,
    'CREPPEL': 0,
    'CREPPS': 0,
    'CREPS': 0,
    'CREQUE': 0,
    'CRERAR': 0,
    'CRESAP': 0,
    'CRESCENTE': 0,
    'CRESCENTI': 0,
    'CRESCENTINI': 0,
    'CRESCENZI': 0,
    'CRESCENZO': 0,
    'CRESCI': 0,
    'CRESCIMANNO': 0,
    'CRESCINI': 0,
    'CRESCITELLI': 0,
    'CRESON': 0,
    'CRESONG': 0,
    'CRESPI': 0,
    'CRESPIN': 0,
    'CRESPO': 0,
    'CRESPY': 0,
    'CRESS': 0,
    'CRESSE': 0,
    'CRESSELL': 0,
    'CRESSEY': 0,
    'CRESSLER': 0,
    'CRESSLEY': 0,
    'CRESSMAN': 0,
    'CRESSON': 0,
    'CRESSOTTI': 0,
    'CRESSWELL': 0,
    'CRESSY': 0,
    'CREST': 0,
    'CRESTA': 0,
    'CRESTANI': 0,
    'CRESTO': 0,
    'CRESWELL': 0,
    'CRESWICK': 0,
    'CRETA': 0,
    'CRETE': 0,
    'CRETELLA': 0,
    'CRETENS': 0,
    'CRETER': 0,
    'CRETIN': 0,
    'CRETSINGER': 0,
    'CRETU': 0,
    'CREUTZ': 0,
    'CREVAR': 0,
    'CREVELING': 0,
    'CREVIER': 0,
    'CREVISTON': 0,
    'CREW': 0,
    'CREWDSON': 0,
    'CREWE': 0,
    'CREWELL': 0,
    'CREWS': 0,
    'CREWSE': 0,
    'CREZEE': 0,
    'CRIADO': 0,
    'CRIBARI': 0,
    'CRIBB': 0,
    'CRIBBEN': 0,
    'CRIBBIN': 0,
    'CRIBBINS': 0,
    'CRIBBS': 0,
    'CRIBLEY': 0,
    'CRICCHIO': 0,
    'CRICE': 0,
    'CRICHFIELD': 0,
    'CRICHLOW': 0,
    'CRICHTON': 0,
    'CRICK': 0,
    'CRICKARD': 0,
    'CRICKENBERGER': 0,
    'CRICKMORE': 0,
    'CRICKS': 0,
    'CRIDDELL': 0,
    'CRIDDLE': 0,
    'CRIDER': 0,
    'CRIDGE': 0,
    'CRIDLAND': 0,
    'CRIDLEBAUGH': 0,
    'CRIDLIN': 0,
    'CRIEL': 0,
    'CRIER': 0,
    'CRIFASI': 0,
    'CRIGER': 0,
    'CRIGGER': 0,
    'CRIGHTON': 0,
    'CRIGLER': 0,
    'CRIHFIELD': 0,
    'CRILE': 0,
    'CRILEY': 0,
    'CRILL': 0,
    'CRILLEY': 0,
    'CRILLY': 0,
    'CRIM': 0,
    'CRIMALDI': 0,
    'CRIMES': 0,
    'CRIMI': 0,
    'CRIMINGER': 0,
    'CRIMM': 0,
    'CRIMMEL': 0,
    'CRIMMINS': 0,
    'CRINCOLI': 0,
    'CRINE': 0,
    'CRINER': 0,
    'CRING': 0,
    'CRINION': 0,
    'CRINITI': 0,
    'CRINKLAW': 0,
    'CRINNION': 0,
    'CRINO': 0,
    'CRIOLLO': 0,
    'CRIPE': 0,
    'CRIPPEN': 0,
    'CRIPPIN': 0,
    'CRIPPLE': 0,
    'CRIPPS': 0,
    'CRIQUI': 0,
    'CRIS': 1,
    'CRISAFI': 0,
    'CRISAFULLI': 0,
    'CRISALLI': 0,
    'CRISAMORE': 0,
    'CRISAN': 0,
    'CRISANTE': 0,
    'CRISANTI': 0,
    'CRISANTO': 0,
    'CRISANTOS': 0,
    'CRISCI': 0,
    'CRISCIONE': 0,
    'CRISCITIELLO': 0,
    'CRISCO': 0,
    'CRISCOE': 0,
    'CRISCOLA': 0,
    'CRISCUOLO': 0,
    'CRISE': 0,
    'CRISEL': 0,
    'CRISELDA': 1,
    'CRISENBERY': 0,
    'CRISER': 0,
    'CRISH': 0,
    'CRISI': 0,
    'CRISLER': 0,
    'CRISLIP': 0,
    'CRISMAN': 0,
    'CRISMON': 0,
    'CRISMOND': 0,
    'CRISMORE': 0,
    'CRISOLOGO': 0,
    'CRISOSTOMO': 0,
    'CRISP': 0,
    'CRISPELL': 0,
    'CRISPEN': 0,
    'CRISPENS': 0,
    'CRISPI': 0,
    'CRISPIN': 0,
    'CRISPINO': 0,
    'CRISPO': 0,
    'CRISS': 0,
    'CRISSEY': 0,
    'CRISSINGER': 0,
    'CRISSMAN': 0,
    'CRISSON': 0,
    'CRISSUP': 0,
    'CRISSWELL': 0,
    'CRISSY': 0.9708737864077669,
    'CRIST': 0,
    'CRISTA': 1,
    'CRISTAL': 0.9861932938856016,
    'CRISTALDI': 0,
    'CRISTALES': 0,
    'CRISTALLO': 0,
    'CRISTAN': 0,
    'CRISTANCHO': 0,
    'CRISTANTIELLO': 0,
    'CRISTE': 0,
    'CRISTEA': 0,
    'CRISTELLI': 0,
    'CRISTELLO': 0,
    'CRISTEN': 1,
    'CRISTERNA': 0,
    'CRISTI': 0.9771986970684039,
    'CRISTIAN': 0,
    'CRISTIANI': 0,
    'CRISTIANO': 0,
    'CRISTIE': 1,
    'CRISTIN': 1,
    'CRISTINA': 0.9945750452079566,
    'CRISTINE': 1,
    'CRISTINI': 0,
    'CRISTINO': 0,
    'CRISTINZIO': 0,
    'CRISTLER': 0,
    'CRISTMAN': 0,
    'CRISTO': 0,
    'CRISTOBAL': 0.8264462809917356,
    'CRISTOFANO': 0,
    'CRISTOFARO': 0,
    'CRISTOFORI': 0,
    'CRISTOFORO': 0,
    'CRISTOL': 0,
    'CRISTOPHER': 1,
    'CRISTY': 0.9836065573770493,
    'CRISWELL': 0,
    'CRITCH': 0,
    'CRITCHELOW': 0,
    'CRITCHER': 0,
    'CRITCHETT': 0,
    'CRITCHFIELD': 0,
    'CRITCHLEY': 0,
    'CRITCHLOW': 0,
    'CRITE': 0,
    'CRITELLI': 0,
    'CRITES': 0,
    'CRITESER': 0,
    'CRITSER': 0,
    'CRITTEN': 0,
    'CRITTENDEN': 0,
    'CRITTENDON': 0,
    'CRITTLE': 0,
    'CRITTON': 0,
    'CRITZ': 0,
    'CRITZER': 0,
    'CRIVARO': 0,
    'CRIVELLI': 0,
    'CRIVELLO': 0,
    'CRIVELLONE': 0,
    'CRIZER': 0,
    'CRNICH': 0,
    'CRNKOVIC': 0,
    'CRNKOVICH': 0,
    'CROAD': 0,
    'CROAK': 0,
    'CROAKE': 0,
    'CROAKER': 0,
    'CROAL': 0,
    'CROALL': 0,
    'CROAN': 0,
    'CROASDALE': 0,
    'CROASMUN': 0,
    'CROAT': 0,
    'CROATT': 0,
    'CROCCO': 0,
    'CROCE': 0,
    'CROCETTI': 0,
    'CROCHET': 0,
    'CROCHETIERE': 0,
    'CROCHIERE': 0,
    'CROCI': 0,
    'CROCIATA': 0,
    'CROCITTO': 0,
    'CROCK': 0,
    'CROCKARELL': 0,
    'CROCKER': 0,
    'CROCKET': 0,
    'CROCKETT': 0,
    'CROCKETTE': 0,
    'CROCKFORD': 0,
    'CROCKRELL': 0,
    'CROCKWELL': 0,
    'CRODDY': 0,
    'CROEGAERT': 0,
    'CROES': 0,
    'CROFF': 0,
    'CROFFORD': 0,
    'CROFOOT': 0,
    'CROFT': 0,
    'CROFTON': 0,
    'CROFTS': 0,
    'CROFUT': 0,
    'CROFUTT': 0,
    'CROGAN': 0,
    'CROGHAN': 0,
    'CROGNALE': 0,
    'CROHAN': 0,
    'CROHN': 0,
    'CROISANT': 0,
    'CROISSANT': 0,
    'CROIX': 0,
    'CROKE': 0,
    'CROKER': 0,
    'CROLEY': 0,
    'CROLIUS': 0,
    'CROLL': 0,
    'CROLLEY': 0,
    'CROLY': 0,
    'CROM': 0,
    'CROMACK': 0,
    'CROMAN': 0,
    'CROMAR': 0,
    'CROMARTIE': 0,
    'CROMARTY': 0,
    'CROMBIE': 0,
    'CROME': 0,
    'CROMEANS': 0,
    'CROMEDY': 0,
    'CROMEENS': 0,
    'CROMELL': 0,
    'CROMER': 0,
    'CROMES': 0,
    'CROMEY': 0,
    'CROMIE': 0,
    'CROMIS': 0,
    'CROMLEY': 0,
    'CROMMETT': 0,
    'CROMP': 0,
    'CROMPTON': 0,
    'CROMWELL': 0,
    'CRON': 0,
    'CRONAN': 0,
    'CRONAUER': 0,
    'CRONBAUGH': 0,
    'CRONCE': 0,
    'CRONE': 0,
    'CRONEN': 0,
    'CRONENBERG': 0,
    'CRONENWETT': 0,
    'CRONER': 0,
    'CRONEY': 0,
    'CRONIC': 0,
    'CRONICK': 0,
    'CRONIER': 0,
    'CRONIN': 0,
    'CRONINGER': 0,
    'CRONISE': 0,
    'CRONISER': 0,
    'CRONISTER': 0,
    'CRONK': 0,
    'CRONKHITE': 0,
    'CRONKITE': 0,
    'CRONKRIGHT': 0,
    'CRONKRITE': 0,
    'CRONLEY': 0,
    'CRONMILLER': 0,
    'CRONN': 0,
    'CRONON': 0,
    'CRONQUIST': 0,
    'CRONRATH': 0,
    'CRONYN': 0,
    'CROOK': 0,
    'CROOKE': 0,
    'CROOKER': 0,
    'CROOKES': 0,
    'CROOKHAM': 0,
    'CROOKS': 0,
    'CROOKSHANK': 0,
    'CROOKSHANKS': 0,
    'CROOKSTON': 0,
    'CROOM': 0,
    'CROOMES': 0,
    'CROOMS': 0,
    'CROON': 0,
    'CROONQUIST': 0,
    'CROOP': 0,
    'CROPLEY': 0,
    'CROPP': 0,
    'CROPPER': 0,
    'CROPSEY': 0,
    'CRORY': 0,
    'CROSBIE': 0,
    'CROSBY': 0,
    'CROSCHERE': 0,
    'CROSDALE': 0,
    'CROSE': 0,
    'CROSEN': 0,
    'CROSETTI': 0,
    'CROSETTO': 0,
    'CROSGROVE': 0,
    'CROSHAW': 0,
    'CROSIER': 0,
    'CROSKEY': 0,
    'CROSKREY': 0,
    'CROSLAND': 0,
    'CROSLEY': 0,
    'CROSLIN': 0,
    'CROSLOW': 0,
    'CROSMAN': 0,
    'CROSNO': 0,
    'CROSON': 0,
    'CROSS': 0,
    'CROSSAN': 0,
    'CROSSE': 0,
    'CROSSEN': 0,
    'CROSSER': 0,
    'CROSSETT': 0,
    'CROSSEY': 0,
    'CROSSFIELD': 0,
    'CROSSGROVE': 0,
    'CROSSIN': 0,
    'CROSSLAND': 0,
    'CROSSLEY': 0,
    'CROSSLIN': 0,
    'CROSSMAN': 0,
    'CROSSNO': 0,
    'CROSSNOE': 0,
    'CROSSON': 0,
    'CROSSWAY': 0,
    'CROSSWELL': 0,
    'CROSSWHITE': 0,
    'CROSTA': 0,
    'CROSTHWAIT': 0,
    'CROSTHWAITE': 0,
    'CROSTIC': 0,
    'CROSTON': 0,
    'CROSWELL': 0,
    'CROSWHITE': 0,
    'CROTCHETT': 0,
    'CROTEAU': 0,
    'CROTHERS': 0,
    'CROTINGER': 0,
    'CROTSER': 0,
    'CROTSLEY': 0,
    'CROTTEAU': 0,
    'CROTTI': 0,
    'CROTTS': 0,
    'CROTTY': 0,
    'CROTWELL': 0,
    'CROTZER': 0,
    'CROUCH': 0,
    'CROUCHER': 0,
    'CROUCHET': 0,
    'CROUGH': 0,
    'CROUNSE': 0,
    'CROUSE': 0,
    'CROUSER': 0,
    'CROUSHORE': 0,
    'CROUSHORN': 0,
    'CROUSORE': 0,
    'CROUT': 0,
    'CROUTCH': 0,
    'CROUTER': 0,
    'CROUTHAMEL': 0,
    'CROUTHER': 0,
    'CROUTHERS': 0,
    'CROVER': 0,
    'CROVETTO': 0,
    'CROVO': 0,
    'CROW': 0,
    'CROWDEN': 0,
    'CROWDER': 0,
    'CROWDIS': 0,
    'CROWDUS': 0,
    'CROWE': 0,
    'CROWEL': 0,
    'CROWELL': 0,
    'CROWER': 0,
    'CROWFOOT': 0,
    'CROWFORD': 0,
    'CROWHURST': 0,
    'CROWL': 0,
    'CROWLE': 0,
    'CROWLEY': 0,
    'CROWN': 0,
    'CROWNE': 0,
    'CROWNER': 0,
    'CROWNHART': 0,
    'CROWNINGSHIELD': 0,
    'CROWNINSHIELD': 0,
    'CROWNOVER': 0,
    'CROWSON': 0,
    'CROWSTON': 0,
    'CROWTHER': 0,
    'CROWTHERS': 0,
    'CROWTON': 0,
    'CROXALL': 0,
    'CROXDALE': 0,
    'CROXEN': 0,
    'CROXFORD': 0,
    'CROXTON': 0,
    'CROY': 0,
    'CROYLE': 0,
    'CROZE': 0,
    'CROZIER': 0,
    'CRUBAUGH': 0,
    'CRUC': 0,
    'CRUCE': 0,
    'CRUCES': 0,
    'CRUCET': 0,
    'CRUCETA': 0,
    'CRUCIANI': 0,
    'CRUCITTI': 0,
    'CRUDDEN': 0,
    'CRUDELE': 0,
    'CRUDEN': 0,
    'CRUDO': 0,
    'CRUDUP': 0,
    'CRUE': 0,
    'CRUEA': 0,
    'CRUEL': 0,
    'CRUELL': 0,
    'CRUES': 0,
    'CRUESS': 0,
    'CRUEY': 0,
    'CRUFF': 0,
    'CRUGER': 0,
    'CRUGNALE': 0,
    'CRUICE': 0,
    'CRUICKSHANK': 0,
    'CRUICKSHANKS': 0,
    'CRUIKSHANK': 0,
    'CRUISE': 0,
    'CRUIT': 0,
    'CRUITT': 0,
    'CRUIZ': 0,
    'CRULL': 0,
    'CRUM': 0,
    'CRUMB': 0,
    'CRUMBACHER': 0,
    'CRUMBACK': 0,
    'CRUMBACKER': 0,
    'CRUMBAKER': 0,
    'CRUMBAUGH': 0,
    'CRUMBIE': 0,
    'CRUMBLE': 0,
    'CRUMBLEY': 0,
    'CRUMBLISS': 0,
    'CRUMBLY': 0,
    'CRUMBO': 0,
    'CRUMBY': 0,
    'CRUME': 0,
    'CRUMEDY': 0,
    'CRUMEL': 0,
    'CRUMES': 0,
    'CRUMITY': 0,
    'CRUMLEY': 0,
    'CRUMLICH': 0,
    'CRUMLING': 0,
    'CRUMLISH': 0,
    'CRUMLY': 0,
    'CRUMM': 0,
    'CRUMMEL': 0,
    'CRUMMER': 0,
    'CRUMMETT': 0,
    'CRUMMEY': 0,
    'CRUMMIE': 0,
    'CRUMMITT': 0,
    'CRUMMY': 0,
    'CRUMP': 0,
    'CRUMPACKER': 0,
    'CRUMPLER': 0,
    'CRUMPLEY': 0,
    'CRUMPTON': 0,
    'CRUMRINE': 0,
    'CRUMSEY': 0,
    'CRUNK': 0,
    'CRUNKILTON': 0,
    'CRUNKLETON': 0,
    'CRUPE': 0,
    'CRUPI': 0,
    'CRUPPER': 0,
    'CRUS': 0,
    'CRUSAN': 0,
    'CRUSCO': 0,
    'CRUSE': 0,
    'CRUSEN': 0,
    'CRUSENBERRY': 0,
    'CRUSER': 0,
    'CRUSEY': 0,
    'CRUSH': 0,
    'CRUSIUS': 0,
    'CRUSO': 0,
    'CRUSOE': 0,
    'CRUSON': 0,
    'CRUSSELL': 0,
    'CRUST': 0,
    'CRUTCH': 0,
    'CRUTCHER': 0,
    'CRUTCHFIELD': 0,
    'CRUTCHLEY': 0,
    'CRUTE': 0,
    'CRUTHERS': 0,
    'CRUTHIRD': 0,
    'CRUTHIRDS': 0,
    'CRUTHIS': 0,
    'CRUTS': 0,
    'CRUTSINGER': 0,
    'CRUTTENDEN': 0,
    'CRUVER': 0,
    'CRUZ': 0.14901649115835483,
    'CRUZADO': 0,
    'CRUZAN': 0,
    'CRUZAT': 0,
    'CRUZCRUZ': 0,
    'CRUZE': 0,
    'CRUZEN': 0,
    'CRUZGARCIA': 0,
    'CRUZGONZALEZ': 0,
    'CRUZHERNANDEZ': 0,
    'CRUZLOPEZ': 0,
    'CRUZMARTINEZ': 0,
    'CRUZPEREZ': 0,
    'CRUZREYES': 0,
    'CRUZRIVERA': 0,
    'CRUZRODRIGUEZ': 0,
    'CRUZSANCHEZ': 0,
    'CRY': 0,
    'CRYAN': 0,
    'CRYAR': 0,
    'CRYDER': 0,
    'CRYDERMAN': 0,
    'CRYE': 0,
    'CRYER': 0,
    'CRYMES': 0,
    'CRYSEL': 0,
    'CRYSLER': 0,
    'CRYSTA': 1,
    'CRYSTAL': 0.9964858229432436,
    'CRYSTLE': 1,
    'CRYTS': 0,
    'CRYTSER': 0,
    'CRYTZER': 0,
    'CRYZ': 0,
    'CSANYI': 0,
    'CSAPO': 0,
    'CSASZAR': 0,
    'CSEH': 0,
    'CSENCSITS': 0,
    'CSER': 0,
    'CSIK': 0,
    'CSIKOS': 0,
    'CSISZAR': 0,
    'CSIZMADIA': 0,
    'CSONKA': 0,
    'CSONTOS': 0,
    'CSORBA': 0,
    'CSORDAS': 0,
    'CU': 0,
    'CUA': 0,
    'CUADRA': 0,
    'CUADRADO': 0,
    'CUADRAS': 0,
    'CUADRO': 0,
    'CUADROS': 0,
    'CUAHUIZO': 0,
    'CUAHUTLE': 0,
    'CUAN': 0,
    'CUARA': 0,
    'CUARENTA': 0,
    'CUARESMA': 0,
    'CUAREZMA': 0,
    'CUARON': 0,
    'CUARTAS': 0,
    'CUARTERO': 0,
    'CUASAY': 0,
    'CUASCUT': 0,
    'CUATE': 0,
    'CUATT': 0,
    'CUAUTLE': 0,
    'CUBA': 0,
    'CUBAN': 0,
    'CUBANGBANG': 0,
    'CUBANO': 0,
    'CUBAS': 0,
    'CUBBAGE': 0,
    'CUBBEDGE': 0,
    'CUBBERLEY': 0,
    'CUBBERLY': 0,
    'CUBBISON': 0,
    'CUBBON': 0,
    'CUBE': 0,
    'CUBEL': 0,
    'CUBELLIS': 0,
    'CUBERO': 0,
    'CUBERT': 0,
    'CUBETA': 0,
    'CUBI': 0,
    'CUBIAS': 0,
    'CUBIC': 0,
    'CUBIDES': 0,
    'CUBIE': 0,
    'CUBILLA': 0,
    'CUBILLAS': 0,
    'CUBILLO': 0,
    'CUBILLOS': 0,
    'CUBINE': 0,
    'CUBIT': 0,
    'CUBITT': 0,
    'CUBLEY': 0,
    'CUC': 0.9615384615384616,
    'CUCALON': 0,
    'CUCCARO': 0,
    'CUCCHI': 0,
    'CUCCHIARA': 0,
    'CUCCHIARO': 0,
    'CUCCI': 0,
    'CUCCIA': 0,
    'CUCCINELLO': 0,
    'CUCCINIELLO': 0,
    'CUCCIO': 0,
    'CUCCO': 0,
    'CUCCURULLO': 0,
    'CUCE': 0,
    'CUCH': 0,
    'CUCHENS': 0,
    'CUCHIARA': 0,
    'CUCHNA': 0,
    'CUCINA': 0,
    'CUCINELLA': 0,
    'CUCINELLO': 0,
    'CUCINOTTA': 0,
    'CUCKLER': 0,
    'CUCOLO': 0,
    'CUCULICH': 0,
    'CUCULLU': 0,
    'CUCURA': 0,
    'CUCURULLO': 0,
    'CUCUZZA': 0,
    'CUDA': 0,
    'CUDABACK': 0,
    'CUDAHY': 0,
    'CUDAK': 0,
    'CUDAL': 0,
    'CUDD': 0,
    'CUDDEBACK': 0,
    'CUDDIE': 0,
    'CUDDIHY': 0,
    'CUDDINGTON': 0,
    'CUDDY': 0,
    'CUDE': 0,
    'CUDIA': 0,
    'CUDIAMAT': 0,
    'CUDJO': 0,
    'CUDJOE': 0,
    'CUDMORE': 0,
    'CUDNEY': 0,
    'CUDNIK': 0,
    'CUDWORTH': 0,
    'CUDZILO': 0,
    'CUE': 0,
    'CUEBAS': 0,
    'CUELLA': 0,
    'CUELLAR': 0,
    'CUELLO': 0,
    'CUEN': 0,
    'CUENCA': 0,
    'CUENCO': 0,
    'CUENIN': 0,
    'CUENTAS': 0,
    'CUERO': 0,
    'CUERVO': 0,
    'CUESTA': 0,
    'CUESTAS': 0,
    'CUETO': 0,
    'CUEVA': 0,
    'CUEVAS': 0,
    'CUFF': 0,
    'CUFFARI': 0,
    'CUFFARO': 0,
    'CUFFE': 0,
    'CUFFEE': 0,
    'CUFFEL': 0,
    'CUFFEY': 0,
    'CUFFIE': 0,
    'CUFFLEY': 0,
    'CUFFMAN': 0,
    'CUFFY': 0,
    'CUGINI': 0,
    'CUGLIARI': 0,
    'CUGNO': 0,
    'CUI': 0,
    'CUIFFO': 0,
    'CUILLA': 0,
    'CUILTY': 0,
    'CUIN': 0,
    'CUIRIZ': 0,
    'CUISON': 0,
    'CUIZON': 0,
    'CUKA': 0,
    'CUKIER': 0,
    'CULAJAY': 0,
    'CULBERSON': 0,
    'CULBERT': 0,
    'CULBERTH': 0,
    'CULBERTSON': 0,
    'CULBREATH': 0,
    'CULBRETH': 0,
    'CULCASI': 0,
    'CULCLASURE': 0,
    'CULEK': 0,
    'CULEY': 0,
    'CULHANE': 0,
    'CULIN': 0,
    'CULKIN': 0,
    'CULL': 0,
    'CULLAR': 0,
    'CULLARI': 0,
    'CULLARS': 0,
    'CULLEN': 0,
    'CULLENS': 0,
    'CULLER': 0,
    'CULLERS': 0,
    'CULLERTON': 0,
    'CULLETON': 0,
    'CULLEY': 0,
    'CULLIFER': 0,
    'CULLIGAN': 0,
    'CULLIMORE': 0,
    'CULLIN': 0,
    'CULLINA': 0,
    'CULLINAN': 0,
    'CULLINANE': 0,
    'CULLING': 0,
    'CULLINGS': 0,
    'CULLINS': 0,
    'CULLIP': 0,
    'CULLIPHER': 0,
    'CULLIS': 0,
    'CULLISON': 0,
    'CULLITON': 0,
    'CULLITY': 0,
    'CULLIVAN': 0,
    'CULLIVER': 0,
    'CULLMAN': 0,
    'CULLOM': 0,
    'CULLOP': 0,
    'CULLOR': 0,
    'CULLORS': 0,
    'CULLOTTA': 0,
    'CULLUM': 0,
    'CULLUMBER': 0,
    'CULLY': 0,
    'CULMER': 0,
    'CULMO': 0,
    'CULMONE': 0,
    'CULOTTA': 0,
    'CULP': 0,
    'CULPEPER': 0,
    'CULPEPPER': 0,
    'CULPS': 0,
    'CULROSS': 0,
    'CULSHAW': 0,
    'CULTER': 0,
    'CULTICE': 0,
    'CULTON': 0,
    'CULTRERA': 0,
    'CULVAHOUSE': 0,
    'CULVER': 0,
    'CULVERHOUSE': 0,
    'CULVERSON': 0,
    'CULVERT': 0,
    'CULVERWELL': 0,
    'CULWELL': 0,
    'CULY': 0,
    'CUMBA': 0,
    'CUMBAA': 0,
    'CUMBE': 0,
    'CUMBEE': 0,
    'CUMBER': 0,
    'CUMBERBATCH': 0,
    'CUMBERLAND': 0,
    'CUMBERLANDER': 0,
    'CUMBERLEDGE': 0,
    'CUMBERWORTH': 0,
    'CUMBESS': 0,
    'CUMBEST': 0,
    'CUMBIE': 0,
    'CUMBO': 0,
    'CUMBOW': 0,
    'CUMBUS': 0,
    'CUMBY': 0,
    'CUMELLA': 0,
    'CUMENS': 0,
    'CUMER': 0,
    'CUMIFORD': 0,
    'CUMING': 0,
    'CUMINGS': 0,
    'CUMINS': 0,
    'CUMISKEY': 0,
    'CUMLEY': 0,
    'CUMM': 0,
    'CUMMENS': 0,
    'CUMMER': 0,
    'CUMMING': 0,
    'CUMMINGS': 0,
    'CUMMINS': 0,
    'CUMMISKEY': 0,
    'CUMMO': 0,
    'CUMMONS': 0,
    'CUMPER': 0,
    'CUMPIAN': 0,
    'CUMPLIDO': 0,
    'CUMPSTON': 0,
    'CUMPTON': 0,
    'CUN': 0,
    'CUNA': 0,
    'CUNAGIN': 0,
    'CUNANAN': 0,
    'CUNARD': 0,
    'CUNAT': 0,
    'CUNDALL': 0,
    'CUNDARI': 0,
    'CUNDEY': 0,
    'CUNDICK': 0,
    'CUNDIFF': 0,
    'CUNDY': 0,
    'CUNEO': 0,
    'CUNFER': 0,
    'CUNG': 0,
    'CUNHA': 0,
    'CUNI': 0,
    'CUNIC': 0,
    'CUNICO': 0,
    'CUNIFF': 0,
    'CUNIGAN': 0,
    'CUNILL': 0,
    'CUNIN': 0,
    'CUNINGHAM': 0,
    'CUNIO': 0,
    'CUNLIFFE': 0,
    'CUNNANE': 0,
    'CUNNEEN': 0,
    'CUNNIEN': 0,
    'CUNNIFF': 0,
    'CUNNIFFE': 0,
    'CUNNING': 0,
    'CUNNINGHAM': 0,
    'CUNNINGHAN': 0,
    'CUNNINGS': 0,
    'CUNNINGTON': 0,
    'CUNNION': 0,
    'CUNNIUS': 0,
    'CUNNYNGHAM': 0,
    'CUNO': 0,
    'CUNSOLO': 0,
    'CUNY': 0,
    'CUNZ': 0,
    'CUOCO': 0,
    'CUOMO': 0,
    'CUOZZO': 0,
    'CUPAK': 0,
    'CUPANI': 0,
    'CUPELES': 0,
    'CUPELLI': 0,
    'CUPERTINO': 0,
    'CUPERUS': 0,
    'CUPERY': 0,
    'CUPID': 0,
    'CUPIDO': 0,
    'CUPIT': 0,
    'CUPITT': 0,
    'CUPKA': 0,
    'CUPLER': 0,
    'CUPO': 0,
    'CUPOLI': 0,
    'CUPOLO': 0,
    'CUPP': 0,
    'CUPPER': 0,
    'CUPPERNELL': 0,
    'CUPPETT': 0,
    'CUPPLES': 0,
    'CUPPS': 0,
    'CUPPY': 0,
    'CUPSTID': 0,
    'CURA': 0,
    'CURAMENG': 0,
    'CURAN': 0,
    'CURASI': 0,
    'CURATO': 0,
    'CURATOLA': 0,
    'CURATOLO': 0,
    'CURB': 0,
    'CURBEAM': 0,
    'CURBELD': 0,
    'CURBELO': 0,
    'CURBO': 0,
    'CURBOW': 0,
    'CURBY': 0,
    'CURCI': 0,
    'CURCIE': 0,
    'CURCIO': 0,
    'CURCIONE': 0,
    'CURCURU': 0,
    'CURCURUTO': 0,
    'CURD': 0,
    'CURDIE': 0,
    'CURDY': 0,
    'CURE': 0,
    'CURELL': 0,
    'CURENTON': 0,
    'CURET': 0,
    'CURETON': 0,
    'CUREY': 0,
    'CURFMAN': 0,
    'CURI': 0,
    'CURIA': 0,
    'CURIALE': 0,
    'CURIE': 0,
    'CURIEL': 0,
    'CURINGA': 0,
    'CURINGTON': 0,
    'CURIO': 0,
    'CURIOSO': 0,
    'CURIT': 0,
    'CURKENDALL': 0,
    'CURL': 0,
    'CURLAND': 0,
    'CURLE': 0,
    'CURLEE': 0,
    'CURLER': 0,
    'CURLES': 0,
    'CURLESS': 0,
    'CURLETT': 0,
    'CURLEY': 0,
    'CURLIN': 0,
    'CURLING': 0,
    'CURLIS': 0,
    'CURLISS': 0,
    'CURLL': 0,
    'CURLS': 0,
    'CURLY': 0,
    'CURMI': 0,
    'CURNAN': 0,
    'CURNEL': 0,
    'CURNELL': 0,
    'CURNES': 0,
    'CURNETT': 0,
    'CURNEY': 0,
    'CURNOW': 0,
    'CURNS': 0,
    'CURNUTT': 0,
    'CURNUTTE': 0,
    'CURNYN': 0,
    'CUROLE': 0,
    'CUROTTO': 0,
    'CURP': 0,
    'CURPHEY': 0,
    'CURR': 0,
    'CURRA': 0,
    'CURRAH': 0,
    'CURRAN': 0,
    'CURRANS': 0,
    'CURRAO': 0,
    'CURREA': 0,
    'CURRELL': 0,
    'CURREN': 0,
    'CURRENCE': 0,
    'CURRENS': 0,
    'CURRENT': 0,
    'CURRERI': 0,
    'CURREY': 0,
    'CURRI': 0,
    'CURRID': 0,
    'CURRIE': 0,
    'CURRIER': 0,
    'CURRIN': 0,
    'CURRINGTON': 0,
    'CURRIVAN': 0,
    'CURRO': 0,
    'CURRY': 0,
    'CURSI': 0,
    'CURSON': 0,
    'CURT': 0.9900990099009901,
    'CURTAIN': 0,
    'CURTH': 0,
    'CURTI': 0,
    'CURTICE': 0,
    'CURTIN': 0,
    'CURTIS': 0.8314957736126424,
    'CURTISS': 0,
    'CURTNER': 0,
    'CURTO': 0,
    'CURTON': 0,
    'CURTRIGHT': 0,
    'CURTS': 0,
    'CURTSINGER': 0,
    'CURTY': 0,
    'CURVEY': 0,
    'CURVIN': 0,
    'CURWEN': 0,
    'CURWICK': 0,
    'CURY': 0,
    'CURYLO': 0,
    'CURZ': 0,
    'CURZI': 0,
    'CURZIO': 0,
    'CURZON': 0,
    'CUSA': 0,
    'CUSAAC': 0,
    'CUSAC': 0,
    'CUSACK': 0,
    'CUSAND': 0,
    'CUSANELLI': 0,
    'CUSANO': 0,
    'CUSATI': 0,
    'CUSATIS': 0,
    'CUSATO': 0,
    'CUSCHIERI': 0,
    'CUSENZA': 0,
    'CUSEO': 0,
    'CUSEY': 0,
    'CUSH': 0,
    'CUSHARD': 0,
    'CUSHEN': 0,
    'CUSHENBERRY': 0,
    'CUSHENBERY': 0,
    'CUSHER': 0,
    'CUSHEY': 0,
    'CUSHINBERRY': 0,
    'CUSHING': 0,
    'CUSHINGBERRY': 0,
    'CUSHION': 0,
    'CUSHMAN': 0,
    'CUSHNER': 0,
    'CUSHNIE': 0,
    'CUSHWA': 0,
    'CUSHWAY': 0,
    'CUSI': 0,
    'CUSIC': 0,
    'CUSICK': 0,
    'CUSIMANO': 0,
    'CUSKER': 0,
    'CUSKEY': 0,
    'CUSMA': 0,
    'CUSMANO': 0,
    'CUSOLITO': 0,
    'CUSON': 0,
    'CUSSEN': 0,
    'CUSSINS': 0,
    'CUSSON': 0,
    'CUST': 0,
    'CUSTALOW': 0,
    'CUSTANCE': 0,
    'CUSTAR': 0,
    'CUSTARD': 0,
    'CUSTEAD': 0,
    'CUSTEAU': 0,
    'CUSTER': 0,
    'CUSTIS': 0,
    'CUSTODE': 0,
    'CUSTODIO': 0,
    'CUSTRED': 0,
    'CUSTY': 0,
    'CUSUMANO': 0,
    'CUSWORTH': 0,
    'CUTAIA': 0,
    'CUTAJAR': 0,
    'CUTBERTH': 0,
    'CUTBIRTH': 0,
    'CUTBURTH': 0,
    'CUTCHALL': 0,
    'CUTCHEMBER': 0,
    'CUTCHEN': 0,
    'CUTCHENS': 0,
    'CUTCHER': 0,
    'CUTCHIN': 0,
    'CUTCHINS': 0,
    'CUTCLIFF': 0,
    'CUTCLIFFE': 0,
    'CUTE': 0,
    'CUTFORTH': 0,
    'CUTHBERT': 0,
    'CUTHBERTSON': 0,
    'CUTHILL': 0,
    'CUTHRELL': 0,
    'CUTI': 0,
    'CUTIE': 0,
    'CUTILLO': 0,
    'CUTINO': 0,
    'CUTKOMP': 0,
    'CUTLER': 0,
    'CUTLIFF': 0,
    'CUTLIP': 0,
    'CUTNER': 0,
    'CUTNO': 0,
    'CUTOLO': 0,
    'CUTONE': 0,
    'CUTRARA': 0,
    'CUTRELL': 0,
    'CUTRER': 0,
    'CUTRERA': 0,
    'CUTRI': 0,
    'CUTRIGHT': 0,
    'CUTRO': 0,
    'CUTRONA': 0,
    'CUTRONE': 0,
    'CUTRUZZULA': 0,
    'CUTSAIL': 0,
    'CUTSFORTH': 0,
    'CUTSHALL': 0,
    'CUTSHAW': 0,
    'CUTSINGER': 0,
    'CUTT': 0,
    'CUTTEN': 0,
    'CUTTER': 0,
    'CUTTILL': 0,
    'CUTTING': 0,
    'CUTTINO': 0,
    'CUTTITTA': 0,
    'CUTTLE': 0,
    'CUTTLER': 0,
    'CUTTONE': 0,
    'CUTTRELL': 0,
    'CUTTS': 0,
    'CUTULI': 0,
    'CUTWAY': 0,
    'CUTWRIGHT': 0,
    'CUVA': 0,
    'CUVAS': 0,
    'CUVELIER': 0,
    'CUVIELLO': 0,
    'CUVILLIER': 0,
    'CUYA': 0,
    'CUYKENDALL': 0,
    'CUYLER': 0,
    'CUYUGAN': 0,
    'CUZA': 0,
    'CUZCO': 0,
    'CUZICK': 0,
    'CUZZI': 0,
    'CUZZO': 0,
    'CUZZONE': 0,
    'CUZZORT': 0,
    'CVAR': 0,
    'CVELBAR': 0,
    'CVENGROS': 0,
    'CVETKOVIC': 0,
    'CVETKOVICH': 0,
    'CVETKOVSKI': 0,
    'CVITANOVICH': 0,
    'CVITKOVIC': 0,
    'CWALINA': 0,
    'CWALINSKI': 0,
    'CWIAK': 0,
    'CWIAKALA': 0,
    'CWICK': 0,
    'CWIEK': 0,
    'CWIK': 0,
    'CWIKLA': 0,
    'CWIKLINSKI': 0,
    'CWYNAR': 0,
    'CYBART': 0,
    'CYBUL': 0,
    'CYBULSKI': 0,
    'CYBURT': 0,
    'CYCHOSZ': 0,
    'CYGAN': 0,
    'CYLKOWSKI': 0,
    'CYMAN': 0,
    'CYMBAL': 0,
    'CYMBALA': 0,
    'CYMBALUK': 0,
    'CYMERMAN': 0,
    'CYNAR': 0,
    'CYNDI': 1,
    'CYNDY': 1,
    'CYNKAR': 0,
    'CYNOR': 0,
    'CYNOVA': 0,
    'CYNTHIA': 1,
    'CYPERT': 0,
    'CYPHER': 0,
    'CYPHERS': 0,
    'CYPHERT': 0,
    'CYPRESS': 0,
    'CYPRET': 0,
    'CYPRIAN': 0,
    'CYPRIANO': 0,
    'CYPRIEN': 0,
    'CYR': 0,
    'CYRA': 0,
    'CYRAN': 0,
    'CYREE': 0,
    'CYRIAC': 0,
    'CYRIAQUE': 0,
    'CYRIER': 0,
    'CYRIL': 0.9873060648801129,
    'CYRILLE': 0,
    'CYRSTAL': 1,
    'CYRULIK': 0,
    'CYRUS': 0.8130081300813008,
    'CYSEWSKI': 0,
    'CYTHIA': 1,
    'CYTRYN': 0,
    'CYWINSKI': 0,
    'CZABAN': 0,
    'CZACH': 0,
    'CZACHOR': 0,
    'CZACHOROWSKI': 0,
    'CZACHOWSKI': 0,
    'CZAHOR': 0,
    'CZAIKOWSKI': 0,
    'CZAJA': 0,
    'CZAJKA': 0,
    'CZAJKOWSKI': 0,
    'CZAK': 0,
    'CZAKO': 0,
    'CZAP': 0,
    'CZAPIEWSKI': 0,
    'CZAPIGA': 0,
    'CZAPLA': 0,
    'CZAPLEWSKI': 0,
    'CZAPLICKI': 0,
    'CZAPLINSKI': 0,
    'CZAPOR': 0,
    'CZAPP': 0,
    'CZAPSKI': 0,
    'CZAR': 0,
    'CZARAPATA': 0,
    'CZARKOWSKI': 0,
    'CZARNECKI': 0,
    'CZARNIAK': 0,
    'CZARNICK': 0,
    'CZARNIECKI': 0,
    'CZARNIK': 0,
    'CZARNOMSKI': 0,
    'CZARNOTA': 0,
    'CZARNOWSKI': 0,
    'CZARNY': 0,
    'CZARTORYSKI': 0,
    'CZECH': 0,
    'CZECHOWICZ': 0,
    'CZECHOWSKI': 0,
    'CZECK': 0,
    'CZEKAJ': 0,
    'CZEKALA': 0,
    'CZEKALSKI': 0,
    'CZEKANSKI': 0,
    'CZELUSNIAK': 0,
    'CZEPIEL': 0,
    'CZEREPAK': 0,
    'CZERKIES': 0,
    'CZERNEK': 0,
    'CZERNIAK': 0,
    'CZERNIAKOWSKI': 0,
    'CZERNIAWSKI': 0,
    'CZERNICKI': 0,
    'CZERNIEJEWSKI': 0,
    'CZERNIEWSKI': 0,
    'CZERNIK': 0,
    'CZERNY': 0,
    'CZERPAK': 0,
    'CZERW': 0,
    'CZERWIEC': 0,
    'CZERWIEN': 0,
    'CZERWINSKI': 0,
    'CZERWONKA': 0,
    'CZESAK': 0,
    'CZESCHIN': 0,
    'CZIRR': 0,
    'CZLAPINSKI': 0,
    'CZOP': 0,
    'CZOPEK': 0,
    'CZORA': 0,
    'CZOSEK': 0,
    'CZOSNYKA': 0,
    'CZUB': 0,
    'CZUBA': 0,
    'CZUBAK': 0,
    'CZUBEK': 0,
    'CZUCHRA': 0,
    'CZUPRYNA': 0,
    'CZUPRYNSKI': 0,
    'CZYSZ': 0,
    'CZYSZCZON': 0,
    'CZYZ': 0,
    'CZYZEWICZ': 0,
    'CZYZEWSKI': 0,
    'CZYZYK': 0,
    'DA': 0,
    'DAAB': 0,
    'DAABOUL': 0,
    'DAAKE': 0,
    'DAANE': 0,
    'DAAR': 0,
    'DAAS': 0,
    'DAAVETTILA': 0,
    'DABABNEH': 0,
    'DABADIE': 0,
    'DABAJA': 0,
    'DABAL': 0,
    'DABALOS': 0,
    'DABB': 0,
    'DABBAGH': 0,
    'DABBAH': 0,
    'DABBAS': 0,
    'DABBELT': 0,
    'DABBERT': 0,
    'DABBRACCIO': 0,
    'DABBS': 0,
    'DABDOUB': 0,
    'DABE': 0,
    'DABEK': 0,
    'DABEL': 0,
    'DABELL': 0,
    'DABERKOW': 0,
    'DABILA': 0,
    'DABILL': 0,
    'DABIRI': 0,
    'DABIS': 0,
    'DABISH': 0,
    'DABIT': 0,
    'DABKOWSKI': 0,
    'DABLE': 0,
    'DABLER': 0,
    'DABNER': 0,
    'DABNEY': 0,
    'DABO': 0,
    'DABON': 0,
    'DABOUB': 0,
    'DABROSKI': 0,
    'DABROWSKA': 0,
    'DABROWSKI': 0,
    'DABSON': 0,
    'DABU': 0,
    'DABY': 0,
    'DABYDEEN': 0,
    'DACANAY': 0,
    'DACE': 0,
    'DACEY': 0,
    'DACH': 0,
    'DACHEL': 0,
    'DACHELET': 0,
    'DACHENHAUSEN': 0,
    'DACHILLE': 0,
    'DACHOWSKI': 0,
    'DACHS': 0,
    'DACHTLER': 0,
    'DACIA': 1,
    'DACIER': 0,
    'DACK': 0,
    'DACKO': 0,
    'DACOSTA': 0,
    'DACQUEL': 0,
    'DACQUISTO': 0,
    'DACRE': 0,
    'DACRES': 0,
    'DACRI': 0,
    'DACRUZ': 0,
    'DACUMOS': 0,
    'DACUNHA': 0,
    'DACUNTO': 0,
    'DACUS': 0,
    'DACUYCUY': 0,
    'DACY': 0,
    'DAD': 0,
    'DADA': 0,
    'DADABHOY': 0,
    'DADABO': 0,
    'DADAMO': 0,
    'DADD': 0,
    'DADDABBO': 0,
    'DADDARIO': 0,
    'DADDATO': 0,
    'DADDEZIO': 0,
    'DADDINO': 0,
    'DADDIO': 0,
    'DADDONA': 0,
    'DADDS': 0,
    'DADE': 0,
    'DADEY': 0,
    'DADI': 0,
    'DADIAN': 0,
    'DADICH': 0,
    'DADISMAN': 0,
    'DADLANI': 0,
    'DADO': 0,
    'DADON': 0,
    'DADSON': 0,
    'DADURA': 0,
    'DADUST': 0,
    'DADY': 0,
    'DADZIE': 0,
    'DAE': 0,
    'DAEGER': 0,
    'DAEHLER': 0,
    'DAEHLING': 0,
    'DAEHN': 0,
    'DAEHNKE': 0,
    'DAENZER': 0,
    'DAERR': 0,
    'DAESCHNER': 0,
    'DAEZ': 0,
    'DAFF': 0,
    'DAFFER': 0,
    'DAFFERN': 0,
    'DAFFIN': 0,
    'DAFFNER': 0,
    'DAFFORN': 0,
    'DAFFRON': 0,
    'DAFLER': 0,
    'DAFNEY': 0,
    'DAFOE': 0,
    'DAFONSECA': 0,
    'DAFONTE': 0,
    'DAFT': 0,
    'DAFTARY': 0,
    'DAG': 0,
    'DAGA': 0,
    'DAGAN': 0,
    'DAGASTINO': 0,
    'DAGATA': 0,
    'DAGATI': 0,
    'DAGDAG': 0,
    'DAGDAGAN': 0,
    'DAGE': 0,
    'DAGEL': 0,
    'DAGEN': 0,
    'DAGENAIS': 0,
    'DAGENHARDT': 0,
    'DAGENHART': 0,
    'DAGER': 0,
    'DAGES': 0,
    'DAGESSE': 0,
    'DAGG': 0,
    'DAGGER': 0,
    'DAGGETT': 0,
    'DAGGS': 0,
    'DAGGY': 0,
    'DAGHER': 0,
    'DAGHLIAN': 0,
    'DAGIT': 0,
    'DAGLE': 0,
    'DAGLEY': 0,
    'DAGMAR': 1,
    'DAGNALL': 0,
    'DAGNAN': 0,
    'DAGNE': 0,
    'DAGNER': 0,
    'DAGNESE': 0,
    'DAGNINO': 0,
    'DAGNON': 0,
    'DAGNY': 1,
    'DAGON': 0,
    'DAGOSTA': 0,
    'DAGOSTARO': 0,
    'DAGOSTIN': 0,
    'DAGOSTINI': 0,
    'DAGOSTINO': 0,
    'DAGOSTO': 0,
    'DAGRACA': 0,
    'DAGROSA': 0,
    'DAGUANNO': 0,
    'DAGUE': 0,
    'DAGUIAR': 0,
    'DAGUIO': 0,
    'DAHAN': 0,
    'DAHARSH': 0,
    'DAHDAH': 0,
    'DAHDAL': 0,
    'DAHDOUH': 0,
    'DAHER': 0,
    'DAHILIG': 0,
    'DAHILL': 0,
    'DAHIR': 0,
    'DAHL': 0,
    'DAHLAGER': 0,
    'DAHLBECK': 0,
    'DAHLBERG': 0,
    'DAHLBY': 0,
    'DAHLE': 0,
    'DAHLEEN': 0,
    'DAHLEM': 0,
    'DAHLEN': 0,
    'DAHLENBURG': 0,
    'DAHLER': 0,
    'DAHLGREN': 0,
    'DAHLHAUSER': 0,
    'DAHLHEIM': 0,
    'DAHLHEIMER': 0,
    'DAHLIA': 1,
    'DAHLIN': 0,
    'DAHLING': 0,
    'DAHLINGER': 0,
    'DAHLINGHAUS': 0,
    'DAHLK': 0,
    'DAHLKE': 0,
    'DAHLMAN': 0,
    'DAHLMANN': 0,
    'DAHLQUIST': 0,
    'DAHLSTEDT': 0,
    'DAHLSTEN': 0,
    'DAHLSTRAND': 0,
    'DAHLSTROM': 0,
    'DAHM': 0,
    'DAHMAN': 0,
    'DAHME': 0,
    'DAHMEN': 0,
    'DAHMER': 0,
    'DAHMS': 0,
    'DAHN': 0,
    'DAHNE': 0,
    'DAHNERT': 0,
    'DAHNKE': 0,
    'DAHSE': 0,
    'DAI': 0,
    'DAIBER': 0,
    'DAIDONE': 0,
    'DAIELLO': 0,
    'DAIGER': 0,
    'DAIGH': 0,
    'DAIGLE': 0,
    'DAIGLER': 0,
    'DAIGNAULT': 0,
    'DAIGNEAU': 0,
    'DAIGNEAULT': 0,
    'DAIGRE': 0,
    'DAIGREPONT': 0,
    'DAIKER': 0,
    'DAIL': 0,
    'DAILEY': 0,
    'DAILING': 0,
    'DAILY': 0,
    'DAIN': 0,
    'DAINA': 1,
    'DAINE': 0.9523809523809523,
    'DAINES': 0,
    'DAINO': 0,
    'DAINS': 0,
    'DAINTON': 0,
    'DAINTY': 0,
    'DAIR': 0,
    'DAIRE': 0,
    'DAIRY': 0,
    'DAIS': 0,
    'DAISE': 0,
    'DAISEY': 0.9009009009009009,
    'DAISLEY': 0,
    'DAISS': 0,
    'DAISY': 0.9963040334243933,
    'DAIT': 0,
    'DAITCH': 0,
    'DAITON': 0,
    'DAIUTO': 0,
    'DAJANI': 0,
    'DAK': 0,
    'DAKA': 0,
    'DAKAN': 0,
    'DAKE': 0,
    'DAKER': 0,
    'DAKERS': 0,
    'DAKES': 0,
    'DAKESSIAN': 0,
    'DAKHLALLAH': 0,
    'DAKIN': 0,
    'DAKINS': 0,
    'DAKIS': 0,
    'DAKOTA': 0.9259259259259258,
    'DAKROUB': 0,
    'DAKU': 0,
    'DAL': 0,
    'DALABA': 0,
    'DALAGER': 0,
    'DALAL': 0,
    'DALAN': 0,
    'DALBA': 0,
    'DALBEC': 0,
    'DALBECK': 0,
    'DALBERG': 0,
    'DALBERTO': 0,
    'DALBEY': 0,
    'DALBO': 0,
    'DALBORA': 0,
    'DALBY': 0,
    'DALCIN': 0,
    'DALCOUR': 0,
    'DALCOURT': 0,
    'DALE': 0.9489916963226572,
    'DALEBOUT': 0,
    'DALEBROUX': 0,
    'DALECKI': 0,
    'DALEE': 0,
    'DALEIDEN': 0,
    'DALELIO': 0,
    'DALEN': 0,
    'DALENA': 0,
    'DALENBERG': 0,
    'DALENE': 1,
    'DALEO': 0,
    'DALERE': 0,
    'DALES': 0,
    'DALESANDRO': 0,
    'DALESIO': 0,
    'DALESKE': 0,
    'DALESSANDRO': 0,
    'DALESSIO': 0,
    'DALEY': 0,
    'DALFERES': 0,
    'DALFONSO': 0,
    'DALFREY': 0,
    'DALGARN': 0,
    'DALGETTY': 0,
    'DALGLEISH': 0,
    'DALGLIESH': 0,
    'DALGLISH': 0,
    'DALGO': 0,
    'DALHOVER': 0,
    'DALI': 0,
    'DALIA': 0.9693053311793215,
    'DALICANDRO': 0,
    'DALIDA': 0,
    'DALIE': 0,
    'DALIEGE': 0,
    'DALILA': 1,
    'DALIMONTE': 0,
    'DALIN': 0,
    'DALING': 0,
    'DALIO': 0,
    'DALIPI': 0,
    'DALIS': 0,
    'DALISAY': 0,
    'DALIT': 0,
    'DALKA': 0,
    'DALKE': 0,
    'DALL': 0,
    'DALLA': 0,
    'DALLAGO': 0,
    'DALLAIRE': 0,
    'DALLAL': 0,
    'DALLAM': 0,
    'DALLAND': 0,
    'DALLAPE': 0,
    'DALLAPIAZZA': 0,
    'DALLARA': 0,
    'DALLAS': 0.8882815169115136,
    'DALLAVALLE': 0,
    'DALLDORF': 0,
    'DALLE': 0,
    'DALLEN': 0,
    'DALLENBACH': 0,
    'DALLER': 0,
    'DALLESANDRO': 0,
    'DALLESSANDRO': 0,
    'DALLEVA': 0,
    'DALLEY': 0,
    'DALLI': 0,
    'DALLIMORE': 0,
    'DALLIN': 0,
    'DALLING': 0,
    'DALLIS': 0,
    'DALLMAN': 0,
    'DALLMANN': 0,
    'DALLMEYER': 0,
    'DALLO': 0,
    'DALLON': 0,
    'DALLOS': 0,
    'DALLUGE': 0,
    'DALLUM': 0,
    'DALLY': 0,
    'DALMACIO': 0,
    'DALMAN': 0,
    'DALMAS': 0,
    'DALMASO': 0,
    'DALMAU': 0,
    'DALME': 0,
    'DALMEIDA': 0,
    'DALMER': 0,
    'DALMOLIN': 0,
    'DALO': 0,
    'DALOIA': 0,
    'DALOISIO': 0,
    'DALOMBA': 0,
    'DALON': 0,
    'DALONZO': 0,
    'DALPE': 0,
    'DALPIAZ': 0,
    'DALPONTE': 0,
    'DALPORTO': 0,
    'DALPRA': 0,
    'DALQUIST': 0,
    'DALRYMPLE': 0,
    'DALSANIA': 0,
    'DALSANTO': 0,
    'DALSING': 0,
    'DALSON': 0,
    'DALTERIO': 0,
    'DALTO': 0,
    'DALTON': 0.3007518796992481,
    'DALTORIO': 0,
    'DALUGA': 0,
    'DALUGE': 0,
    'DALUISIO': 0,
    'DALUM': 0,
    'DALUZ': 0,
    'DALVI': 0,
    'DALY': 0,
    'DALZELL': 0,
    'DALZIEL': 0,
    'DAM': 0,
    'DAMA': 0,
    'DAMALAS': 0,
    'DAMAN': 0,
    'DAMANI': 0,
    'DAMANN': 0,
    'DAMANTE': 0,
    'DAMARIO': 0,
    'DAMARIS': 1,
    'DAMARO': 0,
    'DAMAS': 0,
    'DAMASCO': 0,
    'DAMASK': 0,
    'DAMASKA': 0,
    'DAMASKE': 0,
    'DAMASO': 0,
    'DAMATO': 0,
    'DAMBACH': 0,
    'DAMBACHER': 0,
    'DAMBAUGH': 0,
    'DAMBECK': 0,
    'DAMBERG': 0,
    'DAMBOISE': 0,
    'DAMBRA': 0,
    'DAMBREVILLE': 0,
    'DAMBRO': 0,
    'DAMBROSE': 0,
    'DAMBROSI': 0,
    'DAMBROSIA': 0,
    'DAMBROSIO': 0,
    'DAME': 0,
    'DAMELE': 0,
    'DAMELIO': 0,
    'DAMEN': 0,
    'DAMER': 0,
    'DAMERELL': 0,
    'DAMERON': 0,
    'DAMEROW': 0,
    'DAMERY': 0,
    'DAMES': 0,
    'DAMESWORTH': 0,
    'DAMEWOOD': 0,
    'DAMGAARD': 0,
    'DAMI': 0,
    'DAMIAN': 0.9029345372460497,
    'DAMIANI': 0,
    'DAMIANO': 0,
    'DAMICO': 0,
    'DAMIEN': 0.9929078014184397,
    'DAMIN': 0,
    'DAMION': 0.992063492063492,
    'DAMIS': 0,
    'DAMITIO': 0,
    'DAMITZ': 0,
    'DAMJANOVIC': 0,
    'DAMJANOVICH': 0,
    'DAMLE': 0,
    'DAMM': 0,
    'DAMMAN': 0,
    'DAMMANN': 0,
    'DAMMARELL': 0,
    'DAMME': 0,
    'DAMMEIER': 0,
    'DAMMEL': 0,
    'DAMMEN': 0,
    'DAMMER': 0,
    'DAMMERS': 0,
    'DAMMEYER': 0,
    'DAMMON': 0,
    'DAMMONS': 0,
    'DAMMS': 0,
    'DAMO': 0,
    'DAMON': 0.9259259259259259,
    'DAMOND': 0,
    'DAMONE': 0,
    'DAMONS': 0,
    'DAMONTE': 0,
    'DAMORA': 0,
    'DAMORE': 0,
    'DAMOS': 0,
    'DAMOTA': 0,
    'DAMOTH': 0,
    'DAMOUR': 0,
    'DAMOURS': 0,
    'DAMP': 0,
    'DAMPEER': 0,
    'DAMPER': 0,
    'DAMPF': 0,
    'DAMPIER': 0,
    'DAMPMAN': 0,
    'DAMRAU': 0,
    'DAMRELL': 0,
    'DAMREN': 0,
    'DAMRON': 0,
    'DAMROW': 0,
    'DAMS': 0,
    'DAMSCHEN': 0,
    'DAMSCHRODER': 0,
    'DAMSKY': 0,
    'DAMSTRA': 0,
    'DAMUS': 0,
    'DAMUTH': 0,
    'DAN': 0.9916391211355239,
    'DANA': 0.9880708519098687,
    'DANAE': 1,
    'DANAHER': 0,
    'DANAHEY': 0,
    'DANAHY': 0,
    'DANALS': 0,
    'DANAN': 0,
    'DANAO': 0,
    'DANAS': 0,
    'DANBACK': 0,
    'DANBERG': 0,
    'DANBERRY': 0,
    'DANBOM': 0,
    'DANBURG': 0,
    'DANBURY': 0,
    'DANBY': 0,
    'DANCA': 0,
    'DANCAUSE': 0,
    'DANCE': 0,
    'DANCEL': 0,
    'DANCER': 0,
    'DANCEY': 0,
    'DANCH': 0,
    'DANCHAK': 0,
    'DANCHO': 0,
    'DANCIK': 0,
    'DANCIL': 0,
    'DANCIU': 0,
    'DANCO': 0,
    'DANCONA': 0,
    'DANCY': 0,
    'DANCZAK': 0,
    'DANCZYK': 0,
    'DAND': 0,
    'DANDA': 0,
    'DANDAN': 0,
    'DANDAR': 0,
    'DANDASAN': 0,
    'DANDEKAR': 0,
    'DANDENEAU': 0,
    'DANDINO': 0,
    'DANDO': 0,
    'DANDOY': 0,
    'DANDRADE': 0,
    'DANDREA': 0,
    'DANDRIA': 0,
    'DANDRIDGE': 0,
    'DANDRON': 0,
    'DANDROW': 0,
    'DANDURAND': 0,
    'DANDY': 0,
    'DANE': 0.9146341463414634,
    'DANEAU': 0,
    'DANEAULT': 0,
    'DANEHY': 0,
    'DANEK': 0,
    'DANEKAS': 0,
    'DANEKER': 0,
    'DANEL': 0,
    'DANELL': 0,
    'DANELLA': 0,
    'DANELLE': 1,
    'DANELS': 0,
    'DANELSKI': 0,
    'DANEMAN': 0,
    'DANEN': 0,
    'DANENBERG': 0,
    'DANENHOWER': 0,
    'DANER': 0,
    'DANERI': 0,
    'DANES': 0,
    'DANESE': 0,
    'DANESH': 0,
    'DANESHMAND': 0,
    'DANESHVAR': 0,
    'DANESI': 0,
    'DANET': 0,
    'DANETTE': 1,
    'DANEY': 0,
    'DANFORD': 0,
    'DANFORTH': 0,
    'DANG': 0,
    'DANGANAN': 0,
    'DANGAR': 0,
    'DANGEL': 0,
    'DANGELICO': 0,
    'DANGELO': 0,
    'DANGER': 0,
    'DANGERFIELD': 0,
    'DANGIO': 0,
    'DANGLE': 0,
    'DANGLER': 0,
    'DANGREMOND': 0,
    'DANH': 0,
    'DANHAUER': 0,
    'DANHOF': 0,
    'DANHOFF': 0,
    'DANI': 0.9433962264150944,
    'DANIA': 1,
    'DANIAL': 0.984009840098401,
    'DANICA': 1,
    'DANICO': 0,
    'DANIE': 0,
    'DANIEL': 0.972339474598997,
    'DANIELA': 0.9929078014184397,
    'DANIELAK': 0,
    'DANIELCZYK': 0,
    'DANIELE': 0.8379888268156425,
    'DANIELEWICZ': 0,
    'DANIELEY': 0,
    'DANIELI': 0,
    'DANIELIAN': 0,
    'DANIELL': 0.5494505494505494,
    'DANIELLA': 1,
    'DANIELLE': 0.9991282773419163,
    'DANIELLO': 0,
    'DANIELLS': 0,
    'DANIELLY': 0,
    'DANIELS': 0,
    'DANIELSEN': 0,
    'DANIELSKI': 0,
    'DANIELSON': 0,
    'DANIELY': 0,
    'DANIELYAN': 0,
    'DANIHER': 0,
    'DANIK': 0,
    'DANIKA': 1,
    'DANILE': 0,
    'DANILES': 0,
    'DANILLE': 1,
    'DANILO': 1,
    'DANILOFF': 0,
    'DANILOV': 0,
    'DANILOWICZ': 0,
    'DANILSON': 0,
    'DANILUK': 0,
    'DANINO': 0,
    'DANIO': 0,
    'DANIS': 0,
    'DANISE': 0,
    'DANISH': 0,
    'DANISI': 0,
    'DANISON': 0,
    'DANISZEWSKI': 0,
    'DANITA': 1,
    'DANITZ': 0,
    'DANJOU': 0,
    'DANK': 0,
    'DANKA': 0,
    'DANKANICH': 0,
    'DANKE': 0,
    'DANKEL': 0,
    'DANKENBRING': 0,
    'DANKER': 0,
    'DANKERS': 0,
    'DANKERT': 0,
    'DANKHA': 0,
    'DANKINS': 0,
    'DANKLEFSEN': 0,
    'DANKNER': 0,
    'DANKO': 0,
    'DANKOVICH': 0,
    'DANKOWSKI': 0,
    'DANKS': 0,
    'DANKWORTH': 0,
    'DANLER': 0,
    'DANLEY': 0,
    'DANLY': 0,
    'DANN': 0.39840637450199207,
    'DANNA': 0.8413461538461539,
    'DANNAR': 0,
    'DANNATT': 0,
    'DANNE': 0,
    'DANNECKER': 0,
    'DANNEHL': 0,
    'DANNEKER': 0,
    'DANNEL': 0,
    'DANNELLEY': 0,
    'DANNELLY': 0,
    'DANNELS': 0,
    'DANNEMAN': 0,
    'DANNEMANN': 0,
    'DANNEMILLER': 0,
    'DANNEN': 0,
    'DANNENBAUM': 0,
    'DANNENBERG': 0,
    'DANNENBRING': 0,
    'DANNENFELSER': 0,
    'DANNENMUELLER': 0,
    'DANNER': 0,
    'DANNETTE': 1,
    'DANNEWITZ': 0,
    'DANNHEIM': 0,
    'DANNIBALE': 0,
    'DANNIE': 1,
    'DANNIELLE': 1,
    'DANNIS': 0,
    'DANNO': 0,
    'DANNOLFO': 0,
    'DANNUNZIO': 0,
    'DANNY': 0.9995791245791246,
    'DANO': 0,
    'DANOFF': 0,
    'DANON': 0,
    'DANOS': 0,
    'DANOVICH': 0,
    'DANOWSKI': 0,
    'DANQUAH': 0,
    'DANRIDGE': 0,
    'DANS': 0,
    'DANSAK': 0,
    'DANSBERRY': 0,
    'DANSBURY': 0,
    'DANSBY': 0,
    'DANSER': 0,
    'DANSEREAU': 0,
    'DANSEY': 0,
    'DANSIE': 0,
    'DANSKIN': 0,
    'DANSKY': 0,
    'DANSO': 0,
    'DANSON': 0,
    'DANT': 0,
    'DANTA': 0,
    'DANTAS': 0,
    'DANTE': 0.9718172983479105,
    'DANTER': 0,
    'DANTES': 0,
    'DANTI': 0,
    'DANTICO': 0,
    'DANTIGNAC': 0,
    'DANTIN': 0,
    'DANTINNE': 0,
    'DANTLEY': 0,
    'DANTO': 0,
    'DANTON': 0,
    'DANTONA': 0,
    'DANTONE': 0,
    'DANTONI': 0,
    'DANTONIO': 0,
    'DANTUMA': 0,
    'DANTUONO': 0,
    'DANTZ': 0,
    'DANTZER': 0,
    'DANTZLER': 0,
    'DANUSER': 0,
    'DANUTA': 1,
    'DANVER': 0,
    'DANVERS': 0,
    'DANY': 0,
    'DANYEL': 1,
    'DANYELL': 1,
    'DANYELLE': 1,
    'DANYI': 0,
    'DANYLUK': 0,
    'DANYO': 0,
    'DANYOW': 0,
    'DANYSH': 0,
    'DANZ': 0,
    'DANZA': 0,
    'DANZE': 0,
    'DANZEISEN': 0,
    'DANZER': 0,
    'DANZEY': 0,
    'DANZI': 0,
    'DANZIG': 0,
    'DANZIGER': 0,
    'DANZINGER': 0,
    'DANZL': 0,
    'DANZO': 0,
    'DANZY': 0,
    'DAO': 0,
    'DAOANG': 0,
    'DAOHEUANG': 0,
    'DAOU': 0,
    'DAOUD': 0,
    'DAOUST': 0,
    'DAPHINE': 1,
    'DAPHNE': 1,
    'DAPHNIS': 0,
    'DAPICE': 0,
    'DAPKUS': 0,
    'DAPOLITO': 0,
    'DAPONTE': 0,
    'DAPORE': 0,
    'DAPP': 0,
    'DAPPEN': 0,
    'DAPPER': 0,
    'DAPPRICH': 0,
    'DAPRA': 0,
    'DAPRATO': 0,
    'DAPREMONT': 0,
    'DAPRILE': 0,
    'DAPRON': 0,
    'DAPSON': 0,
    'DAPUZZO': 0,
    'DAQUILA': 0,
    'DAQUIN': 0,
    'DAQUINO': 0,
    'DAQUIOAG': 0,
    'DAR': 0,
    'DARA': 0.9762900976290098,
    'DARABI': 0,
    'DARAGO': 0,
    'DARAKJIAN': 0,
    'DARAMOLA': 0,
    'DARANG': 0,
    'DARAS': 0,
    'DARBE': 0,
    'DARBEE': 0,
    'DARBINYAN': 0,
    'DARBONNE': 0,
    'DARBOUZE': 0,
    'DARBRO': 0,
    'DARBY': 0.23201856148491884,
    'DARBYSHIRE': 0,
    'DARCANGELIS': 0,
    'DARCANGELO': 0,
    'DARCE': 0,
    'DARCEL': 1,
    'DARCEY': 0.8196721311475409,
    'DARCH': 0,
    'DARCHE': 0,
    'DARCI': 1,
    'DARCIE': 1,
    'DARCO': 0,
    'DARCUS': 0,
    'DARCY': 0.8746355685131195,
    'DARD': 0,
    'DARDA': 0,
    'DARDANO': 0,
    'DARDAR': 0,
    'DARDAS': 0,
    'DARDASHTI': 0,
    'DARDEAU': 0,
    'DARDEEN': 0,
    'DARDEN': 0,
    'DARDENNE': 0,
    'DARDER': 0,
    'DARDICK': 0,
    'DARDIS': 0,
    'DARDON': 0,
    'DARDY': 0,
    'DARDZINSKI': 0,
    'DARE': 0,
    'DARELL': 1,
    'DAREN': 0.9950248756218906,
    'DARENSBOURG': 0,
    'DARENSBURG': 0,
    'DARES': 0,
    'DAREY': 0,
    'DAREZZO': 0,
    'DARFLER': 0,
    'DARFUS': 0,
    'DARGA': 0,
    'DARGAN': 0,
    'DARGATZ': 0,
    'DARGAY': 0,
    'DARGE': 0,
    'DARGEL': 0,
    'DARGENIO': 0,
    'DARGENTO': 0,
    'DARGER': 0,
    'DARGIE': 0,
    'DARGIN': 0,
    'DARGIS': 0,
    'DARGITZ': 0,
    'DARGO': 0,
    'DARGON': 0,
    'DARGY': 0,
    'DARHOWER': 0,
    'DARI': 0,
    'DARIA': 0.9756097560975611,
    'DARIAN': 0,
    'DARIANO': 0,
    'DARIAS': 0,
    'DARIEN': 0,
    'DARIENZO': 0,
    'DARIES': 0,
    'DARILEK': 0,
    'DARIN': 0.9857072449482505,
    'DARING': 0,
    'DARINGER': 0,
    'DARIO': 0.9671179883945842,
    'DARIS': 0,
    'DARISSE': 0,
    'DARITY': 0,
    'DARIUS': 0.9841029523088569,
    'DARJEAN': 0,
    'DARJI': 0,
    'DARK': 0,
    'DARKE': 0,
    'DARKER': 0,
    'DARKES': 0,
    'DARKINS': 0,
    'DARKIS': 0,
    'DARKO': 0,
    'DARKOW': 0,
    'DARKS': 0,
    'DARLA': 1,
    'DARLAGE': 0,
    'DARLAK': 0,
    'DARLAND': 0,
    'DARLEEN': 1,
    'DARLENA': 1,
    'DARLENE': 1,
    'DARLEY': 0,
    'DARLIN': 0,
    'DARLINE': 1,
    'DARLING': 0,
    'DARLINGTON': 0,
    'DARLOW': 0,
    'DARM': 0,
    'DARMAN': 0,
    'DARMANIN': 0,
    'DARMER': 0,
    'DARMETKO': 0,
    'DARMIENTO': 0,
    'DARMODY': 0,
    'DARMOFAL': 0,
    'DARMON': 0,
    'DARMSTADT': 0,
    'DARNA': 0,
    'DARNABY': 0,
    'DARNALL': 0,
    'DARNEAL': 0,
    'DARNEILLE': 0,
    'DARNEL': 0,
    'DARNELL': 0.7694998251136761,
    'DARNER': 0,
    'DARNES': 0,
    'DARNEY': 0,
    'DARNIELLE': 0,
    'DARNLEY': 0,
    'DARNOLD': 0,
    'DARO': 0,
    'DAROCHA': 0,
    'DARON': 0.963855421686747,
    'DARONE': 0,
    'DAROS': 0,
    'DAROSA': 0,
    'DAROZA': 0,
    'DARPA': 0,
    'DARPEL': 0,
    'DARPINO': 0,
    'DARR': 0,
    'DARRACH': 0,
    'DARRACOTT': 0,
    'DARRAGH': 0,
    'DARRAH': 0,
    'DARRAS': 0,
    'DARREL': 1,
    'DARRELL': 0.9950248756218906,
    'DARREN': 0.998907444982051,
    'DARRENKAMP': 0,
    'DARRETT': 0,
    'DARRICK': 1,
    'DARRIGO': 0,
    'DARRIN': 0.9937238493723849,
    'DARRING': 0,
    'DARRINGTON': 0,
    'DARRIS': 0,
    'DARRISAW': 0,
    'DARROCH': 0,
    'DARRON': 0.9876543209876544,
    'DARROUGH': 0,
    'DARROW': 0,
    'DARRYL': 1,
    'DARSCH': 0,
    'DARSEY': 0,
    'DARSIE': 0,
    'DARSON': 0,
    'DARSOW': 0,
    'DARST': 0,
    'DART': 0,
    'DARTER': 0,
    'DARTEZ': 0,
    'DARTHARD': 0,
    'DARTING': 0,
    'DARTNELL': 0,
    'DARTON': 0,
    'DARTT': 0,
    'DARTY': 0,
    'DARUS': 0,
    'DARVEAU': 0,
    'DARVEAUX': 0,
    'DARVILLE': 0,
    'DARVIN': 0,
    'DARVISH': 0,
    'DARWELL': 0,
    'DARWICH': 0,
    'DARWICHE': 0,
    'DARWIN': 0.9556313993174061,
    'DARWISH': 0,
    'DARWOOD': 0,
    'DARY': 0,
    'DARYANANI': 0,
    'DARYANI': 0,
    'DARYL': 1,
    'DAS': 0,
    'DASALLA': 0,
    'DASARI': 0,
    'DASARO': 0,
    'DASBACH': 0,
    'DASCANIO': 0,
    'DASCENZO': 0,
    'DASCH': 0,
    'DASCHBACH': 0,
    'DASCHER': 0,
    'DASCHKE': 0,
    'DASCOLI': 0,
    'DASCOMB': 0,
    'DASE': 0,
    'DASEN': 0,
    'DASENBROCK': 0,
    'DASENT': 0,
    'DASGUPTA': 0,
    'DASH': 0,
    'DASHER': 0,
    'DASHEVSKY': 0,
    'DASHIELL': 0,
    'DASHNAW': 0,
    'DASHNER': 0,
    'DASHTI': 0,
    'DASILVA': 0,
    'DASILVEIRA': 0,
    'DASINGER': 0,
    'DASKAL': 0,
    'DASKALAKIS': 0,
    'DASKALOS': 0,
    'DASKAM': 0,
    'DASO': 0,
    'DASOVICH': 0,
    'DASPIT': 0,
    'DASS': 0,
    'DASSAU': 0,
    'DASSE': 0,
    'DASSEL': 0,
    'DASSIE': 0,
    'DASSING': 0,
    'DASSINGER': 0,
    'DASSLER': 0,
    'DASSO': 0,
    'DASSOW': 0,
    'DASTA': 0,
    'DASTE': 0,
    'DASTI': 0,
    'DASTOLI': 0,
    'DASTOUS': 0,
    'DASTRUP': 0,
    'DASWANI': 0,
    'DASZKIEWICZ': 0,
    'DAT': 0,
    'DATA': 0,
    'DATAR': 0,
    'DATCHER': 0,
    'DATE': 0,
    'DATEMA': 0,
    'DATER': 0,
    'DATHE': 0,
    'DATHOUT': 0,
    'DATIL': 0,
    'DATIS': 0,
    'DATKA': 0,
    'DATKO': 0,
    'DATO': 0,
    'DATOR': 0,
    'DATRES': 0,
    'DATRI': 0,
    'DATS': 0,
    'DATSKO': 0,
    'DATSON': 0,
    'DATT': 0,
    'DATTA': 0,
    'DATTALO': 0,
    'DATTILIO': 0,
    'DATTILO': 0,
    'DATTNER': 0,
    'DATTOLI': 0,
    'DATTOLO': 0,
    'DATTOMA': 0,
    'DATU': 0,
    'DATUIN': 0,
    'DATWYLER': 0,
    'DATZ': 0,
    'DATZMAN': 0,
    'DAU': 0,
    'DAUB': 0,
    'DAUBE': 0,
    'DAUBENMIRE': 0,
    'DAUBENSPECK': 0,
    'DAUBER': 0,
    'DAUBERMAN': 0,
    'DAUBERT': 0,
    'DAUBMAN': 0,
    'DAUBNER': 0,
    'DAUBNEY': 0,
    'DAUBS': 0,
    'DAUBY': 0,
    'DAUCH': 0,
    'DAUCHY': 0,
    'DAUD': 0,
    'DAUDELIN': 0,
    'DAUDT': 0,
    'DAUENHAUER': 0,
    'DAUER': 0,
    'DAUFFENBACH': 0,
    'DAUGAARD': 0,
    'DAUGEREAU': 0,
    'DAUGETTE': 0,
    'DAUGHARTY': 0,
    'DAUGHDRILL': 0,
    'DAUGHENBAUGH': 0,
    'DAUGHERITY': 0,
    'DAUGHERTY': 0,
    'DAUGHETEE': 0,
    'DAUGHETY': 0,
    'DAUGHHETEE': 0,
    'DAUGHRITY': 0,
    'DAUGHTER': 0,
    'DAUGHTERS': 0,
    'DAUGHTERY': 0,
    'DAUGHTON': 0,
    'DAUGHTREY': 0,
    'DAUGHTRIDGE': 0,
    'DAUGHTRY': 0,
    'DAUGHTY': 0,
    'DAUGS': 0,
    'DAUGUSTINE': 0,
    'DAUK': 0,
    'DAUL': 0,
    'DAULERIO': 0,
    'DAULEY': 0,
    'DAULT': 0,
    'DAULTON': 0,
    'DAUM': 0,
    'DAUMAN': 0,
    'DAUME': 0,
    'DAUN': 0,
    'DAUNAIS': 0,
    'DAUNER': 0,
    'DAUNHAUER': 0,
    'DAUNIS': 0,
    'DAUNT': 0,
    'DAUPHIN': 0,
    'DAUPHINAIS': 0,
    'DAUPHINE': 0,
    'DAUPHINEE': 0,
    'DAUPLAISE': 0,
    'DAURIA': 0,
    'DAURIO': 0,
    'DAURIZIO': 0,
    'DAURO': 0,
    'DAURORA': 0,
    'DAUS': 0,
    'DAUSCH': 0,
    'DAUSCHER': 0,
    'DAUSE': 0,
    'DAUSER': 0,
    'DAUSEY': 0,
    'DAUSMAN': 0,
    'DAUSS': 0,
    'DAUSTER': 0,
    'DAUT': 0,
    'DAUTEL': 0,
    'DAUTENHAHN': 0,
    'DAUTERIVE': 0,
    'DAUTERMAN': 0,
    'DAUTEUIL': 0,
    'DAUTH': 0,
    'DAUTI': 0,
    'DAUTOVIC': 0,
    'DAUTREMONT': 0,
    'DAUTRICH': 0,
    'DAUWALTER': 0,
    'DAUZ': 0,
    'DAUZART': 0,
    'DAUZAT': 0,
    'DAV': 0,
    'DAVALA': 0,
    'DAVALL': 0,
    'DAVALLE': 0,
    'DAVALOS': 0,
    'DAVAN': 0,
    'DAVANI': 0,
    'DAVANT': 0,
    'DAVANZO': 0,
    'DAVARI': 0,
    'DAVAULT': 0,
    'DAVE': 0.9726555331253441,
    'DAVEE': 0,
    'DAVEIGA': 0,
    'DAVELAAR': 0,
    'DAVELER': 0,
    'DAVELLA': 0,
    'DAVEN': 0,
    'DAVENPORT': 0,
    'DAVER': 0,
    'DAVERN': 0,
    'DAVERSA': 0,
    'DAVES': 0,
    'DAVEY': 0,
    'DAVI': 0,
    'DAVIA': 0,
    'DAVIAU': 0,
    'DAVICH': 0,
    'DAVICK': 0,
    'DAVID': 0.9939874041781877,
    'DAVIDA': 0.9803921568627452,
    'DAVIDE': 0,
    'DAVIDEK': 0,
    'DAVIDENKO': 0,
    'DAVIDGE': 0,
    'DAVIDHEISER': 0,
    'DAVIDHIZAR': 0,
    'DAVIDIAN': 0,
    'DAVIDO': 0,
    'DAVIDOFF': 0,
    'DAVIDOV': 0,
    'DAVIDOVIC': 0,
    'DAVIDOVICH': 0,
    'DAVIDOW': 0,
    'DAVIDOWITZ': 0,
    'DAVIDOWSKI': 0,
    'DAVIDS': 0,
    'DAVIDSEN': 0,
    'DAVIDSON': 0,
    'DAVIE': 0,
    'DAVIED': 0,
    'DAVIES': 0,
    'DAVIGNON': 0,
    'DAVILA': 0,
    'DAVILAR': 0,
    'DAVILLA': 0,
    'DAVILLIER': 0,
    'DAVIN': 0,
    'DAVINA': 1,
    'DAVINE': 0,
    'DAVINI': 0,
    'DAVINO': 0,
    'DAVINROY': 0,
    'DAVION': 0,
    'DAVIRRO': 0,
    'DAVIS': 0.02453927510981326,
    'DAVISLEE': 0,
    'DAVISON': 0,
    'DAVISSMITH': 0,
    'DAVISSON': 0,
    'DAVISTON': 0,
    'DAVIT': 0,
    'DAVITIAN': 0,
    'DAVITO': 0,
    'DAVITT': 0,
    'DAVITZ': 0,
    'DAVLIN': 0,
    'DAVOL': 0,
    'DAVOLI': 0,
    'DAVOLIO': 0,
    'DAVOLL': 0,
    'DAVOLT': 0,
    'DAVOODI': 0,
    'DAVOODIAN': 0,
    'DAVOREN': 0,
    'DAVOUDI': 0,
    'DAVTIAN': 0,
    'DAVTYAN': 0,
    'DAVY': 0,
    'DAVYDOV': 0,
    'DAVYDOVA': 0,
    'DAW': 0,
    'DAWALD': 0,
    'DAWALT': 0,
    'DAWAN': 0,
    'DAWBER': 0,
    'DAWDY': 0,
    'DAWE': 0,
    'DAWES': 0,
    'DAWICKI': 0,
    'DAWID': 0,
    'DAWIDOWICZ': 0,
    'DAWIT': 0,
    'DAWKINS': 0,
    'DAWLEY': 0,
    'DAWN': 0.9975801274136995,
    'DAWNA': 1,
    'DAWNE': 1,
    'DAWOD': 0,
    'DAWODU': 0,
    'DAWOOD': 0,
    'DAWOUD': 0,
    'DAWS': 0,
    'DAWSEY': 0,
    'DAWSON': 0,
    'DAWUD': 0,
    'DAX': 0,
    'DAXON': 0,
    'DAY': 0,
    'DAYA': 0,
    'DAYAL': 0,
    'DAYAN': 0,
    'DAYANI': 0,
    'DAYAO': 0,
    'DAYBELL': 0,
    'DAYBERRY': 0,
    'DAYE': 0,
    'DAYEN': 0,
    'DAYER': 0,
    'DAYES': 0,
    'DAYHOFF': 0,
    'DAYHUFF': 0,
    'DAYKIN': 0,
    'DAYLE': 1,
    'DAYLEY': 0,
    'DAYLONG': 0,
    'DAYLOR': 0,
    'DAYMON': 0,
    'DAYMUDE': 0,
    'DAYNA': 1,
    'DAYNE': 0,
    'DAYNES': 0,
    'DAYOAN': 0,
    'DAYON': 0,
    'DAYOUB': 0,
    'DAYRINGER': 0,
    'DAYRIT': 0,
    'DAYS': 0,
    'DAYSI': 1,
    'DAYSON': 0,
    'DAYTON': 0,
    'DAYVAULT': 0,
    'DAYWALT': 0,
    'DAYZIE': 0,
    'DAZ': 0,
    'DAZA': 0,
    'DAZE': 0,
    'DAZELL': 0,
    'DAZEN': 0,
    'DAZET': 0,
    'DAZEY': 0,
    'DAZLEY': 0,
    'DAZO': 0,
    'DAZZO': 0,
    'DCOSTA': 0,
    'DCRUZ': 0,
    'DE': 0,
    'DEA': 0,
    'DEABENDERFER': 0,
    'DEABLER': 0,
    'DEABREU': 0,
    'DEACETIS': 0,
    'DEACH': 0,
    'DEACON': 0,
    'DEACONS': 0,
    'DEACY': 0,
    'DEADERICK': 0,
    'DEADMAN': 0,
    'DEADMON': 0,
    'DEADMOND': 0,
    'DEADRA': 1,
    'DEADRICK': 0,
    'DEADWYLER': 0,
    'DEADY': 0,
    'DEAGAN': 0,
    'DEAGLE': 0,
    'DEAGUERO': 0,
    'DEAGUIAR': 0,
    'DEAHL': 0,
    'DEAK': 0,
    'DEAKIN': 0,
    'DEAKINS': 0,
    'DEAKLE': 0,
    'DEAKYNE': 0,
    'DEAL': 0,
    'DEALBA': 0,
    'DEALE': 0,
    'DEALEJANDRO': 0,
    'DEALEY': 0,
    'DEALL': 0,
    'DEALMEIDA': 0,
    'DEALVA': 0,
    'DEALY': 0,
    'DEAM': 0,
    'DEAMARAL': 0,
    'DEAMER': 0,
    'DEAMICIS': 0,
    'DEAN': 0.7254729134178589,
    'DEANA': 1,
    'DEANDA': 0,
    'DEANDRA': 1,
    'DEANDRADE': 0,
    'DEANDRE': 1,
    'DEANDREA': 0.8849557522123894,
    'DEANE': 0.4672897196261683,
    'DEANER': 0,
    'DEANES': 0,
    'DEANG': 0,
    'DEANGELES': 0,
    'DEANGELIS': 0,
    'DEANGELO': 0.690846286701209,
    'DEANN': 1,
    'DEANNA': 0.9990797949257264,
    'DEANNE': 1,
    'DEANO': 0,
    'DEANS': 0,
    'DEANTONIO': 0,
    'DEANY': 0,
    'DEAQUINO': 0,
    'DEAR': 0,
    'DEARAGON': 0,
    'DEARAUJO': 0,
    'DEARBORN': 0,
    'DEARCE': 0,
    'DEARCOS': 0,
    'DEARDEN': 0,
    'DEARDEUFF': 0,
    'DEARDOFF': 0,
    'DEARDORF': 0,
    'DEARDORFF': 0,
    'DEARDUFF': 0,
    'DEARDURFF': 0,
    'DEARE': 0,
    'DEAREN': 0,
    'DEARIE': 0,
    'DEARIEN': 0,
    'DEARING': 0,
    'DEARINGER': 0,
    'DEARLOVE': 0,
    'DEARMAN': 0,
    'DEARMAS': 0,
    'DEARMENT': 0,
    'DEARMIN': 0,
    'DEARMITT': 0,
    'DEARMON': 0,
    'DEARMOND': 0,
    'DEARMORE': 0,
    'DEARNLEY': 0,
    'DEARO': 0,
    'DEAROLF': 0,
    'DEARRUDA': 0,
    'DEARRY': 0,
    'DEARS': 0,
    'DEARSTINE': 0,
    'DEARSTYNE': 0,
    'DEARTH': 0,
    'DEARWESTER': 0,
    'DEARY': 0,
    'DEAS': 0,
    'DEASE': 0,
    'DEASES': 0,
    'DEASEY': 0,
    'DEASIS': 0,
    'DEASON': 0,
    'DEASSIS': 0,
    'DEASY': 0,
    'DEATER': 0,
    'DEATH': 0,
    'DEATHERAGE': 0,
    'DEATLEY': 0,
    'DEATON': 0,
    'DEATRICH': 0,
    'DEATRICK': 0,
    'DEATS': 0,
    'DEATSCH': 0,
    'DEAU': 0,
    'DEAUGUSTINE': 0,
    'DEAVEN': 0,
    'DEAVER': 0,
    'DEAVERS': 0,
    'DEAVILA': 0,
    'DEAVILLE': 0,
    'DEAVOURS': 0,
    'DEAY': 0,
    'DEAZA': 0,
    'DEB': 0.9584664536741214,
    'DEBACA': 0,
    'DEBACCO': 0,
    'DEBACK': 0,
    'DEBACKER': 0,
    'DEBAERE': 0,
    'DEBAETS': 0,
    'DEBAGGIS': 0,
    'DEBAISE': 0,
    'DEBAKER': 0,
    'DEBAR': 0,
    'DEBARBIERI': 0,
    'DEBARD': 0,
    'DEBARDELABEN': 0,
    'DEBARDELEBEN': 0,
    'DEBARGE': 0,
    'DEBARI': 0,
    'DEBARR': 0,
    'DEBARROS': 0,
    'DEBARTOLD': 0,
    'DEBARTOLO': 0,
    'DEBARY': 0,
    'DEBATE': 0,
    'DEBATES': 0,
    'DEBATTISTA': 0,
    'DEBAUCHE': 0,
    'DEBAUGH': 0,
    'DEBAULT': 0,
    'DEBAUN': 0,
    'DEBAY': 0,
    'DEBBAN': 0,
    'DEBBI': 1,
    'DEBBIE': 0.999745287824758,
    'DEBBINK': 0,
    'DEBBRA': 1,
    'DEBBS': 0,
    'DEBBY': 1,
    'DEBE': 0,
    'DEBEAU': 0,
    'DEBEAUMONT': 0,
    'DEBECK': 0,
    'DEBEE': 0,
    'DEBEER': 0,
    'DEBEL': 0,
    'DEBELAK': 0,
    'DEBELIUS': 0,
    'DEBELL': 0,
    'DEBELLA': 0,
    'DEBELLIS': 0,
    'DEBELLO': 0,
    'DEBENEDETTI': 0,
    'DEBENEDETTO': 0,
    'DEBENEDICTIS': 0,
    'DEBENEDITTIS': 0,
    'DEBENHAM': 0,
    'DEBENPORT': 0,
    'DEBERA': 1,
    'DEBERARDINIS': 0,
    'DEBERG': 0,
    'DEBERNARD': 0,
    'DEBERNARDI': 0,
    'DEBERNARDIS': 0,
    'DEBERNARDO': 0,
    'DEBERRY': 0,
    'DEBES': 0,
    'DEBETTENCOURT': 0,
    'DEBEVEC': 0,
    'DEBEVOISE': 0,
    'DEBEY': 0,
    'DEBI': 1,
    'DEBIAS': 0,
    'DEBIASE': 0,
    'DEBIASI': 0,
    'DEBIASIO': 0,
    'DEBIASSE': 0,
    'DEBIE': 0,
    'DEBIEN': 0,
    'DEBILZAN': 0,
    'DEBISSCHOP': 0,
    'DEBLAEY': 0,
    'DEBLANC': 0,
    'DEBLASE': 0,
    'DEBLASI': 0,
    'DEBLASIO': 0,
    'DEBLASIS': 0,
    'DEBLAUW': 0,
    'DEBLER': 0,
    'DEBLIECK': 0,
    'DEBLIEUX': 0,
    'DEBLOCK': 0,
    'DEBLOIS': 0,
    'DEBNAM': 0,
    'DEBNAR': 0,
    'DEBNATH': 0,
    'DEBNER': 0,
    'DEBO': 0,
    'DEBOARD': 0,
    'DEBOCK': 0,
    'DEBOE': 0,
    'DEBOEF': 0,
    'DEBOER': 0,
    'DEBOEST': 0,
    'DEBOEVER': 0,
    'DEBOIS': 0,
    'DEBOISE': 0,
    'DEBOLD': 0,
    'DEBOLE': 0,
    'DEBOLT': 0,
    'DEBON': 0,
    'DEBONA': 0,
    'DEBONE': 0,
    'DEBONIS': 0,
    'DEBONO': 0,
    'DEBOO': 0,
    'DEBOOM': 0,
    'DEBOOR': 0,
    'DEBOR': 0,
    'DEBORA': 0.9968282736746715,
    'DEBORAH': 0.9998785572602518,
    'DEBORD': 0,
    'DEBORDE': 0,
    'DEBORJA': 0,
    'DEBORTOLI': 0,
    'DEBOSE': 0,
    'DEBOTH': 0,
    'DEBOTTIS': 0,
    'DEBOUSE': 0,
    'DEBOW': 0,
    'DEBOWER': 0,
    'DEBOWSKI': 0,
    'DEBOY': 0,
    'DEBRA': 0.9998039600078417,
    'DEBRAAL': 0,
    'DEBRABANDER': 0,
    'DEBRAH': 0.992063492063492,
    'DEBRAY': 0,
    'DEBRECHT': 0,
    'DEBREE': 0,
    'DEBREW': 0,
    'DEBRICK': 0,
    'DEBRIE': 0,
    'DEBRINE': 0,
    'DEBRINO': 0,
    'DEBRITO': 0,
    'DEBRO': 0,
    'DEBROAH': 1,
    'DEBROCK': 0,
    'DEBROECK': 0,
    'DEBROSSE': 0,
    'DEBROT': 0,
    'DEBROUX': 0,
    'DEBROW': 0,
    'DEBRUCE': 0,
    'DEBRUHL': 0,
    'DEBRUIN': 0,
    'DEBRUINE': 0,
    'DEBRULER': 0,
    'DEBRUM': 0,
    'DEBRUNNER': 0,
    'DEBRUYCKER': 0,
    'DEBRUYN': 0,
    'DEBRUYNE': 0,
    'DEBRY': 0,
    'DEBS': 0,
    'DEBSKI': 0,
    'DEBUCK': 0,
    'DEBUHR': 0,
    'DEBURGER': 0,
    'DEBURGO': 0,
    'DEBUS': 0,
    'DEBUSE': 0,
    'DEBUSK': 0,
    'DEBUSSCHERE': 0,
    'DEBUTTS': 0,
    'DEC': 0,
    'DECAIR': 0,
    'DECAIRE': 0,
    'DECAIRES': 0,
    'DECALUWE': 0,
    'DECAMARA': 0,
    'DECAMBRA': 0,
    'DECAMILLIS': 0,
    'DECAMILLO': 0,
    'DECAMP': 0,
    'DECAMPO': 0,
    'DECAMPOS': 0,
    'DECAMPS': 0,
    'DECAN': 0,
    'DECANDIA': 0,
    'DECANIO': 0,
    'DECANN': 0,
    'DECANT': 0,
    'DECANTER': 0,
    'DECAPITE': 0,
    'DECAPRIO': 0,
    'DECAPUA': 0,
    'DECARDENAS': 0,
    'DECAREAU': 0,
    'DECARIA': 0,
    'DECARLI': 0,
    'DECARLO': 0,
    'DECARMINE': 0,
    'DECARO': 0,
    'DECAROLIS': 0,
    'DECARR': 0,
    'DECARTERET': 0,
    'DECARVALHO': 0,
    'DECASAS': 0,
    'DECASTRO': 0,
    'DECATALDO': 0,
    'DECATO': 0,
    'DECATOR': 0,
    'DECATUR': 0,
    'DECAUSSIN': 0,
    'DECCIO': 0,
    'DECECCO': 0,
    'DECEGLIE': 0,
    'DECELL': 0,
    'DECELLE': 0,
    'DECELLES': 0,
    'DECEMBER': 0,
    'DECENA': 0,
    'DECENT': 0,
    'DECENZO': 0,
    'DECERBO': 0,
    'DECESARE': 0,
    'DECESARIS': 0,
    'DECESPEDES': 0,
    'DECH': 0,
    'DECHAINE': 0,
    'DECHAMBEAU': 0,
    'DECHAMPLAIN': 0,
    'DECHAMPS': 0,
    'DECHAND': 0,
    'DECHANE': 0,
    'DECHANT': 0,
    'DECHAVEZ': 0,
    'DECHELLIS': 0,
    'DECHENE': 0,
    'DECHENNE': 0,
    'DECHER': 0,
    'DECHERT': 0,
    'DECHIARA': 0,
    'DECHIARO': 0,
    'DECHIRICO': 0,
    'DECHOW': 0,
    'DECHRISTOPHER': 0,
    'DECHTER': 0,
    'DECIANTIS': 0,
    'DECICCO': 0,
    'DECILLIS': 0,
    'DECINA': 0,
    'DECIUS': 0,
    'DECK': 0,
    'DECKARD': 0,
    'DECKELBAUM': 0,
    'DECKELMAN': 0,
    'DECKER': 0,
    'DECKERS': 0,
    'DECKERT': 0,
    'DECKINGA': 0,
    'DECKMAN': 0,
    'DECLARK': 0,
    'DECLAY': 0,
    'DECLEENE': 0,
    'DECLEMENTE': 0,
    'DECLERCK': 0,
    'DECLERCQ': 0,
    'DECLERK': 0,
    'DECLET': 0,
    'DECLOUET': 0,
    'DECLOUETTE': 0,
    'DECLUE': 0,
    'DECOCK': 0,
    'DECOCQ': 0,
    'DECOFF': 0,
    'DECOITE': 0,
    'DECOITO': 0,
    'DECOLA': 0,
    'DECOLLIBUS': 0,
    'DECONCINI': 0,
    'DECONINCK': 0,
    'DECONTI': 0,
    'DECOOK': 0,
    'DECORA': 0,
    'DECORAH': 0,
    'DECORDOVA': 0,
    'DECORE': 0,
    'DECORMIER': 0,
    'DECORSO': 0,
    'DECORTE': 0,
    'DECORY': 0,
    'DECOSMO': 0,
    'DECOSSE': 0,
    'DECOST': 0,
    'DECOSTA': 0,
    'DECOSTE': 0,
    'DECOSTER': 0,
    'DECOT': 0,
    'DECOTA': 0,
    'DECOTEAU': 0,
    'DECOTIS': 0,
    'DECOU': 0,
    'DECOUD': 0,
    'DECOURCEY': 0,
    'DECOURCY': 0,
    'DECOURSEY': 0,
    'DECOUTO': 0,
    'DECOUX': 0,
    'DECOWSKI': 0,
    'DECOY': 0,
    'DECRAENE': 0,
    'DECRAMER': 0,
    'DECRANE': 0,
    'DECREMER': 0,
    'DECRESCENZO': 0,
    'DECRISCIO': 0,
    'DECRISTO': 0,
    'DECRISTOFARO': 0,
    'DECRISTOFORO': 0,
    'DECROCE': 0,
    'DECROIX': 0,
    'DECROSTA': 0,
    'DECROW': 0,
    'DECRUZ': 0,
    'DECTER': 0,
    'DECUBELLIS': 0,
    'DECUIR': 0,
    'DECUIRE': 0,
    'DECURTIS': 0,
    'DED': 0,
    'DEDA': 0,
    'DEDAJ': 0,
    'DEDDEN': 0,
    'DEDDENS': 0,
    'DEDDO': 0,
    'DEDE': 0.8474576271186441,
    'DEDEAR': 0,
    'DEDEAUX': 0,
    'DEDECKER': 0,
    'DEDEK': 0,
    'DEDEN': 0,
    'DEDEO': 0,
    'DEDERER': 0,
    'DEDERICH': 0,
    'DEDERICK': 0,
    'DEDERING': 0,
    'DEDERT': 0,
    'DEDES': 0,
    'DEDHIA': 0,
    'DEDIC': 0,
    'DEDIEGO': 0,
    'DEDINSKY': 0,
    'DEDIO': 0,
    'DEDIOS': 0,
    'DEDMAN': 0,
    'DEDMON': 0,
    'DEDMOND': 0,
    'DEDO': 0,
    'DEDOES': 0,
    'DEDOLPH': 0,
    'DEDOMENICO': 0,
    'DEDOMINICIS': 0,
    'DEDON': 0,
    'DEDONA': 0,
    'DEDONATO': 0,
    'DEDOVIC': 0,
    'DEDRA': 1,
    'DEDRICK': 0,
    'DEDRICKSON': 0,
    'DEDVUKAJ': 0,
    'DEE': 0.902061855670103,
    'DEEANN': 1,
    'DEEANNA': 1,
    'DEEB': 0,
    'DEEBLE': 0,
    'DEED': 0,
    'DEEDE': 0,
    'DEEDEE': 1,
    'DEEDON': 0,
    'DEEDRA': 1,
    'DEEDRICK': 0,
    'DEEDS': 0,
    'DEEDY': 0,
    'DEEG': 0,
    'DEEGAN': 0,
    'DEEHAN': 0,
    'DEEHR': 0,
    'DEEKEN': 0,
    'DEEKS': 0,
    'DEEL': 0,
    'DEELEY': 0,
    'DEELY': 0,
    'DEEM': 0,
    'DEEMER': 0,
    'DEEMS': 0,
    'DEEN': 0,
    'DEENA': 1,
    'DEENER': 0,
    'DEENEY': 0,
    'DEENIHAN': 0,
    'DEENY': 0,
    'DEEP': 0,
    'DEER': 0,
    'DEERE': 0,
    'DEEREN': 0,
    'DEERFIELD': 0,
    'DEERING': 0,
    'DEERINWATER': 0,
    'DEERMAN': 0,
    'DEERR': 0,
    'DEERWESTER': 0,
    'DEERY': 0,
    'DEES': 0,
    'DEESE': 0,
    'DEESON': 0,
    'DEETER': 0,
    'DEETH': 0,
    'DEETJEN': 0,
    'DEETS': 0,
    'DEETTA': 1,
    'DEETZ': 0,
    'DEEVER': 0,
    'DEEVERS': 0,
    'DEFA': 0,
    'DEFABIO': 0,
    'DEFABRIZIO': 0,
    'DEFALCO': 0,
    'DEFARIA': 0,
    'DEFATTA': 0,
    'DEFAUW': 0,
    'DEFAY': 0,
    'DEFAYETTE': 0,
    'DEFAZIO': 0,
    'DEFEBAUGH': 0,
    'DEFEDE': 0,
    'DEFEE': 0,
    'DEFEHR': 0,
    'DEFELICE': 0,
    'DEFENBAUGH': 0,
    'DEFENDINI': 0,
    'DEFENDIS': 0,
    'DEFEO': 0,
    'DEFER': 0,
    'DEFERRARI': 0,
    'DEFEVER': 0,
    'DEFEVERS': 0,
    'DEFEYTER': 0,
    'DEFFENBAUGH': 0,
    'DEFFENDALL': 0,
    'DEFFINBAUGH': 0,
    'DEFFINGER': 0,
    'DEFFLEY': 0,
    'DEFFNER': 0,
    'DEFIBAUGH': 0,
    'DEFIESTA': 0,
    'DEFILIPPI': 0,
    'DEFILIPPIS': 0,
    'DEFILIPPO': 0,
    'DEFILLIPO': 0,
    'DEFILLIPPO': 0,
    'DEFINA': 0,
    'DEFINE': 0,
    'DEFINIS': 0,
    'DEFINO': 0,
    'DEFIORE': 0,
    'DEFISHER': 0,
    'DEFLORA': 0,
    'DEFLORES': 0,
    'DEFLORIO': 0,
    'DEFLUMERI': 0,
    'DEFOE': 0,
    'DEFONCE': 0,
    'DEFONTES': 0,
    'DEFONZO': 0,
    'DEFOOR': 0,
    'DEFORD': 0,
    'DEFORE': 0,
    'DEFOREST': 0,
    'DEFORGE': 0,
    'DEFORREST': 0,
    'DEFOSSE': 0,
    'DEFOSSES': 0,
    'DEFOUR': 0,
    'DEFOUW': 0,
    'DEFRAIN': 0,
    'DEFRANCE': 0,
    'DEFRANCES': 0,
    'DEFRANCESCO': 0,
    'DEFRANCIS': 0,
    'DEFRANCISCO': 0,
    'DEFRANCO': 0,
    'DEFRANG': 0,
    'DEFRANK': 0,
    'DEFRANZA': 0,
    'DEFRANZO': 0,
    'DEFRATES': 0,
    'DEFREECE': 0,
    'DEFREES': 0,
    'DEFREESE': 0,
    'DEFREEST': 0,
    'DEFREHN': 0,
    'DEFREITAS': 0,
    'DEFRIECE': 0,
    'DEFRIES': 0,
    'DEFRIESE': 0,
    'DEFRIEZ': 0,
    'DEFRISCO': 0,
    'DEFRONZO': 0,
    'DEFRUSCIO': 0,
    'DEFUR': 0,
    'DEFURIA': 0,
    'DEFURIO': 0,
    'DEFUSCO': 0,
    'DEGA': 0,
    'DEGADO': 0,
    'DEGAETANO': 0,
    'DEGAGNE': 0,
    'DEGALA': 0,
    'DEGAN': 0,
    'DEGAND': 0,
    'DEGANI': 0,
    'DEGANNES': 0,
    'DEGANO': 0,
    'DEGANTE': 0,
    'DEGARCIA': 0,
    'DEGARD': 0,
    'DEGARMO': 0,
    'DEGASE': 0,
    'DEGASPERIS': 0,
    'DEGE': 0,
    'DEGEARE': 0,
    'DEGEER': 0,
    'DEGEEST': 0,
    'DEGEETER': 0,
    'DEGEL': 0,
    'DEGELE': 0,
    'DEGELIA': 0,
    'DEGEN': 0,
    'DEGENARO': 0,
    'DEGENEFFE': 0,
    'DEGENER': 0,
    'DEGENFELDER': 0,
    'DEGENHARDT': 0,
    'DEGENHART': 0,
    'DEGENKOLB': 0,
    'DEGENNARO': 0,
    'DEGENOVA': 0,
    'DEGENSTEIN': 0,
    'DEGEORGE': 0,
    'DEGER': 0,
    'DEGERSTROM': 0,
    'DEGEUS': 0,
    'DEGEYTER': 0,
    'DEGG': 0,
    'DEGGES': 0,
    'DEGGS': 0,
    'DEGHETTO': 0,
    'DEGIACOMO': 0,
    'DEGIDIO': 0,
    'DEGILIO': 0,
    'DEGIORGIO': 0,
    'DEGIOVANNI': 0,
    'DEGIROLAMO': 0,
    'DEGITZ': 0,
    'DEGIULIO': 0,
    'DEGLER': 0,
    'DEGLOPPER': 0,
    'DEGLOW': 0,
    'DEGMAN': 0,
    'DEGN': 0,
    'DEGNAN': 0,
    'DEGNER': 0,
    'DEGOEDE': 0,
    'DEGOEY': 0,
    'DEGOLIER': 0,
    'DEGOLLADO': 0,
    'DEGOLYER': 0,
    'DEGON': 0,
    'DEGONIA': 0,
    'DEGOOD': 0,
    'DEGOOYER': 0,
    'DEGRAAF': 0,
    'DEGRAAFF': 0,
    'DEGRACE': 0,
    'DEGRACIA': 0,
    'DEGRADO': 0,
    'DEGRAEVE': 0,
    'DEGRAFF': 0,
    'DEGRAFFENREID': 0,
    'DEGRAFFENREIDT': 0,
    'DEGRAFFENRIED': 0,
    'DEGRAND': 0,
    'DEGRANDCHAMP': 0,
    'DEGRANDE': 0,
    'DEGRANDIS': 0,
    'DEGRANDPRE': 0,
    'DEGRANGE': 0,
    'DEGRASSE': 0,
    'DEGRASSI': 0,
    'DEGRATE': 0,
    'DEGRAVE': 0,
    'DEGRAW': 0,
    'DEGRAY': 0,
    'DEGRAZIA': 0,
    'DEGRAZIO': 0,
    'DEGRE': 0,
    'DEGREE': 0,
    'DEGREEF': 0,
    'DEGREEFF': 0,
    'DEGREEN': 0,
    'DEGREENIA': 0,
    'DEGREGORIO': 0,
    'DEGREGORY': 0,
    'DEGRENIER': 0,
    'DEGRO': 0,
    'DEGROAT': 0,
    'DEGROFF': 0,
    'DEGROFT': 0,
    'DEGROOD': 0,
    'DEGROODT': 0,
    'DEGROOT': 0,
    'DEGROOTE': 0,
    'DEGROSS': 0,
    'DEGROTE': 0,
    'DEGRUCCIO': 0,
    'DEGRUCHY': 0,
    'DEGRUTTOLA': 0,
    'DEGRUY': 0,
    'DEGRYSE': 0,
    'DEGUCHI': 0,
    'DEGUGLIELMO': 0,
    'DEGUIA': 0,
    'DEGUILIO': 0,
    'DEGUIRE': 0,
    'DEGUISE': 0,
    'DEGUTIS': 0,
    'DEGUZMAN': 0,
    'DEHAAI': 0,
    'DEHAAN': 0,
    'DEHAAS': 0,
    'DEHAHN': 0,
    'DEHAMER': 0,
    'DEHAN': 0,
    'DEHANEY': 0,
    'DEHARD': 0,
    'DEHARDE': 0,
    'DEHARO': 0,
    'DEHART': 0,
    'DEHASS': 0,
    'DEHATE': 0,
    'DEHAVEN': 0,
    'DEHAY': 0,
    'DEHAYES': 0,
    'DEHEER': 0,
    'DEHEN': 0,
    'DEHERRERA': 0,
    'DEHETRE': 0,
    'DEHGHAN': 0,
    'DEHGHANI': 0,
    'DEHL': 0,
    'DEHLER': 0,
    'DEHLIN': 0,
    'DEHLINGER': 0,
    'DEHM': 0,
    'DEHMEL': 0,
    'DEHMER': 0,
    'DEHMLOW': 0,
    'DEHN': 0,
    'DEHNE': 0,
    'DEHNEL': 0,
    'DEHNER': 0,
    'DEHNERT': 0,
    'DEHNING': 0,
    'DEHNKE': 0,
    'DEHOFF': 0,
    'DEHOLLANDER': 0,
    'DEHON': 0,
    'DEHOND': 0,
    'DEHONEY': 0,
    'DEHOOG': 0,
    'DEHOOP': 0,
    'DEHORITY': 0,
    'DEHORTA': 0,
    'DEHOYOS': 0,
    'DEHRING': 0,
    'DEHUFF': 0,
    'DEHUT': 0,
    'DEI': 0,
    'DEIBEL': 0,
    'DEIBELE': 0,
    'DEIBERT': 0,
    'DEIBLE': 0,
    'DEIBLER': 0,
    'DEICH': 0,
    'DEICHERT': 0,
    'DEICHLER': 0,
    'DEICHMAN': 0,
    'DEICHMANN': 0,
    'DEIDA': 0,
    'DEIDRA': 1,
    'DEIDRE': 1,
    'DEIDRICK': 0,
    'DEIEN': 0,
    'DEIERLEIN': 0,
    'DEIESO': 0,
    'DEIG': 0,
    'DEIGADO': 0,
    'DEIGHAN': 0,
    'DEIGHTON': 0,
    'DEIGNAN': 0,
    'DEIHL': 0,
    'DEIKE': 0,
    'DEILEY': 0,
    'DEILY': 0,
    'DEIMEKE': 0,
    'DEIMEL': 0,
    'DEIMLER': 0,
    'DEIMLING': 0,
    'DEIN': 0,
    'DEINER': 0,
    'DEINERT': 0,
    'DEINES': 0,
    'DEINHARDT': 0,
    'DEININGER': 0,
    'DEINLEIN': 0,
    'DEINZER': 0,
    'DEIORIO': 0,
    'DEIR': 0,
    'DEIRDRE': 1,
    'DEIS': 0,
    'DEISCH': 0,
    'DEISE': 0,
    'DEISENROTH': 0,
    'DEISER': 0,
    'DEISHER': 0,
    'DEISING': 0,
    'DEISINGER': 0,
    'DEISLER': 0,
    'DEISLEY': 0,
    'DEISS': 0,
    'DEISSLER': 0,
    'DEIST': 0,
    'DEISTER': 0,
    'DEITCH': 0,
    'DEITCHLER': 0,
    'DEITCHMAN': 0,
    'DEITEMEYER': 0,
    'DEITER': 0,
    'DEITERING': 0,
    'DEITERMAN': 0,
    'DEITERS': 0,
    'DEITRICH': 0,
    'DEITRICK': 0,
    'DEITS': 0,
    'DEITSCH': 0,
    'DEITZ': 0,
    'DEITZEL': 0,
    'DEIULIIS': 0,
    'DEIWERT': 0,
    'DEJA': 0.8771929824561403,
    'DEJAGER': 0,
    'DEJAN': 0,
    'DEJARDIN': 0,
    'DEJARLAIS': 0,
    'DEJARNATT': 0,
    'DEJARNETT': 0,
    'DEJARNETTE': 0,
    'DEJAYNES': 0,
    'DEJEAN': 0,
    'DEJENE': 0,
    'DEJESSE': 0,
    'DEJESU': 0,
    'DEJESUS': 0,
    'DEJEWSKI': 0,
    'DEJNO': 0,
    'DEJOHN': 0,
    'DEJOHNETTE': 0,
    'DEJOIE': 0,
    'DEJOLIE': 0,
    'DEJONG': 0,
    'DEJONGE': 0,
    'DEJONGH': 0,
    'DEJONGHE': 0,
    'DEJOODE': 0,
    'DEJORDY': 0,
    'DEJOSEPH': 0,
    'DEJOURNETT': 0,
    'DEJOURNETTE': 0,
    'DEJOY': 0,
    'DEJUAN': 0,
    'DEJULIA': 0,
    'DEJULIO': 0,
    'DEJULIUS': 0,
    'DEKA': 0,
    'DEKALB': 0,
    'DEKAM': 0,
    'DEKAN': 0,
    'DEKARSKE': 0,
    'DEKAT': 0,
    'DEKAY': 0,
    'DEKE': 0,
    'DEKELAITA': 0,
    'DEKEMPER': 0,
    'DEKEN': 0,
    'DEKERLEGAND': 0,
    'DEKETT': 0,
    'DEKEYREL': 0,
    'DEKEYSER': 0,
    'DEKEYZER': 0,
    'DEKHTYAR': 0,
    'DEKING': 0,
    'DEKKER': 0,
    'DEKKERS': 0,
    'DEKLE': 0,
    'DEKLEINE': 0,
    'DEKLERK': 0,
    'DEKLOTZ': 0,
    'DEKNIKKER': 0,
    'DEKOCK': 0,
    'DEKOEKKOEK': 0,
    'DEKOK': 0,
    'DEKOKER': 0,
    'DEKONINCK': 0,
    'DEKONING': 0,
    'DEKORNE': 0,
    'DEKORTE': 0,
    'DEKOSTER': 0,
    'DEKRAKER': 0,
    'DEKREY': 0,
    'DEKRUIF': 0,
    'DEKRUYF': 0,
    'DEL': 0.9779951100244498,
    'DELA': 0,
    'DELAAT': 0,
    'DELABAR': 0,
    'DELABARRE': 0,
    'DELABARRERA': 0,
    'DELABRA': 0,
    'DELABRUERE': 0,
    'DELACALZADA': 0,
    'DELACAMPA': 0,
    'DELACERDA': 0,
    'DELACERNA': 0,
    'DELACEY': 0,
    'DELACH': 0,
    'DELACOUR': 0,
    'DELACROIX': 0,
    'DELACRUS': 0,
    'DELACRUZ': 0,
    'DELACUADRA': 0,
    'DELACUESTA': 0,
    'DELACUEVA': 0,
    'DELACY': 0,
    'DELADURANTAYE': 0,
    'DELAESPRIELLA': 0,
    'DELAET': 0,
    'DELAFE': 0,
    'DELAFIELD': 0,
    'DELAFLOR': 0,
    'DELAFOSSE': 0,
    'DELAFUENTE': 0,
    'DELAGARDELLE': 0,
    'DELAGARZA': 0,
    'DELAGE': 0,
    'DELAGO': 0,
    'DELAGRANGE': 0,
    'DELAGUARDIA': 0,
    'DELAGUILA': 0,
    'DELAHANTY': 0,
    'DELAHAY': 0,
    'DELAHAYE': 0,
    'DELAHERRAN': 0,
    'DELAHOUSSAYE': 0,
    'DELAHOYA': 0,
    'DELAHOYDE': 0,
    'DELAHOZ': 0,
    'DELAHUERTA': 0,
    'DELAHUNT': 0,
    'DELAHUNTY': 0,
    'DELAIGLE': 0,
    'DELAIN': 0,
    'DELAINE': 0.8130081300813008,
    'DELAIR': 0,
    'DELAIRE': 0,
    'DELAISLA': 0,
    'DELALLA': 0,
    'DELALLO': 0,
    'DELALUZ': 0,
    'DELAMAR': 0,
    'DELAMARE': 0,
    'DELAMARTER': 0,
    'DELAMATER': 0,
    'DELAMAZA': 0,
    'DELAMERCED': 0,
    'DELAMETER': 0,
    'DELAMO': 0,
    'DELAMORA': 0,
    'DELAMOTTE': 0,
    'DELANA': 0.9615384615384616,
    'DELANCE': 0,
    'DELANCEY': 0,
    'DELANCY': 0,
    'DELAND': 0,
    'DELANDE': 0,
    'DELANDER': 0,
    'DELANDRO': 0,
    'DELANE': 0,
    'DELANEY': 0,
    'DELANG': 0,
    'DELANGE': 0,
    'DELANGEL': 0,
    'DELANNOY': 0,
    'DELANO': 0,
    'DELANOVAL': 0,
    'DELANOY': 0,
    'DELANTY': 0,
    'DELANUEZ': 0,
    'DELANY': 0,
    'DELAO': 0,
    'DELAOSA': 0,
    'DELAOSSA': 0,
    'DELAP': 0,
    'DELAPA': 0,
    'DELAPARRA': 0,
    'DELAPAZ': 0,
    'DELAPENA': 0,
    'DELAPENHA': 0,
    'DELAPIEDRA': 0,
    'DELAPLAIN': 0,
    'DELAPLAINE': 0,
    'DELAPLANE': 0,
    'DELAPORTE': 0,
    'DELAPORTILLA': 0,
    'DELAPP': 0,
    'DELAPPE': 0,
    'DELAPUENTE': 0,
    'DELARA': 0,
    'DELARAMA': 0,
    'DELARBER': 0,
    'DELARGE': 0,
    'DELARGY': 0,
    'DELARIA': 0,
    'DELARIVA': 0,
    'DELARM': 0,
    'DELAROCA': 0,
    'DELAROCHA': 0,
    'DELAROCHE': 0,
    'DELAROSA': 0,
    'DELARUE': 0,
    'DELASALAS': 0,
    'DELASANCHA': 0,
    'DELASANTOS': 0,
    'DELASBOUR': 0,
    'DELASCASAS': 0,
    'DELASERNA': 0,
    'DELASHAW': 0,
    'DELASHMIT': 0,
    'DELASHMITT': 0,
    'DELASHMUTT': 0,
    'DELASIERRA': 0,
    'DELASSUS': 0,
    'DELATORE': 0,
    'DELATORRE': 0,
    'DELATORRES': 0,
    'DELATOUR': 0,
    'DELATRINIDAD': 0,
    'DELATTE': 0,
    'DELATTRE': 0,
    'DELAUDER': 0,
    'DELAUGHTER': 0,
    'DELAUNAY': 0,
    'DELAUNE': 0,
    'DELAUNEY': 0,
    'DELAURA': 0,
    'DELAURENTI': 0,
    'DELAURENTIS': 0,
    'DELAURIER': 0,
    'DELAURO': 0,
    'DELAUTER': 0,
    'DELAVAN': 0,
    'DELAVARA': 0,
    'DELAVEGA': 0,
    'DELAVERGNE': 0,
    'DELAVINA': 0,
    'DELAWARE': 0,
    'DELAWDER': 0,
    'DELAWTER': 0,
    'DELAY': 0,
    'DELAYO': 0,
    'DELAZERDA': 0,
    'DELBAGNO': 0,
    'DELBALSO': 0,
    'DELBARRIO': 0,
    'DELBELLO': 0,
    'DELBENE': 0,
    'DELBERT': 0.9955041746949262,
    'DELBIANCO': 0,
    'DELBO': 0,
    'DELBOCCIO': 0,
    'DELBONIS': 0,
    'DELBONO': 0,
    'DELBOSQUE': 0,
    'DELBRIDGE': 0,
    'DELBROCCO': 0,
    'DELBUONO': 0,
    'DELBUSTO': 0,
    'DELCAMBRE': 0,
    'DELCAMP': 0,
    'DELCAMPO': 0,
    'DELCARLO': 0,
    'DELCARMEN': 0,
    'DELCARPIO': 0,
    'DELCASALE': 0,
    'DELCASTILLO': 0,
    'DELCHER': 0,
    'DELCHIARO': 0,
    'DELCID': 0,
    'DELCIE': 1,
    'DELCO': 0,
    'DELCOLLE': 0,
    'DELCOLLO': 0,
    'DELCONTE': 0,
    'DELCORE': 0,
    'DELCORRAL': 0,
    'DELCORSO': 0,
    'DELCOTTO': 0,
    'DELCOUR': 0,
    'DELCOURE': 0,
    'DELCOURT': 0,
    'DELCUETO': 0,
    'DELDEO': 0,
    'DELDOTTO': 0,
    'DELDUCA': 0,
    'DELEA': 0,
    'DELEBREAU': 0,
    'DELECKI': 0,
    'DELEE': 0,
    'DELEEUW': 0,
    'DELEGAL': 0,
    'DELEHANT': 0,
    'DELEHANTY': 0,
    'DELEHOY': 0,
    'DELEKTA': 0,
    'DELELLIS': 0,
    'DELELLO': 0,
    'DELEMOS': 0,
    'DELENA': 0.9389671361502347,
    'DELEO': 0,
    'DELEON': 0,
    'DELEONARDIS': 0,
    'DELEONARDO': 0,
    'DELEONE': 0,
    'DELEONIBUS': 0,
    'DELEPINE': 0,
    'DELERME': 0,
    'DELERY': 0,
    'DELESDERNIER': 0,
    'DELESKI': 0,
    'DELESKY': 0,
    'DELESLINE': 0,
    'DELESSIO': 0,
    'DELESTON': 0,
    'DELETTO': 0,
    'DELEVA': 0,
    'DELEVEAUX': 0,
    'DELEWSKI': 0,
    'DELEY': 0,
    'DELF': 0,
    'DELFAVERO': 0,
    'DELFIACCO': 0,
    'DELFIERRO': 0,
    'DELFIN': 0,
    'DELFINA': 1,
    'DELFINO': 0,
    'DELFORGE': 0,
    'DELFOSSE': 0,
    'DELFRANCO': 0,
    'DELFRATE': 0,
    'DELFS': 0,
    'DELGADILLO': 0,
    'DELGADO': 0,
    'DELGAIZO': 0,
    'DELGALDO': 0,
    'DELGALLO': 0,
    'DELGARDO': 0,
    'DELGARITO': 0,
    'DELGATO': 0,
    'DELGATTO': 0,
    'DELGAUDIO': 0,
    'DELGENIO': 0,
    'DELGER': 0,
    'DELGIACCO': 0,
    'DELGIORNO': 0,
    'DELGIUDICE': 0,
    'DELGOBBO': 0,
    'DELGRANDE': 0,
    'DELGRECO': 0,
    'DELGREGO': 0,
    'DELGROSSO': 0,
    'DELGUERCIO': 0,
    'DELGUIDICE': 0,
    'DELHAGEN': 0,
    'DELHIERRO': 0,
    'DELHOMME': 0,
    'DELHOMMER': 0,
    'DELHOTAL': 0,
    'DELHOYO': 0,
    'DELI': 0,
    'DELIA': 0.9424764380890478,
    'DELIBERO': 0,
    'DELIBERTO': 0,
    'DELIC': 0,
    'DELICE': 0,
    'DELICH': 0,
    'DELICIA': 1,
    'DELIE': 0,
    'DELIGIANNIS': 0,
    'DELIKAT': 0,
    'DELILA': 1,
    'DELILAH': 1,
    'DELILLE': 0,
    'DELILLO': 0,
    'DELIMA': 0,
    'DELIMAN': 0,
    'DELIMONT': 0,
    'DELIN': 0,
    'DELINDA': 1,
    'DELINE': 0,
    'DELING': 0,
    'DELINGER': 0,
    'DELINO': 0,
    'DELINOIS': 0,
    'DELINSKI': 0,
    'DELIO': 0,
    'DELION': 0,
    'DELIRA': 0,
    'DELIS': 0,
    'DELISA': 0.9009009009009009,
    'DELISE': 0,
    'DELISI': 0,
    'DELISIO': 0,
    'DELISLE': 0,
    'DELISO': 0,
    'DELISSER': 0,
    'DELISSIO': 0,
    'DELIUS': 0,
    'DELIZ': 0,
    'DELIZO': 0,
    'DELK': 0,
    'DELKA': 0,
    'DELKE': 0,
    'DELKER': 0,
    'DELKS': 0,
    'DELL': 0.38684719535783374,
    'DELLA': 0.9960620801482511,
    'DELLABELLA': 0,
    'DELLACAMERA': 0,
    'DELLACCIO': 0,
    'DELLACIOPPA': 0,
    'DELLACORTE': 0,
    'DELLACQUA': 0,
    'DELLACROCE': 0,
    'DELLADONNA': 0,
    'DELLAFAVE': 0,
    'DELLAFERA': 0,
    'DELLAGATTA': 0,
    'DELLAGROTTA': 0,
    'DELLAMAGGIORE': 0,
    'DELLAMANO': 0,
    'DELLAMONICA': 0,
    'DELLANGELO': 0,
    'DELLANNO': 0,
    'DELLANO': 0,
    'DELLAPENNA': 0,
    'DELLAPENTA': 0,
    'DELLAPIA': 0,
    'DELLAPIETRA': 0,
    'DELLAPIETRO': 0,
    'DELLAPINA': 0,
    'DELLAPOLLA': 0,
    'DELLAPORTA': 0,
    'DELLAPOSTA': 0,
    'DELLAQUILA': 0,
    'DELLAR': 0,
    'DELLARATTA': 0,
    'DELLARCIPRETE': 0,
    'DELLARIA': 0,
    'DELLARIO': 0,
    'DELLARIPA': 0,
    'DELLAROCCA': 0,
    'DELLAROCCO': 0,
    'DELLAROSA': 0,
    'DELLAS': 0,
    'DELLASALA': 0,
    'DELLASANTA': 0,
    'DELLATORRE': 0,
    'DELLAVALLE': 0,
    'DELLAVECCHIA': 0,
    'DELLAVEDOVA': 0,
    'DELLAVENTURA': 0,
    'DELLAVOLPE': 0,
    'DELLE': 0,
    'DELLEA': 0,
    'DELLECAVE': 0,
    'DELLECHIAIE': 0,
    'DELLEDONNE': 0,
    'DELLEFAVE': 0,
    'DELLENBACH': 0,
    'DELLER': 0,
    'DELLERA': 0,
    'DELLERBA': 0,
    'DELLERT': 0,
    'DELLES': 0,
    'DELLETT': 0,
    'DELLEY': 0,
    'DELLI': 0,
    'DELLIBOVI': 0,
    'DELLICARPINI': 0,
    'DELLIGATTI': 0,
    'DELLING': 0,
    'DELLINGER': 0,
    'DELLIPAOLI': 0,
    'DELLIQUADRI': 0,
    'DELLIS': 0,
    'DELLISANTI': 0,
    'DELLISOLA': 0,
    'DELLLANO': 0,
    'DELLO': 0,
    'DELLOBUONO': 0,
    'DELLOIACONO': 0,
    'DELLOLIO': 0,
    'DELLOMO': 0,
    'DELLON': 0,
    'DELLORCO': 0,
    'DELLORFANO': 0,
    'DELLORSO': 0,
    'DELLORTO': 0,
    'DELLORUSSO': 0,
    'DELLOS': 0,
    'DELLOSA': 0,
    'DELLOSSO': 0,
    'DELLOSTRITTO': 0,
    'DELLOW': 0,
    'DELLS': 0,
    'DELLUTRI': 0,
    'DELLWO': 0,
    'DELLY': 0,
    'DELMA': 0.9915014164305949,
    'DELMAGE': 0,
    'DELMAN': 0,
    'DELMAR': 0.9554140127388535,
    'DELMAS': 0,
    'DELMASTRO': 0,
    'DELMAURO': 0,
    'DELMEDICO': 0,
    'DELMENDO': 0,
    'DELMER': 0.992063492063492,
    'DELMOLINO': 0,
    'DELMONACO': 0,
    'DELMONICO': 0,
    'DELMONT': 0,
    'DELMONTE': 0,
    'DELMORAL': 0,
    'DELMORE': 0,
    'DELMORO': 0,
    'DELMOTTE': 0,
    'DELMUNDO': 0,
    'DELMURO': 0,
    'DELMY': 1,
    'DELNEGRO': 0,
    'DELNERO': 0,
    'DELO': 0,
    'DELOA': 0,
    'DELOACH': 0,
    'DELOACHE': 0,
    'DELOATCH': 0,
    'DELOATCHE': 0,
    'DELOCH': 0,
    'DELOE': 0,
    'DELOERA': 0,
    'DELOGE': 0,
    'DELOIA': 0,
    'DELOIS': 1,
    'DELOISE': 1,
    'DELOLMO': 0,
    'DELOMBA': 0,
    'DELOME': 0,
    'DELON': 0,
    'DELONE': 0,
    'DELONEY': 0,
    'DELONG': 0,
    'DELONGCHAMP': 0,
    'DELONGE': 0,
    'DELONY': 0,
    'DELOOF': 0,
    'DELOOZE': 0,
    'DELOPEZ': 0,
    'DELOR': 0,
    'DELORA': 0.967741935483871,
    'DELORAS': 1,
    'DELORBE': 0,
    'DELORD': 0,
    'DELORE': 0,
    'DELORENZI': 0,
    'DELORENZO': 0,
    'DELORES': 0.9993688196928255,
    'DELORETO': 0,
    'DELOREY': 0,
    'DELORGE': 0,
    'DELORIA': 0,
    'DELORIE': 0,
    'DELORIEA': 0,
    'DELORIMIER': 0,
    'DELORIS': 1,
    'DELORM': 0,
    'DELORME': 0,
    'DELORSE': 1,
    'DELORY': 0,
    'DELOS': 0,
    'DELOSA': 0,
    'DELOSANGELES': 0,
    'DELOSH': 0,
    'DELOSIER': 0,
    'DELOSREYES': 0,
    'DELOSRIOS': 0,
    'DELOSSANTOS': 0,
    'DELOST': 0,
    'DELOTTO': 0,
    'DELOUGHERY': 0,
    'DELOUIS': 0,
    'DELOUISE': 0,
    'DELOY': 0,
    'DELOYA': 0,
    'DELOYE': 0,
    'DELOZA': 0,
    'DELOZIER': 0,
    'DELP': 0,
    'DELPALACIO': 0,
    'DELPAPA': 0,
    'DELPERCIO': 0,
    'DELPERDANG': 0,
    'DELPH': 0,
    'DELPHA': 0.9803921568627452,
    'DELPHIA': 0.9554140127388534,
    'DELPHIN': 0,
    'DELPHINE': 1,
    'DELPIANO': 0,
    'DELPILAR': 0,
    'DELPINO': 0,
    'DELPIT': 0,
    'DELPIZZO': 0,
    'DELPLATO': 0,
    'DELPONTE': 0,
    'DELPORTO': 0,
    'DELPOZO': 0,
    'DELPOZZO': 0,
    'DELPRADO': 0,
    'DELPRATO': 0,
    'DELPRETE': 0,
    'DELPRINCE': 0,
    'DELPRINCIPE': 0,
    'DELPRIORE': 0,
    'DELPUERTO': 0,
    'DELRASO': 0,
    'DELRE': 0,
    'DELREAL': 0,
    'DELREGNO': 0,
    'DELREY': 0,
    'DELRIE': 0,
    'DELRIO': 0,
    'DELRISCO': 0,
    'DELRIVERO': 0,
    'DELROSA': 0,
    'DELROSAL': 0,
    'DELROSARIO': 0,
    'DELROSE': 0,
    'DELROSSI': 0,
    'DELROSSO': 0,
    'DELRUSSO': 0,
    'DELSALTO': 0,
    'DELSANTO': 0,
    'DELSAVIO': 0,
    'DELSESTO': 0,
    'DELSHAD': 0,
    'DELSI': 0,
    'DELSID': 0,
    'DELSIE': 1,
    'DELSIGNORE': 0,
    'DELSMAN': 0,
    'DELSO': 0,
    'DELSOL': 0,
    'DELSOLAR': 0,
    'DELSOLE': 0,
    'DELSON': 0,
    'DELSORDO': 0,
    'DELTA': 1,
    'DELTON': 0,
    'DELTORO': 0,
    'DELTORTO': 0,
    'DELTUFO': 0,
    'DELUCA': 0,
    'DELUCAS': 0,
    'DELUCCA': 0,
    'DELUCCHI': 0,
    'DELUCCIA': 0,
    'DELUCCO': 0,
    'DELUCE': 0,
    'DELUCENAY': 0,
    'DELUCIA': 0,
    'DELUCIO': 0,
    'DELUCO': 0,
    'DELUDE': 0,
    'DELUE': 0,
    'DELUGA': 0,
    'DELUHERY': 0,
    'DELUIS': 0,
    'DELUISE': 0,
    'DELUKE': 0,
    'DELULLO': 0,
    'DELUNA': 0,
    'DELUNG': 0,
    'DELURY': 0,
    'DELUTIS': 0,
    'DELUZ': 0,
    'DELUZIO': 0,
    'DELVA': 0,
    'DELVAL': 0,
    'DELVALLE': 0,
    'DELVAUX': 0,
    'DELVEAUX': 0,
    'DELVECCHIO': 0,
    'DELVENTHAL': 0,
    'DELVESCOVO': 0,
    'DELVILLAR': 0,
    'DELVIN': 0,
    'DELVISCIO': 0,
    'DELVO': 0,
    'DELWICHE': 0,
    'DELY': 0,
    'DELYSER': 0,
    'DELZEIT': 0,
    'DELZELL': 0,
    'DELZER': 0,
    'DELZOPPO': 0,
    'DELZOTTO': 0,
    'DEMA': 0,
    'DEMAAGD': 0,
    'DEMAGGIO': 0,
    'DEMAGISTRIS': 0,
    'DEMAIN': 0,
    'DEMAINE': 0,
    'DEMAIO': 0,
    'DEMALINE': 0,
    'DEMALLIE': 0,
    'DEMAN': 0,
    'DEMANCHE': 0,
    'DEMAND': 0,
    'DEMANGE': 0,
    'DEMANN': 0,
    'DEMAO': 0,
    'DEMAR': 0,
    'DEMARA': 0,
    'DEMARAIS': 0,
    'DEMARANVILLE': 0,
    'DEMARAY': 0,
    'DEMARCE': 0,
    'DEMARCHI': 0,
    'DEMARCHIS': 0,
    'DEMARCO': 0,
    'DEMARCOS': 0,
    'DEMARCUS': 0.9671179883945842,
    'DEMARE': 0,
    'DEMAREE': 0,
    'DEMAREST': 0,
    'DEMARET': 0,
    'DEMARIA': 0,
    'DEMARIE': 0,
    'DEMARINIS': 0,
    'DEMARINO': 0,
    'DEMARIO': 0,
    'DEMARIS': 0,
    'DEMARK': 0,
    'DEMARO': 0,
    'DEMARR': 0,
    'DEMARRAIS': 0,
    'DEMARRE': 0,
    'DEMARRIAS': 0,
    'DEMARS': 0,
    'DEMARSE': 0,
    'DEMARSH': 0,
    'DEMARSICO': 0,
    'DEMART': 0,
    'DEMARTE': 0,
    'DEMARTIN': 0,
    'DEMARTINE': 0,
    'DEMARTINEZ': 0,
    'DEMARTINI': 0,
    'DEMARTINIS': 0,
    'DEMARTINO': 0,
    'DEMARY': 0,
    'DEMARZIO': 0,
    'DEMARZO': 0,
    'DEMAS': 0,
    'DEMASCIO': 0,
    'DEMASE': 0,
    'DEMASI': 0,
    'DEMASO': 0,
    'DEMASS': 0,
    'DEMASSE': 0,
    'DEMASTER': 0,
    'DEMASTERS': 0,
    'DEMASTUS': 0,
    'DEMATA': 0,
    'DEMATO': 0,
    'DEMATOS': 0,
    'DEMATTEI': 0,
    'DEMATTEIS': 0,
    'DEMATTEO': 0,
    'DEMATTIA': 0,
    'DEMATTIES': 0,
    'DEMATTIO': 0,
    'DEMATTO': 0,
    'DEMATTOS': 0,
    'DEMAURO': 0,
    'DEMAY': 0,
    'DEMAYO': 0,
    'DEMBECK': 0,
    'DEMBEK': 0,
    'DEMBER': 0,
    'DEMBINSKI': 0,
    'DEMBINSKY': 0,
    'DEMBITZER': 0,
    'DEMBO': 0,
    'DEMBOSKI': 0,
    'DEMBOWSKI': 0,
    'DEMBROSKI': 0,
    'DEMBROSKY': 0,
    'DEMBROWSKI': 0,
    'DEMBSKI': 0,
    'DEMBY': 0,
    'DEMCHAK': 0,
    'DEMCHENKO': 0,
    'DEMCHUK': 0,
    'DEME': 0,
    'DEMEDEIROS': 0,
    'DEMEDIO': 0,
    'DEMEESTER': 0,
    'DEMEGLIO': 0,
    'DEMEIS': 0,
    'DEMEL': 0,
    'DEMELL': 0,
    'DEMELLO': 0,
    'DEMELO': 0,
    'DEMENGE': 0,
    'DEMENT': 0,
    'DEMENY': 0,
    'DEMEO': 0,
    'DEMER': 0,
    'DEMERA': 0,
    'DEMERATH': 0,
    'DEMERCHANT': 0,
    'DEMERCURIO': 0,
    'DEMERE': 0,
    'DEMERI': 0,
    'DEMERITT': 0,
    'DEMERITTE': 0,
    'DEMERJIAN': 0,
    'DEMERLY': 0,
    'DEMERRITT': 0,
    'DEMERS': 0,
    'DEMERSE': 0,
    'DEMERSON': 0,
    'DEMERY': 0,
    'DEMES': 0,
    'DEMESA': 0,
    'DEMET': 0,
    'DEMETER': 0,
    'DEMETRA': 1,
    'DEMETRE': 0,
    'DEMETRI': 0,
    'DEMETRIA': 1,
    'DEMETRIADES': 0,
    'DEMETRICE': 1,
    'DEMETRIO': 0,
    'DEMETRIOU': 0,
    'DEMETRIUS': 0.9917355371900826,
    'DEMETRO': 0,
    'DEMETROPOULOS': 0,
    'DEMETROS': 0,
    'DEMETZ': 0,
    'DEMEULE': 0,
    'DEMEULENAERE': 0,
    'DEMEUSE': 0,
    'DEMEY': 0,
    'DEMEYER': 0,
    'DEMEYERE': 0,
    'DEMEZA': 0,
    'DEMI': 0,
    'DEMIAN': 0,
    'DEMIC': 0,
    'DEMICCO': 0,
    'DEMICH': 0,
    'DEMICHAEL': 0,
    'DEMICHELE': 0,
    'DEMICHIEL': 0,
    'DEMICK': 0,
    'DEMIDIO': 0,
    'DEMIDOVICH': 0,
    'DEMIEN': 0,
    'DEMIENTIEFF': 0,
    'DEMIGUEL': 0,
    'DEMIK': 0,
    'DEMILIA': 0,
    'DEMILIO': 0,
    'DEMILL': 0,
    'DEMILLE': 0,
    'DEMILLO': 0,
    'DEMILT': 0,
    'DEMIN': 0,
    'DEMING': 0,
    'DEMINGS': 0,
    'DEMINICO': 0,
    'DEMINK': 0,
    'DEMINO': 0,
    'DEMINT': 0,
    'DEMIR': 0,
    'DEMIRANDA': 0,
    'DEMIRCHYAN': 0,
    'DEMIRCI': 0,
    'DEMIRDJIAN': 0,
    'DEMIRJIAN': 0,
    'DEMIROVIC': 0,
    'DEMIS': 0,
    'DEMISSIE': 0,
    'DEMITA': 0,
    'DEMITRO': 0,
    'DEMKE': 0,
    'DEMKO': 0,
    'DEMKOVICH': 0,
    'DEMKOWICZ': 0,
    'DEMKOWSKI': 0,
    'DEML': 0,
    'DEMLER': 0,
    'DEMLING': 0,
    'DEMLOW': 0,
    'DEMMA': 0,
    'DEMME': 0,
    'DEMMEL': 0,
    'DEMMER': 0,
    'DEMMERLE': 0,
    'DEMMERS': 0,
    'DEMMERT': 0,
    'DEMMIN': 0,
    'DEMMING': 0,
    'DEMMINGS': 0,
    'DEMMITT': 0,
    'DEMMLER': 0,
    'DEMMON': 0,
    'DEMMONS': 0,
    'DEMMY': 0,
    'DEMNY': 0,
    'DEMO': 0,
    'DEMOE': 0,
    'DEMOLA': 0,
    'DEMOLLE': 0,
    'DEMONACO': 0,
    'DEMONBREUN': 0,
    'DEMOND': 0,
    'DEMONE': 0,
    'DEMONEY': 0,
    'DEMONG': 0,
    'DEMONIA': 0,
    'DEMONICO': 0,
    'DEMONS': 0,
    'DEMONT': 0,
    'DEMONTE': 0,
    'DEMONTIGNY': 0,
    'DEMOOR': 0,
    'DEMOPOULOS': 0,
    'DEMORA': 0,
    'DEMORAES': 0,
    'DEMORANVILLE': 0,
    'DEMORE': 0,
    'DEMOREST': 0,
    'DEMORET': 0,
    'DEMORO': 0,
    'DEMORROW': 0,
    'DEMORY': 0,
    'DEMOS': 0,
    'DEMOSKI': 0,
    'DEMOSS': 0,
    'DEMOSTHENE': 0,
    'DEMOSTHENES': 0,
    'DEMOTT': 0,
    'DEMOTTA': 0,
    'DEMOTTE': 0,
    'DEMOTTO': 0,
    'DEMOTTS': 0,
    'DEMOUCHET': 0,
    'DEMOULIN': 0,
    'DEMOURA': 0,
    'DEMOUY': 0,
    'DEMOYA': 0,
    'DEMPEWOLF': 0,
    'DEMPS': 0,
    'DEMPSAY': 0,
    'DEMPSEY': 0,
    'DEMPSKI': 0,
    'DEMPSTER': 0,
    'DEMRO': 0,
    'DEMSEY': 0,
    'DEMSHAR': 0,
    'DEMSKE': 0,
    'DEMSKI': 0,
    'DEMSKO': 0,
    'DEMSKY': 0,
    'DEMSTER': 0,
    'DEMULLING': 0,
    'DEMUNBRUN': 0,
    'DEMUNCK': 0,
    'DEMURO': 0,
    'DEMUS': 0,
    'DEMUSZ': 0,
    'DEMUTH': 0,
    'DEMUYNCK': 0,
    'DEMYAN': 0,
    'DEMYANOVICH': 0,
    'DEMYER': 0,
    'DEMYERS': 0,
    'DEN': 0,
    'DENA': 0.9812667261373774,
    'DENADEL': 0,
    'DENAE': 1,
    'DENAIS': 0,
    'DENAMUR': 0,
    'DENAPOLI': 0,
    'DENARD': 0,
    'DENARDI': 0,
    'DENARDIS': 0,
    'DENARDO': 0,
    'DENARO': 0,
    'DENATALE': 0,
    'DENATO': 0,
    'DENAULT': 0,
    'DENBERG': 0,
    'DENBESTE': 0,
    'DENBESTEN': 0,
    'DENBLEYKER': 0,
    'DENBO': 0,
    'DENBOER': 0,
    'DENBOW': 0,
    'DENBY': 0,
    'DENCE': 0,
    'DENCH': 0,
    'DENCKER': 0,
    'DENCKLAU': 0,
    'DENDER': 0,
    'DENDINGER': 0,
    'DENDLER': 0,
    'DENDRINOS': 0,
    'DENDULK': 0,
    'DENDY': 0,
    'DENE': 0,
    'DENEAL': 0,
    'DENEAU': 0,
    'DENEAULT': 0,
    'DENECKE': 0,
    'DENEEF': 0,
    'DENEEN': 0.8670520231213873,
    'DENEFF': 0,
    'DENEGRE': 0,
    'DENEGRI': 0,
    'DENEHY': 0,
    'DENEKA': 0,
    'DENEKAS': 0,
    'DENEKE': 0,
    'DENELL': 0,
    'DENELSBECK': 0,
    'DENEN': 0,
    'DENENBERG': 0,
    'DENERO': 0,
    'DENES': 0,
    'DENESE': 1,
    'DENESHA': 0,
    'DENET': 0,
    'DENETCLAW': 0,
    'DENETSO': 0,
    'DENETSOSIE': 0,
    'DENETTE': 0,
    'DENEUI': 0,
    'DENEVAN': 0,
    'DENEVE': 0,
    'DENEWETH': 0,
    'DENEY': 0,
    'DENFELD': 0,
    'DENG': 0,
    'DENGATE': 0,
    'DENGEL': 0,
    'DENGER': 0,
    'DENGES': 0,
    'DENGLER': 0,
    'DENHA': 0,
    'DENHAM': 0,
    'DENHARD': 0,
    'DENHARDT': 0,
    'DENHART': 0,
    'DENHARTIGH': 0,
    'DENHARTOG': 0,
    'DENHERDER': 0,
    'DENHOED': 0,
    'DENHOF': 0,
    'DENHOFF': 0,
    'DENHOLLANDER': 0,
    'DENHOLM': 0,
    'DENI': 0,
    'DENICE': 0.9913258983890954,
    'DENICK': 0,
    'DENICOLA': 0,
    'DENICOLO': 0,
    'DENIER': 0,
    'DENIG': 0,
    'DENIGER': 0,
    'DENIGHT': 0,
    'DENIGRIS': 0,
    'DENIHAN': 0,
    'DENIKE': 0,
    'DENINGER': 0,
    'DENINNO': 0,
    'DENINO': 0,
    'DENIO': 0,
    'DENIRO': 0,
    'DENIS': 0.8744534665833854,
    'DENISCO': 0,
    'DENISE': 0.9987893462469734,
    'DENISH': 0,
    'DENISHA': 1,
    'DENISI': 0,
    'DENISON': 0,
    'DENISSE': 1,
    'DENISSEN': 0,
    'DENISTON': 0,
    'DENITA': 1,
    'DENITTO': 0,
    'DENIUS': 0,
    'DENIZ': 0,
    'DENIZARD': 0,
    'DENK': 0,
    'DENKE': 0,
    'DENKER': 0,
    'DENKERS': 0,
    'DENKINGER': 0,
    'DENKINS': 0,
    'DENKLER': 0,
    'DENLER': 0,
    'DENLEY': 0,
    'DENLINGER': 0,
    'DENLY': 0,
    'DENMAN': 0,
    'DENMARK': 0,
    'DENMON': 0,
    'DENN': 0,
    'DENNA': 0.9771986970684039,
    'DENNANY': 0,
    'DENNARD': 0,
    'DENNE': 0,
    'DENNEE': 0,
    'DENNEHY': 0,
    'DENNEN': 0,
    'DENNENY': 0,
    'DENNER': 0,
    'DENNERLEIN': 0,
    'DENNERLINE': 0,
    'DENNERT': 0,
    'DENNERY': 0,
    'DENNES': 0,
    'DENNETT': 0,
    'DENNEWITZ': 0,
    'DENNEY': 0,
    'DENNHARDT': 0,
    'DENNI': 0,
    'DENNICK': 0,
    'DENNIE': 0,
    'DENNIES': 0,
    'DENNIG': 0,
    'DENNIN': 0,
    'DENNING': 0,
    'DENNINGER': 0,
    'DENNINGS': 0,
    'DENNINGTON': 0,
    'DENNIS': 0.9376686454398273,
    'DENNISE': 1,
    'DENNISON': 0,
    'DENNISS': 0,
    'DENNISTON': 0,
    'DENNLER': 0,
    'DENNO': 0,
    'DENNON': 0,
    'DENNY': 0.6307339449541284,
    'DENO': 0,
    'DENOBLE': 0,
    'DENOFA': 0,
    'DENOFRIO': 0,
    'DENOGEAN': 0,
    'DENOIA': 0,
    'DENOMA': 0,
    'DENOME': 0,
    'DENOMIE': 0,
    'DENOMME': 0,
    'DENONCOUR': 0,
    'DENONCOURT': 0,
    'DENOON': 0,
    'DENOOYER': 0,
    'DENOR': 0,
    'DENORA': 0,
    'DENORMANDIE': 0,
    'DENOS': 0,
    'DENOTO': 0,
    'DENOTTER': 0,
    'DENOUDEN': 0,
    'DENOUX': 0,
    'DENOVA': 0,
    'DENOVELLIS': 0,
    'DENOYER': 0,
    'DENSBERGER': 0,
    'DENSE': 0,
    'DENSEL': 0,
    'DENSEN': 0,
    'DENSFORD': 0,
    'DENSING': 0,
    'DENSLEY': 0,
    'DENSLOW': 0,
    'DENSMAN': 0,
    'DENSMORE': 0,
    'DENSON': 0,
    'DENSTEDT': 0,
    'DENT': 0,
    'DENTE': 0,
    'DENTEL': 0,
    'DENTEN': 0,
    'DENTER': 0,
    'DENTI': 0,
    'DENTICE': 0,
    'DENTICI': 0,
    'DENTICO': 0,
    'DENTINGER': 0,
    'DENTINO': 0,
    'DENTLER': 0,
    'DENTLEY': 0,
    'DENTLINGER': 0,
    'DENTON': 0,
    'DENTREMONT': 0,
    'DENTS': 0,
    'DENTY': 0,
    'DENTZ': 0,
    'DENU': 0,
    'DENUCCI': 0,
    'DENUCCIO': 0,
    'DENUE': 0,
    'DENUNE': 0,
    'DENUNZIO': 0,
    'DENURE': 0,
    'DENUYL': 0,
    'DENVER': 0.968783638320775,
    'DENVIR': 0,
    'DENWALT': 0,
    'DENYER': 0,
    'DENYES': 0,
    'DENYS': 0,
    'DENYSE': 0.9615384615384616,
    'DENZ': 0,
    'DENZEL': 0,
    'DENZER': 0,
    'DENZIN': 0,
    'DENZINE': 0,
    'DENZLER': 0,
    'DEO': 0,
    'DEOCA': 0,
    'DEOCAMPO': 0,
    'DEOCHOA': 0,
    'DEODAT': 0,
    'DEOGRACIAS': 0,
    'DEOL': 0,
    'DEOLEO': 0,
    'DEOLIVEIRA': 0,
    'DEON': 0.9615384615384616,
    'DEONARAIN': 0,
    'DEONARINE': 0,
    'DEONNA': 1,
    'DEORIO': 0,
    'DEORNELLAS': 0,
    'DEORTA': 0,
    'DEPA': 0,
    'DEPABLO': 0,
    'DEPACE': 0,
    'DEPADUA': 0,
    'DEPAEPE': 0,
    'DEPAGTER': 0,
    'DEPALMA': 0,
    'DEPALMER': 0,
    'DEPALMO': 0,
    'DEPALO': 0,
    'DEPAMPHILIS': 0,
    'DEPAOLA': 0,
    'DEPAOLI': 0,
    'DEPAOLIS': 0,
    'DEPAOLO': 0,
    'DEPARI': 0,
    'DEPAS': 0,
    'DEPASCALE': 0,
    'DEPASQUA': 0,
    'DEPASQUALE': 0,
    'DEPASS': 0,
    'DEPASSE': 0,
    'DEPATIE': 0,
    'DEPAUL': 0,
    'DEPAULA': 0,
    'DEPAULIS': 0,
    'DEPAULO': 0,
    'DEPAUW': 0,
    'DEPAZ': 0,
    'DEPEDRO': 0,
    'DEPEE': 0,
    'DEPEEL': 0,
    'DEPENA': 0,
    'DEPENBROCK': 0,
    'DEPENNING': 0,
    'DEPERALTA': 0,
    'DEPERI': 0,
    'DEPERIO': 0,
    'DEPERRO': 0,
    'DEPERSIA': 0,
    'DEPERSIS': 0,
    'DEPESA': 0,
    'DEPETRILLO': 0,
    'DEPETRIS': 0,
    'DEPETRO': 0,
    'DEPEW': 0,
    'DEPHILLIPS': 0,
    'DEPIANO': 0,
    'DEPIAZZA': 0,
    'DEPIERO': 0,
    'DEPIERRE': 0,
    'DEPIERRO': 0,
    'DEPIES': 0,
    'DEPIETRO': 0,
    'DEPIETTO': 0,
    'DEPILLO': 0,
    'DEPINA': 0,
    'DEPINET': 0,
    'DEPINHO': 0,
    'DEPINO': 0,
    'DEPINTO': 0,
    'DEPIPPO': 0,
    'DEPIRO': 0,
    'DEPIRRO': 0,
    'DEPKE': 0,
    'DEPNER': 0,
    'DEPOALO': 0,
    'DEPOE': 0,
    'DEPOISTER': 0,
    'DEPOLITO': 0,
    'DEPOLO': 0,
    'DEPONTE': 0,
    'DEPOORTER': 0,
    'DEPORTER': 0,
    'DEPOT': 0,
    'DEPOTO': 0,
    'DEPOY': 0,
    'DEPOYSTER': 0,
    'DEPP': 0,
    'DEPPA': 0,
    'DEPPE': 0,
    'DEPPEN': 0,
    'DEPPER': 0,
    'DEPPERMAN': 0,
    'DEPPERSCHMIDT': 0,
    'DEPPERT': 0,
    'DEPPING': 0,
    'DEPPISCH': 0,
    'DEPPNER': 0,
    'DEPRATO': 0,
    'DEPRATT': 0,
    'DEPRE': 0,
    'DEPREE': 0,
    'DEPREY': 0,
    'DEPREZ': 0,
    'DEPRIEST': 0,
    'DEPRIMA': 0,
    'DEPRIMO': 0,
    'DEPRINCE': 0,
    'DEPRISCO': 0,
    'DEPRIZIO': 0,
    'DEPROFIO': 0,
    'DEPROSPERO': 0,
    'DEPROSPO': 0,
    'DEPROW': 0,
    'DEPTA': 0,
    'DEPTO': 0,
    'DEPTULA': 0,
    'DEPUE': 0,
    'DEPUGH': 0,
    'DEPUTY': 0,
    'DEPUY': 0,
    'DEPUYDT': 0,
    'DEQUAINE': 0,
    'DEQUATTRO': 0,
    'DEQUESADA': 0,
    'DEQUINA': 0,
    'DER': 0,
    'DERA': 0,
    'DERAAD': 0,
    'DERAEDT': 0,
    'DERAGON': 0,
    'DERAIMO': 0,
    'DERAMO': 0,
    'DERAMOS': 0,
    'DERAMUS': 0,
    'DERAN': 0,
    'DERANEK': 0,
    'DERANEY': 0,
    'DERANGER': 0,
    'DERANGO': 0,
    'DERANLEAU': 0,
    'DERAPS': 0,
    'DERAS': 0,
    'DERASMO': 0,
    'DERBER': 0,
    'DERBES': 0,
    'DERBIDGE': 0,
    'DERBIGNY': 0,
    'DERBIN': 0,
    'DERBONNE': 0,
    'DERBY': 0,
    'DERBYSHIRE': 0,
    'DERCK': 0,
    'DERCKS': 0,
    'DERCOLE': 0,
    'DERDA': 0,
    'DERDEN': 0,
    'DERDERIAN': 0,
    'DERDZINSKI': 0,
    'DERE': 0,
    'DEREDITA': 0,
    'DEREE': 0,
    'DEREGO': 0,
    'DEREK': 0.9991079393398752,
    'DEREMER': 0,
    'DEREMIAH': 0,
    'DEREMO': 0,
    'DEREN': 0,
    'DERENBERGER': 0,
    'DERENBURGER': 0,
    'DERENDINGER': 0,
    'DERENGOWSKI': 0,
    'DERENNE': 0,
    'DERENTHAL': 0,
    'DERENZI': 0,
    'DERENZIS': 0,
    'DERENZO': 0,
    'DERENZY': 0,
    'DEREPENTIGNY': 0,
    'DERER': 0,
    'DEREU': 0,
    'DEREUS': 0,
    'DEREZ': 0,
    'DEREZA': 0,
    'DEREZINSKI': 0,
    'DERFLER': 0,
    'DERFLINGER': 0,
    'DERFUS': 0,
    'DERGE': 0,
    'DERHAKE': 0,
    'DERHAM': 0,
    'DERHAMMER': 0,
    'DERHEIM': 0,
    'DERHEIMER': 0,
    'DERI': 0,
    'DERIAN': 0,
    'DERICCO': 0,
    'DERICHSWEILER': 0,
    'DERICK': 0.9865470852017938,
    'DERICKS': 0,
    'DERICKSON': 0,
    'DERICO': 0,
    'DERIDDER': 0,
    'DERIEG': 0,
    'DERIENZO': 0,
    'DERIEUX': 0,
    'DERIFIELD': 0,
    'DERIGGI': 0,
    'DERIGO': 0,
    'DERILUS': 0,
    'DERIN': 0,
    'DERING': 0,
    'DERINGER': 0,
    'DERINGTON': 0,
    'DERIS': 0,
    'DERISE': 0,
    'DERISI': 0,
    'DERISO': 0,
    'DERITA': 0,
    'DERITIS': 0,
    'DERITO': 0,
    'DERITTER': 0,
    'DERIVAL': 0,
    'DERIVERA': 0,
    'DERK': 0,
    'DERKACH': 0,
    'DERKACZ': 0,
    'DERKE': 0,
    'DERKOWSKI': 0,
    'DERKS': 0,
    'DERKSEN': 0,
    'DERLETH': 0,
    'DERMA': 0,
    'DERMAN': 0,
    'DERMER': 0,
    'DERMODY': 0,
    'DERMON': 0,
    'DERMOND': 0,
    'DERMONT': 0,
    'DERMOTT': 0,
    'DERMYER': 0,
    'DERN': 0,
    'DERNBACH': 0,
    'DERNER': 0,
    'DERNIER': 0,
    'DEROBBIO': 0,
    'DEROBERTIS': 0,
    'DEROBERTS': 0,
    'DEROBLES': 0,
    'DEROCCO': 0,
    'DEROCHA': 0,
    'DEROCHE': 0,
    'DEROCHER': 0,
    'DEROCHIE': 0,
    'DEROCK': 0,
    'DEROCKER': 0,
    'DEROECK': 0,
    'DEROGATIS': 0,
    'DEROIN': 0,
    'DEROJAS': 0,
    'DEROLF': 0,
    'DEROMA': 0,
    'DEROME': 0,
    'DERON': 0,
    'DERONDE': 0,
    'DEROO': 0,
    'DEROOS': 0,
    'DEROOY': 0,
    'DEROSA': 0,
    'DEROSAS': 0,
    'DEROSE': 0,
    'DEROSIA': 0,
    'DEROSIER': 0,
    'DEROSIERS': 0,
    'DEROSS': 0,
    'DEROSSETT': 0,
    'DEROSSI': 0,
    'DEROSSO': 0,
    'DEROUCHEY': 0,
    'DEROUCHIE': 0,
    'DEROUEN': 0,
    'DEROUIN': 0,
    'DEROUSELLE': 0,
    'DEROUSSE': 0,
    'DEROUSSEAU': 0,
    'DEROUSSELLE': 0,
    'DEROY': 0,
    'DERR': 0,
    'DERRA': 0,
    'DERRAH': 0,
    'DERREBERRY': 0,
    'DERRENBACHER': 0,
    'DERRER': 0,
    'DERRERA': 0,
    'DERRETT': 0,
    'DERRICK': 0.9680451127819549,
    'DERRICKS': 0,
    'DERRICKSON': 0,
    'DERRICO': 0,
    'DERRICOTT': 0,
    'DERRICOTTE': 0,
    'DERRIG': 0,
    'DERRING': 0,
    'DERRINGER': 0,
    'DERRINGTON': 0,
    'DERRO': 0,
    'DERROUGH': 0,
    'DERROW': 0,
    'DERRY': 0,
    'DERRYBERRY': 0,
    'DERSAM': 0,
    'DERSARKISSIAN': 0,
    'DERSCH': 0,
    'DERSCHEID': 0,
    'DERSE': 0,
    'DERSHAM': 0,
    'DERSHEM': 0,
    'DERSHOWITZ': 0,
    'DERSTINE': 0,
    'DERTEL': 0,
    'DERTHICK': 0,
    'DERTING': 0,
    'DERTINGER': 0,
    'DERTZ': 0,
    'DERU': 0,
    'DERUBEIS': 0,
    'DERUBERTIS': 0,
    'DERUDDER': 0,
    'DERUE': 0,
    'DERUITER': 0,
    'DERUNGS': 0,
    'DERUNTZ': 0,
    'DERUS': 0,
    'DERUSH': 0,
    'DERUSHA': 0,
    'DERUSSO': 0,
    'DERUVO': 0,
    'DERUYTER': 0,
    'DERVIN': 0,
    'DERVISEVIC': 0,
    'DERVISHI': 0,
    'DERVISHIAN': 0,
    'DERWIN': 0,
    'DERY': 0,
    'DERYCKE': 0,
    'DERYKE': 0,
    'DESA': 0,
    'DESABATO': 0,
    'DESADIER': 0,
    'DESAI': 0,
    'DESAIN': 0,
    'DESALES': 0,
    'DESALLE': 0,
    'DESALVATORE': 0,
    'DESALVIO': 0,
    'DESALVO': 0,
    'DESAMOUR': 0,
    'DESAMOURS': 0,
    'DESANCTIS': 0,
    'DESANDO': 0,
    'DESANDRE': 0,
    'DESANDRO': 0,
    'DESANO': 0,
    'DESANTE': 0,
    'DESANTI': 0,
    'DESANTIAGO': 0,
    'DESANTIS': 0,
    'DESANTO': 0,
    'DESANTOS': 0,
    'DESANZO': 0,
    'DESAPIO': 0,
    'DESARDEN': 0,
    'DESARIO': 0,
    'DESARNO': 0,
    'DESARO': 0,
    'DESARRO': 0,
    'DESART': 0,
    'DESATNIK': 0,
    'DESATOFF': 0,
    'DESAULNIER': 0,
    'DESAULNIERS': 0,
    'DESAUSSURE': 0,
    'DESAUTEL': 0,
    'DESAUTELL': 0,
    'DESAUTELS': 0,
    'DESBIEN': 0,
    'DESBIENS': 0,
    'DESCALZO': 0,
    'DESCAMPS': 0,
    'DESCANT': 0,
    'DESCH': 0,
    'DESCHAINE': 0,
    'DESCHAMP': 0,
    'DESCHAMPS': 0,
    'DESCHANE': 0,
    'DESCHEENIE': 0,
    'DESCHENE': 0,
    'DESCHENEAUX': 0,
    'DESCHENES': 0,
    'DESCHEPPER': 0,
    'DESCHER': 0,
    'DESCHLER': 0,
    'DESCHNER': 0,
    'DESCHRYVER': 0,
    'DESCISCIO': 0,
    'DESCOMBES': 0,
    'DESCOTEAU': 0,
    'DESCOTEAUX': 0,
    'DESDUNES': 0,
    'DESELL': 0,
    'DESELLE': 0,
    'DESELMS': 0,
    'DESENA': 0,
    'DESENBERG': 0,
    'DESENS': 0,
    'DESENSI': 0,
    'DESERIO': 0,
    'DESERSA': 0,
    'DESEVE': 0,
    'DESFORGES': 0,
    'DESFOSSES': 0,
    'DESGRANGE': 0,
    'DESGRANGES': 0,
    'DESHA': 0,
    'DESHAIES': 0,
    'DESHAIS': 0,
    'DESHANE': 0,
    'DESHANO': 0,
    'DESHARNAIS': 0,
    'DESHAW': 0,
    'DESHAWN': 1,
    'DESHAY': 0,
    'DESHAYES': 0,
    'DESHAZER': 0,
    'DESHAZIER': 0,
    'DESHAZO': 0,
    'DESHAZOR': 0,
    'DESHER': 0,
    'DESHERLIA': 0,
    'DESHETLER': 0,
    'DESHIELD': 0,
    'DESHIELDS': 0,
    'DESHLER': 0,
    'DESHMUKH': 0,
    'DESHNER': 0,
    'DESHOMMES': 0,
    'DESHON': 0,
    'DESHONE': 0,
    'DESHONG': 0,
    'DESHOTEL': 0,
    'DESHOTELS': 0,
    'DESHPANDE': 0,
    'DESIANO': 0,
    'DESIATO': 0,
    'DESIDERATO': 0,
    'DESIDERIO': 0,
    'DESIENA': 0,
    'DESILET': 0,
    'DESILETS': 0,
    'DESILVA': 0,
    'DESILVEY': 0,
    'DESILVIO': 0,
    'DESIMAS': 0,
    'DESIMINI': 0,
    'DESIMON': 0,
    'DESIMONE': 0,
    'DESIN': 0,
    'DESING': 0,
    'DESINOR': 0,
    'DESIO': 0,
    'DESIR': 0,
    'DESIRAE': 1,
    'DESIRE': 0.9132420091324202,
    'DESIREE': 1,
    'DESISTO': 0,
    'DESJARDIN': 0,
    'DESJARDINS': 0,
    'DESJARLAIS': 0,
    'DESJEAN': 0,
    'DESKA': 0,
    'DESKIN': 0,
    'DESKINS': 0,
    'DESKO': 0,
    'DESLANDES': 0,
    'DESLATTE': 0,
    'DESLAURIER': 0,
    'DESLAURIERS': 0,
    'DESLER': 0,
    'DESLOGE': 0,
    'DESLOOVER': 0,
    'DESMANGLES': 0,
    'DESMARAIS': 0,
    'DESMARTEAU': 0,
    'DESMEDT': 0,
    'DESMET': 0,
    'DESMIDT': 0,
    'DESMIT': 0,
    'DESMITH': 0,
    'DESMOND': 0.8393285371702638,
    'DESMORE': 0,
    'DESNOYER': 0,
    'DESNOYERS': 0,
    'DESO': 0,
    'DESOCIO': 0,
    'DESOLA': 0,
    'DESOMER': 0,
    'DESOMMA': 0,
    'DESON': 0,
    'DESONIA': 0,
    'DESOPO': 0,
    'DESORBO': 0,
    'DESORCY': 0,
    'DESORMEAU': 0,
    'DESORMEAUX': 0,
    'DESORMIER': 0,
    'DESOSA': 0,
    'DESOTA': 0,
    'DESOTEL': 0,
    'DESOTELL': 0,
    'DESOTELLE': 0,
    'DESOTO': 0,
    'DESOURDY': 0,
    'DESOUSA': 0,
    'DESOUZA': 0,
    'DESPAIN': 0,
    'DESPARD': 0,
    'DESPER': 0,
    'DESPINA': 1,
    'DESPINS': 0,
    'DESPIRITO': 0,
    'DESPLAINES': 0,
    'DESPLINTER': 0,
    'DESPORTE': 0,
    'DESPOSITO': 0,
    'DESPOT': 0,
    'DESPRES': 0,
    'DESPREZ': 0,
    'DESRAVINES': 0,
    'DESROCHE': 0,
    'DESROCHER': 0,
    'DESROCHERS': 0,
    'DESROCHES': 0,
    'DESROSIER': 0,
    'DESROSIERS': 0,
    'DESRUISSEAUX': 0,
    'DESS': 0,
    'DESSAINT': 0,
    'DESSALINES': 0,
    'DESSART': 0,
    'DESSAU': 0,
    'DESSAUER': 0,
    'DESSECKER': 0,
    'DESSEL': 0,
    'DESSELIE': 0,
    'DESSELLE': 0,
    'DESSELLES': 0,
    'DESSELLIER': 0,
    'DESSER': 0,
    'DESSERT': 0,
    'DESSIE': 1,
    'DESSIN': 0,
    'DESSLER': 0,
    'DESSNER': 0,
    'DESSO': 0,
    'DESSOURCES': 0,
    'DESSOYE': 0,
    'DEST': 0,
    'DESTA': 0,
    'DESTASIO': 0,
    'DESTEFANI': 0,
    'DESTEFANIS': 0,
    'DESTEFANO': 0,
    'DESTEPHANO': 0,
    'DESTER': 0,
    'DESTERLE': 0,
    'DESTIN': 0,
    'DESTINE': 0,
    'DESTINO': 0,
    'DESTINY': 1,
    'DESTITO': 0,
    'DESTRA': 0,
    'DESTRAMPE': 0,
    'DESTREE': 0,
    'DESTREMPS': 0,
    'DESTRO': 0,
    'DESUE': 0,
    'DESUTTER': 0,
    'DESVARIEUX': 0,
    'DESVIGNES': 0,
    'DESWOOD': 0,
    'DESY': 0,
    'DETAMORE': 0,
    'DETAR': 0,
    'DETCHON': 0,
    'DETEMPLE': 0,
    'DETER': 0,
    'DETERDING': 0,
    'DETERING': 0,
    'DETERMAN': 0,
    'DETERMANN': 0,
    'DETERRA': 0,
    'DETERS': 0,
    'DETERT': 0,
    'DETERVILLE': 0,
    'DETGEN': 0,
    'DETH': 0,
    'DETHERAGE': 0,
    'DETHEROW': 0,
    'DETHLEFS': 0,
    'DETHLEFSEN': 0,
    'DETHLOFF': 0,
    'DETHOMAS': 0,
    'DETHROW': 0,
    'DETIEGE': 0,
    'DETIENNE': 0,
    'DETILLIER': 0,
    'DETILLION': 0,
    'DETIVEAUX': 0,
    'DETJEN': 0,
    'DETKEN': 0,
    'DETLAFF': 0,
    'DETLEFS': 0,
    'DETLEFSEN': 0,
    'DETLING': 0,
    'DETLOFF': 0,
    'DETLOR': 0,
    'DETMAN': 0,
    'DETMAR': 0,
    'DETMER': 0,
    'DETMERS': 0,
    'DETOMA': 0,
    'DETOMASI': 0,
    'DETOMASO': 0,
    'DETOMMASO': 0,
    'DETORA': 0,
    'DETORE': 0,
    'DETORO': 0,
    'DETORRES': 0,
    'DETOUR': 0,
    'DETRA': 0.9708737864077669,
    'DETRAGLIA': 0,
    'DETRANO': 0,
    'DETRAY': 0,
    'DETRAZ': 0,
    'DETRES': 0,
    'DETREVILLE': 0,
    'DETRICH': 0,
    'DETRICK': 0,
    'DETRIE': 0,
    'DETRING': 0,
    'DETRINIDAD': 0,
    'DETRO': 0,
    'DETROLIO': 0,
    'DETROW': 0,
    'DETROY': 0,
    'DETSCH': 0,
    'DETTBARN': 0,
    'DETTE': 0,
    'DETTEN': 0,
    'DETTER': 0,
    'DETTERLINE': 0,
    'DETTERMAN': 0,
    'DETTING': 0,
    'DETTINGER': 0,
    'DETTLAFF': 0,
    'DETTLE': 0,
    'DETTLING': 0,
    'DETTLINGER': 0,
    'DETTLOFF': 0,
    'DETTMAN': 0,
    'DETTMANN': 0,
    'DETTMAR': 0,
    'DETTMER': 0,
    'DETTMERING': 0,
    'DETTMERS': 0,
    'DETTOR': 0,
    'DETTORE': 0,
    'DETTORRE': 0,
    'DETTRA': 0,
    'DETTREY': 0,
    'DETTWEILER': 0,
    'DETTWILER': 0,
    'DETTWILLER': 0,
    'DETTY': 0,
    'DETULLIO': 0,
    'DETURK': 0,
    'DETURRIS': 0,
    'DETWEILER': 0,
    'DETWILER': 0,
    'DETWILLER': 0,
    'DETZ': 0,
    'DETZEL': 0,
    'DETZLER': 0,
    'DEUBEL': 0,
    'DEUBER': 0,
    'DEUBLE': 0,
    'DEUBLER': 0,
    'DEUBNER': 0,
    'DEUCHAR': 0,
    'DEUCHER': 0,
    'DEUEL': 0,
    'DEUELL': 0,
    'DEUERLING': 0,
    'DEULEY': 0,
    'DEUPREE': 0,
    'DEUR': 0,
    'DEURLOO': 0,
    'DEUS': 0,
    'DEUSCHLE': 0,
    'DEUSENBERRY': 0,
    'DEUSER': 0,
    'DEUSO': 0,
    'DEUSTER': 0,
    'DEUTCH': 0,
    'DEUTCHMAN': 0,
    'DEUTER': 0,
    'DEUTH': 0,
    'DEUTMEYER': 0,
    'DEUTSCH': 0,
    'DEUTSCHER': 0,
    'DEUTSCHLANDER': 0,
    'DEUTSCHMAN': 0,
    'DEUTSCHMANN': 0,
    'DEUTZ': 0,
    'DEV': 0,
    'DEVA': 0,
    'DEVAL': 0,
    'DEVALCOURT': 0,
    'DEVALERIO': 0,
    'DEVALK': 0,
    'DEVALL': 0,
    'DEVALLE': 0,
    'DEVAN': 0,
    'DEVANCE': 0,
    'DEVANE': 0,
    'DEVANEY': 0,
    'DEVANNA': 0,
    'DEVANNEY': 0,
    'DEVANTIER': 0,
    'DEVANY': 0,
    'DEVARAJAN': 0,
    'DEVARGAS': 0,
    'DEVARNEY': 0,
    'DEVARONA': 0,
    'DEVARY': 0,
    'DEVASHER': 0,
    'DEVASIA': 0,
    'DEVASIER': 0,
    'DEVASTO': 0,
    'DEVAUGHN': 0,
    'DEVAUL': 0,
    'DEVAULT': 0,
    'DEVAUX': 0,
    'DEVAY': 0,
    'DEVEAU': 0,
    'DEVEAUX': 0,
    'DEVECCHIO': 0,
    'DEVECCHIS': 0,
    'DEVEE': 0,
    'DEVEER': 0,
    'DEVEGA': 0,
    'DEVEL': 0,
    'DEVELASCO': 0,
    'DEVELDER': 0,
    'DEVELLIS': 0,
    'DEVENCENZI': 0,
    'DEVENDORF': 0,
    'DEVENECIA': 0,
    'DEVENEY': 0,
    'DEVENING': 0,
    'DEVENISH': 0,
    'DEVENNEY': 0,
    'DEVENNY': 0,
    'DEVENPORT': 0,
    'DEVENS': 0,
    'DEVENUTO': 0,
    'DEVENY': 0,
    'DEVER': 0,
    'DEVERA': 0,
    'DEVERAUX': 0,
    'DEVERE': 0,
    'DEVEREAUX': 0,
    'DEVERELL': 0,
    'DEVEREUX': 0,
    'DEVERGER': 0,
    'DEVERICK': 0,
    'DEVERICKS': 0,
    'DEVERMAN': 0,
    'DEVERNA': 0,
    'DEVERNEY': 0,
    'DEVERO': 0,
    'DEVERS': 0,
    'DEVERTER': 0,
    'DEVERTEUIL': 0,
    'DEVERY': 0,
    'DEVEY': 0,
    'DEVEYRA': 0,
    'DEVEZIN': 0,
    'DEVI': 0,
    'DEVIA': 0,
    'DEVIC': 0,
    'DEVICENTE': 0,
    'DEVICH': 0,
    'DEVICK': 0,
    'DEVICO': 0,
    'DEVIDO': 0,
    'DEVIER': 0,
    'DEVIEW': 0,
    'DEVILBISS': 0,
    'DEVILLA': 0,
    'DEVILLE': 0,
    'DEVILLERS': 0,
    'DEVILLEZ': 0,
    'DEVILLIER': 0,
    'DEVILLIERS': 0,
    'DEVIN': 0.9843125192248539,
    'DEVINCENT': 0,
    'DEVINCENTIS': 0,
    'DEVINCENZI': 0,
    'DEVINCENZO': 0,
    'DEVINE': 0,
    'DEVINEY': 0,
    'DEVINNEY': 0,
    'DEVINNY': 0,
    'DEVINO': 0,
    'DEVINS': 0,
    'DEVIRGILIO': 0,
    'DEVIS': 0,
    'DEVISH': 0,
    'DEVISSER': 0,
    'DEVITA': 0,
    'DEVITIS': 0,
    'DEVITO': 0,
    'DEVITT': 0,
    'DEVITTO': 0,
    'DEVIVO': 0,
    'DEVLAEMINCK': 0,
    'DEVLIEGER': 0,
    'DEVLIN': 0,
    'DEVNEY': 0,
    'DEVOE': 0,
    'DEVOGEL': 0,
    'DEVOID': 0,
    'DEVOL': 0,
    'DEVOLD': 0,
    'DEVOLDER': 0,
    'DEVOLL': 0,
    'DEVOLLD': 0,
    'DEVON': 0.9887005649717514,
    'DEVONA': 0.9756097560975611,
    'DEVONE': 0,
    'DEVONISH': 0,
    'DEVONSHIRE': 0,
    'DEVOOGD': 0,
    'DEVOOGHT': 0,
    'DEVOR': 0,
    'DEVORA': 0.8368200836820083,
    'DEVORAH': 1,
    'DEVORAK': 0,
    'DEVORCE': 0,
    'DEVORE': 0,
    'DEVORSS': 0,
    'DEVOS': 0,
    'DEVOSE': 0,
    'DEVOSS': 0,
    'DEVOST': 0,
    'DEVOTI': 0,
    'DEVOTIE': 0,
    'DEVOTO': 0,
    'DEVOUS': 0,
    'DEVOY': 0,
    'DEVREE': 0,
    'DEVRIENDT': 0,
    'DEVRIES': 0,
    'DEVRIEZE': 0,
    'DEVROY': 0,
    'DEVUONO': 0,
    'DEVUYST': 0,
    'DEW': 0,
    'DEWAAL': 0,
    'DEWAARD': 0,
    'DEWAELE': 0,
    'DEWALD': 0,
    'DEWALL': 0,
    'DEWALT': 0,
    'DEWAN': 0,
    'DEWANE': 0,
    'DEWAR': 0,
    'DEWARD': 0,
    'DEWARE': 0,
    'DEWART': 0,
    'DEWATER': 0,
    'DEWATERS': 0,
    'DEWAYNE': 1,
    'DEWBERRY': 0,
    'DEWBRE': 0,
    'DEWDNEY': 0,
    'DEWEASE': 0,
    'DEWEBER': 0,
    'DEWEERD': 0,
    'DEWEERDT': 0,
    'DEWEES': 0,
    'DEWEESE': 0,
    'DEWEEVER': 0,
    'DEWEIN': 0,
    'DEWELL': 0,
    'DEWERFF': 0,
    'DEWERT': 0,
    'DEWES': 0,
    'DEWESE': 0,
    'DEWESTER': 0,
    'DEWET': 0,
    'DEWETT': 0,
    'DEWEY': 0.8360596146855689,
    'DEWHIRST': 0,
    'DEWHITT': 0,
    'DEWHURST': 0,
    'DEWICK': 0,
    'DEWIG': 0,
    'DEWILD': 0,
    'DEWILDE': 0,
    'DEWILDT': 0,
    'DEWIND': 0,
    'DEWINDT': 0,
    'DEWINE': 0,
    'DEWING': 0,
    'DEWINTER': 0,
    'DEWIRE': 0,
    'DEWISPELAERE': 0,
    'DEWIT': 0,
    'DEWITT': 0.38885288399222295,
    'DEWITTE': 0,
    'DEWITZ': 0,
    'DEWOLF': 0,
    'DEWOLFE': 0,
    'DEWOODY': 0,
    'DEWRELL': 0,
    'DEWS': 0,
    'DEWSNAP': 0,
    'DEWSNUP': 0,
    'DEWULF': 0,
    'DEWYEA': 0,
    'DEWYER': 0,
    'DEWYSE': 0,
    'DEXHEIMER': 0,
    'DEXTER': 0.8543531326281529,
    'DEXTRADEUR': 0,
    'DEXTRAZE': 0,
    'DEY': 0,
    'DEYA': 0,
    'DEYAMPERT': 0,
    'DEYARMIN': 0,
    'DEYARMOND': 0,
    'DEYE': 0,
    'DEYERLE': 0,
    'DEYETTE': 0,
    'DEYHLE': 0,
    'DEYLE': 0,
    'DEYLING': 0,
    'DEYNES': 0,
    'DEYO': 0,
    'DEYOE': 0,
    'DEYONG': 0,
    'DEYONKER': 0,
    'DEYOUNG': 0,
    'DEYSHER': 0,
    'DEYTON': 0,
    'DEZA': 0,
    'DEZAN': 0,
    'DEZARN': 0,
    'DEZAYAS': 0,
    'DEZEE': 0,
    'DEZEEUW': 0,
    'DEZELAN': 0,
    'DEZELL': 0,
    'DEZENDORF': 0,
    'DEZENZO': 0,
    'DEZERN': 0,
    'DEZIEL': 0,
    'DEZIO': 0,
    'DEZORT': 0,
    'DEZORZI': 0,
    'DEZOTELL': 0,
    'DEZSO': 0,
    'DEZURIK': 0,
    'DEZWAAN': 0,
    'DEZWARTE': 0,
    'DHAENE': 0,
    'DHAENENS': 0,
    'DHAITI': 0,
    'DHALIWAL': 0,
    'DHAM': 0,
    'DHAMI': 0,
    'DHANANI': 0,
    'DHANDA': 0,
    'DHANJAL': 0,
    'DHANOA': 0,
    'DHANOTA': 0,
    'DHANRAJ': 0,
    'DHAR': 0,
    'DHARIA': 0,
    'DHATT': 0,
    'DHAWAN': 0,
    'DHEEL': 0,
    'DHEIN': 0,
    'DHESI': 0,
    'DHILLON': 0,
    'DHIMAN': 0,
    'DHINDSA': 0,
    'DHINGRA': 0,
    'DHIR': 0,
    'DHOLAKIA': 0,
    'DHOM': 0,
    'DHONDT': 0,
    'DHOOGE': 0,
    'DHOOGHE': 0,
    'DHUYVETTER': 0,
    'DI': 0,
    'DIA': 0.7936507936507936,
    'DIAB': 0,
    'DIABATE': 0,
    'DIABO': 0,
    'DIABY': 0,
    'DIACHENKO': 0,
    'DIACO': 0,
    'DIAFERIO': 0,
    'DIAGNE': 0,
    'DIAGO': 0,
    'DIAGOSTINO': 0,
    'DIAH': 0,
    'DIAK': 0,
    'DIAKITE': 0,
    'DIAKOS': 0,
    'DIAL': 0,
    'DIALLO': 0,
    'DIALS': 0,
    'DIAMANT': 0,
    'DIAMANTE': 0,
    'DIAMANTI': 0,
    'DIAMANTIS': 0,
    'DIAMANTOPOULOS': 0,
    'DIAMBRA': 0,
    'DIAMELIO': 0,
    'DIAMENT': 0,
    'DIAMICO': 0,
    'DIAMON': 0,
    'DIAMOND': 0.20554984583761562,
    'DIAN': 0.9732360097323601,
    'DIANA': 0.9953917050691244,
    'DIANDA': 0,
    'DIANDREA': 0,
    'DIANE': 0.9997215260373155,
    'DIANGELD': 0,
    'DIANGELIS': 0,
    'DIANGELO': 0,
    'DIANI': 0,
    'DIANN': 1,
    'DIANNA': 0.9966777408637875,
    'DIANNE': 1,
    'DIANO': 0,
    'DIANTONIO': 0,
    'DIAO': 0,
    'DIARRA': 0,
    'DIARTE': 0,
    'DIAS': 0,
    'DIASIO': 0,
    'DIASPARRA': 0,
    'DIAW': 0,
    'DIAWARA': 0,
    'DIAZ': 0,
    'DIAZBARRIGA': 0,
    'DIAZCRUZ': 0,
    'DIAZDELEON': 0,
    'DIAZDIAZ': 0,
    'DIAZGARCIA': 0,
    'DIAZGONZALEZ': 0,
    'DIAZGRANADOS': 0,
    'DIAZHERNANDEZ': 0,
    'DIAZLOPEZ': 0,
    'DIAZMARTINEZ': 0,
    'DIAZPEREZ': 0,
    'DIAZRAMIREZ': 0,
    'DIAZRODRIGUEZ': 0,
    'DIB': 0,
    'DIBACCO': 0,
    'DIBARI': 0,
    'DIBARTOLO': 0,
    'DIBARTOLOMEO': 0,
    'DIBATTISTA': 0,
    'DIBB': 0,
    'DIBBELL': 0,
    'DIBBEN': 0,
    'DIBBERN': 0,
    'DIBBLE': 0,
    'DIBBLEE': 0,
    'DIBBLES': 0,
    'DIBBS': 0,
    'DIBELL': 0,
    'DIBELLA': 0,
    'DIBELLO': 0,
    'DIBENE': 0,
    'DIBENEDETTO': 0,
    'DIBENEDITTO': 0,
    'DIBERARDINO': 0,
    'DIBERNARDO': 0,
    'DIBERT': 0,
    'DIBETTA': 0,
    'DIBIANCA': 0,
    'DIBIANCO': 0,
    'DIBIASE': 0,
    'DIBIASI': 0,
    'DIBIASIO': 0,
    'DIBIASO': 0,
    'DIBISCEGLIE': 0,
    'DIBITETTO': 0,
    'DIBLASI': 0,
    'DIBLASIO': 0,
    'DIBLE': 0,
    'DIBLER': 0,
    'DIBLEY': 0,
    'DIBLING': 0,
    'DIBONA': 0,
    'DIBONAVENTURA': 0,
    'DIBONO': 0,
    'DIBRELL': 0,
    'DIBUCCI': 0,
    'DIBUONO': 0,
    'DICAMILLO': 0,
    'DICAMPLI': 0,
    'DICANDIA': 0,
    'DICANIO': 0,
    'DICAPO': 0,
    'DICAPRIO': 0,
    'DICAPUA': 0,
    'DICARA': 0,
    'DICARLANTONIO': 0,
    'DICARLO': 0,
    'DICARO': 0,
    'DICASTRO': 0,
    'DICATALDO': 0,
    'DICE': 0,
    'DICECCA': 0,
    'DICECCO': 0,
    'DICELLO': 0,
    'DICENSO': 0,
    'DICENZO': 0,
    'DICERBO': 0,
    'DICESARE': 0,
    'DICEY': 0,
    'DICH': 0,
    'DICHARD': 0,
    'DICHARRY': 0,
    'DICHIARA': 0,
    'DICHIARO': 0,
    'DICHOSO': 0,
    'DICHRISTINA': 0,
    'DICHTER': 0,
    'DICIACCIO': 0,
    'DICIANNI': 0,
    'DICICCIO': 0,
    'DICICCO': 0,
    'DICIERO': 0,
    'DICILLO': 0,
    'DICINTIO': 0,
    'DICIOCCIO': 0,
    'DICK': 0.5253940455341506,
    'DICKAMORE': 0,
    'DICKARD': 0,
    'DICKASON': 0,
    'DICKAU': 0,
    'DICKE': 0,
    'DICKEL': 0,
    'DICKELMAN': 0,
    'DICKEN': 0,
    'DICKENS': 0,
    'DICKENSHEETS': 0,
    'DICKENSON': 0,
    'DICKER': 0,
    'DICKERHOFF': 0,
    'DICKERHOOF': 0,
    'DICKERMAN': 0,
    'DICKERSON': 0,
    'DICKERT': 0,
    'DICKES': 0,
    'DICKESON': 0,
    'DICKESS': 0,
    'DICKEY': 0,
    'DICKHAUS': 0,
    'DICKHAUSEN': 0,
    'DICKHAUT': 0,
    'DICKHERBER': 0,
    'DICKHOFF': 0,
    'DICKHUT': 0,
    'DICKIE': 0,
    'DICKINS': 0,
    'DICKINSON': 0,
    'DICKISON': 0,
    'DICKLER': 0,
    'DICKMAN': 0,
    'DICKMANN': 0,
    'DICKMEYER': 0,
    'DICKNEITE': 0,
    'DICKOVER': 0,
    'DICKOW': 0,
    'DICKRELL': 0,
    'DICKS': 0,
    'DICKSON': 0,
    'DICKSTEIN': 0,
    'DICKY': 0,
    'DICLAUDIO': 0,
    'DICLEMENTE': 0,
    'DICLEMENTI': 0,
    'DICOB': 0,
    'DICOCCO': 0,
    'DICOCHEA': 0,
    'DICOLA': 0,
    'DICONZA': 0,
    'DICORCIA': 0,
    'DICORPO': 0,
    'DICOSIMO': 0,
    'DICOSMO': 0,
    'DICOSOLA': 0,
    'DICOSTANZO': 0,
    'DICRESCENZO': 0,
    'DICRISTINA': 0,
    'DICRISTO': 0,
    'DICRISTOFANO': 0,
    'DICRISTOFARO': 0,
    'DICROCE': 0,
    'DICUS': 0,
    'DIDARIO': 0,
    'DIDAS': 0,
    'DIDATO': 0,
    'DIDAWICK': 0,
    'DIDAY': 0,
    'DIDDEN': 0,
    'DIDDLE': 0,
    'DIDELOT': 0,
    'DIDENKO': 0,
    'DIDERICKSEN': 0,
    'DIDERRICH': 0,
    'DIDIA': 0,
    'DIDIANO': 0,
    'DIDIEGO': 0,
    'DIDIER': 0,
    'DIDIO': 0,
    'DIDION': 0,
    'DIDLAKE': 0,
    'DIDOMENICO': 0,
    'DIDOMIZIO': 0,
    'DIDONATO': 0,
    'DIDONNA': 0,
    'DIDRICKSON': 0,
    'DIDRIKSEN': 0,
    'DIDUCH': 0,
    'DIDWAY': 0,
    'DIDYK': 0,
    'DIDYOUNG': 0,
    'DIE': 0,
    'DIEBALL': 0,
    'DIEBEL': 0,
    'DIEBERT': 0,
    'DIEBOLD': 0,
    'DIEBOLT': 0,
    'DIEC': 0,
    'DIECIDUE': 0,
    'DIECK': 0,
    'DIECKHAUS': 0,
    'DIECKHOFF': 0,
    'DIECKMAN': 0,
    'DIECKMANN': 0,
    'DIECKOW': 0,
    'DIEDE': 0,
    'DIEDERICH': 0,
    'DIEDERICHS': 0,
    'DIEDIKER': 0,
    'DIEDRA': 1,
    'DIEDRE': 1,
    'DIEDRICH': 0,
    'DIEDRICHS': 0,
    'DIEDRICHSEN': 0,
    'DIEDRICK': 0,
    'DIEFENBACH': 0,
    'DIEFENBACHER': 0,
    'DIEFENDERFER': 0,
    'DIEFENDORF': 0,
    'DIEFENTHALER': 0,
    'DIEFFENBACH': 0,
    'DIEFFENBACHER': 0,
    'DIEFFENDERFER': 0,
    'DIEGEL': 0,
    'DIEGELMAN': 0,
    'DIEGIDIO': 0,
    'DIEGO': 0.8849557522123894,
    'DIEGUEZ': 0,
    'DIEHL': 0,
    'DIEHLMAN': 0,
    'DIEHM': 0,
    'DIEHN': 0,
    'DIEHR': 0,
    'DIEKEMA': 0,
    'DIEKEMPER': 0,
    'DIEKEN': 0,
    'DIEKER': 0,
    'DIEKEVERS': 0,
    'DIEKHOFF': 0,
    'DIEKMAN': 0,
    'DIEKMANN': 0,
    'DIEL': 0,
    'DIELEMAN': 0,
    'DIELI': 0,
    'DIELIA': 0,
    'DIELMAN': 0,
    'DIELMANN': 0,
    'DIELS': 0,
    'DIEM': 0,
    'DIEMAND': 0,
    'DIEMEL': 0,
    'DIEMER': 0,
    'DIEMERT': 0,
    'DIEMIDIO': 0,
    'DIEMOND': 0,
    'DIEN': 0,
    'DIENER': 0,
    'DIENES': 0,
    'DIENG': 0,
    'DIENGER': 0,
    'DIENHART': 0,
    'DIENNER': 0,
    'DIENNO': 0,
    'DIENST': 0,
    'DIENSTAG': 0,
    'DIEP': 0,
    'DIEPENBROCK': 0,
    'DIEPENHORST': 0,
    'DIEPPA': 0,
    'DIER': 0,
    'DIERBERGER': 0,
    'DIERCKS': 0,
    'DIERDORF': 0,
    'DIERDORFF': 0,
    'DIERDRE': 1,
    'DIERICH': 0,
    'DIERICKX': 0,
    'DIERINGER': 0,
    'DIERKEN': 0,
    'DIERKER': 0,
    'DIERKES': 0,
    'DIERKHISING': 0,
    'DIERKING': 0,
    'DIERKS': 0,
    'DIERKSEN': 0,
    'DIERLAM': 0,
    'DIEROLF': 0,
    'DIERS': 0,
    'DIERSCHKE': 0,
    'DIERSEN': 0,
    'DIERSING': 0,
    'DIES': 0,
    'DIESBURG': 0,
    'DIESCH': 0,
    'DIESEL': 0,
    'DIESEN': 0,
    'DIESER': 0,
    'DIESING': 0,
    'DIESS': 0,
    'DIESSNER': 0,
    'DIESSO': 0,
    'DIESTEL': 0,
    'DIESTELKAMP': 0,
    'DIESTLER': 0,
    'DIETCH': 0,
    'DIETEL': 0,
    'DIETEMAN': 0,
    'DIETER': 0,
    'DIETERICH': 0,
    'DIETERIE': 0,
    'DIETERLE': 0,
    'DIETERLY': 0,
    'DIETERMAN': 0,
    'DIETERS': 0,
    'DIETERT': 0,
    'DIETHELM': 0,
    'DIETHORN': 0,
    'DIETIKER': 0,
    'DIETL': 0,
    'DIETLE': 0,
    'DIETLEIN': 0,
    'DIETLIN': 0,
    'DIETMAN': 0,
    'DIETMEIER': 0,
    'DIETMEYER': 0,
    'DIETRICH': 0,
    'DIETRICK': 0,
    'DIETSCH': 0,
    'DIETSCHE': 0,
    'DIETTE': 0,
    'DIETTER': 0,
    'DIETTERICH': 0,
    'DIETTERICK': 0,
    'DIETZ': 0,
    'DIETZE': 0,
    'DIETZEL': 0,
    'DIETZEN': 0,
    'DIETZENBACH': 0,
    'DIETZLER': 0,
    'DIETZMAN': 0,
    'DIEU': 0,
    'DIEUDONNE': 0,
    'DIEUGENIO': 0,
    'DIEUJUSTE': 0,
    'DIEVENDORF': 0,
    'DIEWALD': 0,
    'DIEZ': 0,
    'DIEZEL': 0,
    'DIFABIO': 0,
    'DIFABRIZIO': 0,
    'DIFALCO': 0,
    'DIFANI': 0,
    'DIFATTA': 0,
    'DIFAZIO': 0,
    'DIFEBO': 0,
    'DIFEDE': 0,
    'DIFEDERICO': 0,
    'DIFELICE': 0,
    'DIFEO': 0,
    'DIFERDINANDO': 0,
    'DIFFEE': 0,
    'DIFFENBAUGH': 0,
    'DIFFENDAL': 0,
    'DIFFENDERFER': 0,
    'DIFFER': 0,
    'DIFFERDING': 0,
    'DIFFEY': 0,
    'DIFFIE': 0,
    'DIFFIN': 0,
    'DIFFLEY': 0,
    'DIFIGLIA': 0,
    'DIFILIPPI': 0,
    'DIFILIPPO': 0,
    'DIFIORE': 0,
    'DIFLORIO': 0,
    'DIFO': 0,
    'DIFOLCO': 0,
    'DIFONZO': 0,
    'DIFORTE': 0,
    'DIFRANCESCA': 0,
    'DIFRANCESCO': 0,
    'DIFRANCISCO': 0,
    'DIFRANCO': 0,
    'DIFRANK': 0,
    'DIFRONZO': 0,
    'DIFRUSCIO': 0,
    'DIFULVIO': 0,
    'DIFUNTORUM': 0,
    'DIFUSCO': 0,
    'DIGAETANO': 0,
    'DIGAN': 0,
    'DIGANGI': 0,
    'DIGATI': 0,
    'DIGBY': 0,
    'DIGEL': 0,
    'DIGENNARO': 0,
    'DIGENOVA': 0,
    'DIGEORGE': 0,
    'DIGEROLAMO': 0,
    'DIGERONIMO': 0,
    'DIGESARE': 0,
    'DIGESU': 0,
    'DIGGES': 0,
    'DIGGINS': 0,
    'DIGGLE': 0,
    'DIGGLES': 0,
    'DIGGS': 0,
    'DIGH': 0,
    'DIGHERO': 0,
    'DIGHT': 0,
    'DIGHTON': 0,
    'DIGIACINTO': 0,
    'DIGIACOBBE': 0,
    'DIGIACOMO': 0,
    'DIGIALLONARDO': 0,
    'DIGIAMBATTISTA': 0,
    'DIGIAMMARINO': 0,
    'DIGIANDOMENICO': 0,
    'DIGIDIA': 0,
    'DIGIGLIO': 0,
    'DIGILIO': 0,
    'DIGIOIA': 0,
    'DIGIORGI': 0,
    'DIGIORGIO': 0,
    'DIGIOVANNA': 0,
    'DIGIOVANNI': 0,
    'DIGIOVINE': 0,
    'DIGIROLAMO': 0,
    'DIGIULIO': 0,
    'DIGIUSEPPE': 0,
    'DIGIUSTO': 0,
    'DIGLIO': 0,
    'DIGLORIA': 0,
    'DIGMAN': 0,
    'DIGMANN': 0,
    'DIGNA': 1,
    'DIGNAM': 0,
    'DIGNAN': 0,
    'DIGNARD': 0,
    'DIGNAZIO': 0,
    'DIGNEY': 0,
    'DIGRANDE': 0,
    'DIGRAZIA': 0,
    'DIGRAZIO': 0,
    'DIGRE': 0,
    'DIGREGORIO': 0,
    'DIGREGORY': 0,
    'DIGRIGOLI': 0,
    'DIGSBY': 0,
    'DIGUARDI': 0,
    'DIGUGLIELMO': 0,
    'DIGUILIO': 0,
    'DIGUISEPPE': 0,
    'DIGUISEPPI': 0,
    'DIHEL': 0,
    'DIIANNI': 0,
    'DIIENNO': 0,
    'DIIORIO': 0,
    'DIIULIO': 0,
    'DIJAK': 0,
    'DIJAMCO': 0,
    'DIJOHN': 0,
    'DIJOSEPH': 0,
    'DIJULIO': 0,
    'DIK': 0,
    'DIKA': 0,
    'DIKE': 0,
    'DIKEMAN': 0,
    'DIKES': 0,
    'DIKUN': 0,
    'DILALLA': 0,
    'DILALLO': 0,
    'DILAN': 0,
    'DILAPI': 0,
    'DILASCIO': 0,
    'DILAURA': 0,
    'DILAURO': 0,
    'DILBECK': 0,
    'DILBERT': 0,
    'DILBONE': 0,
    'DILCHER': 0,
    'DILDA': 0,
    'DILDAY': 0,
    'DILDINE': 0,
    'DILDY': 0,
    'DILE': 0,
    'DILEGGE': 0,
    'DILELLA': 0,
    'DILELLO': 0,
    'DILENA': 0,
    'DILEO': 0,
    'DILEONARDI': 0,
    'DILEONARDO': 0,
    'DILEONE': 0,
    'DILES': 0,
    'DILEVA': 0,
    'DILEY': 0,
    'DILG': 0,
    'DILGARD': 0,
    'DILGER': 0,
    'DILIBERO': 0,
    'DILIBERTI': 0,
    'DILIBERTO': 0,
    'DILICK': 0,
    'DILIDDO': 0,
    'DILIETO': 0,
    'DILILLO': 0,
    'DILISIO': 0,
    'DILK': 0,
    'DILKA': 0,
    'DILKES': 0,
    'DILKS': 0,
    'DILL': 0,
    'DILLA': 0,
    'DILLABOUGH': 0,
    'DILLAHA': 0,
    'DILLAHAY': 0,
    'DILLAHUNT': 0,
    'DILLAHUNTY': 0,
    'DILLAMAN': 0,
    'DILLAN': 0,
    'DILLANDER': 0,
    'DILLANE': 0,
    'DILLARD': 0,
    'DILLASHAW': 0,
    'DILLAVOU': 0,
    'DILLAWAY': 0,
    'DILLBECK': 0,
    'DILLDINE': 0,
    'DILLE': 0,
    'DILLEHAY': 0,
    'DILLEMUTH': 0,
    'DILLEN': 0,
    'DILLENBACK': 0,
    'DILLENBECK': 0,
    'DILLENBURG': 0,
    'DILLENDER': 0,
    'DILLER': 0,
    'DILLESHAW': 0,
    'DILLEY': 0,
    'DILLHOFF': 0,
    'DILLIARD': 0,
    'DILLIE': 0,
    'DILLIER': 0,
    'DILLIGARD': 0,
    'DILLIN': 0,
    'DILLINER': 0,
    'DILLING': 0,
    'DILLINGER': 0,
    'DILLINGHAM': 0,
    'DILLION': 0,
    'DILLIPLANE': 0,
    'DILLMAN': 0,
    'DILLMANN': 0,
    'DILLNER': 0,
    'DILLON': 0.21645021645021645,
    'DILLOW': 0,
    'DILLOWAY': 0,
    'DILLREE': 0,
    'DILLS': 0,
    'DILLSWORTH': 0,
    'DILLUVIO': 0,
    'DILLWORTH': 0,
    'DILLY': 0,
    'DILMORE': 0,
    'DILONARDO': 0,
    'DILONE': 0,
    'DILORENZO': 0,
    'DILORETO': 0,
    'DILORIO': 0,
    'DILS': 0,
    'DILSAVER': 0,
    'DILTS': 0,
    'DILTZ': 0,
    'DILUCA': 0,
    'DILUCIA': 0,
    'DILUIGI': 0,
    'DILULLO': 0,
    'DILUZIO': 0,
    'DILWORTH': 0,
    'DILYARD': 0,
    'DIM': 0,
    'DIMA': 0,
    'DIMAANO': 0,
    'DIMACALI': 0,
    'DIMACULANGAN': 0,
    'DIMAGGIO': 0,
    'DIMAIO': 0,
    'DIMALANTA': 0,
    'DIMAMBRO': 0,
    'DIMANCHE': 0,
    'DIMANNO': 0,
    'DIMANT': 0,
    'DIMAPILIS': 0,
    'DIMARCANTONIO': 0,
    'DIMARCO': 0,
    'DIMARE': 0,
    'DIMARIA': 0,
    'DIMARINO': 0,
    'DIMARIO': 0,
    'DIMARSICO': 0,
    'DIMARTINI': 0,
    'DIMARTINO': 0,
    'DIMARZIO': 0,
    'DIMARZO': 0,
    'DIMAS': 0,
    'DIMASCIO': 0,
    'DIMASE': 0,
    'DIMASI': 0,
    'DIMASO': 0,
    'DIMASSA': 0,
    'DIMASSIMO': 0,
    'DIMASSO': 0,
    'DIMATTEI': 0,
    'DIMATTEO': 0,
    'DIMATTIA': 0,
    'DIMATTINA': 0,
    'DIMATTIO': 0,
    'DIMAURO': 0,
    'DIMAYA': 0,
    'DIMAYUGA': 0,
    'DIME': 0,
    'DIMECH': 0,
    'DIMECO': 0,
    'DIMEDIO': 0,
    'DIMEGLIO': 0,
    'DIMELER': 0,
    'DIMELLA': 0,
    'DIMENNA': 0,
    'DIMENT': 0,
    'DIMENTO': 0,
    'DIMEO': 0,
    'DIMEOLA': 0,
    'DIMERCURIO': 0,
    'DIMERY': 0,
    'DIMES': 0,
    'DIMEZZA': 0,
    'DIMICCO': 0,
    'DIMICELI': 0,
    'DIMICH': 0,
    'DIMICHELE': 0,
    'DIMICK': 0,
    'DIMILIA': 0,
    'DIMILLO': 0,
    'DIMINICO': 0,
    'DIMINNO': 0,
    'DIMINO': 0,
    'DIMISA': 0,
    'DIMIT': 0,
    'DIMITRATOS': 0,
    'DIMITRI': 0,
    'DIMITRIADIS': 0,
    'DIMITRIJEVIC': 0,
    'DIMITRIOU': 0,
    'DIMITROFF': 0,
    'DIMITROPOULOS': 0,
    'DIMITROV': 0,
    'DIMITROVA': 0,
    'DIMITRY': 0,
    'DIMITT': 0,
    'DIMKE': 0,
    'DIMLER': 0,
    'DIMM': 0,
    'DIMMER': 0,
    'DIMMERLING': 0,
    'DIMMETT': 0,
    'DIMMETTE': 0,
    'DIMMICK': 0,
    'DIMMIG': 0,
    'DIMMITT': 0,
    'DIMMOCK': 0,
    'DIMOCK': 0,
    'DIMODICA': 0,
    'DIMOFF': 0,
    'DIMOLA': 0,
    'DIMON': 0,
    'DIMOND': 0,
    'DIMONDA': 0,
    'DIMONTE': 0,
    'DIMOPOULOS': 0,
    'DIMORA': 0,
    'DIMOS': 0,
    'DIMOU': 0,
    'DIMOV': 0,
    'DIMOVSKI': 0,
    'DIMPERIO': 0,
    'DIMPFL': 0,
    'DIMPLE': 1,
    'DIMSDALE': 0,
    'DIMSEY': 0,
    'DIMSON': 0,
    'DIMUCCIO': 0,
    'DIMURA': 0,
    'DIMURO': 0,
    'DIMUZIO': 0,
    'DIN': 0,
    'DINA': 0.9847806624888094,
    'DINAH': 1,
    'DINALLO': 0,
    'DINAN': 0,
    'DINAPOLI': 0,
    'DINARDI': 0,
    'DINARDO': 0,
    'DINARO': 0,
    'DINARTE': 0,
    'DINASO': 0,
    'DINATALE': 0,
    'DINCAU': 0,
    'DINCH': 0,
    'DINCHER': 0,
    'DINDA': 0,
    'DINDIA': 0,
    'DINDIAL': 0,
    'DINDINGER': 0,
    'DINE': 0,
    'DINEAL': 0,
    'DINEEN': 0,
    'DINEHART': 0,
    'DINELL': 0,
    'DINELLA': 0,
    'DINELLI': 0,
    'DINELLO': 0,
    'DINENNA': 0,
    'DINER': 0,
    'DINERMAN': 0,
    'DINERO': 0,
    'DINEROS': 0,
    'DINERSTEIN': 0,
    'DINES': 0,
    'DINET': 0,
    'DING': 0,
    'DINGA': 0,
    'DINGEE': 0,
    'DINGEL': 0,
    'DINGELDEIN': 0,
    'DINGEMAN': 0,
    'DINGER': 0,
    'DINGERSON': 0,
    'DINGES': 0,
    'DINGESS': 0,
    'DINGEY': 0,
    'DINGFELDER': 0,
    'DINGLASAN': 0,
    'DINGLE': 0,
    'DINGLEDINE': 0,
    'DINGLER': 0,
    'DINGLEY': 0,
    'DINGMAN': 0,
    'DINGMANN': 0,
    'DINGS': 0,
    'DINGUS': 0,
    'DINGWALL': 0,
    'DINGWELL': 0,
    'DINH': 0,
    'DINHAM': 0,
    'DINI': 0,
    'DINICOLA': 0,
    'DININGER': 0,
    'DININNO': 0,
    'DININO': 0,
    'DINIS': 0,
    'DINITTO': 0,
    'DINIUS': 0,
    'DINIZ': 0,
    'DINIZO': 0,
    'DINKEL': 0,
    'DINKELACKER': 0,
    'DINKELMAN': 0,
    'DINKENS': 0,
    'DINKHA': 0,
    'DINKIN': 0,
    'DINKINS': 0,
    'DINKLE': 0,
    'DINKLER': 0,
    'DINN': 0,
    'DINNALL': 0,
    'DINNAN': 0,
    'DINNDORF': 0,
    'DINNEEN': 0,
    'DINNEL': 0,
    'DINNELL': 0,
    'DINNEN': 0,
    'DINNER': 0,
    'DINNING': 0,
    'DINNOCENZO': 0,
    'DINO': 0.9538950715421304,
    'DINOBILE': 0,
    'DINOFF': 0,
    'DINOFRIO': 0,
    'DINOIA': 0,
    'DINOLA': 0,
    'DINOLFO': 0,
    'DINON': 0,
    'DINONNO': 0,
    'DINORAH': 1,
    'DINOTO': 0,
    'DINOVA': 0,
    'DINOVI': 0,
    'DINOVO': 0,
    'DINS': 0,
    'DINSDALE': 0,
    'DINSE': 0,
    'DINSER': 0,
    'DINSLAGE': 0,
    'DINSMOOR': 0,
    'DINSMORE': 0,
    'DINSON': 0,
    'DINTAMAN': 0,
    'DINTELMAN': 0,
    'DINTER': 0,
    'DINTERMAN': 0,
    'DINTINO': 0,
    'DINU': 0,
    'DINUCCI': 0,
    'DINUNNO': 0,
    'DINUNZIO': 0,
    'DINUZZO': 0,
    'DINVERNO': 0,
    'DINWIDDIE': 0,
    'DINWOODIE': 0,
    'DINY': 0,
    'DIO': 0,
    'DIODATI': 0,
    'DIODATO': 0,
    'DIODONET': 0,
    'DIOGO': 0,
    'DIOGUARDI': 0,
    'DIOKNO': 0,
    'DIOMEDE': 0,
    'DION': 0.7845934379457918,
    'DIONE': 0.9756097560975611,
    'DIONES': 0,
    'DIONICIO': 0,
    'DIONIS': 0,
    'DIONISE': 0,
    'DIONISI': 0,
    'DIONISIO': 0,
    'DIONIZIO': 0,
    'DIONNA': 1,
    'DIONNE': 0.7901668129938543,
    'DIOP': 0,
    'DIOQUINO': 0,
    'DIORIO': 0,
    'DIOS': 0,
    'DIOSDADO': 0,
    'DIOSO': 0,
    'DIOTALEVI': 0,
    'DIOTTE': 0,
    'DIOUF': 0,
    'DIP': 0,
    'DIPACE': 0,
    'DIPADOVA': 0,
    'DIPALERMO': 0,
    'DIPALMA': 0,
    'DIPALO': 0,
    'DIPAOLA': 0,
    'DIPAOLO': 0,
    'DIPASQUA': 0,
    'DIPASQUALE': 0,
    'DIPATRI': 0,
    'DIPAULA': 0,
    'DIPAULO': 0,
    'DIPERI': 0,
    'DIPERNA': 0,
    'DIPERRI': 0,
    'DIPERSIO': 0,
    'DIPERT': 0,
    'DIPESA': 0,
    'DIPETRILLO': 0,
    'DIPIAZZA': 0,
    'DIPIERO': 0,
    'DIPIERRO': 0,
    'DIPIETRA': 0,
    'DIPIETRANTONIO': 0,
    'DIPIETRO': 0,
    'DIPILATO': 0,
    'DIPILLA': 0,
    'DIPILLO': 0,
    'DIPINTO': 0,
    'DIPIPPA': 0,
    'DIPIPPO': 0,
    'DIPIRRO': 0,
    'DIPISA': 0,
    'DIPLACIDO': 0,
    'DIPMAN': 0,
    'DIPOFI': 0,
    'DIPONIO': 0,
    'DIPONZIO': 0,
    'DIPP': 0,
    'DIPPEL': 0,
    'DIPPERY': 0,
    'DIPPLE': 0,
    'DIPPOLD': 0,
    'DIPPOLITO': 0,
    'DIPPRE': 0,
    'DIPRE': 0,
    'DIPRETA': 0,
    'DIPRETE': 0,
    'DIPRIMA': 0,
    'DIPRIMIO': 0,
    'DIPRIMO': 0,
    'DIPRINZIO': 0,
    'DIPRIZIO': 0,
    'DIPROSPERO': 0,
    'DIPUCCIO': 0,
    'DIPUMA': 0,
    'DIPZINSKI': 0,
    'DIQUATTRO': 0,
    'DIR': 0,
    'DIRADDO': 0,
    'DIRADO': 0,
    'DIRAFFAELE': 0,
    'DIRAGO': 0,
    'DIRAIMO': 0,
    'DIRAIMONDO': 0,
    'DIRAMIO': 0,
    'DIRCIO': 0,
    'DIRCK': 0,
    'DIRCKS': 0,
    'DIRCKSEN': 0,
    'DIRDEN': 0,
    'DIRE': 0,
    'DIRECTO': 0,
    'DIRECTOR': 0,
    'DIREGAN': 0,
    'DIRENZO': 0,
    'DIRESTA': 0,
    'DIRGO': 0,
    'DIRICKSON': 0,
    'DIRICO': 0,
    'DIRIE': 0,
    'DIRIENZO': 0,
    'DIRIG': 0,
    'DIRILEY': 0,
    'DIRINGER': 0,
    'DIRISIO': 0,
    'DIRITO': 0,
    'DIRK': 0.9768009768009768,
    'DIRKES': 0,
    'DIRKS': 0,
    'DIRKSCHNEIDER': 0,
    'DIRKSE': 0,
    'DIRKSEN': 0,
    'DIRKSON': 0,
    'DIRKX': 0,
    'DIRLAM': 0,
    'DIRMEYER': 0,
    'DIRNBERGER': 0,
    'DIROBERTO': 0,
    'DIROCCO': 0,
    'DIROFF': 0,
    'DIROMA': 0,
    'DIROSA': 0,
    'DIROSARIO': 0,
    'DIRR': 0,
    'DIRRIM': 0,
    'DIRSA': 0,
    'DIRSCHERL': 0,
    'DIRST': 0,
    'DIRTH': 0,
    'DIRTON': 0,
    'DIRUBBO': 0,
    'DIRUSSO': 0,
    'DIRUZZA': 0,
    'DIRZO': 0,
    'DISABATINO': 0,
    'DISABATO': 0,
    'DISABELLA': 0,
    'DISALLE': 0,
    'DISALVATORE': 0,
    'DISALVIO': 0,
    'DISALVO': 0,
    'DISANDRO': 0,
    'DISANO': 0,
    'DISANTE': 0,
    'DISANTI': 0,
    'DISANTIS': 0,
    'DISANTO': 0,
    'DISANZA': 0,
    'DISANZO': 0,
    'DISARIO': 0,
    'DISARNO': 0,
    'DISARRO': 0,
    'DISBENNETT': 0,
    'DISBRO': 0,
    'DISBROW': 0,
    'DISCALA': 0,
    'DISCENZA': 0,
    'DISCEPOLO': 0,
    'DISCH': 0,
    'DISCHER': 0,
    'DISCHERT': 0,
    'DISCHINGER': 0,
    'DISCHINO': 0,
    'DISCHLER': 0,
    'DISCHNER': 0,
    'DISCIASCIO': 0,
    'DISCIPIO': 0,
    'DISCIULLO': 0,
    'DISCLAFANI': 0,
    'DISCO': 0,
    'DISCUA': 0,
    'DISCUILLO': 0,
    'DISE': 0,
    'DISEN': 0,
    'DISERIO': 0,
    'DISESSA': 0,
    'DISHAROON': 0,
    'DISHAW': 0,
    'DISHER': 0,
    'DISHEROON': 0,
    'DISHINGER': 0,
    'DISHION': 0,
    'DISHLER': 0,
    'DISHMAN': 0,
    'DISHMON': 0,
    'DISHMOND': 0,
    'DISHNEAU': 0,
    'DISHNER': 0,
    'DISHNO': 0,
    'DISHON': 0,
    'DISHONG': 0,
    'DISHONGH': 0,
    'DISHROON': 0,
    'DISIBIO': 0,
    'DISIENA': 0,
    'DISILVA': 0,
    'DISILVESTRO': 0,
    'DISILVIO': 0,
    'DISIMONE': 0,
    'DISINGER': 0,
    'DISIPIO': 0,
    'DISISTO': 0,
    'DISKEY': 0,
    'DISKIN': 0,
    'DISKO': 0,
    'DISLA': 0,
    'DISLER': 0,
    'DISMAN': 0,
    'DISMANG': 0,
    'DISMORE': 0,
    'DISMUKE': 0,
    'DISMUKES': 0,
    'DISNER': 0,
    'DISNEY': 0,
    'DISOMMA': 0,
    'DISORBO': 0,
    'DISOTELL': 0,
    'DISPAIN': 0,
    'DISPENNETT': 0,
    'DISPENSA': 0,
    'DISPENZA': 0,
    'DISPENZIERE': 0,
    'DISPIRITO': 0,
    'DISPOTO': 0,
    'DISQUE': 0,
    'DISRUD': 0,
    'DISS': 0,
    'DISSE': 0,
    'DISSELKOEN': 0,
    'DISSEN': 0,
    'DISSER': 0,
    'DISSETTE': 0,
    'DISSINGER': 0,
    'DISSMORE': 0,
    'DISTAD': 0,
    'DISTASI': 0,
    'DISTASIO': 0,
    'DISTASO': 0,
    'DISTEFANO': 0,
    'DISTEL': 0,
    'DISTELHORST': 0,
    'DISTELRATH': 0,
    'DISTER': 0,
    'DISTIN': 0,
    'DISTLER': 0,
    'DITALIA': 0,
    'DITARANTO': 0,
    'DITCH': 0,
    'DITCHFIELD': 0,
    'DITERLIZZI': 0,
    'DITHOMAS': 0,
    'DITIRRO': 0,
    'DITIZIO': 0,
    'DITLEVSON': 0,
    'DITLOW': 0,
    'DITMAN': 0,
    'DITMAR': 0,
    'DITMARS': 0,
    'DITMER': 0,
    'DITMORE': 0,
    'DITO': 0,
    'DITOLLA': 0,
    'DITOMASO': 0,
    'DITOMASSO': 0,
    'DITOMMASO': 0,
    'DITONNO': 0,
    'DITORE': 0,
    'DITORO': 0,
    'DITRANI': 0,
    'DITRAPANI': 0,
    'DITRI': 0,
    'DITROIA': 0,
    'DITROLIO': 0,
    'DITSCH': 0,
    'DITSON': 0,
    'DITSWORTH': 0,
    'DITTA': 0,
    'DITTBENNER': 0,
    'DITTBERNER': 0,
    'DITTBRENNER': 0,
    'DITTEL': 0,
    'DITTEMORE': 0,
    'DITTENBER': 0,
    'DITTER': 0,
    'DITTERLINE': 0,
    'DITTERT': 0,
    'DITTES': 0,
    'DITTFURTH': 0,
    'DITTLER': 0,
    'DITTMAN': 0,
    'DITTMANN': 0,
    'DITTMAR': 0,
    'DITTMEIER': 0,
    'DITTMER': 0,
    'DITTMORE': 0,
    'DITTNER': 0,
    'DITTO': 0,
    'DITTOE': 0,
    'DITTON': 0,
    'DITTRICH': 0,
    'DITTRICK': 0,
    'DITTUS': 0,
    'DITTY': 0,
    'DITUCCI': 0,
    'DITULLIO': 0,
    'DITURI': 0,
    'DITUSA': 0,
    'DITZ': 0,
    'DITZEL': 0,
    'DITZENBERGER': 0,
    'DITZIG': 0,
    'DITZLER': 0,
    'DIUGUID': 0,
    'DIULIO': 0,
    'DIULUS': 0,
    'DIVALENTINO': 0,
    'DIVALERIO': 0,
    'DIVAN': 0,
    'DIVAS': 0,
    'DIVECCHIO': 0,
    'DIVEL': 0,
    'DIVELBISS': 0,
    'DIVELBLISS': 0,
    'DIVELEY': 0,
    'DIVELY': 0,
    'DIVEN': 0,
    'DIVENERE': 0,
    'DIVENS': 0,
    'DIVENTI': 0,
    'DIVER': 0,
    'DIVERS': 0,
    'DIVIAK': 0,
    'DIVICO': 0,
    'DIVIETRO': 0,
    'DIVIN': 0,
    'DIVINA': 0.9433962264150944,
    'DIVINAGRACIA': 0,
    'DIVINCENTI': 0,
    'DIVINCENZO': 0,
    'DIVINE': 0,
    'DIVINEY': 0,
    'DIVINITY': 0,
    'DIVINO': 0,
    'DIVINS': 0,
    'DIVIRGILIO': 0,
    'DIVIS': 0,
    'DIVITA': 0,
    'DIVITO': 0,
    'DIVITTO': 0,
    'DIVITTORIO': 0,
    'DIVIZIO': 0,
    'DIVJAK': 0,
    'DIVOKY': 0,
    'DIVOLL': 0,
    'DIVVER': 0,
    'DIWA': 0,
    'DIWAN': 0,
    'DIX': 0,
    'DIXEY': 0,
    'DIXIE': 0.9939652112176074,
    'DIXION': 0,
    'DIXIT': 0,
    'DIXON': 0,
    'DIXSON': 0,
    'DIZ': 0,
    'DIZA': 0,
    'DIZARD': 0,
    'DIZAZZO': 0,
    'DIZDAR': 0,
    'DIZDAREVIC': 0,
    'DIZE': 0,
    'DIZENZO': 0,
    'DIZER': 0,
    'DIZINNO': 0,
    'DIZIO': 0,
    'DIZMANG': 0,
    'DIZNEY': 0,
    'DIZOGLIO': 0,
    'DIZON': 0,
    'DJERF': 0,
    'DJOKIC': 0,
    'DJOKOVIC': 0,
    'DJORDJEVIC': 0,
    'DJUKIC': 0,
    'DJURIC': 0,
    'DLOUHY': 0,
    'DLUBAC': 0,
    'DLUGOLECKI': 0,
    'DLUGOPOLSKI': 0,
    'DLUGOS': 0,
    'DLUGOSH': 0,
    'DLUGOSZ': 0,
    'DLUHY': 0,
    'DLUZAK': 0,
    'DMELLO': 0,
    'DMITRIEV': 0,
    'DMITRIYEV': 0,
    'DMITRUK': 0,
    'DMOCHOWSKI': 0,
    'DMUCHOWSKI': 0,
    'DO': 0,
    'DOAK': 0,
    'DOAKES': 0,
    'DOAKS': 0,
    'DOAN': 0,
    'DOANE': 0,
    'DOAR': 0,
    'DOATY': 0,
    'DOBAK': 0,
    'DOBARD': 0,
    'DOBASHI': 0,
    'DOBAY': 0,
    'DOBB': 0,
    'DOBBE': 0,
    'DOBBELAERE': 0,
    'DOBBELS': 0,
    'DOBBERFUHL': 0,
    'DOBBERPUHL': 0,
    'DOBBERSTEIN': 0,
    'DOBBERT': 0,
    'DOBBERTIN': 0,
    'DOBBIE': 0,
    'DOBBIN': 0,
    'DOBBINS': 0,
    'DOBBRATZ': 0,
    'DOBBS': 0,
    'DOBBYN': 0,
    'DOBE': 0,
    'DOBECK': 0,
    'DOBEK': 0,
    'DOBEL': 0,
    'DOBELBOWER': 0,
    'DOBELL': 0,
    'DOBENS': 0,
    'DOBER': 0,
    'DOBERSTEIN': 0,
    'DOBERT': 0,
    'DOBES': 0,
    'DOBESH': 0,
    'DOBEY': 0,
    'DOBIAS': 0,
    'DOBIE': 0,
    'DOBIES': 0,
    'DOBIESZ': 0,
    'DOBIN': 0,
    'DOBINE': 0,
    'DOBIS': 0,
    'DOBISH': 0,
    'DOBKIN': 0,
    'DOBKINS': 0,
    'DOBKOWSKI': 0,
    'DOBLADO': 0,
    'DOBLE': 0,
    'DOBLER': 0,
    'DOBLES': 0,
    'DOBMEIER': 0,
    'DOBNER': 0,
    'DOBNEY': 0,
    'DOBO': 0,
    'DOBOS': 0,
    'DOBOSH': 0,
    'DOBOSZ': 0,
    'DOBRA': 0,
    'DOBRANSKI': 0,
    'DOBRANSKY': 0,
    'DOBRATZ': 0,
    'DOBRE': 0,
    'DOBRIC': 0,
    'DOBRICH': 0,
    'DOBRICK': 0,
    'DOBRIN': 0,
    'DOBRINSKI': 0,
    'DOBRON': 0,
    'DOBROSKI': 0,
    'DOBROSKY': 0,
    'DOBROVOLNY': 0,
    'DOBROW': 0,
    'DOBROWOLSKI': 0,
    'DOBROWOLSKY': 0,
    'DOBROWSKI': 0,
    'DOBRY': 0,
    'DOBRZANSKI': 0,
    'DOBRZENIECKI': 0,
    'DOBRZENSKI': 0,
    'DOBRZYKOWSKI': 0,
    'DOBRZYNSKI': 0,
    'DOBSON': 0,
    'DOBY': 0,
    'DOBYNE': 0,
    'DOBYNES': 0,
    'DOBYNS': 0,
    'DOC': 0,
    'DOCAMPO': 0,
    'DOCANTO': 0,
    'DOCARMO': 0,
    'DOCCHIO': 0,
    'DOCEKAL': 0,
    'DOCHERTY': 0,
    'DOCHNAHL': 0,
    'DOCHTERMAN': 0,
    'DOCIMO': 0,
    'DOCK': 0,
    'DOCKAL': 0,
    'DOCKEN': 0,
    'DOCKENDORF': 0,
    'DOCKENDORFF': 0,
    'DOCKENS': 0,
    'DOCKER': 0,
    'DOCKERTY': 0,
    'DOCKERY': 0,
    'DOCKETT': 0,
    'DOCKEY': 0,
    'DOCKHAM': 0,
    'DOCKINS': 0,
    'DOCKMAN': 0,
    'DOCKRAY': 0,
    'DOCKREY': 0,
    'DOCKS': 0,
    'DOCKSTADER': 0,
    'DOCKTER': 0,
    'DOCKTOR': 0,
    'DOCKUM': 0,
    'DOCKUS': 0,
    'DOCKWEILER': 0,
    'DOCOUTO': 0,
    'DOCTER': 0,
    'DOCTEUR': 0,
    'DOCTOLERO': 0,
    'DOCTOR': 0,
    'DOD': 0,
    'DODA': 0,
    'DODARD': 0,
    'DODARO': 0,
    'DODD': 0,
    'DODDER': 0,
    'DODDRIDGE': 0,
    'DODDS': 0,
    'DODDY': 0,
    'DODEN': 0,
    'DODENHOFF': 0,
    'DODERO': 0,
    'DODGE': 0,
    'DODGEN': 0,
    'DODGENS': 0,
    'DODGIN': 0,
    'DODGINS': 0,
    'DODGION': 0,
    'DODGSON': 0,
    'DODIE': 1,
    'DODIER': 0,
    'DODIG': 0,
    'DODIRY': 0,
    'DODLEY': 0,
    'DODOO': 0,
    'DODRIDGE': 0,
    'DODRILL': 0,
    'DODS': 0,
    'DODSON': 0,
    'DODSWORTH': 0,
    'DODT': 0,
    'DODWELL': 0,
    'DODY': 0,
    'DOE': 0,
    'DOEBEL': 0,
    'DOEBELE': 0,
    'DOEBEREINER': 0,
    'DOEBLER': 0,
    'DOEDE': 0,
    'DOEDEN': 0,
    'DOEDTMAN': 0,
    'DOEG': 0,
    'DOEGE': 0,
    'DOEHLER': 0,
    'DOEHLING': 0,
    'DOEHNE': 0,
    'DOEHRING': 0,
    'DOEHRMAN': 0,
    'DOEHRMANN': 0,
    'DOEING': 0,
    'DOEL': 0,
    'DOELGER': 0,
    'DOELKER': 0,
    'DOELL': 0,
    'DOELLE': 0,
    'DOELLING': 0,
    'DOELLMAN': 0,
    'DOEMEL': 0,
    'DOENCH': 0,
    'DOENGES': 0,
    'DOEPEL': 0,
    'DOEPKE': 0,
    'DOEPKER': 0,
    'DOEPP': 0,
    'DOEREN': 0,
    'DOERFER': 0,
    'DOERFLEIN': 0,
    'DOERFLER': 0,
    'DOERFLINGER': 0,
    'DOERGE': 0,
    'DOERGER': 0,
    'DOERHOFF': 0,
    'DOERING': 0,
    'DOERKSEN': 0,
    'DOERLE': 0,
    'DOERMANN': 0,
    'DOERN': 0,
    'DOERNER': 0,
    'DOERR': 0,
    'DOERRE': 0,
    'DOERRER': 0,
    'DOERS': 0,
    'DOERSAM': 0,
    'DOERSCH': 0,
    'DOERSCHUK': 0,
    'DOES': 0,
    'DOESCHER': 0,
    'DOETSCH': 0,
    'DOEZEMA': 0,
    'DOFFIN': 0,
    'DOFFING': 0,
    'DOFFLEMYER': 0,
    'DOG': 0,
    'DOGAN': 0,
    'DOGGETT': 0,
    'DOGGETTE': 0,
    'DOGGS': 0,
    'DOGRA': 0,
    'DOH': 0,
    'DOHAN': 0,
    'DOHENY': 0,
    'DOHERTY': 0,
    'DOHL': 0,
    'DOHLE': 0,
    'DOHLER': 0,
    'DOHLMAN': 0,
    'DOHM': 0,
    'DOHMAN': 0,
    'DOHMANN': 0,
    'DOHME': 0,
    'DOHMEN': 0,
    'DOHMS': 0,
    'DOHN': 0,
    'DOHNAL': 0,
    'DOHNER': 0,
    'DOHOGNE': 0,
    'DOHONEY': 0,
    'DOHR': 0,
    'DOHRER': 0,
    'DOHRING': 0,
    'DOHRMAN': 0,
    'DOHRMANN': 0,
    'DOHRN': 0,
    'DOHSE': 0,
    'DOI': 0,
    'DOIDGE': 0,
    'DOIEL': 0,
    'DOIG': 0,
    'DOILEY': 0,
    'DOING': 0,
    'DOINO': 0,
    'DOIRE': 0,
    'DOIRON': 0,
    'DOISE': 0,
    'DOK': 0,
    'DOKA': 0,
    'DOKAS': 0,
    'DOKE': 0,
    'DOKES': 0,
    'DOKEY': 0,
    'DOKIC': 0,
    'DOKKEN': 0,
    'DOKKO': 0,
    'DOKO': 0,
    'DOKOS': 0,
    'DOKTER': 0,
    'DOKTOR': 0,
    'DOKU': 0,
    'DOLACK': 0,
    'DOLAK': 0,
    'DOLAN': 0,
    'DOLAND': 0,
    'DOLANSKY': 0,
    'DOLAR': 0,
    'DOLATA': 0,
    'DOLATOWSKI': 0,
    'DOLBEAR': 0,
    'DOLBEARE': 0,
    'DOLBEC': 0,
    'DOLBEE': 0,
    'DOLBERG': 0,
    'DOLBERRY': 0,
    'DOLBIER': 0,
    'DOLBIN': 0,
    'DOLBOW': 0,
    'DOLBY': 0,
    'DOLCE': 0,
    'DOLCH': 0,
    'DOLCI': 0,
    'DOLCIMASCOLO': 0,
    'DOLCINE': 0,
    'DOLCINI': 0,
    'DOLD': 0,
    'DOLDE': 0,
    'DOLDER': 0,
    'DOLE': 0,
    'DOLECHEK': 0,
    'DOLECKI': 0,
    'DOLEH': 0,
    'DOLEJS': 0,
    'DOLEJSI': 0,
    'DOLEMAN': 0,
    'DOLEN': 0,
    'DOLENCE': 0,
    'DOLENTE': 0,
    'DOLER': 0,
    'DOLES': 0,
    'DOLESE': 0,
    'DOLESHAL': 0,
    'DOLEY': 0,
    'DOLEZAL': 0,
    'DOLEZEL': 0,
    'DOLF': 0,
    'DOLFI': 0,
    'DOLFORD': 0,
    'DOLGE': 0,
    'DOLGIN': 0,
    'DOLGNER': 0,
    'DOLGOFF': 0,
    'DOLGOS': 0,
    'DOLIBER': 0,
    'DOLIMPIO': 0,
    'DOLIN': 0,
    'DOLINA': 0,
    'DOLINAR': 0,
    'DOLINER': 0,
    'DOLING': 0,
    'DOLINGER': 0,
    'DOLINSKI': 0,
    'DOLINSKY': 0,
    'DOLISON': 0,
    'DOLITTLE': 0,
    'DOLIVE': 0,
    'DOLIVEIRA': 0,
    'DOLK': 0,
    'DOLL': 0,
    'DOLLAHAN': 0,
    'DOLLAHITE': 0,
    'DOLLAK': 0,
    'DOLLAR': 0,
    'DOLLARD': 0,
    'DOLLARHIDE': 0,
    'DOLLARHITE': 0,
    'DOLLARHYDE': 0,
    'DOLLE': 0,
    'DOLLEN': 0,
    'DOLLENS': 0,
    'DOLLENTE': 0,
    'DOLLER': 0,
    'DOLLEY': 0,
    'DOLLHOPF': 0,
    'DOLLIE': 1,
    'DOLLING': 0,
    'DOLLINGER': 0,
    'DOLLINS': 0,
    'DOLLIOLE': 0,
    'DOLLISON': 0,
    'DOLLIVER': 0,
    'DOLLMAN': 0,
    'DOLLOFF': 0,
    'DOLLY': 0.9696969696969696,
    'DOLLYHIGH': 0,
    'DOLMA': 0,
    'DOLMAGE': 0,
    'DOLMAN': 0,
    'DOLNEY': 0,
    'DOLNICK': 0,
    'DOLNY': 0,
    'DOLO': 0,
    'DOLOR': 0,
    'DOLORES': 0.9972941631233089,
    'DOLORIS': 1,
    'DOLPH': 0,
    'DOLPHIN': 0,
    'DOLPHUS': 0,
    'DOLS': 0,
    'DOLSEN': 0,
    'DOLSKI': 0,
    'DOLSON': 0,
    'DOLT': 0,
    'DOLTER': 0,
    'DOLTON': 0,
    'DOLVEN': 0,
    'DOLVIN': 0,
    'DOLWICK': 0,
    'DOM': 0,
    'DOMA': 0,
    'DOMAGALA': 0,
    'DOMAGALSKI': 0,
    'DOMAGAS': 0,
    'DOMAIN': 0,
    'DOMALESKI': 0,
    'DOMALEWSKI': 0,
    'DOMALIK': 0,
    'DOMAN': 0,
    'DOMANGUE': 0,
    'DOMANICK': 0,
    'DOMANICO': 0,
    'DOMANN': 0,
    'DOMANOWSKI': 0,
    'DOMANSKI': 0,
    'DOMANSKY': 0,
    'DOMANTAY': 0,
    'DOMARACKI': 0,
    'DOMAS': 0,
    'DOMASK': 0,
    'DOMAZET': 0,
    'DOMB': 0,
    'DOMBACH': 0,
    'DOMBECK': 0,
    'DOMBEK': 0,
    'DOMBI': 0,
    'DOMBKOWSKI': 0,
    'DOMBRO': 0,
    'DOMBROCK': 0,
    'DOMBROSKI': 0,
    'DOMBROSKY': 0,
    'DOMBROVSKI': 0,
    'DOMBROW': 0,
    'DOMBROWSKI': 0,
    'DOMBROWSKY': 0,
    'DOMBY': 0,
    'DOME': 0,
    'DOMEC': 0,
    'DOMEIER': 0,
    'DOMEK': 0,
    'DOMEL': 0,
    'DOMEN': 0,
    'DOMENA': 0,
    'DOMENECH': 0,
    'DOMENGEAUX': 0,
    'DOMENIC': 1,
    'DOMENICA': 1,
    'DOMENICI': 0,
    'DOMENICK': 0,
    'DOMENICO': 0,
    'DOMER': 0,
    'DOMERACKI': 0,
    'DOMERESE': 0,
    'DOMES': 0,
    'DOMEY': 0,
    'DOMEYER': 0,
    'DOMHOFF': 0,
    'DOMIAN': 0,
    'DOMIANO': 0,
    'DOMICO': 0,
    'DOMIER': 0,
    'DOMIGAN': 0,
    'DOMIGUEZ': 0,
    'DOMIJAN': 0,
    'DOMIN': 0,
    'DOMINA': 0,
    'DOMINE': 0,
    'DOMINECK': 0,
    'DOMINELLI': 0,
    'DOMINELLO': 0,
    'DOMINEY': 0,
    'DOMING': 0,
    'DOMINGA': 1,
    'DOMINGAS': 0,
    'DOMINGO': 0.8659981768459434,
    'DOMINGOS': 0,
    'DOMINGUE': 0,
    'DOMINGUES': 0,
    'DOMINGUEZ': 0,
    'DOMINGUS': 0,
    'DOMINI': 0,
    'DOMINIAK': 0,
    'DOMINIANNI': 0,
    'DOMINIC': 0.9882643607164917,
    'DOMINICA': 1,
    'DOMINICCI': 0,
    'DOMINICI': 0,
    'DOMINICIS': 0,
    'DOMINICK': 0.9134615384615384,
    'DOMINICO': 0,
    'DOMINIE': 0,
    'DOMINIK': 0,
    'DOMINIQUE': 0.963855421686747,
    'DOMINO': 0,
    'DOMINOWSKI': 0,
    'DOMINQUE': 0.9708737864077669,
    'DOMINQUEZ': 0,
    'DOMINSKI': 0,
    'DOMINY': 0,
    'DOMIO': 0,
    'DOMITILA': 1,
    'DOMITROVICH': 0,
    'DOMIZIO': 0,
    'DOMKA': 0,
    'DOMKE': 0,
    'DOMKOWSKI': 0,
    'DOMM': 0,
    'DOMME': 0,
    'DOMMEL': 0,
    'DOMMEN': 0,
    'DOMMER': 0,
    'DOMMERMUTH': 0,
    'DOMMERT': 0,
    'DOMNICK': 0,
    'DOMNITZ': 0,
    'DOMOKOS': 0,
    'DOMON': 0,
    'DOMOND': 0,
    'DOMONDON': 0,
    'DOMONIQUE': 1,
    'DOMONKOS': 0,
    'DOMPIER': 0,
    'DOMPIERRE': 0,
    'DOMRES': 0,
    'DOMROSE': 0,
    'DOMS': 0,
    'DOMSCHOT': 0,
    'DOMSIC': 0,
    'DOMSKI': 0,
    'DOMSKY': 0,
    'DOMURAT': 0,
    'DOMVILLE': 0,
    'DOMYAN': 0,
    'DOMZALSKI': 0,
    'DON': 0.9936270814774206,
    'DONA': 0.9790209790209791,
    'DONABAUER': 0,
    'DONABEDIAN': 0,
    'DONABY': 0,
    'DONACHIE': 0,
    'DONACHY': 0,
    'DONADIO': 0,
    'DONADO': 0,
    'DONAGHE': 0,
    'DONAGHEY': 0,
    'DONAGHUE': 0,
    'DONAGHY': 0,
    'DONAH': 0,
    'DONAHAY': 0,
    'DONAHE': 0,
    'DONAHER': 0,
    'DONAHEY': 0,
    'DONAHO': 0,
    'DONAHOE': 0,
    'DONAHOO': 0,
    'DONAHOU': 0,
    'DONAHUE': 0,
    'DONAIRE': 0,
    'DONAIS': 0,
    'DONAJKOWSKI': 0,
    'DONAKOWSKI': 0,
    'DONALD': 0.9953486387300504,
    'DONALDS': 0,
    'DONALDSON': 0,
    'DONALS': 0,
    'DONALSON': 0,
    'DONAN': 0,
    'DONAR': 0,
    'DONARSKI': 0,
    'DONART': 0,
    'DONARUMA': 0,
    'DONASCIMENTO': 0,
    'DONAT': 0,
    'DONATE': 0,
    'DONATELL': 0,
    'DONATELLI': 0,
    'DONATELLO': 0,
    'DONATH': 0,
    'DONATHAN': 0,
    'DONATI': 0,
    'DONATIELLO': 0,
    'DONATIEN': 0,
    'DONATO': 0,
    'DONATONE': 0,
    'DONATONI': 0,
    'DONATTO': 0,
    'DONATUCCI': 0,
    'DONAVAN': 0,
    'DONAVON': 0,
    'DONAWA': 0,
    'DONAWAY': 0,
    'DONAYRE': 0,
    'DONBROSKY': 0,
    'DONCARLOS': 0,
    'DONCASTER': 0,
    'DONCHEZ': 0,
    'DONDANVILLE': 0,
    'DONDE': 0,
    'DONDELINGER': 0,
    'DONDERO': 0,
    'DONDIEGO': 0,
    'DONDLINGER': 0,
    'DONE': 0,
    'DONECKER': 0,
    'DONEFF': 0,
    'DONEGAN': 0,
    'DONEGHY': 0,
    'DONEHOO': 0,
    'DONEHUE': 0,
    'DONEL': 0,
    'DONELAN': 0,
    'DONELL': 0,
    'DONELLA': 1,
    'DONELLAN': 0,
    'DONELLY': 0,
    'DONELON': 0,
    'DONELSON': 0,
    'DONENFELD': 0,
    'DONER': 0,
    'DONERSON': 0,
    'DONES': 0,
    'DONETTA': 1,
    'DONETTE': 1,
    'DONEY': 0,
    'DONEZ': 0,
    'DONG': 0.6476683937823834,
    'DONGES': 0,
    'DONGO': 0,
    'DONHAM': 0,
    'DONHAUSER': 0,
    'DONIA': 0,
    'DONIAS': 0,
    'DONICA': 0,
    'DONIGAN': 0,
    'DONIGER': 0,
    'DONIGIAN': 0,
    'DONIHOO': 0,
    'DONIHUE': 0,
    'DONIN': 0,
    'DONINGER': 0,
    'DONINI': 0,
    'DONIO': 0,
    'DONIS': 0,
    'DONISI': 0,
    'DONITA': 1,
    'DONITHAN': 0,
    'DONIVAN': 0,
    'DONJON': 0,
    'DONJUAN': 0,
    'DONK': 0,
    'DONKER': 0,
    'DONKERS': 0,
    'DONKERSLOOT': 0,
    'DONKIN': 0,
    'DONKOR': 0,
    'DONLAN': 0,
    'DONLEVY': 0,
    'DONLEY': 0,
    'DONLIN': 0,
    'DONLON': 0,
    'DONMOYER': 0,
    'DONN': 0.9523809523809524,
    'DONNA': 0.9995885055894658,
    'DONNACHIE': 0,
    'DONNAHOO': 0,
    'DONNAL': 0,
    'DONNALLEY': 0,
    'DONNALLY': 0,
    'DONNAN': 0,
    'DONNARUMMA': 0,
    'DONNAY': 0,
    'DONNE': 0,
    'DONNEL': 0,
    'DONNELL': 0.8077544426494346,
    'DONNELLAN': 0,
    'DONNELLEY': 0,
    'DONNELLON': 0,
    'DONNELLY': 0,
    'DONNELSON': 0,
    'DONNENWIRTH': 0,
    'DONNER': 0,
    'DONNETTA': 1,
    'DONNETTE': 1,
    'DONNEY': 0,
    'DONNICI': 0,
    'DONNIE': 1,
    'DONNINI': 0,
    'DONNY': 1,
    'DONO': 0,
    'DONOFRIO': 0,
    'DONOGHUE': 0,
    'DONOHEW': 0,
    'DONOHO': 0,
    'DONOHOE': 0,
    'DONOHOO': 0,
    'DONOHOUE': 0,
    'DONOHUE': 0,
    'DONOR': 0,
    'DONOSO': 0,
    'DONOUGHE': 0,
    'DONOVAN': 0.40716612377850164,
    'DONOWAY': 0,
    'DONSBACH': 0,
    'DONSKY': 0,
    'DONSON': 0,
    'DONTE': 1,
    'DONTJE': 0,
    'DONTKNOW': 0,
    'DONTON': 0,
    'DONVITO': 0,
    'DONYA': 1,
    'DONZA': 0,
    'DONZE': 0,
    'DONZELLA': 0,
    'DONZELLI': 0,
    'DOO': 0,
    'DOOBAY': 0,
    'DOOCY': 0,
    'DOOD': 0,
    'DOODNAUTH': 0,
    'DOODY': 0,
    'DOOGAN': 0,
    'DOOHAN': 0,
    'DOOHER': 0,
    'DOOKIE': 0,
    'DOOL': 0,
    'DOOLAN': 0,
    'DOOLE': 0,
    'DOOLEN': 0,
    'DOOLEY': 0,
    'DOOLIN': 0,
    'DOOLING': 0,
    'DOOLITTLE': 0,
    'DOOLY': 0,
    'DOOM': 0,
    'DOOMAN': 0,
    'DOOMES': 0,
    'DOOMS': 0,
    'DOON': 0,
    'DOONAN': 0,
    'DOONE': 0,
    'DOONER': 0,
    'DOONEY': 0,
    'DOONG': 0,
    'DOOP': 0,
    'DOOR': 0,
    'DOORE': 0,
    'DOORENBOS': 0,
    'DOORES': 0,
    'DOORLAG': 0,
    'DOORLEY': 0,
    'DOORLY': 0,
    'DOORN': 0,
    'DOORNBOS': 0,
    'DOORNINK': 0,
    'DOOSE': 0,
    'DOOT': 0,
    'DOOTSON': 0,
    'DOP': 0,
    'DOPERALSKI': 0,
    'DOPHEIDE': 0,
    'DOPICO': 0,
    'DOPKE': 0,
    'DOPKINS': 0,
    'DOPKOWSKI': 0,
    'DOPLE': 0,
    'DOPLER': 0,
    'DOPORTO': 0,
    'DOPP': 0,
    'DOPPELT': 0,
    'DOPPENBERG': 0,
    'DOPPLER': 0,
    'DOPPS': 0,
    'DOPSON': 0,
    'DOPWELL': 0,
    'DOR': 0,
    'DORA': 0.9953785993601137,
    'DORADO': 0,
    'DORAIS': 0,
    'DORAK': 0,
    'DORAL': 0,
    'DORAM': 0,
    'DORAME': 0,
    'DORAMUS': 0,
    'DORAN': 0,
    'DORANTE': 0,
    'DORANTES': 0,
    'DORATHY': 1,
    'DORATO': 0,
    'DORAU': 0,
    'DORAY': 0,
    'DORAZIO': 0,
    'DORBAND': 0,
    'DORBIN': 0,
    'DORCAS': 0.9823182711198428,
    'DORCE': 0,
    'DORCELY': 0,
    'DORCENT': 0,
    'DORCEUS': 0,
    'DORCEY': 0,
    'DORCH': 0,
    'DORCHAK': 0,
    'DORCHESTER': 0,
    'DORCY': 0,
    'DORDAL': 0,
    'DORE': 0,
    'DOREATHA': 1,
    'DOREE': 0,
    'DOREEN': 1,
    'DOREGO': 0,
    'DORELIEN': 0,
    'DORELUS': 0,
    'DOREMUS': 0,
    'DOREN': 0,
    'DORENE': 1,
    'DORENKAMP': 0,
    'DORER': 0,
    'DORES': 0,
    'DORETHA': 1,
    'DORETHEA': 1,
    'DORETHY': 0,
    'DORETTA': 1,
    'DORETY': 0,
    'DOREY': 0,
    'DORF': 0,
    'DORFF': 0,
    'DORFLER': 0,
    'DORFLINGER': 0,
    'DORFMAN': 0,
    'DORFMEYER': 0,
    'DORFNER': 0,
    'DORGAN': 0,
    'DORGER': 0,
    'DORHAM': 0,
    'DORHOUT': 0,
    'DORI': 0.9803921568627452,
    'DORIA': 0.5050505050505051,
    'DORIAN': 0.9557945041816011,
    'DORICH': 0,
    'DORIE': 0.966183574879227,
    'DORIETY': 0,
    'DORILAS': 0,
    'DORIN': 0,
    'DORINDA': 1,
    'DORINE': 1,
    'DORING': 0,
    'DORIO': 0,
    'DORION': 0,
    'DORIOT': 0,
    'DORIOTT': 0,
    'DORIS': 0.997974261201144,
    'DORISCA': 0,
    'DORISMOND': 0,
    'DORITY': 0,
    'DORIUS': 0,
    'DORIVAL': 0,
    'DORJEE': 0,
    'DORK': 0,
    'DORKIN': 0,
    'DORKO': 0,
    'DORL': 0,
    'DORLA': 1,
    'DORLAC': 0,
    'DORLAND': 0,
    'DORLANDO': 0,
    'DORLEAN': 0,
    'DORLEANS': 0,
    'DORLEY': 0,
    'DORM': 0,
    'DORMADY': 0,
    'DORMAIER': 0,
    'DORMAN': 0,
    'DORMANEN': 0,
    'DORMANN': 0,
    'DORMER': 0,
    'DORMEUS': 0,
    'DORMEVIL': 0,
    'DORMINEY': 0,
    'DORMINY': 0,
    'DORMIRE': 0,
    'DORN': 0,
    'DORNACKER': 0,
    'DORNAK': 0,
    'DORNAN': 0,
    'DORNBACH': 0,
    'DORNBERGER': 0,
    'DORNBLASER': 0,
    'DORNBOS': 0,
    'DORNBURG': 0,
    'DORNBUSCH': 0,
    'DORNBUSH': 0,
    'DORNE': 0,
    'DORNELLAS': 0,
    'DORNEMAN': 0,
    'DORNER': 0,
    'DORNES': 0,
    'DORNEY': 0,
    'DORNFELD': 0,
    'DORNHECKER': 0,
    'DORNICK': 0,
    'DORNIER': 0,
    'DORNIN': 0,
    'DORNING': 0,
    'DORNINK': 0,
    'DORNISCH': 0,
    'DORNON': 0,
    'DORNQUAST': 0,
    'DORNSEIF': 0,
    'DORNSIFE': 0,
    'DORO': 0,
    'DOROBA': 0,
    'DOROBIALA': 0,
    'DOROFF': 0,
    'DOROMAL': 0,
    'DORON': 0,
    'DOROS': 0,
    'DOROSH': 0,
    'DOROSHENKO': 0,
    'DOROSKI': 0,
    'DOROSZ': 0,
    'DOROTEO': 0,
    'DOROTHA': 1,
    'DOROTHEA': 1,
    'DOROTHY': 0.9995462857299987,
    'DOROUGH': 0,
    'DOROW': 0,
    'DORR': 0,
    'DORRAH': 0,
    'DORRANCE': 0,
    'DORRE': 0,
    'DORREL': 0,
    'DORRELL': 0,
    'DORRES': 0,
    'DORRIAN': 0,
    'DORRIER': 0,
    'DORRIES': 0,
    'DORRIETY': 0,
    'DORRILL': 0,
    'DORRINGTON': 0,
    'DORRIS': 0.7117437722419929,
    'DORRITY': 0,
    'DORROH': 0,
    'DORROUGH': 0,
    'DORRY': 0,
    'DORS': 0,
    'DORSA': 0,
    'DORSAINVIL': 0,
    'DORSAM': 0,
    'DORSANEO': 0,
    'DORSCH': 0,
    'DORSCHEL': 0,
    'DORSCHER': 0,
    'DORSCHNER': 0,
    'DORSE': 0,
    'DORSET': 0,
    'DORSETT': 0,
    'DORSETTE': 0,
    'DORSEY': 0.20790020790020794,
    'DORSHEIMER': 0,
    'DORSHIMER': 0,
    'DORSHORST': 0,
    'DORSI': 0,
    'DORSKY': 0,
    'DORSO': 0,
    'DORSON': 0,
    'DORST': 0,
    'DORSTEN': 0,
    'DORT': 0,
    'DORTA': 0,
    'DORTCH': 0,
    'DORTENZIO': 0,
    'DORTHA': 1,
    'DORTHEA': 1,
    'DORTHEY': 1,
    'DORTHY': 1,
    'DORTMAN': 0,
    'DORTON': 0,
    'DORTY': 0,
    'DORVAL': 0,
    'DORVIL': 0,
    'DORVILIER': 0,
    'DORVILLE': 0,
    'DORVILUS': 0,
    'DORWARD': 0,
    'DORWART': 0,
    'DORWEILER': 0,
    'DORWIN': 0,
    'DORY': 0,
    'DOS': 0,
    'DOSA': 0,
    'DOSAL': 0,
    'DOSANJH': 0,
    'DOSANJOS': 0,
    'DOSANTOS': 0,
    'DOSCH': 0,
    'DOSCHER': 0,
    'DOSDALL': 0,
    'DOSE': 0,
    'DOSECK': 0,
    'DOSELA': 0,
    'DOSEN': 0,
    'DOSER': 0,
    'DOSEY': 0,
    'DOSH': 0,
    'DOSHER': 0,
    'DOSHI': 0,
    'DOSHIER': 0,
    'DOSIER': 0,
    'DOSKEY': 0,
    'DOSKI': 0,
    'DOSKOCIL': 0,
    'DOSLAND': 0,
    'DOSMANN': 0,
    'DOSREIS': 0,
    'DOSS': 0,
    'DOSSA': 0,
    'DOSSANTOS': 0,
    'DOSSER': 0,
    'DOSSETT': 0,
    'DOSSEY': 0,
    'DOSSIE': 0,
    'DOSSIN': 0,
    'DOSSMAN': 0,
    'DOSSOUS': 0,
    'DOST': 0,
    'DOSTAL': 0,
    'DOSTALER': 0,
    'DOSTER': 0,
    'DOSTERT': 0,
    'DOSTIE': 0,
    'DOSTON': 0,
    'DOSUNMU': 0,
    'DOSWELL': 0,
    'DOT': 1,
    'DOTA': 0,
    'DOTE': 0,
    'DOTEL': 0,
    'DOTEN': 0,
    'DOTHAGE': 0,
    'DOTHAGER': 0,
    'DOTHARD': 0,
    'DOTI': 0,
    'DOTIE': 0,
    'DOTLICH': 0,
    'DOTO': 0,
    'DOTOLO': 0,
    'DOTSETH': 0,
    'DOTSON': 0,
    'DOTT': 0,
    'DOTTA': 0,
    'DOTTAVIO': 0,
    'DOTTEN': 0,
    'DOTTER': 0,
    'DOTTERER': 0,
    'DOTTERWEICH': 0,
    'DOTTERY': 0,
    'DOTTIE': 1,
    'DOTTIN': 0,
    'DOTTO': 0,
    'DOTTORE': 0,
    'DOTTS': 0,
    'DOTTY': 1,
    'DOTY': 0,
    'DOTZEL': 0,
    'DOTZLER': 0,
    'DOU': 0,
    'DOUANGDARA': 0,
    'DOUANGMALA': 0,
    'DOUB': 0,
    'DOUBEK': 0,
    'DOUBERLEY': 0,
    'DOUBERLY': 0,
    'DOUBET': 0,
    'DOUBLE': 0,
    'DOUBLEDAY': 0,
    'DOUBLEDEE': 0,
    'DOUBLER': 0,
    'DOUBLIN': 0,
    'DOUBRAVA': 0,
    'DOUBT': 0,
    'DOUCE': 0,
    'DOUCET': 0,
    'DOUCETT': 0,
    'DOUCETTE': 0,
    'DOUD': 0,
    'DOUDA': 0,
    'DOUDNA': 0,
    'DOUDS': 0,
    'DOUEK': 0,
    'DOUET': 0,
    'DOUG': 0.9982530571499875,
    'DOUGAL': 0,
    'DOUGALL': 0,
    'DOUGAN': 0,
    'DOUGE': 0,
    'DOUGET': 0,
    'DOUGH': 0,
    'DOUGHAN': 0,
    'DOUGHARTY': 0,
    'DOUGHER': 0,
    'DOUGHERTY': 0,
    'DOUGHMAN': 0,
    'DOUGHTEN': 0,
    'DOUGHTERY': 0,
    'DOUGHTIE': 0,
    'DOUGHTON': 0,
    'DOUGHTRY': 0,
    'DOUGHTY': 0,
    'DOUGLAS': 0.9112578834980384,
    'DOUGLASS': 0.4310344827586207,
    'DOUIN': 0,
    'DOUKAS': 0,
    'DOULL': 0,
    'DOUMA': 0,
    'DOUMAS': 0,
    'DOUMBIA': 0,
    'DOUMIT': 0,
    'DOUNG': 0,
    'DOUP': 0,
    'DOUPE': 0,
    'DOUR': 0,
    'DOURA': 0,
    'DOURADO': 0,
    'DOURIS': 0,
    'DOUROS': 0,
    'DOUSAY': 0,
    'DOUSE': 0,
    'DOUSHARM': 0,
    'DOUST': 0,
    'DOUT': 0,
    'DOUTE': 0,
    'DOUTHARD': 0,
    'DOUTHART': 0,
    'DOUTHAT': 0,
    'DOUTHETT': 0,
    'DOUTHIT': 0,
    'DOUTHITT': 0,
    'DOUTRE': 0,
    'DOUTRICH': 0,
    'DOUTT': 0,
    'DOUTY': 0,
    'DOUVIER': 0,
    'DOUVILLE': 0,
    'DOUYON': 0,
    'DOUZART': 0,
    'DOVAL': 0,
    'DOVALE': 0,
    'DOVALINA': 0,
    'DOVAN': 0,
    'DOVE': 0,
    'DOVEL': 0,
    'DOVELL': 0,
    'DOVENBARGER': 0,
    'DOVER': 0,
    'DOVERS': 0,
    'DOVERSPIKE': 0,
    'DOVEY': 0,
    'DOVI': 0,
    'DOVIAK': 0,
    'DOVICH': 0,
    'DOVICO': 0,
    'DOVIDIO': 0,
    'DOVIE': 1,
    'DOVIN': 0,
    'DOW': 0,
    'DOWARD': 0,
    'DOWD': 0,
    'DOWDA': 0,
    'DOWDALL': 0,
    'DOWDELL': 0,
    'DOWDEN': 0,
    'DOWDEY': 0,
    'DOWDING': 0,
    'DOWDLE': 0,
    'DOWDS': 0,
    'DOWDY': 0,
    'DOWE': 0,
    'DOWELL': 0,
    'DOWEN': 0,
    'DOWER': 0,
    'DOWERS': 0,
    'DOWERY': 0,
    'DOWEY': 0,
    'DOWGIALLO': 0,
    'DOWHAN': 0,
    'DOWHOWER': 0,
    'DOWIE': 0,
    'DOWING': 0,
    'DOWIS': 0,
    'DOWKER': 0,
    'DOWL': 0,
    'DOWLAND': 0,
    'DOWLATSHAHI': 0,
    'DOWLEARN': 0,
    'DOWLEN': 0,
    'DOWLER': 0,
    'DOWLESS': 0,
    'DOWLEY': 0,
    'DOWLIN': 0,
    'DOWLING': 0,
    'DOWMAN': 0,
    'DOWN': 0,
    'DOWNAM': 0,
    'DOWNARD': 0,
    'DOWNEN': 0,
    'DOWNER': 0,
    'DOWNES': 0,
    'DOWNEY': 0,
    'DOWNHAM': 0,
    'DOWNHOUR': 0,
    'DOWNIE': 0,
    'DOWNIN': 0,
    'DOWNING': 0,
    'DOWNS': 0,
    'DOWNTON': 0,
    'DOWNUM': 0,
    'DOWNWARD': 0,
    'DOWNY': 0,
    'DOWREY': 0,
    'DOWS': 0,
    'DOWSE': 0,
    'DOWSETT': 0,
    'DOWSEY': 0,
    'DOWSON': 0,
    'DOWTIN': 0,
    'DOWTY': 0,
    'DOX': 0,
    'DOXEY': 0,
    'DOXIE': 0,
    'DOXSEE': 0,
    'DOXSEY': 0,
    'DOXTADER': 0,
    'DOXTATER': 0,
    'DOXTATOR': 0,
    'DOY': 0,
    'DOYAL': 0,
    'DOYE': 0,
    'DOYEL': 0,
    'DOYEN': 0,
    'DOYER': 0,
    'DOYLE': 0.44670050761421315,
    'DOYLEY': 0,
    'DOYNE': 0,
    'DOYON': 0,
    'DOZA': 0,
    'DOZAL': 0,
    'DOZARK': 0,
    'DOZE': 0,
    'DOZEMAN': 0,
    'DOZER': 0,
    'DOZIER': 0,
    'DOZLER': 0,
    'DOZOIS': 0,
    'DRAA': 0,
    'DRAAYER': 0,
    'DRAB': 0,
    'DRABANT': 0,
    'DRABCZYK': 0,
    'DRABEK': 0,
    'DRABIC': 0,
    'DRABICK': 0,
    'DRABIK': 0,
    'DRABKIN': 0,
    'DRACE': 0,
    'DRACH': 0,
    'DRACHENBERG': 0,
    'DRACHMAN': 0,
    'DRACUP': 0,
    'DRADER': 0,
    'DRAEGER': 0,
    'DRAFFEN': 0,
    'DRAFFIN': 0,
    'DRAFT': 0,
    'DRAFTON': 0,
    'DRAFTS': 0,
    'DRAG': 0,
    'DRAGAN': 0,
    'DRAGANI': 0,
    'DRAGE': 0,
    'DRAGER': 0,
    'DRAGG': 0,
    'DRAGGOO': 0,
    'DRAGHI': 0,
    'DRAGIC': 0,
    'DRAGICEVIC': 0,
    'DRAGICEVICH': 0,
    'DRAGICH': 0,
    'DRAGISIC': 0,
    'DRAGNA': 0,
    'DRAGO': 0,
    'DRAGOMIR': 0,
    'DRAGON': 0,
    'DRAGONE': 0,
    'DRAGONETTE': 0,
    'DRAGONETTI': 0,
    'DRAGOO': 0,
    'DRAGOON': 0,
    'DRAGOS': 0,
    'DRAGOTTA': 0,
    'DRAGOTTO': 0,
    'DRAGOVIC': 0,
    'DRAGOVICH': 0,
    'DRAGSETH': 0,
    'DRAGT': 0,
    'DRAGUN': 0,
    'DRAHEIM': 0,
    'DRAHER': 0,
    'DRAHN': 0,
    'DRAHOS': 0,
    'DRAHOTA': 0,
    'DRAIME': 0,
    'DRAIN': 0,
    'DRAINE': 0,
    'DRAINER': 0,
    'DRAINVILLE': 0,
    'DRAIS': 0,
    'DRAISEY': 0,
    'DRAKE': 0,
    'DRAKEFORD': 0,
    'DRAKELEY': 0,
    'DRAKER': 0,
    'DRAKES': 0,
    'DRAKOPOULOS': 0,
    'DRAKOS': 0,
    'DRAKULIC': 0,
    'DRAKULICH': 0,
    'DRALLE': 0,
    'DRAMAN': 0,
    'DRAME': 0,
    'DRAMIS': 0,
    'DRAMMEH': 0,
    'DRAN': 0,
    'DRANCHAK': 0,
    'DRANE': 0,
    'DRANEY': 0,
    'DRANGE': 0,
    'DRANGINIS': 0,
    'DRANOFF': 0,
    'DRANSFIELD': 0,
    'DRANTES': 0,
    'DRAPALA': 0,
    'DRAPCHO': 0,
    'DRAPE': 0,
    'DRAPEAU': 0,
    'DRAPELA': 0,
    'DRAPER': 0,
    'DRAPKIN': 0,
    'DRAPP': 0,
    'DRASHER': 0,
    'DRASKOVIC': 0,
    'DRASKOVICH': 0,
    'DRASS': 0,
    'DRATCH': 0,
    'DRATH': 0,
    'DRAUCKER': 0,
    'DRAUDE': 0,
    'DRAUDT': 0,
    'DRAUGHAN': 0,
    'DRAUGHN': 0,
    'DRAUGHON': 0,
    'DRAUS': 0,
    'DRAUT': 0,
    'DRAVENSTOTT': 0,
    'DRAVES': 0,
    'DRAVING': 0,
    'DRAVIS': 0,
    'DRAWBAUGH': 0,
    'DRAWBRIDGE': 0,
    'DRAWDY': 0,
    'DRAWE': 0,
    'DRAWHORN': 0,
    'DRAXLER': 0,
    'DRAY': 0,
    'DRAYDEN': 0,
    'DRAYER': 0,
    'DRAYTON': 0,
    'DRAZ': 0,
    'DRAZBA': 0,
    'DRAZEK': 0,
    'DRAZEN': 0,
    'DRAZIC': 0,
    'DRAZICH': 0,
    'DRAZIN': 0,
    'DRAZKOWSKI': 0,
    'DRDA': 0,
    'DREA': 0,
    'DREAD': 0,
    'DREADEN': 0,
    'DREADFULWATER': 0,
    'DREADIN': 0,
    'DREAGER': 0,
    'DREAMA': 1,
    'DREAMER': 0,
    'DREAS': 0,
    'DREBENSTEDT': 0,
    'DREBES': 0,
    'DREBIN': 0,
    'DREBLOW': 0,
    'DRECHSEL': 0,
    'DRECHSLER': 0,
    'DRECKMAN': 0,
    'DREDDEN': 0,
    'DREDGE': 0,
    'DREER': 0,
    'DREES': 0,
    'DREESE': 0,
    'DREESEN': 0,
    'DREESMAN': 0,
    'DREESSEN': 0,
    'DREESZEN': 0,
    'DREFFS': 0,
    'DREFKE': 0,
    'DREGER': 0,
    'DREGGORS': 0,
    'DREGNE': 0,
    'DREHER': 0,
    'DREHMEL': 0,
    'DREHOBL': 0,
    'DREIBELBIS': 0,
    'DREIER': 0,
    'DREIFUERST': 0,
    'DREIFUS': 0,
    'DREIFUSS': 0,
    'DREIKOSEN': 0,
    'DREILING': 0,
    'DREIMAN': 0,
    'DREIS': 0,
    'DREISBACH': 0,
    'DREISS': 0,
    'DREISTADT': 0,
    'DREITH': 0,
    'DREITLEIN': 0,
    'DREKE': 0,
    'DRELICH': 0,
    'DRELICK': 0,
    'DRELL': 0,
    'DREMA': 1,
    'DREMANN': 0,
    'DREMEL': 0,
    'DRENCKHAHN': 0,
    'DRENDEL': 0,
    'DRENKHAHN': 0,
    'DRENNAN': 0,
    'DRENNEN': 0,
    'DRENNER': 0,
    'DRENNING': 0,
    'DRENNON': 0,
    'DRENON': 0,
    'DRENT': 0,
    'DRENTH': 0,
    'DRENTLAW': 0,
    'DRENZEK': 0,
    'DREON': 0,
    'DREPAUL': 0,
    'DREPS': 0,
    'DRERUP': 0,
    'DRES': 0,
    'DRESBACH': 0,
    'DRESBACK': 0,
    'DRESCH': 0,
    'DRESCHER': 0,
    'DRESDEN': 0,
    'DRESDNER': 0,
    'DRESEL': 0,
    'DRESEN': 0,
    'DRESHER': 0,
    'DRESKIN': 0,
    'DRESLINSKI': 0,
    'DRESNER': 0,
    'DRESS': 0,
    'DRESSEL': 0,
    'DRESSELHAUS': 0,
    'DRESSELL': 0,
    'DRESSEN': 0,
    'DRESSER': 0,
    'DRESSING': 0,
    'DRESSLAR': 0,
    'DRESSLER': 0,
    'DRESSMAN': 0,
    'DRESSNER': 0,
    'DRESTE': 0,
    'DRETZKA': 0,
    'DREVER': 0,
    'DREVES': 0,
    'DREVLOW': 0,
    'DREW': 0.7494004796163071,
    'DREWA': 0,
    'DREWEK': 0,
    'DREWEL': 0,
    'DREWELOW': 0,
    'DREWER': 0,
    'DREWERY': 0,
    'DREWES': 0,
    'DREWETT': 0,
    'DREWITZ': 0,
    'DREWNIAK': 0,
    'DREWNO': 0,
    'DREWNOWSKI': 0,
    'DREWREY': 0,
    'DREWRY': 0,
    'DREWS': 0,
    'DREWYOR': 0,
    'DREXEL': 0,
    'DREXLER': 0,
    'DREY': 0,
    'DREYER': 0,
    'DREYFUS': 0,
    'DREYFUSS': 0,
    'DREZEK': 0,
    'DREZNER': 0,
    'DRICK': 0,
    'DRIEDGER': 0,
    'DRIELING': 0,
    'DRIEMEYER': 0,
    'DRIER': 0,
    'DRIES': 0,
    'DRIESBACH': 0,
    'DRIESEN': 0,
    'DRIESENGA': 0,
    'DRIESSE': 0,
    'DRIESSEN': 0,
    'DRIETZ': 0,
    'DRIEVER': 0,
    'DRIFFILL': 0,
    'DRIFT': 0,
    'DRIGGARS': 0,
    'DRIGGERS': 0,
    'DRIGGINS': 0,
    'DRIGGS': 0,
    'DRIGHT': 0,
    'DRILL': 0,
    'DRILLER': 0,
    'DRILLING': 0,
    'DRINAN': 0,
    'DRING': 0,
    'DRINKA': 0,
    'DRINKALL': 0,
    'DRINKARD': 0,
    'DRINKER': 0,
    'DRINKS': 0,
    'DRINKWALTER': 0,
    'DRINKWATER': 0,
    'DRINKWINE': 0,
    'DRINNEN': 0,
    'DRINNON': 0,
    'DRIPPS': 0,
    'DRISCOL': 0,
    'DRISCOLL': 0,
    'DRISDALE': 0,
    'DRISDOM': 0,
    'DRISH': 0,
    'DRISKEL': 0,
    'DRISKELL': 0,
    'DRISKILL': 0,
    'DRISKO': 0,
    'DRISLANE': 0,
    'DRISSEL': 0,
    'DRITSAS': 0,
    'DRITZ': 0,
    'DRIVAS': 0,
    'DRIVER': 0,
    'DRNEK': 0,
    'DROB': 0,
    'DROBAC': 0,
    'DROBECK': 0,
    'DROBEK': 0,
    'DROBINSKI': 0,
    'DROBISH': 0,
    'DROBNEY': 0,
    'DROBNICK': 0,
    'DROBNY': 0,
    'DROBOT': 0,
    'DRODDY': 0,
    'DROEGE': 0,
    'DROEGEMUELLER': 0,
    'DROESCH': 0,
    'DROESE': 0,
    'DROESSLER': 0,
    'DROGAN': 0,
    'DROGE': 0,
    'DROGIN': 0,
    'DROGO': 0,
    'DROGOS': 0,
    'DROGOWSKI': 0,
    'DROHAN': 0,
    'DROHMAN': 0,
    'DROKE': 0,
    'DROLET': 0,
    'DROLETTE': 0,
    'DROLL': 0,
    'DROLLETTE': 0,
    'DROLLINGER': 0,
    'DROLSHAGEN': 0,
    'DROMGOOLE': 0,
    'DRON': 0,
    'DRONE': 0,
    'DRONEBURG': 0,
    'DRONEN': 0,
    'DRONES': 0,
    'DRONET': 0,
    'DRONEY': 0,
    'DRONG': 0,
    'DRONZEK': 0,
    'DROOG': 0,
    'DROOGSMA': 0,
    'DROOK': 0,
    'DROP': 0,
    'DROPE': 0,
    'DROPIK': 0,
    'DROPKIN': 0,
    'DROPP': 0,
    'DROPPA': 0,
    'DROPPERS': 0,
    'DROPPS': 0,
    'DROR': 0,
    'DROSCHE': 0,
    'DROSE': 0,
    'DROSKE': 0,
    'DROSKI': 0,
    'DROSKY': 0,
    'DROSOS': 0,
    'DROSS': 0,
    'DROSSART': 0,
    'DROSSEL': 0,
    'DROSSMAN': 0,
    'DROSSOS': 0,
    'DROST': 0,
    'DROSTE': 0,
    'DROSTER': 0,
    'DROTAR': 0,
    'DROTLEFF': 0,
    'DROTOS': 0,
    'DROTT': 0,
    'DROUBAY': 0,
    'DROUET': 0,
    'DROUGAS': 0,
    'DROUGHT': 0,
    'DROUHARD': 0,
    'DROUILLARD': 0,
    'DROUIN': 0,
    'DROUSE': 0,
    'DROVER': 0,
    'DROW': 0,
    'DROWN': 0,
    'DROWNE': 0,
    'DROWNS': 0,
    'DROZ': 0,
    'DROZD': 0,
    'DROZDA': 0,
    'DROZDOWICZ': 0,
    'DROZDOWSKI': 0,
    'DROZDZ': 0,
    'DROZE': 0,
    'DRUBE': 0,
    'DRUCE': 0,
    'DRUCILLA': 1,
    'DRUCK': 0,
    'DRUCKEMILLER': 0,
    'DRUCKENMILLER': 0,
    'DRUCKER': 0,
    'DRUCKMAN': 0,
    'DRUCKREY': 0,
    'DRUDE': 0,
    'DRUDGE': 0,
    'DRUDING': 0,
    'DRUDY': 0,
    'DRUEKE': 0,
    'DRUEN': 0,
    'DRUERY': 0,
    'DRUFFEL': 0,
    'DRUGA': 0,
    'DRUGAN': 0,
    'DRUHAN': 0,
    'DRUHOT': 0,
    'DRUIEN': 0,
    'DRUIN': 0,
    'DRUITT': 0,
    'DRUKER': 0,
    'DRULEY': 0,
    'DRULLINGER': 0,
    'DRUM': 0,
    'DRUMGO': 0,
    'DRUMGOLD': 0,
    'DRUMGOLE': 0,
    'DRUMGOOLE': 0,
    'DRUMHEISER': 0,
    'DRUMHELLER': 0,
    'DRUMM': 0,
    'DRUMMER': 0,
    'DRUMMEY': 0,
    'DRUMMING': 0,
    'DRUMMOND': 0,
    'DRUMMONDS': 0,
    'DRUMMY': 0,
    'DRUMOND': 0,
    'DRUMRIGHT': 0,
    'DRUMWRIGHT': 0,
    'DRURY': 0,
    'DRUSCH': 0,
    'DRUSCHEL': 0,
    'DRUSE': 0,
    'DRUSHEL': 0,
    'DRUSILLA': 1,
    'DRUSS': 0,
    'DRUST': 0,
    'DRUYOR': 0,
    'DRWAL': 0,
    'DRY': 0,
    'DRYBREAD': 0,
    'DRYBURGH': 0,
    'DRYDEN': 0,
    'DRYE': 0,
    'DRYER': 0,
    'DRYJA': 0,
    'DRYLIE': 0,
    'DRYMAN': 0,
    'DRYMON': 0,
    'DRYNAN': 0,
    'DRYSDALE': 0,
    'DRYWATER': 0,
    'DRZAL': 0,
    'DRZEWICKI': 0,
    'DRZEWIECKI': 0,
    'DRZYMALA': 0,
    'DSA': 0,
    'DSCHAAK': 0,
    'DSILVA': 0,
    'DSOUZA': 0,
    'DU': 0,
    'DUA': 0,
    'DUAH': 0,
    'DUALE': 0,
    'DUAN': 0,
    'DUANE': 0.9911185480756854,
    'DUANY': 0,
    'DUARDO': 0,
    'DUART': 0,
    'DUARTE': 0,
    'DUAX': 0,
    'DUB': 0,
    'DUBA': 0,
    'DUBACH': 0,
    'DUBACK': 0,
    'DUBAL': 0,
    'DUBALL': 0,
    'DUBAN': 0,
    'DUBAR': 0,
    'DUBARD': 0,
    'DUBARRY': 0,
    'DUBAS': 0,
    'DUBAY': 0,
    'DUBB': 0,
    'DUBBE': 0,
    'DUBBELDE': 0,
    'DUBBELS': 0,
    'DUBBERKE': 0,
    'DUBBERLY': 0,
    'DUBBERT': 0,
    'DUBBIN': 0,
    'DUBBLE': 0,
    'DUBBS': 0,
    'DUBE': 0,
    'DUBEA': 0,
    'DUBEAU': 0,
    'DUBEC': 0,
    'DUBECK': 0,
    'DUBEE': 0,
    'DUBEL': 0,
    'DUBELL': 0,
    'DUBEN': 0,
    'DUBENDORF': 0,
    'DUBENSKY': 0,
    'DUBER': 0,
    'DUBERRY': 0,
    'DUBERSTEIN': 0,
    'DUBERT': 0,
    'DUBES': 0,
    'DUBEY': 0,
    'DUBIA': 0,
    'DUBICH': 0,
    'DUBICK': 0,
    'DUBICKI': 0,
    'DUBIE': 0,
    'DUBIEL': 0,
    'DUBIK': 0,
    'DUBIL': 0,
    'DUBIN': 0,
    'DUBINA': 0,
    'DUBINSKAYA': 0,
    'DUBINSKI': 0,
    'DUBINSKY': 0,
    'DUBIS': 0,
    'DUBISAR': 0,
    'DUBITSKY': 0,
    'DUBKE': 0,
    'DUBLE': 0,
    'DUBLER': 0,
    'DUBLIN': 0,
    'DUBLINSKI': 0,
    'DUBLO': 0,
    'DUBMAN': 0,
    'DUBNER': 0,
    'DUBNICKA': 0,
    'DUBOFF': 0,
    'DUBOIS': 0,
    'DUBOISE': 0,
    'DUBON': 0,
    'DUBORD': 0,
    'DUBOS': 0,
    'DUBOSE': 0,
    'DUBOV': 0,
    'DUBOVIK': 0,
    'DUBOVOY': 0,
    'DUBOVSKY': 0,
    'DUBOW': 0,
    'DUBOWSKI': 0,
    'DUBOWSKY': 0,
    'DUBRAVA': 0,
    'DUBRAY': 0,
    'DUBRE': 0,
    'DUBREE': 0,
    'DUBREUIL': 0,
    'DUBREY': 0,
    'DUBRIDGE': 0,
    'DUBRO': 0,
    'DUBROC': 0,
    'DUBROCK': 0,
    'DUBROFF': 0,
    'DUBROSKY': 0,
    'DUBROVSKY': 0,
    'DUBROW': 0,
    'DUBROWSKI': 0,
    'DUBRUL': 0,
    'DUBRULE': 0,
    'DUBRY': 0,
    'DUBS': 0,
    'DUBSKY': 0,
    'DUBSON': 0,
    'DUBUC': 0,
    'DUBUISSON': 0,
    'DUBUQUE': 0,
    'DUBUS': 0,
    'DUBY': 0,
    'DUBYAK': 0,
    'DUC': 0,
    'DUCA': 0,
    'DUCAR': 0,
    'DUCAS': 0,
    'DUCASSE': 0,
    'DUCAT': 0,
    'DUCATO': 0,
    'DUCATTE': 0,
    'DUCAY': 0,
    'DUCCINI': 0,
    'DUCE': 0,
    'DUCEY': 0,
    'DUCH': 0,
    'DUCHAC': 0,
    'DUCHAINE': 0,
    'DUCHAM': 0,
    'DUCHAMP': 0,
    'DUCHAN': 0,
    'DUCHANE': 0,
    'DUCHARME': 0,
    'DUCHATEAU': 0,
    'DUCHE': 0,
    'DUCHEINE': 0,
    'DUCHEK': 0,
    'DUCHEMIN': 0,
    'DUCHENE': 0,
    'DUCHENEAUX': 0,
    'DUCHESNE': 0,
    'DUCHESNEAU': 0,
    'DUCHI': 0,
    'DUCHIN': 0,
    'DUCHNOWSKI': 0,
    'DUCHON': 0,
    'DUCHOW': 0,
    'DUCHSCHER': 0,
    'DUCHSCHERER': 0,
    'DUCHSHERER': 0,
    'DUCK': 0,
    'DUCKART': 0,
    'DUCKER': 0,
    'DUCKERT': 0,
    'DUCKERY': 0,
    'DUCKETT': 0,
    'DUCKHAM': 0,
    'DUCKLOW': 0,
    'DUCKRO': 0,
    'DUCKSON': 0,
    'DUCKSWORTH': 0,
    'DUCKWALL': 0,
    'DUCKWILER': 0,
    'DUCKWITZ': 0,
    'DUCKWORTH': 0,
    'DUCLO': 0,
    'DUCLOS': 0,
    'DUCO': 0,
    'DUCOING': 0,
    'DUCOMMUN': 0,
    'DUCOS': 0,
    'DUCOTE': 0,
    'DUCRE': 0,
    'DUCRET': 0,
    'DUCROS': 0,
    'DUCSAY': 0,
    'DUCTAN': 0,
    'DUCUSIN': 0,
    'DUCY': 0,
    'DUDA': 0,
    'DUDAK': 0,
    'DUDAR': 0,
    'DUDAS': 0,
    'DUDASH': 0,
    'DUDDEN': 0,
    'DUDDERAR': 0,
    'DUDDING': 0,
    'DUDDLES': 0,
    'DUDDLESTON': 0,
    'DUDDY': 0,
    'DUDE': 0,
    'DUDECK': 0,
    'DUDEK': 0,
    'DUDEN': 0,
    'DUDENHEFER': 0,
    'DUDENHOEFER': 0,
    'DUDENHOEFFER': 0,
    'DUDERSTADT': 0,
    'DUDGEON': 0,
    'DUDIAK': 0,
    'DUDICH': 0,
    'DUDICK': 0,
    'DUDIK': 0,
    'DUDKA': 0,
    'DUDKIEWICZ': 0,
    'DUDKO': 0,
    'DUDKOWSKI': 0,
    'DUDLEY': 0.41114664230242115,
    'DUDMAN': 0,
    'DUDNEY': 0,
    'DUDO': 0,
    'DUDOIT': 0,
    'DUDRA': 0,
    'DUDREY': 0,
    'DUDUKOVICH': 0,
    'DUDUM': 0,
    'DUDYCHA': 0,
    'DUDZIAK': 0,
    'DUDZIC': 0,
    'DUDZIK': 0,
    'DUDZINSKI': 0,
    'DUE': 0,
    'DUEA': 0,
    'DUEBER': 0,
    'DUECK': 0,
    'DUECKER': 0,
    'DUEDE': 0,
    'DUEHR': 0,
    'DUEHRING': 0,
    'DUEITT': 0,
    'DUEKER': 0,
    'DUEL': 0,
    'DUELING': 0,
    'DUELL': 0,
    'DUELLETTE': 0,
    'DUELLEY': 0,
    'DUELLMAN': 0,
    'DUELLO': 0,
    'DUEMLER': 0,
    'DUEMMEL': 0,
    'DUENAS': 0,
    'DUENAZ': 0,
    'DUENES': 0,
    'DUENEZ': 0,
    'DUENKEL': 0,
    'DUENO': 0,
    'DUENOW': 0,
    'DUENSING': 0,
    'DUENWALD': 0,
    'DUER': 0,
    'DUERDEN': 0,
    'DUERFELDT': 0,
    'DUERING': 0,
    'DUERINGER': 0,
    'DUERK': 0,
    'DUERKOP': 0,
    'DUERKSEN': 0,
    'DUERR': 0,
    'DUERRE': 0,
    'DUERSCH': 0,
    'DUERSON': 0,
    'DUERST': 0,
    'DUES': 0,
    'DUESCHER': 0,
    'DUESENBERG': 0,
    'DUESING': 0,
    'DUESLER': 0,
    'DUESTERBECK': 0,
    'DUESTERHAUS': 0,
    'DUESTERHOEFT': 0,
    'DUET': 0,
    'DUETSCH': 0,
    'DUETT': 0,
    'DUEWEKE': 0,
    'DUEWEL': 0,
    'DUEY': 0,
    'DUEZ': 0,
    'DUFALA': 0,
    'DUFAULT': 0,
    'DUFEK': 0,
    'DUFEL': 0,
    'DUFER': 0,
    'DUFF': 0,
    'DUFFALA': 0,
    'DUFFANY': 0,
    'DUFFE': 0,
    'DUFFEE': 0,
    'DUFFEK': 0,
    'DUFFEL': 0,
    'DUFFELL': 0,
    'DUFFER': 0,
    'DUFFETT': 0,
    'DUFFEY': 0,
    'DUFFICY': 0,
    'DUFFIE': 0,
    'DUFFIELD': 0,
    'DUFFIN': 0,
    'DUFFINA': 0,
    'DUFFINEY': 0,
    'DUFFLE': 0,
    'DUFFLEY': 0,
    'DUFFNER': 0,
    'DUFFNEY': 0,
    'DUFFORD': 0,
    'DUFFRIN': 0,
    'DUFFUS': 0,
    'DUFFY': 0,
    'DUFLO': 0,
    'DUFLOTH': 0,
    'DUFNER': 0,
    'DUFOE': 0,
    'DUFORD': 0,
    'DUFORE': 0,
    'DUFORT': 0,
    'DUFOUR': 0,
    'DUFRAIN': 0,
    'DUFRAINE': 0,
    'DUFRANE': 0,
    'DUFRENE': 0,
    'DUFRENNE': 0,
    'DUFRESNE': 0,
    'DUFT': 0,
    'DUFTON': 0,
    'DUFTY': 0,
    'DUFUR': 0,
    'DUGA': 0,
    'DUGAL': 0,
    'DUGAN': 0,
    'DUGANDZIC': 0,
    'DUGANS': 0,
    'DUGAR': 0,
    'DUGARD': 0,
    'DUGAS': 0,
    'DUGAT': 0,
    'DUGAY': 0,
    'DUGDALE': 0,
    'DUGE': 0,
    'DUGER': 0,
    'DUGGAL': 0,
    'DUGGAN': 0,
    'DUGGANS': 0,
    'DUGGAR': 0,
    'DUGGER': 0,
    'DUGGIN': 0,
    'DUGGINS': 0,
    'DUGGIRALA': 0,
    'DUGHI': 0,
    'DUGHMAN': 0,
    'DUGI': 0,
    'DUGIE': 0,
    'DUGINSKI': 0,
    'DUGLE': 0,
    'DUGO': 0,
    'DUGOSH': 0,
    'DUGRE': 0,
    'DUGUAY': 0,
    'DUGUE': 0,
    'DUGUID': 0,
    'DUH': 0,
    'DUHAIME': 0,
    'DUHAME': 0,
    'DUHAMEL': 0,
    'DUHAMELL': 0,
    'DUHAN': 0,
    'DUHANEY': 0,
    'DUHART': 0,
    'DUHE': 0,
    'DUHIG': 0,
    'DUHIGG': 0,
    'DUHL': 0,
    'DUHME': 0,
    'DUHN': 0,
    'DUHON': 0,
    'DUHR': 0,
    'DUHS': 0,
    'DUIGNAN': 0,
    'DUIMSTRA': 0,
    'DUIN': 0,
    'DUININCK': 0,
    'DUIS': 0,
    'DUITSMAN': 0,
    'DUJARDIN': 0,
    'DUJMOVIC': 0,
    'DUK': 0,
    'DUKA': 0,
    'DUKART': 0,
    'DUKAS': 0,
    'DUKAT': 0,
    'DUKATE': 0,
    'DUKATZ': 0,
    'DUKE': 0,
    'DUKEHART': 0,
    'DUKELOW': 0,
    'DUKEMAN': 0,
    'DUKER': 0,
    'DUKES': 0,
    'DUKESHIRE': 0,
    'DUKET': 0,
    'DUKETT': 0,
    'DUKETTE': 0,
    'DUKIC': 0,
    'DUKICH': 0,
    'DUKOWITZ': 0,
    'DUL': 0,
    'DULA': 0,
    'DULAC': 0,
    'DULAI': 0,
    'DULAK': 0,
    'DULAN': 0,
    'DULANEY': 0,
    'DULANTO': 0,
    'DULANY': 0,
    'DULAS': 0,
    'DULAY': 0,
    'DULBERG': 0,
    'DULCE': 0.9861932938856016,
    'DULCIE': 1,
    'DULCIO': 0,
    'DULDULAO': 0,
    'DULEBOHN': 0,
    'DULEK': 0,
    'DULEMBA': 0,
    'DULEY': 0,
    'DULGAR': 0,
    'DULIAN': 0,
    'DULICK': 0,
    'DULIK': 0,
    'DULIN': 0,
    'DULING': 0,
    'DULINSKI': 0,
    'DULISSE': 0,
    'DULITZ': 0,
    'DULKA': 0,
    'DULKOSKI': 0,
    'DULL': 0,
    'DULLA': 0,
    'DULLAGHAN': 0,
    'DULLARD': 0,
    'DULLE': 0,
    'DULLEA': 0,
    'DULLEN': 0,
    'DULLER': 0,
    'DULLEY': 0,
    'DULLINGER': 0,
    'DULLUM': 0,
    'DULLY': 0,
    'DULMAGE': 0,
    'DULMAINE': 0,
    'DULMAN': 0,
    'DULMES': 0,
    'DULOCK': 0,
    'DULONG': 0,
    'DULSKI': 0,
    'DULSKY': 0,
    'DULTZ': 0,
    'DULUDE': 0,
    'DULWORTH': 0,
    'DULY': 0,
    'DULYEA': 0,
    'DUM': 0,
    'DUMA': 0,
    'DUMADAG': 0,
    'DUMAINE': 0,
    'DUMAIS': 0,
    'DUMAN': 0,
    'DUMAR': 0,
    'DUMARCE': 0,
    'DUMARS': 0,
    'DUMAS': 0,
    'DUMAY': 0,
    'DUMBAR': 0,
    'DUMBAUGH': 0,
    'DUMBAULD': 0,
    'DUMBLETON': 0,
    'DUMBRIQUE': 0,
    'DUMBUYA': 0,
    'DUMDEI': 0,
    'DUMDIE': 0,
    'DUME': 0,
    'DUMELLE': 0,
    'DUMENG': 0,
    'DUMENIGO': 0,
    'DUMES': 0,
    'DUMESNIL': 0,
    'DUMEY': 0,
    'DUMEZ': 0,
    'DUMFORD': 0,
    'DUMIRE': 0,
    'DUMITRESCU': 0,
    'DUMITRU': 0,
    'DUMKA': 0,
    'DUMKE': 0,
    'DUMLAO': 0,
    'DUMLER': 0,
    'DUMM': 0,
    'DUMMER': 0,
    'DUMMERMUTH': 0,
    'DUMMETT': 0,
    'DUMMITT': 0,
    'DUMO': 0,
    'DUMOLT': 0,
    'DUMONCEAUX': 0,
    'DUMOND': 0,
    'DUMONT': 0,
    'DUMONTIER': 0,
    'DUMORNAY': 0,
    'DUMOUCHEL': 0,
    'DUMOULIN': 0,
    'DUMPERT': 0,
    'DUMPHY': 0,
    'DUMPIT': 0,
    'DUMPSON': 0,
    'DUMS': 0,
    'DUMSER': 0,
    'DUN': 0,
    'DUNA': 0,
    'DUNAGAN': 0,
    'DUNAGIN': 0,
    'DUNAHEE': 0,
    'DUNAHOO': 0,
    'DUNAJ': 0,
    'DUNAJSKI': 0,
    'DUNAKEY': 0,
    'DUNAKIN': 0,
    'DUNAS': 0,
    'DUNAVAN': 0,
    'DUNAVANT': 0,
    'DUNAVENT': 0,
    'DUNAVIN': 0,
    'DUNAWAY': 0,
    'DUNAY': 0,
    'DUNAYER': 0,
    'DUNBAR': 0,
    'DUNBRACK': 0,
    'DUNCAN': 0.12646793134598014,
    'DUNCANSON': 0,
    'DUNCH': 0,
    'DUNCIL': 0,
    'DUNCKEL': 0,
    'DUNCKER': 0,
    'DUNCKLEE': 0,
    'DUNCKLEY': 0,
    'DUNCOMBE': 0,
    'DUNCUM': 0,
    'DUNDA': 0,
    'DUNDAS': 0,
    'DUNDEE': 0,
    'DUNDER': 0,
    'DUNDERDALE': 0,
    'DUNDON': 0,
    'DUNDORE': 0,
    'DUNE': 0,
    'DUNEGAN': 0,
    'DUNEHEW': 0,
    'DUNEMAN': 0,
    'DUNETZ': 0,
    'DUNEVANT': 0,
    'DUNFEE': 0,
    'DUNFEY': 0,
    'DUNFIELD': 0,
    'DUNFORD': 0,
    'DUNG': 0.9174311926605505,
    'DUNGAN': 0,
    'DUNGCA': 0,
    'DUNGEE': 0,
    'DUNGER': 0,
    'DUNGEY': 0,
    'DUNGO': 0,
    'DUNGY': 0,
    'DUNHAM': 0,
    'DUNHAN': 0,
    'DUNI': 0,
    'DUNICAN': 0,
    'DUNIFER': 0,
    'DUNIFON': 0,
    'DUNIGAN': 0,
    'DUNING': 0,
    'DUNITHAN': 0,
    'DUNIVAN': 0,
    'DUNIVANT': 0,
    'DUNIVEN': 0,
    'DUNIVENT': 0,
    'DUNIVIN': 0,
    'DUNK': 0,
    'DUNKEL': 0,
    'DUNKELBERG': 0,
    'DUNKELBERGER': 0,
    'DUNKELMAN': 0,
    'DUNKEN': 0,
    'DUNKER': 0,
    'DUNKERLEY': 0,
    'DUNKERLY': 0,
    'DUNKERSON': 0,
    'DUNKERTON': 0,
    'DUNKIN': 0,
    'DUNKINS': 0,
    'DUNKIRK': 0,
    'DUNKLAU': 0,
    'DUNKLE': 0,
    'DUNKLEBERGER': 0,
    'DUNKLEE': 0,
    'DUNKLEMAN': 0,
    'DUNKLEY': 0,
    'DUNKLIN': 0,
    'DUNKMAN': 0,
    'DUNKS': 0,
    'DUNKUM': 0,
    'DUNLAP': 0,
    'DUNLAVEY': 0,
    'DUNLAVY': 0,
    'DUNLAY': 0,
    'DUNLEA': 0,
    'DUNLEAVY': 0,
    'DUNLEVY': 0,
    'DUNLOP': 0,
    'DUNLOW': 0,
    'DUNMAN': 0,
    'DUNMARS': 0,
    'DUNMEYER': 0,
    'DUNMIRE': 0,
    'DUNMON': 0,
    'DUNMORE': 0,
    'DUNMYER': 0,
    'DUNMYRE': 0,
    'DUNN': 0,
    'DUNNAGAN': 0,
    'DUNNAHOE': 0,
    'DUNNAHOO': 0,
    'DUNNAM': 0,
    'DUNNAN': 0,
    'DUNNAVANT': 0,
    'DUNNAWAY': 0,
    'DUNNE': 0,
    'DUNNEBACK': 0,
    'DUNNEGAN': 0,
    'DUNNELL': 0,
    'DUNNELLS': 0,
    'DUNNER': 0,
    'DUNNETT': 0,
    'DUNNICK': 0,
    'DUNNIGAN': 0,
    'DUNNIHOO': 0,
    'DUNNING': 0,
    'DUNNINGS': 0,
    'DUNNINGTON': 0,
    'DUNNIVAN': 0,
    'DUNNIVANT': 0,
    'DUNNO': 0,
    'DUNNOCK': 0,
    'DUNNUCK': 0,
    'DUNNUM': 0,
    'DUNOW': 0,
    'DUNPHEY': 0,
    'DUNPHY': 0,
    'DUNSCOMB': 0,
    'DUNSCOMBE': 0,
    'DUNSE': 0,
    'DUNSEATH': 0,
    'DUNSEITH': 0,
    'DUNSETH': 0,
    'DUNSFORD': 0,
    'DUNSHEE': 0,
    'DUNSHIE': 0,
    'DUNSING': 0,
    'DUNSKY': 0,
    'DUNSMOOR': 0,
    'DUNSMORE': 0,
    'DUNSMUIR': 0,
    'DUNSON': 0,
    'DUNST': 0,
    'DUNSTAN': 0,
    'DUNSTER': 0,
    'DUNSTON': 0,
    'DUNSWORTH': 0,
    'DUNTEMAN': 0,
    'DUNTEN': 0,
    'DUNTLEY': 0,
    'DUNTON': 0,
    'DUNTZ': 0,
    'DUNVILLE': 0,
    'DUNWELL': 0,
    'DUNWIDDIE': 0,
    'DUNWOODIE': 0,
    'DUNWOODY': 0,
    'DUNWORTH': 0,
    'DUNYON': 0,
    'DUONG': 0,
    'DUOS': 0,
    'DUPAIX': 0,
    'DUPAR': 0,
    'DUPARD': 0,
    'DUPART': 0,
    'DUPAS': 0,
    'DUPAUL': 0,
    'DUPAY': 0,
    'DUPEA': 0,
    'DUPEE': 0,
    'DUPELL': 0,
    'DUPERE': 0,
    'DUPERON': 0,
    'DUPERRE': 0,
    'DUPERRON': 0,
    'DUPERRY': 0,
    'DUPERT': 0,
    'DUPERVAL': 0,
    'DUPES': 0,
    'DUPEY': 0,
    'DUPHILY': 0,
    'DUPIN': 0,
    'DUPKE': 0,
    'DUPLAGA': 0,
    'DUPLAIN': 0,
    'DUPLAN': 0,
    'DUPLANTIER': 0,
    'DUPLANTIS': 0,
    'DUPLECHAIN': 0,
    'DUPLECHIN': 0,
    'DUPLER': 0,
    'DUPLESSIE': 0,
    'DUPLESSIS': 0,
    'DUPLESSY': 0,
    'DUPLICHAN': 0,
    'DUPLIN': 0,
    'DUPLISEA': 0,
    'DUPLISSEY': 0,
    'DUPNIK': 0,
    'DUPON': 0,
    'DUPONT': 0,
    'DUPONTE': 0,
    'DUPOUX': 0,
    'DUPPER': 0,
    'DUPPINS': 0,
    'DUPPONG': 0,
    'DUPPS': 0,
    'DUPPSTADT': 0,
    'DUPRA': 0,
    'DUPRAS': 0,
    'DUPRAT': 0,
    'DUPRAW': 0,
    'DUPRAY': 0,
    'DUPRE': 0,
    'DUPREE': 0,
    'DUPREY': 0,
    'DUPREZ': 0,
    'DUPRIE': 0,
    'DUPRIEST': 0,
    'DUPRIS': 0,
    'DUPUIE': 0,
    'DUPUIS': 0,
    'DUPUY': 0,
    'DUPY': 0,
    'DUQUAINE': 0,
    'DUQUE': 0,
    'DUQUESNAY': 0,
    'DUQUET': 0,
    'DUQUETTE': 0,
    'DURA': 0,
    'DURACK': 0,
    'DURADA': 0,
    'DURAIN': 0,
    'DURAK': 0,
    'DURAKO': 0,
    'DURAKOVIC': 0,
    'DURAL': 0,
    'DURALL': 0,
    'DURAM': 0,
    'DURAN': 0,
    'DURANCE': 0,
    'DURANCEAU': 0,
    'DURAND': 0,
    'DURANDISSE': 0,
    'DURANDO': 0,
    'DURANGO': 0,
    'DURANLEAU': 0,
    'DURANSO': 0,
    'DURANT': 0,
    'DURANTE': 0,
    'DURAPAU': 0,
    'DURAS': 0,
    'DURASO': 0,
    'DURAY': 0,
    'DURAZO': 0,
    'DURAZZO': 0,
    'DURBAN': 0,
    'DURBANO': 0,
    'DURBEN': 0,
    'DURBIN': 0,
    'DURBORAW': 0,
    'DURBOROW': 0,
    'DURCAN': 0,
    'DURCH': 0,
    'DURCHHOLZ': 0,
    'DURCHOLZ': 0,
    'DURCI': 0,
    'DURDA': 0,
    'DURDAN': 0,
    'DURDEL': 0,
    'DURDEN': 0,
    'DURDIN': 0,
    'DURE': 0,
    'DURECKI': 0,
    'DUREE': 0,
    'DUREL': 0,
    'DURELL': 0,
    'DUREN': 0,
    'DURENBERGER': 0,
    'DURESKY': 0,
    'DURET': 0,
    'DURETT': 0,
    'DURETTE': 0,
    'DUREY': 0,
    'DURFEE': 0,
    'DURFEY': 0,
    'DURFLINGER': 0,
    'DURGA': 0,
    'DURGAN': 0,
    'DURGIN': 0,
    'DURHAM': 0,
    'DURHAN': 0,
    'DURHEIM': 0,
    'DURIAN': 0,
    'DURIC': 0,
    'DURICA': 0,
    'DURICK': 0,
    'DURIE': 0,
    'DURIEUX': 0,
    'DURIG': 0,
    'DURIK': 0,
    'DURING': 0,
    'DURIO': 0,
    'DURIS': 0,
    'DURISH': 0,
    'DURITY': 0,
    'DURIVAGE': 0,
    'DURK': 0,
    'DURKA': 0,
    'DURKAN': 0,
    'DURKE': 0,
    'DURKEE': 0,
    'DURKES': 0,
    'DURKIN': 0,
    'DURKO': 0,
    'DURKOP': 0,
    'DURKOT': 0,
    'DURKOVIC': 0,
    'DURLACHER': 0,
    'DURLAK': 0,
    'DURLAND': 0,
    'DURLER': 0,
    'DURLEY': 0,
    'DURLIN': 0,
    'DURLING': 0,
    'DURM': 0,
    'DURMAN': 0,
    'DURN': 0,
    'DURNAL': 0,
    'DURNAN': 0,
    'DURNBAUGH': 0,
    'DURNELL': 0,
    'DURNER': 0,
    'DURNEY': 0,
    'DURNFORD': 0,
    'DURNIAK': 0,
    'DURNIL': 0,
    'DURNIN': 0,
    'DURNING': 0,
    'DURNWALD': 0,
    'DURO': 0,
    'DUROCHER': 0,
    'DURON': 0,
    'DURONSLET': 0,
    'DUROS': 0,
    'DUROSE': 0,
    'DUROSEAU': 0,
    'DUROSS': 0,
    'DUROSSETTE': 0,
    'DUROST': 0,
    'DUROUSSEAU': 0,
    'DUROW': 0,
    'DUROY': 0,
    'DURR': 0,
    'DURRAH': 0,
    'DURRAN': 0,
    'DURRANCE': 0,
    'DURRANI': 0,
    'DURRANT': 0,
    'DURRE': 0,
    'DURRELL': 0,
    'DURRENBERGER': 0,
    'DURRENCE': 0,
    'DURRER': 0,
    'DURRETT': 0,
    'DURRETTE': 0,
    'DURRILL': 0,
    'DURRIN': 0,
    'DURROUGH': 0,
    'DURRUM': 0,
    'DURRWACHTER': 0,
    'DURRY': 0,
    'DURSI': 0,
    'DURSKI': 0,
    'DURSO': 0,
    'DURST': 0,
    'DURSTELER': 0,
    'DURSTON': 0,
    'DURTSCHI': 0,
    'DURU': 0,
    'DURUSSEL': 0,
    'DURVIN': 0,
    'DURWARD': 0,
    'DURY': 0,
    'DURYEA': 0,
    'DURYEE': 0,
    'DUS': 0,
    'DUSA': 0,
    'DUSABLON': 0,
    'DUSAK': 0,
    'DUSANG': 0,
    'DUSATKO': 0,
    'DUSBABEK': 0,
    'DUSCH': 0,
    'DUSCHEN': 0,
    'DUSCHER': 0,
    'DUSCHL': 0,
    'DUSEK': 0,
    'DUSEL': 0,
    'DUSENBERRY': 0,
    'DUSENBERY': 0,
    'DUSENBURY': 0,
    'DUSH': 0,
    'DUSHA': 0,
    'DUSHAJ': 0,
    'DUSHANE': 0,
    'DUSHARM': 0,
    'DUSHEK': 0,
    'DUSHKIN': 0,
    'DUSI': 0,
    'DUSICK': 0,
    'DUSIK': 0,
    'DUSIN': 0,
    'DUSINA': 0,
    'DUSING': 0,
    'DUSKA': 0,
    'DUSKE': 0,
    'DUSKEY': 0,
    'DUSKIN': 0,
    'DUSKY': 0,
    'DUSLEY': 0,
    'DUSMAN': 0,
    'DUSO': 0,
    'DUSOLD': 0,
    'DUSON': 0,
    'DUSS': 0,
    'DUSSAN': 0,
    'DUSSAULT': 0,
    'DUSSEAU': 0,
    'DUSSEAULT': 0,
    'DUSSEL': 0,
    'DUSSIA': 0,
    'DUSSINGER': 0,
    'DUSSO': 0,
    'DUST': 0,
    'DUSTER': 0,
    'DUSTERHOFT': 0,
    'DUSTI': 1,
    'DUSTIN': 0.989813569094753,
    'DUSTMAN': 0,
    'DUSTON': 0,
    'DUSTY': 1,
    'DUSZA': 0,
    'DUSZAK': 0,
    'DUSZYNSKI': 0,
    'DUTAN': 0,
    'DUTCH': 0,
    'DUTCHAK': 0,
    'DUTCHER': 0,
    'DUTCHESS': 0,
    'DUTCHOVER': 0,
    'DUTE': 0,
    'DUTEAU': 0,
    'DUTERTE': 0,
    'DUTHIE': 0,
    'DUTHLER': 0,
    'DUTHU': 0,
    'DUTIEL': 0,
    'DUTIL': 0,
    'DUTILE': 0,
    'DUTILL': 0,
    'DUTILLY': 0,
    'DUTKA': 0,
    'DUTKIEWICZ': 0,
    'DUTKO': 0,
    'DUTKOWSKI': 0,
    'DUTLER': 0,
    'DUTOIT': 0,
    'DUTRA': 0,
    'DUTREMBLE': 0,
    'DUTRO': 0,
    'DUTROW': 0,
    'DUTSCH': 0,
    'DUTSCHKE': 0,
    'DUTSON': 0,
    'DUTT': 0,
    'DUTTA': 0,
    'DUTTER': 0,
    'DUTTERA': 0,
    'DUTTERER': 0,
    'DUTTLINGER': 0,
    'DUTTO': 0,
    'DUTTON': 0,
    'DUTTRY': 0,
    'DUTTWEILER': 0,
    'DUTY': 0,
    'DUTZ': 0,
    'DUUS': 0,
    'DUVA': 0,
    'DUVAL': 0,
    'DUVALL': 0,
    'DUVALLE': 0,
    'DUVARNEY': 0,
    'DUVAUCHELLE': 0,
    'DUVE': 0,
    'DUVEL': 0,
    'DUVERGE': 0,
    'DUVERGER': 0,
    'DUVERNAY': 0,
    'DUVERNEY': 0,
    'DUVIC': 0,
    'DUVICK': 0,
    'DUVIVIER': 0,
    'DUVNJAK': 0,
    'DUVOISIN': 0,
    'DUVON': 0,
    'DUVVURI': 0,
    'DUWA': 0,
    'DUWE': 0,
    'DUWEL': 0,
    'DUWELL': 0,
    'DUX': 0,
    'DUXBURY': 0,
    'DUY': 0,
    'DUYCK': 0,
    'DUYSEN': 0,
    'DUZAN': 0,
    'DUZANT': 0,
    'DUZY': 0,
    'DVORACEK': 0,
    'DVORACHEK': 0,
    'DVORAK': 0,
    'DVORCHAK': 0,
    'DVORIN': 0,
    'DVORKIN': 0,
    'DVORSCAK': 0,
    'DVORSKY': 0,
    'DWAIN': 1,
    'DWAN': 0,
    'DWANA': 1,
    'DWANE': 0,
    'DWARKA': 0,
    'DWAYNE': 1,
    'DWECK': 0,
    'DWELLE': 0,
    'DWELLEY': 0,
    'DWELLY': 0,
    'DWENGER': 0,
    'DWIER': 0,
    'DWIGANS': 0,
    'DWIGGINS': 0,
    'DWIGHT': 0.9872340425531915,
    'DWINELL': 0,
    'DWINNELL': 0,
    'DWIRE': 0,
    'DWIVEDI': 0,
    'DWORACZYK': 0,
    'DWORAK': 0,
    'DWORAKOWSKI': 0,
    'DWOREK': 0,
    'DWORK': 0,
    'DWORKIN': 0,
    'DWORNIK': 0,
    'DWORSHAK': 0,
    'DWORSKY': 0,
    'DWOSKIN': 0,
    'DWY': 0,
    'DWYER': 0,
    'DWYRE': 0,
    'DY': 0,
    'DYAL': 0,
    'DYALS': 0,
    'DYAN': 1,
    'DYAR': 0,
    'DYAS': 0,
    'DYBA': 0,
    'DYBALA': 0,
    'DYBALL': 0,
    'DYBALSKI': 0,
    'DYBAS': 0,
    'DYBDAHL': 0,
    'DYBDAL': 0,
    'DYBEVIK': 0,
    'DYBING': 0,
    'DYBOWSKI': 0,
    'DYBUS': 0,
    'DYCE': 0,
    'DYCH': 0,
    'DYCHE': 0,
    'DYCHES': 0,
    'DYCK': 0,
    'DYCKMAN': 0,
    'DYCUS': 0,
    'DYDA': 0,
    'DYDELL': 0,
    'DYDO': 0,
    'DYE': 0,
    'DYEHOUSE': 0,
    'DYER': 0,
    'DYERS': 0,
    'DYES': 0,
    'DYESS': 0,
    'DYETT': 0,
    'DYGERT': 0,
    'DYJAK': 0,
    'DYK': 0,
    'DYKAS': 0,
    'DYKE': 0,
    'DYKEHOUSE': 0,
    'DYKEMA': 0,
    'DYKEMAN': 0,
    'DYKENS': 0,
    'DYKES': 0,
    'DYKGRAAF': 0,
    'DYKHOFF': 0,
    'DYKHOUSE': 0,
    'DYKHUIS': 0,
    'DYKHUIZEN': 0,
    'DYKINS': 0,
    'DYKMAN': 0,
    'DYKSTERHOUSE': 0,
    'DYKSTRA': 0,
    'DYL': 0,
    'DYLAG': 0,
    'DYLAN': 0.9956440572495333,
    'DYLE': 0,
    'DYLES': 0,
    'DYLEWSKI': 0,
    'DYLLA': 0,
    'DYLONG': 0,
    'DYM': 0,
    'DYMEK': 0,
    'DYMENT': 0,
    'DYMERSKI': 0,
    'DYMOCK': 0,
    'DYMON': 0,
    'DYMOND': 0,
    'DYNAK': 0,
    'DYNAN': 0,
    'DYNDA': 0,
    'DYNE': 0,
    'DYNEK': 0,
    'DYNES': 0,
    'DYNIA': 0,
    'DYON': 0,
    'DYOTT': 0,
    'DYOUS': 0,
    'DYRDA': 0,
    'DYRDAHL': 0,
    'DYRE': 0,
    'DYREK': 0,
    'DYRESON': 0,
    'DYRLAND': 0,
    'DYROFF': 0,
    'DYRUD': 0,
    'DYS': 0,
    'DYSARD': 0,
    'DYSART': 0,
    'DYSERT': 0,
    'DYSINGER': 0,
    'DYSLIN': 0,
    'DYSON': 0,
    'DYSTE': 0,
    'DYVIG': 0,
    'DZAFIC': 0,
    'DZAMBA': 0,
    'DZIADOSZ': 0,
    'DZIADUL': 0,
    'DZIADZIO': 0,
    'DZIAK': 0,
    'DZIALO': 0,
    'DZIEDZIC': 0,
    'DZIEGIELEWSKI': 0,
    'DZIEKAN': 0,
    'DZIEKONSKI': 0,
    'DZIELAK': 0,
    'DZIELINSKI': 0,
    'DZIELSKI': 0,
    'DZIENIS': 0,
    'DZIERWA': 0,
    'DZIERZANOWSKI': 0,
    'DZIERZYNSKI': 0,
    'DZIESINSKI': 0,
    'DZIEWA': 0,
    'DZIEWIOR': 0,
    'DZIEWIT': 0,
    'DZIK': 0,
    'DZIKI': 0,
    'DZIKOWSKI': 0,
    'DZIOBA': 0,
    'DZIOMBA': 0,
    'DZIUBA': 0,
    'DZIUBAN': 0,
    'DZIUBEK': 0,
    'DZIUBINSKI': 0,
    'DZIUK': 0,
    'DZIURA': 0,
    'DZIWULSKI': 0,
    'DZUBA': 0,
    'DZUBAK': 0,
    'DZUBAY': 0,
    'DZUGAN': 0,
    'DZUL': 0,
    'DZURICK': 0,
    'DZURIK': 0,
    'DZURILLA': 0,
    'DZURIS': 0,
    'DZURISIN': 0,
    'DZURKO': 0,
    'DZWONCZYK': 0,
    'DZWONKOWSKI': 0,
    'EA': 0,
    'EABY': 0,
    'EACHES': 0,
    'EACHO': 0,
    'EACHUS': 0,
    'EACKER': 0,
    'EACKLES': 0,
    'EACRET': 0,
    'EAD': 0,
    'EADDY': 0,
    'EADE': 0,
    'EADEH': 0,
    'EADEN': 0,
    'EADENS': 0,
    'EADER': 0,
    'EADES': 0,
    'EADIE': 0,
    'EADLER': 0,
    'EADON': 0,
    'EADS': 0,
    'EADY': 0,
    'EAFFORD': 0,
    'EAGAN': 0,
    'EAGANS': 0,
    'EAGAR': 0,
    'EAGEN': 0,
    'EAGER': 0,
    'EAGERTON': 0,
    'EAGLE': 0,
    'EAGLEBURGER': 0,
    'EAGLEMAN': 0,
    'EAGLEN': 0,
    'EAGLER': 0,
    'EAGLES': 0,
    'EAGLESON': 0,
    'EAGLESTON': 0,
    'EAGLETON': 0,
    'EAGLIN': 0,
    'EAGON': 0,
    'EAGY': 0,
    'EAHEART': 0,
    'EAKEN': 0,
    'EAKENS': 0,
    'EAKER': 0,
    'EAKES': 0,
    'EAKIN': 0,
    'EAKINS': 0,
    'EAKLE': 0,
    'EAKMAN': 0,
    'EAKRIGHT': 0,
    'EAKS': 0,
    'EALES': 0,
    'EALEY': 0,
    'EALOM': 0,
    'EALUM': 0,
    'EALY': 0,
    'EAM': 0,
    'EAMES': 0,
    'EAMIGH': 0,
    'EAN': 0,
    'EANES': 0,
    'EANG': 0,
    'EANS': 0,
    'EAP': 0,
    'EAPEN': 0,
    'EAR': 0,
    'EARBY': 0,
    'EARCIA': 0,
    'EARDLEY': 0,
    'EAREGOOD': 0,
    'EAREHART': 0,
    'EARGLE': 0,
    'EARHART': 0,
    'EARHEART': 0,
    'EARICH': 0,
    'EARICK': 0,
    'EARING': 0,
    'EARIS': 0,
    'EARL': 0.9713624238763903,
    'EARLE': 0.6593406593406593,
    'EARLEAN': 1,
    'EARLEEN': 1,
    'EARLENBAUGH': 0,
    'EARLENE': 1,
    'EARLES': 0,
    'EARLEY': 0,
    'EARLEYWINE': 0,
    'EARLIE': 1,
    'EARLINE': 1,
    'EARLING': 0,
    'EARLL': 0,
    'EARLS': 0,
    'EARLY': 0,
    'EARLYWINE': 0,
    'EARMAN': 0,
    'EARNER': 0,
    'EARNEST': 0.9139150943396226,
    'EARNESTINE': 1,
    'EARNEY': 0,
    'EARNHARDT': 0,
    'EARNHART': 0,
    'EARNHEART': 0,
    'EARNSHAW': 0,
    'EARNST': 0,
    'EARP': 0,
    'EARSING': 0,
    'EARSLEY': 0,
    'EARTHA': 1,
    'EARTHMAN': 0,
    'EARVIN': 0,
    'EARWOOD': 0,
    'EARY': 0,
    'EASDON': 0,
    'EASH': 0,
    'EASLER': 0,
    'EASLEY': 0,
    'EASLICK': 0,
    'EASLING': 0,
    'EASLON': 0,
    'EASLY': 0,
    'EASOM': 0,
    'EASON': 0,
    'EASSA': 0,
    'EASSON': 0,
    'EAST': 0,
    'EASTABROOKS': 0,
    'EASTBERG': 0,
    'EASTBURN': 0,
    'EASTEP': 0,
    'EASTER': 0.5302226935312832,
    'EASTERBROOK': 0,
    'EASTERBROOKS': 0,
    'EASTERBY': 0,
    'EASTERDAY': 0,
    'EASTERLIN': 0,
    'EASTERLING': 0,
    'EASTERLY': 0,
    'EASTERN': 0,
    'EASTERS': 0,
    'EASTERWOOD': 0,
    'EASTES': 0,
    'EASTGATE': 0,
    'EASTHAM': 0,
    'EASTHOPE': 0,
    'EASTHOUSE': 0,
    'EASTIN': 0,
    'EASTLACK': 0,
    'EASTLAKE': 0,
    'EASTLAND': 0,
    'EASTLEY': 0,
    'EASTLICK': 0,
    'EASTLING': 0,
    'EASTLUND': 0,
    'EASTMAN': 0,
    'EASTMOND': 0,
    'EASTON': 0,
    'EASTRIDGE': 0,
    'EASTVOLD': 0,
    'EASTWICK': 0,
    'EASTWOOD': 0,
    'EASUM': 0,
    'EASY': 0,
    'EATCHEL': 0,
    'EATHERLY': 0,
    'EATHERTON': 0,
    'EATHORNE': 0,
    'EATINGER': 0,
    'EATMAN': 0,
    'EATMON': 0,
    'EATON': 0,
    'EATOUGH': 0,
    'EAVENSON': 0,
    'EAVERS': 0,
    'EAVES': 0,
    'EAVEY': 0,
    'EAYRS': 0,
    'EBACH': 0,
    'EBACHER': 0,
    'EBACK': 0,
    'EBADI': 0,
    'EBALO': 0,
    'EBAN': 0,
    'EBANEZ': 0,
    'EBANKS': 0,
    'EBANS': 0,
    'EBARB': 0,
    'EBARE': 0,
    'EBARRA': 0,
    'EBAUGH': 0,
    'EBB': 0,
    'EBBA': 0,
    'EBBE': 0,
    'EBBECKE': 0,
    'EBBEN': 0,
    'EBBENS': 0,
    'EBBERS': 0,
    'EBBERSON': 0,
    'EBBERT': 0,
    'EBBERTS': 0,
    'EBBESEN': 0,
    'EBBIGHAUSEN': 0,
    'EBBING': 0,
    'EBBINGHAUS': 0,
    'EBBITT': 0,
    'EBBOLE': 0,
    'EBBS': 0,
    'EBE': 0,
    'EBEID': 0,
    'EBEL': 0,
    'EBELER': 0,
    'EBELHAR': 0,
    'EBELING': 0,
    'EBELL': 0,
    'EBELS': 0,
    'EBELT': 0,
    'EBEN': 0,
    'EBENAL': 0,
    'EBENER': 0,
    'EBENEZER': 0,
    'EBENHOEH': 0,
    'EBENSBERGER': 0,
    'EBENSTEIN': 0,
    'EBENSTEINER': 0,
    'EBER': 0,
    'EBERBACH': 0,
    'EBERENZ': 0,
    'EBERHARD': 0,
    'EBERHARDT': 0,
    'EBERHARDY': 0,
    'EBERHART': 0,
    'EBERL': 0,
    'EBERLE': 0,
    'EBERLEIN': 0,
    'EBERLEY': 0,
    'EBERLIN': 0,
    'EBERLINE': 0,
    'EBERLING': 0,
    'EBERLY': 0,
    'EBERMAN': 0,
    'EBERS': 0,
    'EBERSBACH': 0,
    'EBERSBERGER': 0,
    'EBERSOHL': 0,
    'EBERSOL': 0,
    'EBERSOLD': 0,
    'EBERSOLE': 0,
    'EBERSPACHER': 0,
    'EBERST': 0,
    'EBERSTEIN': 0,
    'EBERT': 0,
    'EBERTH': 0,
    'EBERTOWSKI': 0,
    'EBERTS': 0,
    'EBERTZ': 0,
    'EBERWEIN': 0,
    'EBERWINE': 0,
    'EBERZ': 0,
    'EBEY': 0,
    'EBIE': 0,
    'EBINGER': 0,
    'EBKE': 0,
    'EBLE': 0,
    'EBLEN': 0,
    'EBLER': 0,
    'EBLIN': 0,
    'EBLING': 0,
    'EBMEIER': 0,
    'EBMEYER': 0,
    'EBNER': 0,
    'EBNET': 0,
    'EBO': 0,
    'EBOLI': 0,
    'EBONI': 1,
    'EBONIE': 1,
    'EBONY': 1,
    'EBORN': 0,
    'EBRAHIM': 0,
    'EBRAHIMI': 0,
    'EBRAHIMIAN': 0,
    'EBRECHT': 0,
    'EBREO': 0,
    'EBRIGHT': 0,
    'EBROM': 0,
    'EBRON': 0,
    'EBSEN': 0,
    'EBSTEIN': 0,
    'EBUEN': 0,
    'EBY': 0,
    'ECCARD': 0,
    'ECCHER': 0,
    'ECCLES': 0,
    'ECCLESTON': 0,
    'ECCLESTONE': 0,
    'ECHANIQUE': 0,
    'ECHANIZ': 0,
    'ECHARD': 0,
    'ECHARTEA': 0,
    'ECHAVARIA': 0,
    'ECHAVARRIA': 0,
    'ECHAVE': 0,
    'ECHAVEZ': 0,
    'ECHAZABAL': 0,
    'ECHEANDIA': 0,
    'ECHEGARAY': 0,
    'ECHEGOYEN': 0,
    'ECHELBARGER': 0,
    'ECHELBERGER': 0,
    'ECHELBERRY': 0,
    'ECHEMENDIA': 0,
    'ECHENIQUE': 0,
    'ECHERD': 0,
    'ECHEVARIA': 0,
    'ECHEVARRIA': 0,
    'ECHEVERIA': 0,
    'ECHEVERRI': 0,
    'ECHEVERRIA': 0,
    'ECHEVERRY': 0,
    'ECHEVESTE': 0,
    'ECHIVERRI': 0,
    'ECHLER': 0,
    'ECHLIN': 0,
    'ECHO': 0.9756097560975611,
    'ECHOLES': 0,
    'ECHOLS': 0,
    'ECHON': 0,
    'ECHT': 0,
    'ECHTENKAMP': 0,
    'ECHTERLING': 0,
    'ECHTERNACH': 0,
    'ECHTERNACHT': 0,
    'ECK': 0,
    'ECKARD': 0,
    'ECKARDT': 0,
    'ECKART': 0,
    'ECKBERG': 0,
    'ECKBLAD': 0,
    'ECKBURG': 0,
    'ECKDAHL': 0,
    'ECKE': 0,
    'ECKEL': 0,
    'ECKELBARGER': 0,
    'ECKELBERG': 0,
    'ECKELBERGER': 0,
    'ECKELBERRY': 0,
    'ECKELKAMP': 0,
    'ECKELMAN': 0,
    'ECKELS': 0,
    'ECKENBERG': 0,
    'ECKENFELS': 0,
    'ECKENROAD': 0,
    'ECKENROD': 0,
    'ECKENRODE': 0,
    'ECKENROTH': 0,
    'ECKER': 0,
    'ECKERD': 0,
    'ECKERDT': 0,
    'ECKERLE': 0,
    'ECKERMAN': 0,
    'ECKERMANN': 0,
    'ECKERSLEY': 0,
    'ECKERSON': 0,
    'ECKERT': 0,
    'ECKERTY': 0,
    'ECKES': 0,
    'ECKFORD': 0,
    'ECKHARD': 0,
    'ECKHARDT': 0,
    'ECKHART': 0,
    'ECKHAUS': 0,
    'ECKHOFF': 0,
    'ECKHOLM': 0,
    'ECKHOUSE': 0,
    'ECKHOUT': 0,
    'ECKINGER': 0,
    'ECKL': 0,
    'ECKLAND': 0,
    'ECKLAR': 0,
    'ECKLE': 0,
    'ECKLEBERRY': 0,
    'ECKLER': 0,
    'ECKLES': 0,
    'ECKLEY': 0,
    'ECKLOFF': 0,
    'ECKLOR': 0,
    'ECKLUND': 0,
    'ECKMAN': 0,
    'ECKMANN': 0,
    'ECKOLS': 0,
    'ECKRICH': 0,
    'ECKROAT': 0,
    'ECKROTE': 0,
    'ECKROTH': 0,
    'ECKSTEIN': 0,
    'ECKSTINE': 0,
    'ECKSTROM': 0,
    'ECKWOOD': 0,
    'ECKWRIGHT': 0,
    'ECLEVIA': 0,
    'ECOFF': 0,
    'ECONOMIDES': 0,
    'ECONOMOS': 0,
    'ECONOMOU': 0,
    'ECONOMY': 0,
    'ECORD': 0,
    'ECRET': 0,
    'ECTON': 0,
    'ECTOR': 0,
    'ED': 0.9968847352024921,
    'EDA': 0.9803921568627452,
    'EDAAKIE': 0,
    'EDALGO': 0,
    'EDBERG': 0,
    'EDBLOM': 0,
    'EDD': 0,
    'EDDA': 1,
    'EDDE': 0,
    'EDDEN': 0,
    'EDDENS': 0,
    'EDDER': 0,
    'EDDIE': 0.9967204681370972,
    'EDDINGER': 0,
    'EDDINGFIELD': 0,
    'EDDINGS': 0,
    'EDDINGTON': 0,
    'EDDINS': 0,
    'EDDIS': 0,
    'EDDLEMAN': 0,
    'EDDLEMON': 0,
    'EDDLESTON': 0,
    'EDDLETON': 0,
    'EDDOWES': 0,
    'EDDS': 0,
    'EDDY': 0.5837711617046119,
    'EDE': 0,
    'EDEBURN': 0,
    'EDEEN': 0,
    'EDEKER': 0,
    'EDEL': 0,
    'EDELBACH': 0,
    'EDELBERG': 0,
    'EDELBLUTE': 0,
    'EDELBROCK': 0,
    'EDELE': 0,
    'EDELEN': 0,
    'EDELHEIT': 0,
    'EDELIN': 0,
    'EDELL': 0,
    'EDELMAN': 0,
    'EDELMANN': 0,
    'EDELMAYER': 0,
    'EDELMIRA': 1,
    'EDELSON': 0,
    'EDELSTEIN': 0,
    'EDEM': 0,
    'EDEN': 0.5338078291814947,
    'EDENBURN': 0,
    'EDENFIELD': 0,
    'EDENS': 0,
    'EDENSHAW': 0,
    'EDENTON': 0,
    'EDER': 0,
    'EDERER': 0,
    'EDERY': 0,
    'EDES': 0,
    'EDEY': 0,
    'EDEZA': 0,
    'EDGAR': 0.9489916963226572,
    'EDGARDO': 1,
    'EDGCOMB': 0,
    'EDGE': 0,
    'EDGECOMB': 0,
    'EDGECOMBE': 0,
    'EDGEHILL': 0,
    'EDGEL': 0,
    'EDGELL': 0,
    'EDGEMAN': 0,
    'EDGEMON': 0,
    'EDGER': 0,
    'EDGERLEY': 0,
    'EDGERLY': 0,
    'EDGERSON': 0,
    'EDGERTON': 0,
    'EDGESTON': 0,
    'EDGETON': 0,
    'EDGETT': 0,
    'EDGETTE': 0,
    'EDGEWORTH': 0,
    'EDGHILL': 0,
    'EDGIL': 0,
    'EDGIN': 0,
    'EDGING': 0,
    'EDGINGTON': 0,
    'EDGINTON': 0,
    'EDGLEY': 0,
    'EDGMON': 0,
    'EDGREN': 0,
    'EDHOLM': 0,
    'EDIC': 0,
    'EDICK': 0,
    'EDIE': 0.8676789587852495,
    'EDIGER': 0,
    'EDIN': 0,
    'EDINBURGH': 0,
    'EDING': 0,
    'EDINGER': 0,
    'EDINGTON': 0,
    'EDISON': 0.7366482504604052,
    'EDITH': 1,
    'EDKIN': 0,
    'EDKINS': 0,
    'EDL': 0,
    'EDLAND': 0,
    'EDLEBECK': 0,
    'EDLEFSEN': 0,
    'EDLEMAN': 0,
    'EDLEN': 0,
    'EDLER': 0,
    'EDLEY': 0,
    'EDLIN': 0,
    'EDLING': 0,
    'EDLOW': 0,
    'EDLUND': 0,
    'EDMAISTON': 0,
    'EDMAN': 0,
    'EDMANDS': 0,
    'EDMARK': 0,
    'EDME': 0,
    'EDMEAD': 0,
    'EDMERSON': 0,
    'EDMINSTER': 0,
    'EDMISON': 0,
    'EDMISSON': 0,
    'EDMISTEN': 0,
    'EDMISTER': 0,
    'EDMISTON': 0,
    'EDMO': 0,
    'EDMON': 0,
    'EDMOND': 0.8659981768459434,
    'EDMONDS': 0,
    'EDMONDSON': 0,
    'EDMONS': 0,
    'EDMONSON': 0,
    'EDMONSTON': 0,
    'EDMUND': 0.988793671720501,
    'EDMUNDO': 1,
    'EDMUNDS': 0,
    'EDMUNDSON': 0,
    'EDMUNSON': 0,
    'EDNA': 1,
    'EDNER': 0,
    'EDNEY': 0,
    'EDNIE': 0,
    'EDOM': 0,
    'EDON': 0,
    'EDORA': 0,
    'EDOUARD': 0,
    'EDQUIST': 0,
    'EDRA': 0.9523809523809523,
    'EDRADA': 0,
    'EDRALIN': 0,
    'EDRICH': 0,
    'EDRINGTON': 0,
    'EDRIS': 0.8620689655172414,
    'EDSALL': 0,
    'EDSEL': 0,
    'EDSELL': 0,
    'EDSITTY': 0,
    'EDSON': 0,
    'EDSTROM': 0,
    'EDU': 0,
    'EDUARDO': 0.9957627118644068,
    'EDVALSON': 0,
    'EDWARD': 0.9975349009489992,
    'EDWARDO': 0.9950248756218906,
    'EDWARDS': 0,
    'EDWARDSEN': 0,
    'EDWARDSON': 0,
    'EDWARS': 0,
    'EDWIN': 0.9979770734996629,
    'EDWINA': 1,
    'EDWINS': 0,
    'EDY': 0,
    'EDYTH': 1,
    'EDYTHE': 1,
    'EE': 0,
    'EEDS': 0,
    'EEKHOFF': 0,
    'EELLS': 0,
    'EELMAN': 0,
    'EENIGENBURG': 0,
    'EERNISSE': 0,
    'EETEN': 0,
    'EFAW': 0,
    'EFF': 0,
    'EFFA': 0,
    'EFFENBERGER': 0,
    'EFFENDI': 0,
    'EFFERSON': 0,
    'EFFERTZ': 0,
    'EFFIE': 1,
    'EFFINGER': 0,
    'EFFLAND': 0,
    'EFFLER': 0,
    'EFFNER': 0,
    'EFFORD': 0,
    'EFFRON': 0,
    'EFINGER': 0,
    'EFIRD': 0,
    'EFLAND': 0,
    'EFRAIMSON': 0,
    'EFRAIN': 1,
    'EFREN': 1,
    'EFRON': 0,
    'EFROS': 0,
    'EFSTATHIOU': 0,
    'EFTA': 0,
    'EFTEKHARI': 0,
    'EFTHIMIOU': 0,
    'EFTING': 0,
    'EFTINK': 0,
    'EFURD': 0,
    'EGAL': 0,
    'EGAMI': 0,
    'EGAN': 0,
    'EGANA': 0,
    'EGANHOUSE': 0,
    'EGANS': 0,
    'EGAR': 0,
    'EGAS': 0,
    'EGAWA': 0,
    'EGBE': 0,
    'EGBERS': 0,
    'EGBERT': 0,
    'EGDORF': 0,
    'EGE': 0,
    'EGEA': 0,
    'EGEBERG': 0,
    'EGEL': 0,
    'EGELAND': 0,
    'EGELER': 0,
    'EGELHOFF': 0,
    'EGELSTON': 0,
    'EGEN': 0,
    'EGENBERGER': 0,
    'EGENES': 0,
    'EGENLAUF': 0,
    'EGER': 0,
    'EGERDAHL': 0,
    'EGERER': 0,
    'EGERMAN': 0,
    'EGERSON': 0,
    'EGERT': 0,
    'EGERTER': 0,
    'EGERTON': 0,
    'EGET': 0,
    'EGG': 0,
    'EGGAN': 0,
    'EGGAR': 0,
    'EGGART': 0,
    'EGGE': 0,
    'EGGEBEEN': 0,
    'EGGEBRAATEN': 0,
    'EGGEBRECHT': 0,
    'EGGELING': 0,
    'EGGELSTON': 0,
    'EGGEMAN': 0,
    'EGGEMEYER': 0,
    'EGGEN': 0,
    'EGGENBERGER': 0,
    'EGGER': 0,
    'EGGERDING': 0,
    'EGGERING': 0,
    'EGGERLING': 0,
    'EGGERMAN': 0,
    'EGGERS': 0,
    'EGGERSON': 0,
    'EGGERT': 0,
    'EGGERTH': 0,
    'EGGERTON': 0,
    'EGGERTSEN': 0,
    'EGGETT': 0,
    'EGGIMAN': 0,
    'EGGIMANN': 0,
    'EGGING': 0,
    'EGGINK': 0,
    'EGGINS': 0,
    'EGGLER': 0,
    'EGGLESTON': 0,
    'EGGLETON': 0,
    'EGGLI': 0,
    'EGGMAN': 0,
    'EGGUM': 0,
    'EGHBALI': 0,
    'EGIDI': 0,
    'EGIDIO': 0,
    'EGINTON': 0,
    'EGIPCIACO': 0,
    'EGITTO': 0,
    'EGIZI': 0,
    'EGIZIO': 0,
    'EGLAND': 0,
    'EGLE': 0,
    'EGLER': 0,
    'EGLESTON': 0,
    'EGLEY': 0,
    'EGLI': 0,
    'EGLIN': 0,
    'EGLINTON': 0,
    'EGLITIS': 0,
    'EGLOFF': 0,
    'EGLY': 0,
    'EGNER': 0,
    'EGNEW': 0,
    'EGNOR': 0,
    'EGNOT': 0,
    'EGO': 0,
    'EGOAVIL': 0,
    'EGOLF': 0,
    'EGRI': 0,
    'EGSTAD': 0,
    'EGTS': 0,
    'EGUCHI': 0,
    'EGUIA': 0,
    'EGUIZABAL': 0,
    'EGURE': 0,
    'EGURROLA': 0,
    'EGUSQUIZA': 0,
    'EGY': 0,
    'EGYED': 0,
    'EHA': 0,
    'EHALT': 0,
    'EHARDT': 0,
    'EHART': 0,
    'EHASZ': 0,
    'EHEMANN': 0,
    'EHINGER': 0,
    'EHL': 0,
    'EHLE': 0,
    'EHLEBRACHT': 0,
    'EHLEN': 0,
    'EHLENFELDT': 0,
    'EHLER': 0,
    'EHLERS': 0,
    'EHLERT': 0,
    'EHLEY': 0,
    'EHLI': 0,
    'EHLING': 0,
    'EHLINGER': 0,
    'EHLIS': 0,
    'EHLKE': 0,
    'EHLMAN': 0,
    'EHLMANN': 0,
    'EHLY': 0,
    'EHM': 0,
    'EHMAN': 0,
    'EHMANN': 0,
    'EHMEN': 0,
    'EHMER': 0,
    'EHMKE': 0,
    'EHN': 0,
    'EHNERT': 0,
    'EHNES': 0,
    'EHNI': 0,
    'EHNIS': 0,
    'EHNLE': 0,
    'EHNOT': 0,
    'EHNSTROM': 0,
    'EHORN': 0,
    'EHR': 0,
    'EHRBAR': 0,
    'EHRECKE': 0,
    'EHREDT': 0,
    'EHREN': 0,
    'EHRENBERG': 0,
    'EHRENBERGER': 0,
    'EHRENFELD': 0,
    'EHRENFRIED': 0,
    'EHRENKRANZ': 0,
    'EHRENPREIS': 0,
    'EHRENREICH': 0,
    'EHRENS': 0,
    'EHRENSBERGER': 0,
    'EHRENZELLER': 0,
    'EHRESMAN': 0,
    'EHRESMANN': 0,
    'EHRET': 0,
    'EHRETT': 0,
    'EHRGOOD': 0,
    'EHRGOTT': 0,
    'EHRHARD': 0,
    'EHRHARDT': 0,
    'EHRHART': 0,
    'EHRHORN': 0,
    'EHRICH': 0,
    'EHRIE': 0,
    'EHRIG': 0,
    'EHRING': 0,
    'EHRINGER': 0,
    'EHRISMAN': 0,
    'EHRKE': 0,
    'EHRLE': 0,
    'EHRLER': 0,
    'EHRLICH': 0,
    'EHRLICHMAN': 0,
    'EHRLINGER': 0,
    'EHRMAN': 0,
    'EHRMANN': 0,
    'EHRMANTRAUT': 0,
    'EHRSAM': 0,
    'EHSAN': 0,
    'EHSANI': 0,
    'EHST': 0,
    'EHTEL': 1,
    'EIB': 0,
    'EIBECK': 0,
    'EIBEL': 0,
    'EIBEN': 0,
    'EIBERGER': 0,
    'EIBERT': 0,
    'EIBL': 0,
    'EIBLING': 0,
    'EICH': 0,
    'EICHACKER': 0,
    'EICHAR': 0,
    'EICHAS': 0,
    'EICHBERG': 0,
    'EICHBERGER': 0,
    'EICHE': 0,
    'EICHEL': 0,
    'EICHELBERG': 0,
    'EICHELBERGER': 0,
    'EICHELE': 0,
    'EICHELKRAUT': 0,
    'EICHELMAN': 0,
    'EICHEN': 0,
    'EICHENAUER': 0,
    'EICHENBAUM': 0,
    'EICHENBERG': 0,
    'EICHENBERGER': 0,
    'EICHENLAUB': 0,
    'EICHENSEER': 0,
    'EICHENSEHR': 0,
    'EICHENSTEIN': 0,
    'EICHER': 0,
    'EICHERS': 0,
    'EICHERT': 0,
    'EICHHOLTZ': 0,
    'EICHHOLZ': 0,
    'EICHHORN': 0,
    'EICHHORST': 0,
    'EICHINGER': 0,
    'EICHLER': 0,
    'EICHLIN': 0,
    'EICHMAN': 0,
    'EICHMANN': 0,
    'EICHMEIER': 0,
    'EICHMILLER': 0,
    'EICHNER': 0,
    'EICHOLTZ': 0,
    'EICHOLZ': 0,
    'EICHORN': 0,
    'EICHORST': 0,
    'EICHSTADT': 0,
    'EICHSTAEDT': 0,
    'EICHSTEDT': 0,
    'EICHTEN': 0,
    'EICHWALD': 0,
    'EICK': 0,
    'EICKE': 0,
    'EICKELBERG': 0,
    'EICKELMAN': 0,
    'EICKENHORST': 0,
    'EICKER': 0,
    'EICKERT': 0,
    'EICKHOFF': 0,
    'EICKHOLT': 0,
    'EICKHORST': 0,
    'EICKLEBERRY': 0,
    'EICKMAN': 0,
    'EICKMANN': 0,
    'EICKMEIER': 0,
    'EICKMEYER': 0,
    'EICKSTADT': 0,
    'EICKSTAEDT': 0,
    'EID': 0,
    'EIDAM': 0,
    'EIDE': 0,
    'EIDEL': 0,
    'EIDELMAN': 0,
    'EIDEM': 0,
    'EIDEMILLER': 0,
    'EIDEN': 0,
    'EIDENSCHINK': 0,
    'EIDER': 0,
    'EIDINGER': 0,
    'EIDMAN': 0,
    'EIDSMOE': 0,
    'EIDSNESS': 0,
    'EIDSON': 0,
    'EIDT': 0,
    'EIERMAN': 0,
    'EIERMANN': 0,
    'EIESLAND': 0,
    'EIFERT': 0,
    'EIFFERT': 0,
    'EIFFLER': 0,
    'EIFLER': 0,
    'EIG': 0,
    'EIGEL': 0,
    'EIGEN': 0,
    'EIGENBERGER': 0,
    'EIGENBROD': 0,
    'EIGENBRODE': 0,
    'EIGENMANN': 0,
    'EIGER': 0,
    'EIGHME': 0,
    'EIGHMEY': 0,
    'EIGHMY': 0,
    'EIGNER': 0,
    'EIGSTI': 0,
    'EIK': 0,
    'EIKE': 0,
    'EIKEL': 0,
    'EIKEN': 0,
    'EIKENBARY': 0,
    'EIKENBERG': 0,
    'EIKENBERRY': 0,
    'EIKER': 0,
    'EIKERMANN': 0,
    'EIKLEBERRY': 0,
    'EIKLOR': 0,
    'EIKMEIER': 0,
    'EIKNER': 0,
    'EILAND': 0,
    'EILANDER': 0,
    'EILBACHER': 0,
    'EILDERS': 0,
    'EILEEN': 1,
    'EILENBERG': 0,
    'EILENBERGER': 0,
    'EILENE': 1,
    'EILER': 0,
    'EILERMAN': 0,
    'EILERS': 0,
    'EILERT': 0,
    'EILERTS': 0,
    'EILERTSEN': 0,
    'EILERTSON': 0,
    'EILOLA': 0,
    'EILRICH': 0,
    'EILTS': 0,
    'EIMAN': 0,
    'EIMER': 0,
    'EIMERS': 0,
    'EINARSON': 0,
    'EINARSSON': 0,
    'EINBERGER': 0,
    'EINBINDER': 0,
    'EINCK': 0,
    'EINERSON': 0,
    'EINERTSON': 0,
    'EINFALT': 0,
    'EINFELDT': 0,
    'EING': 0,
    'EINHAUS': 0,
    'EINHORN': 0,
    'EINIG': 0,
    'EINKAUF': 0,
    'EINSEL': 0,
    'EINSIG': 0,
    'EINSPAHR': 0,
    'EINSTEIN': 0,
    'EIPPER': 0,
    'EIRAS': 0,
    'EIRHART': 0,
    'EIRICH': 0,
    'EIRING': 0,
    'EIS': 0,
    'EISA': 0,
    'EISAMAN': 0,
    'EISBERG': 0,
    'EISBRENNER': 0,
    'EISCH': 0,
    'EISCHEID': 0,
    'EISCHEN': 0,
    'EISCHENS': 0,
    'EISDORFER': 0,
    'EISE': 0,
    'EISEL': 0,
    'EISELE': 0,
    'EISELSTEIN': 0,
    'EISEMAN': 0,
    'EISEMANN': 0,
    'EISEN': 0,
    'EISENACH': 0,
    'EISENACHER': 0,
    'EISENBACH': 0,
    'EISENBACHER': 0,
    'EISENBACK': 0,
    'EISENBART': 0,
    'EISENBARTH': 0,
    'EISENBATH': 0,
    'EISENBEIS': 0,
    'EISENBEISS': 0,
    'EISENBEISZ': 0,
    'EISENBERG': 0,
    'EISENBERGER': 0,
    'EISENBISE': 0,
    'EISENBRANDT': 0,
    'EISENBRAUN': 0,
    'EISENBREY': 0,
    'EISENGA': 0,
    'EISENHARD': 0,
    'EISENHARDT': 0,
    'EISENHART': 0,
    'EISENHAUER': 0,
    'EISENHOUR': 0,
    'EISENHOWER': 0,
    'EISENHUT': 0,
    'EISENHUTH': 0,
    'EISENLOHR': 0,
    'EISENMAN': 0,
    'EISENMANN': 0,
    'EISENMENGER': 0,
    'EISENREICH': 0,
    'EISENSCHENK': 0,
    'EISENSMITH': 0,
    'EISENSTADT': 0,
    'EISENSTAT': 0,
    'EISENSTEIN': 0,
    'EISENTRAGER': 0,
    'EISENTRAUT': 0,
    'EISENTROUT': 0,
    'EISENZIMMER': 0,
    'EISER': 0,
    'EISERMAN': 0,
    'EISERMANN': 0,
    'EISERT': 0,
    'EISHEN': 0,
    'EISIMINGER': 0,
    'EISING': 0,
    'EISINGER': 0,
    'EISKANT': 0,
    'EISLER': 0,
    'EISLEY': 0,
    'EISMA': 0,
    'EISMAN': 0,
    'EISMANN': 0,
    'EISNAUGLE': 0,
    'EISNER': 0,
    'EISNOR': 0,
    'EISOLD': 0,
    'EISON': 0,
    'EISS': 0,
    'EISSA': 0,
    'EISSINGER': 0,
    'EISSLER': 0,
    'EISTER': 0,
    'EISTERHOLD': 0,
    'EISWERTH': 0,
    'EITEL': 0,
    'EITEN': 0,
    'EITER': 0,
    'EITH': 0,
    'EITING': 0,
    'EITNER': 0,
    'EITNIEAR': 0,
    'EITNIER': 0,
    'EITREIM': 0,
    'EITTREIM': 0,
    'EITZEN': 0,
    'EITZMANN': 0,
    'EIVINS': 0,
    'EIYNCK': 0,
    'EJAZ': 0,
    'EJIOFOR': 0,
    'EK': 0,
    'EKANAYAKE': 0,
    'EKANEM': 0,
    'EKART': 0,
    'EKAS': 0,
    'EKBERG': 0,
    'EKBLAD': 0,
    'EKDAHL': 0,
    'EKE': 0,
    'EKEH': 0,
    'EKELUND': 0,
    'EKEMA': 0,
    'EKEN': 0,
    'EKENSTAM': 0,
    'EKER': 0,
    'EKEREN': 0,
    'EKERN': 0,
    'EKERS': 0,
    'EKERT': 0,
    'EKES': 0,
    'EKEY': 0,
    'EKHOFF': 0,
    'EKHOLM': 0,
    'EKIN': 0,
    'EKINS': 0,
    'EKIS': 0,
    'EKISS': 0,
    'EKIZIAN': 0,
    'EKKER': 0,
    'EKLAND': 0,
    'EKLE': 0,
    'EKLEBERRY': 0,
    'EKLOF': 0,
    'EKLUND': 0,
    'EKMAN': 0,
    'EKNESS': 0,
    'EKOLA': 0,
    'EKONG': 0,
    'EKPO': 0,
    'EKREN': 0,
    'EKSTAM': 0,
    'EKSTEDT': 0,
    'EKSTEIN': 0,
    'EKSTRAND': 0,
    'EKSTROM': 0,
    'EKSTRUM': 0,
    'EKVALL': 0,
    'EKWALL': 0,
    'EL': 0,
    'ELA': 0.8849557522123894,
    'ELABED': 0,
    'ELACQUA': 0,
    'ELADIA': 1,
    'ELAHI': 0,
    'ELAINA': 1,
    'ELAINE': 1,
    'ELALI': 0,
    'ELAM': 0,
    'ELAMIN': 0,
    'ELAN': 0,
    'ELANA': 1,
    'ELAND': 0,
    'ELANDER': 0,
    'ELANDT': 0,
    'ELANE': 1,
    'ELANOR': 1,
    'ELARDO': 0,
    'ELARTON': 0,
    'ELAVSKY': 0,
    'ELAYAN': 0,
    'ELAYNE': 1,
    'ELAYYAN': 0,
    'ELAZEGUI': 0,
    'ELBA': 1,
    'ELBANNA': 0,
    'ELBAUM': 0,
    'ELBAZ': 0,
    'ELBE': 0,
    'ELBEL': 0,
    'ELBEN': 0,
    'ELBER': 0,
    'ELBERFELD': 0,
    'ELBERG': 0,
    'ELBERS': 0,
    'ELBERSON': 0,
    'ELBERT': 0.9507346585998271,
    'ELBERTSON': 0,
    'ELBIN': 0,
    'ELBLE': 0,
    'ELBOGEN': 0,
    'ELBON': 0,
    'ELBRECHT': 0,
    'ELBURN': 0,
    'ELCAN': 0,
    'ELCHERT': 0,
    'ELCOCK': 0,
    'ELD': 0,
    'ELDA': 1,
    'ELDEEN': 0,
    'ELDEN': 0.9569377990430621,
    'ELDER': 0,
    'ELDERKIN': 0,
    'ELDERS': 0,
    'ELDERT': 0,
    'ELDIN': 0,
    'ELDON': 0.9929906542056075,
    'ELDORA': 1,
    'ELDRED': 0,
    'ELDREDGE': 0,
    'ELDRETH': 0,
    'ELDRIDGE': 0.30557677616501144,
    'ELDRIGE': 0,
    'ELDRINGHOFF': 0,
    'ELE': 0,
    'ELEAM': 0,
    'ELEANOR': 1,
    'ELEANORA': 1,
    'ELEANORE': 1,
    'ELEASE': 1,
    'ELEAZAR': 0,
    'ELEAZER': 0,
    'ELEBY': 0,
    'ELECCION': 0,
    'ELEDGE': 0,
    'ELEFANT': 0,
    'ELEFANTE': 0,
    'ELEFTHERIOU': 0,
    'ELEJALDE': 0,
    'ELEK': 0,
    'ELEKES': 0,
    'ELEM': 0,
    'ELENA': 0.9956942949407966,
    'ELENBAAS': 0,
    'ELENBURG': 0,
    'ELENE': 1,
    'ELENES': 0,
    'ELENI': 1,
    'ELENOR': 1,
    'ELENORA': 1,
    'ELENORE': 1,
    'ELENZ': 0,
    'ELEONOR': 1,
    'ELEONORA': 1,
    'ELEONORE': 1,
    'ELERICK': 0,
    'ELERSON': 0,
    'ELERT': 0,
    'ELERY': 0,
    'ELES': 0,
    'ELETTO': 0,
    'ELEY': 0,
    'ELEZI': 0,
    'ELEZOVIC': 0,
    'ELF': 0,
    'ELFE': 0,
    'ELFENBEIN': 0,
    'ELFER': 0,
    'ELFERING': 0,
    'ELFERS': 0,
    'ELFERT': 0,
    'ELFLEIN': 0,
    'ELFMAN': 0,
    'ELFNER': 0,
    'ELFORD': 0,
    'ELFREDA': 1,
    'ELFRIEDA': 1,
    'ELFRIEDE': 1,
    'ELFRING': 0,
    'ELFRINK': 0,
    'ELFSTROM': 0,
    'ELFTMANN': 0,
    'ELG': 0,
    'ELGAMAL': 0,
    'ELGAN': 0,
    'ELGAR': 0,
    'ELGART': 0,
    'ELGAS': 0,
    'ELGENDY': 0,
    'ELGER': 0,
    'ELGERSMA': 0,
    'ELGERT': 0,
    'ELGES': 0,
    'ELGIE': 0,
    'ELGIN': 0,
    'ELGUEA': 0,
    'ELGUERA': 0,
    'ELGUEZABAL': 0,
    'ELHAG': 0,
    'ELHAGE': 0,
    'ELHAJ': 0,
    'ELHAJJ': 0,
    'ELHARD': 0,
    'ELHARDT': 0,
    'ELHART': 0,
    'ELHASSAN': 0,
    'ELHINDI': 0,
    'ELI': 0.9673518742442564,
    'ELIA': 0.8610086100861009,
    'ELIACIN': 0,
    'ELIADES': 0,
    'ELIAN': 0,
    'ELIANA': 1,
    'ELIAS': 0.7536827680712572,
    'ELIASEN': 0,
    'ELIASON': 0,
    'ELIASSAINT': 0,
    'ELIASSEN': 0,
    'ELIASSON': 0,
    'ELICERIO': 0,
    'ELICH': 0,
    'ELICIA': 1,
    'ELICK': 0,
    'ELICKER': 0,
    'ELIDA': 1,
    'ELIDIA': 1,
    'ELIE': 0,
    'ELIEFF': 0,
    'ELIEN': 0,
    'ELIEZER': 0,
    'ELIFF': 0,
    'ELIFRITZ': 0,
    'ELIGIO': 0,
    'ELIJAH': 0.9834368530020704,
    'ELIN': 0.9259259259259258,
    'ELINA': 1,
    'ELINE': 0,
    'ELING': 0,
    'ELINGS': 0,
    'ELINOR': 1,
    'ELINORE': 1,
    'ELINSKI': 0,
    'ELINSKY': 0,
    'ELIO': 0,
    'ELION': 0,
    'ELIOPOULOS': 0,
    'ELIOPULOS': 0,
    'ELIOT': 0,
    'ELIOTT': 0,
    'ELIS': 0,
    'ELISA': 1,
    'ELISABETH': 1,
    'ELISE': 0.9978991596638654,
    'ELISEA': 0,
    'ELISEO': 0.986842105263158,
    'ELISERIO': 0,
    'ELISH': 0,
    'ELISHA': 0.9925558312655087,
    'ELISON': 0,
    'ELISONDO': 0,
    'ELISSA': 1,
    'ELIX': 0,
    'ELIXSON': 0,
    'ELIZ': 1,
    'ELIZA': 1,
    'ELIZABET': 1,
    'ELIZABETH': 0.9997972662960551,
    'ELIZABETHA': 0,
    'ELIZAGA': 0,
    'ELIZALDE': 0,
    'ELIZALDI': 0,
    'ELIZANDO': 0,
    'ELIZARDO': 0,
    'ELIZARES': 0,
    'ELIZARRARAS': 0,
    'ELIZARRARAZ': 0,
    'ELIZBETH': 1,
    'ELIZEBETH': 1,
    'ELIZEE': 0,
    'ELIZER': 0,
    'ELIZONDO': 0,
    'ELK': 0,
    'ELKADI': 0,
    'ELKAN': 0,
    'ELKAYAM': 0,
    'ELKE': 0.9615384615384616,
    'ELKEN': 0,
    'ELKER': 0,
    'ELKES': 0,
    'ELKHATIB': 0,
    'ELKHOURI': 0,
    'ELKHOURY': 0,
    'ELKIN': 0,
    'ELKIND': 0,
    'ELKING': 0,
    'ELKINGTON': 0,
    'ELKINS': 0,
    'ELKINTON': 0,
    'ELKO': 0,
    'ELKS': 0,
    'ELKUS': 0,
    'ELL': 0,
    'ELLA': 0.9991097042239587,
    'ELLAM': 0,
    'ELLAMAE': 1,
    'ELLAN': 1,
    'ELLANSON': 0,
    'ELLARD': 0,
    'ELLARS': 0,
    'ELLAS': 0,
    'ELLAZAR': 0,
    'ELLCESSOR': 0,
    'ELLE': 0,
    'ELLEBRACHT': 0,
    'ELLEBRECHT': 0,
    'ELLEBY': 0,
    'ELLEDGE': 0,
    'ELLEFSEN': 0,
    'ELLEFSON': 0,
    'ELLEGOOD': 0,
    'ELLEMAN': 0,
    'ELLEN': 0.9975206135040073,
    'ELLENA': 0.8695652173913043,
    'ELLENBECKER': 0,
    'ELLENBERG': 0,
    'ELLENBERGER': 0,
    'ELLENBOGEN': 0,
    'ELLENBURG': 0,
    'ELLENDER': 0,
    'ELLENS': 0,
    'ELLENSON': 0,
    'ELLENWOOD': 0,
    'ELLENZ': 0,
    'ELLER': 0,
    'ELLERBE': 0,
    'ELLERBECK': 0,
    'ELLERBEE': 0,
    'ELLERBROCK': 0,
    'ELLERBROEK': 0,
    'ELLERBROOK': 0,
    'ELLERBUSCH': 0,
    'ELLERBY': 0,
    'ELLERD': 0,
    'ELLERHORST': 0,
    'ELLERING': 0,
    'ELLERMAN': 0,
    'ELLERMANN': 0,
    'ELLERS': 0,
    'ELLERSICK': 0,
    'ELLERSON': 0,
    'ELLERT': 0,
    'ELLERTON': 0,
    'ELLERTSON': 0,
    'ELLERY': 0,
    'ELLES': 0,
    'ELLESON': 0,
    'ELLESTAD': 0,
    'ELLET': 0,
    'ELLETSON': 0,
    'ELLETT': 0,
    'ELLEY': 0,
    'ELLI': 0.9259259259259258,
    'ELLIAS': 0,
    'ELLICK': 0,
    'ELLICKSON': 0,
    'ELLICOTT': 0,
    'ELLIE': 0.9884678747940693,
    'ELLIES': 0,
    'ELLIFF': 0,
    'ELLIFRITS': 0,
    'ELLIFRITT': 0,
    'ELLIFRITZ': 0,
    'ELLIG': 0,
    'ELLIN': 0,
    'ELLING': 0,
    'ELLINGBOE': 0,
    'ELLINGBURG': 0,
    'ELLINGER': 0,
    'ELLINGFORD': 0,
    'ELLINGHAM': 0,
    'ELLINGHAUS': 0,
    'ELLINGHAUSEN': 0,
    'ELLINGHUYSEN': 0,
    'ELLINGSEN': 0,
    'ELLINGSON': 0,
    'ELLINGSWORTH': 0,
    'ELLINGTON': 0,
    'ELLINGWOOD': 0,
    'ELLINGWORTH': 0,
    'ELLINWOOD': 0,
    'ELLIOT': 0.812536273940801,
    'ELLIOTT': 0.2218700475435816,
    'ELLIOTTE': 0,
    'ELLIS': 0.2704456945045435,
    'ELLISON': 0,
    'ELLISOR': 0,
    'ELLISTON': 0,
    'ELLITHORPE': 0,
    'ELLIXSON': 0,
    'ELLMAKER': 0,
    'ELLMAN': 0,
    'ELLMANN': 0,
    'ELLMER': 0,
    'ELLMORE': 0,
    'ELLNER': 0,
    'ELLO': 0,
    'ELLOITT': 0,
    'ELLORIN': 0,
    'ELLOTT': 0,
    'ELLRICH': 0,
    'ELLS': 0,
    'ELLSBERRY': 0,
    'ELLSBURY': 0,
    'ELLSMORE': 0,
    'ELLSON': 0,
    'ELLSTON': 0,
    'ELLSTROM': 0,
    'ELLSWORTH': 0.449438202247191,
    'ELLUL': 0,
    'ELLWANGER': 0,
    'ELLWEIN': 0,
    'ELLWOOD': 0,
    'ELLY': 0.966183574879227,
    'ELLYN': 1,
    'ELLYSON': 0,
    'ELLZEY': 0,
    'ELLZY': 0,
    'ELM': 0,
    'ELMA': 0.9970674486803518,
    'ELMALEH': 0,
    'ELMAN': 0,
    'ELMASRI': 0,
    'ELMASRY': 0,
    'ELMBLAD': 0,
    'ELMEN': 0,
    'ELMENDORF': 0,
    'ELMER': 0.9716284492809949,
    'ELMERS': 0,
    'ELMES': 0,
    'ELMGREN': 0,
    'ELMHORST': 0,
    'ELMI': 0,
    'ELMIRA': 1,
    'ELMLINGER': 0,
    'ELMO': 0.9771986970684039,
    'ELMORE': 0,
    'ELMQUIST': 0,
    'ELMS': 0,
    'ELMY': 0,
    'ELNA': 1,
    'ELNAGGAR': 0,
    'ELNESS': 0,
    'ELNICKI': 0,
    'ELNORA': 1,
    'ELO': 0,
    'ELODIA': 1,
    'ELOE': 0,
    'ELOFF': 0,
    'ELOFSON': 0,
    'ELOI': 0,
    'ELOIS': 1,
    'ELOISA': 0.9929078014184397,
    'ELOISE': 1,
    'ELOM': 0,
    'ELORRIAGA': 0,
    'ELORZA': 0,
    'ELOUISE': 1,
    'ELOWSKY': 0,
    'ELOY': 0.9917355371900827,
    'ELPERS': 0,
    'ELPHICK': 0,
    'ELQUIST': 0,
    'ELRICH': 0,
    'ELRICK': 0,
    'ELRIDGE': 0,
    'ELROD': 0,
    'ELROY': 0.9876543209876544,
    'ELS': 0,
    'ELSA': 0.9985734664764622,
    'ELSAESSER': 0,
    'ELSAID': 0,
    'ELSAS': 0,
    'ELSASS': 0,
    'ELSASSER': 0,
    'ELSAYED': 0,
    'ELSBERG': 0,
    'ELSBERND': 0,
    'ELSBERRY': 0,
    'ELSBREE': 0,
    'ELSBURY': 0,
    'ELSDON': 0,
    'ELSE': 0.8474576271186441,
    'ELSEA': 0,
    'ELSEMAN': 0,
    'ELSEMORE': 0,
    'ELSEN': 0,
    'ELSENER': 0,
    'ELSENHEIMER': 0,
    'ELSENPETER': 0,
    'ELSENSOHN': 0,
    'ELSER': 0,
    'ELSESSER': 0,
    'ELSETH': 0,
    'ELSEY': 0,
    'ELSHEIKH': 0,
    'ELSHERIF': 0,
    'ELSHIRE': 0,
    'ELSHOFF': 0,
    'ELSHOLZ': 0,
    'ELSIE': 0.999545661063153,
    'ELSIK': 0,
    'ELSING': 0,
    'ELSINGER': 0,
    'ELSKAMP': 0,
    'ELSLAGER': 0,
    'ELSMAN': 0,
    'ELSMORE': 0,
    'ELSNER': 0,
    'ELSOM': 0,
    'ELSON': 0,
    'ELSTAD': 0,
    'ELSTE': 0,
    'ELSTEIN': 0,
    'ELSTEN': 0,
    'ELSTER': 0,
    'ELSTNER': 0,
    'ELSTON': 0,
    'ELSTROM': 0,
    'ELSTUN': 0,
    'ELSWICK': 0,
    'ELSWORTH': 0,
    'ELSY': 1,
    'ELTER': 0,
    'ELTERMAN': 0,
    'ELTING': 0,
    'ELTISTE': 0,
    'ELTMAN': 0,
    'ELTON': 0.9512485136741974,
    'ELTRICH': 0,
    'ELTRINGHAM': 0,
    'ELTZ': 0,
    'ELTZROTH': 0,
    'ELUM': 0,
    'ELVA': 1,
    'ELVERA': 1,
    'ELVERS': 0,
    'ELVERT': 0,
    'ELVERUD': 0,
    'ELVERUM': 0,
    'ELVEY': 0,
    'ELVIA': 1,
    'ELVIDGE': 0,
    'ELVIE': 1,
    'ELVIN': 0.9789156626506025,
    'ELVINA': 1,
    'ELVINE': 0,
    'ELVINGTON': 0,
    'ELVIR': 0,
    'ELVIRA': 0.9928106812735364,
    'ELVIS': 0.9871668311944718,
    'ELVY': 0,
    'ELWANDA': 1,
    'ELWARD': 0,
    'ELWART': 0,
    'ELWAY': 0,
    'ELWELL': 0,
    'ELWER': 0,
    'ELWESS': 0,
    'ELWICK': 0,
    'ELWIN': 0,
    'ELWING': 0,
    'ELWOOD': 0.8777852802160702,
    'ELWORTH': 0,
    'ELWORTHY': 0,
    'ELWYN': 0,
    'ELY': 0,
    'ELYA': 0,
    'ELYEA': 0,
    'ELYSE': 1,
    'ELYSEE': 0,
    'ELZA': 0.8264462809917356,
    'ELZE': 0,
    'ELZEA': 0,
    'ELZEIN': 0,
    'ELZER': 0,
    'ELZERMAN': 0,
    'ELZEY': 0,
    'ELZIE': 0,
    'ELZINGA': 0,
    'ELZNER': 0,
    'ELZY': 0,
    'EM': 0,
    'EMA': 1,
    'EMADI': 0,
    'EMAHISER': 0,
    'EMAM': 0,
    'EMAMI': 0,
    'EMAN': 0,
    'EMANS': 0,
    'EMANUEL': 0.8945386064030132,
    'EMANUELE': 0,
    'EMANUELLI': 0,
    'EMANUELSON': 0,
    'EMARD': 0,
    'EMARY': 0,
    'EMAS': 0,
    'EMBER': 0,
    'EMBERG': 0,
    'EMBERGER': 0,
    'EMBERLEY': 0,
    'EMBERLIN': 0,
    'EMBERS': 0,
    'EMBERSON': 0,
    'EMBERT': 0,
    'EMBERTON': 0,
    'EMBERTSON': 0,
    'EMBERY': 0,
    'EMBICK': 0,
    'EMBLER': 0,
    'EMBLETON': 0,
    'EMBLEY': 0,
    'EMBLY': 0,
    'EMBODY': 0,
    'EMBREE': 0,
    'EMBRETSON': 0,
    'EMBREY': 0,
    'EMBRY': 0,
    'EMBS': 0,
    'EMBURY': 0,
    'EMCH': 0,
    'EMDE': 0,
    'EMDEN': 0,
    'EME': 0,
    'EMEIGH': 0,
    'EMEL': 0,
    'EMELANDER': 0,
    'EMELDA': 1,
    'EMELIA': 1,
    'EMELINA': 1,
    'EMELINE': 1,
    'EMELIO': 0,
    'EMELY': 1,
    'EMENHEISER': 0,
    'EMENHISER': 0,
    'EMENS': 0,
    'EMEOTT': 0,
    'EMER': 0,
    'EMERALD': 0.9523809523809523,
    'EMERIC': 0,
    'EMERICH': 0,
    'EMERICK': 0,
    'EMERINE': 0,
    'EMERITA': 1,
    'EMERLING': 0,
    'EMERSON': 0.41819132253005753,
    'EMERT': 0,
    'EMERTON': 0,
    'EMERY': 0.515729757607014,
    'EMERZIAN': 0,
    'EMES': 0,
    'EMETERIO': 0,
    'EMETT': 0,
    'EMFINGER': 0,
    'EMGE': 0,
    'EMHOF': 0,
    'EMHOFF': 0,
    'EMICH': 0,
    'EMICK': 0,
    'EMIG': 0,
    'EMIGH': 0,
    'EMIKO': 1,
    'EMIL': 0.9952854897852279,
    'EMILE': 0.9554140127388534,
    'EMILEE': 1,
    'EMILIA': 1,
    'EMILIANI': 0,
    'EMILIANO': 0,
    'EMILIE': 1,
    'EMILIEN': 0,
    'EMILIO': 0.9921671018276762,
    'EMILY': 0.9985118333253326,
    'EMIN': 0,
    'EMINETH': 0,
    'EMINGER': 0,
    'EMINHIZER': 0,
    'EMINI': 0,
    'EMISON': 0,
    'EMKE': 0,
    'EMKEN': 0,
    'EMLAW': 0,
    'EMLER': 0,
    'EMLET': 0,
    'EMLEY': 0,
    'EMLING': 0,
    'EMLY': 0,
    'EMM': 0,
    'EMMA': 0.9977022614584593,
    'EMMALINE': 1,
    'EMMANS': 0,
    'EMMANUEL': 0.9620523784072688,
    'EMMANUELLI': 0,
    'EMMART': 0,
    'EMME': 0,
    'EMMEL': 0,
    'EMMELL': 0,
    'EMMENDORFER': 0,
    'EMMENEGGER': 0,
    'EMMENS': 0,
    'EMMER': 0,
    'EMMERICH': 0,
    'EMMERICK': 0,
    'EMMERLING': 0,
    'EMMERS': 0,
    'EMMERSON': 0,
    'EMMERT': 0,
    'EMMET': 0,
    'EMMETT': 0.935960591133005,
    'EMMI': 0,
    'EMMICK': 0,
    'EMMIE': 1,
    'EMMING': 0,
    'EMMINGER': 0,
    'EMMITT': 0.9523809523809523,
    'EMMONS': 0,
    'EMMOTT': 0,
    'EMMRICH': 0,
    'EMMS': 0,
    'EMMY': 1,
    'EMO': 0,
    'EMOGENE': 1,
    'EMON': 0,
    'EMOND': 0,
    'EMONS': 0,
    'EMORD': 0,
    'EMORE': 0,
    'EMORY': 0.7968127490039841,
    'EMOTO': 0,
    'EMPERADOR': 0,
    'EMPEY': 0,
    'EMPFIELD': 0,
    'EMPIE': 0,
    'EMPLEO': 0,
    'EMPSON': 0,
    'EMPTAGE': 0,
    'EMRANI': 0,
    'EMREY': 0,
    'EMRICH': 0,
    'EMRICK': 0,
    'EMRY': 0,
    'EMS': 0,
    'EMSHOFF': 0,
    'EMSHWILLER': 0,
    'EMSLANDER': 0,
    'EMSLEY': 0,
    'EMSLIE': 0,
    'EMSWELLER': 0,
    'EMSWILER': 0,
    'EMTER': 0,
    'EN': 0,
    'ENA': 0.9876543209876544,
    'ENABNIT': 0,
    'ENAMA': 0,
    'ENAMORADO': 0,
    'ENARSON': 0,
    'ENAS': 0,
    'ENAYATI': 0,
    'ENBERG': 0,
    'ENBODY': 0,
    'ENCABO': 0,
    'ENCALADA': 0,
    'ENCALADE': 0,
    'ENCARNACAO': 0,
    'ENCARNACION': 0,
    'ENCE': 0,
    'ENCINA': 0,
    'ENCINAS': 0,
    'ENCINIA': 0,
    'ENCINIAS': 0,
    'ENCINO': 0,
    'ENCINOSA': 0,
    'ENCISO': 0,
    'ENCIZO': 0,
    'ENCK': 0,
    'ENCKE': 0,
    'END': 0,
    'ENDA': 1,
    'ENDAHL': 0,
    'ENDARA': 0,
    'ENDAYA': 0,
    'ENDE': 0,
    'ENDEAN': 0,
    'ENDECOTT': 0,
    'ENDELMAN': 0,
    'ENDER': 0,
    'ENDERBY': 0,
    'ENDERIE': 0,
    'ENDERLE': 0,
    'ENDERLEIN': 0,
    'ENDERLIN': 0,
    'ENDERS': 0,
    'ENDERSBE': 0,
    'ENDERSBY': 0,
    'ENDERSON': 0,
    'ENDERT': 0,
    'ENDERUD': 0,
    'ENDICOTT': 0,
    'ENDL': 0,
    'ENDLER': 0,
    'ENDLICH': 0,
    'ENDO': 0,
    'ENDORF': 0,
    'ENDOW': 0,
    'ENDRE': 0,
    'ENDRES': 0,
    'ENDRESEN': 0,
    'ENDRESON': 0,
    'ENDRESS': 0,
    'ENDRIES': 0,
    'ENDRIS': 0,
    'ENDRISS': 0,
    'ENDRIZZI': 0,
    'ENDSLEY': 0,
    'ENDTER': 0,
    'ENDY': 0,
    'ENE': 0,
    'ENEA': 0,
    'ENEDINA': 1,
    'ENEIDA': 1,
    'ENEIX': 0,
    'ENER': 0,
    'ENERIO': 0,
    'ENERSON': 0,
    'ENES': 0,
    'ENEVOLDSEN': 0,
    'ENEY': 0,
    'ENFIELD': 0,
    'ENFINGER': 0,
    'ENG': 0,
    'ENGA': 0,
    'ENGAN': 0,
    'ENGARD': 0,
    'ENGASSER': 0,
    'ENGBARTH': 0,
    'ENGBER': 0,
    'ENGBERG': 0,
    'ENGBERS': 0,
    'ENGBLOM': 0,
    'ENGBRECHT': 0,
    'ENGBRETSON': 0,
    'ENGBROCK': 0,
    'ENGDAHL': 0,
    'ENGE': 0,
    'ENGEBRETSEN': 0,
    'ENGEBRETSON': 0,
    'ENGEL': 0,
    'ENGELAGE': 0,
    'ENGELBACH': 0,
    'ENGELBART': 0,
    'ENGELBERG': 0,
    'ENGELBERGER': 0,
    'ENGELBERT': 0,
    'ENGELBRECHT': 0,
    'ENGELBY': 0,
    'ENGELDINGER': 0,
    'ENGELEN': 0,
    'ENGELGAU': 0,
    'ENGELHARD': 0,
    'ENGELHARDT': 0,
    'ENGELHART': 0,
    'ENGELHAUPT': 0,
    'ENGELHORN': 0,
    'ENGELKE': 0,
    'ENGELKEN': 0,
    'ENGELKENS': 0,
    'ENGELKES': 0,
    'ENGELKING': 0,
    'ENGELL': 0,
    'ENGELLAND': 0,
    'ENGELMAN': 0,
    'ENGELMANN': 0,
    'ENGELMEIER': 0,
    'ENGELMEYER': 0,
    'ENGELS': 0,
    'ENGELSEN': 0,
    'ENGELSMA': 0,
    'ENGELSMAN': 0,
    'ENGELSON': 0,
    'ENGELSTAD': 0,
    'ENGEMAN': 0,
    'ENGEMANN': 0,
    'ENGEN': 0,
    'ENGER': 0,
    'ENGERMAN': 0,
    'ENGERON': 0,
    'ENGERS': 0,
    'ENGERT': 0,
    'ENGESETH': 0,
    'ENGESSER': 0,
    'ENGET': 0,
    'ENGFER': 0,
    'ENGH': 0,
    'ENGHAUSER': 0,
    'ENGHOLM': 0,
    'ENGIE': 0,
    'ENGINEER': 0,
    'ENGL': 0,
    'ENGLADE': 0,
    'ENGLAND': 0,
    'ENGLANDER': 0,
    'ENGLAR': 0,
    'ENGLE': 0,
    'ENGLEBERT': 0,
    'ENGLEBRECHT': 0,
    'ENGLEBRETSON': 0,
    'ENGLEBRIGHT': 0,
    'ENGLEDOW': 0,
    'ENGLEHARDT': 0,
    'ENGLEHART': 0,
    'ENGLEKA': 0,
    'ENGLEKING': 0,
    'ENGLEMAN': 0,
    'ENGLEN': 0,
    'ENGLER': 0,
    'ENGLERT': 0,
    'ENGLERTH': 0,
    'ENGLES': 0,
    'ENGLESE': 0,
    'ENGLESON': 0,
    'ENGLETON': 0,
    'ENGLETT': 0,
    'ENGLEY': 0,
    'ENGLIN': 0,
    'ENGLING': 0,
    'ENGLIS': 0,
    'ENGLISH': 0,
    'ENGLISHBEE': 0,
    'ENGLUND': 0,
    'ENGMAN': 0,
    'ENGMANN': 0,
    'ENGQUIST': 0,
    'ENGRAM': 0,
    'ENGROFF': 0,
    'ENGST': 0,
    'ENGSTLER': 0,
    'ENGSTRAND': 0,
    'ENGSTROM': 0,
    'ENGUM': 0,
    'ENGVALL': 0,
    'ENGWALL': 0,
    'ENGWER': 0,
    'ENICK': 0,
    'ENID': 1,
    'ENIS': 0,
    'ENIX': 0,
    'ENK': 0,
    'ENKE': 0,
    'ENLOE': 0,
    'ENLOW': 0,
    'ENLUND': 0,
    'ENMAN': 0,
    'ENMON': 0,
    'ENNA': 0,
    'ENNALS': 0,
    'ENNEKING': 0,
    'ENNELS': 0,
    'ENNEN': 0,
    'ENNENGA': 0,
    'ENNES': 0,
    'ENNESSER': 0,
    'ENNETT': 0,
    'ENNEY': 0,
    'ENNINGA': 0,
    'ENNIS': 0,
    'ENNISS': 0,
    'ENNIST': 0,
    'ENNO': 0,
    'ENNS': 0,
    'ENO': 0,
    'ENOCH': 0.8064516129032258,
    'ENOCHS': 0,
    'ENOCKSON': 0,
    'ENOLA': 1,
    'ENOMOTO': 0,
    'ENOS': 0,
    'ENOX': 0,
    'ENQUIST': 0,
    'ENRICO': 0,
    'ENRIGHT': 0,
    'ENRIGUEZ': 0,
    'ENRILE': 0,
    'ENRIQUE': 0.9918068132815869,
    'ENRIQUES': 0,
    'ENRIQUETA': 1,
    'ENRIQUEZ': 0,
    'ENROTH': 0,
    'ENROUGHTY': 0,
    'ENRRIQUEZ': 0,
    'ENS': 0,
    'ENSCH': 0,
    'ENSCOE': 0,
    'ENSELL': 0,
    'ENSENAT': 0,
    'ENSER': 0,
    'ENSEY': 0,
    'ENSIGN': 0,
    'ENSING': 0,
    'ENSINGER': 0,
    'ENSLEN': 0,
    'ENSLEY': 0,
    'ENSLIN': 0,
    'ENSLOW': 0,
    'ENSMAN': 0,
    'ENSMINGER': 0,
    'ENSOR': 0,
    'ENSRUD': 0,
    'ENSSLIN': 0,
    'ENSTAD': 0,
    'ENSTROM': 0,
    'ENSWORTH': 0,
    'ENSZ': 0,
    'ENT': 0,
    'ENTE': 0,
    'ENTENMAN': 0,
    'ENTENMANN': 0,
    'ENTER': 0,
    'ENTERKIN': 0,
    'ENTERLINE': 0,
    'ENTERS': 0,
    'ENTIN': 0,
    'ENTINGER': 0,
    'ENTINGH': 0,
    'ENTLER': 0,
    'ENTNER': 0,
    'ENTREKIN': 0,
    'ENTRESS': 0,
    'ENTRICAN': 0,
    'ENTRIKEN': 0,
    'ENTRIKIN': 0,
    'ENTRINGER': 0,
    'ENTROP': 0,
    'ENTRUP': 0,
    'ENTSMINGER': 0,
    'ENTWISLE': 0,
    'ENTWISTLE': 0,
    'ENTZ': 0,
    'ENTZEL': 0,
    'ENTZI': 0,
    'ENTZMINGER': 0,
    'ENWRIGHT': 0,
    'ENYARD': 0,
    'ENYART': 0,
    'ENYEART': 0,
    'ENZ': 0,
    'ENZENAUER': 0,
    'ENZER': 0,
    'ENZLER': 0,
    'ENZMANN': 0,
    'ENZMINGER': 0,
    'ENZOR': 0,
    'ENZWEILER': 0,
    'EODICE': 0,
    'EOFF': 0,
    'EOM': 0,
    'EON': 0,
    'EOVALDI': 0,
    'EPELBAUM': 0,
    'EPERJESI': 0,
    'EPES': 0,
    'EPHRAIM': 0,
    'EPHREM': 0,
    'EPHRIAM': 0,
    'EPHRON': 0,
    'EPIFANIA': 1,
    'EPIFANIO': 0,
    'EPIFANO': 0,
    'EPISCOPO': 0,
    'EPKE': 0,
    'EPLEE': 0,
    'EPLER': 0,
    'EPLETT': 0,
    'EPLEY': 0,
    'EPLIN': 0,
    'EPLING': 0,
    'EPNER': 0,
    'EPOLITO': 0,
    'EPP': 0,
    'EPPARD': 0,
    'EPPEL': 0,
    'EPPENGER': 0,
    'EPPENS': 0,
    'EPPENSTEIN': 0,
    'EPPER': 0,
    'EPPERHART': 0,
    'EPPERLEY': 0,
    'EPPERLY': 0,
    'EPPERS': 0,
    'EPPERSON': 0,
    'EPPERT': 0,
    'EPPES': 0,
    'EPPICH': 0,
    'EPPIG': 0,
    'EPPINETTE': 0,
    'EPPING': 0,
    'EPPINGA': 0,
    'EPPINGER': 0,
    'EPPINK': 0,
    'EPPLE': 0,
    'EPPLER': 0,
    'EPPLEY': 0,
    'EPPLIN': 0,
    'EPPLING': 0,
    'EPPOLITO': 0,
    'EPPRIGHT': 0,
    'EPPS': 0,
    'EPPSTEIN': 0,
    'EPRIGHT': 0,
    'EPSHTEYN': 0,
    'EPSON': 0,
    'EPSTEIN': 0,
    'EPTING': 0,
    'EPTON': 0,
    'EQUI': 0,
    'EQUIHUA': 0,
    'ER': 0,
    'ERA': 0.9732360097323601,
    'ERAL': 0,
    'ERAMO': 0,
    'ERARD': 0,
    'ERARDI': 0,
    'ERAS': 0,
    'ERASMO': 1,
    'ERASMUS': 0,
    'ERASO': 0,
    'ERATH': 0,
    'ERATO': 0,
    'ERAZMUS': 0,
    'ERAZO': 0,
    'ERB': 0,
    'ERBA': 0,
    'ERBACH': 0,
    'ERBACHER': 0,
    'ERBAN': 0,
    'ERBAUGH': 0,
    'ERBE': 0,
    'ERBECK': 0,
    'ERBELE': 0,
    'ERBEN': 0,
    'ERBER': 0,
    'ERBERT': 0,
    'ERBES': 0,
    'ERBLAND': 0,
    'ERBS': 0,
    'ERBST': 0,
    'ERBSTOESSER': 0,
    'ERBY': 0,
    'ERCANBRACK': 0,
    'ERCEG': 0,
    'ERCHUL': 0,
    'ERCK': 0,
    'ERCOLANI': 0,
    'ERCOLANO': 0,
    'ERCOLE': 0,
    'ERCOLI': 0,
    'ERCOLINI': 0,
    'ERCOLINO': 0,
    'ERD': 0,
    'ERDAHL': 0,
    'ERDAL': 0,
    'ERDEI': 0,
    'ERDEL': 0,
    'ERDELT': 0,
    'ERDELY': 0,
    'ERDELYI': 0,
    'ERDEM': 0,
    'ERDIE': 0,
    'ERDLE': 0,
    'ERDLEY': 0,
    'ERDLY': 0,
    'ERDMAN': 0,
    'ERDMANN': 0,
    'ERDNER': 0,
    'ERDODY': 0,
    'ERDOGAN': 0,
    'ERDOS': 0,
    'ERDRICH': 0,
    'ERDY': 0,
    'EREBIA': 0,
    'EREDIA': 0,
    'EREKSON': 0,
    'EREMITA': 0,
    'EREN': 0,
    'ERENBERG': 0,
    'ERES': 0,
    'ERETH': 0,
    'EREVIA': 0,
    'EREZ': 0,
    'ERFANI': 0,
    'ERFE': 0,
    'ERFLE': 0,
    'ERFMAN': 0,
    'ERFORD': 0,
    'ERFOURTH': 0,
    'ERFURT': 0,
    'ERFURTH': 0,
    'ERGAS': 0,
    'ERGEN': 0,
    'ERGENBRIGHT': 0,
    'ERGER': 0,
    'ERGLE': 0,
    'ERHARD': 0,
    'ERHARDT': 0,
    'ERHART': 0,
    'ERIACHO': 0,
    'ERIC': 0.9997802680729511,
    'ERICA': 1,
    'ERICE': 0,
    'ERICH': 0.9722222222222223,
    'ERICHSEN': 0,
    'ERICHSON': 0,
    'ERICK': 0.9918068132815869,
    'ERICKA': 1,
    'ERICKS': 0,
    'ERICKSEN': 0,
    'ERICKSON': 0,
    'ERICSON': 0,
    'ERICSSON': 0,
    'ERIE': 0,
    'ERIK': 0.9994121105232217,
    'ERIKA': 1,
    'ERIKS': 0,
    'ERIKSEN': 0,
    'ERIKSON': 0,
    'ERIKSSON': 0,
    'ERIN': 0.999392261462624,
    'ERINN': 1,
    'ERION': 0,
    'ERISMAN': 0,
    'ERIVES': 0,
    'ERIVEZ': 0,
    'ERIXON': 0,
    'ERJAVEC': 0,
    'ERK': 0,
    'ERKAN': 0,
    'ERKE': 0,
    'ERKEL': 0,
    'ERKELENS': 0,
    'ERKENBRACK': 0,
    'ERKENS': 0,
    'ERKER': 0,
    'ERKERT': 0,
    'ERKHART': 0,
    'ERKINS': 0,
    'ERKKILA': 0,
    'ERKMAN': 0,
    'ERKS': 0,
    'ERL': 0,
    'ERLACHER': 0,
    'ERLAND': 0,
    'ERLANDSEN': 0,
    'ERLANDSON': 0,
    'ERLANGER': 0,
    'ERLANSON': 0,
    'ERLE': 0,
    'ERLENBACH': 0,
    'ERLENBUSCH': 0,
    'ERLENE': 1,
    'ERLER': 0,
    'ERLEWEIN': 0,
    'ERLEWINE': 0,
    'ERLICH': 0,
    'ERLICHMAN': 0,
    'ERLICK': 0,
    'ERLIKH': 0,
    'ERLINDA': 1,
    'ERLINE': 1,
    'ERLING': 0,
    'ERLINGER': 0,
    'ERLITZ': 0,
    'ERLWEIN': 0,
    'ERMA': 1,
    'ERMAN': 0,
    'ERMANN': 0,
    'ERMATINGER': 0,
    'ERMEL': 0,
    'ERMELINDA': 1,
    'ERMELING': 0,
    'ERMER': 0,
    'ERMERT': 0,
    'ERMEY': 0,
    'ERMI': 0,
    'ERMILIO': 0,
    'ERMINIA': 1,
    'ERMIS': 0,
    'ERMISCH': 0,
    'ERMOLD': 0,
    'ERNA': 1,
    'ERNANDEZ': 0,
    'ERNAT': 0,
    'ERNDT': 0,
    'ERNE': 0,
    'ERNENWEIN': 0,
    'ERNER': 0,
    'ERNEST': 0.9919719479560765,
    'ERNESTI': 0,
    'ERNESTINA': 1,
    'ERNESTINE': 0.9989484752891693,
    'ERNESTO': 0.9978425026968716,
    'ERNEWEIN': 0,
    'ERNEY': 0,
    'ERNHART': 0,
    'ERNI': 0,
    'ERNIE': 1,
    'ERNISSE': 0,
    'ERNO': 0,
    'ERNSBERGER': 0,
    'ERNSPIKER': 0,
    'ERNST': 0,
    'ERNSTBERGER': 0,
    'ERNSTER': 0,
    'ERNSTES': 0,
    'ERNSTING': 0,
    'ERNY': 0,
    'ERNZEN': 0,
    'ERO': 0,
    'EROH': 0,
    'EROL': 0,
    'ERON': 0,
    'EROS': 0,
    'ERP': 0,
    'ERPELDING': 0,
    'ERPENBACH': 0,
    'ERPENBECK': 0,
    'ERPS': 0,
    'ERQUIAGA': 0,
    'ERRANTE': 0,
    'ERRERA': 0,
    'ERRETT': 0,
    'ERRICHETTI': 0,
    'ERRICHETTO': 0,
    'ERRICHIELLO': 0,
    'ERRICKSON': 0,
    'ERRICO': 0,
    'ERRIGO': 0,
    'ERRINGTON': 0,
    'ERRO': 0,
    'ERROL': 1,
    'ERROR': 0,
    'ERRTHUM': 0,
    'ERSCHEN': 0,
    'ERSEK': 0,
    'ERSERY': 0,
    'ERSING': 0,
    'ERSKIN': 0,
    'ERSKINE': 0,
    'ERSLAND': 0,
    'ERSOY': 0,
    'ERSPAMER': 0,
    'ERSTAD': 0,
    'ERTEL': 0,
    'ERTELL': 0,
    'ERTELT': 0,
    'ERTER': 0,
    'ERTHAL': 0,
    'ERTL': 0,
    'ERTLE': 0,
    'ERTLEY': 0,
    'ERTMAN': 0,
    'ERTMER': 0,
    'ERTTER': 0,
    'ERTZ': 0,
    'ERTZBERGER': 0,
    'ERVAY': 0,
    'ERVEN': 0,
    'ERVES': 0,
    'ERVIN': 0.7167341851043939,
    'ERVINE': 0,
    'ERVING': 0,
    'ERVINS': 0,
    'ERVOLINA': 0,
    'ERWAY': 0,
    'ERWERT': 0,
    'ERWIN': 0.646551724137931,
    'ERWINE': 0,
    'ERWOOD': 0,
    'ERXLEBEN': 0,
    'ERY': 0,
    'ERYN': 1,
    'ERZ': 0,
    'ERZEN': 0,
    'ERZINGER': 0,
    'ES': 0,
    'ESA': 0,
    'ESAKI': 0,
    'ESALA': 0,
    'ESANCY': 0,
    'ESANNASON': 0,
    'ESAREY': 0,
    'ESAU': 0,
    'ESAW': 0,
    'ESBECK': 0,
    'ESBENSEN': 0,
    'ESBENSHADE': 0,
    'ESBER': 0,
    'ESCABAR': 0,
    'ESCABI': 0,
    'ESCAJEDA': 0,
    'ESCALA': 0,
    'ESCALADA': 0,
    'ESCALANTE': 0,
    'ESCALERA': 0,
    'ESCALON': 0,
    'ESCALONA': 0,
    'ESCAMILLA': 0,
    'ESCANDELL': 0,
    'ESCANDON': 0,
    'ESCANO': 0,
    'ESCANUELA': 0,
    'ESCANUELAS': 0,
    'ESCARCEGA': 0,
    'ESCARENO': 0,
    'ESCARMENT': 0,
    'ESCARPITA': 0,
    'ESCARRA': 0,
    'ESCARREGA': 0,
    'ESCARSEGA': 0,
    'ESCARTIN': 0,
    'ESCARZAGA': 0,
    'ESCATEL': 0,
    'ESCH': 0,
    'ESCHBACH': 0,
    'ESCHBACHER': 0,
    'ESCHBAUGH': 0,
    'ESCHBERGER': 0,
    'ESCHE': 0,
    'ESCHELBACH': 0,
    'ESCHEN': 0,
    'ESCHENBACH': 0,
    'ESCHENBACHER': 0,
    'ESCHENBAUM': 0,
    'ESCHENBERG': 0,
    'ESCHENBRENNER': 0,
    'ESCHENBURG': 0,
    'ESCHENFELDER': 0,
    'ESCHER': 0,
    'ESCHERICH': 0,
    'ESCHETE': 0,
    'ESCHETTE': 0,
    'ESCHLER': 0,
    'ESCHLIMAN': 0,
    'ESCHMAN': 0,
    'ESCHMANN': 0,
    'ESCHNER': 0,
    'ESCHRICH': 0,
    'ESCHWEILER': 0,
    'ESCO': 0,
    'ESCOBAL': 0,
    'ESCOBALES': 0,
    'ESCOBAR': 0,
    'ESCOBEDO': 0,
    'ESCOBER': 0,
    'ESCOBIO': 0,
    'ESCOBOSA': 0,
    'ESCOBOZA': 0,
    'ESCOCHEA': 0,
    'ESCOE': 0,
    'ESCOFFERY': 0,
    'ESCOFFIER': 0,
    'ESCOLA': 0,
    'ESCOLASTICO': 0,
    'ESCOLERO': 0,
    'ESCONTRIAS': 0,
    'ESCORCIA': 0,
    'ESCORT': 0,
    'ESCORZA': 0,
    'ESCOT': 0,
    'ESCOTO': 0,
    'ESCOTT': 0,
    'ESCOTTO': 0,
    'ESCOVAR': 0,
    'ESCOVEDO': 0,
    'ESCOVER': 0,
    'ESCRIBANO': 0,
    'ESCUADRA': 0,
    'ESCUDE': 0,
    'ESCUDERO': 0,
    'ESCUE': 0,
    'ESCUETA': 0,
    'ESCUTIA': 0,
    'ESDAILE': 0,
    'ESDALE': 0,
    'ESENWEIN': 0,
    'ESER': 0,
    'ESFAHANI': 0,
    'ESFANDIARI': 0,
    'ESFORD': 0,
    'ESGAR': 0,
    'ESGRO': 0,
    'ESGUERRA': 0,
    'ESH': 0,
    'ESHAGHIAN': 0,
    'ESHAM': 0,
    'ESHBACH': 0,
    'ESHBAUGH': 0,
    'ESHEL': 0,
    'ESHELMAN': 0,
    'ESHENBAUGH': 0,
    'ESHENOUR': 0,
    'ESHER': 0,
    'ESHETE': 0,
    'ESHLEMAN': 0,
    'ESHMAN': 0,
    'ESHO': 0,
    'ESHOM': 0,
    'ESHOO': 0,
    'ESHRAGHI': 0,
    'ESHUN': 0,
    'ESKANDAR': 0,
    'ESKANDARI': 0,
    'ESKANDER': 0,
    'ESKELI': 0,
    'ESKELSEN': 0,
    'ESKELSON': 0,
    'ESKEN': 0,
    'ESKENAZI': 0,
    'ESKER': 0,
    'ESKESEN': 0,
    'ESKEW': 0,
    'ESKEY': 0,
    'ESKILDSEN': 0,
    'ESKIN': 0,
    'ESKIND': 0,
    'ESKINE': 0,
    'ESKINS': 0,
    'ESKO': 0,
    'ESKOLA': 0,
    'ESKOW': 0,
    'ESKRA': 0,
    'ESKRIDGE': 0,
    'ESKUE': 0,
    'ESLAMI': 0,
    'ESLAVA': 0,
    'ESLER': 0,
    'ESLICK': 0,
    'ESLIN': 0,
    'ESLINGER': 0,
    'ESMAEILI': 0,
    'ESMAIL': 0,
    'ESMAILI': 0,
    'ESMAN': 0,
    'ESMAY': 0,
    'ESMERALDA': 0.9923664122137404,
    'ESMON': 0,
    'ESMOND': 0,
    'ESMONDE': 0,
    'ESNARD': 0,
    'ESNER': 0,
    'ESOLA': 0,
    'ESON': 0,
    'ESP': 0,
    'ESPADA': 0,
    'ESPADAS': 0,
    'ESPAILLAT': 0,
    'ESPALIN': 0,
    'ESPANA': 0,
    'ESPANOL': 0,
    'ESPANOLA': 0,
    'ESPANOSA': 0,
    'ESPANOZA': 0,
    'ESPARRA': 0,
    'ESPARSA': 0,
    'ESPARZA': 0,
    'ESPE': 0,
    'ESPEDAL': 0,
    'ESPEJEL': 0,
    'ESPEJO': 0,
    'ESPELAGE': 0,
    'ESPELAND': 0,
    'ESPELETA': 0,
    'ESPELIEN': 0,
    'ESPEN': 0,
    'ESPENLAUB': 0,
    'ESPENOZA': 0,
    'ESPENSCHIED': 0,
    'ESPENSHADE': 0,
    'ESPER': 0,
    'ESPERANCE': 0,
    'ESPERANZA': 0.9831460674157303,
    'ESPERICUETA': 0,
    'ESPERO': 0,
    'ESPERON': 0,
    'ESPERSEN': 0,
    'ESPERSON': 0,
    'ESPESETH': 0,
    'ESPEUT': 0,
    'ESPEY': 0,
    'ESPICH': 0,
    'ESPIE': 0,
    'ESPIN': 0,
    'ESPINA': 0,
    'ESPINAL': 0,
    'ESPINALES': 0,
    'ESPINAR': 0,
    'ESPINDA': 0,
    'ESPINDOLA': 0,
    'ESPINEL': 0,
    'ESPINELI': 0,
    'ESPINET': 0,
    'ESPING': 0,
    'ESPINO': 0,
    'ESPINOLA': 0,
    'ESPINOSA': 0,
    'ESPINOZA': 0,
    'ESPINUEVA': 0,
    'ESPIRICUETA': 0,
    'ESPIRITU': 0,
    'ESPIRITUSANTO': 0,
    'ESPITIA': 0,
    'ESPLIN': 0,
    'ESPLING': 0,
    'ESPONDA': 0,
    'ESPONGE': 0,
    'ESPOSITO': 0,
    'ESPOSO': 0,
    'ESPOSTI': 0,
    'ESPOSTO': 0,
    'ESPREE': 0,
    'ESPRIT': 0,
    'ESPUDO': 0,
    'ESPY': 0,
    'ESQUE': 0,
    'ESQUEA': 0,
    'ESQUEDA': 0,
    'ESQUENAZI': 0,
    'ESQUER': 0,
    'ESQUERRA': 0,
    'ESQUERRE': 0,
    'ESQUIBEL': 0,
    'ESQUIJAROSA': 0,
    'ESQUILIN': 0,
    'ESQUIVAL': 0,
    'ESQUIVEL': 0,
    'ESQUIVIAS': 0,
    'ESRY': 0,
    'ESS': 0,
    'ESSA': 0,
    'ESSARY': 0,
    'ESSAY': 0,
    'ESSE': 0,
    'ESSEL': 0,
    'ESSELMAN': 0,
    'ESSELSTROM': 0,
    'ESSEN': 0,
    'ESSENBERG': 0,
    'ESSENBURG': 0,
    'ESSENMACHER': 0,
    'ESSENPREIS': 0,
    'ESSER': 0,
    'ESSERMAN': 0,
    'ESSERT': 0,
    'ESSERY': 0,
    'ESSES': 0,
    'ESSEX': 0,
    'ESSEY': 0,
    'ESSHAKI': 0,
    'ESSICK': 0,
    'ESSIE': 0.9986225895316804,
    'ESSIEN': 0,
    'ESSIG': 0,
    'ESSING': 0,
    'ESSINGER': 0,
    'ESSINGTON': 0,
    'ESSINK': 0,
    'ESSIX': 0,
    'ESSLER': 0,
    'ESSLEY': 0,
    'ESSLING': 0,
    'ESSLINGER': 0,
    'ESSMAN': 0,
    'ESSMANN': 0,
    'ESSNER': 0,
    'ESSON': 0,
    'ESSWEIN': 0,
    'EST': 0,
    'ESTA': 0.9803921568627452,
    'ESTABILLO': 0,
    'ESTABROOK': 0,
    'ESTABROOKS': 0,
    'ESTACIO': 0,
    'ESTADES': 0,
    'ESTADT': 0,
    'ESTALA': 0,
    'ESTANISLAO': 0,
    'ESTAVE': 0,
    'ESTAVILLO': 0,
    'ESTAY': 0,
    'ESTBY': 0,
    'ESTE': 0,
    'ESTEB': 0,
    'ESTEBAN': 0.9187279151943463,
    'ESTEE': 0,
    'ESTEEN': 0,
    'ESTEFAN': 0,
    'ESTEFANA': 1,
    'ESTEL': 0,
    'ESTELA': 0.9852216748768473,
    'ESTELL': 0.7272727272727273,
    'ESTELLA': 0.9942004971002485,
    'ESTELLE': 0.9833378858235455,
    'ESTEN': 0,
    'ESTENSON': 0,
    'ESTEP': 0,
    'ESTEPA': 0,
    'ESTEPHAN': 0,
    'ESTEPP': 0,
    'ESTEPPE': 0,
    'ESTER': 0.9625126646403243,
    'ESTERAS': 0,
    'ESTERBERG': 0,
    'ESTERBROOK': 0,
    'ESTERBY': 0,
    'ESTERLE': 0,
    'ESTERLINE': 0,
    'ESTERLING': 0,
    'ESTERLY': 0,
    'ESTERMAN': 0,
    'ESTERMYER': 0,
    'ESTERS': 0,
    'ESTERSON': 0,
    'ESTES': 0,
    'ESTESS': 0,
    'ESTEVA': 0,
    'ESTEVAN': 0,
    'ESTEVANE': 0,
    'ESTEVE': 0,
    'ESTEVES': 0,
    'ESTEVEZ': 0,
    'ESTEVIS': 0,
    'ESTEY': 0,
    'ESTHER': 0.9987966305655837,
    'ESTIGOY': 0,
    'ESTILETTE': 0,
    'ESTILL': 0,
    'ESTILLORE': 0,
    'ESTIMABLE': 0,
    'ESTIME': 0,
    'ESTIOKO': 0,
    'ESTIPONA': 0,
    'ESTIS': 0,
    'ESTIVERNE': 0,
    'ESTLE': 0,
    'ESTLER': 0,
    'ESTLING': 0,
    'ESTLOW': 0,
    'ESTLUND': 0,
    'ESTOCK': 0,
    'ESTOESTA': 0,
    'ESTOK': 0,
    'ESTON': 0,
    'ESTOPARE': 0,
    'ESTOPINAL': 0,
    'ESTOPINAN': 0,
    'ESTOQUE': 0,
    'ESTORES': 0,
    'ESTORGA': 0,
    'ESTRACA': 0,
    'ESTRADA': 0,
    'ESTRADO': 0,
    'ESTRELA': 0,
    'ESTRELLA': 0.44313146233382567,
    'ESTRELLADO': 0,
    'ESTRELLO': 0,
    'ESTREM': 0,
    'ESTREMERA': 0,
    'ESTRICH': 0,
    'ESTRIDGE': 0,
    'ESTRIGHT': 0,
    'ESTRIN': 0,
    'ESTROFF': 0,
    'ESTUDILLO': 0,
    'ESTUPINAN': 0,
    'ESTUPINIAN': 0,
    'ESTUS': 0,
    'ESTWICK': 0,
    'ESTY': 0,
    'ESWORTHY': 0,
    'ETCHART': 0,
    'ETCHASON': 0,
    'ETCHBERGER': 0,
    'ETCHELLS': 0,
    'ETCHER': 0,
    'ETCHESON': 0,
    'ETCHEVERRY': 0,
    'ETCHIESON': 0,
    'ETCHISON': 0,
    'ETCITTY': 0,
    'ETEAKI': 0,
    'ETELAMAKI': 0,
    'ETEMADI': 0,
    'ETEN': 0,
    'ETERNO': 0,
    'ETGEN': 0,
    'ETHA': 1,
    'ETHAN': 1,
    'ETHEART': 0,
    'ETHEL': 1,
    'ETHELBAH': 0,
    'ETHELENE': 1,
    'ETHELL': 0,
    'ETHELYN': 1,
    'ETHEN': 0,
    'ETHER': 0,
    'ETHEREDGE': 0,
    'ETHERIDGE': 0,
    'ETHERINGTON': 0,
    'ETHERLY': 0,
    'ETHERTON': 0,
    'ETHIER': 0,
    'ETHINGTON': 0,
    'ETHREDGE': 0,
    'ETHRIDGE': 0,
    'ETHYL': 1,
    'ETIE': 0,
    'ETIENNE': 0,
    'ETIER': 0,
    'ETIM': 0,
    'ETKIN': 0,
    'ETKINS': 0,
    'ETLER': 0,
    'ETLING': 0,
    'ETLINGER': 0,
    'ETNYRE': 0,
    'ETO': 0,
    'ETRATA': 0,
    'ETRINGER': 0,
    'ETRIS': 0,
    'ETSITTY': 0,
    'ETSUKO': 1,
    'ETTA': 0.9979209979209979,
    'ETTEL': 0,
    'ETTELSON': 0,
    'ETTEN': 0,
    'ETTENGER': 0,
    'ETTENHOFER': 0,
    'ETTER': 0,
    'ETTERS': 0,
    'ETTIE': 1,
    'ETTIENNE': 0,
    'ETTINGER': 0,
    'ETTL': 0,
    'ETTLEMAN': 0,
    'ETTLIN': 0,
    'ETTLING': 0,
    'ETTLINGER': 0,
    'ETTNER': 0,
    'ETTORE': 0,
    'ETTORRE': 0,
    'ETTS': 0,
    'ETUE': 0,
    'ETUK': 0,
    'ETWAROO': 0,
    'ETZ': 0,
    'ETZEL': 0,
    'ETZKORN': 0,
    'ETZLER': 0,
    'ETZOLD': 0,
    'ETZWEILER': 0,
    'ETZWILER': 0,
    'EU': 0,
    'EUBANK': 0,
    'EUBANKS': 0,
    'EUBER': 0,
    'EUCEDA': 0,
    'EUCHNER': 0,
    'EUCKER': 0,
    'EUCLIDE': 0,
    'EUDALEY': 0,
    'EUDALY': 0,
    'EUDAVE': 0,
    'EUDEY': 0,
    'EUDY': 0,
    'EUELL': 0,
    'EUERLE': 0,
    'EUFEMIA': 0.9615384615384616,
    'EUFRACIO': 0,
    'EUGENA': 1,
    'EUGENE': 0.9949822018269933,
    'EUGENIA': 1,
    'EUGENIE': 1,
    'EUGENIO': 0.9234828496042216,
    'EUGLEY': 0,
    'EUGSTER': 0,
    'EUHUS': 0,
    'EUKER': 0,
    'EUL': 0,
    'EULA': 1,
    'EULAH': 1,
    'EULALIA': 1,
    'EULBERG': 0,
    'EULER': 0,
    'EULIANO': 0,
    'EULISS': 0,
    'EULL': 0,
    'EULLOQUI': 0,
    'EULO': 0,
    'EUM': 0,
    'EUN': 0.9615384615384616,
    'EUNA': 1,
    'EUNICE': 0.9963099630996309,
    'EUPER': 0,
    'EURA': 1,
    'EURE': 0,
    'EUREK': 0,
    'EURESTE': 0,
    'EURESTI': 0,
    'EURICH': 0,
    'EURICK': 0,
    'EUROPA': 0,
    'EURTON': 0,
    'EURY': 0,
    'EUSANIO': 0,
    'EUSEBIA': 1,
    'EUSEBIO': 0.8849557522123894,
    'EUSEY': 0,
    'EUSON': 0,
    'EUSTACE': 0,
    'EUSTACHE': 0,
    'EUSTAQUIO': 0,
    'EUSTICE': 0,
    'EUSTIS': 0,
    'EUSTOLIA': 1,
    'EUSTON': 0,
    'EUTENEUER': 0,
    'EUTON': 0,
    'EUTSEY': 0,
    'EUTSLER': 0,
    'EUTZY': 0,
    'EUYOQUE': 0,
    'EVA': 0.9984301412872842,
    'EVALYN': 1,
    'EVAN': 0.9834599910594546,
    'EVANCHO': 0,
    'EVANGELHO': 0,
    'EVANGELINA': 1,
    'EVANGELINE': 1,
    'EVANGELIST': 0,
    'EVANGELISTA': 0,
    'EVANGELISTI': 0,
    'EVANGELOU': 0,
    'EVANGER': 0,
    'EVANICH': 0,
    'EVANICK': 0,
    'EVANISH': 0,
    'EVANKO': 0,
    'EVANKOVICH': 0,
    'EVANOFF': 0,
    'EVANOSKI': 0,
    'EVANOVICH': 0,
    'EVANOW': 0,
    'EVANS': 0,
    'EVANSKI': 0,
    'EVANSON': 0,
    'EVARD': 0,
    'EVARISTO': 0,
    'EVARO': 0,
    'EVARTS': 0,
    'EVARTT': 0,
    'EVATT': 0,
    'EVAVOLD': 0,
    'EVE': 0.9781790820165539,
    'EVEANS': 0,
    'EVEILLARD': 0,
    'EVELAND': 0,
    'EVELD': 0,
    'EVELEIGH': 0,
    'EVELER': 0,
    'EVELETH': 0,
    'EVELIA': 1,
    'EVELIN': 1,
    'EVELINA': 1,
    'EVELINE': 1,
    'EVELSIZER': 0,
    'EVELY': 0,
    'EVELYN': 0.9986973512809378,
    'EVELYNE': 1,
    'EVELYNN': 1,
    'EVEN': 0,
    'EVENDEN': 0,
    'EVENER': 0,
    'EVENHOUSE': 0,
    'EVENS': 0,
    'EVENSEN': 0,
    'EVENSON': 0,
    'EVENSTAD': 0,
    'EVER': 0,
    'EVERAGE': 0,
    'EVERARD': 0,
    'EVERDING': 0,
    'EVERED': 0,
    'EVEREST': 0,
    'EVERET': 0,
    'EVERETT': 0.7988787666433077,
    'EVERETTE': 0.8310249307479224,
    'EVERETTS': 0,
    'EVERHARD': 0,
    'EVERHARDT': 0,
    'EVERHART': 0,
    'EVERHEART': 0,
    'EVERIDGE': 0,
    'EVERILL': 0,
    'EVERING': 0,
    'EVERINGHAM': 0,
    'EVERIST': 0,
    'EVERITT': 0,
    'EVERLEY': 0,
    'EVERLINE': 0,
    'EVERLING': 0,
    'EVERLY': 0,
    'EVERMAN': 0,
    'EVERNHAM': 0,
    'EVERROAD': 0,
    'EVERS': 0,
    'EVERSGERD': 0,
    'EVERSLEY': 0,
    'EVERSMAN': 0,
    'EVERSMEYER': 0,
    'EVERSOLE': 0,
    'EVERSOLL': 0,
    'EVERSON': 0,
    'EVERSULL': 0,
    'EVERT': 0,
    'EVERTON': 0,
    'EVERTS': 0,
    'EVERTSEN': 0,
    'EVERTSON': 0,
    'EVERTT': 0,
    'EVERTZ': 0,
    'EVERY': 0,
    'EVES': 0,
    'EVESLAGE': 0,
    'EVETT': 0,
    'EVETTE': 1,
    'EVETTS': 0,
    'EVEY': 0,
    'EVIA': 1,
    'EVICH': 0,
    'EVICK': 0,
    'EVIE': 1,
    'EVILSIZER': 0,
    'EVILSIZOR': 0,
    'EVINGER': 0,
    'EVINK': 0,
    'EVINS': 0,
    'EVISON': 0,
    'EVISTON': 0,
    'EVITA': 1,
    'EVITT': 0,
    'EVITTS': 0,
    'EVJE': 0,
    'EVJEN': 0,
    'EVOLA': 0,
    'EVON': 0.9146341463414634,
    'EVONIUK': 0,
    'EVONNE': 1,
    'EVORA': 0,
    'EVORS': 0,
    'EVOY': 0,
    'EVRAETS': 0,
    'EVRARD': 0,
    'EVRIDGE': 0,
    'EWA': 1,
    'EWALD': 0,
    'EWALT': 0,
    'EWAN': 0,
    'EWARD': 0,
    'EWARDS': 0,
    'EWART': 0,
    'EWASKO': 0,
    'EWBANK': 0,
    'EWELL': 0,
    'EWEN': 0,
    'EWENS': 0,
    'EWER': 0,
    'EWERS': 0,
    'EWERT': 0,
    'EWERTZ': 0,
    'EWIG': 0,
    'EWIN': 0,
    'EWING': 0,
    'EWINGS': 0,
    'EWINS': 0,
    'EWOLDT': 0,
    'EWRY': 0,
    'EWTON': 0,
    'EWY': 0,
    'EX': 0,
    'EXANTUS': 0,
    'EXAVIER': 0,
    'EXCELL': 0,
    'EXCELLENT': 0,
    'EXE': 0,
    'EXEL': 0,
    'EXELBY': 0,
    'EXENDINE': 0,
    'EXFORD': 0,
    'EXIE': 1,
    'EXIGA': 0,
    'EXIL': 0,
    'EXILUS': 0,
    'EXLER': 0,
    'EXLEY': 0,
    'EXLINE': 0,
    'EXNER': 0,
    'EXON': 0,
    'EXPOSE': 0,
    'EXPOSITO': 0,
    'EXTER': 0,
    'EXTINE': 0,
    'EXTON': 0,
    'EXUM': 0,
    'EXUME': 0,
    'EY': 0,
    'EYBERG': 0,
    'EYCHANER': 0,
    'EYCHNER': 0,
    'EYDELMAN': 0,
    'EYE': 0,
    'EYER': 0,
    'EYERLY': 0,
    'EYERMAN': 0,
    'EYERMANN': 0,
    'EYERS': 0,
    'EYESTONE': 0,
    'EYINK': 0,
    'EYL': 0,
    'EYLANDER': 0,
    'EYLAR': 0,
    'EYLER': 0,
    'EYLES': 0,
    'EYMAN': 0,
    'EYMANN': 0,
    'EYMARD': 0,
    'EYMER': 0,
    'EYNON': 0,
    'EYO': 0,
    'EYOB': 0,
    'EYRAUD': 0,
    'EYRE': 0,
    'EYRES': 0,
    'EYRICH': 0,
    'EYRING': 0,
    'EYSTAD': 0,
    'EYSTER': 0,
    'EYTCHESON': 0,
    'EYTCHISON': 0,
    'EYTH': 0,
    'EYZAGUIRRE': 0,
    'EZAKI': 0,
    'EZE': 0,
    'EZEH': 0,
    'EZEKIEL': 0.9324009324009324,
    'EZELL': 0,
    'EZELLE': 0,
    'EZENWA': 0,
    'EZEQUIEL': 1,
    'EZER': 0,
    'EZERNACK': 0,
    'EZERSKY': 0,
    'EZINGA': 0,
    'EZPINOZA': 0,
    'EZQUIVEL': 0,
    'EZRA': 0.9776536312849162,
    'EZRATTY': 0,
    'EZZARD': 0,
    'EZZAT': 0,
    'EZZELL': 0,
    'EZZELLE': 0,
    'EZZI': 0,
    'EZZO': 0,
    'FA': 0,
    'FAABORG': 0,
    'FAAMAUSILI': 0,
    'FAAS': 0,
    'FAASS': 0,
    'FAASSE': 0,
    'FAATZ': 0,
    'FABACHER': 0,
    'FABBO': 0,
    'FABBRI': 0,
    'FABBRINI': 0,
    'FABBRO': 0,
    'FABE': 0,
    'FABEC': 0,
    'FABEL': 0,
    'FABELA': 0,
    'FABELLA': 0,
    'FABELO': 0,
    'FABER': 0,
    'FABERT': 0,
    'FABI': 0,
    'FABIA': 0,
    'FABIAN': 0.7471980074719801,
    'FABIANI': 0,
    'FABIANO': 0,
    'FABIANSKI': 0,
    'FABICH': 0,
    'FABICK': 0,
    'FABIE': 0,
    'FABIEN': 0,
    'FABILA': 0,
    'FABIN': 0,
    'FABINA': 0,
    'FABING': 0,
    'FABINSKI': 0,
    'FABINY': 0,
    'FABIO': 0,
    'FABIOLA': 1,
    'FABIS': 0,
    'FABISH': 0,
    'FABISIAK': 0,
    'FABISZAK': 0,
    'FABISZEWSKI': 0,
    'FABLE': 0,
    'FABOR': 0,
    'FABOZZI': 0,
    'FABRE': 0,
    'FABREGA': 0,
    'FABREGAS': 0,
    'FABRI': 0,
    'FABRICANT': 0,
    'FABRICANTE': 0,
    'FABRICATORE': 0,
    'FABRICIUS': 0,
    'FABRICK': 0,
    'FABRIKANT': 0,
    'FABRIS': 0,
    'FABRIZI': 0,
    'FABRIZIO': 0,
    'FABRIZIUS': 0,
    'FABRO': 0,
    'FABROS': 0,
    'FABRY': 0,
    'FABULA': 0,
    'FABUS': 0,
    'FABY': 0,
    'FABYAN': 0,
    'FACCENDA': 0,
    'FACCHIANO': 0,
    'FACCHINE': 0,
    'FACCHINI': 0,
    'FACCIANI': 0,
    'FACCINI': 0,
    'FACCIO': 0,
    'FACCIOLA': 0,
    'FACCIOLO': 0,
    'FACCONE': 0,
    'FACE': 0,
    'FACEMIRE': 0,
    'FACEMYER': 0,
    'FACEN': 0,
    'FACENDA': 0,
    'FACER': 0,
    'FACEY': 0,
    'FACH': 0,
    'FACHA': 0,
    'FACHINI': 0,
    'FACIANA': 0,
    'FACIANE': 0,
    'FACINELLI': 0,
    'FACIO': 0,
    'FACKELMAN': 0,
    'FACKLAM': 0,
    'FACKLER': 0,
    'FACKRELL': 0,
    'FACTEAU': 0,
    'FACTO': 0,
    'FACTOR': 0,
    'FACTORA': 0,
    'FACUNDO': 0,
    'FADA': 0,
    'FADAL': 0,
    'FADALE': 0,
    'FADDEN': 0,
    'FADDIS': 0,
    'FADDOUL': 0,
    'FADE': 0,
    'FADEL': 0,
    'FADELEY': 0,
    'FADELL': 0,
    'FADELY': 0,
    'FADEM': 0,
    'FADEN': 0,
    'FADENRECHT': 0,
    'FADER': 0,
    'FADGEN': 0,
    'FADIL': 0,
    'FADLER': 0,
    'FADLEY': 0,
    'FADNESS': 0,
    'FADUL': 0,
    'FAE': 1,
    'FAEHNRICH': 0,
    'FAEHR': 0,
    'FAELLA': 0,
    'FAENZA': 0,
    'FAERBER': 0,
    'FAERMAN': 0,
    'FAES': 0,
    'FAESSLER': 0,
    'FAETH': 0,
    'FAFALIOS': 0,
    'FAFARA': 0,
    'FAFARD': 0,
    'FAFINSKI': 0,
    'FAFORD': 0,
    'FAGA': 0,
    'FAGALA': 0,
    'FAGALY': 0,
    'FAGAN': 0,
    'FAGANS': 0,
    'FAGARAGAN': 0,
    'FAGE': 0,
    'FAGEL': 0,
    'FAGEN': 0,
    'FAGER': 0,
    'FAGERBERG': 0,
    'FAGERLAND': 0,
    'FAGERLIE': 0,
    'FAGERLUND': 0,
    'FAGERMAN': 0,
    'FAGERNESS': 0,
    'FAGERQUIST': 0,
    'FAGERSTROM': 0,
    'FAGG': 0,
    'FAGGARD': 0,
    'FAGGART': 0,
    'FAGGETT': 0,
    'FAGGIANO': 0,
    'FAGGINS': 0,
    'FAGIN': 0,
    'FAGLER': 0,
    'FAGLEY': 0,
    'FAGLIE': 0,
    'FAGLIER': 0,
    'FAGNAN': 0,
    'FAGNANI': 0,
    'FAGNANO': 0,
    'FAGNANT': 0,
    'FAGNER': 0,
    'FAGO': 0,
    'FAGONE': 0,
    'FAGOT': 0,
    'FAGRE': 0,
    'FAGUE': 0,
    'FAGUNDES': 0,
    'FAGUNDO': 0,
    'FAH': 0,
    'FAHEEM': 0,
    'FAHERTY': 0,
    'FAHEY': 0,
    'FAHIE': 0,
    'FAHIM': 0,
    'FAHL': 0,
    'FAHLAND': 0,
    'FAHLE': 0,
    'FAHLEN': 0,
    'FAHLER': 0,
    'FAHLGREN': 0,
    'FAHLING': 0,
    'FAHLMAN': 0,
    'FAHLSING': 0,
    'FAHLSTROM': 0,
    'FAHMI': 0,
    'FAHMIE': 0,
    'FAHMY': 0,
    'FAHN': 0,
    'FAHNBULLEH': 0,
    'FAHNER': 0,
    'FAHNESTOCK': 0,
    'FAHNING': 0,
    'FAHR': 0,
    'FAHRBACH': 0,
    'FAHRENBACH': 0,
    'FAHRENBRUCH': 0,
    'FAHRENDORF': 0,
    'FAHRENHOLTZ': 0,
    'FAHRENHOLZ': 0,
    'FAHRENKAMP': 0,
    'FAHRENKOPF': 0,
    'FAHRENKROG': 0,
    'FAHRENKRUG': 0,
    'FAHRENTHOLD': 0,
    'FAHRER': 0,
    'FAHRIG': 0,
    'FAHRINGER': 0,
    'FAHRION': 0,
    'FAHRLANDER': 0,
    'FAHRMAN': 0,
    'FAHRNER': 0,
    'FAHRNEY': 0,
    'FAHRNI': 0,
    'FAHS': 0,
    'FAHY': 0,
    'FAIA': 0,
    'FAICON': 0,
    'FAIDLEY': 0,
    'FAIELLA': 0,
    'FAIELLO': 0,
    'FAIETA': 0,
    'FAIG': 0,
    'FAIGEN': 0,
    'FAIGLE': 0,
    'FAIL': 0,
    'FAILE': 0,
    'FAILES': 0,
    'FAILEY': 0,
    'FAILING': 0,
    'FAILLA': 0,
    'FAILLACE': 0,
    'FAILLE': 0,
    'FAILOR': 0,
    'FAILS': 0,
    'FAIMAN': 0,
    'FAIMON': 0,
    'FAIN': 0,
    'FAINA': 0,
    'FAINE': 0,
    'FAINES': 0,
    'FAINT': 0,
    'FAINTER': 0,
    'FAIOLA': 0,
    'FAIR': 0,
    'FAIRALL': 0,
    'FAIRBAIRN': 0,
    'FAIRBANK': 0,
    'FAIRBANKS': 0,
    'FAIRBOURN': 0,
    'FAIRBROTHER': 0,
    'FAIRBURN': 0,
    'FAIRCHILD': 0,
    'FAIRCHILDS': 0,
    'FAIRCLOTH': 0,
    'FAIRCLOUGH': 0,
    'FAIRE': 0,
    'FAIRES': 0,
    'FAIREY': 0,
    'FAIRFAX': 0,
    'FAIRFIELD': 0,
    'FAIRGRIEVE': 0,
    'FAIRHEAD': 0,
    'FAIRHOLM': 0,
    'FAIRHURST': 0,
    'FAIRLAMB': 0,
    'FAIRLEE': 0,
    'FAIRLEIGH': 0,
    'FAIRLESS': 0,
    'FAIRLEY': 0,
    'FAIRLIE': 0,
    'FAIRLY': 0,
    'FAIRMAN': 0,
    'FAIRRIS': 0,
    'FAIRROW': 0,
    'FAIRWEATHER': 0,
    'FAIRWELL': 0,
    'FAIRY': 1,
    'FAIS': 0,
    'FAISAL': 0,
    'FAISON': 0,
    'FAIST': 0,
    'FAIT': 0,
    'FAITH': 0.9543285616905249,
    'FAITHFUL': 0,
    'FAIVRE': 0,
    'FAIX': 0,
    'FAIZ': 0,
    'FAIZI': 0,
    'FAJARDO': 0,
    'FAJEN': 0,
    'FAJKUS': 0,
    'FAKE': 0,
    'FAKER': 0,
    'FAKES': 0,
    'FAKHOURI': 0,
    'FAKHOURY': 0,
    'FAKHREDDINE': 0,
    'FAKHRI': 0,
    'FAKIH': 0,
    'FAKLER': 0,
    'FAKO': 0,
    'FAKTOR': 0,
    'FAKTOROVICH': 0,
    'FALA': 0,
    'FALABELLA': 0,
    'FALAGAN': 0,
    'FALANA': 0,
    'FALANGA': 0,
    'FALARDEAU': 0,
    'FALASCA': 0,
    'FALASCO': 0,
    'FALAT': 0,
    'FALATKO': 0,
    'FALATO': 0,
    'FALB': 0,
    'FALBE': 0,
    'FALBER': 0,
    'FALBERG': 0,
    'FALBO': 0,
    'FALBY': 0,
    'FALCAO': 0,
    'FALCE': 0,
    'FALCETTA': 0,
    'FALCETTI': 0,
    'FALCH': 0,
    'FALCI': 0,
    'FALCIANI': 0,
    'FALCIANO': 0,
    'FALCIGNO': 0,
    'FALCINELLI': 0,
    'FALCIONE': 0,
    'FALCIONI': 0,
    'FALCK': 0,
    'FALCO': 0,
    'FALCON': 0,
    'FALCONBURG': 0,
    'FALCONBURY': 0,
    'FALCONE': 0,
    'FALCONER': 0,
    'FALCONES': 0,
    'FALCONI': 0,
    'FALCONIERI': 0,
    'FALCONIO': 0,
    'FALDE': 0,
    'FALDET': 0,
    'FALDETTA': 0,
    'FALDUTO': 0,
    'FALDYN': 0,
    'FALE': 0,
    'FALEN': 0,
    'FALER': 0,
    'FALERO': 0,
    'FALES': 0,
    'FALETTI': 0,
    'FALETTO': 0,
    'FALEY': 0,
    'FALGIANO': 0,
    'FALGOUST': 0,
    'FALGOUT': 0,
    'FALIK': 0,
    'FALIN': 0,
    'FALING': 0,
    'FALIS': 0,
    'FALISE': 0,
    'FALISH': 0,
    'FALIVENE': 0,
    'FALK': 0,
    'FALKE': 0,
    'FALKENBACH': 0,
    'FALKENBERG': 0,
    'FALKENBERRY': 0,
    'FALKENBURG': 0,
    'FALKENHAGEN': 0,
    'FALKENRATH': 0,
    'FALKENSTEIN': 0,
    'FALKENSTERN': 0,
    'FALKENSTINE': 0,
    'FALKENTHAL': 0,
    'FALKER': 0,
    'FALKIEWICZ': 0,
    'FALKIN': 0,
    'FALKINBURG': 0,
    'FALKMAN': 0,
    'FALKNER': 0,
    'FALKNOR': 0,
    'FALKOFF': 0,
    'FALKOWITZ': 0,
    'FALKOWSKI': 0,
    'FALKS': 0,
    'FALL': 0,
    'FALLA': 0,
    'FALLACARO': 0,
    'FALLAH': 0,
    'FALLAHI': 0,
    'FALLAS': 0,
    'FALLAT': 0,
    'FALLAVOLLITA': 0,
    'FALLAW': 0,
    'FALLECKER': 0,
    'FALLEN': 0,
    'FALLER': 0,
    'FALLERT': 0,
    'FALLETTA': 0,
    'FALLETTI': 0,
    'FALLEY': 0,
    'FALLGREN': 0,
    'FALLICA': 0,
    'FALLICK': 0,
    'FALLICO': 0,
    'FALLIN': 0,
    'FALLING': 0,
    'FALLIS': 0,
    'FALLO': 0,
    'FALLON': 0.3886010362694301,
    'FALLONE': 0,
    'FALLOON': 0,
    'FALLOT': 0,
    'FALLOW': 0,
    'FALLOWFIELD': 0,
    'FALLOWS': 0,
    'FALLS': 0,
    'FALLSTROM': 0,
    'FALLUCCA': 0,
    'FALLWELL': 0,
    'FALO': 0,
    'FALONE': 0,
    'FALOON': 0,
    'FALOR': 0,
    'FALOTICO': 0,
    'FALQUEZ': 0,
    'FALS': 0,
    'FALSETTA': 0,
    'FALSETTI': 0,
    'FALSETTO': 0,
    'FALSEY': 0,
    'FALSO': 0,
    'FALSON': 0,
    'FALSONE': 0,
    'FALSTAD': 0,
    'FALT': 0,
    'FALTA': 0,
    'FALTAS': 0,
    'FALTER': 0,
    'FALTERMAN': 0,
    'FALTERSACK': 0,
    'FALTESEK': 0,
    'FALTIN': 0,
    'FALTISCO': 0,
    'FALTUS': 0,
    'FALTYS': 0,
    'FALTZ': 0,
    'FALU': 0,
    'FALVEY': 0,
    'FALVO': 0,
    'FALWELL': 0,
    'FALZARANO': 0,
    'FALZON': 0,
    'FALZONE': 0,
    'FAM': 0,
    'FAMA': 0,
    'FAMBLE': 0,
    'FAMBRINI': 0,
    'FAMBRO': 0,
    'FAMBROUGH': 0,
    'FAMEREE': 0,
    'FAMIANO': 0,
    'FAMIGHETTI': 0,
    'FAMIGLIETTI': 0,
    'FAMILIA': 0,
    'FAMOLARE': 0,
    'FAMOSO': 0,
    'FAMOUS': 0,
    'FAMULARD': 0,
    'FAMULARE': 0,
    'FAMULARI': 0,
    'FAMULARO': 0,
    'FAN': 0,
    'FANA': 0,
    'FANALE': 0,
    'FANARA': 0,
    'FANARO': 0,
    'FANCE': 0,
    'FANCETT': 0,
    'FANCHER': 0,
    'FANCIULLO': 0,
    'FANCY': 0,
    'FAND': 0,
    'FANDAL': 0,
    'FANDEL': 0,
    'FANDINO': 0,
    'FANDL': 0,
    'FANDREY': 0,
    'FANDRICH': 0,
    'FANE': 0,
    'FANELLA': 0,
    'FANELLE': 0,
    'FANELLI': 0,
    'FANELLO': 0,
    'FANENE': 0,
    'FANEUF': 0,
    'FANFAN': 0,
    'FANG': 0,
    'FANGER': 0,
    'FANGMAN': 0,
    'FANGMANN': 0,
    'FANGMEIER': 0,
    'FANGMEYER': 0,
    'FANGUE': 0,
    'FANGUY': 0,
    'FANI': 0,
    'FANIA': 0,
    'FANIEL': 0,
    'FANION': 0,
    'FANIZZA': 0,
    'FANIZZI': 0,
    'FANJOY': 0,
    'FANJUL': 0,
    'FANK': 0,
    'FANKELL': 0,
    'FANKHANEL': 0,
    'FANKHAUSER': 0,
    'FANKHOUSER': 0,
    'FANN': 0,
    'FANNAN': 0,
    'FANNER': 0,
    'FANNEY': 0,
    'FANNIE': 1,
    'FANNIN': 0,
    'FANNING': 0,
    'FANNON': 0,
    'FANNY': 0.9933774834437086,
    'FANO': 0,
    'FANOUS': 0,
    'FANSHER': 0,
    'FANSHIER': 0,
    'FANSLAU': 0,
    'FANSLER': 0,
    'FANSLOW': 0,
    'FANSON': 0,
    'FANT': 0,
    'FANTA': 0,
    'FANTACONE': 0,
    'FANTASIA': 0,
    'FANTAUZZI': 0,
    'FANTAUZZO': 0,
    'FANTE': 0,
    'FANTER': 0,
    'FANTETTI': 0,
    'FANTI': 0,
    'FANTIN': 0,
    'FANTINI': 0,
    'FANTINO': 0,
    'FANTO': 0,
    'FANTOM': 0,
    'FANTON': 0,
    'FANTONE': 0,
    'FANTONI': 0,
    'FANTOZZI': 0,
    'FANTROY': 0,
    'FANTRY': 0,
    'FANTUZZO': 0,
    'FANTZ': 0,
    'FANUCCHI': 0,
    'FANUCCI': 0,
    'FANUS': 0,
    'FANZ': 0,
    'FANZO': 0,
    'FAORO': 0,
    'FAOUR': 0,
    'FAPPIANO': 0,
    'FAR': 0,
    'FARA': 0,
    'FARABAUGH': 0,
    'FARABEE': 0,
    'FARACA': 0,
    'FARACE': 0,
    'FARACH': 0,
    'FARACI': 0,
    'FARACO': 0,
    'FARADAY': 0,
    'FARAG': 0,
    'FARAGALLI': 0,
    'FARAGE': 0,
    'FARAGHER': 0,
    'FARAGO': 0,
    'FARAH': 0.5780346820809249,
    'FARAHANI': 0,
    'FARAHMAND': 0,
    'FARAJ': 0,
    'FARAJI': 0,
    'FARALDO': 0,
    'FARANDA': 0,
    'FARANO': 0,
    'FARAON': 0,
    'FARAONE': 0,
    'FARAR': 0,
    'FARB': 0,
    'FARBER': 0,
    'FARBMAN': 0,
    'FARBO': 0,
    'FARBSTEIN': 0,
    'FARCAS': 0,
    'FARCHIONE': 0,
    'FARCIERT': 0,
    'FARD': 0,
    'FARDELLA': 0,
    'FARDEN': 0,
    'FARDY': 0,
    'FARE': 0,
    'FAREED': 0,
    'FAREK': 0,
    'FAREL': 0,
    'FARELL': 0,
    'FARELLA': 0,
    'FAREN': 0,
    'FARENGA': 0,
    'FARERI': 0,
    'FARES': 0,
    'FARESE': 0,
    'FARETRA': 0,
    'FARETTA': 0,
    'FAREWELL': 0,
    'FAREY': 0,
    'FARFAN': 0,
    'FARGAS': 0,
    'FARGASON': 0,
    'FARGEN': 0,
    'FARGHER': 0,
    'FARGIS': 0,
    'FARGNOLI': 0,
    'FARGO': 0,
    'FARHA': 0,
    'FARHAD': 0,
    'FARHADI': 0,
    'FARHAN': 0,
    'FARHANG': 0,
    'FARHAT': 0,
    'FARHI': 0,
    'FARHOOD': 0,
    'FARHOUD': 0,
    'FARIA': 0,
    'FARIAS': 0,
    'FARICY': 0,
    'FARID': 0,
    'FARIDA': 0,
    'FARIDI': 0,
    'FARIELLO': 0,
    'FARIES': 0,
    'FARIN': 0,
    'FARINA': 0,
    'FARINACCI': 0,
    'FARINAS': 0,
    'FARINE': 0,
    'FARINEAU': 0,
    'FARINELLA': 0,
    'FARINELLI': 0,
    'FARINHA': 0,
    'FARINHOLT': 0,
    'FARINO': 0,
    'FARINOLA': 0,
    'FARIS': 0,
    'FARISH': 0,
    'FARISON': 0,
    'FARISS': 0,
    'FARIST': 0,
    'FARIVAR': 0,
    'FARK': 0,
    'FARKAS': 0,
    'FARKASH': 0,
    'FARKUS': 0,
    'FARLAND': 0,
    'FARLEE': 0,
    'FARLEIGH': 0,
    'FARLER': 0,
    'FARLESS': 0,
    'FARLEY': 0,
    'FARLIN': 0,
    'FARLING': 0,
    'FARLOUGH': 0,
    'FARLOW': 0,
    'FARM': 0,
    'FARMAKIS': 0,
    'FARMAN': 0,
    'FARMAR': 0,
    'FARMEN': 0,
    'FARMER': 0,
    'FARMERIE': 0,
    'FARMS': 0,
    'FARMWALD': 0,
    'FARNAM': 0,
    'FARNAN': 0,
    'FARNELL': 0,
    'FARNEN': 0,
    'FARNER': 0,
    'FARNES': 0,
    'FARNESE': 0,
    'FARNESS': 0,
    'FARNETH': 0,
    'FARNETI': 0,
    'FARNEY': 0,
    'FARNHAM': 0,
    'FARNI': 0,
    'FARNIOK': 0,
    'FARNSLEY': 0,
    'FARNSTROM': 0,
    'FARNSWORTH': 0,
    'FARNUM': 0,
    'FARNWORTH': 0,
    'FARO': 0,
    'FAROL': 0,
    'FARON': 0,
    'FARONE': 0,
    'FARONI': 0,
    'FAROOQ': 0,
    'FAROOQI': 0,
    'FAROOQUI': 0,
    'FARQUE': 0,
    'FARQUER': 0,
    'FARQUHAR': 0,
    'FARQUHARSON': 0,
    'FARR': 0,
    'FARRA': 0,
    'FARRAGHER': 0,
    'FARRAGUT': 0,
    'FARRAH': 0.936768149882904,
    'FARRAHER': 0,
    'FARRAJ': 0,
    'FARRAKHAN': 0,
    'FARRALES': 0,
    'FARRALL': 0,
    'FARRAN': 0,
    'FARRANCE': 0,
    'FARRAND': 0,
    'FARRANT': 0,
    'FARRAR': 0,
    'FARRARA': 0,
    'FARRARE': 0,
    'FARRAY': 0,
    'FARREII': 0,
    'FARREL': 0,
    'FARRELL': 0,
    'FARRELLY': 0,
    'FARREN': 0,
    'FARRENKOPF': 0,
    'FARRENS': 0,
    'FARRER': 0,
    'FARRES': 0,
    'FARREY': 0,
    'FARRIA': 0,
    'FARRIER': 0,
    'FARRIES': 0,
    'FARRILL': 0,
    'FARRIMOND': 0,
    'FARRIN': 0,
    'FARRINGER': 0,
    'FARRINGTON': 0,
    'FARRIOR': 0,
    'FARRIS': 0,
    'FARRISH': 0,
    'FARRISS': 0,
    'FARRO': 0,
    'FARRON': 0,
    'FARROW': 0,
    'FARRUGGIA': 0,
    'FARRUGGIO': 0,
    'FARRUGIA': 0,
    'FARRUKH': 0,
    'FARRY': 0,
    'FARSON': 0,
    'FARST': 0,
    'FARSTAD': 0,
    'FARSTER': 0,
    'FARTHING': 0,
    'FARUQI': 0,
    'FARUQUE': 0,
    'FARUQUI': 0,
    'FARVE': 0,
    'FARVER': 0,
    'FARVOUR': 0,
    'FARWELL': 0,
    'FARWICK': 0,
    'FARWIG': 0,
    'FARY': 0,
    'FARZAD': 0,
    'FARZAN': 0,
    'FARZANEH': 0,
    'FASANELLA': 0,
    'FASANELLO': 0,
    'FASANO': 0,
    'FASBENDER': 0,
    'FASBINDER': 0,
    'FASCE': 0,
    'FASCHING': 0,
    'FASCHINGBAUER': 0,
    'FASCI': 0,
    'FASCIA': 0,
    'FASCIANA': 0,
    'FASCIANO': 0,
    'FASCIO': 0,
    'FASE': 0,
    'FASEL': 0,
    'FASENMYER': 0,
    'FASH': 0,
    'FASHAW': 0,
    'FASHBAUGH': 0,
    'FASHEH': 0,
    'FASHING': 0,
    'FASHINGBAUER': 0,
    'FASICK': 0,
    'FASIG': 0,
    'FASKE': 0,
    'FASMAN': 0,
    'FASNACHT': 0,
    'FASO': 0,
    'FASOLA': 0,
    'FASOLD': 0,
    'FASOLI': 0,
    'FASOLINO': 0,
    'FASOLO': 0,
    'FASON': 0,
    'FASONE': 0,
    'FASS': 0,
    'FASSBENDER': 0,
    'FASSBINDER': 0,
    'FASSE': 0,
    'FASSEL': 0,
    'FASSERO': 0,
    'FASSETT': 0,
    'FASSINGER': 0,
    'FASSINO': 0,
    'FASSIO': 0,
    'FASSL': 0,
    'FASSLER': 0,
    'FASSNACHT': 0,
    'FASSO': 0,
    'FASSOLD': 0,
    'FAST': 0,
    'FASTENAU': 0,
    'FASTER': 0,
    'FASTHORSE': 0,
    'FASTIGGI': 0,
    'FASTNACHT': 0,
    'FASULA': 0,
    'FASULLO': 0,
    'FASULO': 0,
    'FASY': 0,
    'FATA': 0,
    'FATAL': 0,
    'FATE': 0,
    'FATEMI': 0,
    'FATER': 0,
    'FATH': 0,
    'FATHAUER': 0,
    'FATHEREE': 0,
    'FATHERREE': 0,
    'FATHI': 0,
    'FATHY': 0,
    'FATICA': 0,
    'FATIGATE': 0,
    'FATIGATI': 0,
    'FATIMA': 0.9615384615384616,
    'FATIMAH': 1,
    'FATINO': 0,
    'FATJO': 0,
    'FATKIN': 0,
    'FATLA': 0,
    'FATLAND': 0,
    'FATO': 0,
    'FATONE': 0,
    'FATOVIC': 0,
    'FATT': 0,
    'FATTA': 0,
    'FATTAH': 0,
    'FATTAHI': 0,
    'FATTAL': 0,
    'FATTIG': 0,
    'FATTORE': 0,
    'FATTORI': 0,
    'FATTORUSSO': 0,
    'FATU': 0,
    'FATULA': 0,
    'FATUR': 0,
    'FATZ': 0,
    'FATZINGER': 0,
    'FAU': 0,
    'FAUBEL': 0,
    'FAUBER': 0,
    'FAUBERT': 0,
    'FAUBION': 0,
    'FAUBLE': 0,
    'FAUBUS': 0,
    'FAUCETT': 0,
    'FAUCETTE': 0,
    'FAUCHEAUX': 0,
    'FAUCHER': 0,
    'FAUCHEUX': 0,
    'FAUCI': 0,
    'FAUDE': 0,
    'FAUDOA': 0,
    'FAUDREE': 0,
    'FAUE': 0,
    'FAUERBACH': 0,
    'FAUGHN': 0,
    'FAUGHNAN': 0,
    'FAUGHT': 0,
    'FAUGNO': 0,
    'FAUL': 0,
    'FAULCON': 0,
    'FAULCONER': 0,
    'FAULDER': 0,
    'FAULDS': 0,
    'FAULHABER': 0,
    'FAULISE': 0,
    'FAULISI': 0,
    'FAULK': 0,
    'FAULKENBERG': 0,
    'FAULKENBERRY': 0,
    'FAULKENBURG': 0,
    'FAULKENBURY': 0,
    'FAULKER': 0,
    'FAULKINGHAM': 0,
    'FAULKNER': 0,
    'FAULKNOR': 0,
    'FAULKS': 0,
    'FAULL': 0,
    'FAULLS': 0,
    'FAULMAN': 0,
    'FAULS': 0,
    'FAULSTICH': 0,
    'FAULSTICK': 0,
    'FAULTERSACK': 0,
    'FAUMUINA': 0,
    'FAUNCE': 0,
    'FAUNT': 0,
    'FAUNTLEROY': 0,
    'FAUNTROY': 0,
    'FAUPEL': 0,
    'FAUR': 0,
    'FAURA': 0,
    'FAURE': 0,
    'FAURIA': 0,
    'FAURIE': 0,
    'FAUROT': 0,
    'FAUROTE': 0,
    'FAUS': 0,
    'FAUSAK': 0,
    'FAUSCH': 0,
    'FAUSEL': 0,
    'FAUSER': 0,
    'FAUSETT': 0,
    'FAUSEY': 0,
    'FAUSKE': 0,
    'FAUSNAUGH': 0,
    'FAUSNAUGHT': 0,
    'FAUSNIGHT': 0,
    'FAUSONE': 0,
    'FAUSS': 0,
    'FAUSSET': 0,
    'FAUSSETT': 0,
    'FAUST': 0,
    'FAUSTIN': 0,
    'FAUSTINA': 0.9803921568627452,
    'FAUSTINE': 0,
    'FAUSTINI': 0,
    'FAUSTINO': 0.9345794392523364,
    'FAUSTMAN': 0,
    'FAUSTO': 0.8869179600886917,
    'FAUSZ': 0,
    'FAUT': 0,
    'FAUTEUX': 0,
    'FAUTH': 0,
    'FAUTSCH': 0,
    'FAUTT': 0,
    'FAUVER': 0,
    'FAUX': 0,
    'FAVA': 0,
    'FAVALE': 0,
    'FAVALORA': 0,
    'FAVALORO': 0,
    'FAVARA': 0,
    'FAVARO': 0,
    'FAVATA': 0,
    'FAVAZZA': 0,
    'FAVAZZO': 0,
    'FAVELA': 0,
    'FAVELL': 0,
    'FAVELLA': 0,
    'FAVER': 0,
    'FAVERO': 0,
    'FAVERTY': 0,
    'FAVIA': 0,
    'FAVIAN': 0,
    'FAVIER': 0,
    'FAVILA': 0,
    'FAVILLA': 0,
    'FAVILLE': 0,
    'FAVINGER': 0,
    'FAVIOLA': 1,
    'FAVIS': 0,
    'FAVOR': 0,
    'FAVORITE': 0,
    'FAVORITO': 0,
    'FAVORS': 0,
    'FAVOUR': 0,
    'FAVRE': 0,
    'FAVREAU': 0,
    'FAVRET': 0,
    'FAVRO': 0,
    'FAVUZZA': 0,
    'FAVUZZI': 0,
    'FAW': 0,
    'FAWAZ': 0,
    'FAWBER': 0,
    'FAWBUSH': 0,
    'FAWCETT': 0,
    'FAWELL': 0,
    'FAWKES': 0,
    'FAWKS': 0,
    'FAWLEY': 0,
    'FAWN': 1,
    'FAWNS': 0,
    'FAWSON': 0,
    'FAWVER': 0,
    'FAWZI': 0,
    'FAWZY': 0,
    'FAX': 0,
    'FAXON': 0,
    'FAY': 0.7906626506024097,
    'FAYA': 0,
    'FAYAD': 0,
    'FAYALL': 0,
    'FAYARD': 0,
    'FAYE': 0.9911141490088858,
    'FAYED': 0,
    'FAYER': 0,
    'FAYERMAN': 0,
    'FAYERWEATHER': 0,
    'FAYETTE': 0,
    'FAYLE': 0,
    'FAYLOR': 0,
    'FAYMAN': 0,
    'FAYNE': 0,
    'FAYNSHTEYN': 0,
    'FAYSON': 0,
    'FAYYAZ': 0,
    'FAZ': 0,
    'FAZAL': 0,
    'FAZEKAS': 0,
    'FAZEL': 0,
    'FAZELI': 0,
    'FAZENBAKER': 0,
    'FAZENDIN': 0,
    'FAZI': 0,
    'FAZIO': 0,
    'FAZIOLI': 0,
    'FAZLI': 0,
    'FAZLIC': 0,
    'FAZZARI': 0,
    'FAZZI': 0,
    'FAZZINA': 0,
    'FAZZINI': 0,
    'FAZZINO': 0,
    'FAZZIO': 0,
    'FAZZOLARI': 0,
    'FAZZONE': 0,
    'FE': 0.9803921568627452,
    'FEA': 0,
    'FEACHER': 0,
    'FEAD': 0,
    'FEAGA': 0,
    'FEAGAN': 0,
    'FEAGANES': 0,
    'FEAGANS': 0,
    'FEAGIN': 0,
    'FEAGINS': 0,
    'FEAGLE': 0,
    'FEAGLER': 0,
    'FEAGLES': 0,
    'FEAGLEY': 0,
    'FEAKER': 0,
    'FEAKES': 0,
    'FEAL': 0,
    'FEALEY': 0,
    'FEALY': 0,
    'FEAMAN': 0,
    'FEAMSTER': 0,
    'FEAR': 0,
    'FEARDAY': 0,
    'FEARER': 0,
    'FEARING': 0,
    'FEARN': 0,
    'FEARNEYHOUGH': 0,
    'FEARNLEY': 0,
    'FEARNOW': 0,
    'FEARNS': 0,
    'FEARNSIDE': 0,
    'FEARON': 0,
    'FEARRINGTON': 0,
    'FEARS': 0,
    'FEARSON': 0,
    'FEARY': 0,
    'FEASBY': 0,
    'FEASEL': 0,
    'FEASER': 0,
    'FEAST': 0,
    'FEASTER': 0,
    'FEATHER': 0,
    'FEATHERINGILL': 0,
    'FEATHERLY': 0,
    'FEATHERMAN': 0,
    'FEATHERS': 0,
    'FEATHERSON': 0,
    'FEATHERSTON': 0,
    'FEATHERSTONE': 0,
    'FEAUTO': 0,
    'FEAVEL': 0,
    'FEAVER': 0,
    'FEAZEL': 0,
    'FEAZELL': 0,
    'FEBBO': 0,
    'FEBBRARO': 0,
    'FEBLES': 0,
    'FEBO': 0,
    'FEBRE': 0,
    'FEBRES': 0,
    'FEBUS': 0,
    'FECCI': 0,
    'FECH': 0,
    'FECHER': 0,
    'FECHNER': 0,
    'FECHO': 0,
    'FECHT': 0,
    'FECHTEL': 0,
    'FECHTER': 0,
    'FECHTNER': 0,
    'FECIK': 0,
    'FECK': 0,
    'FECKE': 0,
    'FECKER': 0,
    'FECKO': 0,
    'FECTEAU': 0,
    'FECZKO': 0,
    'FED': 0,
    'FEDA': 0,
    'FEDAK': 0,
    'FEDD': 0,
    'FEDDE': 0,
    'FEDDELER': 0,
    'FEDDEMA': 0,
    'FEDDER': 0,
    'FEDDERLY': 0,
    'FEDDERN': 0,
    'FEDDERS': 0,
    'FEDDERSEN': 0,
    'FEDDERSON': 0,
    'FEDE': 0,
    'FEDEL': 0,
    'FEDELE': 0,
    'FEDELI': 0,
    'FEDELL': 0,
    'FEDER': 0,
    'FEDERER': 0,
    'FEDERICI': 0,
    'FEDERICK': 0,
    'FEDERICO': 0.8326394671107411,
    'FEDERIGHI': 0,
    'FEDERLE': 0,
    'FEDERLINE': 0,
    'FEDERMAN': 0,
    'FEDEROFF': 0,
    'FEDEROWICZ': 0,
    'FEDERSPIEL': 0,
    'FEDERWITZ': 0,
    'FEDEWA': 0,
    'FEDICK': 0,
    'FEDIE': 0,
    'FEDIGAN': 0,
    'FEDISON': 0,
    'FEDJE': 0,
    'FEDLER': 0,
    'FEDO': 0,
    'FEDOCK': 0,
    'FEDON': 0,
    'FEDOR': 0,
    'FEDORA': 0,
    'FEDORCHAK': 0,
    'FEDORCHUK': 0,
    'FEDORCZYK': 0,
    'FEDORE': 0,
    'FEDOREK': 0,
    'FEDORENKO': 0,
    'FEDORKA': 0,
    'FEDORKO': 0,
    'FEDOROFF': 0,
    'FEDOROV': 0,
    'FEDOROVA': 0,
    'FEDOROVICH': 0,
    'FEDOROWICZ': 0,
    'FEDORUK': 0,
    'FEDRICK': 0,
    'FEDRIZZI': 0,
    'FEDRO': 0,
    'FEDUCCIA': 0,
    'FEDUN': 0,
    'FEDUS': 0,
    'FEDYK': 0,
    'FEDYNA': 0,
    'FEE': 0,
    'FEEBACK': 0,
    'FEECE': 0,
    'FEEHAN': 0,
    'FEEHERY': 0,
    'FEEHLEY': 0,
    'FEEHRER': 0,
    'FEEK': 0,
    'FEEKEN': 0,
    'FEEKES': 0,
    'FEELER': 0,
    'FEELEY': 0,
    'FEELY': 0,
    'FEEMAN': 0,
    'FEEMSTER': 0,
    'FEEN': 0,
    'FEENAN': 0,
    'FEENER': 0,
    'FEENEY': 0,
    'FEENSTRA': 0,
    'FEENY': 0,
    'FEERER': 0,
    'FEERICK': 0,
    'FEERO': 0,
    'FEERY': 0,
    'FEES': 0,
    'FEESE': 0,
    'FEESER': 0,
    'FEEST': 0,
    'FEETHAM': 0,
    'FEEZEL': 0,
    'FEEZELL': 0,
    'FEEZLE': 0,
    'FEEZOR': 0,
    'FEFEE': 0,
    'FEFER': 0,
    'FEFFER': 0,
    'FEFFERMAN': 0,
    'FEGAN': 0,
    'FEGANS': 0,
    'FEGEL': 0,
    'FEGELY': 0,
    'FEGER': 0,
    'FEGERT': 0,
    'FEGETT': 0,
    'FEGGANS': 0,
    'FEGGINS': 0,
    'FEGHALI': 0,
    'FEGLER': 0,
    'FEGLEY': 0,
    'FEGUSON': 0,
    'FEHER': 0,
    'FEHL': 0,
    'FEHLBERG': 0,
    'FEHLEN': 0,
    'FEHLER': 0,
    'FEHLHABER': 0,
    'FEHLING': 0,
    'FEHLINGER': 0,
    'FEHLMAN': 0,
    'FEHN': 0,
    'FEHNEL': 0,
    'FEHNER': 0,
    'FEHR': 0,
    'FEHRENBACH': 0,
    'FEHRENBACHER': 0,
    'FEHRER': 0,
    'FEHRIBACH': 0,
    'FEHRING': 0,
    'FEHRINGER': 0,
    'FEHRLE': 0,
    'FEHRMAN': 0,
    'FEHRMANN': 0,
    'FEHRS': 0,
    'FEHSENFELD': 0,
    'FEI': 0,
    'FEIA': 0,
    'FEIBEL': 0,
    'FEIBELMAN': 0,
    'FEIBUSCH': 0,
    'FEICHT': 0,
    'FEICHTER': 0,
    'FEICHTINGER': 0,
    'FEICHTNER': 0,
    'FEICK': 0,
    'FEICKERT': 0,
    'FEID': 0,
    'FEIDEN': 0,
    'FEIDER': 0,
    'FEIDLER': 0,
    'FEIDT': 0,
    'FEIERABEND': 0,
    'FEIERSTEIN': 0,
    'FEIERTAG': 0,
    'FEIFER': 0,
    'FEIG': 0,
    'FEIGE': 0,
    'FEIGEL': 0,
    'FEIGELSON': 0,
    'FEIGEN': 0,
    'FEIGENBAUM': 0,
    'FEIGER': 0,
    'FEIGERT': 0,
    'FEIGHAN': 0,
    'FEIGHERY': 0,
    'FEIGHNER': 0,
    'FEIGHT': 0,
    'FEIGHTNER': 0,
    'FEIGIN': 0,
    'FEIGL': 0,
    'FEIGLEY': 0,
    'FEIGUM': 0,
    'FEIJO': 0,
    'FEIJOO': 0,
    'FEIK': 0,
    'FEIKEMA': 0,
    'FEIKERT': 0,
    'FEIL': 0,
    'FEILD': 0,
    'FEILEN': 0,
    'FEILER': 0,
    'FEILING': 0,
    'FEILMEIER': 0,
    'FEIMER': 0,
    'FEIMSTER': 0,
    'FEIN': 0,
    'FEINAUER': 0,
    'FEINBERG': 0,
    'FEINBLATT': 0,
    'FEIND': 0,
    'FEINDEL': 0,
    'FEINDT': 0,
    'FEINE': 0,
    'FEINER': 0,
    'FEINERMAN': 0,
    'FEINGOLD': 0,
    'FEINMAN': 0,
    'FEINS': 0,
    'FEINSILVER': 0,
    'FEINSOD': 0,
    'FEINSTEIN': 0,
    'FEINTUCH': 0,
    'FEIOCK': 0,
    'FEIPEL': 0,
    'FEIR': 0,
    'FEIRER': 0,
    'FEIRICK': 0,
    'FEIRING': 0,
    'FEIS': 0,
    'FEISE': 0,
    'FEISEL': 0,
    'FEISER': 0,
    'FEISS': 0,
    'FEIST': 0,
    'FEISTEL': 0,
    'FEISTER': 0,
    'FEISTHAMEL': 0,
    'FEISTNER': 0,
    'FEIT': 0,
    'FEITEN': 0,
    'FEITH': 0,
    'FEITL': 0,
    'FEITO': 0,
    'FEITSHANS': 0,
    'FEITZ': 0,
    'FEIX': 0,
    'FEJEDELEM': 0,
    'FEJERAN': 0,
    'FEJES': 0,
    'FEJFAR': 0,
    'FEJZIC': 0,
    'FEKETE': 0,
    'FEKETY': 0,
    'FELA': 0,
    'FELAN': 0,
    'FELAND': 0,
    'FELARCA': 0,
    'FELBER': 0,
    'FELBERBAUM': 0,
    'FELBERG': 0,
    'FELBINGER': 0,
    'FELCH': 0,
    'FELCHER': 0,
    'FELCHLE': 0,
    'FELCIANO': 0,
    'FELCYN': 0,
    'FELCZAK': 0,
    'FELD': 0,
    'FELDBAUER': 0,
    'FELDBAUM': 0,
    'FELDBERG': 0,
    'FELDBUSCH': 0,
    'FELDBUSH': 0,
    'FELDE': 0,
    'FELDEN': 0,
    'FELDER': 0,
    'FELDERHOFF': 0,
    'FELDERMAN': 0,
    'FELDEWERTH': 0,
    'FELDHACKER': 0,
    'FELDHAKE': 0,
    'FELDHAUS': 0,
    'FELDHAUSEN': 0,
    'FELDHEIM': 0,
    'FELDHUSEN': 0,
    'FELDICK': 0,
    'FELDKAMP': 0,
    'FELDMAN': 0,
    'FELDMANN': 0,
    'FELDMEIER': 0,
    'FELDMEYER': 0,
    'FELDNER': 0,
    'FELDON': 0,
    'FELDPAUSCH': 0,
    'FELDSCHER': 0,
    'FELDSHER': 0,
    'FELDSTEIN': 0,
    'FELDT': 0,
    'FELECIA': 1,
    'FELEGY': 0,
    'FELEKE': 0,
    'FELGAR': 0,
    'FELGENHAUER': 0,
    'FELGER': 0,
    'FELICA': 1,
    'FELICANO': 0,
    'FELICE': 0.7246376811594203,
    'FELICETTA': 0,
    'FELICETTI': 0,
    'FELICI': 0,
    'FELICIA': 0.9983849654969902,
    'FELICIANO': 0,
    'FELICIDAD': 1,
    'FELICIEN': 0,
    'FELICIO': 0,
    'FELICIONE': 0,
    'FELICITA': 1,
    'FELICITAS': 0.9852216748768473,
    'FELIO': 0,
    'FELION': 0,
    'FELIPA': 1,
    'FELIPE': 0.9560800717060054,
    'FELIS': 0,
    'FELISA': 1,
    'FELISHA': 1,
    'FELIU': 0,
    'FELIX': 0.8317797217840242,
    'FELIZ': 0,
    'FELIZARDO': 0,
    'FELKE': 0,
    'FELKEL': 0,
    'FELKER': 0,
    'FELKEY': 0,
    'FELKINS': 0,
    'FELKNER': 0,
    'FELKNOR': 0,
    'FELKS': 0,
    'FELL': 0,
    'FELLA': 0,
    'FELLABAUM': 0,
    'FELLAND': 0,
    'FELLBAUM': 0,
    'FELLENBAUM': 0,
    'FELLENSTEIN': 0,
    'FELLENZ': 0,
    'FELLER': 0,
    'FELLERMAN': 0,
    'FELLERS': 0,
    'FELLHAUER': 0,
    'FELLHOELTER': 0,
    'FELLI': 0,
    'FELLIN': 0,
    'FELLING': 0,
    'FELLINGER': 0,
    'FELLINI': 0,
    'FELLION': 0,
    'FELLMAN': 0,
    'FELLMETH': 0,
    'FELLNER': 0,
    'FELLO': 0,
    'FELLON': 0,
    'FELLOW': 0,
    'FELLOWES': 0,
    'FELLOWS': 0,
    'FELLRATH': 0,
    'FELLS': 0,
    'FELLURE': 0,
    'FELLWOCK': 0,
    'FELLY': 0,
    'FELMAN': 0,
    'FELMET': 0,
    'FELMEY': 0,
    'FELMLEE': 0,
    'FELNER': 0,
    'FELOCK': 0,
    'FELPS': 0,
    'FELS': 0,
    'FELSCH': 0,
    'FELSEN': 0,
    'FELSENTHAL': 0,
    'FELSER': 0,
    'FELSHAW': 0,
    'FELSHER': 0,
    'FELSING': 0,
    'FELSINGER': 0,
    'FELSKE': 0,
    'FELSKI': 0,
    'FELSMAN': 0,
    'FELSON': 0,
    'FELSTEAD': 0,
    'FELSTED': 0,
    'FELT': 0,
    'FELTCH': 0,
    'FELTEN': 0,
    'FELTENBERGER': 0,
    'FELTER': 0,
    'FELTES': 0,
    'FELTHAM': 0,
    'FELTIS': 0,
    'FELTMAN': 0,
    'FELTMANN': 0,
    'FELTMEYER': 0,
    'FELTNER': 0,
    'FELTON': 0.4069175991861648,
    'FELTROP': 0,
    'FELTS': 0,
    'FELTUS': 0,
    'FELTY': 0,
    'FELTZ': 0,
    'FELUX': 0,
    'FELVER': 0,
    'FELZ': 0,
    'FELZER': 0,
    'FELZIEN': 0,
    'FEMAL': 0,
    'FEMAT': 0,
    'FEMATT': 0,
    'FEMIA': 0,
    'FEMIANO': 0,
    'FEMINELLA': 0,
    'FEMINO': 0,
    'FEMLING': 0,
    'FEMMER': 0,
    'FEMRITE': 0,
    'FENA': 0,
    'FENBERT': 0,
    'FENBY': 0,
    'FENCEROY': 0,
    'FENCHAK': 0,
    'FENCHEL': 0,
    'FENCIK': 0,
    'FENCIL': 0,
    'FENCL': 0,
    'FEND': 0,
    'FENDALL': 0,
    'FENDEL': 0,
    'FENDELL': 0,
    'FENDER': 0,
    'FENDERSON': 0,
    'FENDLER': 0,
    'FENDLEY': 0,
    'FENDRICH': 0,
    'FENDRICK': 0,
    'FENDT': 0,
    'FENECH': 0,
    'FENECK': 0,
    'FENEIS': 0,
    'FENELL': 0,
    'FENELON': 0,
    'FENELUS': 0,
    'FENERTY': 0,
    'FENG': 0,
    'FENGEL': 0,
    'FENGER': 0,
    'FENGLER': 0,
    'FENHAUS': 0,
    'FENICHEL': 0,
    'FENICK': 0,
    'FENICLE': 0,
    'FENIELLO': 0,
    'FENIK': 0,
    'FENILI': 0,
    'FENIMORE': 0,
    'FENISON': 0,
    'FENIX': 0,
    'FENKER': 0,
    'FENLASON': 0,
    'FENLEY': 0,
    'FENLON': 0,
    'FENN': 0,
    'FENNE': 0,
    'FENNEL': 0,
    'FENNELL': 0,
    'FENNELLY': 0,
    'FENNEMA': 0,
    'FENNEMAN': 0,
    'FENNEN': 0,
    'FENNER': 0,
    'FENNERN': 0,
    'FENNESSEY': 0,
    'FENNESSY': 0,
    'FENNEWALD': 0,
    'FENNEY': 0,
    'FENNICK': 0,
    'FENNIE': 0,
    'FENNIG': 0,
    'FENNIMORE': 0,
    'FENNING': 0,
    'FENNINGER': 0,
    'FENNO': 0,
    'FENO': 0,
    'FENOFF': 0,
    'FENOGLIO': 0,
    'FENRICH': 0,
    'FENRICK': 0,
    'FENSKE': 0,
    'FENSLER': 0,
    'FENSOM': 0,
    'FENSTEMAKER': 0,
    'FENSTER': 0,
    'FENSTERER': 0,
    'FENSTERMACHER': 0,
    'FENSTERMAKER': 0,
    'FENT': 0,
    'FENTER': 0,
    'FENTERS': 0,
    'FENTIMAN': 0,
    'FENTON': 0,
    'FENTRESS': 0,
    'FENTY': 0,
    'FENWICK': 0,
    'FENYES': 0,
    'FENZEL': 0,
    'FENZL': 0,
    'FEO': 0,
    'FEOLA': 0,
    'FEOLE': 0,
    'FEQUIERE': 0,
    'FER': 0,
    'FERA': 0,
    'FERACO': 0,
    'FERAN': 0,
    'FERANDEZ': 0,
    'FERATOVIC': 0,
    'FERBER': 0,
    'FERBERT': 0,
    'FERBRACHE': 0,
    'FERBY': 0,
    'FERCH': 0,
    'FERCHAK': 0,
    'FERCHAU': 0,
    'FERCHAUD': 0,
    'FERCHO': 0,
    'FERDA': 0,
    'FERDEN': 0,
    'FERDER': 0,
    'FERDERER': 0,
    'FERDIG': 0,
    'FERDIN': 0,
    'FERDINAND': 0.8939974457215837,
    'FERDINANDI': 0,
    'FERDINANDO': 0,
    'FERDINANDSEN': 0,
    'FERDMAN': 0,
    'FERDON': 0,
    'FERDOUS': 0,
    'FEREBEE': 0,
    'FEREDAY': 0,
    'FEREGRINO': 0,
    'FEREIRA': 0,
    'FEREK': 0,
    'FERELL': 0,
    'FEREN': 0,
    'FERENC': 0,
    'FERENCAK': 0,
    'FERENCE': 0,
    'FERENCHAK': 0,
    'FERENCIK': 0,
    'FERENCY': 0,
    'FERENCZ': 0,
    'FERENCZI': 0,
    'FERENCZY': 0,
    'FERENS': 0,
    'FERENTINOS': 0,
    'FERENTZ': 0,
    'FERENZ': 0,
    'FERER': 0,
    'FERET': 0,
    'FEREZ': 0,
    'FERG': 0,
    'FERGASON': 0,
    'FERGE': 0,
    'FERGEN': 0,
    'FERGER': 0,
    'FERGERSON': 0,
    'FERGESON': 0,
    'FERGISON': 0,
    'FERGSON': 0,
    'FERGUESON': 0,
    'FERGURSON': 0,
    'FERGUS': 0,
    'FERGUSEN': 0,
    'FERGUSON': 0,
    'FERGUSSON': 0,
    'FERIA': 0,
    'FERINA': 0,
    'FERINGA': 0,
    'FERINGTON': 0,
    'FERINO': 0,
    'FERIOLI': 0,
    'FERIOZZI': 0,
    'FERIS': 0,
    'FERKEL': 0,
    'FERKO': 0,
    'FERKOVICH': 0,
    'FERLA': 0,
    'FERLAND': 0,
    'FERLAUTO': 0,
    'FERLAZZO': 0,
    'FERLEY': 0,
    'FERLIN': 0,
    'FERLISE': 0,
    'FERLISI': 0,
    'FERLITA': 0,
    'FERLITO': 0,
    'FERLO': 0,
    'FERM': 0,
    'FERMAINT': 0,
    'FERMAN': 0,
    'FERMANIAN': 0,
    'FERMANICH': 0,
    'FERMIN': 0.8025682182985555,
    'FERMINA': 1,
    'FERMO': 0,
    'FERN': 0.961153384060873,
    'FERNAAYS': 0,
    'FERNADES': 0,
    'FERNALD': 0,
    'FERNAN': 0,
    'FERNAND': 0,
    'FERNANDA': 1,
    'FERNANDE': 1,
    'FERNANDER': 0,
    'FERNANDERS': 0,
    'FERNANDES': 0,
    'FERNANDEZ': 0,
    'FERNANDINI': 0,
    'FERNANDO': 0.9761225409220604,
    'FERNATT': 0,
    'FERNAU': 0,
    'FERNBACH': 0,
    'FERNE': 1,
    'FERNEAU': 0,
    'FERNEDING': 0,
    'FERNELIUS': 0,
    'FERNER': 0,
    'FERNETTE': 0,
    'FERNEY': 0,
    'FERNHOLZ': 0,
    'FERNICOLA': 0,
    'FERNIE': 0,
    'FERNIZA': 0,
    'FERNLEY': 0,
    'FERNLUND': 0,
    'FERNOW': 0,
    'FERNQUIST': 0,
    'FERNS': 0,
    'FERNSLER': 0,
    'FERNSTROM': 0,
    'FERO': 0,
    'FEROCE': 0,
    'FEROLA': 0,
    'FEROLI': 0,
    'FEROLITO': 0,
    'FERON': 0,
    'FERONE': 0,
    'FERONTI': 0,
    'FEROZ': 0,
    'FERR': 0,
    'FERRA': 0,
    'FERRACANE': 0,
    'FERRACCI': 0,
    'FERRAGAMO': 0,
    'FERRAINA': 0,
    'FERRAIOLI': 0,
    'FERRAIOLO': 0,
    'FERRAIUOLO': 0,
    'FERRAL': 0,
    'FERRALES': 0,
    'FERRALL': 0,
    'FERRAN': 0,
    'FERRANCE': 0,
    'FERRAND': 0,
    'FERRANDINO': 0,
    'FERRANDO': 0,
    'FERRANS': 0,
    'FERRANT': 0,
    'FERRANTE': 0,
    'FERRANTELLI': 0,
    'FERRANTI': 0,
    'FERRANTINO': 0,
    'FERRANTO': 0,
    'FERRAO': 0,
    'FERRAR': 0,
    'FERRARA': 0,
    'FERRARACCIO': 0,
    'FERRARE': 0,
    'FERRARELLI': 0,
    'FERRARESE': 0,
    'FERRARI': 0,
    'FERRARINI': 0,
    'FERRARIO': 0,
    'FERRARIS': 0,
    'FERRARO': 0,
    'FERRAS': 0,
    'FERRATO': 0,
    'FERRAZ': 0,
    'FERRAZZA': 0,
    'FERRAZZANO': 0,
    'FERRAZZI': 0,
    'FERRE': 0,
    'FERREBEE': 0,
    'FERREE': 0,
    'FERREIRA': 0,
    'FERREIRAS': 0,
    'FERREIRO': 0,
    'FERREL': 0,
    'FERRELL': 0,
    'FERRELLI': 0,
    'FERREN': 0,
    'FERRENCE': 0,
    'FERRENTINO': 0,
    'FERRER': 0,
    'FERRERA': 0,
    'FERRERAS': 0,
    'FERRERI': 0,
    'FERRERIA': 0,
    'FERRERO': 0,
    'FERRES': 0,
    'FERRESE': 0,
    'FERRET': 0,
    'FERRETIZ': 0,
    'FERRETT': 0,
    'FERRETTE': 0,
    'FERRETTI': 0,
    'FERREY': 0,
    'FERREYRA': 0,
    'FERRI': 0,
    'FERRIAN': 0,
    'FERRICK': 0,
    'FERRIE': 0,
    'FERRIELL': 0,
    'FERRIER': 0,
    'FERRIERA': 0,
    'FERRIERE': 0,
    'FERRIERI': 0,
    'FERRIERO': 0,
    'FERRIES': 0,
    'FERRIGAN': 0,
    'FERRIGNO': 0,
    'FERRIL': 0,
    'FERRILL': 0,
    'FERRIMAN': 0,
    'FERRIN': 0,
    'FERRING': 0,
    'FERRINGER': 0,
    'FERRINGTON': 0,
    'FERRINI': 0,
    'FERRINO': 0,
    'FERRIO': 0,
    'FERRIOLA': 0,
    'FERRIOLO': 0,
    'FERRIS': 0,
    'FERRISE': 0,
    'FERRISS': 0,
    'FERRITER': 0,
    'FERRITO': 0,
    'FERRITTO': 0,
    'FERRO': 0,
    'FERRON': 0,
    'FERRONE': 0,
    'FERRONI': 0,
    'FERRUCCI': 0,
    'FERRUCCIO': 0,
    'FERRUFINO': 0,
    'FERRUGGIA': 0,
    'FERRUGIA': 0,
    'FERRULLI': 0,
    'FERRUSCA': 0,
    'FERRUSQUIA': 0,
    'FERRUZZA': 0,
    'FERRUZZI': 0,
    'FERRY': 0,
    'FERRYMAN': 0,
    'FERSCH': 0,
    'FERSCHKE': 0,
    'FERSNER': 0,
    'FERSON': 0,
    'FERST': 0,
    'FERSTER': 0,
    'FERSTL': 0,
    'FERSTLER': 0,
    'FERTAL': 0,
    'FERTEL': 0,
    'FERTIG': 0,
    'FERTIL': 0,
    'FERTITTA': 0,
    'FERULLO': 0,
    'FERUS': 0,
    'FERWERDA': 0,
    'FERY': 0,
    'FERZOCO': 0,
    'FESENMAIER': 0,
    'FESER': 0,
    'FESI': 0,
    'FESKE': 0,
    'FESKO': 0,
    'FESLER': 0,
    'FESMIRE': 0,
    'FESPERMAN': 0,
    'FESS': 0,
    'FESSEL': 0,
    'FESSENDEN': 0,
    'FESSER': 0,
    'FESSLER': 0,
    'FEST': 0,
    'FESTA': 0,
    'FESTE': 0,
    'FESTEJO': 0,
    'FESTER': 0,
    'FESTERMAN': 0,
    'FESTO': 0,
    'FETCH': 0,
    'FETCHER': 0,
    'FETCHKO': 0,
    'FETCHO': 0,
    'FETE': 0,
    'FETH': 0,
    'FETHER': 0,
    'FETHERMAN': 0,
    'FETHEROLF': 0,
    'FETHERSTON': 0,
    'FETKO': 0,
    'FETNER': 0,
    'FETROW': 0,
    'FETSCH': 0,
    'FETSCHER': 0,
    'FETSKO': 0,
    'FETT': 0,
    'FETTA': 0,
    'FETTE': 0,
    'FETTER': 0,
    'FETTERER': 0,
    'FETTERHOFF': 0,
    'FETTERLEY': 0,
    'FETTERLY': 0,
    'FETTERMAN': 0,
    'FETTEROLF': 0,
    'FETTERS': 0,
    'FETTES': 0,
    'FETTIG': 0,
    'FETTING': 0,
    'FETTINGER': 0,
    'FETTIS': 0,
    'FETTKETHER': 0,
    'FETTY': 0,
    'FETZ': 0,
    'FETZER': 0,
    'FETZKO': 0,
    'FETZNER': 0,
    'FEUCHT': 0,
    'FEUCHTER': 0,
    'FEUDALE': 0,
    'FEUDNER': 0,
    'FEUDO': 0,
    'FEUER': 0,
    'FEUERBACH': 0,
    'FEUERBACHER': 0,
    'FEUERBORN': 0,
    'FEUERHELM': 0,
    'FEUERMAN': 0,
    'FEUERSTEIN': 0,
    'FEUGE': 0,
    'FEULING': 0,
    'FEULNER': 0,
    'FEUQUAY': 0,
    'FEURER': 0,
    'FEURT': 0,
    'FEURTADO': 0,
    'FEURY': 0,
    'FEUSNER': 0,
    'FEUSS': 0,
    'FEUSTEL': 0,
    'FEUTZ': 0,
    'FEUZ': 0,
    'FEVER': 0,
    'FEVOLA': 0,
    'FEVOLD': 0,
    'FEVRIER': 0,
    'FEW': 0,
    'FEWEL': 0,
    'FEWELL': 0,
    'FEWER': 0,
    'FEWINS': 0,
    'FEWKES': 0,
    'FEWLESS': 0,
    'FEWOX': 0,
    'FEWSTER': 0,
    'FEX': 0,
    'FEY': 0,
    'FEYDER': 0,
    'FEYE': 0,
    'FEYEN': 0,
    'FEYERABEND': 0,
    'FEYEREISEN': 0,
    'FEYERHERM': 0,
    'FEYES': 0,
    'FEYGIN': 0,
    'FEYH': 0,
    'FEYLER': 0,
    'FEYRER': 0,
    'FEYS': 0,
    'FEZZA': 0,
    'FFRENCH': 0,
    'FIACCO': 0,
    'FIACK': 0,
    'FIAL': 0,
    'FIALA': 0,
    'FIALHO': 0,
    'FIALKO': 0,
    'FIALKOFF': 0,
    'FIALKOWSKI': 0,
    'FIALLO': 0,
    'FIALLOS': 0,
    'FIAMENGO': 0,
    'FIAMINGO': 0,
    'FIANAGAN': 0,
    'FIANDACA': 0,
    'FIANDER': 0,
    'FIANO': 0,
    'FIASCHETTI': 0,
    'FIASCO': 0,
    'FIASCONARO': 0,
    'FIATO': 0,
    'FIBER': 0,
    'FIBICH': 0,
    'FIC': 0,
    'FICALORA': 0,
    'FICARA': 0,
    'FICARELLA': 0,
    'FICARO': 0,
    'FICARRA': 0,
    'FICARRO': 0,
    'FICARROTTA': 0,
    'FICCA': 0,
    'FICCHI': 0,
    'FICCO': 0,
    'FICEK': 0,
    'FICENEC': 0,
    'FICHER': 0,
    'FICHERA': 0,
    'FICHMAN': 0,
    'FICHT': 0,
    'FICHTEL': 0,
    'FICHTER': 0,
    'FICHTHORN': 0,
    'FICHTNER': 0,
    'FICI': 0,
    'FICK': 0,
    'FICKAS': 0,
    'FICKBOHM': 0,
    'FICKE': 0,
    'FICKEL': 0,
    'FICKEN': 0,
    'FICKENSCHER': 0,
    'FICKER': 0,
    'FICKERT': 0,
    'FICKES': 0,
    'FICKETT': 0,
    'FICKEY': 0,
    'FICKINGER': 0,
    'FICKLE': 0,
    'FICKLEN': 0,
    'FICKLER': 0,
    'FICKLIN': 0,
    'FICKLING': 0,
    'FICKS': 0,
    'FICO': 0,
    'FICOCELLI': 0,
    'FICOCIELLO': 0,
    'FICORILLI': 0,
    'FIDA': 0,
    'FIDALGO': 0,
    'FIDANZA': 0,
    'FIDDELKE': 0,
    'FIDDES': 0,
    'FIDDLER': 0,
    'FIDEL': 0.9811937857726902,
    'FIDELA': 1,
    'FIDELER': 0,
    'FIDELIA': 1,
    'FIDELL': 0,
    'FIDELMAN': 0,
    'FIDLER': 0,
    'FIDONE': 0,
    'FIDRYCH': 0,
    'FIDUCCIA': 0,
    'FIDUCIA': 0,
    'FIE': 0,
    'FIEBELKORN': 0,
    'FIEBER': 0,
    'FIEBIG': 0,
    'FIEBIGER': 0,
    'FIECHTER': 0,
    'FIECHTNER': 0,
    'FIECK': 0,
    'FIECKE': 0,
    'FIEDERLEIN': 0,
    'FIEDLER': 0,
    'FIEDOR': 0,
    'FIEDOROWICZ': 0,
    'FIEF': 0,
    'FIEGE': 0,
    'FIEGEL': 0,
    'FIEGEN': 0,
    'FIEGENER': 0,
    'FIEGER': 0,
    'FIEGL': 0,
    'FIEGLE': 0,
    'FIEHLER': 0,
    'FIEL': 0,
    'FIELD': 0,
    'FIELDEN': 0,
    'FIELDER': 0,
    'FIELDERS': 0,
    'FIELDHOUSE': 0,
    'FIELDING': 0,
    'FIELDMAN': 0,
    'FIELDS': 0,
    'FIELDSON': 0,
    'FIELER': 0,
    'FIELITZ': 0,
    'FIELY': 0,
    'FIEMING': 0,
    'FIEN': 0,
    'FIENBERG': 0,
    'FIENE': 0,
    'FIENGO': 0,
    'FIER': 0,
    'FIERCE': 0,
    'FIERKE': 0,
    'FIERLE': 0,
    'FIERMAN': 0,
    'FIERMONTE': 0,
    'FIERO': 0,
    'FIERRO': 0,
    'FIERROS': 0,
    'FIERS': 0,
    'FIERST': 0,
    'FIERSTEIN': 0,
    'FIERY': 0,
    'FIES': 0,
    'FIESEL': 0,
    'FIESELER': 0,
    'FIESELMAN': 0,
    'FIESER': 0,
    'FIESLER': 0,
    'FIESS': 0,
    'FIEST': 0,
    'FIESTA': 0,
    'FIESTER': 0,
    'FIET': 0,
    'FIETSAM': 0,
    'FIETZ': 0,
    'FIEVET': 0,
    'FIEWEGER': 0,
    'FIEWELLING': 0,
    'FIFAREK': 0,
    'FIFE': 0,
    'FIFELSKI': 0,
    'FIFER': 0,
    'FIFFE': 0,
    'FIFFICK': 0,
    'FIFFIE': 0,
    'FIFIELD': 0,
    'FIFITA': 0,
    'FIG': 0,
    'FIGARD': 0,
    'FIGARI': 0,
    'FIGARO': 0,
    'FIGAROA': 0,
    'FIGAROLA': 0,
    'FIGART': 0,
    'FIGAS': 0,
    'FIGEL': 0,
    'FIGEROA': 0,
    'FIGERT': 0,
    'FIGG': 0,
    'FIGGATT': 0,
    'FIGGE': 0,
    'FIGGERS': 0,
    'FIGGINS': 0,
    'FIGGS': 0,
    'FIGHT': 0,
    'FIGHTMASTER': 0,
    'FIGHTS': 0,
    'FIGI': 0,
    'FIGIEL': 0,
    'FIGLAR': 0,
    'FIGLER': 0,
    'FIGLEY': 0,
    'FIGLIA': 0,
    'FIGLIOLA': 0,
    'FIGLIOLI': 0,
    'FIGLIOMENI': 0,
    'FIGLIOZZI': 0,
    'FIGLIUOLO': 0,
    'FIGNAR': 0,
    'FIGONE': 0,
    'FIGONI': 0,
    'FIGUEIRA': 0,
    'FIGUEIRAS': 0,
    'FIGUEIREDO': 0,
    'FIGUERA': 0,
    'FIGUERAS': 0,
    'FIGUERDA': 0,
    'FIGUEREDO': 0,
    'FIGUEREO': 0,
    'FIGUERO': 0,
    'FIGUEROA': 0,
    'FIGUERON': 0,
    'FIGULY': 0,
    'FIGURA': 0,
    'FIGURACION': 0,
    'FIGURELLI': 0,
    'FIGURES': 0,
    'FIGURSKI': 0,
    'FIGY': 0,
    'FIJAL': 0,
    'FIJALKOWSKI': 0,
    'FIKAC': 0,
    'FIKAR': 0,
    'FIKE': 0,
    'FIKES': 0,
    'FIKSE': 0,
    'FIL': 0,
    'FILA': 0,
    'FILAK': 0,
    'FILAN': 0,
    'FILANOWSKI': 0,
    'FILAR': 0,
    'FILARDI': 0,
    'FILARDO': 0,
    'FILARSKI': 0,
    'FILAS': 0,
    'FILATOV': 0,
    'FILBECK': 0,
    'FILBERT': 0,
    'FILBEY': 0,
    'FILBIN': 0,
    'FILBRANDT': 0,
    'FILBRUN': 0,
    'FILBURN': 0,
    'FILBY': 0,
    'FILCHAK': 0,
    'FILDES': 0,
    'FILE': 0,
    'FILECCIA': 0,
    'FILEK': 0,
    'FILER': 0,
    'FILES': 0,
    'FILETO': 0,
    'FILETTI': 0,
    'FILGO': 0,
    'FILHO': 0,
    'FILI': 0,
    'FILIAGGI': 0,
    'FILIATRAULT': 0,
    'FILIATREAU': 0,
    'FILIAULT': 0,
    'FILIBECK': 0,
    'FILIBERTI': 0,
    'FILIBERTO': 0.9803921568627452,
    'FILICE': 0,
    'FILICETTI': 0,
    'FILICKY': 0,
    'FILIMON': 0,
    'FILINGERI': 0,
    'FILIO': 0,
    'FILION': 0,
    'FILIP': 0,
    'FILIPCZAK': 0,
    'FILIPE': 0,
    'FILIPEK': 0,
    'FILIPELLI': 0,
    'FILIPI': 0,
    'FILIPIAK': 0,
    'FILIPKOWSKI': 0,
    'FILIPOVIC': 0,
    'FILIPOVICH': 0,
    'FILIPOWICZ': 0,
    'FILIPOWSKI': 0,
    'FILIPP': 0,
    'FILIPPELLI': 0,
    'FILIPPELLO': 0,
    'FILIPPI': 0,
    'FILIPPINI': 0,
    'FILIPPO': 0,
    'FILIPPONE': 0,
    'FILIPPONI': 0,
    'FILIPS': 0,
    'FILIPSKI': 0,
    'FILIUS': 0,
    'FILKIN': 0,
    'FILKINS': 0,
    'FILKO': 0,
    'FILL': 0,
    'FILLA': 0,
    'FILLAR': 0,
    'FILLBACH': 0,
    'FILLEBROWN': 0,
    'FILLENWARTH': 0,
    'FILLER': 0,
    'FILLERS': 0,
    'FILLERUP': 0,
    'FILLEY': 0,
    'FILLHART': 0,
    'FILLING': 0,
    'FILLINGAME': 0,
    'FILLINGER': 0,
    'FILLINGHAM': 0,
    'FILLINGIM': 0,
    'FILLIO': 0,
    'FILLION': 0,
    'FILLIP': 0,
    'FILLIPI': 0,
    'FILLIS': 0,
    'FILLIUS': 0,
    'FILLMAN': 0,
    'FILLMER': 0,
    'FILLMON': 0,
    'FILLMORE': 0,
    'FILLNER': 0,
    'FILLO': 0,
    'FILLON': 0,
    'FILLOON': 0,
    'FILLPOT': 0,
    'FILLYAW': 0,
    'FILMER': 0,
    'FILMORE': 0,
    'FILO': 0,
    'FILOMENA': 0.9900990099009901,
    'FILOMENO': 0,
    'FILORAMO': 0,
    'FILOSA': 0,
    'FILOSI': 0,
    'FILOSO': 0,
    'FILOTEO': 0,
    'FILPI': 0,
    'FILPO': 0,
    'FILS': 0,
    'FILSAIME': 0,
    'FILSINGER': 0,
    'FILSON': 0,
    'FILTEAU': 0,
    'FILTER': 0,
    'FILTZ': 0,
    'FILUT': 0,
    'FILYAW': 0,
    'FILZ': 0,
    'FILZEN': 0,
    'FIMBEL': 0,
    'FIMBRES': 0,
    'FIMBREZ': 0,
    'FIMIANI': 0,
    'FIMPLE': 0,
    'FIN': 0,
    'FINA': 0,
    'FINALDI': 0,
    'FINALE': 0,
    'FINAMORE': 0,
    'FINAN': 0,
    'FINATERI': 0,
    'FINAU': 0,
    'FINAZZO': 0,
    'FINBERG': 0,
    'FINCANNON': 0,
    'FINCEL': 0,
    'FINCH': 0,
    'FINCHAM': 0,
    'FINCHER': 0,
    'FINCHUM': 0,
    'FINCK': 0,
    'FINCKBONE': 0,
    'FINCKE': 0,
    'FINCO': 0,
    'FINDEIS': 0,
    'FINDEISEN': 0,
    'FINDELL': 0,
    'FINDER': 0,
    'FINDERS': 0,
    'FINDLATER': 0,
    'FINDLAY': 0,
    'FINDLEY': 0,
    'FINDLING': 0,
    'FINE': 0,
    'FINEBERG': 0,
    'FINEDAY': 0,
    'FINEFROCK': 0,
    'FINEGAN': 0,
    'FINEGOLD': 0,
    'FINEHOUT': 0,
    'FINELL': 0,
    'FINELLI': 0,
    'FINELLO': 0,
    'FINELY': 0,
    'FINEMAN': 0,
    'FINEOUT': 0,
    'FINER': 0,
    'FINERAN': 0,
    'FINERSON': 0,
    'FINERTY': 0,
    'FINES': 0,
    'FINESTONE': 0,
    'FINEWOOD': 0,
    'FINFROCK': 0,
    'FING': 0,
    'FINGADO': 0,
    'FINGAL': 0,
    'FINGAR': 0,
    'FINGER': 0,
    'FINGERHUT': 0,
    'FINGERLE': 0,
    'FINGERMAN': 0,
    'FINGERS': 0,
    'FINGERSON': 0,
    'FINGLAND': 0,
    'FINI': 0,
    'FINICAL': 0,
    'FINIGAN': 0,
    'FINISTER': 0,
    'FINIZIO': 0,
    'FINK': 0,
    'FINKBEINER': 0,
    'FINKBINER': 0,
    'FINKBONNER': 0,
    'FINKE': 0,
    'FINKEL': 0,
    'FINKELBERG': 0,
    'FINKELMAN': 0,
    'FINKELSHTEYN': 0,
    'FINKELSON': 0,
    'FINKELSTEIN': 0,
    'FINKEN': 0,
    'FINKENBINDER': 0,
    'FINKENBINER': 0,
    'FINKES': 0,
    'FINKEY': 0,
    'FINKLE': 0,
    'FINKLEA': 0,
    'FINKLER': 0,
    'FINKLESTEIN': 0,
    'FINKLEY': 0,
    'FINKS': 0,
    'FINLAN': 0,
    'FINLAND': 0,
    'FINLAW': 0,
    'FINLAY': 0,
    'FINLAYSON': 0,
    'FINLEN': 0,
    'FINLEY': 0,
    'FINLINSON': 0,
    'FINLON': 0,
    'FINMAN': 0,
    'FINN': 0,
    'FINNAN': 0,
    'FINNE': 0,
    'FINNEFROCK': 0,
    'FINNEGAN': 0,
    'FINNEL': 0,
    'FINNELL': 0,
    'FINNEMAN': 0,
    'FINNEMORE': 0,
    'FINNEN': 0,
    'FINNER': 0,
    'FINNERAN': 0,
    'FINNERN': 0,
    'FINNERTY': 0,
    'FINNESSY': 0,
    'FINNESTAD': 0,
    'FINNEY': 0,
    'FINNEYFROCK': 0,
    'FINNICUM': 0,
    'FINNIE': 0,
    'FINNIGAN': 0,
    'FINNIMORE': 0,
    'FINNIN': 0,
    'FINNING': 0,
    'FINNO': 0,
    'FINO': 0,
    'FINOCCHI': 0,
    'FINOCCHIARO': 0,
    'FINOCCHIO': 0,
    'FINOCHIO': 0,
    'FINOTTI': 0,
    'FINS': 0,
    'FINSEL': 0,
    'FINSETH': 0,
    'FINSON': 0,
    'FINSTAD': 0,
    'FINSTER': 0,
    'FINSTON': 0,
    'FINSTROM': 0,
    'FINT': 0,
    'FINTA': 0,
    'FINTAK': 0,
    'FINTEL': 0,
    'FINTO': 0,
    'FINTON': 0,
    'FINUCAN': 0,
    'FINUCANE': 0,
    'FINUF': 0,
    'FINWALL': 0,
    'FINZEL': 0,
    'FINZER': 0,
    'FIOCCA': 0,
    'FIOCCHI': 0,
    'FIOCCO': 0,
    'FIOL': 0,
    'FIOLA': 0,
    'FIOLEK': 0,
    'FIONA': 1,
    'FIONDA': 0,
    'FIONDELLA': 0,
    'FIORAMONTI': 0,
    'FIORANI': 0,
    'FIORAVANTI': 0,
    'FIORE': 0,
    'FIORELLA': 0,
    'FIORELLI': 0,
    'FIORELLO': 0,
    'FIORENTINI': 0,
    'FIORENTINO': 0,
    'FIORENZA': 0,
    'FIORENZO': 0,
    'FIORES': 0,
    'FIORETTI': 0,
    'FIORETTO': 0,
    'FIORI': 0,
    'FIORICA': 0,
    'FIORILLA': 0,
    'FIORILLI': 0,
    'FIORILLO': 0,
    'FIORINA': 0,
    'FIORINI': 0,
    'FIORINO': 0,
    'FIORIO': 0,
    'FIORITA': 0,
    'FIORITO': 0,
    'FIORITTO': 0,
    'FIORUCCI': 0,
    'FIPPINGER': 0,
    'FIPPS': 0,
    'FIQUEROA': 0,
    'FIRA': 0,
    'FIRARI': 0,
    'FIRCH': 0,
    'FIRCHAU': 0,
    'FIRE': 0,
    'FIREBAUGH': 0,
    'FIREHAMMER': 0,
    'FIREK': 0,
    'FIREMAN': 0,
    'FIRENZE': 0,
    'FIRER': 0,
    'FIRES': 0,
    'FIRESTEIN': 0,
    'FIRESTINE': 0,
    'FIRESTONE': 0,
    'FIRETTO': 0,
    'FIREY': 0,
    'FIRICANO': 0,
    'FIRKINS': 0,
    'FIRKUS': 0,
    'FIRL': 0,
    'FIRLE': 0,
    'FIRLEY': 0,
    'FIRLIK': 0,
    'FIRLIT': 0,
    'FIRM': 0,
    'FIRMAN': 0,
    'FIRMANI': 0,
    'FIRME': 0,
    'FIRMENT': 0,
    'FIRMIN': 0,
    'FIRMSTONE': 0,
    'FIRNHABER': 0,
    'FIRNSTAHL': 0,
    'FIROR': 0,
    'FIRPO': 0,
    'FIRSCHING': 0,
    'FIRST': 0,
    'FIRSTENBERG': 0,
    'FIRSTER': 0,
    'FIRTH': 0,
    'FISACKERLY': 0,
    'FISBECK': 0,
    'FISCAL': 0,
    'FISCELLA': 0,
    'FISCH': 0,
    'FISCHBACH': 0,
    'FISCHBECK': 0,
    'FISCHBEIN': 0,
    'FISCHEL': 0,
    'FISCHELS': 0,
    'FISCHENICH': 0,
    'FISCHER': 0,
    'FISCHESSER': 0,
    'FISCHETTE': 0,
    'FISCHETTI': 0,
    'FISCHETTO': 0,
    'FISCHL': 0,
    'FISCHLER': 0,
    'FISCHMAN': 0,
    'FISCHMANN': 0,
    'FISCINA': 0,
    'FISCO': 0,
    'FISCUS': 0,
    'FISER': 0,
    'FISET': 0,
    'FISETTE': 0,
    'FISH': 0,
    'FISHBACH': 0,
    'FISHBACK': 0,
    'FISHBAUGH': 0,
    'FISHBECK': 0,
    'FISHBEIN': 0,
    'FISHBURN': 0,
    'FISHBURNE': 0,
    'FISHE': 0,
    'FISHEL': 0,
    'FISHELL': 0,
    'FISHER': 0,
    'FISHERMAN': 0,
    'FISHKIN': 0,
    'FISHKIND': 0,
    'FISHLER': 0,
    'FISHMAN': 0,
    'FISHPAW': 0,
    'FISHWICK': 0,
    'FISK': 0,
    'FISKE': 0,
    'FISKUM': 0,
    'FISLER': 0,
    'FISS': 0,
    'FISSE': 0,
    'FISSEL': 0,
    'FISSELL': 0,
    'FISSETTE': 0,
    'FISTE': 0,
    'FISTER': 0,
    'FISTLER': 0,
    'FITCH': 0,
    'FITCHETT': 0,
    'FITCHETTE': 0,
    'FITCHNER': 0,
    'FITCHPATRICK': 0,
    'FITE': 0,
    'FITES': 0,
    'FITGERALD': 0,
    'FITHEN': 0,
    'FITHIAN': 0,
    'FITKIN': 0,
    'FITSCHEN': 0,
    'FITT': 0,
    'FITTANTE': 0,
    'FITTE': 0,
    'FITTEN': 0,
    'FITTER': 0,
    'FITTERER': 0,
    'FITTERLING': 0,
    'FITTERMAN': 0,
    'FITTING': 0,
    'FITTIPALDI': 0,
    'FITTJE': 0,
    'FITTON': 0,
    'FITTRO': 0,
    'FITTS': 0,
    'FITTZ': 0,
    'FITZ': 0,
    'FITZCHARLES': 0,
    'FITZE': 0,
    'FITZELL': 0,
    'FITZER': 0,
    'FITZERALD': 0,
    'FITZGEARLD': 0,
    'FITZGERALD': 0,
    'FITZGIBBON': 0,
    'FITZGIBBONS': 0,
    'FITZHARRIS': 0,
    'FITZHENRY': 0,
    'FITZHERBERT': 0,
    'FITZHUGH': 0,
    'FITZJARRALD': 0,
    'FITZJARRELL': 0,
    'FITZKE': 0,
    'FITZKEE': 0,
    'FITZLOFF': 0,
    'FITZMARTIN': 0,
    'FITZMAURICE': 0,
    'FITZMORRIS': 0,
    'FITZNER': 0,
    'FITZPATRIC': 0,
    'FITZPATRICK': 0,
    'FITZRANDOLPH': 0,
    'FITZROY': 0,
    'FITZSIMMONS': 0,
    'FITZSIMON': 0,
    'FITZSIMONDS': 0,
    'FITZSIMONS': 0,
    'FITZTHUM': 0,
    'FITZWATER': 0,
    'FITZWILLIAM': 0,
    'FITZWILLIAMS': 0,
    'FIUMANO': 0,
    'FIUMARA': 0,
    'FIUME': 0,
    'FIUMEFREDDO': 0,
    'FIVEASH': 0,
    'FIVECOAT': 0,
    'FIVECOATE': 0,
    'FIVES': 0,
    'FIX': 0,
    'FIXEL': 0,
    'FIXICO': 0,
    'FIXLER': 0,
    'FIXMER': 0,
    'FIXSEN': 0,
    'FIZER': 0,
    'FIZZ': 0,
    'FJELD': 0,
    'FJELDHEIM': 0,
    'FJELDSTED': 0,
    'FJELLMAN': 0,
    'FJELSTAD': 0,
    'FJERSTAD': 0,
    'FJETLAND': 0,
    'FLAA': 0,
    'FLAAGAN': 0,
    'FLACCO': 0,
    'FLACH': 0,
    'FLACHS': 0,
    'FLACK': 0,
    'FLACKS': 0,
    'FLAD': 0,
    'FLADAGER': 0,
    'FLADD': 0,
    'FLADE': 0,
    'FLADELAND': 0,
    'FLADER': 0,
    'FLADGER': 0,
    'FLADHAMMER': 0,
    'FLADING': 0,
    'FLADLAND': 0,
    'FLADUNG': 0,
    'FLAG': 0,
    'FLAGE': 0,
    'FLAGEL': 0,
    'FLAGEOLLE': 0,
    'FLAGER': 0,
    'FLAGG': 0,
    'FLAGGE': 0,
    'FLAGGS': 0,
    'FLAGLE': 0,
    'FLAGLER': 0,
    'FLAGSTAD': 0,
    'FLAHART': 0,
    'FLAHARTY': 0,
    'FLAHAUT': 0,
    'FLAHAVEN': 0,
    'FLAHERTY': 0,
    'FLAHIVE': 0,
    'FLAIG': 0,
    'FLAIL': 0,
    'FLAIM': 0,
    'FLAIR': 0,
    'FLAITZ': 0,
    'FLAIZ': 0,
    'FLAK': 0,
    'FLAKE': 0,
    'FLAKER': 0,
    'FLAKES': 0,
    'FLAKS': 0,
    'FLAKUS': 0,
    'FLAM': 0,
    'FLAMAND': 0,
    'FLAMENCO': 0,
    'FLAMENT': 0,
    'FLAMER': 0,
    'FLAMING': 0,
    'FLAMINI': 0,
    'FLAMINIO': 0,
    'FLAMINO': 0,
    'FLAMION': 0,
    'FLAMM': 0,
    'FLAMMANG': 0,
    'FLAMME': 0,
    'FLAMMER': 0,
    'FLAMMIA': 0,
    'FLAMMINI': 0,
    'FLANAGAN': 0,
    'FLANAGIN': 0,
    'FLANARY': 0,
    'FLANDER': 0,
    'FLANDERS': 0,
    'FLANDREAU': 0,
    'FLANDRO': 0,
    'FLANEGAN': 0,
    'FLANERY': 0,
    'FLANIGAN': 0,
    'FLANIKEN': 0,
    'FLANINGAM': 0,
    'FLANK': 0,
    'FLANN': 0,
    'FLANNAGAN': 0,
    'FLANNAGIN': 0,
    'FLANNELLY': 0,
    'FLANNER': 0,
    'FLANNERY': 0,
    'FLANNIGAN': 0,
    'FLANSBURG': 0,
    'FLAQUER': 0,
    'FLARIDA': 0,
    'FLARITY': 0,
    'FLASCH': 0,
    'FLASH': 0,
    'FLASHER': 0,
    'FLASHMAN': 0,
    'FLASHNER': 0,
    'FLASK': 0,
    'FLASKA': 0,
    'FLASKERUD': 0,
    'FLASPOHLER': 0,
    'FLASTER': 0,
    'FLATAU': 0,
    'FLATEAU': 0,
    'FLATEBO': 0,
    'FLATEN': 0,
    'FLATER': 0,
    'FLATFORD': 0,
    'FLATGARD': 0,
    'FLATH': 0,
    'FLATHERS': 0,
    'FLATLAND': 0,
    'FLATLEY': 0,
    'FLATNESS': 0,
    'FLATO': 0,
    'FLATOW': 0,
    'FLATT': 0,
    'FLATTEN': 0,
    'FLATTER': 0,
    'FLATTERY': 0,
    'FLATTUM': 0,
    'FLAUCHER': 0,
    'FLAUDING': 0,
    'FLAUGH': 0,
    'FLAUGHER': 0,
    'FLAUM': 0,
    'FLAUTT': 0,
    'FLAVELL': 0,
    'FLAVIA': 1,
    'FLAVIN': 0,
    'FLAWS': 0,
    'FLAX': 0,
    'FLAXMAN': 0,
    'FLAY': 0,
    'FLEAGLE': 0,
    'FLEAK': 0,
    'FLEARY': 0,
    'FLEBBE': 0,
    'FLEBOTTE': 0,
    'FLECHA': 0,
    'FLECHSIG': 0,
    'FLECHTNER': 0,
    'FLECK': 0,
    'FLECKENSTEIN': 0,
    'FLECKER': 0,
    'FLECKNER': 0,
    'FLECTHER': 0,
    'FLEDDERJOHANN': 0,
    'FLEDDERJOHN': 0,
    'FLEDDERMAN': 0,
    'FLEECE': 0,
    'FLEEGAL': 0,
    'FLEEGE': 0,
    'FLEEGER': 0,
    'FLEEGLE': 0,
    'FLEEK': 0,
    'FLEEKS': 0,
    'FLEEMAN': 0,
    'FLEENER': 0,
    'FLEENOR': 0,
    'FLEER': 0,
    'FLEES': 0,
    'FLEESON': 0,
    'FLEET': 0,
    'FLEETHAM': 0,
    'FLEETON': 0,
    'FLEETWOOD': 0,
    'FLEGAL': 0,
    'FLEGE': 0,
    'FLEGEL': 0,
    'FLEGLE': 0,
    'FLEGLER': 0,
    'FLEHARTY': 0,
    'FLEIG': 0,
    'FLEIGLE': 0,
    'FLEINER': 0,
    'FLEIS': 0,
    'FLEISCH': 0,
    'FLEISCHACKER': 0,
    'FLEISCHAKER': 0,
    'FLEISCHAUER': 0,
    'FLEISCHER': 0,
    'FLEISCHFRESSER': 0,
    'FLEISCHHACKER': 0,
    'FLEISCHHAUER': 0,
    'FLEISCHMAN': 0,
    'FLEISCHMANN': 0,
    'FLEISCHNER': 0,
    'FLEISHER': 0,
    'FLEISHMAN': 0,
    'FLEISIG': 0,
    'FLEISNER': 0,
    'FLEISS': 0,
    'FLEISSNER': 0,
    'FLEITAS': 0,
    'FLEITES': 0,
    'FLEITMAN': 0,
    'FLEITZ': 0,
    'FLEM': 0,
    'FLEMATE': 0,
    'FLEMENS': 0,
    'FLEMER': 0,
    'FLEMING': 0,
    'FLEMINGS': 0,
    'FLEMISTER': 0,
    'FLEMM': 0,
    'FLEMMER': 0,
    'FLEMMING': 0,
    'FLEMMINGS': 0,
    'FLEMMONS': 0,
    'FLEMON': 0,
    'FLEMONS': 0,
    'FLENER': 0,
    'FLENIKEN': 0,
    'FLENNER': 0,
    'FLENNIKEN': 0,
    'FLENNOY': 0,
    'FLENORY': 0,
    'FLENOY': 0,
    'FLENTGE': 0,
    'FLENTJE': 0,
    'FLERCHINGER': 0,
    'FLERI': 0,
    'FLERLAGE': 0,
    'FLESCH': 0,
    'FLESCHER': 0,
    'FLESCHNER': 0,
    'FLESER': 0,
    'FLESH': 0,
    'FLESHER': 0,
    'FLESHMAN': 0,
    'FLESHNER': 0,
    'FLESKES': 0,
    'FLESNER': 0,
    'FLESSAS': 0,
    'FLESSNER': 0,
    'FLESZAR': 0,
    'FLETA': 1,
    'FLETCHALL': 0,
    'FLETCHER': 0.21052631578947373,
    'FLETE': 0,
    'FLETES': 0,
    'FLETT': 0,
    'FLETTER': 0,
    'FLEURANT': 0,
    'FLEURIDOR': 0,
    'FLEURIMA': 0,
    'FLEURIMOND': 0,
    'FLEURY': 0,
    'FLEWELLEN': 0,
    'FLEWELLING': 0,
    'FLEWELLYN': 0,
    'FLEX': 0,
    'FLEXER': 0,
    'FLEXON': 0,
    'FLEYSHMAN': 0,
    'FLIBOTTE': 0,
    'FLICEK': 0,
    'FLICK': 0,
    'FLICKER': 0,
    'FLICKINGER': 0,
    'FLICKNER': 0,
    'FLIEDER': 0,
    'FLIEG': 0,
    'FLIEGEL': 0,
    'FLIEGELMAN': 0,
    'FLIEGER': 0,
    'FLIEHMAN': 0,
    'FLIER': 0,
    'FLIERL': 0,
    'FLIES': 0,
    'FLIESS': 0,
    'FLIFLET': 0,
    'FLIGER': 0,
    'FLIGG': 0,
    'FLIGHT': 0,
    'FLIGOR': 0,
    'FLIKKEMA': 0,
    'FLINCHBAUGH': 0,
    'FLINCHUM': 0,
    'FLINDERS': 0,
    'FLINDT': 0,
    'FLING': 0,
    'FLINK': 0,
    'FLINN': 0,
    'FLINNER': 0,
    'FLINT': 0,
    'FLINTOFF': 0,
    'FLINTON': 0,
    'FLINTROP': 0,
    'FLINTROY': 0,
    'FLIPPEN': 0,
    'FLIPPIN': 0,
    'FLIPPO': 0,
    'FLIPSE': 0,
    'FLIS': 0,
    'FLISS': 0,
    'FLISTER': 0,
    'FLITCRAFT': 0,
    'FLITCROFT': 0,
    'FLITSCH': 0,
    'FLITTER': 0,
    'FLITTNER': 0,
    'FLITTON': 0,
    'FLO': 0.9615384615384616,
    'FLOAN': 0,
    'FLOATE': 0,
    'FLOBERG': 0,
    'FLOCCHINI': 0,
    'FLOCCO': 0,
    'FLOCH': 0,
    'FLOCK': 0,
    'FLOCKEN': 0,
    'FLOCKER': 0,
    'FLOCKHART': 0,
    'FLODEN': 0,
    'FLODIN': 0,
    'FLODSTROM': 0,
    'FLOE': 0,
    'FLOECK': 0,
    'FLOER': 0,
    'FLOERCHINGER': 0,
    'FLOERKE': 0,
    'FLOERSCH': 0,
    'FLOETER': 0,
    'FLOGEL': 0,
    'FLOHR': 0,
    'FLOHRE': 0,
    'FLOHRS': 0,
    'FLOLO': 0,
    'FLOM': 0,
    'FLONES': 0,
    'FLOOD': 0,
    'FLOODY': 0,
    'FLOOK': 0,
    'FLOOM': 0,
    'FLOOR': 0,
    'FLOORE': 0,
    'FLOR': 0.9188361408882083,
    'FLORA': 0.9461285962541032,
    'FLORACK': 0,
    'FLORAN': 0,
    'FLORANCE': 0.9259259259259258,
    'FLORAS': 0,
    'FLORAVANTI': 0,
    'FLORCZAK': 0,
    'FLORCZYK': 0,
    'FLORE': 0,
    'FLOREA': 0,
    'FLOREANI': 0,
    'FLOREK': 0,
    'FLORELL': 0,
    'FLORELLA': 0,
    'FLORELLI': 0,
    'FLORELLO': 0,
    'FLOREN': 0,
    'FLORENCE': 0.983671060397403,
    'FLORENCIA': 1,
    'FLORENCIO': 0.9596928982725529,
    'FLORENDO': 0,
    'FLORENE': 1,
    'FLORENT': 0,
    'FLORENTIN': 0,
    'FLORENTINA': 1,
    'FLORENTINE': 0,
    'FLORENTINO': 0.898876404494382,
    'FLORENZA': 0,
    'FLORER': 0,
    'FLORES': 0,
    'FLORESCA': 0,
    'FLORESCU': 0,
    'FLORESFLORES': 0,
    'FLORESGARCIA': 0,
    'FLORESGONZALEZ': 0,
    'FLORESHERNANDE': 0,
    'FLORESLOPEZ': 0,
    'FLORESMARTINEZ': 0,
    'FLORESPEREZ': 0,
    'FLORESRAMIREZ': 0,
    'FLORESRODRIGUE': 0,
    'FLORESSANCHEZ': 0,
    'FLORESTAL': 0,
    'FLORETTA': 1,
    'FLORETTI': 0,
    'FLOREY': 0,
    'FLOREZ': 0,
    'FLORI': 0,
    'FLORIA': 0.8849557522123894,
    'FLORIAN': 0,
    'FLORIANI': 0,
    'FLORIANO': 0,
    'FLORIDA': 0.936768149882904,
    'FLORIDIA': 0,
    'FLORIDO': 0,
    'FLORIE': 0,
    'FLORIMON': 0,
    'FLORIN': 0,
    'FLORINDA': 1,
    'FLORINE': 0.994475138121547,
    'FLORINO': 0,
    'FLORIO': 0,
    'FLORIS': 0,
    'FLORITA': 0,
    'FLORKE': 0,
    'FLORKEY': 0,
    'FLORKIEWICZ': 0,
    'FLORKOWSKI': 0,
    'FLORMAN': 0,
    'FLORO': 0,
    'FLOROS': 0,
    'FLORRIE': 1,
    'FLORS': 0,
    'FLORSHEIM': 0,
    'FLORVIL': 0,
    'FLORY': 0,
    'FLOSI': 0,
    'FLOSS': 0,
    'FLOSSIE': 1,
    'FLOT': 0,
    'FLOTA': 0,
    'FLOTH': 0,
    'FLOTO': 0,
    'FLOTRON': 0,
    'FLOTT': 0,
    'FLOTTE': 0,
    'FLOTTMAN': 0,
    'FLOUNDERS': 0,
    'FLOURNOY': 0,
    'FLOW': 0,
    'FLOWE': 0,
    'FLOWER': 0,
    'FLOWERDAY': 0,
    'FLOWERS': 0,
    'FLOY': 0.9881422924901185,
    'FLOYD': 0.8181679155834225,
    'FLUCAS': 0,
    'FLUCK': 0,
    'FLUCKE': 0,
    'FLUCKER': 0,
    'FLUCKEY': 0,
    'FLUCKIGER': 0,
    'FLUD': 0,
    'FLUDD': 0,
    'FLUDER': 0,
    'FLUECKIGER': 0,
    'FLUEGEL': 0,
    'FLUEGGE': 0,
    'FLUEHR': 0,
    'FLUELLEN': 0,
    'FLUENT': 0,
    'FLUET': 0,
    'FLUETTE': 0,
    'FLUG': 0,
    'FLUGEL': 0,
    'FLUGENCE': 0,
    'FLUGER': 0,
    'FLUGGE': 0,
    'FLUGSTAD': 0,
    'FLUGUM': 0,
    'FLUHART': 0,
    'FLUHARTY': 0,
    'FLUHR': 0,
    'FLUHRER': 0,
    'FLUIT': 0,
    'FLUITT': 0,
    'FLUKE': 0,
    'FLUKER': 0,
    'FLUM': 0,
    'FLUMAN': 0,
    'FLUMERFELT': 0,
    'FLUNDER': 0,
    'FLUNKER': 0,
    'FLURER': 0,
    'FLURI': 0,
    'FLURRY': 0,
    'FLURY': 0,
    'FLUSCHE': 0,
    'FLUSS': 0,
    'FLUTE': 0,
    'FLUTH': 0,
    'FLUTY': 0,
    'FLY': 0,
    'FLYE': 0,
    'FLYER': 0,
    'FLYGARE': 0,
    'FLYN': 0,
    'FLYNN': 0,
    'FLYNT': 0,
    'FLYTE': 0,
    'FLYTHE': 0,
    'FO': 0,
    'FOARD': 0,
    'FOAT': 0,
    'FOBAR': 0,
    'FOBARE': 0,
    'FOBB': 0,
    'FOBBE': 0,
    'FOBBS': 0,
    'FOBEAR': 0,
    'FOBER': 0,
    'FOBERT': 0,
    'FOBES': 0,
    'FOBIAN': 0,
    'FOCA': 0,
    'FOCHLER': 0,
    'FOCHS': 0,
    'FOCHT': 0,
    'FOCHTMAN': 0,
    'FOCKE': 0,
    'FOCKEN': 0,
    'FOCKLER': 0,
    'FOCO': 0,
    'FODDRELL': 0,
    'FODDRILL': 0,
    'FODE': 0,
    'FODEN': 0,
    'FODER': 0,
    'FODERA': 0,
    'FODERARO': 0,
    'FODERO': 0,
    'FODGE': 0,
    'FODNESS': 0,
    'FODOR': 0,
    'FODRIE': 0,
    'FODY': 0,
    'FOE': 0,
    'FOEGE': 0,
    'FOEGEN': 0,
    'FOEHL': 0,
    'FOEHNER': 0,
    'FOEHR': 0,
    'FOEHRKOLB': 0,
    'FOELKER': 0,
    'FOELL': 0,
    'FOELLER': 0,
    'FOELS': 0,
    'FOELSCH': 0,
    'FOELSKE': 0,
    'FOERCH': 0,
    'FOERG': 0,
    'FOERST': 0,
    'FOERSTEL': 0,
    'FOERSTER': 0,
    'FOERSTNER': 0,
    'FOERTSCH': 0,
    'FOESCH': 0,
    'FOFANA': 0,
    'FOFANAH': 0,
    'FOG': 0,
    'FOGAL': 0,
    'FOGAN': 0,
    'FOGARTY': 0,
    'FOGEL': 0,
    'FOGELBERG': 0,
    'FOGELMAN': 0,
    'FOGELQUIST': 0,
    'FOGELSANGER': 0,
    'FOGELSON': 0,
    'FOGELSONG': 0,
    'FOGELSONGER': 0,
    'FOGELSTROM': 0,
    'FOGERSON': 0,
    'FOGERTY': 0,
    'FOGG': 0,
    'FOGGIA': 0,
    'FOGGIE': 0,
    'FOGGIN': 0,
    'FOGGO': 0,
    'FOGGS': 0,
    'FOGGY': 0,
    'FOGHT': 0,
    'FOGIE': 0,
    'FOGLE': 0,
    'FOGLEMAN': 0,
    'FOGLER': 0,
    'FOGLESON': 0,
    'FOGLESONG': 0,
    'FOGLIA': 0,
    'FOGLIANO': 0,
    'FOGLIETTA': 0,
    'FOGLIO': 0,
    'FOGO': 0,
    'FOGT': 0,
    'FOGUS': 0,
    'FOGWELL': 0,
    'FOHEY': 0,
    'FOHL': 0,
    'FOHN': 0,
    'FOHNER': 0,
    'FOHR': 0,
    'FOHRMAN': 0,
    'FOHT': 0,
    'FOIL': 0,
    'FOILES': 0,
    'FOISEY': 0,
    'FOIST': 0,
    'FOISTER': 0,
    'FOISY': 0,
    'FOIT': 0,
    'FOIX': 0,
    'FOJAS': 0,
    'FOJTIK': 0,
    'FOK': 0,
    'FOKAS': 0,
    'FOKKEN': 0,
    'FOLAN': 0,
    'FOLAND': 0,
    'FOLAU': 0,
    'FOLCARELLI': 0,
    'FOLCH': 0,
    'FOLCHI': 0,
    'FOLCIK': 0,
    'FOLCK': 0,
    'FOLCKEMER': 0,
    'FOLCO': 0,
    'FOLDEN': 0,
    'FOLDENAUER': 0,
    'FOLDES': 0,
    'FOLDESI': 0,
    'FOLDI': 0,
    'FOLDS': 0,
    'FOLDY': 0,
    'FOLES': 0,
    'FOLETTA': 0,
    'FOLEY': 0,
    'FOLGAR': 0,
    'FOLGATE': 0,
    'FOLGER': 0,
    'FOLI': 0,
    'FOLIGNO': 0,
    'FOLINO': 0,
    'FOLIO': 0,
    'FOLK': 0,
    'FOLKE': 0,
    'FOLKEMA': 0,
    'FOLKEN': 0,
    'FOLKENROTH': 0,
    'FOLKENS': 0,
    'FOLKER': 0,
    'FOLKERS': 0,
    'FOLKERT': 0,
    'FOLKERTH': 0,
    'FOLKERTS': 0,
    'FOLKERTSMA': 0,
    'FOLKES': 0,
    'FOLKESTAD': 0,
    'FOLKINS': 0,
    'FOLKMAN': 0,
    'FOLKMANN': 0,
    'FOLKNER': 0,
    'FOLKS': 0,
    'FOLL': 0,
    'FOLLAND': 0,
    'FOLLANSBEE': 0,
    'FOLLAS': 0,
    'FOLLEN': 0,
    'FOLLENSBEE': 0,
    'FOLLER': 0,
    'FOLLET': 0,
    'FOLLETT': 0,
    'FOLLETTE': 0,
    'FOLLEY': 0,
    'FOLLIARD': 0,
    'FOLLICK': 0,
    'FOLLIN': 0,
    'FOLLINS': 0,
    'FOLLIS': 0,
    'FOLLMAN': 0,
    'FOLLMAR': 0,
    'FOLLMER': 0,
    'FOLLO': 0,
    'FOLLOWELL': 0,
    'FOLLOWILL': 0,
    'FOLLOWWILL': 0,
    'FOLLWEILER': 0,
    'FOLLY': 0,
    'FOLMAR': 0,
    'FOLMER': 0,
    'FOLMSBEE': 0,
    'FOLSE': 0,
    'FOLSKE': 0,
    'FOLSOM': 0,
    'FOLSON': 0,
    'FOLSTAD': 0,
    'FOLSTER': 0,
    'FOLSTON': 0,
    'FOLSY': 0,
    'FOLTA': 0,
    'FOLTIN': 0,
    'FOLTS': 0,
    'FOLTYN': 0,
    'FOLTZ': 0,
    'FOLWELL': 0,
    'FOLZ': 0,
    'FOMAN': 0,
    'FOMBY': 0,
    'FOMENKO': 0,
    'FOMIN': 0,
    'FON': 0,
    'FONACIER': 0,
    'FONCANNON': 0,
    'FONCECA': 0,
    'FONCK': 0,
    'FOND': 0,
    'FONDA': 0.8498583569405098,
    'FONDACARO': 0,
    'FONDAW': 0,
    'FONDELL': 0,
    'FONDER': 0,
    'FONDEUR': 0,
    'FONDON': 0,
    'FONDREN': 0,
    'FONDRIEST': 0,
    'FONDY': 0,
    'FONE': 0,
    'FONER': 0,
    'FONES': 0,
    'FONEY': 0,
    'FONFARA': 0,
    'FONG': 0,
    'FONGEMIE': 0,
    'FONGER': 0,
    'FONK': 0,
    'FONKEN': 0,
    'FONNER': 0,
    'FONNESBECK': 0,
    'FONOIMOANA': 0,
    'FONOTI': 0,
    'FONROSE': 0,
    'FONS': 0,
    'FONSECA': 0,
    'FONT': 0,
    'FONTAIN': 0,
    'FONTAINE': 0,
    'FONTALVO': 0,
    'FONTAN': 0,
    'FONTANA': 0,
    'FONTANAROSA': 0,
    'FONTANAZZA': 0,
    'FONTANE': 0,
    'FONTANELLA': 0,
    'FONTANELLI': 0,
    'FONTANES': 0,
    'FONTANETTA': 0,
    'FONTANEZ': 0,
    'FONTANILLA': 0,
    'FONTANINI': 0,
    'FONTANO': 0,
    'FONTE': 0,
    'FONTECCHIO': 0,
    'FONTECHA': 0,
    'FONTELA': 0,
    'FONTELERA': 0,
    'FONTENELLE': 0,
    'FONTENETTE': 0,
    'FONTENO': 0,
    'FONTENOT': 0,
    'FONTES': 0,
    'FONTI': 0,
    'FONTILLAS': 0,
    'FONTNEAU': 0,
    'FONTS': 0,
    'FONTUS': 0,
    'FONTZ': 0,
    'FONUA': 0,
    'FONVIELLE': 0,
    'FONVILLE': 0,
    'FONZI': 0,
    'FONZO': 0,
    'FOO': 0,
    'FOOCE': 0,
    'FOODY': 0,
    'FOOKES': 0,
    'FOOKS': 0,
    'FOON': 0,
    'FOONG': 0,
    'FOOR': 0,
    'FOORD': 0,
    'FOORE': 0,
    'FOOS': 0,
    'FOOSE': 0,
    'FOOSHEE': 0,
    'FOOT': 0,
    'FOOTE': 0,
    'FOOTER': 0,
    'FOOTIT': 0,
    'FOOTMAN': 0,
    'FOOTS': 0,
    'FOPIANO': 0,
    'FOPMA': 0,
    'FOPPE': 0,
    'FOPPIANO': 0,
    'FOR': 0,
    'FORADORI': 0,
    'FORAKER': 0,
    'FORAL': 0,
    'FORAN': 0,
    'FORAND': 0,
    'FORANT': 0,
    'FORAY': 0,
    'FORBECK': 0,
    'FORBERG': 0,
    'FORBES': 0,
    'FORBESS': 0,
    'FORBEY': 0,
    'FORBING': 0,
    'FORBIS': 0,
    'FORBORD': 0,
    'FORBS': 0,
    'FORBUS': 0,
    'FORBUSH': 0,
    'FORBY': 0,
    'FORCADE': 0,
    'FORCE': 0,
    'FORCELLA': 0,
    'FORCEY': 0,
    'FORCH': 0,
    'FORCHE': 0,
    'FORCHIONE': 0,
    'FORCHT': 0,
    'FORCIER': 0,
    'FORCINA': 0,
    'FORCINO': 0,
    'FORCK': 0,
    'FORCUCCI': 0,
    'FORCUM': 0,
    'FORD': 0,
    'FORDAHL': 0,
    'FORDE': 0,
    'FORDEN': 0,
    'FORDER': 0,
    'FORDHAM': 0,
    'FORDICE': 0,
    'FORDING': 0,
    'FORDJOUR': 0,
    'FORDNEY': 0,
    'FORDON': 0,
    'FORDYCE': 0,
    'FORE': 0,
    'FOREBACK': 0,
    'FOREE': 0,
    'FOREHAND': 0,
    'FOREIT': 0,
    'FORELL': 0,
    'FOREMAN': 0,
    'FOREN': 0,
    'FORER': 0,
    'FORERD': 0,
    'FORERO': 0,
    'FORES': 0,
    'FORESE': 0,
    'FORESEE': 0,
    'FORESMAN': 0,
    'FOREST': 0.7900677200902935,
    'FORESTA': 0,
    'FORESTAL': 0,
    'FORESTER': 0,
    'FORESTIER': 0,
    'FORESTIERE': 0,
    'FORESTIERI': 0,
    'FORET': 0,
    'FORETICH': 0,
    'FOREY': 0,
    'FORFA': 0,
    'FORGA': 0,
    'FORGACH': 0,
    'FORGACS': 0,
    'FORGAN': 0,
    'FORGAS': 0,
    'FORGASH': 0,
    'FORGE': 0,
    'FORGER': 0,
    'FORGES': 0,
    'FORGET': 0,
    'FORGETTE': 0,
    'FORGEY': 0,
    'FORGIE': 0,
    'FORGIONE': 0,
    'FORGIT': 0,
    'FORGRAVE': 0,
    'FORGUE': 0,
    'FORGUES': 0,
    'FORGUSON': 0,
    'FORGY': 0,
    'FORHAN': 0,
    'FORIEST': 0,
    'FORINASH': 0,
    'FORINGER': 0,
    'FORINO': 0,
    'FORIS': 0,
    'FORISH': 0,
    'FORISTER': 0,
    'FORK': 0,
    'FORKE': 0,
    'FORKEL': 0,
    'FORKELL': 0,
    'FORKER': 0,
    'FORKEY': 0,
    'FORKIN': 0,
    'FORKNER': 0,
    'FORKS': 0,
    'FORKUM': 0,
    'FORLAND': 0,
    'FORLANO': 0,
    'FORLENZA': 0,
    'FORLER': 0,
    'FORLINES': 0,
    'FORLINI': 0,
    'FORLIZZI': 0,
    'FORMA': 0,
    'FORMAN': 0,
    'FORMANEK': 0,
    'FORMANSKI': 0,
    'FORMARO': 0,
    'FORMATO': 0,
    'FORMBY': 0,
    'FORMELLA': 0,
    'FORMENTO': 0,
    'FORMER': 0,
    'FORMHALS': 0,
    'FORMICA': 0,
    'FORMICHELLA': 0,
    'FORMICHELLI': 0,
    'FORMICOLA': 0,
    'FORMISANO': 0,
    'FORMO': 0,
    'FORMOLO': 0,
    'FORMOSA': 0,
    'FORMOSO': 0,
    'FORMYDUVAL': 0,
    'FORNACIARI': 0,
    'FORNADEL': 0,
    'FORNAL': 0,
    'FORNARA': 0,
    'FORNARI': 0,
    'FORNARIS': 0,
    'FORNARO': 0,
    'FORNAROTTO': 0,
    'FORNASH': 0,
    'FORNATARO': 0,
    'FORNEA': 0,
    'FORNEAR': 0,
    'FORNELL': 0,
    'FORNELLI': 0,
    'FORNER': 0,
    'FORNERIS': 0,
    'FORNERO': 0,
    'FORNES': 0,
    'FORNESS': 0,
    'FORNEY': 0,
    'FORNI': 0,
    'FORNICOLA': 0,
    'FORNINO': 0,
    'FORNO': 0,
    'FORNOF': 0,
    'FORNOFF': 0,
    'FORNOS': 0,
    'FORNSHELL': 0,
    'FORNWALD': 0,
    'FORNWALT': 0,
    'FORONDA': 0,
    'FOROUGHI': 0,
    'FOROUTAN': 0,
    'FORQUER': 0,
    'FORRAY': 0,
    'FORREN': 0,
    'FORRER': 0,
    'FORREST': 0.7670454545454546,
    'FORRESTAL': 0,
    'FORRESTALL': 0,
    'FORRESTER': 0,
    'FORRET': 0,
    'FORRETTE': 0,
    'FORREY': 0,
    'FORRISTAL': 0,
    'FORRISTALL': 0,
    'FORRISTER': 0,
    'FORRO': 0,
    'FORRY': 0,
    'FORS': 0,
    'FORSBERG': 0,
    'FORSCH': 0,
    'FORSCHEN': 0,
    'FORSCHLER': 0,
    'FORSCHNER': 0,
    'FORSE': 0,
    'FORSEE': 0,
    'FORSELL': 0,
    'FORSEN': 0,
    'FORSETH': 0,
    'FORSEY': 0,
    'FORSGREN': 0,
    'FORSHA': 0,
    'FORSHAW': 0,
    'FORSHAY': 0,
    'FORSHEE': 0,
    'FORSHEY': 0,
    'FORSHT': 0,
    'FORSLAND': 0,
    'FORSLIN': 0,
    'FORSLUND': 0,
    'FORSMAN': 0,
    'FORSMANN': 0,
    'FORSMARK': 0,
    'FORSON': 0,
    'FORSS': 0,
    'FORSSELL': 0,
    'FORSSTROM': 0,
    'FORST': 0,
    'FORSTALL': 0,
    'FORSTE': 0,
    'FORSTER': 0,
    'FORSTHOEFEL': 0,
    'FORSTHOFFER': 0,
    'FORSTING': 0,
    'FORSTNER': 0,
    'FORSTON': 0,
    'FORSTROM': 0,
    'FORSYTH': 0,
    'FORSYTHE': 0,
    'FORT': 0,
    'FORTADO': 0,
    'FORTALEZA': 0,
    'FORTE': 0,
    'FORTENBAUGH': 0,
    'FORTENBERRY': 0,
    'FORTENBERY': 0,
    'FORTENBURY': 0,
    'FORTENER': 0,
    'FORTER': 0,
    'FORTES': 0,
    'FORTESCUE': 0,
    'FORTEZA': 0,
    'FORTGANG': 0,
    'FORTH': 0,
    'FORTHMAN': 0,
    'FORTHOFER': 0,
    'FORTHUN': 0,
    'FORTI': 0,
    'FORTICH': 0,
    'FORTIER': 0,
    'FORTIN': 0,
    'FORTINBERRY': 0,
    'FORTINE': 0,
    'FORTINI': 0,
    'FORTINO': 0,
    'FORTIS': 0,
    'FORTIZ': 0,
    'FORTKAMP': 0,
    'FORTMAN': 0,
    'FORTMANN': 0,
    'FORTMEYER': 0,
    'FORTNA': 0,
    'FORTNER': 0,
    'FORTNEY': 0,
    'FORTON': 0,
    'FORTS': 0,
    'FORTSCH': 0,
    'FORTSON': 0,
    'FORTT': 0,
    'FORTUGNO': 0,
    'FORTUN': 0,
    'FORTUNA': 0,
    'FORTUNATO': 0,
    'FORTUNE': 0,
    'FORTUNO': 0,
    'FORTWENGLER': 0,
    'FORTY': 0,
    'FORWARD': 0,
    'FORWOOD': 0,
    'FORYS': 0,
    'FORYSTEK': 0,
    'FORZANO': 0,
    'FORZIATI': 0,
    'FOS': 0,
    'FOSBENNER': 0,
    'FOSBERG': 0,
    'FOSBINDER': 0,
    'FOSBRINK': 0,
    'FOSBURG': 0,
    'FOSBURGH': 0,
    'FOSCHI': 0,
    'FOSCHINI': 0,
    'FOSCO': 0,
    'FOSCUE': 0,
    'FOSDICK': 0,
    'FOSE': 0,
    'FOSGATE': 0,
    'FOSHA': 0,
    'FOSHAG': 0,
    'FOSHAY': 0,
    'FOSHE': 0,
    'FOSHEE': 0,
    'FOSHEIM': 0,
    'FOSHER': 0,
    'FOSHIE': 0,
    'FOSKET': 0,
    'FOSKETT': 0,
    'FOSKEY': 0,
    'FOSLER': 0,
    'FOSLIEN': 0,
    'FOSMARK': 0,
    'FOSMIRE': 0,
    'FOSNAUGH': 0,
    'FOSNAUGHT': 0,
    'FOSNESS': 0,
    'FOSNIGHT': 0,
    'FOSNOT': 0,
    'FOSNOW': 0,
    'FOSQUE': 0,
    'FOSS': 0,
    'FOSSA': 0,
    'FOSSATI': 0,
    'FOSSE': 0,
    'FOSSELL': 0,
    'FOSSELLA': 0,
    'FOSSELMAN': 0,
    'FOSSEN': 0,
    'FOSSETT': 0,
    'FOSSEY': 0,
    'FOSSI': 0,
    'FOSSIER': 0,
    'FOSSITT': 0,
    'FOSSLER': 0,
    'FOSSO': 0,
    'FOSSON': 0,
    'FOSSUM': 0,
    'FOST': 0,
    'FOSTER': 0.06822833750284285,
    'FOSTON': 0,
    'FOTE': 0,
    'FOTH': 0,
    'FOTHERGILL': 0,
    'FOTHERINGHAM': 0,
    'FOTI': 0,
    'FOTIA': 0,
    'FOTIADES': 0,
    'FOTIADIS': 0,
    'FOTINO': 0,
    'FOTINOS': 0,
    'FOTIOU': 0,
    'FOTIS': 0,
    'FOTO': 0,
    'FOTOPOULOS': 0,
    'FOTOS': 0,
    'FOTSCH': 0,
    'FOTTA': 0,
    'FOTTER': 0,
    'FOTU': 0,
    'FOTY': 0,
    'FOUAD': 0,
    'FOUBERT': 0,
    'FOUCAULT': 0,
    'FOUCH': 0,
    'FOUCHA': 0,
    'FOUCHE': 0,
    'FOUCHER': 0,
    'FOUCHEY': 0,
    'FOUDRAY': 0,
    'FOUGERE': 0,
    'FOUGEROUSSE': 0,
    'FOUGHT': 0,
    'FOUGHTY': 0,
    'FOUGNER': 0,
    'FOUHY': 0,
    'FOUKE': 0,
    'FOUKS': 0,
    'FOULADI': 0,
    'FOULDS': 0,
    'FOULGER': 0,
    'FOULK': 0,
    'FOULKE': 0,
    'FOULKES': 0,
    'FOULKROD': 0,
    'FOULKS': 0,
    'FOULON': 0,
    'FOULTZ': 0,
    'FOUND': 0,
    'FOUNDAS': 0,
    'FOUNDS': 0,
    'FOUNTAIN': 0,
    'FOUNTAINE': 0,
    'FOUNTAS': 0,
    'FOUNTIAN': 0,
    'FOUQUET': 0,
    'FOUQUETTE': 0,
    'FOURAKER': 0,
    'FOURCADE': 0,
    'FOURHMAN': 0,
    'FOURIE': 0,
    'FOURKILLER': 0,
    'FOURMAN': 0,
    'FOURNERAT': 0,
    'FOURNET': 0,
    'FOURNEY': 0,
    'FOURNIE': 0,
    'FOURNIER': 0,
    'FOURQUREAN': 0,
    'FOURRE': 0,
    'FOURROUX': 0,
    'FOURT': 0,
    'FOURTE': 0,
    'FOURTNER': 0,
    'FOUSE': 0,
    'FOUSEK': 0,
    'FOUSER': 0,
    'FOUSHEE': 0,
    'FOUSS': 0,
    'FOUST': 0,
    'FOUT': 0,
    'FOUTCH': 0,
    'FOUTS': 0,
    'FOUTTY': 0,
    'FOUTY': 0,
    'FOUTZ': 0,
    'FOUX': 0,
    'FOW': 0,
    'FOWBLE': 0,
    'FOWELL': 0,
    'FOWERS': 0,
    'FOWKE': 0,
    'FOWKES': 0,
    'FOWLDS': 0,
    'FOWLE': 0,
    'FOWLER': 0,
    'FOWLES': 0,
    'FOWLEY': 0,
    'FOWLIE': 0,
    'FOWLKES': 0,
    'FOWLKS': 0,
    'FOWLS': 0,
    'FOWLSTON': 0,
    'FOX': 0,
    'FOXALL': 0,
    'FOXE': 0,
    'FOXEN': 0,
    'FOXHALL': 0,
    'FOXHOVEN': 0,
    'FOXLEY': 0,
    'FOXMAN': 0,
    'FOXWELL': 0,
    'FOXWORTH': 0,
    'FOXWORTHY': 0,
    'FOXX': 0,
    'FOY': 0,
    'FOYE': 0,
    'FOYER': 0,
    'FOYIL': 0,
    'FOYLE': 0,
    'FOYT': 0,
    'FOYTIK': 0,
    'FOZARD': 0,
    'FOZZARD': 0,
    'FR': 0,
    'FRAAS': 0,
    'FRAASE': 0,
    'FRABLE': 0,
    'FRABONI': 0,
    'FRABOTTA': 0,
    'FRACASSA': 0,
    'FRACASSI': 0,
    'FRACASSO': 0,
    'FRACCHIA': 0,
    'FRACE': 0,
    'FRACHISEUR': 0,
    'FRACIS': 0,
    'FRACK': 0,
    'FRACKER': 0,
    'FRACKOWIAK': 0,
    'FRACTION': 0,
    'FRACZEK': 0,
    'FRADE': 0,
    'FRADELLA': 0,
    'FRADENBURG': 0,
    'FRADERA': 0,
    'FRADETTE': 0,
    'FRADIN': 0,
    'FRADKIN': 0,
    'FRADY': 0,
    'FRAEDRICH': 0,
    'FRAELICH': 0,
    'FRAENKEL': 0,
    'FRAGA': 0,
    'FRAGALA': 0,
    'FRAGALE': 0,
    'FRAGAPANE': 0,
    'FRAGASSI': 0,
    'FRAGER': 0,
    'FRAGNITO': 0,
    'FRAGO': 0,
    'FRAGOLA': 0,
    'FRAGOMENI': 0,
    'FRAGOSA': 0,
    'FRAGOSO': 0,
    'FRAGOZA': 0,
    'FRAGOZO': 0,
    'FRAGUA': 0,
    'FRAGUADA': 0,
    'FRAHER': 0,
    'FRAHM': 0,
    'FRAIDE': 0,
    'FRAIJO': 0,
    'FRAIL': 0,
    'FRAILE': 0,
    'FRAILEY': 0,
    'FRAILING': 0,
    'FRAILS': 0,
    'FRAIM': 0,
    'FRAIMAN': 0,
    'FRAIN': 0,
    'FRAINE': 0,
    'FRAIOLI': 0,
    'FRAIR': 0,
    'FRAIRE': 0,
    'FRAIS': 0,
    'FRAISE': 0,
    'FRAISER': 0,
    'FRAIZE': 0,
    'FRAIZER': 0,
    'FRAKE': 0,
    'FRAKER': 0,
    'FRAKES': 0,
    'FRAKLIN': 0,
    'FRALEIGH': 0,
    'FRALEY': 0,
    'FRALIC': 0,
    'FRALICH': 0,
    'FRALICK': 0,
    'FRALIN': 0,
    'FRALISH': 0,
    'FRALIX': 0,
    'FRAM': 0,
    'FRAMBACH': 0,
    'FRAMBES': 0,
    'FRAME': 0,
    'FRAMENT': 0,
    'FRAMER': 0,
    'FRAMES': 0,
    'FRAMKE': 0,
    'FRAMPTON': 0,
    'FRAN': 0.990990990990991,
    'FRANA': 0,
    'FRANC': 0,
    'FRANCA': 0,
    'FRANCART': 0,
    'FRANCAVILLA': 0,
    'FRANCE': 0.31152647975077885,
    'FRANCEK': 0,
    'FRANCEL': 0,
    'FRANCELLA': 0,
    'FRANCEN': 0,
    'FRANCENE': 1,
    'FRANCES': 0.9976853699417352,
    'FRANCESCA': 1,
    'FRANCESCHELLI': 0,
    'FRANCESCHETTI': 0,
    'FRANCESCHI': 0,
    'FRANCESCHINA': 0,
    'FRANCESCHINI': 0,
    'FRANCESCO': 0.9708737864077669,
    'FRANCESCON': 0,
    'FRANCESCONE': 0,
    'FRANCESCONI': 0,
    'FRANCESE': 0,
    'FRANCETIC': 0,
    'FRANCEY': 0,
    'FRANCH': 0,
    'FRANCHAK': 0,
    'FRANCHER': 0,
    'FRANCHESCA': 1,
    'FRANCHETTI': 0,
    'FRANCHI': 0,
    'FRANCHINA': 0,
    'FRANCHINI': 0,
    'FRANCHINO': 0,
    'FRANCHUK': 0,
    'FRANCI': 0,
    'FRANCIA': 0,
    'FRANCICA': 0,
    'FRANCIE': 1,
    'FRANCIES': 0,
    'FRANCIK': 0,
    'FRANCILLON': 0,
    'FRANCINA': 1,
    'FRANCINE': 1,
    'FRANCINI': 0,
    'FRANCIONE': 0,
    'FRANCIONI': 0,
    'FRANCIOS': 0,
    'FRANCIOSA': 0,
    'FRANCIOSE': 0,
    'FRANCIOSI': 0,
    'FRANCIS': 0.8821313001462832,
    'FRANCISCA': 1,
    'FRANCISCO': 0.9497964721845319,
    'FRANCISCUS': 0,
    'FRANCISE': 0,
    'FRANCISKOVICH': 0,
    'FRANCISQUE': 0,
    'FRANCK': 0,
    'FRANCKA': 0,
    'FRANCKE': 0,
    'FRANCKOWIAK': 0,
    'FRANCKS': 0,
    'FRANCO': 0,
    'FRANCOEUR': 0,
    'FRANCOIS': 0,
    'FRANCOISE': 0.9803921568627452,
    'FRANCOLINO': 0,
    'FRANCOM': 0,
    'FRANCONE': 0,
    'FRANCOS': 0,
    'FRANCOUR': 0,
    'FRANCY': 0,
    'FRANCZAK': 0,
    'FRANCZEK': 0,
    'FRANCZYK': 0,
    'FRAND': 0,
    'FRANDLE': 0,
    'FRANDO': 0,
    'FRANDRUP': 0,
    'FRANDSEN': 0,
    'FRANDSON': 0,
    'FRANE': 0,
    'FRANECKI': 0,
    'FRANEK': 0,
    'FRANER': 0,
    'FRANEY': 0,
    'FRANGELLA': 0,
    'FRANGER': 0,
    'FRANGIE': 0,
    'FRANGIONE': 0,
    'FRANGIOSA': 0,
    'FRANGIPANE': 0,
    'FRANGOS': 0,
    'FRANGOULIS': 0,
    'FRANICH': 0,
    'FRANJUL': 0,
    'FRANK': 0.9597655735545898,
    'FRANKART': 0,
    'FRANKE': 0,
    'FRANKEBERGER': 0,
    'FRANKEL': 0,
    'FRANKEN': 0,
    'FRANKENBACH': 0,
    'FRANKENBERG': 0,
    'FRANKENBERGER': 0,
    'FRANKENBERRY': 0,
    'FRANKENFELD': 0,
    'FRANKENFIELD': 0,
    'FRANKENSTEIN': 0,
    'FRANKER': 0,
    'FRANKFORD': 0,
    'FRANKFORT': 0,
    'FRANKFORTER': 0,
    'FRANKFURT': 0,
    'FRANKFURTH': 0,
    'FRANKHAUSER': 0,
    'FRANKHOUSE': 0,
    'FRANKHOUSER': 0,
    'FRANKI': 0,
    'FRANKIE': 0.9964570416297609,
    'FRANKIEWICZ': 0,
    'FRANKIN': 0,
    'FRANKINO': 0,
    'FRANKL': 0,
    'FRANKLAND': 0,
    'FRANKLE': 0,
    'FRANKLIN': 0.6439203880247534,
    'FRANKLYN': 0.9433962264150944,
    'FRANKMAN': 0,
    'FRANKO': 0,
    'FRANKOS': 0,
    'FRANKOVIC': 0,
    'FRANKOVICH': 0,
    'FRANKOWIAK': 0,
    'FRANKOWSKI': 0,
    'FRANKS': 0,
    'FRANKSON': 0,
    'FRANKUM': 0,
    'FRANO': 0,
    'FRANQUEZ': 0,
    'FRANQUI': 0,
    'FRANQUIZ': 0,
    'FRANS': 0,
    'FRANSAW': 0,
    'FRANSE': 0,
    'FRANSEEN': 0,
    'FRANSEN': 0,
    'FRANSICO': 0,
    'FRANSISCA': 1,
    'FRANSISCO': 0,
    'FRANSON': 0,
    'FRANSSEN': 0,
    'FRANSUA': 0,
    'FRANSWAY': 0,
    'FRANTA': 0,
    'FRANTI': 0,
    'FRANTOM': 0,
    'FRANTUM': 0,
    'FRANTZ': 0,
    'FRANTZEN': 0,
    'FRANTZICH': 0,
    'FRANTZIS': 0,
    'FRANZ': 0,
    'FRANZA': 0,
    'FRANZBLAU': 0,
    'FRANZE': 0,
    'FRANZEL': 0,
    'FRANZEN': 0,
    'FRANZESE': 0,
    'FRANZETTI': 0,
    'FRANZI': 0,
    'FRANZINI': 0,
    'FRANZINO': 0,
    'FRANZKE': 0,
    'FRANZMAN': 0,
    'FRANZMANN': 0,
    'FRANZMEIER': 0,
    'FRANZO': 0,
    'FRANZOI': 0,
    'FRANZONE': 0,
    'FRANZONI': 0,
    'FRANZOSA': 0,
    'FRANZOSO': 0,
    'FRANZOY': 0,
    'FRANZWA': 0,
    'FRAPPIER': 0,
    'FRARACCIO': 0,
    'FRARE': 0,
    'FRARY': 0,
    'FRAS': 0,
    'FRASCA': 0,
    'FRASCARELLI': 0,
    'FRASCATI': 0,
    'FRASCATORE': 0,
    'FRASCELLA': 0,
    'FRASCH': 0,
    'FRASCHETTI': 0,
    'FRASCHILLA': 0,
    'FRASCINO': 0,
    'FRASCO': 0,
    'FRASCONA': 0,
    'FRASCONE': 0,
    'FRASE': 0,
    'FRASER': 0,
    'FRASH': 0,
    'FRASHER': 0,
    'FRASHIER': 0,
    'FRASHURE': 0,
    'FRASIER': 0,
    'FRASQUILLO': 0,
    'FRASSETTO': 0,
    'FRASSO': 0,
    'FRASSRAND': 0,
    'FRASURE': 0,
    'FRATANGELO': 0,
    'FRATARCANGELI': 0,
    'FRATE': 0,
    'FRATELLO': 0,
    'FRATER': 0,
    'FRATES': 0,
    'FRATESI': 0,
    'FRATI': 0,
    'FRATIANNI': 0,
    'FRATICELLI': 0,
    'FRATINI': 0,
    'FRATIS': 0,
    'FRATO': 0,
    'FRATONI': 0,
    'FRATT': 0,
    'FRATTA': 0,
    'FRATTALI': 0,
    'FRATTALONE': 0,
    'FRATTARELLI': 0,
    'FRATTAROLA': 0,
    'FRATTAROLI': 0,
    'FRATTINI': 0,
    'FRATTO': 0,
    'FRATTURA': 0,
    'FRATUS': 0,
    'FRATZ': 0,
    'FRATZKE': 0,
    'FRAUENDIENST': 0,
    'FRAUENDORFER': 0,
    'FRAUENFELDER': 0,
    'FRAUENHEIM': 0,
    'FRAUGHTON': 0,
    'FRAUHIGER': 0,
    'FRAUMENI': 0,
    'FRAUNFELDER': 0,
    'FRAUNFELTER': 0,
    'FRAUSTO': 0,
    'FRAUTSCHI': 0,
    'FRAVEL': 0,
    'FRAVERT': 0,
    'FRAWLEY': 0,
    'FRAY': 0,
    'FRAYER': 0,
    'FRAYLE': 0,
    'FRAYNE': 0,
    'FRAYRE': 0,
    'FRAYSER': 0,
    'FRAYSIER': 0,
    'FRAZAO': 0,
    'FRAZAR': 0,
    'FRAZE': 0,
    'FRAZEE': 0,
    'FRAZEL': 0,
    'FRAZELL': 0,
    'FRAZELLE': 0,
    'FRAZER': 0,
    'FRAZEUR': 0,
    'FRAZEY': 0,
    'FRAZHO': 0,
    'FRAZIER': 0,
    'FRAZIN': 0,
    'FRAZINE': 0,
    'FRAZZETTA': 0,
    'FRAZZINI': 0,
    'FRAZZITTA': 0,
    'FREA': 0,
    'FREAD': 0,
    'FREAM': 0,
    'FREANEY': 0,
    'FREAR': 0,
    'FREARSON': 0,
    'FREAS': 0,
    'FREASE': 0,
    'FREASIER': 0,
    'FREBERG': 0,
    'FREBURG': 0,
    'FREBURGER': 0,
    'FRECH': 0,
    'FRECHETTE': 0,
    'FRECK': 0,
    'FRECKER': 0,
    'FRECKLETON': 0,
    'FRED': 0.9975062344139651,
    'FREDA': 0.9764503159103963,
    'FREDD': 0,
    'FREDDA': 1,
    'FREDDIE': 0.9983047654925599,
    'FREDDY': 1,
    'FREDE': 0,
    'FREDEEN': 0,
    'FREDELL': 0,
    'FREDELLA': 0,
    'FREDEN': 0,
    'FREDENBERG': 0,
    'FREDENBURG': 0,
    'FREDENBURGH': 0,
    'FREDENDALL': 0,
    'FREDERES': 0,
    'FREDERIC': 0.9615384615384615,
    'FREDERICA': 1,
    'FREDERICH': 0,
    'FREDERICI': 0,
    'FREDERICK': 0.9123763256117068,
    'FREDERICKA': 1,
    'FREDERICKS': 0,
    'FREDERICKSEN': 0,
    'FREDERICKSON': 0,
    'FREDERICO': 0,
    'FREDERIKSEN': 0,
    'FREDERIQUE': 0,
    'FREDERKING': 0,
    'FREDETTE': 0,
    'FREDIA': 1,
    'FREDIANI': 0,
    'FREDIEU': 0,
    'FREDIN': 0,
    'FREDLEY': 0,
    'FREDLUND': 0,
    'FREDMAN': 0,
    'FREDO': 0,
    'FREDREGILL': 0,
    'FREDRIC': 1,
    'FREDRICH': 0,
    'FREDRICHS': 0,
    'FREDRICK': 0.9460946094609461,
    'FREDRICKA': 1,
    'FREDRICKS': 0,
    'FREDRICKSEN': 0,
    'FREDRICKSON': 0,
    'FREDRIKSEN': 0,
    'FREDRIKSON': 0,
    'FREDRITZ': 0,
    'FREDSON': 0,
    'FREE': 0,
    'FREEBAIRN': 0,
    'FREEBERG': 0,
    'FREEBERN': 0,
    'FREEBORN': 0,
    'FREEBURG': 0,
    'FREEBURGER': 0,
    'FREEBURN': 0,
    'FREEBURY': 0,
    'FREEBY': 0,
    'FREECE': 0,
    'FREED': 0,
    'FREEDA': 1,
    'FREEDBERG': 0,
    'FREEDLAND': 0,
    'FREEDLE': 0,
    'FREEDLINE': 0,
    'FREEDLUND': 0,
    'FREEDMAN': 0,
    'FREEDOM': 0,
    'FREEH': 0,
    'FREEHAUF': 0,
    'FREEHILL': 0,
    'FREEHLING': 0,
    'FREEL': 0,
    'FREELAND': 0,
    'FREELEN': 0,
    'FREELEY': 0,
    'FREELING': 0,
    'FREELON': 0,
    'FREELOVE': 0,
    'FREELS': 0,
    'FREELY': 0,
    'FREEMAN': 0.10399643440796318,
    'FREEMANTLE': 0,
    'FREEMEN': 0,
    'FREEMIRE': 0,
    'FREEMON': 0,
    'FREEMONT': 0,
    'FREEMYER': 0,
    'FREENEY': 0,
    'FREENY': 0,
    'FREER': 0,
    'FREERKS': 0,
    'FREERKSEN': 0,
    'FREES': 0,
    'FREESE': 0,
    'FREESMEIER': 0,
    'FREESTONE': 0,
    'FREET': 0,
    'FREETAGE': 0,
    'FREETH': 0,
    'FREEWALT': 0,
    'FREEZE': 0,
    'FREGA': 0,
    'FREGEAU': 0,
    'FREGIA': 0,
    'FREGIN': 0,
    'FREGO': 0,
    'FREGOE': 0,
    'FREGOSI': 0,
    'FREGOSO': 0,
    'FREGOZO': 0,
    'FREHNER': 0,
    'FREHSE': 0,
    'FREI': 0,
    'FREIBERG': 0,
    'FREIBERGER': 0,
    'FREIBERT': 0,
    'FREIBOTH': 0,
    'FREIBURG': 0,
    'FREIBURGER': 0,
    'FREID': 0,
    'FREIDA': 1,
    'FREIDEL': 0,
    'FREIDHOF': 0,
    'FREIDHOFF': 0,
    'FREIDIN': 0,
    'FREIDINGER': 0,
    'FREIDLINE': 0,
    'FREIDMAN': 0,
    'FREIE': 0,
    'FREIER': 0,
    'FREIERMUTH': 0,
    'FREIERT': 0,
    'FREIFELD': 0,
    'FREIHAUT': 0,
    'FREIHEIT': 0,
    'FREIHOFER': 0,
    'FREIJ': 0,
    'FREIJE': 0,
    'FREIL': 0,
    'FREILER': 0,
    'FREILEY': 0,
    'FREILICH': 0,
    'FREILING': 0,
    'FREILINGER': 0,
    'FREIMAN': 0,
    'FREIMANIS': 0,
    'FREIMANN': 0,
    'FREIMARK': 0,
    'FREIMUND': 0,
    'FREIMUTH': 0,
    'FREIN': 0,
    'FREINER': 0,
    'FREIRE': 0,
    'FREIREICH': 0,
    'FREIS': 0,
    'FREISE': 0,
    'FREISINGER': 0,
    'FREISLEBEN': 0,
    'FREISMUTH': 0,
    'FREISS': 0,
    'FREITAG': 0,
    'FREITAS': 0,
    'FREITES': 0,
    'FREIWALD': 0,
    'FREKING': 0,
    'FRELAND': 0,
    'FRELICH': 0,
    'FRELIGH': 0,
    'FRELIN': 0,
    'FRELIX': 0,
    'FRELOW': 0,
    'FRELS': 0,
    'FREMD': 0,
    'FREMDER': 0,
    'FREMER': 0,
    'FREMGEN': 0,
    'FREMIN': 0,
    'FREMLING': 0,
    'FREMMING': 0,
    'FREMONT': 0,
    'FREMOUW': 0,
    'FREMPONG': 0,
    'FREMSTAD': 0,
    'FRENCH': 0,
    'FRENCHER': 0,
    'FRENCHIK': 0,
    'FRENCHMAN': 0,
    'FREND': 0,
    'FRENDO': 0,
    'FRENES': 0,
    'FRENETTE': 0,
    'FRENG': 0,
    'FRENGEL': 0,
    'FRENGER': 0,
    'FRENI': 0,
    'FRENIER': 0,
    'FRENIERE': 0,
    'FRENK': 0,
    'FRENKEL': 0,
    'FRENN': 0,
    'FRENO': 0,
    'FRENS': 0,
    'FRENSLEY': 0,
    'FRENTRESS': 0,
    'FRENTZ': 0,
    'FRENTZEL': 0,
    'FRENYEA': 0,
    'FRENZ': 0,
    'FRENZA': 0,
    'FRENZEL': 0,
    'FRERE': 0,
    'FRERES': 0,
    'FRERICH': 0,
    'FRERICHS': 0,
    'FRERICKS': 0,
    'FRERIKS': 0,
    'FRERK': 0,
    'FRERKER': 0,
    'FRERKING': 0,
    'FRESCAS': 0,
    'FRESCH': 0,
    'FRESCHI': 0,
    'FRESCO': 0,
    'FRESCURA': 0,
    'FRESE': 0,
    'FRESH': 0,
    'FRESHCORN': 0,
    'FRESHLEY': 0,
    'FRESHMAN': 0,
    'FRESHOUR': 0,
    'FRESHWATER': 0,
    'FRESINA': 0,
    'FRESNEDA': 0,
    'FRESOLONE': 0,
    'FRESON': 0,
    'FRESONKE': 0,
    'FRESQUEZ': 0,
    'FRESSE': 0,
    'FRET': 0,
    'FRETER': 0,
    'FRETHEIM': 0,
    'FRETT': 0,
    'FRETTE': 0,
    'FRETTER': 0,
    'FRETTO': 0,
    'FRETTS': 0,
    'FRETTY': 0,
    'FRETWELL': 0,
    'FRETZ': 0,
    'FREUD': 0,
    'FREUDE': 0,
    'FREUDENBERG': 0,
    'FREUDENBERGER': 0,
    'FREUDENBURG': 0,
    'FREUDENRICH': 0,
    'FREUDENSTEIN': 0,
    'FREUDENTHAL': 0,
    'FREUDIGER': 0,
    'FREULER': 0,
    'FREUND': 0,
    'FREUNDLICH': 0,
    'FREUNDT': 0,
    'FREVELE': 0,
    'FREVERT': 0,
    'FREVILLE': 0,
    'FREVOLA': 0,
    'FREW': 0,
    'FREWIN': 0,
    'FREY': 0,
    'FREYALDENHOVEN': 0,
    'FREYBERG': 0,
    'FREYBERGER': 0,
    'FREYE': 0,
    'FREYER': 0,
    'FREYERMUTH': 0,
    'FREYHOLTZ': 0,
    'FREYLER': 0,
    'FREYLING': 0,
    'FREYMAN': 0,
    'FREYMILLER': 0,
    'FREYMUTH': 0,
    'FREYOU': 0,
    'FREYRE': 0,
    'FREYTA': 0,
    'FREYTAG': 0,
    'FREYTES': 0,
    'FREZZA': 0,
    'FRIA': 0,
    'FRIANT': 0,
    'FRIAR': 0,
    'FRIAS': 0,
    'FRIBERG': 0,
    'FRIBLEY': 0,
    'FRICAND': 0,
    'FRICANO': 0,
    'FRICCHIONE': 0,
    'FRICHTL': 0,
    'FRICK': 0,
    'FRICKE': 0,
    'FRICKEL': 0,
    'FRICKER': 0,
    'FRICKEY': 0,
    'FRICKS': 0,
    'FRICKSON': 0,
    'FRID': 0,
    'FRIDA': 1,
    'FRIDAY': 0,
    'FRIDDELL': 0,
    'FRIDDLE': 0,
    'FRIDEL': 0,
    'FRIDELL': 0,
    'FRIDEN': 0,
    'FRIDENMAKER': 0,
    'FRIDERES': 0,
    'FRIDGE': 0,
    'FRIDGEN': 0,
    'FRIDIA': 0,
    'FRIDIE': 0,
    'FRIDINGER': 0,
    'FRIDLEY': 0,
    'FRIDLUND': 0,
    'FRIDMAN': 0,
    'FRIDRICH': 0,
    'FRIDY': 0,
    'FRIE': 0,
    'FRIEBE': 0,
    'FRIEBEL': 0,
    'FRIEBERG': 0,
    'FRIEBUS': 0,
    'FRIED': 0,
    'FRIEDA': 0.9958992384299942,
    'FRIEDBERG': 0,
    'FRIEDE': 0,
    'FRIEDECK': 0,
    'FRIEDEL': 0,
    'FRIEDELL': 0,
    'FRIEDEMANN': 0,
    'FRIEDEN': 0,
    'FRIEDENBERG': 0,
    'FRIEDENBERGER': 0,
    'FRIEDENTHAL': 0,
    'FRIEDER': 0,
    'FRIEDERICH': 0,
    'FRIEDERICHS': 0,
    'FRIEDERICK': 0,
    'FRIEDERS': 0,
    'FRIEDHEIM': 0,
    'FRIEDHOFF': 0,
    'FRIEDKIN': 0,
    'FRIEDL': 0,
    'FRIEDLAND': 0,
    'FRIEDLANDER': 0,
    'FRIEDLE': 0,
    'FRIEDLEIN': 0,
    'FRIEDLER': 0,
    'FRIEDLEY': 0,
    'FRIEDLI': 0,
    'FRIEDLINE': 0,
    'FRIEDLUND': 0,
    'FRIEDLY': 0,
    'FRIEDMAN': 0,
    'FRIEDMANN': 0,
    'FRIEDMEYER': 0,
    'FRIEDRICH': 0,
    'FRIEDRICHS': 0,
    'FRIEDRICHSEN': 0,
    'FRIEDRICK': 0,
    'FRIEDSON': 0,
    'FRIEDT': 0,
    'FRIEL': 0,
    'FRIELDS': 0,
    'FRIELER': 0,
    'FRIELING': 0,
    'FRIELLO': 0,
    'FRIELS': 0,
    'FRIEMAN': 0,
    'FRIEMEL': 0,
    'FRIEMOTH': 0,
    'FRIEND': 0,
    'FRIENDLY': 0,
    'FRIENDS': 0,
    'FRIENDSHUH': 0,
    'FRIER': 0,
    'FRIERDICH': 0,
    'FRIERI': 0,
    'FRIERMOOD': 0,
    'FRIERSON': 0,
    'FRIERY': 0,
    'FRIES': 0,
    'FRIESE': 0,
    'FRIESEL': 0,
    'FRIESEMA': 0,
    'FRIESEN': 0,
    'FRIESENHAHN': 0,
    'FRIESLAND': 0,
    'FRIESNER': 0,
    'FRIESON': 0,
    'FRIESS': 0,
    'FRIESSEN': 0,
    'FRIEST': 0,
    'FRIESTAD': 0,
    'FRIESTH': 0,
    'FRIESZ': 0,
    'FRIETAS': 0,
    'FRIETSCH': 0,
    'FRIETZE': 0,
    'FRIEZ': 0,
    'FRIEZE': 0,
    'FRIGA': 0,
    'FRIGAARD': 0,
    'FRIGERIO': 0,
    'FRIGGE': 0,
    'FRIGILLANA': 0,
    'FRIGO': 0,
    'FRIGON': 0,
    'FRIIS': 0,
    'FRILEY': 0,
    'FRILLING': 0,
    'FRILLMAN': 0,
    'FRILOT': 0,
    'FRILOUX': 0,
    'FRIMAN': 0,
    'FRIMEL': 0,
    'FRIMML': 0,
    'FRIMPONG': 0,
    'FRINDT': 0,
    'FRINGER': 0,
    'FRINGS': 0,
    'FRINK': 0,
    'FRINKS': 0,
    'FRINO': 0,
    'FRINT': 0,
    'FRINZI': 0,
    'FRIO': 0,
    'FRIOT': 0,
    'FRIOU': 0,
    'FRIPP': 0,
    'FRIS': 0,
    'FRISA': 0,
    'FRISBEE': 0,
    'FRISBEY': 0,
    'FRISBIE': 0,
    'FRISBY': 0,
    'FRISCH': 0,
    'FRISCHE': 0,
    'FRISCHER': 0,
    'FRISCHKNECHT': 0,
    'FRISCHKORN': 0,
    'FRISCHMAN': 0,
    'FRISCHMANN': 0,
    'FRISCIA': 0,
    'FRISCO': 0,
    'FRISELL': 0,
    'FRISELLA': 0,
    'FRISENDA': 0,
    'FRISH': 0,
    'FRISHBERG': 0,
    'FRISHKORN': 0,
    'FRISHMAN': 0,
    'FRISINA': 0,
    'FRISINGER': 0,
    'FRISK': 0,
    'FRISKE': 0,
    'FRISKEY': 0,
    'FRISOLI': 0,
    'FRISON': 0,
    'FRISONE': 0,
    'FRISQUE': 0,
    'FRISS': 0,
    'FRISSELL': 0,
    'FRISSORA': 0,
    'FRIST': 0,
    'FRISTAD': 0,
    'FRISTOE': 0,
    'FRISVOLD': 0,
    'FRISZ': 0,
    'FRITCH': 0,
    'FRITCHEN': 0,
    'FRITCHER': 0,
    'FRITCHEY': 0,
    'FRITCHIE': 0,
    'FRITCHLEY': 0,
    'FRITCHMAN': 0,
    'FRITEL': 0,
    'FRITH': 0,
    'FRITS': 0,
    'FRITSCH': 0,
    'FRITSCHE': 0,
    'FRITSCHER': 0,
    'FRITSCHI': 0,
    'FRITSCHLE': 0,
    'FRITTER': 0,
    'FRITTON': 0,
    'FRITTS': 0,
    'FRITZ': 0.3285870755750274,
    'FRITZE': 0,
    'FRITZEL': 0,
    'FRITZEN': 0,
    'FRITZGERALD': 0,
    'FRITZGES': 0,
    'FRITZINGER': 0,
    'FRITZKE': 0,
    'FRITZLER': 0,
    'FRITZSCHE': 0,
    'FRIX': 0,
    'FRIZ': 0,
    'FRIZELL': 0,
    'FRIZZELL': 0,
    'FRIZZELLE': 0,
    'FRIZZI': 0,
    'FRIZZLE': 0,
    'FRNKA': 0,
    'FROATS': 0,
    'FROBEL': 0,
    'FROBERG': 0,
    'FROBISH': 0,
    'FROCK': 0,
    'FRODERMAN': 0,
    'FRODGE': 0,
    'FRODL': 0,
    'FRODSHAM': 0,
    'FRODYMA': 0,
    'FROEBA': 0,
    'FROEBE': 0,
    'FROEBEL': 0,
    'FROEBER': 0,
    'FROEDGE': 0,
    'FROEHLE': 0,
    'FROEHLICH': 0,
    'FROEHLING': 0,
    'FROEHNER': 0,
    'FROELICH': 0,
    'FROELICHER': 0,
    'FROEMEL': 0,
    'FROEMKE': 0,
    'FROEMMING': 0,
    'FROERER': 0,
    'FROESCHLE': 0,
    'FROESE': 0,
    'FROGGATT': 0,
    'FROGGE': 0,
    'FROGNER': 0,
    'FROH': 0,
    'FROHARDT': 0,
    'FROHLICH': 0,
    'FROHLING': 0,
    'FROHM': 0,
    'FROHMADER': 0,
    'FROHMAN': 0,
    'FROHN': 0,
    'FROHNAPFEL': 0,
    'FROHNE': 0,
    'FROHNHOEFER': 0,
    'FROHNING': 0,
    'FROHOCK': 0,
    'FROHREICH': 0,
    'FROHRIEP': 0,
    'FROHWEIN': 0,
    'FROID': 0,
    'FROILAND': 0,
    'FROIO': 0,
    'FROISLAND': 0,
    'FROKE': 0,
    'FROLA': 0,
    'FROLAND': 0,
    'FROLICH': 0,
    'FROLIK': 0,
    'FROLING': 0,
    'FROLOV': 0,
    'FROM': 0,
    'FROMAL': 0,
    'FROMAN': 0,
    'FROMBACH': 0,
    'FROMBERG': 0,
    'FROMDAHL': 0,
    'FROME': 0,
    'FROMEL': 0,
    'FROMENT': 0,
    'FROMER': 0,
    'FROMETA': 0,
    'FROMHERZ': 0,
    'FROMHOLD': 0,
    'FROMKIN': 0,
    'FROMKNECHT': 0,
    'FROMM': 0,
    'FROMME': 0,
    'FROMMEL': 0,
    'FROMMELT': 0,
    'FROMMER': 0,
    'FROMMEYER': 0,
    'FROMOWITZ': 0,
    'FROMSON': 0,
    'FROMWILLER': 0,
    'FRON': 0,
    'FRONABARGER': 0,
    'FRONCE': 0,
    'FRONCEK': 0,
    'FRONCKOWIAK': 0,
    'FRONCZAK': 0,
    'FRONCZEK': 0,
    'FRONDA': 0,
    'FRONDORF': 0,
    'FRONEBERGER': 0,
    'FRONEK': 0,
    'FRONGILLO': 0,
    'FRONHEISER': 0,
    'FRONING': 0,
    'FRONIUS': 0,
    'FRONK': 0,
    'FRONT': 0,
    'FRONTCZAK': 0,
    'FRONTE': 0,
    'FRONTERA': 0,
    'FRONTERHOUSE': 0,
    'FRONTIERA': 0,
    'FRONTIERO': 0,
    'FRONTINO': 0,
    'FRONTZ': 0,
    'FRONZAGLIO': 0,
    'FROOM': 0,
    'FROSCH': 0,
    'FROSCHAUER': 0,
    'FROSETH': 0,
    'FROSH': 0,
    'FROSOLONE': 0,
    'FROSS': 0,
    'FROSSARD': 0,
    'FROST': 0,
    'FROSTAD': 0,
    'FROSTER': 0,
    'FROSTICK': 0,
    'FROTHINGHAM': 0,
    'FROTTEN': 0,
    'FROUDE': 0,
    'FROULA': 0,
    'FROUNFELTER': 0,
    'FROVARP': 0,
    'FROWNER': 0,
    'FROWNFELTER': 0,
    'FROYD': 0,
    'FRUCCI': 0,
    'FRUCHEY': 0,
    'FRUCHT': 0,
    'FRUCHTER': 0,
    'FRUCHTMAN': 0,
    'FRUCHTNICHT': 0,
    'FRUCI': 0,
    'FRUCIANO': 0,
    'FRUECHTE': 0,
    'FRUEH': 0,
    'FRUEHAN': 0,
    'FRUEHAUF': 0,
    'FRUEHLING': 0,
    'FRUEN': 0,
    'FRUEND': 0,
    'FRUENDT': 0,
    'FRUETEL': 0,
    'FRUGE': 0,
    'FRUGOLI': 0,
    'FRUH': 0,
    'FRUHLING': 0,
    'FRUHWIRTH': 0,
    'FRUIN': 0,
    'FRUIT': 0,
    'FRUITS': 0,
    'FRUITT': 0,
    'FRULLA': 0,
    'FRUM': 0,
    'FRUMAN': 0,
    'FRUMENTO': 0,
    'FRUMIN': 0,
    'FRUMKIN': 0,
    'FRUMP': 0,
    'FRUNZI': 0,
    'FRUSCELLA': 0,
    'FRUSCIANTE': 0,
    'FRUSCIONE': 0,
    'FRUSH': 0,
    'FRUSHER': 0,
    'FRUSHON': 0,
    'FRUSHOUR': 0,
    'FRUSTACI': 0,
    'FRUSTER': 0,
    'FRUTCHEY': 0,
    'FRUTH': 0,
    'FRUTIGER': 0,
    'FRUTIS': 0,
    'FRUTO': 0,
    'FRUTOS': 0,
    'FRUZZETTI': 0,
    'FRY': 0,
    'FRYAR': 0,
    'FRYATT': 0,
    'FRYBACK': 0,
    'FRYBARGER': 0,
    'FRYBERG': 0,
    'FRYBERGER': 0,
    'FRYC': 0,
    'FRYDA': 0,
    'FRYDENDALL': 0,
    'FRYDENLUND': 0,
    'FRYDMAN': 0,
    'FRYDRYCH': 0,
    'FRYE': 0,
    'FRYER': 0,
    'FRYFOGLE': 0,
    'FRYHOVER': 0,
    'FRYKHOLM': 0,
    'FRYKMAN': 0,
    'FRYLING': 0,
    'FRYMAN': 0,
    'FRYMARK': 0,
    'FRYMIER': 0,
    'FRYMIRE': 0,
    'FRYMOYER': 0,
    'FRYMYER': 0,
    'FRYOU': 0,
    'FRYREAR': 0,
    'FRYS': 0,
    'FRYSINGER': 0,
    'FRYSLIE': 0,
    'FRYSON': 0,
    'FRYSTAK': 0,
    'FRYXELL': 0,
    'FRYZEL': 0,
    'FU': 0,
    'FUA': 0,
    'FUCA': 0,
    'FUCARINO': 0,
    'FUCCI': 0,
    'FUCCILLO': 0,
    'FUCHIGAMI': 0,
    'FUCHS': 0,
    'FUCHSER': 0,
    'FUCIK': 0,
    'FUCILE': 0,
    'FUCILLO': 0,
    'FUCITO': 0,
    'FUDA': 0,
    'FUDACZ': 0,
    'FUDALA': 0,
    'FUDALI': 0,
    'FUDE': 0,
    'FUDGE': 0,
    'FUEGER': 0,
    'FUEHNE': 0,
    'FUEHRER': 0,
    'FUEHRING': 0,
    'FUEL': 0,
    'FUELL': 0,
    'FUELLER': 0,
    'FUELLING': 0,
    'FUEMMELER': 0,
    'FUENMAYOR': 0,
    'FUENTAS': 0,
    'FUENTE': 0,
    'FUENTES': 0,
    'FUENTEZ': 0,
    'FUENZALIDA': 0,
    'FUERST': 0,
    'FUERSTENAU': 0,
    'FUERSTENBERG': 0,
    'FUERTE': 0,
    'FUERTES': 0,
    'FUERY': 0,
    'FUESS': 0,
    'FUESSEL': 0,
    'FUESTING': 0,
    'FUESTON': 0,
    'FUGA': 0,
    'FUGAL': 0,
    'FUGARINO': 0,
    'FUGATE': 0,
    'FUGATT': 0,
    'FUGAZZI': 0,
    'FUGE': 0,
    'FUGEL': 0,
    'FUGER': 0,
    'FUGERE': 0,
    'FUGET': 0,
    'FUGETT': 0,
    'FUGGER': 0,
    'FUGH': 0,
    'FUGIEL': 0,
    'FUGINA': 0,
    'FUGIT': 0,
    'FUGITT': 0,
    'FUGLE': 0,
    'FUGLEBERG': 0,
    'FUGLER': 0,
    'FUGLESTAD': 0,
    'FUGLSANG': 0,
    'FUGMAN': 0,
    'FUGUA': 0,
    'FUHER': 0,
    'FUHLER': 0,
    'FUHR': 0,
    'FUHRER': 0,
    'FUHRIMAN': 0,
    'FUHRMAN': 0,
    'FUHRMANN': 0,
    'FUHRMEISTER': 0,
    'FUHRY': 0,
    'FUHS': 0,
    'FUIAVA': 0,
    'FUIMAONO': 0,
    'FUITEN': 0,
    'FUJA': 0,
    'FUJAN': 0,
    'FUJIHARA': 0,
    'FUJII': 0,
    'FUJIKAWA': 0,
    'FUJIKI': 0,
    'FUJIMORI': 0,
    'FUJIMOTO': 0,
    'FUJIMURA': 0,
    'FUJINAGA': 0,
    'FUJINAKA': 0,
    'FUJINAMI': 0,
    'FUJINO': 0,
    'FUJIOKA': 0,
    'FUJISAKI': 0,
    'FUJISAWA': 0,
    'FUJISHIGE': 0,
    'FUJITA': 0,
    'FUJITANI': 0,
    'FUJIWARA': 0,
    'FUJIYAMA': 0,
    'FUKA': 0,
    'FUKAI': 0,
    'FUKS': 0,
    'FUKSA': 0,
    'FUKSMAN': 0,
    'FUKUCHI': 0,
    'FUKUDA': 0,
    'FUKUHARA': 0,
    'FUKUI': 0,
    'FUKUMITSU': 0,
    'FUKUMOTO': 0,
    'FUKUNAGA': 0,
    'FUKUOKA': 0,
    'FUKUSHIMA': 0,
    'FUKUTOMI': 0,
    'FUKUYAMA': 0,
    'FUKUZAWA': 0,
    'FULARA': 0,
    'FULBRIGHT': 0,
    'FULCE': 0,
    'FULCER': 0,
    'FULCHER': 0,
    'FULCINITI': 0,
    'FULCO': 0,
    'FULCOMER': 0,
    'FULD': 0,
    'FULDA': 0,
    'FULENWIDER': 0,
    'FULFER': 0,
    'FULFORD': 0,
    'FULFS': 0,
    'FULGENCIO': 0,
    'FULGENZI': 0,
    'FULGER': 0,
    'FULGHAM': 0,
    'FULGHUM': 0,
    'FULGIERI': 0,
    'FULGINITI': 0,
    'FULGONI': 0,
    'FULHAM': 0,
    'FULINARA': 0,
    'FULK': 0,
    'FULKER': 0,
    'FULKERSON': 0,
    'FULKROD': 0,
    'FULKS': 0,
    'FULL': 0,
    'FULLAGAR': 0,
    'FULLAM': 0,
    'FULLAN': 0,
    'FULLARD': 0,
    'FULLBRIGHT': 0,
    'FULLE': 0,
    'FULLEM': 0,
    'FULLEN': 0,
    'FULLENKAMP': 0,
    'FULLENWIDER': 0,
    'FULLER': 0,
    'FULLERTON': 0,
    'FULLHART': 0,
    'FULLICK': 0,
    'FULLILOVE': 0,
    'FULLING': 0,
    'FULLINGIM': 0,
    'FULLINGTON': 0,
    'FULLMAN': 0,
    'FULLMER': 0,
    'FULLMORE': 0,
    'FULLNER': 0,
    'FULLONE': 0,
    'FULLOVE': 0,
    'FULLUM': 0,
    'FULLWOOD': 0,
    'FULMER': 0,
    'FULMORE': 0,
    'FULNER': 0,
    'FULOP': 0,
    'FULP': 0,
    'FULPER': 0,
    'FULPS': 0,
    'FULS': 0,
    'FULSE': 0,
    'FULSOM': 0,
    'FULSON': 0,
    'FULTINEER': 0,
    'FULTON': 0,
    'FULTS': 0,
    'FULTZ': 0,
    'FULWIDER': 0,
    'FULWILER': 0,
    'FULWILEY': 0,
    'FULWOOD': 0,
    'FUMAGALLI': 0,
    'FUMANTI': 0,
    'FUMAROLA': 0,
    'FUMERO': 0,
    'FUMIA': 0,
    'FUMICH': 0,
    'FUMIKO': 1,
    'FUMO': 0,
    'FUN': 0,
    'FUNAI': 0,
    'FUNAKI': 0,
    'FUNAKOSHI': 0,
    'FUNARI': 0,
    'FUNARO': 0,
    'FUNCH': 0,
    'FUNCHEON': 0,
    'FUNCHES': 0,
    'FUNCHESS': 0,
    'FUNCHION': 0,
    'FUNCK': 0,
    'FUND': 0,
    'FUNDARO': 0,
    'FUNDERBURG': 0,
    'FUNDERBURGH': 0,
    'FUNDERBURK': 0,
    'FUNDERBURKE': 0,
    'FUNDINGSLAND': 0,
    'FUNDIS': 0,
    'FUNDORA': 0,
    'FUNE': 0,
    'FUNES': 0,
    'FUNEZ': 0,
    'FUNG': 0,
    'FUNICELLI': 0,
    'FUNICELLO': 0,
    'FUNK': 0,
    'FUNKE': 0,
    'FUNKHOUSER': 0,
    'FUNMAKER': 0,
    'FUNN': 0,
    'FUNNELL': 0,
    'FUNNEMAN': 0,
    'FUNNY': 0,
    'FUNNYE': 0,
    'FUNSCH': 0,
    'FUNSETH': 0,
    'FUNSTEN': 0,
    'FUNSTON': 0,
    'FUNT': 0,
    'FUNTANILLA': 0,
    'FUNTES': 0,
    'FUNYAK': 0,
    'FUOCO': 0,
    'FUOSS': 0,
    'FUQUA': 0,
    'FUQUAY': 0,
    'FURA': 0,
    'FURAN': 0,
    'FURANO': 0,
    'FURAY': 0,
    'FURBAY': 0,
    'FURBECK': 0,
    'FURBEE': 0,
    'FURBER': 0,
    'FURBISH': 0,
    'FURBUSH': 0,
    'FURBY': 0,
    'FURCA': 0,
    'FURCH': 0,
    'FURCHAK': 0,
    'FURCHES': 0,
    'FURCHNER': 0,
    'FURCI': 0,
    'FURCO': 0,
    'FURCRON': 0,
    'FURDA': 0,
    'FURE': 0,
    'FURER': 0,
    'FUREY': 0,
    'FURFARI': 0,
    'FURFARO': 0,
    'FURGAL': 0,
    'FURGASON': 0,
    'FURGERSON': 0,
    'FURGESON': 0,
    'FURGISON': 0,
    'FURGIUELE': 0,
    'FURIA': 0,
    'FURIE': 0,
    'FURIN': 0,
    'FURINO': 0,
    'FURIO': 0,
    'FURJANIC': 0,
    'FURKA': 0,
    'FURKIN': 0,
    'FURL': 0,
    'FURLAN': 0,
    'FURLAND': 0,
    'FURLANI': 0,
    'FURLANO': 0,
    'FURLER': 0,
    'FURLEY': 0,
    'FURLIN': 0,
    'FURLINE': 0,
    'FURLO': 0,
    'FURLONG': 0,
    'FURLOUGH': 0,
    'FURLOW': 0,
    'FURMAGE': 0,
    'FURMAN': 0,
    'FURMANEK': 0,
    'FURMANSKI': 0,
    'FURNACE': 0,
    'FURNALD': 0,
    'FURNARI': 0,
    'FURNAS': 0,
    'FURNE': 0,
    'FURNEAUX': 0,
    'FURNELL': 0,
    'FURNER': 0,
    'FURNESS': 0,
    'FURNEY': 0,
    'FURNIA': 0,
    'FURNIER': 0,
    'FURNISH': 0,
    'FURNISS': 0,
    'FURNIVAL': 0,
    'FURNO': 0,
    'FURO': 0,
    'FURPHY': 0,
    'FURQUERON': 0,
    'FURR': 0,
    'FURRER': 0,
    'FURREY': 0,
    'FURRH': 0,
    'FURRIER': 0,
    'FURROW': 0,
    'FURRY': 0,
    'FURSE': 0,
    'FURSETH': 0,
    'FURST': 0,
    'FURSTENAU': 0,
    'FURSTENBERG': 0,
    'FURTADO': 0,
    'FURTAH': 0,
    'FURTAK': 0,
    'FURTAW': 0,
    'FURTEK': 0,
    'FURTH': 0,
    'FURTICK': 0,
    'FURTNEY': 0,
    'FURTON': 0,
    'FURUKAWA': 0,
    'FURUMOTO': 0,
    'FURUSHO': 0,
    'FURUTA': 0,
    'FURUTANI': 0,
    'FURUYA': 0,
    'FURUYAMA': 0,
    'FURY': 0,
    'FURZE': 0,
    'FUS': 0,
    'FUSARD': 0,
    'FUSARI': 0,
    'FUSARO': 0,
    'FUSCA': 0,
    'FUSCALDO': 0,
    'FUSCHETTI': 0,
    'FUSCHETTO': 0,
    'FUSCHINO': 0,
    'FUSCO': 0,
    'FUSE': 0,
    'FUSEK': 0,
    'FUSELIER': 0,
    'FUSI': 0,
    'FUSILIER': 0,
    'FUSILLI': 0,
    'FUSILLO': 0,
    'FUSNER': 0,
    'FUSON': 0,
    'FUSS': 0,
    'FUSSELL': 0,
    'FUSSELMAN': 0,
    'FUSSNECKER': 0,
    'FUSSNER': 0,
    'FUSSY': 0,
    'FUST': 0,
    'FUSTE': 0,
    'FUSTER': 0,
    'FUSTING': 0,
    'FUSTON': 0,
    'FUSTOS': 0,
    'FUTA': 0,
    'FUTCH': 0,
    'FUTCHER': 0,
    'FUTCHKO': 0,
    'FUTERMAN': 0,
    'FUTEY': 0,
    'FUTHEY': 0,
    'FUTIA': 0,
    'FUTO': 0,
    'FUTRAL': 0,
    'FUTRELL': 0,
    'FUTRELLE': 0,
    'FUTSCHER': 0,
    'FUTTER': 0,
    'FUTTERER': 0,
    'FUTTERMAN': 0,
    'FUTTY': 0,
    'FUXA': 0,
    'FUZAYLOV': 0,
    'FUZI': 0,
    'FUZY': 0,
    'FUZZELL': 0,
    'FYALL': 0,
    'FYAN': 0,
    'FYDA': 0,
    'FYE': 0,
    'FYFE': 0,
    'FYFFE': 0,
    'FYKE': 0,
    'FYKES': 0,
    'FYLE': 0,
    'FYLER': 0,
    'FYLES': 0,
    'FYLSTRA': 0,
    'FYNES': 0,
    'FYNN': 0,
    'FYOCK': 0,
    'FYTEN': 0,
    'FYVIE': 0,
    'GA': 0,
    'GAA': 0,
    'GAAB': 0,
    'GAAL': 0,
    'GAALSWYK': 0,
    'GAAR': 0,
    'GAARD': 0,
    'GAARDER': 0,
    'GAARE': 0,
    'GAAS': 0,
    'GAASCH': 0,
    'GAB': 0,
    'GABA': 0,
    'GABAI': 0,
    'GABALDON': 0,
    'GABANY': 0,
    'GABARDI': 0,
    'GABAREE': 0,
    'GABAUER': 0,
    'GABAY': 0,
    'GABB': 0,
    'GABBARD': 0,
    'GABBART': 0,
    'GABBAY': 0,
    'GABBERT': 0,
    'GABBEY': 0,
    'GABBIDON': 0,
    'GABBITAS': 0,
    'GABBY': 0,
    'GABE': 0,
    'GABEHART': 0,
    'GABEL': 0,
    'GABELE': 0,
    'GABELLA': 0,
    'GABELMAN': 0,
    'GABELMANN': 0,
    'GABER': 0,
    'GABERT': 0,
    'GABET': 0,
    'GABHART': 0,
    'GABIN': 0,
    'GABINO': 0,
    'GABIOLA': 0,
    'GABIS': 0,
    'GABLE': 0,
    'GABLER': 0,
    'GABLES': 0,
    'GABOR': 0,
    'GABORIAULT': 0,
    'GABOS': 0,
    'GABOUREL': 0,
    'GABOURY': 0,
    'GABR': 0,
    'GABRA': 0,
    'GABREE': 0,
    'GABREL': 0,
    'GABRELCIK': 0,
    'GABRI': 0,
    'GABRICK': 0,
    'GABRIEL': 0.903041825095057,
    'GABRIELA': 1,
    'GABRIELE': 0.7194244604316546,
    'GABRIELIAN': 0,
    'GABRIELLA': 0.9881422924901185,
    'GABRIELLE': 0.9912536443148687,
    'GABRIELLI': 0,
    'GABRIELS': 0,
    'GABRIELSE': 0,
    'GABRIELSEN': 0,
    'GABRIELSON': 0,
    'GABRIELYAN': 0,
    'GABRILLO': 0,
    'GABRIS': 0,
    'GABRISH': 0,
    'GABRYS': 0,
    'GABRYSCH': 0,
    'GABRYSIAK': 0,
    'GABY': 0,
    'GAC': 0,
    'GACA': 0,
    'GACAD': 0,
    'GACAYAN': 0,
    'GACCETTA': 0,
    'GACCIONE': 0,
    'GACEK': 0,
    'GACH': 0,
    'GACHASSIN': 0,
    'GACHES': 0,
    'GACHETTE': 0,
    'GACHUPIN': 0,
    'GACIA': 0,
    'GACIOCH': 0,
    'GACK': 0,
    'GACKE': 0,
    'GACKI': 0,
    'GACKLE': 0,
    'GACKOWSKI': 0,
    'GACKSTETTER': 0,
    'GACULA': 0,
    'GACUSAN': 0,
    'GACUTAN': 0,
    'GAD': 0,
    'GADA': 0,
    'GADACZ': 0,
    'GADALETA': 0,
    'GADALLA': 0,
    'GADBAW': 0,
    'GADBERRY': 0,
    'GADBOIS': 0,
    'GADBURY': 0,
    'GADD': 0,
    'GADDAM': 0,
    'GADDE': 0,
    'GADDES': 0,
    'GADDI': 0,
    'GADDIE': 0,
    'GADDINI': 0,
    'GADDIS': 0,
    'GADDISON': 0,
    'GADDIST': 0,
    'GADDY': 0,
    'GADE': 0,
    'GADEA': 0,
    'GADEK': 0,
    'GADEKEN': 0,
    'GADEN': 0,
    'GADES': 0,
    'GADHIA': 0,
    'GADIA': 0,
    'GADIENT': 0,
    'GADISON': 0,
    'GADKE': 0,
    'GADLEY': 0,
    'GADLIN': 0,
    'GADOLA': 0,
    'GADOMSKI': 0,
    'GADOUA': 0,
    'GADOURY': 0,
    'GADOW': 0,
    'GADSBY': 0,
    'GADSDEN': 0,
    'GADSEN': 0,
    'GADSON': 0,
    'GADUE': 0,
    'GADUS': 0,
    'GADWA': 0,
    'GADWAH': 0,
    'GADWAY': 0,
    'GADY': 0,
    'GADZIALA': 0,
    'GADZINSKI': 0,
    'GAEBE': 0,
    'GAEBEL': 0,
    'GAEBLER': 0,
    'GAEDDERT': 0,
    'GAEDE': 0,
    'GAEDKE': 0,
    'GAEDTKE': 0,
    'GAEKE': 0,
    'GAENZLE': 0,
    'GAER': 0,
    'GAERKE': 0,
    'GAERLAN': 0,
    'GAERTE': 0,
    'GAERTNER': 0,
    'GAESSER': 0,
    'GAESTEL': 0,
    'GAETA': 0,
    'GAETAN': 0,
    'GAETANI': 0,
    'GAETANO': 0,
    'GAETE': 0,
    'GAETH': 0,
    'GAETJENS': 0,
    'GAETKE': 0,
    'GAETO': 0,
    'GAETZ': 0,
    'GAFA': 0,
    'GAFF': 0,
    'GAFFANEY': 0,
    'GAFFAR': 0,
    'GAFFEN': 0,
    'GAFFER': 0,
    'GAFFEY': 0,
    'GAFFIELD': 0,
    'GAFFIGAN': 0,
    'GAFFIN': 0,
    'GAFFKE': 0,
    'GAFFNER': 0,
    'GAFFNEY': 0,
    'GAFFORD': 0,
    'GAFFREY': 0,
    'GAFFRON': 0,
    'GAFKJEN': 0,
    'GAFNER': 0,
    'GAFNEY': 0,
    'GAFUR': 0,
    'GAG': 0,
    'GAGAN': 0,
    'GAGARIN': 0,
    'GAGAS': 0,
    'GAGE': 0,
    'GAGEBY': 0,
    'GAGEL': 0,
    'GAGEN': 0,
    'GAGER': 0,
    'GAGGINI': 0,
    'GAGHAN': 0,
    'GAGICH': 0,
    'GAGLE': 0,
    'GAGLIA': 0,
    'GAGLIANO': 0,
    'GAGLIARDI': 0,
    'GAGLIARDO': 0,
    'GAGLIO': 0,
    'GAGLIONE': 0,
    'GAGLIOTI': 0,
    'GAGNARD': 0,
    'GAGNE': 0,
    'GAGNEBIN': 0,
    'GAGNER': 0,
    'GAGNET': 0,
    'GAGNIER': 0,
    'GAGNON': 0,
    'GAGO': 0,
    'GAGON': 0,
    'GAGUM': 0,
    'GAHAFER': 0,
    'GAHAGAN': 0,
    'GAHAGEN': 0,
    'GAHAN': 0,
    'GAHART': 0,
    'GAHERTY': 0,
    'GAHIMER': 0,
    'GAHL': 0,
    'GAHLER': 0,
    'GAHM': 0,
    'GAHMAN': 0,
    'GAHN': 0,
    'GAHR': 0,
    'GAHRING': 0,
    'GAI': 0,
    'GAIA': 0,
    'GAIDA': 0,
    'GAIDE': 0,
    'GAIDO': 0,
    'GAIDOS': 0,
    'GAIENNIE': 0,
    'GAIER': 0,
    'GAIETTO': 0,
    'GAIGE': 0,
    'GAII': 0,
    'GAIK': 0,
    'GAIKOWSKI': 0,
    'GAIL': 0.9972262580900806,
    'GAILBREATH': 0,
    'GAILE': 0,
    'GAILES': 0,
    'GAILEY': 0,
    'GAILLARD': 0,
    'GAILLIARD': 0,
    'GAILOR': 0,
    'GAIMARI': 0,
    'GAIN': 0,
    'GAINE': 0,
    'GAINER': 0,
    'GAINES': 0,
    'GAINEY': 0,
    'GAINOR': 0,
    'GAINOUS': 0,
    'GAINS': 0,
    'GAINZA': 0,
    'GAIR': 0,
    'GAISER': 0,
    'GAISFORD': 0,
    'GAISSER': 0,
    'GAISSERT': 0,
    'GAITA': 0,
    'GAITAN': 0,
    'GAITENS': 0,
    'GAITER': 0,
    'GAITERS': 0,
    'GAITHER': 0,
    'GAITLEY': 0,
    'GAITO': 0,
    'GAITOR': 0,
    'GAJ': 0,
    'GAJADHAR': 0,
    'GAJAN': 0,
    'GAJARDO': 0,
    'GAJDA': 0,
    'GAJDOS': 0,
    'GAJDOSIK': 0,
    'GAJESKI': 0,
    'GAJEWSKI': 0,
    'GAJIC': 0,
    'GAJJAR': 0,
    'GAJKOWSKI': 0,
    'GAL': 0,
    'GALA': 0.7352941176470589,
    'GALAL': 0,
    'GALAM': 0,
    'GALAMBOS': 0,
    'GALAN': 0,
    'GALANEK': 0,
    'GALANES': 0,
    'GALANG': 0,
    'GALANIS': 0,
    'GALANO': 0,
    'GALANOPOULOS': 0,
    'GALANOS': 0,
    'GALANT': 0,
    'GALANTE': 0,
    'GALANTER': 0,
    'GALANTI': 0,
    'GALANTO': 0,
    'GALANTY': 0,
    'GALAPON': 0,
    'GALARCE': 0,
    'GALARDI': 0,
    'GALARDO': 0,
    'GALARNEAU': 0,
    'GALARRAGA': 0,
    'GALARSA': 0,
    'GALARZA': 0,
    'GALAS': 0,
    'GALASKA': 0,
    'GALASSI': 0,
    'GALASSINI': 0,
    'GALASSO': 0,
    'GALASZEWSKI': 0,
    'GALAT': 0,
    'GALATA': 0,
    'GALATAS': 0,
    'GALATI': 0,
    'GALATIOTO': 0,
    'GALATIS': 0,
    'GALATRO': 0,
    'GALAVIS': 0,
    'GALAVIZ': 0,
    'GALAWAY': 0,
    'GALAY': 0,
    'GALAYDA': 0,
    'GALAZ': 0,
    'GALAZIN': 0,
    'GALAZKA': 0,
    'GALBA': 0,
    'GALBAN': 0,
    'GALBAVY': 0,
    'GALBERT': 0,
    'GALBERTH': 0,
    'GALBEZ': 0,
    'GALBO': 0,
    'GALBRAITH': 0,
    'GALBREATH': 0,
    'GALBRECHT': 0,
    'GALBRETH': 0,
    'GALCERAN': 0,
    'GALCZYNSKI': 0,
    'GALD': 0,
    'GALDA': 0,
    'GALDAMES': 0,
    'GALDAMEZ': 0,
    'GALDE': 0,
    'GALDEANO': 0,
    'GALDES': 0,
    'GALDI': 0,
    'GALDIERI': 0,
    'GALDO': 0,
    'GALDONES': 0,
    'GALDOS': 0,
    'GALE': 0.809989875126561,
    'GALEA': 0,
    'GALEAI': 0,
    'GALEANA': 0,
    'GALEANO': 0,
    'GALEAS': 0,
    'GALEAZZI': 0,
    'GALECKI': 0,
    'GALEENER': 0,
    'GALEGO': 0,
    'GALEHOUSE': 0,
    'GALEK': 0,
    'GALELLA': 0,
    'GALEMORE': 0,
    'GALEN': 0.9729729729729729,
    'GALENA': 0,
    'GALENO': 0,
    'GALENS': 0,
    'GALENSKI': 0,
    'GALENTINE': 0,
    'GALEONE': 0,
    'GALEOTA': 0,
    'GALEOTTI': 0,
    'GALER': 0,
    'GALERA': 0,
    'GALES': 0,
    'GALESKI': 0,
    'GALETKA': 0,
    'GALETTA': 0,
    'GALETTE': 0,
    'GALETTI': 0,
    'GALETTO': 0,
    'GALEWSKI': 0,
    'GALEY': 0,
    'GALFANO': 0,
    'GALFO': 0,
    'GALFORD': 0,
    'GALGAN': 0,
    'GALGANO': 0,
    'GALGON': 0,
    'GALI': 0,
    'GALIA': 0,
    'GALIANA': 0,
    'GALIANO': 0,
    'GALIARDI': 0,
    'GALIARDO': 0,
    'GALIATSATOS': 0,
    'GALIC': 0,
    'GALICA': 0,
    'GALICH': 0,
    'GALICIA': 0,
    'GALICINAO': 0,
    'GALICK': 0,
    'GALICKI': 0,
    'GALIDO': 0,
    'GALIE': 0,
    'GALIETTA': 0,
    'GALIETTI': 0,
    'GALIGHER': 0,
    'GALIHER': 0,
    'GALIK': 0,
    'GALIMA': 0,
    'GALIMBA': 0,
    'GALIMI': 0,
    'GALIMORE': 0,
    'GALIN': 0,
    'GALINA': 0.9433962264150944,
    'GALINAT': 0,
    'GALINATO': 0,
    'GALINDEZ': 0,
    'GALINDO': 0,
    'GALINIS': 0,
    'GALINO': 0,
    'GALINSKI': 0,
    'GALINSKY': 0,
    'GALIONE': 0,
    'GALIOTO': 0,
    'GALIPEAU': 0,
    'GALIPO': 0,
    'GALIS': 0,
    'GALIT': 0,
    'GALITZ': 0,
    'GALIVAN': 0,
    'GALIZA': 0,
    'GALIZIA': 0,
    'GALIZIO': 0,
    'GALJOUR': 0,
    'GALKA': 0,
    'GALKIN': 0,
    'GALKO': 0,
    'GALKOWSKI': 0,
    'GALL': 0,
    'GALLA': 0,
    'GALLACHER': 0,
    'GALLAGA': 0,
    'GALLAGHER': 0,
    'GALLAGOS': 0,
    'GALLAHAN': 0,
    'GALLAHAR': 0,
    'GALLAHER': 0,
    'GALLAHUE': 0,
    'GALLAMORE': 0,
    'GALLAN': 0,
    'GALLAND': 0,
    'GALLANDER': 0,
    'GALLANT': 0,
    'GALLARD': 0,
    'GALLARDO': 0,
    'GALLARO': 0,
    'GALLART': 0,
    'GALLARZO': 0,
    'GALLAS': 0,
    'GALLASHAW': 0,
    'GALLASPY': 0,
    'GALLATI': 0,
    'GALLATIN': 0,
    'GALLATY': 0,
    'GALLAUGHER': 0,
    'GALLAWAY': 0,
    'GALLAY': 0,
    'GALLE': 0,
    'GALLEA': 0,
    'GALLEGLY': 0,
    'GALLEGO': 0,
    'GALLEGOS': 0,
    'GALLEHER': 0,
    'GALLELLI': 0,
    'GALLELLO': 0,
    'GALLEMORE': 0,
    'GALLEN': 0,
    'GALLENBERG': 0,
    'GALLENBERGER': 0,
    'GALLENSTEIN': 0,
    'GALLENTINE': 0,
    'GALLER': 0,
    'GALLERANI': 0,
    'GALLERT': 0,
    'GALLERY': 0,
    'GALLES': 0,
    'GALLESE': 0,
    'GALLET': 0,
    'GALLETLY': 0,
    'GALLETT': 0,
    'GALLETTA': 0,
    'GALLETTI': 0,
    'GALLETTO': 0,
    'GALLEY': 0,
    'GALLI': 0,
    'GALLIA': 0,
    'GALLIAN': 0,
    'GALLIANI': 0,
    'GALLIANO': 0,
    'GALLIART': 0,
    'GALLICCHIO': 0,
    'GALLICHIO': 0,
    'GALLICK': 0,
    'GALLIE': 0,
    'GALLIEN': 0,
    'GALLIER': 0,
    'GALLIFORD': 0,
    'GALLIGAN': 0,
    'GALLIGANI': 0,
    'GALLIGER': 0,
    'GALLIGHER': 0,
    'GALLIHER': 0,
    'GALLIHUGH': 0,
    'GALLIK': 0,
    'GALLIMORE': 0,
    'GALLIN': 0,
    'GALLINA': 0,
    'GALLINARO': 0,
    'GALLINAT': 0,
    'GALLINGER': 0,
    'GALLINGTON': 0,
    'GALLINI': 0,
    'GALLINO': 0,
    'GALLIO': 0,
    'GALLION': 0,
    'GALLIONE': 0,
    'GALLIPEAU': 0,
    'GALLIPO': 0,
    'GALLIPOLI': 0,
    'GALLIS': 0,
    'GALLISHAW': 0,
    'GALLISON': 0,
    'GALLITZ': 0,
    'GALLIVAN': 0,
    'GALLMAN': 0,
    'GALLMEIER': 0,
    'GALLMEYER': 0,
    'GALLMON': 0,
    'GALLO': 0,
    'GALLOB': 0,
    'GALLOGLY': 0,
    'GALLON': 0,
    'GALLONE': 0,
    'GALLONI': 0,
    'GALLOP': 0,
    'GALLOPS': 0,
    'GALLOS': 0,
    'GALLOSO': 0,
    'GALLOUP': 0,
    'GALLOW': 0,
    'GALLOWAY': 0,
    'GALLOZA': 0,
    'GALLUCCI': 0,
    'GALLUCCIO': 0,
    'GALLUP': 0,
    'GALLUPPI': 0,
    'GALLUPS': 0,
    'GALLUS': 0,
    'GALLUZZI': 0,
    'GALLUZZO': 0,
    'GALLWAY': 0,
    'GALLY': 0,
    'GALM': 0,
    'GALMAN': 0,
    'GALMICHE': 0,
    'GALMISH': 0,
    'GALMON': 0,
    'GALMORE': 0,
    'GALO': 0,
    'GALOFARO': 0,
    'GALON': 0,
    'GALONSKI': 0,
    'GALOR': 0,
    'GALOS': 0,
    'GALOTTI': 0,
    'GALOVIC': 0,
    'GALOVICH': 0,
    'GALOW': 0,
    'GALOWNIA': 0,
    'GALPER': 0,
    'GALPERIN': 0,
    'GALPERN': 0,
    'GALPIN': 0,
    'GALSTAD': 0,
    'GALSTER': 0,
    'GALSTIAN': 0,
    'GALSTON': 0,
    'GALSTYAN': 0,
    'GALT': 0,
    'GALTERIO': 0,
    'GALTIERI': 0,
    'GALTNEY': 0,
    'GALTON': 0,
    'GALUPPO': 0,
    'GALURA': 0,
    'GALUS': 0,
    'GALUSHA': 0,
    'GALUSKA': 0,
    'GALUSKI': 0,
    'GALUSZKA': 0,
    'GALVA': 0,
    'GALVAN': 0,
    'GALVANI': 0,
    'GALVANO': 0,
    'GALVAO': 0,
    'GALVES': 0,
    'GALVEZ': 0,
    'GALVIN': 0,
    'GALVIS': 0,
    'GALWAY': 0,
    'GALY': 0,
    'GALYA': 0,
    'GALYAN': 0,
    'GALYARDT': 0,
    'GALYEAN': 0,
    'GALYEN': 0,
    'GALYON': 0,
    'GALZERANO': 0,
    'GALZOTE': 0,
    'GAM': 0,
    'GAMA': 0,
    'GAMACHE': 0,
    'GAMAGE': 0,
    'GAMARRA': 0,
    'GAMARRO': 0,
    'GAMAS': 0,
    'GAMAUF': 0,
    'GAMBA': 0,
    'GAMBACCINI': 0,
    'GAMBACORTA': 0,
    'GAMBAL': 0,
    'GAMBALE': 0,
    'GAMBARDELLA': 0,
    'GAMBARO': 0,
    'GAMBATESE': 0,
    'GAMBEE': 0,
    'GAMBEL': 0,
    'GAMBELL': 0,
    'GAMBER': 0,
    'GAMBERG': 0,
    'GAMBERT': 0,
    'GAMBETTA': 0,
    'GAMBHIR': 0,
    'GAMBIE': 0,
    'GAMBILL': 0,
    'GAMBINA': 0,
    'GAMBINI': 0,
    'GAMBINO': 0,
    'GAMBLE': 0,
    'GAMBLER': 0,
    'GAMBLES': 0,
    'GAMBLIN': 0,
    'GAMBLING': 0,
    'GAMBO': 0,
    'GAMBOA': 0,
    'GAMBOL': 0,
    'GAMBON': 0,
    'GAMBONE': 0,
    'GAMBONI': 0,
    'GAMBREL': 0,
    'GAMBRELL': 0,
    'GAMBRILL': 0,
    'GAMBS': 0,
    'GAMBUCCI': 0,
    'GAMBUTI': 0,
    'GAMBUZZA': 0,
    'GAMBY': 0,
    'GAME': 0,
    'GAMEL': 0,
    'GAMELIN': 0,
    'GAMELLI': 0,
    'GAMER': 0,
    'GAMERDINGER': 0,
    'GAMERO': 0,
    'GAMEROS': 0,
    'GAMERTSFELDER': 0,
    'GAMES': 0,
    'GAMESTER': 0,
    'GAMET': 0,
    'GAMEWELL': 0,
    'GAMEZ': 0,
    'GAMIAO': 0,
    'GAMINO': 0,
    'GAMIZ': 0,
    'GAMLIN': 0,
    'GAMM': 0,
    'GAMMA': 0,
    'GAMMAGE': 0,
    'GAMMEL': 0,
    'GAMMELL': 0,
    'GAMMIE': 0,
    'GAMMILL': 0,
    'GAMMON': 0,
    'GAMMONS': 0,
    'GAMO': 0,
    'GAMON': 0,
    'GAMPEL': 0,
    'GAMPER': 0,
    'GAMPP': 0,
    'GAMRADT': 0,
    'GAMRAT': 0,
    'GAMROTH': 0,
    'GAMS': 0,
    'GAMSBY': 0,
    'GAMSON': 0,
    'GAMWELL': 0,
    'GAN': 0,
    'GANA': 0,
    'GANADEN': 0,
    'GANADONEGRO': 0,
    'GANAHL': 0,
    'GANAL': 0,
    'GANAN': 0,
    'GANAPATHY': 0,
    'GANAS': 0,
    'GANATRA': 0,
    'GANAWAY': 0,
    'GANBOA': 0,
    'GANCARZ': 0,
    'GANCE': 0,
    'GANCEDO': 0,
    'GANCI': 0,
    'GANDA': 0,
    'GANDARA': 0,
    'GANDARIA': 0,
    'GANDARILLA': 0,
    'GANDARILLAS': 0,
    'GANDE': 0,
    'GANDEE': 0,
    'GANDEL': 0,
    'GANDELMAN': 0,
    'GANDER': 0,
    'GANDERT': 0,
    'GANDEZA': 0,
    'GANDHI': 0,
    'GANDIA': 0,
    'GANDINI': 0,
    'GANDOLFI': 0,
    'GANDOLFO': 0,
    'GANDRE': 0,
    'GANDRUD': 0,
    'GANDT': 0,
    'GANDY': 0,
    'GANE': 0,
    'GANELES': 0,
    'GANEM': 0,
    'GANER': 0,
    'GANES': 0,
    'GANESAN': 0,
    'GANESH': 0,
    'GANEY': 0,
    'GANFIELD': 0,
    'GANG': 0,
    'GANGA': 0,
    'GANGALE': 0,
    'GANGARAM': 0,
    'GANGE': 0,
    'GANGEL': 0,
    'GANGELHOFF': 0,
    'GANGEMI': 0,
    'GANGER': 0,
    'GANGES': 0,
    'GANGESTAD': 0,
    'GANGI': 0,
    'GANGITANO': 0,
    'GANGL': 0,
    'GANGLE': 0,
    'GANGLER': 0,
    'GANGLOFF': 0,
    'GANGLUFF': 0,
    'GANGONE': 0,
    'GANGOPADHYAY': 0,
    'GANGSTAD': 0,
    'GANGULI': 0,
    'GANGULY': 0,
    'GANGWER': 0,
    'GANGWISH': 0,
    'GANI': 0,
    'GANIC': 0,
    'GANIER': 0,
    'GANIERE': 0,
    'GANIM': 0,
    'GANIO': 0,
    'GANIR': 0,
    'GANIRON': 0,
    'GANIS': 0,
    'GANJE': 0,
    'GANJI': 0,
    'GANK': 0,
    'GANLEY': 0,
    'GANLY': 0,
    'GANN': 0,
    'GANNAWAY': 0,
    'GANNER': 0,
    'GANNETT': 0,
    'GANNON': 0,
    'GANNUSCIO': 0,
    'GANO': 0,
    'GANOE': 0,
    'GANON': 0,
    'GANONG': 0,
    'GANOS': 0,
    'GANOTE': 0,
    'GANOUNG': 0,
    'GANOW': 0,
    'GANOZA': 0,
    'GANPAT': 0,
    'GANS': 0,
    'GANSBERG': 0,
    'GANSCHOW': 0,
    'GANSE': 0,
    'GANSEL': 0,
    'GANSEMER': 0,
    'GANSEN': 0,
    'GANSER': 0,
    'GANSERT': 0,
    'GANSHIRT': 0,
    'GANSHORN': 0,
    'GANSKE': 0,
    'GANSKI': 0,
    'GANSKY': 0,
    'GANSLER': 0,
    'GANSMAN': 0,
    'GANSMANN': 0,
    'GANSON': 0,
    'GANSS': 0,
    'GANSSLE': 0,
    'GANSTER': 0,
    'GANSZ': 0,
    'GANT': 0,
    'GANTA': 0,
    'GANTE': 0,
    'GANTENBEIN': 0,
    'GANTER': 0,
    'GANTERT': 0,
    'GANTES': 0,
    'GANTHER': 0,
    'GANTHIER': 0,
    'GANTI': 0,
    'GANTMAN': 0,
    'GANTNER': 0,
    'GANTON': 0,
    'GANTOS': 0,
    'GANTS': 0,
    'GANTT': 0,
    'GANTZ': 0,
    'GANTZER': 0,
    'GANUCHEAU': 0,
    'GANUES': 0,
    'GANUN': 0,
    'GANUNG': 0,
    'GANUS': 0,
    'GANYARD': 0,
    'GANYO': 0,
    'GANZ': 0,
    'GANZALEZ': 0,
    'GANZE': 0,
    'GANZEL': 0,
    'GANZER': 0,
    'GANZHORN': 0,
    'GANZON': 0,
    'GANZY': 0,
    'GAO': 0,
    'GAOIRAN': 0,
    'GAON': 0,
    'GAONA': 0,
    'GAOUETTE': 0,
    'GAPASIN': 0,
    'GAPEN': 0,
    'GAPINSKI': 0,
    'GAPP': 0,
    'GAPPA': 0,
    'GAPPMAYER': 0,
    'GAPPY': 0,
    'GAPSKI': 0,
    'GAPUSAN': 0,
    'GAPUZ': 0,
    'GAR': 0,
    'GARA': 0,
    'GARABEDIAN': 0,
    'GARABITO': 0,
    'GARABRANDT': 0,
    'GARAFALO': 0,
    'GARAFANO': 0,
    'GARAFFA': 0,
    'GARAFOLA': 0,
    'GARAFOLO': 0,
    'GARAI': 0,
    'GARALDE': 0,
    'GARAMELLA': 0,
    'GARAN': 0,
    'GARAND': 0,
    'GARANT': 0,
    'GARANZUAY': 0,
    'GARARD': 0,
    'GARAS': 0,
    'GARASCIA': 0,
    'GARATE': 0,
    'GARAVAGLIA': 0,
    'GARAVALIA': 0,
    'GARAVENTA': 0,
    'GARAVITO': 0,
    'GARAY': 0,
    'GARB': 0,
    'GARBA': 0,
    'GARBACIK': 0,
    'GARBACK': 0,
    'GARBACZ': 0,
    'GARBADE': 0,
    'GARBAN': 0,
    'GARBARINI': 0,
    'GARBARINO': 0,
    'GARBART': 0,
    'GARBE': 0,
    'GARBEE': 0,
    'GARBER': 0,
    'GARBERA': 0,
    'GARBERDING': 0,
    'GARBERG': 0,
    'GARBERICH': 0,
    'GARBERS': 0,
    'GARBERSON': 0,
    'GARBES': 0,
    'GARBETT': 0,
    'GARBIN': 0,
    'GARBINI': 0,
    'GARBINSKI': 0,
    'GARBIS': 0,
    'GARBISCH': 0,
    'GARBISO': 0,
    'GARBISON': 0,
    'GARBO': 0,
    'GARBODEN': 0,
    'GARBOSKI': 0,
    'GARBOW': 0,
    'GARBOWSKI': 0,
    'GARBRANDT': 0,
    'GARBRECHT': 0,
    'GARBRICK': 0,
    'GARBS': 0,
    'GARBUS': 0,
    'GARBUTT': 0,
    'GARBY': 0,
    'GARCEA': 0,
    'GARCEAU': 0,
    'GARCED': 0,
    'GARCELL': 0,
    'GARCELON': 0,
    'GARCES': 0,
    'GARCEZ': 0,
    'GARCHA': 0,
    'GARCHAR': 0,
    'GARCHITORENA': 0,
    'GARCHOW': 0,
    'GARCI': 0,
    'GARCIA': 0,
    'GARCIAALVAREZ': 0,
    'GARCIACASTILLO': 0,
    'GARCIACHAVEZ': 0,
    'GARCIACRUZ': 0,
    'GARCIADEALBA': 0,
    'GARCIADIAZ': 0,
    'GARCIAFLORES': 0,
    'GARCIAGARCIA': 0,
    'GARCIAGOMEZ': 0,
    'GARCIAGONZALEZ': 0,
    'GARCIAHERNANDE': 0,
    'GARCIALOPEZ': 0,
    'GARCIAMARTINEZ': 0,
    'GARCIAMENDEZ': 0,
    'GARCIAMENDOZA': 0,
    'GARCIAMORALES': 0,
    'GARCIAMORENO': 0,
    'GARCIAORTIZ': 0,
    'GARCIAPEREZ': 0,
    'GARCIARAMIREZ': 0,
    'GARCIARAMOS': 0,
    'GARCIAREYES': 0,
    'GARCIARIVERA': 0,
    'GARCIARODRIGUE': 0,
    'GARCIARUIZ': 0,
    'GARCIASALAS': 0,
    'GARCIASANCHEZ': 0,
    'GARCIATORRES': 0,
    'GARCIDUENAS': 0,
    'GARCIE': 0,
    'GARCIGA': 0,
    'GARCILAZO': 0,
    'GARCIN': 0,
    'GARCIO': 0,
    'GARCON': 0,
    'GARCZYNSKI': 0,
    'GARD': 0,
    'GARDA': 0,
    'GARDAS': 0,
    'GARDE': 0,
    'GARDEA': 0,
    'GARDECKI': 0,
    'GARDELL': 0,
    'GARDELLA': 0,
    'GARDEN': 0,
    'GARDENER': 0,
    'GARDENHIRE': 0,
    'GARDENIER': 0,
    'GARDENOUR': 0,
    'GARDEPE': 0,
    'GARDER': 0,
    'GARDERE': 0,
    'GARDETTO': 0,
    'GARDI': 0,
    'GARDIN': 0,
    'GARDINA': 0,
    'GARDINE': 0,
    'GARDINEER': 0,
    'GARDINER': 0,
    'GARDING': 0,
    'GARDINI': 0,
    'GARDINIER': 0,
    'GARDINO': 0,
    'GARDIPE': 0,
    'GARDIPEE': 0,
    'GARDLEY': 0,
    'GARDNER': 0,
    'GARDO': 0,
    'GARDOCKI': 0,
    'GARDON': 0,
    'GARDONE': 0,
    'GARDUNIO': 0,
    'GARDUNO': 0,
    'GARDUQUE': 0,
    'GARDY': 0,
    'GARE': 0,
    'GAREAU': 0,
    'GARECHT': 0,
    'GAREE': 0,
    'GAREIA': 0,
    'GAREIS': 0,
    'GAREL': 0,
    'GARELA': 0,
    'GARELICK': 0,
    'GARELL': 0,
    'GARELLI': 0,
    'GAREN': 0,
    'GARERI': 0,
    'GARES': 0,
    'GARETSON': 0,
    'GAREWAL': 0,
    'GAREY': 0,
    'GARFF': 0,
    'GARFIAS': 0,
    'GARFIELD': 0.7587253414264037,
    'GARFIN': 0,
    'GARFINKEL': 0,
    'GARFINKLE': 0,
    'GARFIO': 0,
    'GARFOOT': 0,
    'GARFUNKEL': 0,
    'GARG': 0,
    'GARGAC': 0,
    'GARGAN': 0,
    'GARGANI': 0,
    'GARGANO': 0,
    'GARGANTA': 0,
    'GARGARO': 0,
    'GARGAS': 0,
    'GARGASZ': 0,
    'GARGER': 0,
    'GARGES': 0,
    'GARGIA': 0,
    'GARGIS': 0,
    'GARGIULO': 0,
    'GARGONE': 0,
    'GARGUILO': 0,
    'GARGUS': 0,
    'GARHART': 0,
    'GARI': 0,
    'GARIA': 0,
    'GARIANO': 0,
    'GARIB': 0,
    'GARIBALDI': 0,
    'GARIBALDO': 0,
    'GARIBAY': 0,
    'GARIBIAN': 0,
    'GARIBO': 0,
    'GARIBYAN': 0,
    'GARIC': 0,
    'GARICA': 0,
    'GARICH': 0,
    'GARICIA': 0,
    'GARICK': 0,
    'GARIEPY': 0,
    'GARIETY': 0,
    'GARIFO': 0,
    'GARIG': 0,
    'GARIMELLA': 0,
    'GARIN': 0,
    'GARING': 0,
    'GARINGER': 0,
    'GARINO': 0,
    'GARIPPA': 0,
    'GARIPPO': 0,
    'GARIS': 0,
    'GARISON': 0,
    'GARISS': 0,
    'GARITA': 0,
    'GARITI': 0,
    'GARITO': 0,
    'GARITY': 0,
    'GARIVAY': 0,
    'GARL': 0,
    'GARLAND': 0.6405425772418991,
    'GARLANGER': 0,
    'GARLETT': 0,
    'GARLETTS': 0,
    'GARLEY': 0,
    'GARLIA': 0,
    'GARLIC': 0,
    'GARLICH': 0,
    'GARLICK': 0,
    'GARLIN': 0,
    'GARLING': 0,
    'GARLINGER': 0,
    'GARLINGHOUSE': 0,
    'GARLINGTON': 0,
    'GARLISCH': 0,
    'GARLIT': 0,
    'GARLITOS': 0,
    'GARLITZ': 0,
    'GARLOCH': 0,
    'GARLOCK': 0,
    'GARLOFF': 0,
    'GARLOUGH': 0,
    'GARLOW': 0,
    'GARMA': 0,
    'GARMAN': 0,
    'GARMANN': 0,
    'GARMANY': 0,
    'GARMEN': 0,
    'GARMENDEZ': 0,
    'GARMENDIA': 0,
    'GARMER': 0,
    'GARMIRE': 0,
    'GARMO': 0,
    'GARMOE': 0,
    'GARMON': 0,
    'GARMONG': 0,
    'GARMS': 0,
    'GARN': 0,
    'GARNAAT': 0,
    'GARNAND': 0,
    'GARNATZ': 0,
    'GARNCARZ': 0,
    'GARNDER': 0,
    'GARNEAU': 0,
    'GARNER': 0,
    'GARNES': 0,
    'GARNESS': 0,
    'GARNET': 0.9708737864077669,
    'GARNETT': 0.35398230088495575,
    'GARNETTE': 0,
    'GARNEY': 0,
    'GARNHAM': 0,
    'GARNHART': 0,
    'GARNICA': 0,
    'GARNICK': 0,
    'GARNIER': 0,
    'GARNO': 0,
    'GARNS': 0,
    'GARNSEY': 0,
    'GARNTO': 0,
    'GARO': 0,
    'GAROFALO': 0,
    'GAROFANO': 0,
    'GAROFOLA': 0,
    'GAROFOLI': 0,
    'GAROFOLO': 0,
    'GARON': 0,
    'GARONE': 0,
    'GARONER': 0,
    'GAROT': 0,
    'GAROUTTE': 0,
    'GAROZZO': 0,
    'GARR': 0,
    'GARRA': 0,
    'GARRABRANT': 0,
    'GARRAHAN': 0,
    'GARRAHY': 0,
    'GARRAMONE': 0,
    'GARRAND': 0,
    'GARRANT': 0,
    'GARRARD': 0,
    'GARRATT': 0,
    'GARRAWAY': 0,
    'GARRE': 0,
    'GARREAU': 0,
    'GARRECHT': 0,
    'GARRED': 0,
    'GARREFFA': 0,
    'GARRELL': 0,
    'GARRELS': 0,
    'GARRELTS': 0,
    'GARREN': 0,
    'GARREPY': 0,
    'GARRET': 1,
    'GARRETSON': 0,
    'GARRETT': 0.4205946337926033,
    'GARRETTE': 0,
    'GARRETTSON': 0,
    'GARRETY': 0,
    'GARREY': 0,
    'GARRICK': 0,
    'GARRIDO': 0,
    'GARRIE': 0,
    'GARRIES': 0,
    'GARRIGA': 0,
    'GARRIGAN': 0,
    'GARRIGUES': 0,
    'GARRIGUS': 0,
    'GARRINGER': 0,
    'GARRINGTON': 0,
    'GARRIOTT': 0,
    'GARRIQUES': 0,
    'GARRIS': 0,
    'GARRISH': 0,
    'GARRISI': 0,
    'GARRISON': 0,
    'GARRISS': 0,
    'GARRITANO': 0,
    'GARRITSON': 0,
    'GARRITT': 0,
    'GARRITY': 0,
    'GARRO': 0,
    'GARROD': 0,
    'GARRON': 0,
    'GARRONE': 0,
    'GARROTE': 0,
    'GARROTT': 0,
    'GARROUTTE': 0,
    'GARROVILLAS': 0,
    'GARROW': 0,
    'GARRUTO': 0,
    'GARRY': 0.9621166566446182,
    'GARSA': 0,
    'GARSEE': 0,
    'GARSIA': 0,
    'GARSIDE': 0,
    'GARSKA': 0,
    'GARSKE': 0,
    'GARSKI': 0,
    'GARSON': 0,
    'GARST': 0,
    'GARSTANG': 0,
    'GARSTECKI': 0,
    'GARSTKA': 0,
    'GART': 0,
    'GARTEE': 0,
    'GARTEN': 0,
    'GARTENBERG': 0,
    'GARTER': 0,
    'GARTH': 0.8674101610904584,
    'GARTHE': 0,
    'GARTHRIGHT': 0,
    'GARTHWAIT': 0,
    'GARTHWAITE': 0,
    'GARTIN': 0,
    'GARTLAN': 0,
    'GARTLAND': 0,
    'GARTLEY': 0,
    'GARTMAN': 0,
    'GARTMANN': 0,
    'GARTNER': 0,
    'GARTON': 0,
    'GARTRELL': 0,
    'GARTSIDE': 0,
    'GARTY': 0,
    'GARTZ': 0,
    'GARTZKE': 0,
    'GARUCCIO': 0,
    'GARUFI': 0,
    'GARUTI': 0,
    'GARVAN': 0,
    'GARVELINK': 0,
    'GARVEN': 0,
    'GARVENS': 0,
    'GARVER': 0,
    'GARVERICK': 0,
    'GARVERT': 0,
    'GARVES': 0,
    'GARVEY': 0,
    'GARVICK': 0,
    'GARVIDA': 0,
    'GARVIE': 0,
    'GARVIN': 0,
    'GARVINE': 0,
    'GARVIS': 0,
    'GARWACKI': 0,
    'GARWICK': 0,
    'GARWOOD': 0,
    'GARY': 0.9880883823841421,
    'GARZA': 0,
    'GARZARELLI': 0,
    'GARZARO': 0,
    'GARZES': 0,
    'GARZIA': 0,
    'GARZILLO': 0,
    'GARZON': 0,
    'GARZONA': 0,
    'GARZONE': 0,
    'GARZORIA': 0,
    'GAS': 0,
    'GASAWAY': 0,
    'GASBARRA': 0,
    'GASBARRE': 0,
    'GASBARRO': 0,
    'GASCA': 0,
    'GASCH': 0,
    'GASCHE': 0,
    'GASCHLER': 0,
    'GASCHO': 0,
    'GASCO': 0,
    'GASCOIGNE': 0,
    'GASCON': 0,
    'GASCOYNE': 0,
    'GASE': 0,
    'GASH': 0,
    'GASHI': 0,
    'GASHO': 0,
    'GASIENICA': 0,
    'GASIEWICZ': 0,
    'GASIEWSKI': 0,
    'GASIK': 0,
    'GASIOR': 0,
    'GASIOREK': 0,
    'GASIOROWSKI': 0,
    'GASKA': 0,
    'GASKAMP': 0,
    'GASKE': 0,
    'GASKELL': 0,
    'GASKEY': 0,
    'GASKILL': 0,
    'GASKIN': 0,
    'GASKINS': 0,
    'GASKO': 0,
    'GASLIN': 0,
    'GASMAN': 0,
    'GASMEN': 0,
    'GASNER': 0,
    'GASOWSKI': 0,
    'GASPAR': 0,
    'GASPARAC': 0,
    'GASPARD': 0,
    'GASPARDO': 0,
    'GASPARI': 0,
    'GASPARIAN': 0,
    'GASPARICH': 0,
    'GASPARIK': 0,
    'GASPARINI': 0,
    'GASPARINO': 0,
    'GASPAROVIC': 0,
    'GASPAROVICH': 0,
    'GASPARRE': 0,
    'GASPARRI': 0,
    'GASPARRINI': 0,
    'GASPARRO': 0,
    'GASPARYAN': 0,
    'GASPER': 0,
    'GASPERETTI': 0,
    'GASPERI': 0,
    'GASPERICH': 0,
    'GASPERINI': 0,
    'GASPERINO': 0,
    'GASPERONI': 0,
    'GASPERS': 0,
    'GASPERSON': 0,
    'GASQUE': 0,
    'GASS': 0,
    'GASSAWAY': 0,
    'GASSEL': 0,
    'GASSELING': 0,
    'GASSEN': 0,
    'GASSER': 0,
    'GASSERT': 0,
    'GASSETT': 0,
    'GASSIOTT': 0,
    'GASSLER': 0,
    'GASSMAN': 0,
    'GASSMANN': 0,
    'GASSNER': 0,
    'GASSO': 0,
    'GASSON': 0,
    'GAST': 0,
    'GASTA': 0,
    'GASTALDI': 0,
    'GASTEL': 0,
    'GASTELLUM': 0,
    'GASTELO': 0,
    'GASTELUM': 0,
    'GASTER': 0,
    'GASTIN': 0,
    'GASTINEAU': 0,
    'GASTLER': 0,
    'GASTLEY': 0,
    'GASTON': 0.3703703703703704,
    'GASTONGUAY': 0,
    'GASTROCK': 0,
    'GASVODA': 0,
    'GASWAY': 0,
    'GASWINT': 0,
    'GAT': 0,
    'GATAN': 0,
    'GATBONTON': 0,
    'GATCH': 0,
    'GATCHALIAN': 0,
    'GATCHEL': 0,
    'GATCHELL': 0,
    'GATCOMB': 0,
    'GATDULA': 0,
    'GATE': 0,
    'GATEAU': 0,
    'GATEHOUSE': 0,
    'GATELEY': 0,
    'GATELY': 0,
    'GATEN': 0,
    'GATENBY': 0,
    'GATENS': 0,
    'GATER': 0,
    'GATERS': 0,
    'GATES': 0,
    'GATESMAN': 0,
    'GATEWOOD': 0,
    'GATFIELD': 0,
    'GATH': 0,
    'GATHAGAN': 0,
    'GATHE': 0,
    'GATHER': 0,
    'GATHERCOLE': 0,
    'GATHERIGHT': 0,
    'GATHERS': 0,
    'GATHERUM': 0,
    'GATHING': 0,
    'GATHINGS': 0,
    'GATHJE': 0,
    'GATHMAN': 0,
    'GATHMANN': 0,
    'GATHOF': 0,
    'GATHRIGHT': 0,
    'GATI': 0,
    'GATIAN': 0,
    'GATICA': 0,
    'GATIEN': 0,
    'GATISON': 0,
    'GATLEY': 0,
    'GATLIFF': 0,
    'GATLIN': 0,
    'GATLING': 0,
    'GATMAITAN': 0,
    'GATO': 0,
    'GATON': 0,
    'GATRELL': 0,
    'GATROST': 0,
    'GATSCHET': 0,
    'GATSON': 0,
    'GATT': 0,
    'GATTA': 0,
    'GATTAS': 0,
    'GATTE': 0,
    'GATTEN': 0,
    'GATTENBY': 0,
    'GATTER': 0,
    'GATTERDAM': 0,
    'GATTI': 0,
    'GATTIE': 0,
    'GATTIS': 0,
    'GATTISON': 0,
    'GATTMAN': 0,
    'GATTO': 0,
    'GATTON': 0,
    'GATTONE': 0,
    'GATTONI': 0,
    'GATTOZZI': 0,
    'GATTS': 0,
    'GATTSHALL': 0,
    'GATTUSO': 0,
    'GATUS': 0,
    'GATWOOD': 0,
    'GATZ': 0,
    'GATZA': 0,
    'GATZEMEYER': 0,
    'GATZKE': 0,
    'GAU': 0,
    'GAUB': 0,
    'GAUBATZ': 0,
    'GAUBERT': 0,
    'GAUCH': 0,
    'GAUCHAT': 0,
    'GAUCHE': 0,
    'GAUCHER': 0,
    'GAUCI': 0,
    'GAUCIN': 0,
    'GAUCK': 0,
    'GAUD': 0,
    'GAUDE': 0,
    'GAUDEN': 0,
    'GAUDENZI': 0,
    'GAUDER': 0,
    'GAUDET': 0,
    'GAUDETTE': 0,
    'GAUDI': 0,
    'GAUDIAN': 0,
    'GAUDIANO': 0,
    'GAUDIELLO': 0,
    'GAUDIN': 0,
    'GAUDING': 0,
    'GAUDINIER': 0,
    'GAUDINO': 0,
    'GAUDIO': 0,
    'GAUDIOSI': 0,
    'GAUDIOSO': 0,
    'GAUDREAU': 0,
    'GAUDREAULT': 0,
    'GAUDRY': 0,
    'GAUDY': 0,
    'GAUEN': 0,
    'GAUER': 0,
    'GAUERKE': 0,
    'GAUF': 0,
    'GAUFF': 0,
    'GAUG': 0,
    'GAUGER': 0,
    'GAUGERT': 0,
    'GAUGH': 0,
    'GAUGHAN': 0,
    'GAUGHEN': 0,
    'GAUGHF': 0,
    'GAUGHRAN': 0,
    'GAUGLER': 0,
    'GAUKEL': 0,
    'GAUKER': 0,
    'GAUL': 0,
    'GAULD': 0,
    'GAULDEN': 0,
    'GAULDIN': 0,
    'GAULDING': 0,
    'GAULE': 0,
    'GAULEY': 0,
    'GAULIN': 0,
    'GAULKE': 0,
    'GAULL': 0,
    'GAULRAPP': 0,
    'GAULT': 0,
    'GAULTNEY': 0,
    'GAUME': 0,
    'GAUMER': 0,
    'GAUMOND': 0,
    'GAUMONT': 0,
    'GAUN': 0,
    'GAUNA': 0,
    'GAUNCE': 0,
    'GAUNT': 0,
    'GAUNTLETT': 0,
    'GAUNTNER': 0,
    'GAUNTT': 0,
    'GAUPP': 0,
    'GAUR': 0,
    'GAURA': 0,
    'GAURON': 0,
    'GAUS': 0,
    'GAUSE': 0,
    'GAUSEPOHL': 0,
    'GAUSIN': 0,
    'GAUSMAN': 0,
    'GAUSS': 0,
    'GAUSTAD': 0,
    'GAUT': 0,
    'GAUTAM': 0,
    'GAUTHE': 0,
    'GAUTHIER': 0,
    'GAUTHREAUX': 0,
    'GAUTIER': 0,
    'GAUTIERI': 0,
    'GAUTNEY': 0,
    'GAUTREAU': 0,
    'GAUTREAUX': 0,
    'GAUTSCH': 0,
    'GAUTSCHI': 0,
    'GAUVAIN': 0,
    'GAUVEY': 0,
    'GAUVIN': 0,
    'GAUVREAU': 0,
    'GAUWITZ': 0,
    'GAUZE': 0,
    'GAVA': 0,
    'GAVAGAN': 0,
    'GAVAGHAN': 0,
    'GAVAL': 0,
    'GAVALAS': 0,
    'GAVALDON': 0,
    'GAVAN': 0,
    'GAVARRETE': 0,
    'GAVAZZI': 0,
    'GAVE': 0,
    'GAVEL': 0,
    'GAVEN': 0,
    'GAVENDA': 0,
    'GAVER': 0,
    'GAVERN': 0,
    'GAVETT': 0,
    'GAVETTE': 0,
    'GAVEY': 0,
    'GAVIA': 0,
    'GAVIC': 0,
    'GAVIDIA': 0,
    'GAVIGAN': 0,
    'GAVILAN': 0,
    'GAVILANES': 0,
    'GAVILANEZ': 0,
    'GAVIN': 0.6662225183211192,
    'GAVINA': 0,
    'GAVINO': 0,
    'GAVINS': 0,
    'GAVINSKI': 0,
    'GAVIOLA': 0,
    'GAVIRIA': 0,
    'GAVIS': 0,
    'GAVIT': 0,
    'GAVITO': 0,
    'GAVITT': 0,
    'GAVLAK': 0,
    'GAVLICK': 0,
    'GAVLIK': 0,
    'GAVLIN': 0,
    'GAVRILOV': 0,
    'GAVRILOVIC': 0,
    'GAVRILYUK': 0,
    'GAVRON': 0,
    'GAVULA': 0,
    'GAW': 0,
    'GAWARECKI': 0,
    'GAWEL': 0,
    'GAWENDA': 0,
    'GAWIN': 0,
    'GAWINSKI': 0,
    'GAWITH': 0,
    'GAWLAK': 0,
    'GAWLAS': 0,
    'GAWLE': 0,
    'GAWLER': 0,
    'GAWLEY': 0,
    'GAWLIK': 0,
    'GAWLINSKI': 0,
    'GAWLOWSKI': 0,
    'GAWNE': 0,
    'GAWORECKI': 0,
    'GAWORSKI': 0,
    'GAWRON': 0,
    'GAWRONSKI': 0,
    'GAWRYCH': 0,
    'GAWRYS': 0,
    'GAWTHORP': 0,
    'GAWTHROP': 0,
    'GAXIOLA': 0,
    'GAY': 0.4977187888842804,
    'GAYA': 0,
    'GAYAN': 0,
    'GAYDA': 0,
    'GAYDEN': 0,
    'GAYDON': 0,
    'GAYDOS': 0,
    'GAYDOSH': 0,
    'GAYE': 0.9380863039399625,
    'GAYED': 0,
    'GAYER': 0,
    'GAYESKI': 0,
    'GAYFIELD': 0,
    'GAYHART': 0,
    'GAYHEART': 0,
    'GAYKEN': 0,
    'GAYLA': 1,
    'GAYLE': 0.9496868054152355,
    'GAYLENE': 1,
    'GAYLER': 0,
    'GAYLES': 0,
    'GAYLOR': 0,
    'GAYLORD': 0.6768189509306262,
    'GAYMAN': 0,
    'GAYMON': 0,
    'GAYNE': 0,
    'GAYNELL': 1,
    'GAYNELLE': 1,
    'GAYNER': 0,
    'GAYNES': 0,
    'GAYNIER': 0,
    'GAYNOR': 0,
    'GAYO': 0,
    'GAYON': 0,
    'GAYOSO': 0,
    'GAYOSSO': 0,
    'GAYTAN': 0,
    'GAYTEN': 0,
    'GAYTON': 0,
    'GAZ': 0,
    'GAZA': 0,
    'GAZAILLE': 0,
    'GAZAREK': 0,
    'GAZARIAN': 0,
    'GAZAWAY': 0,
    'GAZCA': 0,
    'GAZCON': 0,
    'GAZDA': 0,
    'GAZDAG': 0,
    'GAZDECKI': 0,
    'GAZDIK': 0,
    'GAZE': 0,
    'GAZELEY': 0,
    'GAZELLA': 0,
    'GAZELLE': 0,
    'GAZI': 0,
    'GAZIANO': 0,
    'GAZLAY': 0,
    'GAZLEY': 0,
    'GAZMEN': 0,
    'GAZO': 0,
    'GAZZA': 0,
    'GAZZANO': 0,
    'GAZZARA': 0,
    'GAZZILLO': 0,
    'GAZZO': 0,
    'GAZZOLA': 0,
    'GBADAMOSI': 0,
    'GBUR': 0,
    'GDOVIN': 0,
    'GDOWSKI': 0,
    'GDULA': 0,
    'GE': 0,
    'GEACH': 0,
    'GEAGAN': 0,
    'GEAGHAN': 0,
    'GEAKE': 0,
    'GEALY': 0,
    'GEAN': 0,
    'GEANEY': 0,
    'GEANS': 0,
    'GEAR': 0,
    'GEARE': 0,
    'GEAREN': 0,
    'GEAREY': 0,
    'GEARHARDT': 0,
    'GEARHART': 0,
    'GEARHEART': 0,
    'GEARIG': 0,
    'GEARIN': 0,
    'GEARING': 0,
    'GEARINGER': 0,
    'GEARITY': 0,
    'GEARLDINE': 1,
    'GEARLDS': 0,
    'GEARNS': 0,
    'GEARON': 0,
    'GEARRING': 0,
    'GEARS': 0,
    'GEARTY': 0,
    'GEARY': 0,
    'GEASE': 0,
    'GEASLAND': 0,
    'GEASLIN': 0,
    'GEASON': 0,
    'GEATER': 0,
    'GEATHERS': 0,
    'GEBALA': 0,
    'GEBARA': 0,
    'GEBAUER': 0,
    'GEBBEN': 0,
    'GEBBIA': 0,
    'GEBBIE': 0,
    'GEBEL': 0,
    'GEBELEIN': 0,
    'GEBER': 0,
    'GEBERS': 0,
    'GEBERT': 0,
    'GEBHARD': 0,
    'GEBHARDT': 0,
    'GEBHART': 0,
    'GEBKE': 0,
    'GEBLER': 0,
    'GEBO': 0,
    'GEBOY': 0,
    'GEBRE': 0,
    'GEBREHIWOT': 0,
    'GEBREKIDAN': 0,
    'GEBREMARIAM': 0,
    'GEBREMEDHIN': 0,
    'GEBREMESKEL': 0,
    'GEBREMICHAEL': 0,
    'GEBRESELASSIE': 0,
    'GEBREYESUS': 0,
    'GEBRU': 0,
    'GEBUR': 0,
    'GECEWICZ': 0,
    'GECHTER': 0,
    'GECI': 0,
    'GECK': 0,
    'GECKLE': 0,
    'GECKLER': 0,
    'GECZI': 0,
    'GEDA': 0,
    'GEDDE': 0,
    'GEDDES': 0,
    'GEDDIE': 0,
    'GEDDINGS': 0,
    'GEDDIS': 0,
    'GEDE': 0,
    'GEDEON': 0,
    'GEDERT': 0,
    'GEDGE': 0,
    'GEDMAN': 0,
    'GEDNEY': 0,
    'GEDRAITIS': 0,
    'GEDRICH': 0,
    'GEDROSE': 0,
    'GEE': 0,
    'GEECK': 0,
    'GEEDING': 0,
    'GEEDY': 0,
    'GEEGAN': 0,
    'GEEHAN': 0,
    'GEEKIE': 0,
    'GEEL': 0,
    'GEELAN': 0,
    'GEELHOED': 0,
    'GEELS': 0,
    'GEEN': 0,
    'GEENE': 0,
    'GEENEN': 0,
    'GEER': 0,
    'GEERDES': 0,
    'GEERING': 0,
    'GEERLING': 0,
    'GEERLINGS': 0,
    'GEERS': 0,
    'GEERTGENS': 0,
    'GEERTS': 0,
    'GEERTSEMA': 0,
    'GEERTSEN': 0,
    'GEERTZ': 0,
    'GEERY': 0,
    'GEESAMAN': 0,
    'GEESE': 0,
    'GEESEY': 0,
    'GEESLIN': 0,
    'GEESLING': 0,
    'GEETER': 0,
    'GEETING': 0,
    'GEEVARGHESE': 0,
    'GEFELL': 0,
    'GEFEN': 0,
    'GEFFE': 0,
    'GEFFEN': 0,
    'GEFFERS': 0,
    'GEFFERT': 0,
    'GEFFKEN': 0,
    'GEFFNER': 0,
    'GEFFRARD': 0,
    'GEFFRE': 0,
    'GEFRE': 0,
    'GEFROH': 0,
    'GEFTER': 0,
    'GEGA': 0,
    'GEGAN': 0,
    'GEGEN': 0,
    'GEGENHEIMER': 0,
    'GEGG': 0,
    'GEGNER': 0,
    'GEHA': 0,
    'GEHAN': 0,
    'GEHANT': 0,
    'GEHEB': 0,
    'GEHIN': 0,
    'GEHL': 0,
    'GEHLBACH': 0,
    'GEHLE': 0,
    'GEHLEN': 0,
    'GEHLER': 0,
    'GEHLERT': 0,
    'GEHLHAUSEN': 0,
    'GEHLING': 0,
    'GEHLKEN': 0,
    'GEHLSEN': 0,
    'GEHM': 0,
    'GEHMAN': 0,
    'GEHNER': 0,
    'GEHO': 0,
    'GEHR': 0,
    'GEHRELS': 0,
    'GEHRER': 0,
    'GEHRES': 0,
    'GEHRET': 0,
    'GEHRETT': 0,
    'GEHRI': 0,
    'GEHRIG': 0,
    'GEHRING': 0,
    'GEHRINGER': 0,
    'GEHRIS': 0,
    'GEHRISCH': 0,
    'GEHRKE': 0,
    'GEHRKING': 0,
    'GEHRLEIN': 0,
    'GEHRLS': 0,
    'GEHRMAN': 0,
    'GEHRMANN': 0,
    'GEHRON': 0,
    'GEHRS': 0,
    'GEHRT': 0,
    'GEHRTS': 0,
    'GEIB': 0,
    'GEIBE': 0,
    'GEIBEL': 0,
    'GEICK': 0,
    'GEIDEL': 0,
    'GEIDNER': 0,
    'GEIER': 0,
    'GEIERSBACH': 0,
    'GEIGEL': 0,
    'GEIGER': 0,
    'GEIGES': 0,
    'GEIGLE': 0,
    'GEIKEN': 0,
    'GEIL': 0,
    'GEILE': 0,
    'GEILER': 0,
    'GEILFUSS': 0,
    'GEILING': 0,
    'GEILS': 0,
    'GEIMAN': 0,
    'GEIMER': 0,
    'GEIPEL': 0,
    'GEIS': 0,
    'GEISBERT': 0,
    'GEISE': 0,
    'GEISEL': 0,
    'GEISELHART': 0,
    'GEISELMAN': 0,
    'GEISEN': 0,
    'GEISENDORFER': 0,
    'GEISENDORFF': 0,
    'GEISER': 0,
    'GEISERT': 0,
    'GEISINGER': 0,
    'GEISLER': 0,
    'GEISLINGER': 0,
    'GEISMAN': 0,
    'GEISMAR': 0,
    'GEISS': 0,
    'GEISSEL': 0,
    'GEISSER': 0,
    'GEISSINGER': 0,
    'GEISSLER': 0,
    'GEIST': 0,
    'GEISTER': 0,
    'GEISTFELD': 0,
    'GEISTWEIDT': 0,
    'GEISZ': 0,
    'GEISZLER': 0,
    'GEITER': 0,
    'GEITGEY': 0,
    'GEITH': 0,
    'GEITNER': 0,
    'GEITZ': 0,
    'GEIWITZ': 0,
    'GEKAS': 0,
    'GELABERT': 0,
    'GELACIO': 0,
    'GELARDEN': 0,
    'GELARDI': 0,
    'GELATT': 0,
    'GELB': 0,
    'GELBACH': 0,
    'GELBAND': 0,
    'GELBARD': 0,
    'GELBART': 0,
    'GELBAUGH': 0,
    'GELBER': 0,
    'GELBERG': 0,
    'GELBERT': 0,
    'GELBMAN': 0,
    'GELD': 0,
    'GELDART': 0,
    'GELDER': 0,
    'GELDERLOOS': 0,
    'GELDERMAN': 0,
    'GELDERSMA': 0,
    'GELDERT': 0,
    'GELDHOF': 0,
    'GELDMACHER': 0,
    'GELDREICH': 0,
    'GELDZAHLER': 0,
    'GELE': 0,
    'GELET': 0,
    'GELETA': 0,
    'GELETKA': 0,
    'GELFAND': 0,
    'GELFER': 0,
    'GELFMAN': 0,
    'GELFO': 0,
    'GELFOND': 0,
    'GELFUSO': 0,
    'GELHAR': 0,
    'GELHAUS': 0,
    'GELHAUSEN': 0,
    'GELIN': 0,
    'GELINA': 0,
    'GELINAS': 0,
    'GELINEAU': 0,
    'GELINO': 0,
    'GELIS': 0,
    'GELL': 0,
    'GELLA': 0,
    'GELLAR': 0,
    'GELLATLY': 0,
    'GELLE': 0,
    'GELLENBECK': 0,
    'GELLER': 0,
    'GELLERMAN': 0,
    'GELLERSON': 0,
    'GELLERSTEDT': 0,
    'GELLERT': 0,
    'GELLES': 0,
    'GELLEY': 0,
    'GELLHAUS': 0,
    'GELLIN': 0,
    'GELLING': 0,
    'GELLINGER': 0,
    'GELLINGS': 0,
    'GELLIS': 0,
    'GELLMAN': 0,
    'GELLNER': 0,
    'GELLY': 0,
    'GELMAN': 0,
    'GELNER': 0,
    'GELNETT': 0,
    'GELO': 0,
    'GELOK': 0,
    'GELORMINI': 0,
    'GELORMINO': 0,
    'GELOSO': 0,
    'GELOW': 0,
    'GELPI': 0,
    'GELS': 0,
    'GELSEY': 0,
    'GELSINGER': 0,
    'GELSO': 0,
    'GELSOMINI': 0,
    'GELSOMINO': 0,
    'GELSON': 0,
    'GELSTON': 0,
    'GELTER': 0,
    'GELTMAN': 0,
    'GELTZ': 0,
    'GELUSO': 0,
    'GELUZ': 0,
    'GELVIN': 0,
    'GELWICKS': 0,
    'GELZER': 0,
    'GEMA': 1,
    'GEMAR': 0,
    'GEMAS': 0,
    'GEMBALA': 0,
    'GEMBE': 0,
    'GEMBERLING': 0,
    'GEMBLER': 0,
    'GEMEINHARDT': 0,
    'GEMELLARO': 0,
    'GEMELLI': 0,
    'GEMES': 0,
    'GEMIGNANI': 0,
    'GEML': 0,
    'GEMMA': 0.9090909090909091,
    'GEMME': 0,
    'GEMMEL': 0,
    'GEMMELL': 0,
    'GEMMER': 0,
    'GEMMILL': 0,
    'GEMPERLINE': 0,
    'GEMPLER': 0,
    'GEMZA': 0,
    'GEN': 0,
    'GENA': 0.992063492063492,
    'GENAO': 0,
    'GENARD': 0,
    'GENARO': 0.98159509202454,
    'GENAW': 0,
    'GENBERG': 0,
    'GENCARELLI': 0,
    'GENCHI': 0,
    'GENCO': 0,
    'GENDA': 0,
    'GENDE': 0,
    'GENDEL': 0,
    'GENDELMAN': 0,
    'GENDER': 0,
    'GENDLER': 0,
    'GENDREAU': 0,
    'GENDRON': 0,
    'GENDUSA': 0,
    'GENDUSO': 0,
    'GENDY': 0,
    'GENE': 0.9978308026030368,
    'GENEL': 0,
    'GENENBACHER': 0,
    'GENER': 0,
    'GENERA': 0,
    'GENERAL': 0,
    'GENERALI': 0,
    'GENEREAUX': 0,
    'GENERETTE': 0,
    'GENEREUX': 0,
    'GENEROSO': 0,
    'GENEROUS': 0,
    'GENES': 0,
    'GENESER': 0,
    'GENESIS': 1,
    'GENEST': 0,
    'GENET': 0,
    'GENETT': 0,
    'GENETTI': 0,
    'GENEUS': 0,
    'GENEVA': 0.99847689964461,
    'GENEVIE': 1,
    'GENEVIEVE': 1,
    'GENEVIVE': 1,
    'GENG': 0,
    'GENGA': 0,
    'GENGE': 0,
    'GENGELBACH': 0,
    'GENGENBACH': 0,
    'GENGER': 0,
    'GENGLER': 0,
    'GENGO': 0,
    'GENIA': 1,
    'GENIE': 0.9803921568627452,
    'GENIER': 0,
    'GENIESSE': 0,
    'GENIN': 0,
    'GENIS': 0,
    'GENISE': 0,
    'GENITO': 0,
    'GENKE': 0,
    'GENKIN': 0,
    'GENKINS': 0,
    'GENN': 0,
    'GENNA': 0.7575757575757576,
    'GENNARD': 0,
    'GENNARELLI': 0,
    'GENNARI': 0,
    'GENNARO': 0,
    'GENNETT': 0,
    'GENNETTE': 0,
    'GENNIE': 1,
    'GENNINGS': 0,
    'GENNRICH': 0,
    'GENNUSA': 0,
    'GENNUSO': 0,
    'GENNY': 1,
    'GENO': 0,
    'GENORD': 0,
    'GENOVA': 0,
    'GENOVESE': 0,
    'GENOVESI': 0,
    'GENOVEVA': 1,
    'GENRE': 0,
    'GENRICH': 0,
    'GENS': 0,
    'GENSAMER': 0,
    'GENSCH': 0,
    'GENSEL': 0,
    'GENSEMER': 0,
    'GENSER': 0,
    'GENSHEIMER': 0,
    'GENSINGER': 0,
    'GENSKE': 0,
    'GENSLER': 0,
    'GENSLINGER': 0,
    'GENSMER': 0,
    'GENSON': 0,
    'GENT': 0,
    'GENTA': 0,
    'GENTEMAN': 0,
    'GENTEMANN': 0,
    'GENTER': 0,
    'GENTES': 0,
    'GENTGES': 0,
    'GENTH': 0,
    'GENTHE': 0,
    'GENTHER': 0,
    'GENTHNER': 0,
    'GENTIL': 0,
    'GENTILCORE': 0,
    'GENTILE': 0,
    'GENTILELLA': 0,
    'GENTILI': 0,
    'GENTILINI': 0,
    'GENTILLE': 0,
    'GENTILUCCI': 0,
    'GENTILUOMO': 0,
    'GENTIS': 0,
    'GENTLE': 0,
    'GENTLEMAN': 0,
    'GENTLES': 0,
    'GENTNER': 0,
    'GENTON': 0,
    'GENTRUP': 0,
    'GENTRY': 0,
    'GENTSCH': 0,
    'GENTY': 0,
    'GENTZ': 0,
    'GENTZEL': 0,
    'GENTZKOW': 0,
    'GENTZLER': 0,
    'GENUA': 0,
    'GENUALDI': 0,
    'GENUARDI': 0,
    'GENUARIO': 0,
    'GENUNG': 0,
    'GENUS': 0,
    'GENUSA': 0,
    'GENWRIGHT': 0,
    'GENZ': 0,
    'GENZALE': 0,
    'GENZEL': 0,
    'GENZER': 0,
    'GENZINK': 0,
    'GENZLER': 0,
    'GENZLINGER': 0,
    'GEOFFREY': 0.9962640099626402,
    'GEOFFRION': 0,
    'GEOFFROY': 0,
    'GEOGHAGAN': 0,
    'GEOGHAN': 0,
    'GEOGHEGAN': 0,
    'GEOHAGAN': 0,
    'GEOPFERT': 0,
    'GEORG': 0,
    'GEORGAKIS': 0,
    'GEORGAKOPOULOS': 0,
    'GEORGALAS': 0,
    'GEORGANN': 1,
    'GEORGANTAS': 0,
    'GEORGAS': 0,
    'GEORGATOS': 0,
    'GEORGE': 0.9545268332650553,
    'GEORGEANN': 1,
    'GEORGEANNA': 1,
    'GEORGEFF': 0,
    'GEORGEN': 0,
    'GEORGENE': 1,
    'GEORGER': 0,
    'GEORGES': 0,
    'GEORGESCU': 0,
    'GEORGESON': 0,
    'GEORGETOWN': 0,
    'GEORGETTA': 1,
    'GEORGETTE': 0.9936766034327009,
    'GEORGETTI': 0,
    'GEORGEVICH': 0,
    'GEORGHIOU': 0,
    'GEORGI': 0,
    'GEORGIA': 0.9959505308087994,
    'GEORGIADES': 0,
    'GEORGIADIS': 0,
    'GEORGIAN': 0,
    'GEORGIANA': 0.984251968503937,
    'GEORGIANN': 1,
    'GEORGIANNA': 0.9861932938856016,
    'GEORGIANNE': 1,
    'GEORGIE': 0.9828009828009829,
    'GEORGIEFF': 0,
    'GEORGIEV': 0,
    'GEORGINA': 1,
    'GEORGINE': 1,
    'GEORGIO': 0,
    'GEORGIOU': 0,
    'GEORGIS': 0,
    'GEORGIUS': 0,
    'GEORGOPOULOS': 0,
    'GEORGOULIS': 0,
    'GEORGY': 0,
    'GEOSITS': 0,
    'GEOUGE': 0,
    'GEPFORD': 0,
    'GEPHARDT': 0,
    'GEPHART': 0,
    'GEPNER': 0,
    'GEPPERT': 0,
    'GEPPI': 0,
    'GER': 0,
    'GERA': 0,
    'GERACE': 0,
    'GERACI': 0,
    'GERADS': 0,
    'GERAETS': 0,
    'GERAGHTY': 0,
    'GERAGOSIAN': 0,
    'GERAK': 0,
    'GERALD': 0.9940676607343274,
    'GERALDI': 0,
    'GERALDINE': 1,
    'GERALDINO': 0,
    'GERALDO': 0.9633911368015414,
    'GERALDS': 0,
    'GERALYN': 1,
    'GERAMI': 0,
    'GERAMITA': 0,
    'GERAN': 0,
    'GERARD': 0.9257116408238834,
    'GERARDEN': 0,
    'GERARDI': 0,
    'GERARDINO': 0,
    'GERARDO': 0.9765028989929813,
    'GERARDOT': 0,
    'GERARDY': 0,
    'GERAS': 0,
    'GERASIMOV': 0,
    'GERATY': 0,
    'GERAY': 0,
    'GERBA': 0,
    'GERBASI': 0,
    'GERBE': 0,
    'GERBEC': 0,
    'GERBEN': 0,
    'GERBER': 0,
    'GERBERDING': 0,
    'GERBERICH': 0,
    'GERBERICK': 0,
    'GERBERS': 0,
    'GERBERT': 0,
    'GERBI': 0,
    'GERBICK': 0,
    'GERBIG': 0,
    'GERBING': 0,
    'GERBINO': 0,
    'GERBITZ': 0,
    'GERBOTH': 0,
    'GERBRACHT': 0,
    'GERBRANDT': 0,
    'GERBUS': 0,
    'GERCHAK': 0,
    'GERCHMAN': 0,
    'GERCKEN': 0,
    'GERCZAK': 0,
    'GERDA': 0.9852216748768473,
    'GERDAU': 0,
    'GERDE': 0,
    'GERDEMAN': 0,
    'GERDES': 0,
    'GERDIN': 0,
    'GERDING': 0,
    'GERDOM': 0,
    'GERDON': 0,
    'GERDS': 0,
    'GERDTS': 0,
    'GERE': 0,
    'GEREAU': 0,
    'GEREAUX': 0,
    'GERECKE': 0,
    'GEREG': 0,
    'GEREK': 0,
    'GEREMIA': 0,
    'GEREN': 0,
    'GERENA': 0,
    'GERENCSER': 0,
    'GERES': 0,
    'GERETY': 0,
    'GEREW': 0,
    'GEREZ': 0,
    'GERFEN': 0,
    'GERFIN': 0,
    'GERG': 0,
    'GERGEL': 0,
    'GERGELY': 0,
    'GERGEN': 0,
    'GERGER': 0,
    'GERGES': 0,
    'GERGICH': 0,
    'GERGIS': 0,
    'GERGITS': 0,
    'GERHARD': 0,
    'GERHARDS': 0,
    'GERHARDSON': 0,
    'GERHARDSTEIN': 0,
    'GERHARDT': 0,
    'GERHART': 0,
    'GERHARTZ': 0,
    'GERHARZ': 0,
    'GERHAUSER': 0,
    'GERHOLD': 0,
    'GERHOLDT': 0,
    'GERI': 0.99009900990099,
    'GERIAK': 0,
    'GERICH': 0,
    'GERICK': 0,
    'GERICKE': 0,
    'GERIG': 0,
    'GERIK': 0,
    'GERIKE': 0,
    'GERIN': 0,
    'GERING': 0,
    'GERINGER': 0,
    'GERIS': 0,
    'GERISCH': 0,
    'GERITY': 0,
    'GERJETS': 0,
    'GERK': 0,
    'GERKE': 0,
    'GERKEN': 0,
    'GERKENS': 0,
    'GERKEY': 0,
    'GERKIN': 0,
    'GERKING': 0,
    'GERL': 0,
    'GERLA': 0,
    'GERLACH': 0,
    'GERLACK': 0,
    'GERLAND': 0,
    'GERLE': 0,
    'GERLEMAN': 0,
    'GERLER': 0,
    'GERLICH': 0,
    'GERLING': 0,
    'GERLINGER': 0,
    'GERLITS': 0,
    'GERLITZ': 0,
    'GERLOCK': 0,
    'GERLOFF': 0,
    'GERLT': 0,
    'GERM': 0,
    'GERMACK': 0,
    'GERMAIN': 0,
    'GERMAINE': 0.9411764705882353,
    'GERMAN': 0.5939123979213067,
    'GERMANA': 0,
    'GERMANI': 0,
    'GERMANN': 0,
    'GERMANO': 0,
    'GERMANOS': 0,
    'GERMANOVICH': 0,
    'GERMANY': 0,
    'GERMEK': 0,
    'GERMER': 0,
    'GERMEROTH': 0,
    'GERMINARIO': 0,
    'GERMINARO': 0,
    'GERMINO': 0,
    'GERMON': 0,
    'GERMOND': 0,
    'GERMOSEN': 0,
    'GERMSCHEID': 0,
    'GERMUNDSON': 0,
    'GERN': 0,
    'GERNAAT': 0,
    'GERNAND': 0,
    'GERNANDT': 0,
    'GERNANT': 0,
    'GERNAT': 0,
    'GERNATT': 0,
    'GERNDT': 0,
    'GERNENTZ': 0,
    'GERNER': 0,
    'GERNERT': 0,
    'GERNES': 0,
    'GERNEY': 0,
    'GERNHARDT': 0,
    'GERNHART': 0,
    'GERNON': 0,
    'GERO': 0,
    'GEROLD': 0,
    'GEROME': 0,
    'GERON': 0,
    'GERONA': 0,
    'GERONDALE': 0,
    'GERONIMO': 0,
    'GEROSA': 0,
    'GEROT': 0,
    'GEROU': 0,
    'GEROULD': 0,
    'GEROUX': 0,
    'GEROVAC': 0,
    'GEROW': 0,
    'GEROY': 0,
    'GERR': 0,
    'GERRA': 0,
    'GERRALD': 0,
    'GERRANS': 0,
    'GERRARD': 0,
    'GERRED': 0,
    'GERRELL': 0,
    'GERRELLS': 0,
    'GERREN': 0,
    'GERRETY': 0,
    'GERRI': 1,
    'GERRICK': 0,
    'GERRIE': 0,
    'GERRIN': 0,
    'GERRING': 0,
    'GERRINGER': 0,
    'GERRIOR': 0,
    'GERRISH': 0,
    'GERRITS': 0,
    'GERRITSEN': 0,
    'GERRITSON': 0,
    'GERRITY': 0,
    'GERRON': 0,
    'GERROW': 0,
    'GERRY': 0.9340338587273789,
    'GERS': 0,
    'GERSBACH': 0,
    'GERSCH': 0,
    'GERSCHUTZ': 0,
    'GERSDORF': 0,
    'GERSH': 0,
    'GERSHBERG': 0,
    'GERSHEN': 0,
    'GERSHENSON': 0,
    'GERSHKOVICH': 0,
    'GERSHMAN': 0,
    'GERSHON': 0,
    'GERSHOWITZ': 0,
    'GERSKY': 0,
    'GERSON': 0,
    'GERSPACHER': 0,
    'GERST': 0,
    'GERSTEIN': 0,
    'GERSTEL': 0,
    'GERSTEN': 0,
    'GERSTENBERG': 0,
    'GERSTENBERGER': 0,
    'GERSTENFELD': 0,
    'GERSTENKORN': 0,
    'GERSTER': 0,
    'GERSTL': 0,
    'GERSTLE': 0,
    'GERSTLER': 0,
    'GERSTMAN': 0,
    'GERSTMANN': 0,
    'GERSTNER': 0,
    'GERSTORFF': 0,
    'GERSTUNG': 0,
    'GERSZEWSKI': 0,
    'GERTEISEN': 0,
    'GERTEN': 0,
    'GERTH': 0,
    'GERTHA': 1,
    'GERTHOFFER': 0,
    'GERTIE': 1,
    'GERTKEN': 0,
    'GERTLER': 0,
    'GERTMAN': 0,
    'GERTNER': 0,
    'GERTON': 0,
    'GERTRUD': 1,
    'GERTRUDE': 1,
    'GERTRUDIS': 1,
    'GERTS': 0,
    'GERTSCH': 0,
    'GERTSEN': 0,
    'GERTSON': 0,
    'GERTUDE': 1,
    'GERTZ': 0,
    'GERTZEN': 0,
    'GERUS': 0,
    'GERVACIO': 0,
    'GERVAIS': 0,
    'GERVASE': 0,
    'GERVASI': 0,
    'GERVASIO': 0,
    'GERVASONI': 0,
    'GERVER': 0,
    'GERVIN': 0,
    'GERVING': 0,
    'GERWE': 0,
    'GERWECK': 0,
    'GERWICK': 0,
    'GERWIG': 0,
    'GERWIN': 0,
    'GERWING': 0,
    'GERWITZ': 0,
    'GERY': 0,
    'GERYCH': 0,
    'GERZ': 0,
    'GERZON': 0,
    'GESAMAN': 0,
    'GESCH': 0,
    'GESCHKE': 0,
    'GESCHWIND': 0,
    'GESE': 0,
    'GESEK': 0,
    'GESELL': 0,
    'GESERICK': 0,
    'GESFORD': 0,
    'GESIAKOWSKI': 0,
    'GESICK': 0,
    'GESICKI': 0,
    'GESIN': 0,
    'GESING': 0,
    'GESINGER': 0,
    'GESINK': 0,
    'GESKE': 0,
    'GESLER': 0,
    'GESLING': 0,
    'GESME': 0,
    'GESMUNDO': 0,
    'GESNER': 0,
    'GESS': 0,
    'GESSAY': 0,
    'GESSE': 0,
    'GESSEL': 0,
    'GESSELL': 0,
    'GESSELMAN': 0,
    'GESSER': 0,
    'GESSERT': 0,
    'GESSESSE': 0,
    'GESSFORD': 0,
    'GESSLER': 0,
    'GESSLING': 0,
    'GESSMAN': 0,
    'GESSNER': 0,
    'GESSWEIN': 0,
    'GEST': 0,
    'GESTER': 0,
    'GESTETNER': 0,
    'GESTON': 0,
    'GESTRICH': 0,
    'GESTRING': 0,
    'GESUALDI': 0,
    'GESUALDO': 0,
    'GESWEIN': 0,
    'GETACHEW': 0,
    'GETAHUN': 0,
    'GETCH': 0,
    'GETCHEL': 0,
    'GETCHELL': 0,
    'GETCHIUS': 0,
    'GETER': 0,
    'GETGEN': 0,
    'GETHERS': 0,
    'GETHING': 0,
    'GETLER': 0,
    'GETMAN': 0,
    'GETNER': 0,
    'GETSINGER': 0,
    'GETSON': 0,
    'GETSY': 0,
    'GETT': 0,
    'GETTE': 0,
    'GETTEL': 0,
    'GETTELFINGER': 0,
    'GETTELMAN': 0,
    'GETTEMY': 0,
    'GETTEN': 0,
    'GETTENS': 0,
    'GETTER': 0,
    'GETTIER': 0,
    'GETTIG': 0,
    'GETTING': 0,
    'GETTINGER': 0,
    'GETTINGS': 0,
    'GETTIS': 0,
    'GETTLE': 0,
    'GETTLEMAN': 0,
    'GETTLER': 0,
    'GETTMAN': 0,
    'GETTMANN': 0,
    'GETTO': 0,
    'GETTS': 0,
    'GETTY': 0,
    'GETTYS': 0,
    'GETZ': 0,
    'GETZELMAN': 0,
    'GETZEN': 0,
    'GETZIN': 0,
    'GETZINGER': 0,
    'GETZLAFF': 0,
    'GETZLER': 0,
    'GETZLOFF': 0,
    'GETZOFF': 0,
    'GEUDER': 0,
    'GEURIN': 0,
    'GEURINK': 0,
    'GEURKINK': 0,
    'GEURTS': 0,
    'GEUSS': 0,
    'GEUTHER': 0,
    'GEVARA': 0,
    'GEVAS': 0,
    'GEVEDON': 0,
    'GEVERS': 0,
    'GEVING': 0,
    'GEVORGYAN': 0,
    'GEVORKIAN': 0,
    'GEVORKYAN': 0,
    'GEVRY': 0,
    'GEWARGIS': 0,
    'GEWECKE': 0,
    'GEWERTH': 0,
    'GEWIN': 0,
    'GEWIRTZ': 0,
    'GEX': 0,
    'GEY': 0,
    'GEYEN': 0,
    'GEYER': 0,
    'GEYMAN': 0,
    'GEYSER': 0,
    'GEZALYAN': 0,
    'GEZELLA': 0,
    'GFELL': 0,
    'GFELLER': 0,
    'GFROERER': 0,
    'GHADERI': 0,
    'GHADIMI': 0,
    'GHAEMI': 0,
    'GHAEMMAGHAMI': 0,
    'GHAFARI': 0,
    'GHAFFAR': 0,
    'GHAFFARI': 0,
    'GHAFOOR': 0,
    'GHAFOORI': 0,
    'GHAFOURI': 0,
    'GHAHRAMANI': 0,
    'GHAHREMANI': 0,
    'GHAI': 0,
    'GHALAYINI': 0,
    'GHALEB': 0,
    'GHALI': 0,
    'GHALY': 0,
    'GHAN': 0,
    'GHANAYEM': 0,
    'GHANBARI': 0,
    'GHANDOUR': 0,
    'GHANEM': 0,
    'GHANI': 0,
    'GHANIM': 0,
    'GHANNAM': 0,
    'GHANT': 0,
    'GHANTOUS': 0,
    'GHANY': 0,
    'GHAREEB': 0,
    'GHARIB': 0,
    'GHARIBIAN': 0,
    'GHARST': 0,
    'GHASEMI': 0,
    'GHASSEMI': 0,
    'GHASTIN': 0,
    'GHATTAS': 0,
    'GHAURI': 0,
    'GHAVAMI': 0,
    'GHAZAL': 0,
    'GHAZALI': 0,
    'GHAZARIAN': 0,
    'GHAZI': 0,
    'GHAZNAVI': 0,
    'GHEE': 0,
    'GHEEN': 0,
    'GHEESLING': 0,
    'GHEEWALA': 0,
    'GHEGAN': 0,
    'GHEITH': 0,
    'GHELFI': 0,
    'GHENT': 0,
    'GHEORGHE': 0,
    'GHEORGHIU': 0,
    'GHER': 0,
    'GHERARDI': 0,
    'GHERARDINI': 0,
    'GHERE': 0,
    'GHERING': 0,
    'GHERMAN': 0,
    'GHERNA': 0,
    'GHERSI': 0,
    'GHESQUIERE': 0,
    'GHEZZI': 0,
    'GHIA': 0,
    'GHIASSI': 0,
    'GHIGLIERI': 0,
    'GHIGLIOTTY': 0,
    'GHILARDI': 0,
    'GHILARDUCCI': 0,
    'GHILONI': 0,
    'GHIM': 0,
    'GHIO': 0,
    'GHIORSO': 0,
    'GHIOTTO': 0,
    'GHIRARDI': 0,
    'GHIRINGHELLI': 0,
    'GHISELLI': 0,
    'GHISLAINE': 1,
    'GHIZ': 0,
    'GHOBRIAL': 0,
    'GHODS': 0,
    'GHODSI': 0,
    'GHOLAMI': 0,
    'GHOLAR': 0,
    'GHOLSON': 0,
    'GHOLSTON': 0,
    'GHORBANI': 0,
    'GHORI': 0,
    'GHORLEY': 0,
    'GHORMLEY': 0,
    'GHOSE': 0,
    'GHOSH': 0,
    'GHOSHAL': 0,
    'GHOSN': 0,
    'GHOST': 0,
    'GHOSTON': 0,
    'GHOTRA': 0,
    'GHOUSE': 0,
    'GHRIST': 0,
    'GHULAM': 0,
    'GHUMAN': 0,
    'GHUMMAN': 0,
    'GI': 0,
    'GIA': 0.9756097560975611,
    'GIACALONE': 0,
    'GIACCHETTI': 0,
    'GIACCHI': 0,
    'GIACCHINO': 0,
    'GIACCIO': 0,
    'GIACCO': 0,
    'GIACCONE': 0,
    'GIACHETTI': 0,
    'GIACHINO': 0,
    'GIACINTO': 0,
    'GIACOBBE': 0,
    'GIACOBBI': 0,
    'GIACOLETTI': 0,
    'GIACOLETTO': 0,
    'GIACOLONE': 0,
    'GIACOMA': 0,
    'GIACOMAZZI': 0,
    'GIACOMELLI': 0,
    'GIACOMETTI': 0,
    'GIACOMI': 0,
    'GIACOMINI': 0,
    'GIACOMINO': 0,
    'GIACOMO': 0,
    'GIACONA': 0,
    'GIACONE': 0,
    'GIACONIA': 0,
    'GIACOPELLI': 0,
    'GIAIMO': 0,
    'GIALAMAS': 0,
    'GIALANELLA': 0,
    'GIALLANZA': 0,
    'GIALLOMBARDO': 0,
    'GIALLONARDO': 0,
    'GIAMALVA': 0,
    'GIAMANCO': 0,
    'GIAMBALVO': 0,
    'GIAMBANCO': 0,
    'GIAMBATTISTA': 0,
    'GIAMBELLUCA': 0,
    'GIAMBONA': 0,
    'GIAMBRA': 0,
    'GIAMBRONE': 0,
    'GIAMBRUNO': 0,
    'GIAMETTA': 0,
    'GIAMMALVA': 0,
    'GIAMMALVO': 0,
    'GIAMMANCO': 0,
    'GIAMMARCO': 0,
    'GIAMMARIA': 0,
    'GIAMMARINO': 0,
    'GIAMMATTEI': 0,
    'GIAMMATTEO': 0,
    'GIAMMICHELE': 0,
    'GIAMMONA': 0,
    'GIAMO': 0,
    'GIAMPA': 0,
    'GIAMPAOLI': 0,
    'GIAMPAOLO': 0,
    'GIAMPAPA': 0,
    'GIAMPIETRO': 0,
    'GIAMPINO': 0,
    'GIAN': 0,
    'GIANAKOS': 0,
    'GIANARIS': 0,
    'GIANATASIO': 0,
    'GIANCARLO': 0,
    'GIANCASPRO': 0,
    'GIANCATERINO': 0,
    'GIANCOLA': 0,
    'GIANDOMENICO': 0,
    'GIANDONATO': 0,
    'GIANELLA': 0,
    'GIANELLI': 0,
    'GIANELLONI': 0,
    'GIANETTI': 0,
    'GIANFAGNA': 0,
    'GIANFORTE': 0,
    'GIANFRANCESCO': 0,
    'GIANG': 0,
    'GIANGIACOMO': 0,
    'GIANGIULIO': 0,
    'GIANGRANDE': 0,
    'GIANGRASSO': 0,
    'GIANGRECO': 0,
    'GIANGREGORIO': 0,
    'GIANGROSSO': 0,
    'GIANI': 0,
    'GIANINI': 0,
    'GIANINO': 0,
    'GIANNA': 0.9615384615384616,
    'GIANNAKOPOULOS': 0,
    'GIANNAMORE': 0,
    'GIANNANDREA': 0,
    'GIANNANTONIO': 0,
    'GIANNASCOLI': 0,
    'GIANNATTASIO': 0,
    'GIANNECCHINI': 0,
    'GIANNELLA': 0,
    'GIANNELLI': 0,
    'GIANNESCHI': 0,
    'GIANNETTA': 0,
    'GIANNETTI': 0,
    'GIANNETTINO': 0,
    'GIANNETTO': 0,
    'GIANNI': 0,
    'GIANNICO': 0,
    'GIANNINI': 0,
    'GIANNINO': 0,
    'GIANNOBILE': 0,
    'GIANNOLA': 0,
    'GIANNONE': 0,
    'GIANNONI': 0,
    'GIANNOPOULOS': 0,
    'GIANNOS': 0,
    'GIANNOSA': 0,
    'GIANNOTTA': 0,
    'GIANNOTTI': 0,
    'GIANNUZZI': 0,
    'GIANO': 0,
    'GIANOLA': 0,
    'GIANOLI': 0,
    'GIANOPOULOS': 0,
    'GIANOPULOS': 0,
    'GIANOS': 0,
    'GIANOTTI': 0,
    'GIANQUINTO': 0,
    'GIANSANTE': 0,
    'GIANSANTI': 0,
    'GIANT': 0,
    'GIANTONIO': 0,
    'GIANUNZIO': 0,
    'GIAP': 0,
    'GIAQUINTA': 0,
    'GIAQUINTO': 0,
    'GIARAMITA': 0,
    'GIARD': 0,
    'GIARDIELLO': 0,
    'GIARDINA': 0,
    'GIARDINELLI': 0,
    'GIARDINI': 0,
    'GIARDINO': 0,
    'GIARLA': 0,
    'GIARMO': 0,
    'GIARRAFFA': 0,
    'GIARRAPUTO': 0,
    'GIARRATANA': 0,
    'GIARRATANO': 0,
    'GIARRIZZO': 0,
    'GIARRUSSO': 0,
    'GIASSON': 0,
    'GIATTINO': 0,
    'GIAUQUE': 0,
    'GIBA': 0,
    'GIBALA': 0,
    'GIBALDI': 0,
    'GIBAS': 0,
    'GIBAU': 0,
    'GIBB': 0,
    'GIBBAR': 0,
    'GIBBARD': 0,
    'GIBBEL': 0,
    'GIBBENS': 0,
    'GIBBER': 0,
    'GIBBES': 0,
    'GIBBINGS': 0,
    'GIBBINS': 0,
    'GIBBLE': 0,
    'GIBBON': 0,
    'GIBBONEY': 0,
    'GIBBONS': 0,
    'GIBBS': 0,
    'GIBBSON': 0,
    'GIBBY': 0,
    'GIBEAU': 0,
    'GIBEAULT': 0,
    'GIBEAUT': 0,
    'GIBEL': 0,
    'GIBELYOU': 0,
    'GIBENS': 0,
    'GIBERSON': 0,
    'GIBERT': 0,
    'GIBERTI': 0,
    'GIBES': 0,
    'GIBIAN': 0,
    'GIBILISCO': 0,
    'GIBLER': 0,
    'GIBLIN': 0,
    'GIBNEY': 0,
    'GIBO': 0,
    'GIBONEY': 0,
    'GIBOYEAUX': 0,
    'GIBSON': 0,
    'GICK': 0,
    'GICKER': 0,
    'GIDARO': 0,
    'GIDCUMB': 0,
    'GIDDEN': 0,
    'GIDDENS': 0,
    'GIDDEON': 0,
    'GIDDINGS': 0,
    'GIDDINS': 0,
    'GIDDIS': 0,
    'GIDEL': 0,
    'GIDEN': 0,
    'GIDENKO': 0,
    'GIDEON': 0,
    'GIDEONS': 0,
    'GIDGET': 1,
    'GIDLEY': 0,
    'GIDLUND': 0,
    'GIDNEY': 0,
    'GIDO': 0,
    'GIDRON': 0,
    'GIDWANI': 0,
    'GIEBEL': 0,
    'GIEBELHAUS': 0,
    'GIEBER': 0,
    'GIEBINK': 0,
    'GIEBLER': 0,
    'GIEBNER': 0,
    'GIECK': 0,
    'GIEDD': 0,
    'GIEDRAITIS': 0,
    'GIEDT': 0,
    'GIEFER': 0,
    'GIEG': 0,
    'GIEGER': 0,
    'GIEGERICH': 0,
    'GIEHL': 0,
    'GIEL': 0,
    'GIELAROWSKI': 0,
    'GIELEN': 0,
    'GIELLA': 0,
    'GIELLO': 0,
    'GIELOW': 0,
    'GIEM': 0,
    'GIEMZA': 0,
    'GIENAPP': 0,
    'GIENGER': 0,
    'GIER': 0,
    'GIERA': 0,
    'GIERACH': 0,
    'GIERCZAK': 0,
    'GIERE': 0,
    'GIERER': 0,
    'GIERHART': 0,
    'GIERING': 0,
    'GIERINGER': 0,
    'GIERISCH': 0,
    'GIERKE': 0,
    'GIERL': 0,
    'GIERLACH': 0,
    'GIERMAN': 0,
    'GIEROK': 0,
    'GIERS': 0,
    'GIERSCH': 0,
    'GIERSDORF': 0,
    'GIERSZEWSKI': 0,
    'GIERTZ': 0,
    'GIERUT': 0,
    'GIES': 0,
    'GIESBRECHT': 0,
    'GIESCHEN': 0,
    'GIESE': 0,
    'GIESECKE': 0,
    'GIESEKE': 0,
    'GIESEKING': 0,
    'GIESEL': 0,
    'GIESELER': 0,
    'GIESELMAN': 0,
    'GIESEMAN': 0,
    'GIESEMANN': 0,
    'GIESEN': 0,
    'GIESER': 0,
    'GIESEY': 0,
    'GIESICK': 0,
    'GIESIGE': 0,
    'GIESING': 0,
    'GIESKE': 0,
    'GIESKEN': 0,
    'GIESLER': 0,
    'GIESMAN': 0,
    'GIESS': 0,
    'GIESSEL': 0,
    'GIESSINGER': 0,
    'GIESSLER': 0,
    'GIEST': 0,
    'GIESTING': 0,
    'GIESY': 0,
    'GIETL': 0,
    'GIETZ': 0,
    'GIETZEN': 0,
    'GIFFELS': 0,
    'GIFFEN': 0,
    'GIFFEY': 0,
    'GIFFIN': 0,
    'GIFFORD': 0,
    'GIFT': 0,
    'GIGANDET': 0,
    'GIGANTE': 0,
    'GIGANTI': 0,
    'GIGAX': 0,
    'GIGER': 0,
    'GIGGER': 0,
    'GIGGETTS': 0,
    'GIGGEY': 0,
    'GIGGY': 0,
    'GIGI': 0.9756097560975611,
    'GIGL': 0,
    'GIGLER': 0,
    'GIGLI': 0,
    'GIGLIA': 0,
    'GIGLIELLO': 0,
    'GIGLIO': 0,
    'GIGLIOTTI': 0,
    'GIGNAC': 0,
    'GIGNILLIAT': 0,
    'GIGON': 0,
    'GIGOT': 0,
    'GIGOUS': 0,
    'GIGOWSKI': 0,
    'GIGSTAD': 0,
    'GIGSTEAD': 0,
    'GIGUERE': 0,
    'GIGUIERE': 0,
    'GIJON': 0,
    'GIKAS': 0,
    'GIL': 0.45489006823351025,
    'GILAD': 0,
    'GILANI': 0,
    'GILARDI': 0,
    'GILB': 0,
    'GILBAR': 0,
    'GILBAUGH': 0,
    'GILBEAU': 0,
    'GILBEAUX': 0,
    'GILBERG': 0,
    'GILBERT': 0.6811050738501568,
    'GILBERTE': 1,
    'GILBERTI': 0,
    'GILBERTIE': 0,
    'GILBERTO': 0.9933774834437086,
    'GILBERTS': 0,
    'GILBERTSEN': 0,
    'GILBERTSON': 0,
    'GILBEY': 0,
    'GILBO': 0,
    'GILBODY': 0,
    'GILBOE': 0,
    'GILBOW': 0,
    'GILBOY': 0,
    'GILBRAITH': 0,
    'GILBREATH': 0,
    'GILBRECH': 0,
    'GILBRETH': 0,
    'GILBRIDE': 0,
    'GILBY': 0,
    'GILCHER': 0,
    'GILCHREST': 0,
    'GILCHRIEST': 0,
    'GILCHRIST': 0,
    'GILCREASE': 0,
    'GILCREAST': 0,
    'GILCREST': 0,
    'GILCRIST': 0,
    'GILDA': 0.995575221238938,
    'GILDART': 0,
    'GILDAY': 0,
    'GILDE': 0,
    'GILDEA': 0,
    'GILDEHAUS': 0,
    'GILDEMEISTER': 0,
    'GILDEN': 0,
    'GILDER': 0,
    'GILDERSLEEVE': 0,
    'GILDING': 0,
    'GILDNER': 0,
    'GILDO': 0,
    'GILDON': 0,
    'GILDOW': 0,
    'GILE': 0,
    'GILER': 0,
    'GILES': 0,
    'GILESPIE': 0,
    'GILETTE': 0,
    'GILEWSKI': 0,
    'GILFEATHER': 0,
    'GILFERT': 0,
    'GILFILEN': 0,
    'GILFILLAN': 0,
    'GILFOIL': 0,
    'GILFORD': 0,
    'GILFOY': 0,
    'GILFOYLE': 0,
    'GILFUS': 0,
    'GILG': 0,
    'GILGALLON': 0,
    'GILGAN': 0,
    'GILGE': 0,
    'GILGEN': 0,
    'GILGENBACH': 0,
    'GILGER': 0,
    'GILGORE': 0,
    'GILHAM': 0,
    'GILHEANY': 0,
    'GILHOOL': 0,
    'GILHOOLEY': 0,
    'GILHOOLY': 0,
    'GILHOUSEN': 0,
    'GILHULY': 0,
    'GILI': 0,
    'GILIBERTI': 0,
    'GILIBERTO': 0,
    'GILILLAND': 0,
    'GILINSKY': 0,
    'GILIO': 0,
    'GILIS': 0,
    'GILJE': 0,
    'GILK': 0,
    'GILKER': 0,
    'GILKERSON': 0,
    'GILKES': 0,
    'GILKESON': 0,
    'GILKEY': 0,
    'GILKINSON': 0,
    'GILKISON': 0,
    'GILKS': 0,
    'GILL': 0,
    'GILLAHAN': 0,
    'GILLAM': 0,
    'GILLAN': 0,
    'GILLAND': 0,
    'GILLANDERS': 0,
    'GILLANI': 0,
    'GILLAR': 0,
    'GILLARD': 0,
    'GILLASPIE': 0,
    'GILLASPY': 0,
    'GILLCRIST': 0,
    'GILLE': 0,
    'GILLEAN': 0,
    'GILLECE': 0,
    'GILLEECE': 0,
    'GILLELAND': 0,
    'GILLEM': 0,
    'GILLEN': 0,
    'GILLENS': 0,
    'GILLENTINE': 0,
    'GILLENWATER': 0,
    'GILLENWATERS': 0,
    'GILLEO': 0,
    'GILLEON': 0,
    'GILLER': 0,
    'GILLERAN': 0,
    'GILLERT': 0,
    'GILLES': 0,
    'GILLESPI': 0,
    'GILLESPIE': 0,
    'GILLESPY': 0,
    'GILLET': 0,
    'GILLETT': 0,
    'GILLETTE': 0,
    'GILLEY': 0,
    'GILLEYLEN': 0,
    'GILLFILLAN': 0,
    'GILLHAM': 0,
    'GILLHOUSE': 0,
    'GILLI': 0,
    'GILLIAM': 0,
    'GILLIAMS': 0,
    'GILLIAN': 0.8708272859216256,
    'GILLIAND': 0,
    'GILLIANS': 0,
    'GILLIARD': 0,
    'GILLIATT': 0,
    'GILLICH': 0,
    'GILLICK': 0,
    'GILLIE': 0,
    'GILLIES': 0,
    'GILLIG': 0,
    'GILLIGAN': 0,
    'GILLIHAN': 0,
    'GILLIKIN': 0,
    'GILLILAN': 0,
    'GILLILAND': 0,
    'GILLIM': 0,
    'GILLIN': 0,
    'GILLING': 0,
    'GILLINGER': 0,
    'GILLINGHAM': 0,
    'GILLINGS': 0,
    'GILLINS': 0,
    'GILLIO': 0,
    'GILLIOM': 0,
    'GILLION': 0,
    'GILLIS': 0,
    'GILLISON': 0,
    'GILLISPIE': 0,
    'GILLISS': 0,
    'GILLIT': 0,
    'GILLITZER': 0,
    'GILLIUM': 0,
    'GILLMAN': 0,
    'GILLMANN': 0,
    'GILLMEISTER': 0,
    'GILLMER': 0,
    'GILLMING': 0,
    'GILLMOR': 0,
    'GILLMORE': 0,
    'GILLO': 0,
    'GILLOCK': 0,
    'GILLOGLY': 0,
    'GILLOM': 0,
    'GILLON': 0,
    'GILLOOLEY': 0,
    'GILLOOLY': 0,
    'GILLOT': 0,
    'GILLOTT': 0,
    'GILLOTTE': 0,
    'GILLOTTI': 0,
    'GILLOW': 0,
    'GILLPATRICK': 0,
    'GILLS': 0,
    'GILLSON': 0,
    'GILLULY': 0,
    'GILLUM': 0,
    'GILLUND': 0,
    'GILLUS': 0,
    'GILLY': 0,
    'GILLYARD': 0,
    'GILMA': 1,
    'GILMAN': 0,
    'GILMARTIN': 0,
    'GILMER': 0,
    'GILMET': 0,
    'GILMOR': 0,
    'GILMORE': 0,
    'GILMOUR': 0,
    'GILNER': 0,
    'GILO': 0,
    'GILOMEN': 0,
    'GILOT': 0,
    'GILPATRIC': 0,
    'GILPATRICK': 0,
    'GILPEN': 0,
    'GILPIN': 0,
    'GILRAY': 0,
    'GILREATH': 0,
    'GILROY': 0,
    'GILSDORF': 0,
    'GILSENAN': 0,
    'GILSETH': 0,
    'GILSINGER': 0,
    'GILSON': 0,
    'GILSRUD': 0,
    'GILSTAD': 0,
    'GILSTER': 0,
    'GILSTRAP': 0,
    'GILTINAN': 0,
    'GILTNER': 0,
    'GILTON': 0,
    'GILTZ': 0,
    'GILVARY': 0,
    'GILVIN': 0,
    'GILYARD': 0,
    'GILZOW': 0,
    'GIM': 0,
    'GIMA': 0,
    'GIMBEL': 0,
    'GIMBER': 0,
    'GIMBERT': 0,
    'GIMBLE': 0,
    'GIMBRONE': 0,
    'GIMENES': 0,
    'GIMENEZ': 0,
    'GIMENO': 0,
    'GIMINO': 0,
    'GIMLER': 0,
    'GIMLIN': 0,
    'GIMM': 0,
    'GIMPEL': 0,
    'GIMPLE': 0,
    'GIMSON': 0,
    'GIN': 0,
    'GINA': 0.9989909182643795,
    'GINART': 0,
    'GINCHEREAU': 0,
    'GINDA': 0,
    'GINDELE': 0,
    'GINDER': 0,
    'GINDHART': 0,
    'GINDI': 0,
    'GINDIN': 0,
    'GINDLESBERGER': 0,
    'GINDLESPERGER': 0,
    'GINDLING': 0,
    'GINDT': 0,
    'GINEL': 0,
    'GINER': 0,
    'GINES': 0,
    'GINETTE': 1,
    'GINEVAN': 0,
    'GINEZ': 0,
    'GING': 0,
    'GINGELL': 0,
    'GINGER': 0.9872241579558653,
    'GINGERELLA': 0,
    'GINGERELLI': 0,
    'GINGERICH': 0,
    'GINGERY': 0,
    'GINGHER': 0,
    'GINGLES': 0,
    'GINGO': 0,
    'GINGOLD': 0,
    'GINGRAS': 0,
    'GINGRICH': 0,
    'GINI': 0,
    'GINIS': 0,
    'GINKEL': 0,
    'GINLEY': 0,
    'GINN': 0,
    'GINNANE': 0,
    'GINNERY': 0,
    'GINNETT': 0,
    'GINNETTI': 0,
    'GINNEVER': 0,
    'GINNINGS': 0,
    'GINNIS': 0,
    'GINNS': 0,
    'GINNY': 1,
    'GINO': 0.9852216748768473,
    'GINOCCHIO': 0,
    'GINOLFI': 0,
    'GINORIO': 0,
    'GINOS': 0,
    'GINOZA': 0,
    'GINS': 0,
    'GINSBACH': 0,
    'GINSBERG': 0,
    'GINSBURG': 0,
    'GINTER': 0,
    'GINTERT': 0,
    'GINTHER': 0,
    'GINTNER': 0,
    'GINTY': 0,
    'GINTZ': 0,
    'GINWRIGHT': 0,
    'GINYARD': 0,
    'GINZBURG': 0,
    'GINZEL': 0,
    'GIOCONDO': 0,
    'GIOE': 0,
    'GIOELI': 0,
    'GIOFFRE': 0,
    'GIOIA': 0,
    'GIOIELLI': 0,
    'GIOIOSA': 0,
    'GIOKAS': 0,
    'GIOMBETTI': 0,
    'GIOMETTI': 0,
    'GIOMI': 0,
    'GION': 0,
    'GIONET': 0,
    'GIONFRIDDO': 0,
    'GIONIS': 0,
    'GIONTA': 0,
    'GIONTI': 0,
    'GIORDANA': 0,
    'GIORDANI': 0,
    'GIORDANO': 0,
    'GIORGETTI': 0,
    'GIORGI': 0,
    'GIORGIANNI': 0,
    'GIORGINI': 0,
    'GIORGIO': 0,
    'GIORGIONE': 0,
    'GIORGIS': 0,
    'GIORLANDO': 0,
    'GIORNO': 0,
    'GIOSA': 0,
    'GIOTTA': 0,
    'GIOVACCHINI': 0,
    'GIOVAGNOLI': 0,
    'GIOVANELLI': 0,
    'GIOVANETTI': 0,
    'GIOVANINI': 0,
    'GIOVANNA': 1,
    'GIOVANNELLI': 0,
    'GIOVANNETTI': 0,
    'GIOVANNI': 0.9628610729023384,
    'GIOVANNIELLO': 0,
    'GIOVANNINI': 0,
    'GIOVANNONE': 0,
    'GIOVANNONI': 0,
    'GIOVANNUCCI': 0,
    'GIOVE': 0,
    'GIOVENCO': 0,
    'GIOVENGO': 0,
    'GIOVINAZZI': 0,
    'GIOVINAZZO': 0,
    'GIOVINCO': 0,
    'GIOVINE': 0,
    'GIOVINGO': 0,
    'GIOVINO': 0,
    'GIP': 0,
    'GIPE': 0,
    'GIPP': 0,
    'GIPPERT': 0,
    'GIPPLE': 0,
    'GIPS': 0,
    'GIPSON': 0,
    'GIRA': 0,
    'GIRADO': 0,
    'GIRAGOSIAN': 0,
    'GIRAL': 0,
    'GIRALDEZ': 0,
    'GIRALDI': 0,
    'GIRALDO': 0,
    'GIRALT': 0,
    'GIRARD': 0,
    'GIRARDEAU': 0,
    'GIRARDI': 0,
    'GIRARDIER': 0,
    'GIRARDIN': 0,
    'GIRARDO': 0,
    'GIRARDOT': 0,
    'GIRAUD': 0,
    'GIRAUDO': 0,
    'GIRAULT': 0,
    'GIRBACH': 0,
    'GIRD': 0,
    'GIRDLER': 0,
    'GIRDLESTONE': 0,
    'GIRDLEY': 0,
    'GIRDNER': 0,
    'GIRDWOOD': 0,
    'GIRDY': 0,
    'GIRE': 0,
    'GIRESI': 0,
    'GIRGENTI': 0,
    'GIRGIS': 0,
    'GIRI': 0,
    'GIRIMONTE': 0,
    'GIRKIN': 0,
    'GIRLEY': 0,
    'GIRLING': 0,
    'GIRLINGHOUSE': 0,
    'GIRMA': 0,
    'GIRMAN': 0,
    'GIRMAY': 0,
    'GIRNDT': 0,
    'GIRO': 0,
    'GIROD': 0,
    'GIRODAT': 0,
    'GIROIR': 0,
    'GIROLAMI': 0,
    'GIROLAMO': 0,
    'GIRON': 0,
    'GIRONA': 0,
    'GIRONDA': 0,
    'GIRONE': 0,
    'GIROT': 0,
    'GIROUARD': 0,
    'GIROUD': 0,
    'GIROUX': 0,
    'GIRRES': 0,
    'GIRSCH': 0,
    'GIRT': 0,
    'GIRTEN': 0,
    'GIRTMAN': 0,
    'GIRTON': 0,
    'GIRTS': 0,
    'GIRTY': 0,
    'GIRTZ': 0,
    'GIRVAN': 0,
    'GIRVEN': 0,
    'GIRVIN': 0,
    'GISBERT': 0,
    'GISCH': 0,
    'GISCHEL': 0,
    'GISCLAIR': 0,
    'GISCOMBE': 0,
    'GISE': 0,
    'GISEL': 0,
    'GISELA': 1,
    'GISELE': 1,
    'GISELLE': 1,
    'GISEWHITE': 0,
    'GISH': 0,
    'GISHIE': 0,
    'GISI': 0,
    'GISIN': 0,
    'GISKE': 0,
    'GISLASON': 0,
    'GISLER': 0,
    'GISMONDI': 0,
    'GISONDI': 0,
    'GISPERT': 0,
    'GISRIEL': 0,
    'GISSEL': 0,
    'GISSENDANER': 0,
    'GISSENDANNER': 0,
    'GISSER': 0,
    'GISSLER': 0,
    'GIST': 0,
    'GISTER': 0,
    'GISVOLD': 0,
    'GITA': 1,
    'GITCH': 0,
    'GITCHEL': 0,
    'GITCHELL': 0,
    'GITELMAN': 0,
    'GITELSON': 0,
    'GITHENS': 0,
    'GITLER': 0,
    'GITLIN': 0,
    'GITLITZ': 0,
    'GITMAN': 0,
    'GITOMER': 0,
    'GITS': 0,
    'GITSCHIER': 0,
    'GITT': 0,
    'GITTELMAN': 0,
    'GITTEMEIER': 0,
    'GITTENS': 0,
    'GITTER': 0,
    'GITTHENS': 0,
    'GITTINGER': 0,
    'GITTINGS': 0,
    'GITTINS': 0,
    'GITTLEMAN': 0,
    'GITTLER': 0,
    'GITTLESON': 0,
    'GITTMAN': 0,
    'GITTO': 0,
    'GITZ': 0,
    'GITZEN': 0,
    'GITZLAFF': 0,
    'GIUDICE': 0,
    'GIUDICI': 0,
    'GIUFFRE': 0,
    'GIUFFRIDA': 0,
    'GIUGGIO': 0,
    'GIUGLIANO': 0,
    'GIULIANA': 0,
    'GIULIANI': 0,
    'GIULIANO': 0,
    'GIULIETTI': 0,
    'GIUMARRA': 0,
    'GIUNTA': 0,
    'GIUNTINI': 0,
    'GIUNTOLI': 0,
    'GIUS': 0,
    'GIUSEFFI': 0,
    'GIUSEPPE': 1,
    'GIUSEPPINA': 1,
    'GIUSTI': 0,
    'GIUSTINIANI': 0,
    'GIUSTINO': 0,
    'GIUSTO': 0,
    'GIUSTRA': 0,
    'GIVAN': 0,
    'GIVANS': 0,
    'GIVEN': 0,
    'GIVENS': 0,
    'GIVHAN': 0,
    'GIVIDEN': 0,
    'GIVIN': 0,
    'GIVINGS': 0,
    'GIVINS': 0,
    'GIVLER': 0,
    'GIVNER': 0,
    'GIWA': 0,
    'GIX': 0,
    'GIZA': 0,
    'GIZAW': 0,
    'GIZINSKI': 0,
    'GIZOWSKI': 0,
    'GIZZARELLI': 0,
    'GIZZI': 0,
    'GIZZO': 0,
    'GJELAJ': 0,
    'GJERDE': 0,
    'GJERE': 0,
    'GJERSTAD': 0,
    'GJERTSEN': 0,
    'GJERTSON': 0,
    'GJESDAL': 0,
    'GJOKAJ': 0,
    'GJONAJ': 0,
    'GJONBALAJ': 0,
    'GJONI': 0,
    'GJOVIK': 0,
    'GJURAJ': 0,
    'GLAAB': 0,
    'GLAB': 0,
    'GLACE': 0,
    'GLACKEN': 0,
    'GLACKIN': 0,
    'GLAD': 0,
    'GLADBACH': 0,
    'GLADD': 0,
    'GLADDEN': 0,
    'GLADDING': 0,
    'GLADE': 0,
    'GLADEN': 0,
    'GLADER': 0,
    'GLADFELDER': 0,
    'GLADFELTER': 0,
    'GLADHILL': 0,
    'GLADIEUX': 0,
    'GLADIN': 0,
    'GLADING': 0,
    'GLADIS': 0.9584664536741214,
    'GLADISH': 0,
    'GLADKOWSKI': 0,
    'GLADLE': 0,
    'GLADMAN': 0,
    'GLADNEY': 0,
    'GLADSON': 0,
    'GLADSTEIN': 0,
    'GLADSTONE': 0,
    'GLADU': 0,
    'GLADUE': 0,
    'GLADWELL': 0,
    'GLADWIN': 0,
    'GLADY': 0.9615384615384616,
    'GLADYS': 0.9994149765990641,
    'GLADYSZ': 0,
    'GLAESER': 0,
    'GLAGOLA': 0,
    'GLAHN': 0,
    'GLAISTER': 0,
    'GLAIZE': 0,
    'GLAMANN': 0,
    'GLANCE': 0,
    'GLANCEY': 0,
    'GLANCY': 0,
    'GLAND': 0,
    'GLANDEN': 0,
    'GLANDER': 0,
    'GLANDON': 0,
    'GLANDORF': 0,
    'GLANDT': 0,
    'GLANN': 0,
    'GLANS': 0,
    'GLANT': 0,
    'GLANTON': 0,
    'GLANTZ': 0,
    'GLANVILLE': 0,
    'GLANZ': 0,
    'GLANZER': 0,
    'GLANZMAN': 0,
    'GLANZMANN': 0,
    'GLAPA': 0,
    'GLAPION': 0,
    'GLARDON': 0,
    'GLARNER': 0,
    'GLAROS': 0,
    'GLAS': 0,
    'GLASBERG': 0,
    'GLASBRENNER': 0,
    'GLASBY': 0,
    'GLASCO': 0,
    'GLASCOCK': 0,
    'GLASCOE': 0,
    'GLASCOTT': 0,
    'GLASCOW': 0,
    'GLASE': 0,
    'GLASEL': 0,
    'GLASENAPP': 0,
    'GLASENER': 0,
    'GLASER': 0,
    'GLASFORD': 0,
    'GLASGO': 0,
    'GLASGOW': 0,
    'GLASHEEN': 0,
    'GLASIER': 0,
    'GLASKER': 0,
    'GLASMAN': 0,
    'GLASMANN': 0,
    'GLASNAPP': 0,
    'GLASNER': 0,
    'GLASOE': 0,
    'GLASOW': 0,
    'GLASPELL': 0,
    'GLASPER': 0,
    'GLASPEY': 0,
    'GLASPIE': 0,
    'GLASPY': 0,
    'GLASS': 0,
    'GLASSBERG': 0,
    'GLASSBURN': 0,
    'GLASSCO': 0,
    'GLASSCOCK': 0,
    'GLASSCOE': 0,
    'GLASSE': 0,
    'GLASSEL': 0,
    'GLASSEN': 0,
    'GLASSER': 0,
    'GLASSETT': 0,
    'GLASSEY': 0,
    'GLASSFORD': 0,
    'GLASSGOW': 0,
    'GLASSLEY': 0,
    'GLASSMAN': 0,
    'GLASSMEYER': 0,
    'GLASSMIRE': 0,
    'GLASSMYER': 0,
    'GLASSNER': 0,
    'GLASSON': 0,
    'GLASSPOOLE': 0,
    'GLASSTETTER': 0,
    'GLASTER': 0,
    'GLASTETTER': 0,
    'GLASURE': 0,
    'GLATCZAK': 0,
    'GLATFELTER': 0,
    'GLATHAR': 0,
    'GLATT': 0,
    'GLATTER': 0,
    'GLATZ': 0,
    'GLATZEL': 0,
    'GLATZER': 0,
    'GLAU': 0,
    'GLAUB': 0,
    'GLAUBER': 0,
    'GLAUBITZ': 0,
    'GLAUDE': 0,
    'GLAUM': 0,
    'GLAUNER': 0,
    'GLAUS': 0,
    'GLAUSE': 0,
    'GLAUSER': 0,
    'GLAUSIER': 0,
    'GLAVAN': 0,
    'GLAVAS': 0,
    'GLAVE': 0,
    'GLAVES': 0,
    'GLAVEY': 0,
    'GLAVIANO': 0,
    'GLAVICH': 0,
    'GLAVIN': 0,
    'GLAWE': 0,
    'GLAWSON': 0,
    'GLAY': 0,
    'GLAYDS': 1,
    'GLAZ': 0,
    'GLAZA': 0,
    'GLAZAR': 0,
    'GLAZE': 0,
    'GLAZEBROOK': 0,
    'GLAZENER': 0,
    'GLAZER': 0,
    'GLAZEWSKI': 0,
    'GLAZIER': 0,
    'GLAZIK': 0,
    'GLAZMAN': 0,
    'GLAZNER': 0,
    'GLEAN': 0,
    'GLEASMAN': 0,
    'GLEASON': 0,
    'GLEATON': 0,
    'GLEAVE': 0,
    'GLEAVES': 0,
    'GLEBA': 0,
    'GLEBE': 0,
    'GLEBER': 0,
    'GLEBOCKI': 0,
    'GLEBUS': 0,
    'GLECKLER': 0,
    'GLEDHILL': 0,
    'GLEE': 0,
    'GLEED': 0,
    'GLEEN': 0,
    'GLEESE': 0,
    'GLEESING': 0,
    'GLEESON': 0,
    'GLEFFE': 0,
    'GLEGHORN': 0,
    'GLEIBERMAN': 0,
    'GLEICH': 0,
    'GLEICHAUF': 0,
    'GLEICHER': 0,
    'GLEICHMAN': 0,
    'GLEIM': 0,
    'GLEISBERG': 0,
    'GLEISER': 0,
    'GLEISNER': 0,
    'GLEISSNER': 0,
    'GLEIT': 0,
    'GLEITER': 0,
    'GLEITZ': 0,
    'GLEIXNER': 0,
    'GLEMBOCKI': 0,
    'GLEMSER': 0,
    'GLEN': 0.9896820383238576,
    'GLENDA': 1,
    'GLENDAY': 0,
    'GLENDE': 0,
    'GLENDENING': 0,
    'GLENDENNING': 0,
    'GLENDINNING': 0,
    'GLENDON': 0,
    'GLENDORA': 1,
    'GLENEWINKEL': 0,
    'GLENISTER': 0,
    'GLENN': 0.9020134228187919,
    'GLENNA': 0.9950248756218906,
    'GLENNAN': 0,
    'GLENNEN': 0,
    'GLENNEY': 0,
    'GLENNIE': 0.9216589861751152,
    'GLENNING': 0,
    'GLENNIS': 1,
    'GLENNON': 0,
    'GLENNY': 0,
    'GLENTZ': 0,
    'GLENTZER': 0,
    'GLENZ': 0,
    'GLENZER': 0,
    'GLERUM': 0,
    'GLESENER': 0,
    'GLESMANN': 0,
    'GLESNER': 0,
    'GLESS': 0,
    'GLESSING': 0,
    'GLESSNER': 0,
    'GLEW': 0,
    'GLEWWE': 0,
    'GLEYZER': 0,
    'GLEZEN': 0,
    'GLICA': 0,
    'GLICK': 0,
    'GLICKEN': 0,
    'GLICKER': 0,
    'GLICKMAN': 0,
    'GLICKSMAN': 0,
    'GLICKSTEIN': 0,
    'GLIDDEN': 0,
    'GLIDDON': 0,
    'GLIDER': 0,
    'GLIDEWELL': 0,
    'GLIDWELL': 0,
    'GLIEBE': 0,
    'GLIELMI': 0,
    'GLIEM': 0,
    'GLIENKE': 0,
    'GLIHA': 0,
    'GLIKMAN': 0,
    'GLIME': 0,
    'GLIMP': 0,
    'GLIMPSE': 0,
    'GLINDA': 1,
    'GLINES': 0,
    'GLINIECKI': 0,
    'GLINKA': 0,
    'GLINN': 0,
    'GLINSEY': 0,
    'GLINSKI': 0,
    'GLINSKY': 0,
    'GLINSMANN': 0,
    'GLINTON': 0,
    'GLISAN': 0,
    'GLISCH': 0,
    'GLISCZINSKI': 0,
    'GLISPIE': 0,
    'GLISPY': 0,
    'GLISSENDORF': 0,
    'GLISSMAN': 0,
    'GLISSMEYER': 0,
    'GLISSON': 0,
    'GLISTA': 0,
    'GLITZ': 0,
    'GLIVA': 0,
    'GLIWA': 0,
    'GLOBE': 0,
    'GLOBER': 0,
    'GLOBERMAN': 0,
    'GLOBKE': 0,
    'GLOBUS': 0,
    'GLOCK': 0,
    'GLOCKE': 0,
    'GLOCKNER': 0,
    'GLOCKZIN': 0,
    'GLOD': 0,
    'GLODE': 0,
    'GLODEK': 0,
    'GLODEN': 0,
    'GLODICH': 0,
    'GLODOSKI': 0,
    'GLODOWSKI': 0,
    'GLOE': 0,
    'GLOECKLER': 0,
    'GLOECKNER': 0,
    'GLOEDE': 0,
    'GLOEGE': 0,
    'GLOEKLER': 0,
    'GLOER': 0,
    'GLOFF': 0,
    'GLOGER': 0,
    'GLOGOWER': 0,
    'GLOGOWSKI': 0,
    'GLOMB': 0,
    'GLOMBOWSKI': 0,
    'GLOMSKI': 0,
    'GLON': 0,
    'GLONEK': 0,
    'GLOOR': 0,
    'GLOR': 0,
    'GLORDANO': 0,
    'GLORE': 0,
    'GLORIA': 0.995483180791632,
    'GLORIOSO': 0,
    'GLORY': 0.9740259740259739,
    'GLOS': 0,
    'GLOSE': 0,
    'GLOSEMEYER': 0,
    'GLOSENGER': 0,
    'GLOSS': 0,
    'GLOSSER': 0,
    'GLOSSIP': 0,
    'GLOSSNER': 0,
    'GLOSSON': 0,
    'GLOSSOP': 0,
    'GLOSSUP': 0,
    'GLOSTER': 0,
    'GLOSTON': 0,
    'GLOSUP': 0,
    'GLOTFELTY': 0,
    'GLOTH': 0,
    'GLOTZ': 0,
    'GLOTZBACH': 0,
    'GLOTZER': 0,
    'GLOUDEMAN': 0,
    'GLOUDEMANS': 0,
    'GLOVA': 0,
    'GLOVE': 0,
    'GLOVER': 0,
    'GLOVIER': 0,
    'GLOVINSKY': 0,
    'GLOW': 0,
    'GLOWA': 0,
    'GLOWACKI': 0,
    'GLOWACZ': 0,
    'GLOWASKI': 0,
    'GLOWCZEWSKI': 0,
    'GLOWE': 0,
    'GLOWIAK': 0,
    'GLOWICKI': 0,
    'GLOWINSKI': 0,
    'GLOWKA': 0,
    'GLOWSKI': 0,
    'GLOYD': 0,
    'GLUBKA': 0,
    'GLUCH': 0,
    'GLUCHOWSKI': 0,
    'GLUCK': 0,
    'GLUCKMAN': 0,
    'GLUCKSMAN': 0,
    'GLUECK': 0,
    'GLUECKERT': 0,
    'GLUESING': 0,
    'GLUGLA': 0,
    'GLUM': 0,
    'GLUMAC': 0,
    'GLUMM': 0,
    'GLUNT': 0,
    'GLUNZ': 0,
    'GLUPKER': 0,
    'GLUS': 0,
    'GLUSHKO': 0,
    'GLUSKIN': 0,
    'GLUSZEK': 0,
    'GLUTH': 0,
    'GLUTZ': 0,
    'GLUVNA': 0,
    'GLUZMAN': 0,
    'GLYMPH': 0,
    'GLYNDA': 1,
    'GLYNIS': 1,
    'GLYNN': 0,
    'GMACH': 0,
    'GMEINDER': 0,
    'GMEINER': 0,
    'GMEREK': 0,
    'GMITTER': 0,
    'GMUR': 0,
    'GMYREK': 0,
    'GNACINSKI': 0,
    'GNAD': 0,
    'GNADE': 0,
    'GNADT': 0,
    'GNAGEY': 0,
    'GNAGY': 0,
    'GNALL': 0,
    'GNAN': 0,
    'GNANDT': 0,
    'GNANN': 0,
    'GNAT': 0,
    'GNATEK': 0,
    'GNAU': 0,
    'GNAZZO': 0,
    'GNECCO': 0,
    'GNEGY': 0,
    'GNEHM': 0,
    'GNEITING': 0,
    'GNERRE': 0,
    'GNEWUCH': 0,
    'GNIADEK': 0,
    'GNIAZDOWSKI': 0,
    'GNIEWEK': 0,
    'GNOZA': 0,
    'GNUSE': 0,
    'GNYP': 0,
    'GO': 0,
    'GOACHER': 0,
    'GOAD': 0,
    'GOADE': 0,
    'GOAN': 0,
    'GOANS': 0,
    'GOAR': 0,
    'GOARD': 0,
    'GOATCHER': 0,
    'GOATEE': 0,
    'GOATES': 0,
    'GOATLEY': 0,
    'GOATS': 0,
    'GOBA': 0,
    'GOBAH': 0,
    'GOBAR': 0,
    'GOBBEL': 0,
    'GOBBELL': 0,
    'GOBBER': 0,
    'GOBBI': 0,
    'GOBBLE': 0,
    'GOBBO': 0,
    'GOBEA': 0,
    'GOBEIL': 0,
    'GOBEILLE': 0,
    'GOBEL': 0,
    'GOBELI': 0,
    'GOBEN': 0,
    'GOBER': 0,
    'GOBERDHAN': 0,
    'GOBERT': 0,
    'GOBIE': 0,
    'GOBIN': 0,
    'GOBLE': 0,
    'GOBLER': 0,
    'GOBLIRSCH': 0,
    'GOBRAN': 0,
    'GOBRECHT': 0,
    'GOBROGGE': 0,
    'GOC': 0,
    'GOCAL': 0,
    'GOCEK': 0,
    'GOCH': 0,
    'GOCHA': 0,
    'GOCHANOUR': 0,
    'GOCHE': 0,
    'GOCHEE': 0,
    'GOCHENAUER': 0,
    'GOCHENAUR': 0,
    'GOCHENOUER': 0,
    'GOCHENOUR': 0,
    'GOCHEZ': 0,
    'GOCHIS': 0,
    'GOCHMAN': 0,
    'GOCHNAUER': 0,
    'GOCHNOUR': 0,
    'GOCKE': 0,
    'GOCKEL': 0,
    'GOCKEN': 0,
    'GOCKENBACH': 0,
    'GOCKLEY': 0,
    'GOCO': 0,
    'GODA': 0,
    'GODAIR': 0,
    'GODAIRE': 0,
    'GODAR': 0,
    'GODARD': 0,
    'GODAT': 0,
    'GODAWA': 0,
    'GODBEE': 0,
    'GODBEHERE': 0,
    'GODBER': 0,
    'GODBEY': 0,
    'GODBOLD': 0,
    'GODBOLE': 0,
    'GODBOLT': 0,
    'GODBOUT': 0,
    'GODBURN': 0,
    'GODBY': 0,
    'GODCHAUX': 0,
    'GODDARD': 0,
    'GODDEAU': 0,
    'GODDEN': 0,
    'GODDIN': 0,
    'GODDING': 0,
    'GODDU': 0,
    'GODDY': 0,
    'GODE': 0,
    'GODEAUX': 0,
    'GODEC': 0,
    'GODEJOHN': 0,
    'GODEK': 0,
    'GODEL': 0,
    'GODELL': 0,
    'GODEN': 0,
    'GODES': 0,
    'GODETTE': 0,
    'GODFREY': 0,
    'GODFROY': 0,
    'GODI': 0,
    'GODIER': 0,
    'GODIN': 0,
    'GODINA': 0,
    'GODINE': 0,
    'GODINES': 0,
    'GODINEZ': 0,
    'GODING': 0,
    'GODINHO': 0,
    'GODINO': 0,
    'GODISH': 0,
    'GODKIN': 0,
    'GODLESKI': 0,
    'GODLEWSKI': 0,
    'GODLEY': 0,
    'GODLOVE': 0,
    'GODMAN': 0,
    'GODO': 0,
    'GODON': 0,
    'GODOWN': 0,
    'GODOY': 0,
    'GODREAU': 0,
    'GODSELL': 0,
    'GODSEY': 0,
    'GODSHALK': 0,
    'GODSHALL': 0,
    'GODSIL': 0,
    'GODSOE': 0,
    'GODSON': 0,
    'GODSY': 0,
    'GODT': 0,
    'GODUTO': 0,
    'GODWARD': 0,
    'GODWIN': 0,
    'GODZIK': 0,
    'GOE': 0,
    'GOEB': 0,
    'GOEBEL': 0,
    'GOEBELER': 0,
    'GOEBERT': 0,
    'GOECKE': 0,
    'GOECKEL': 0,
    'GOECKER': 0,
    'GOECKERITZ': 0,
    'GOECKNER': 0,
    'GOECKS': 0,
    'GOEDDE': 0,
    'GOEDDEL': 0,
    'GOEDE': 0,
    'GOEDECKE': 0,
    'GOEDEKE': 0,
    'GOEDEKER': 0,
    'GOEDEL': 0,
    'GOEDEN': 0,
    'GOEDERS': 0,
    'GOEDERT': 0,
    'GOEDHART': 0,
    'GOEDICKE': 0,
    'GOEDKEN': 0,
    'GOEDTEL': 0,
    'GOEGLEIN': 0,
    'GOEHL': 0,
    'GOEHLE': 0,
    'GOEHLER': 0,
    'GOEHNER': 0,
    'GOEHRIG': 0,
    'GOEHRING': 0,
    'GOEHRINGER': 0,
    'GOEING': 0,
    'GOEKE': 0,
    'GOEKEN': 0,
    'GOEKLER': 0,
    'GOEL': 0,
    'GOELDNER': 0,
    'GOELLER': 0,
    'GOELLNER': 0,
    'GOELTZ': 0,
    'GOELZ': 0,
    'GOELZER': 0,
    'GOEMAAT': 0,
    'GOEMAN': 0,
    'GOEMBEL': 0,
    'GOEN': 0,
    'GOENAGA': 0,
    'GOENNER': 0,
    'GOENS': 0,
    'GOEPEL': 0,
    'GOEPFERT': 0,
    'GOEPFRICH': 0,
    'GOEPPINGER': 0,
    'GOEPPNER': 0,
    'GOERDT': 0,
    'GOERES': 0,
    'GOERG': 0,
    'GOERGE': 0,
    'GOERGEN': 0,
    'GOERGER': 0,
    'GOERGES': 0,
    'GOERIG': 0,
    'GOERING': 0,
    'GOERINGER': 0,
    'GOERKE': 0,
    'GOERL': 0,
    'GOERLICH': 0,
    'GOERLITZ': 0,
    'GOERNDT': 0,
    'GOERNER': 0,
    'GOERS': 0,
    'GOERSS': 0,
    'GOERTZ': 0,
    'GOERTZEN': 0,
    'GOERZ': 0,
    'GOERZEN': 0,
    'GOES': 0,
    'GOESCH': 0,
    'GOESCHEL': 0,
    'GOESER': 0,
    'GOESSL': 0,
    'GOESSLING': 0,
    'GOESSMAN': 0,
    'GOETCHIUS': 0,
    'GOETHALS': 0,
    'GOETHE': 0,
    'GOETHEL': 0,
    'GOETSCH': 0,
    'GOETSCHEL': 0,
    'GOETSCHIUS': 0,
    'GOETT': 0,
    'GOETTE': 0,
    'GOETTEL': 0,
    'GOETTEMOELLER': 0,
    'GOETTEN': 0,
    'GOETTER': 0,
    'GOETTING': 0,
    'GOETTL': 0,
    'GOETTLE': 0,
    'GOETTLER': 0,
    'GOETTLING': 0,
    'GOETTSCH': 0,
    'GOETTSCHE': 0,
    'GOETZ': 0,
    'GOETZE': 0,
    'GOETZEL': 0,
    'GOETZINGER': 0,
    'GOETZKE': 0,
    'GOETZMAN': 0,
    'GOETZMANN': 0,
    'GOEWERT': 0,
    'GOEWEY': 0,
    'GOEZ': 0,
    'GOFF': 0,
    'GOFFARD': 0,
    'GOFFE': 0,
    'GOFFENA': 0,
    'GOFFIGAN': 0,
    'GOFFIN': 0,
    'GOFFINET': 0,
    'GOFFMAN': 0,
    'GOFFNER': 0,
    'GOFFNEY': 0,
    'GOFFREDO': 0,
    'GOFMAN': 0,
    'GOFORTH': 0,
    'GOFOURTH': 0,
    'GOGA': 0,
    'GOGAL': 0,
    'GOGAN': 0,
    'GOGARTY': 0,
    'GOGAS': 0,
    'GOGEL': 0,
    'GOGER': 0,
    'GOGERTY': 0,
    'GOGGANS': 0,
    'GOGGIN': 0,
    'GOGGINS': 0,
    'GOGGLES': 0,
    'GOGGLEYE': 0,
    'GOGINENI': 0,
    'GOGINS': 0,
    'GOGLIA': 0,
    'GOGLIN': 0,
    'GOGNA': 0,
    'GOGO': 0,
    'GOGOL': 0,
    'GOGOLA': 0,
    'GOGOLIN': 0,
    'GOGOS': 0,
    'GOGUE': 0,
    'GOGUEN': 0,
    'GOH': 0,
    'GOHAR': 0,
    'GOHARI': 0,
    'GOHDE': 0,
    'GOHEEN': 0,
    'GOHEL': 0,
    'GOHIL': 0,
    'GOHL': 0,
    'GOHLKE': 0,
    'GOHMAN': 0,
    'GOHMANN': 0,
    'GOHN': 0,
    'GOHO': 0,
    'GOHR': 0,
    'GOHRING': 0,
    'GOHS': 0,
    'GOICOCHEA': 0,
    'GOICOECHEA': 0,
    'GOIK': 0,
    'GOIKE': 0,
    'GOIN': 0,
    'GOINES': 0,
    'GOING': 0,
    'GOINGS': 0,
    'GOINS': 0,
    'GOIS': 0,
    'GOIST': 0,
    'GOIT': 0,
    'GOITIA': 0,
    'GOITOM': 0,
    'GOJCAJ': 0,
    'GOJKOVICH': 0,
    'GOKE': 0,
    'GOKEE': 0,
    'GOKEY': 0,
    'GOKHALE': 0,
    'GOKHMAN': 0,
    'GOKOOL': 0,
    'GOL': 0,
    'GOLA': 0,
    'GOLAB': 0,
    'GOLABEK': 0,
    'GOLAN': 0,
    'GOLAND': 0,
    'GOLAR': 0,
    'GOLAS': 0,
    'GOLASH': 0,
    'GOLASZEWSKI': 0,
    'GOLAT': 0,
    'GOLATA': 0,
    'GOLATT': 0,
    'GOLAY': 0,
    'GOLBA': 0,
    'GOLBECK': 0,
    'GOLBEK': 0,
    'GOLBERG': 0,
    'GOLBERT': 0,
    'GOLBY': 0,
    'GOLD': 0,
    'GOLDA': 0.9316770186335402,
    'GOLDACKER': 0,
    'GOLDADE': 0,
    'GOLDAMMER': 0,
    'GOLDBACH': 0,
    'GOLDBAUM': 0,
    'GOLDBECK': 0,
    'GOLDBERG': 0,
    'GOLDBERGER': 0,
    'GOLDBLATT': 0,
    'GOLDBLOOM': 0,
    'GOLDBLUM': 0,
    'GOLDBURG': 0,
    'GOLDE': 0,
    'GOLDEN': 0.053390282968499736,
    'GOLDENBAUM': 0,
    'GOLDENBERG': 0,
    'GOLDENSTEIN': 0,
    'GOLDENTHAL': 0,
    'GOLDER': 0,
    'GOLDESBERRY': 0,
    'GOLDEY': 0,
    'GOLDFADEN': 0,
    'GOLDFARB': 0,
    'GOLDFEDER': 0,
    'GOLDFEIN': 0,
    'GOLDFELD': 0,
    'GOLDFIELD': 0,
    'GOLDFINE': 0,
    'GOLDFINGER': 0,
    'GOLDFUSS': 0,
    'GOLDHABER': 0,
    'GOLDHAGEN': 0,
    'GOLDHAHN': 0,
    'GOLDHAMMER': 0,
    'GOLDHIRSCH': 0,
    'GOLDHORN': 0,
    'GOLDIE': 0.9783071033602723,
    'GOLDIN': 0,
    'GOLDING': 0,
    'GOLDINGER': 0,
    'GOLDIS': 0,
    'GOLDIZEN': 0,
    'GOLDKAMP': 0,
    'GOLDKLANG': 0,
    'GOLDMAN': 0,
    'GOLDMANN': 0,
    'GOLDNER': 0,
    'GOLDRICH': 0,
    'GOLDRICK': 0,
    'GOLDRING': 0,
    'GOLDS': 0,
    'GOLDSBERRY': 0,
    'GOLDSBORO': 0,
    'GOLDSBOROUGH': 0,
    'GOLDSBURY': 0,
    'GOLDSBY': 0,
    'GOLDSCHMIDT': 0,
    'GOLDSHTEYN': 0,
    'GOLDSMITH': 0,
    'GOLDSON': 0,
    'GOLDSTEIN': 0,
    'GOLDSTIEN': 0,
    'GOLDSTINE': 0,
    'GOLDSTON': 0,
    'GOLDSTONE': 0,
    'GOLDSTROHM': 0,
    'GOLDSTROM': 0,
    'GOLDSWORTH': 0,
    'GOLDSWORTHY': 0,
    'GOLDTHORPE': 0,
    'GOLDTHWAIT': 0,
    'GOLDTHWAITE': 0,
    'GOLDTOOTH': 0,
    'GOLDTRAP': 0,
    'GOLDWASSER': 0,
    'GOLDWATER': 0,
    'GOLDWIRE': 0,
    'GOLDWYN': 0,
    'GOLDY': 0,
    'GOLDYN': 0,
    'GOLE': 0,
    'GOLEBIEWSKI': 0,
    'GOLEBIOWSKI': 0,
    'GOLEC': 0,
    'GOLEM': 0,
    'GOLEMAN': 0,
    'GOLEMBESKI': 0,
    'GOLEMBIESKI': 0,
    'GOLEMBIEWSKI': 0,
    'GOLEMO': 0,
    'GOLEMON': 0,
    'GOLEN': 0,
    'GOLER': 0,
    'GOLES': 0,
    'GOLESKI': 0,
    'GOLETZ': 0,
    'GOLEY': 0,
    'GOLEZ': 0,
    'GOLF': 0,
    'GOLFIN': 0,
    'GOLI': 0,
    'GOLIA': 0,
    'GOLIAN': 0,
    'GOLIAS': 0,
    'GOLICH': 0,
    'GOLICK': 0,
    'GOLIDAY': 0,
    'GOLIE': 0,
    'GOLIGHTLY': 0,
    'GOLIK': 0,
    'GOLIKE': 0,
    'GOLIN': 0,
    'GOLINI': 0,
    'GOLINO': 0,
    'GOLINSKI': 0,
    'GOLIO': 0,
    'GOLIS': 0,
    'GOLISANO': 0,
    'GOLISCH': 0,
    'GOLISH': 0,
    'GOLKA': 0,
    'GOLKE': 0,
    'GOLL': 0,
    'GOLLA': 0,
    'GOLLADAY': 0,
    'GOLLAHER': 0,
    'GOLLAHON': 0,
    'GOLLAN': 0,
    'GOLLAND': 0,
    'GOLLAPUDI': 0,
    'GOLLE': 0,
    'GOLLEHER': 0,
    'GOLLEHON': 0,
    'GOLLER': 0,
    'GOLLEY': 0,
    'GOLLHOFER': 0,
    'GOLLIDAY': 0,
    'GOLLIHAR': 0,
    'GOLLIHER': 0,
    'GOLLIHUE': 0,
    'GOLLIHUGH': 0,
    'GOLLIN': 0,
    'GOLLING': 0,
    'GOLLINGER': 0,
    'GOLLIVER': 0,
    'GOLLMER': 0,
    'GOLLNER': 0,
    'GOLLNICK': 0,
    'GOLLOB': 0,
    'GOLLOGLY': 0,
    'GOLLON': 0,
    'GOLLOTT': 0,
    'GOLLUB': 0,
    'GOLLWITZER': 0,
    'GOLLY': 0,
    'GOLMAN': 0,
    'GOLMON': 0,
    'GOLNICK': 0,
    'GOLOB': 0,
    'GOLOBIC': 0,
    'GOLOD': 0,
    'GOLOJUCH': 0,
    'GOLOMB': 0,
    'GOLOMBEK': 0,
    'GOLON': 0,
    'GOLONKA': 0,
    'GOLOVIN': 0,
    'GOLPHENEE': 0,
    'GOLPHIN': 0,
    'GOLSAN': 0,
    'GOLSBY': 0,
    'GOLSHAN': 0,
    'GOLSHANI': 0,
    'GOLSON': 0,
    'GOLSTON': 0,
    'GOLT': 0,
    'GOLTER': 0,
    'GOLTERMANN': 0,
    'GOLTRA': 0,
    'GOLTRY': 0,
    'GOLTZ': 0,
    'GOLUB': 0,
    'GOLUBIC': 0,
    'GOLUBSKI': 0,
    'GOLUS': 0,
    'GOLWITZER': 0,
    'GOLZ': 0,
    'GOMAA': 0,
    'GOMAN': 0,
    'GOMAR': 0,
    'GOMAS': 0,
    'GOMAZ': 0,
    'GOMBAR': 0,
    'GOMBAS': 0,
    'GOMBASH': 0,
    'GOMBER': 0,
    'GOMBERG': 0,
    'GOMBERT': 0,
    'GOMBOS': 0,
    'GOMBOSI': 0,
    'GOMEL': 0,
    'GOMER': 0,
    'GOMERA': 0,
    'GOMERSALL': 0,
    'GOMES': 0,
    'GOMEZ': 0,
    'GOMEZDIAZ': 0,
    'GOMEZGARCIA': 0,
    'GOMEZGOMEZ': 0,
    'GOMEZGONZALEZ': 0,
    'GOMEZHERNANDEZ': 0,
    'GOMEZLOPEZ': 0,
    'GOMEZMARTINEZ': 0,
    'GOMEZPEREZ': 0,
    'GOMEZRAMIREZ': 0,
    'GOMEZSANCHEZ': 0,
    'GOMILA': 0,
    'GOMILLIA': 0,
    'GOMILLION': 0,
    'GOMIS': 0,
    'GOMM': 0,
    'GOMMEL': 0,
    'GOMMER': 0,
    'GOMOLA': 0,
    'GOMOLKA': 0,
    'GOMOLL': 0,
    'GOMON': 0,
    'GOMORA': 0,
    'GOMORY': 0,
    'GOMPERS': 0,
    'GOMPERT': 0,
    'GOMPERTS': 0,
    'GOMPF': 0,
    'GOMPPER': 0,
    'GOMULA': 0,
    'GOMULKA': 0,
    'GOMZALEZ': 0,
    'GON': 0,
    'GONALES': 0,
    'GONALEZ': 0,
    'GONCALO': 0,
    'GONCALVES': 0,
    'GONCE': 0,
    'GONCHAR': 0,
    'GONCHAROV': 0,
    'GONCHER': 0,
    'GONCZY': 0,
    'GONDA': 0,
    'GONDAL': 0,
    'GONDECK': 0,
    'GONDEK': 0,
    'GONDER': 0,
    'GONDERMAN': 0,
    'GONDOLA': 0,
    'GONDOS': 0,
    'GONDRON': 0,
    'GONE': 0,
    'GONEAU': 0,
    'GONELL': 0,
    'GONELLA': 0,
    'GONES': 0,
    'GONET': 0,
    'GONEY': 0,
    'GONEZ': 0,
    'GONG': 0,
    'GONGALES': 0,
    'GONGALEZ': 0,
    'GONGAWARE': 0,
    'GONGLOFF': 0,
    'GONGOLA': 0,
    'GONGORA': 0,
    'GONGRE': 0,
    'GONGWER': 0,
    'GONI': 0,
    'GONIA': 0,
    'GONICK': 0,
    'GONIEA': 0,
    'GONIS': 0,
    'GONIWICHA': 0,
    'GONKA': 0,
    'GONNELLA': 0,
    'GONNELLI': 0,
    'GONNER': 0,
    'GONNERING': 0,
    'GONNERMAN': 0,
    'GONNEVILLE': 0,
    'GONOS': 0,
    'GONRING': 0,
    'GONSALES': 0,
    'GONSALEZ': 0,
    'GONSALVES': 0,
    'GONSER': 0,
    'GONSETH': 0,
    'GONSIEWSKI': 0,
    'GONSIOR': 0,
    'GONSKA': 0,
    'GONSKI': 0,
    'GONSMAN': 0,
    'GONSOULIN': 0,
    'GONSOWSKI': 0,
    'GONTAREK': 0,
    'GONTARZ': 0,
    'GONTER': 0,
    'GONTERMAN': 0,
    'GONTHIER': 0,
    'GONTZ': 0,
    'GONWA': 0,
    'GONYA': 0,
    'GONYAW': 0,
    'GONYEA': 0,
    'GONYEAU': 0,
    'GONYER': 0,
    'GONYO': 0,
    'GONYON': 0,
    'GONYOU': 0,
    'GONZ': 0,
    'GONZA': 0,
    'GONZABA': 0,
    'GONZAEZ': 0,
    'GONZAGA': 0,
    'GONZALES': 0,
    'GONZALEX': 0,
    'GONZALEZ': 0,
    'GONZALEZCRUZ': 0,
    'GONZALEZDIAZ': 0,
    'GONZALEZFLORES': 0,
    'GONZALEZGARCIA': 0,
    'GONZALEZGOMEZ': 0,
    'GONZALEZHERNAN': 0,
    'GONZALEZLOPEZ': 0,
    'GONZALEZMARTIN': 0,
    'GONZALEZPEREZ': 0,
    'GONZALEZRAMOS': 0,
    'GONZALEZREYES': 0,
    'GONZALEZRUIZ': 0,
    'GONZALEZSANCHE': 0,
    'GONZALEZTORRES': 0,
    'GONZALIS': 0,
    'GONZALO': 0.9821428571428572,
    'GONZALOS': 0,
    'GONZALVES': 0,
    'GONZALZ': 0,
    'GONZELES': 0,
    'GONZELEZ': 0,
    'GONZLES': 0,
    'GONZLEZ': 0,
    'GONZOLAS': 0,
    'GOO': 0,
    'GOOCH': 0,
    'GOOCHER': 0,
    'GOOD': 0,
    'GOODACRE': 0,
    'GOODAKER': 0,
    'GOODALE': 0,
    'GOODALL': 0,
    'GOODAN': 0,
    'GOODARD': 0,
    'GOODART': 0,
    'GOODARZI': 0,
    'GOODAY': 0,
    'GOODBAR': 0,
    'GOODBERLET': 0,
    'GOODBODY': 0,
    'GOODBRAKE': 0,
    'GOODBREAD': 0,
    'GOODBRED': 0,
    'GOODBURN': 0,
    'GOODCHILD': 0,
    'GOODDING': 0,
    'GOODE': 0,
    'GOODEAUX': 0,
    'GOODELL': 0,
    'GOODEMOTE': 0,
    'GOODEN': 0,
    'GOODENBERGER': 0,
    'GOODENOUGH': 0,
    'GOODENOW': 0,
    'GOODER': 0,
    'GOODERHAM': 0,
    'GOODERMOTE': 0,
    'GOODES': 0,
    'GOODEY': 0,
    'GOODFELLOW': 0,
    'GOODFIELD': 0,
    'GOODFRIEND': 0,
    'GOODGAME': 0,
    'GOODGE': 0,
    'GOODGER': 0,
    'GOODGION': 0,
    'GOODHALL': 0,
    'GOODHAND': 0,
    'GOODHART': 0,
    'GOODHEART': 0,
    'GOODHEW': 0,
    'GOODHOPE': 0,
    'GOODHUE': 0,
    'GOODIE': 0,
    'GOODIER': 0,
    'GOODIN': 0,
    'GOODINE': 0,
    'GOODING': 0,
    'GOODIS': 0,
    'GOODISON': 0,
    'GOODKIN': 0,
    'GOODKIND': 0,
    'GOODKNIGHT': 0,
    'GOODLAND': 0,
    'GOODLANDER': 0,
    'GOODLET': 0,
    'GOODLETT': 0,
    'GOODLEY': 0,
    'GOODLIFFE': 0,
    'GOODLIN': 0,
    'GOODLING': 0,
    'GOODLOE': 0,
    'GOODLOW': 0,
    'GOODLUCK': 0,
    'GOODLY': 0,
    'GOODMAN': 0,
    'GOODMANSON': 0,
    'GOODMEN': 0,
    'GOODMON': 0,
    'GOODNATURE': 0,
    'GOODNER': 0,
    'GOODNESS': 0,
    'GOODNEY': 0,
    'GOODNIGHT': 0,
    'GOODNITE': 0,
    'GOODNO': 0,
    'GOODNOE': 0,
    'GOODNOUGH': 0,
    'GOODNOW': 0,
    'GOODON': 0,
    'GOODPASTER': 0,
    'GOODPASTOR': 0,
    'GOODPASTURE': 0,
    'GOODREAU': 0,
    'GOODRICH': 0,
    'GOODRICK': 0,
    'GOODRIDGE': 0,
    'GOODRO': 0,
    'GOODROAD': 0,
    'GOODROE': 0,
    'GOODROW': 0,
    'GOODRUM': 0,
    'GOODS': 0,
    'GOODSELL': 0,
    'GOODSITE': 0,
    'GOODSON': 0,
    'GOODSPEED': 0,
    'GOODSTEIN': 0,
    'GOODVIN': 0,
    'GOODWATER': 0,
    'GOODWILL': 0,
    'GOODWILLIE': 0,
    'GOODWIN': 0,
    'GOODWINE': 0,
    'GOODWORTH': 0,
    'GOODWYN': 0,
    'GOODWYNE': 0,
    'GOODY': 0,
    'GOODYEAR': 0,
    'GOODYKE': 0,
    'GOODYKOONTZ': 0,
    'GOOGE': 0,
    'GOOGINS': 0,
    'GOOKIN': 0,
    'GOOKINS': 0,
    'GOOL': 0,
    'GOOLD': 0,
    'GOOLDY': 0,
    'GOOLER': 0,
    'GOOLESBY': 0,
    'GOOLEY': 0,
    'GOOLSBEE': 0,
    'GOOLSBY': 0,
    'GOON': 0,
    'GOONAN': 0,
    'GOOR': 0,
    'GOOS': 0,
    'GOOSBY': 0,
    'GOOSE': 0,
    'GOOSEBERRY': 0,
    'GOOSEN': 0,
    'GOOSEY': 0,
    'GOOSLIN': 0,
    'GOOSMAN': 0,
    'GOOSMANN': 0,
    'GOOSSEN': 0,
    'GOOSSENS': 0,
    'GOOSTREE': 0,
    'GOOT': 0,
    'GOOTEE': 0,
    'GOPAL': 0,
    'GOPALAKRISHNAN': 0,
    'GOPALAN': 0,
    'GOPAR': 0,
    'GOPAUL': 0,
    'GOPEN': 0,
    'GOPEZ': 0,
    'GOPHER': 0,
    'GOPIE': 0,
    'GOPIN': 0,
    'GOPINATH': 0,
    'GOPLEN': 0,
    'GOPLIN': 0,
    'GOPP': 0,
    'GOPPERT': 0,
    'GOR': 0,
    'GORA': 0,
    'GORAB': 0,
    'GORACKE': 0,
    'GORADIA': 0,
    'GORAJ': 0,
    'GORAK': 0,
    'GORAL': 0,
    'GORALCZYK': 0,
    'GORALSKI': 0,
    'GORAM': 0,
    'GORAN': 0,
    'GORANSON': 0,
    'GORAY': 0,
    'GORAYA': 0,
    'GORBACH': 0,
    'GORBAN': 0,
    'GORBEA': 0,
    'GORBET': 0,
    'GORBETT': 0,
    'GORBEY': 0,
    'GORBUNOV': 0,
    'GORBY': 0,
    'GORCZYCA': 0,
    'GORCZYNSKI': 0,
    'GORD': 0,
    'GORDA': 0,
    'GORDAN': 0,
    'GORDANIER': 0,
    'GORDAY': 0,
    'GORDE': 0,
    'GORDEN': 0,
    'GORDER': 0,
    'GORDEY': 0,
    'GORDIAN': 0,
    'GORDIANO': 0,
    'GORDIER': 0,
    'GORDILLO': 0,
    'GORDILS': 0,
    'GORDIN': 0,
    'GORDINEER': 0,
    'GORDINIER': 0,
    'GORDISH': 0,
    'GORDLEY': 0,
    'GORDNER': 0,
    'GORDO': 0,
    'GORDON': 0.6442420863532181,
    'GORDWIN': 0,
    'GORDY': 0,
    'GORE': 0,
    'GORECKI': 0,
    'GOREE': 0,
    'GOREHAM': 0,
    'GOREL': 0,
    'GORELICK': 0,
    'GORELIK': 0,
    'GORELL': 0,
    'GOREN': 0,
    'GORENA': 0,
    'GORENC': 0,
    'GORENFLO': 0,
    'GORENSTEIN': 0,
    'GORES': 0,
    'GORETSKI': 0,
    'GORETSKY': 0,
    'GOREY': 0,
    'GORG': 0,
    'GORGA': 0,
    'GORGAN': 0,
    'GORGAS': 0,
    'GORGE': 0,
    'GORGEN': 0,
    'GORGES': 0,
    'GORGIS': 0,
    'GORGOL': 0,
    'GORGON': 0,
    'GORGONE': 0,
    'GORGONIO': 0,
    'GORHAM': 0,
    'GORI': 0,
    'GORIA': 0,
    'GORIN': 0,
    'GORING': 0,
    'GORIS': 0,
    'GORKA': 0,
    'GORKOWSKI': 0,
    'GORLA': 0,
    'GORLEWSKI': 0,
    'GORLEY': 0,
    'GORLICK': 0,
    'GORLIN': 0,
    'GORMALLY': 0,
    'GORMAN': 0,
    'GORMELY': 0,
    'GORMLEY': 0,
    'GORMLY': 0,
    'GORMONT': 0,
    'GORMSEN': 0,
    'GORMUS': 0,
    'GORN': 0,
    'GORNALL': 0,
    'GORNEAULT': 0,
    'GORNEY': 0,
    'GORNIAK': 0,
    'GORNICK': 0,
    'GORNIK': 0,
    'GORNOWICZ': 0,
    'GORNTO': 0,
    'GORNY': 0,
    'GORO': 0,
    'GORODETSKY': 0,
    'GOROG': 0,
    'GORON': 0,
    'GOROSKI': 0,
    'GOROSPE': 0,
    'GOROSTIETA': 0,
    'GOROSTIZA': 0,
    'GORR': 0,
    'GORRA': 0,
    'GORRE': 0,
    'GORRELL': 0,
    'GORRES': 0,
    'GORRIE': 0,
    'GORRILL': 0,
    'GORRIN': 0,
    'GORRINGE': 0,
    'GORRIS': 0,
    'GORRITZ': 0,
    'GORROSTIETA': 0,
    'GORRY': 0,
    'GORS': 0,
    'GORSAGE': 0,
    'GORSCH': 0,
    'GORSE': 0,
    'GORSEGNER': 0,
    'GORSH': 0,
    'GORSHE': 0,
    'GORSICH': 0,
    'GORSKE': 0,
    'GORSKI': 0,
    'GORSKY': 0,
    'GORSLINE': 0,
    'GORSON': 0,
    'GORST': 0,
    'GORSUCH': 0,
    'GORT': 0,
    'GORTAREZ': 0,
    'GORTE': 0,
    'GORTER': 0,
    'GORTH': 0,
    'GORTMAKER': 0,
    'GORTMAN': 0,
    'GORTNER': 0,
    'GORTNEY': 0,
    'GORTON': 0,
    'GORTSEMA': 0,
    'GORTZ': 0,
    'GORUM': 0,
    'GORUP': 0,
    'GORY': 0,
    'GORYL': 0,
    'GORZ': 0,
    'GORZALSKI': 0,
    'GORZKOWSKI': 0,
    'GORZYNSKI': 0,
    'GOSA': 0,
    'GOSAI': 0,
    'GOSAL': 0,
    'GOSALIA': 0,
    'GOSBY': 0,
    'GOSCH': 0,
    'GOSCHA': 0,
    'GOSCHE': 0,
    'GOSCHKE': 0,
    'GOSCIMINSKI': 0,
    'GOSCINIAK': 0,
    'GOSCINSKI': 0,
    'GOSDA': 0,
    'GOSDEN': 0,
    'GOSDIN': 0,
    'GOSE': 0,
    'GOSELIN': 0,
    'GOSEN': 0,
    'GOSEWISCH': 0,
    'GOSEY': 0,
    'GOSEYUN': 0,
    'GOSH': 0,
    'GOSHA': 0,
    'GOSHAY': 0,
    'GOSHE': 0,
    'GOSHEA': 0,
    'GOSHEN': 0,
    'GOSHERT': 0,
    'GOSHGARIAN': 0,
    'GOSHORN': 0,
    'GOSIER': 0,
    'GOSIEWSKI': 0,
    'GOSIK': 0,
    'GOSINE': 0,
    'GOSK': 0,
    'GOSLAR': 0,
    'GOSLEE': 0,
    'GOSLIN': 0,
    'GOSLINE': 0,
    'GOSLING': 0,
    'GOSMAN': 0,
    'GOSNELL': 0,
    'GOSNEY': 0,
    'GOSPODAREK': 0,
    'GOSS': 0,
    'GOSSAGE': 0,
    'GOSSAR': 0,
    'GOSSARD': 0,
    'GOSSE': 0,
    'GOSSEL': 0,
    'GOSSELIN': 0,
    'GOSSELINK': 0,
    'GOSSELL': 0,
    'GOSSEN': 0,
    'GOSSENS': 0,
    'GOSSER': 0,
    'GOSSERAND': 0,
    'GOSSERT': 0,
    'GOSSET': 0,
    'GOSSETT': 0,
    'GOSSETTE': 0,
    'GOSSIN': 0,
    'GOSSLER': 0,
    'GOSSLING': 0,
    'GOSSMAN': 0,
    'GOSSNER': 0,
    'GOSSOM': 0,
    'GOSSON': 0,
    'GOSTANIAN': 0,
    'GOSTKOWSKI': 0,
    'GOSTOMSKI': 0,
    'GOSTON': 0,
    'GOSVENER': 0,
    'GOSWAMI': 0,
    'GOSWICK': 0,
    'GOSZ': 0,
    'GOTAY': 0,
    'GOTBERG': 0,
    'GOTCH': 0,
    'GOTCHALL': 0,
    'GOTCHER': 0,
    'GOTELL': 0,
    'GOTELLI': 0,
    'GOTERA': 0,
    'GOTFREDSON': 0,
    'GOTH': 0,
    'GOTHAM': 0,
    'GOTHARD': 0,
    'GOTHBERG': 0,
    'GOTHE': 0,
    'GOTHELF': 0,
    'GOTHIER': 0,
    'GOTIERREZ': 0,
    'GOTKIN': 0,
    'GOTLIB': 0,
    'GOTLIEB': 0,
    'GOTO': 0,
    'GOTREAUX': 0,
    'GOTSCH': 0,
    'GOTSCHALL': 0,
    'GOTSHALL': 0,
    'GOTSIS': 0,
    'GOTT': 0,
    'GOTTA': 0,
    'GOTTARDI': 0,
    'GOTTARDO': 0,
    'GOTTBERG': 0,
    'GOTTE': 0,
    'GOTTER': 0,
    'GOTTESFELD': 0,
    'GOTTESMAN': 0,
    'GOTTFREDSON': 0,
    'GOTTFRIED': 0,
    'GOTTHARDT': 0,
    'GOTTHELF': 0,
    'GOTTI': 0,
    'GOTTIER': 0,
    'GOTTKE': 0,
    'GOTTLEIB': 0,
    'GOTTLER': 0,
    'GOTTLICH': 0,
    'GOTTLIEB': 0,
    'GOTTLOB': 0,
    'GOTTMAN': 0,
    'GOTTO': 0,
    'GOTTRON': 0,
    'GOTTS': 0,
    'GOTTSACKER': 0,
    'GOTTSCH': 0,
    'GOTTSCHALK': 0,
    'GOTTSCHALL': 0,
    'GOTTSCHLICH': 0,
    'GOTTSCHLING': 0,
    'GOTTSEGEN': 0,
    'GOTTSHALK': 0,
    'GOTTSHALL': 0,
    'GOTTSMAN': 0,
    'GOTTSTEIN': 0,
    'GOTTULA': 0,
    'GOTTUSO': 0,
    'GOTTWALD': 0,
    'GOTTWALT': 0,
    'GOTWALD': 0,
    'GOTWALS': 0,
    'GOTWALT': 0,
    'GOTZ': 0,
    'GOU': 0,
    'GOUBEAUX': 0,
    'GOUCH': 0,
    'GOUCHER': 0,
    'GOUD': 0,
    'GOUDA': 0,
    'GOUDARZI': 0,
    'GOUDE': 0,
    'GOUDEAU': 0,
    'GOUDELOCK': 0,
    'GOUDEY': 0,
    'GOUDGE': 0,
    'GOUDIE': 0,
    'GOUDREAU': 0,
    'GOUDREAULT': 0,
    'GOUDY': 0,
    'GOUGE': 0,
    'GOUGEON': 0,
    'GOUGER': 0,
    'GOUGH': 0,
    'GOUGHENOUR': 0,
    'GOUGHLER': 0,
    'GOUGHNOUR': 0,
    'GOUGIS': 0,
    'GOUGLER': 0,
    'GOUID': 0,
    'GOUIN': 0,
    'GOUINE': 0,
    'GOUKER': 0,
    'GOUL': 0,
    'GOULA': 0,
    'GOULART': 0,
    'GOULARTE': 0,
    'GOULAS': 0,
    'GOULBOURNE': 0,
    'GOULD': 0,
    'GOULDEN': 0,
    'GOULDER': 0,
    'GOULDIN': 0,
    'GOULDING': 0,
    'GOULDMAN': 0,
    'GOULDSMITH': 0,
    'GOULDTHORPE': 0,
    'GOULET': 0,
    'GOULETTE': 0,
    'GOUMAS': 0,
    'GOUNARIS': 0,
    'GOUND': 0,
    'GOUNDER': 0,
    'GOUNTANIS': 0,
    'GOUPIL': 0,
    'GOUR': 0,
    'GOURAS': 0,
    'GOURD': 0,
    'GOURDE': 0,
    'GOURDET': 0,
    'GOURDIN': 0,
    'GOURDINE': 0,
    'GOURE': 0,
    'GOURGUE': 0,
    'GOURGUES': 0,
    'GOURLAY': 0,
    'GOURLEY': 0,
    'GOURLIE': 0,
    'GOURNEAU': 0,
    'GOUSE': 0,
    'GOUSSE': 0,
    'GOUT': 0,
    'GOUTHIER': 0,
    'GOUTHRO': 0,
    'GOUTY': 0,
    'GOUVEA': 0,
    'GOUVEIA': 0,
    'GOUWENS': 0,
    'GOUX': 0,
    'GOUZALEZ': 0,
    'GOV': 0,
    'GOVAN': 0,
    'GOVANI': 0,
    'GOVANTES': 0,
    'GOVE': 0,
    'GOVEA': 0,
    'GOVEDNIK': 0,
    'GOVEIA': 0,
    'GOVEN': 0,
    'GOVENDER': 0,
    'GOVER': 0,
    'GOVERN': 0,
    'GOVERNALE': 0,
    'GOVERNO': 0,
    'GOVERNOR': 0,
    'GOVERO': 0,
    'GOVERT': 0,
    'GOVIA': 0,
    'GOVIER': 0,
    'GOVIG': 0,
    'GOVIL': 0,
    'GOVIN': 0,
    'GOVIND': 0,
    'GOVINDAN': 0,
    'GOVINDARAJAN': 0,
    'GOVONI': 0,
    'GOVREAU': 0,
    'GOVRO': 0,
    'GOW': 0,
    'GOWAN': 0,
    'GOWANS': 0,
    'GOWARD': 0,
    'GOWDA': 0,
    'GOWDER': 0,
    'GOWDY': 0,
    'GOWE': 0,
    'GOWELL': 0,
    'GOWEN': 0,
    'GOWENS': 0,
    'GOWER': 0,
    'GOWERS': 0,
    'GOWEY': 0,
    'GOWIE': 0,
    'GOWIN': 0,
    'GOWING': 0,
    'GOWINS': 0,
    'GOWLAND': 0,
    'GOWLER': 0,
    'GOWMAN': 0,
    'GOY': 0,
    'GOYA': 0,
    'GOYAL': 0,
    'GOYANES': 0,
    'GOYCO': 0,
    'GOYCOCHEA': 0,
    'GOYEN': 0,
    'GOYER': 0,
    'GOYETTE': 0,
    'GOYINS': 0,
    'GOYKE': 0,
    'GOYKHMAN': 0,
    'GOYNE': 0,
    'GOYNES': 0,
    'GOYTIA': 0,
    'GOYZUETA': 0,
    'GOZA': 0,
    'GOZALES': 0,
    'GOZALEZ': 0,
    'GOZDECKI': 0,
    'GOZMAN': 0,
    'GOZUM': 0,
    'GOZUN': 0,
    'GOZZI': 0,
    'GOZZO': 0,
    'GR': 0,
    'GRA': 0,
    'GRAACK': 0,
    'GRAAF': 0,
    'GRAAP': 0,
    'GRAAS': 0,
    'GRAB': 0,
    'GRABAN': 0,
    'GRABANSKI': 0,
    'GRABAR': 0,
    'GRABARCZYK': 0,
    'GRABAREK': 0,
    'GRABARZ': 0,
    'GRABAU': 0,
    'GRABB': 0,
    'GRABBE': 0,
    'GRABBER': 0,
    'GRABE': 0,
    'GRABEEL': 0,
    'GRABEK': 0,
    'GRABEL': 0,
    'GRABEN': 0,
    'GRABENHORST': 0,
    'GRABENSTEIN': 0,
    'GRABER': 0,
    'GRABERT': 0,
    'GRABHER': 0,
    'GRABHORN': 0,
    'GRABIAK': 0,
    'GRABIEC': 0,
    'GRABIEL': 0,
    'GRABILL': 0,
    'GRABIN': 0,
    'GRABINGER': 0,
    'GRABINSKI': 0,
    'GRABKO': 0,
    'GRABLE': 0,
    'GRABLER': 0,
    'GRABNER': 0,
    'GRABO': 0,
    'GRABON': 0,
    'GRABOSKI': 0,
    'GRABOSKY': 0,
    'GRABOW': 0,
    'GRABOWSKA': 0,
    'GRABOWSKI': 0,
    'GRABOWSKY': 0,
    'GRABOWY': 0,
    'GRABOYES': 0,
    'GRABSKI': 0,
    'GRABY': 0,
    'GRACA': 0,
    'GRACANIN': 0,
    'GRACE': 0.9501784726760846,
    'GRACEFFA': 0,
    'GRACEFFO': 0,
    'GRACELY': 0,
    'GRACEY': 0,
    'GRACH': 0,
    'GRACHEK': 0,
    'GRACI': 0,
    'GRACIA': 0.41753653444676414,
    'GRACIAN': 0,
    'GRACIANI': 0,
    'GRACIANO': 0,
    'GRACIAS': 0,
    'GRACIDA': 0,
    'GRACIE': 0.9825327510917031,
    'GRACIELA': 1,
    'GRACIK': 0,
    'GRACIN': 0,
    'GRACK': 0,
    'GRACY': 0,
    'GRACYALNY': 0,
    'GRACZYK': 0,
    'GRAD': 0,
    'GRADDICK': 0,
    'GRADDY': 0,
    'GRADE': 0,
    'GRADEL': 0,
    'GRADELESS': 0,
    'GRADEN': 0,
    'GRADER': 0,
    'GRADERT': 0,
    'GRADIAS': 0,
    'GRADICK': 0,
    'GRADILLA': 0,
    'GRADILLAS': 0,
    'GRADIN': 0,
    'GRADISHER': 0,
    'GRADL': 0,
    'GRADLE': 0,
    'GRADNEY': 0,
    'GRADNIGO': 0,
    'GRADO': 0,
    'GRADOS': 0,
    'GRADOVILLE': 0,
    'GRADOWSKI': 0,
    'GRADWELL': 0,
    'GRADWOHL': 0,
    'GRADY': 0.6928406466512702,
    'GRADZKI': 0,
    'GRAEB': 0,
    'GRAEBE': 0,
    'GRAEBER': 0,
    'GRAEBNER': 0,
    'GRAEF': 0,
    'GRAEFE': 0,
    'GRAEFEN': 0,
    'GRAEFF': 0,
    'GRAEME': 0,
    'GRAEN': 0,
    'GRAENING': 0,
    'GRAESE': 0,
    'GRAESER': 0,
    'GRAESSER': 0,
    'GRAESSLE': 0,
    'GRAETER': 0,
    'GRAETTINGER': 0,
    'GRAETZ': 0,
    'GRAEVE': 0,
    'GRAF': 0,
    'GRAFALS': 0,
    'GRAFE': 0,
    'GRAFELMAN': 0,
    'GRAFER': 0,
    'GRAFF': 0,
    'GRAFFAGNINO': 0,
    'GRAFFAM': 0,
    'GRAFFED': 0,
    'GRAFFEO': 0,
    'GRAFFIA': 0,
    'GRAFFIGNA': 0,
    'GRAFFIN': 0,
    'GRAFFIS': 0,
    'GRAFFIUS': 0,
    'GRAFFT': 0,
    'GRAFFUNDER': 0,
    'GRAFING': 0,
    'GRAFIUS': 0,
    'GRAFMAN': 0,
    'GRAFSTEIN': 0,
    'GRAFSTROM': 0,
    'GRAFT': 0,
    'GRAFTON': 0,
    'GRAGASIN': 0,
    'GRAGE': 0,
    'GRAGEDA': 0,
    'GRAGER': 0,
    'GRAGERT': 0,
    'GRAGG': 0,
    'GRAGGS': 0,
    'GRAGNANI': 0,
    'GRAGO': 0,
    'GRAGSON': 0,
    'GRAH': 0,
    'GRAHAM': 0.14295925661186562,
    'GRAHAME': 0,
    'GRAHAN': 0,
    'GRAHEK': 0,
    'GRAHL': 0,
    'GRAHMANN': 0,
    'GRAHN': 0,
    'GRAHOVAC': 0,
    'GRAICHEN': 0,
    'GRAIG': 0.9345794392523364,
    'GRAIL': 0,
    'GRAIN': 0,
    'GRAINER': 0,
    'GRAINGER': 0,
    'GRAISE': 0,
    'GRAJALES': 0,
    'GRAJCZYK': 0,
    'GRAJEDA': 0,
    'GRAJEK': 0,
    'GRAJEWSKI': 0,
    'GRALA': 0,
    'GRALAK': 0,
    'GRALEWSKI': 0,
    'GRALEY': 0,
    'GRALINSKI': 0,
    'GRALL': 0,
    'GRALLA': 0,
    'GRALTON': 0,
    'GRAM': 0,
    'GRAMA': 0,
    'GRAMAGLIA': 0,
    'GRAMAJO': 0,
    'GRAMAN': 0,
    'GRAMANN': 0,
    'GRAMAROSSA': 0,
    'GRAMAZIO': 0,
    'GRAMBERG': 0,
    'GRAMBLING': 0,
    'GRAMBO': 0,
    'GRAMBOW': 0,
    'GRAMBY': 0,
    'GRAME': 0,
    'GRAMELSPACHER': 0,
    'GRAMENZ': 0,
    'GRAMER': 0,
    'GRAMES': 0,
    'GRAMHAM': 0,
    'GRAMIAK': 0,
    'GRAMIGNA': 0,
    'GRAMKE': 0,
    'GRAMKOW': 0,
    'GRAMLEY': 0,
    'GRAMLICH': 0,
    'GRAMLICK': 0,
    'GRAMLING': 0,
    'GRAMLY': 0,
    'GRAMM': 0,
    'GRAMMAN': 0,
    'GRAMMAR': 0,
    'GRAMMAS': 0,
    'GRAMMATICO': 0,
    'GRAMMEL': 0,
    'GRAMMER': 0,
    'GRAMMES': 0,
    'GRAMMONT': 0,
    'GRAMOLINI': 0,
    'GRAMPP': 0,
    'GRAMPS': 0,
    'GRAMS': 0,
    'GRAMSE': 0,
    'GRAMSTAD': 0,
    'GRAMUGLIA': 0,
    'GRAMZA': 0,
    'GRAN': 0,
    'GRANA': 0,
    'GRANADA': 0,
    'GRANADE': 0,
    'GRANADINO': 0,
    'GRANADO': 0,
    'GRANADOS': 0,
    'GRANADOZ': 0,
    'GRANAHAN': 0,
    'GRANAM': 0,
    'GRANAT': 0,
    'GRANATA': 0,
    'GRANATELLI': 0,
    'GRANATH': 0,
    'GRANATO': 0,
    'GRANBERG': 0,
    'GRANBERRY': 0,
    'GRANBOIS': 0,
    'GRANBY': 0,
    'GRANCE': 0,
    'GRANCHELLI': 0,
    'GRAND': 0,
    'GRANDA': 0,
    'GRANDAHL': 0,
    'GRANDAL': 0,
    'GRANDAW': 0,
    'GRANDBERRY': 0,
    'GRANDBOIS': 0,
    'GRANDCHAMP': 0,
    'GRANDE': 0,
    'GRANDEL': 0,
    'GRANDELL': 0,
    'GRANDERSON': 0,
    'GRANDEY': 0,
    'GRANDFIELD': 0,
    'GRANDGENETT': 0,
    'GRANDGEORGE': 0,
    'GRANDI': 0,
    'GRANDIA': 0,
    'GRANDIN': 0,
    'GRANDINETTI': 0,
    'GRANDIS': 0,
    'GRANDISON': 0,
    'GRANDITS': 0,
    'GRANDIZIO': 0,
    'GRANDJEAN': 0,
    'GRANDLE': 0,
    'GRANDMAISON': 0,
    'GRANDMONT': 0,
    'GRANDO': 0,
    'GRANDOLFO': 0,
    'GRANDON': 0,
    'GRANDONE': 0,
    'GRANDOS': 0,
    'GRANDPIERRE': 0,
    'GRANDPRE': 0,
    'GRANDSON': 0,
    'GRANDSTAFF': 0,
    'GRANDSTRAND': 0,
    'GRANDT': 0,
    'GRANDY': 0,
    'GRANDYS': 0,
    'GRANE': 0,
    'GRANELL': 0,
    'GRANELLI': 0,
    'GRANER': 0,
    'GRANESE': 0,
    'GRANET': 0,
    'GRANEY': 0,
    'GRANFIELD': 0,
    'GRANFORS': 0,
    'GRANGAARD': 0,
    'GRANGE': 0,
    'GRANGER': 0,
    'GRANGROTH': 0,
    'GRANGRUTH': 0,
    'GRANHOLM': 0,
    'GRANICA': 0,
    'GRANICH': 0,
    'GRANICK': 0,
    'GRANIER': 0,
    'GRANIERI': 0,
    'GRANIERO': 0,
    'GRANILLO': 0,
    'GRANING': 0,
    'GRANINGER': 0,
    'GRANISON': 0,
    'GRANITE': 0,
    'GRANITO': 0,
    'GRANITTO': 0,
    'GRANITZ': 0,
    'GRANIZO': 0,
    'GRANJA': 0,
    'GRANKE': 0,
    'GRANLUND': 0,
    'GRANN': 0,
    'GRANNAN': 0,
    'GRANNELL': 0,
    'GRANNEMAN': 0,
    'GRANNEMANN': 0,
    'GRANNER': 0,
    'GRANNES': 0,
    'GRANNIS': 0,
    'GRANNUM': 0,
    'GRANO': 0,
    'GRANOFF': 0,
    'GRANOVSKY': 0,
    'GRANQUIST': 0,
    'GRANROTH': 0,
    'GRANRUTH': 0,
    'GRANSBERRY': 0,
    'GRANSBURY': 0,
    'GRANSDEN': 0,
    'GRANSEE': 0,
    'GRANSON': 0,
    'GRANSTAFF': 0,
    'GRANSTON': 0,
    'GRANSTROM': 0,
    'GRANT': 0.4201190337262224,
    'GRANTHAM': 0,
    'GRANTIER': 0,
    'GRANTLAND': 0,
    'GRANTON': 0,
    'GRANTZ': 0,
    'GRANUCCI': 0,
    'GRANUM': 0,
    'GRANVILLE': 0.8213552361396304,
    'GRANZELLA': 0,
    'GRANZIN': 0,
    'GRANZOW': 0,
    'GRAP': 0,
    'GRAPE': 0,
    'GRAPENTINE': 0,
    'GRAPER': 0,
    'GRAPES': 0,
    'GRAPEVINE': 0,
    'GRAPHENTEEN': 0,
    'GRAPHMAN': 0,
    'GRAPP': 0,
    'GRAPPE': 0,
    'GRAPPERHAUS': 0,
    'GRAPPIN': 0,
    'GRAPPONE': 0,
    'GRAS': 0,
    'GRASBERGER': 0,
    'GRASCH': 0,
    'GRASELA': 0,
    'GRASER': 0,
    'GRASHAM': 0,
    'GRASHEL': 0,
    'GRASHER': 0,
    'GRASHOFF': 0,
    'GRASHORN': 0,
    'GRASKA': 0,
    'GRASKE': 0,
    'GRASLEY': 0,
    'GRASMAN': 0,
    'GRASMICK': 0,
    'GRASON': 0,
    'GRASS': 0,
    'GRASSA': 0,
    'GRASSANO': 0,
    'GRASSE': 0,
    'GRASSEL': 0,
    'GRASSER': 0,
    'GRASSESCHI': 0,
    'GRASSETTI': 0,
    'GRASSHOFF': 0,
    'GRASSI': 0,
    'GRASSIA': 0,
    'GRASSIE': 0,
    'GRASSINGER': 0,
    'GRASSINI': 0,
    'GRASSL': 0,
    'GRASSLE': 0,
    'GRASSLEY': 0,
    'GRASSMAN': 0,
    'GRASSMANN': 0,
    'GRASSMUCK': 0,
    'GRASSMYER': 0,
    'GRASSO': 0,
    'GRASSROPE': 0,
    'GRASTON': 0,
    'GRASTY': 0,
    'GRASZ': 0,
    'GRAT': 0,
    'GRATA': 0,
    'GRATCH': 0,
    'GRATE': 0,
    'GRATER': 0,
    'GRATEREAUX': 0,
    'GRATES': 0,
    'GRATHWOHL': 0,
    'GRATHWOL': 0,
    'GRATIAS': 0,
    'GRATIOT': 0,
    'GRATKOWSKI': 0,
    'GRATO': 0,
    'GRATON': 0,
    'GRATOPP': 0,
    'GRATRIX': 0,
    'GRATSCH': 0,
    'GRATT': 0,
    'GRATTA': 0,
    'GRATTAN': 0,
    'GRATTO': 0,
    'GRATTON': 0,
    'GRATZ': 0,
    'GRATZER': 0,
    'GRAU': 0,
    'GRAUBARD': 0,
    'GRAUBART': 0,
    'GRAUBERGER': 0,
    'GRAUE': 0,
    'GRAUEL': 0,
    'GRAUER': 0,
    'GRAUERHOLZ': 0,
    'GRAUF': 0,
    'GRAUL': 0,
    'GRAULICH': 0,
    'GRAUMAN': 0,
    'GRAUMANN': 0,
    'GRAUNKE': 0,
    'GRAUPMAN': 0,
    'GRAUPMANN': 0,
    'GRAUPNER': 0,
    'GRAUS': 0,
    'GRAUSAM': 0,
    'GRAUSE': 0,
    'GRAUSO': 0,
    'GRAUSTEIN': 0,
    'GRAVA': 0,
    'GRAVAGNA': 0,
    'GRAVALLESE': 0,
    'GRAVANTE': 0,
    'GRAVATT': 0,
    'GRAVATTE': 0,
    'GRAVDAHL': 0,
    'GRAVE': 0,
    'GRAVEDONI': 0,
    'GRAVEEN': 0,
    'GRAVEL': 0,
    'GRAVELEY': 0,
    'GRAVELIN': 0,
    'GRAVELINE': 0,
    'GRAVELL': 0,
    'GRAVELLE': 0,
    'GRAVELY': 0,
    'GRAVELYN': 0,
    'GRAVEMAN': 0,
    'GRAVEN': 0,
    'GRAVENER': 0,
    'GRAVENOR': 0,
    'GRAVENS': 0,
    'GRAVENSTEIN': 0,
    'GRAVER': 0,
    'GRAVERSON': 0,
    'GRAVERT': 0,
    'GRAVES': 0,
    'GRAVESANDE': 0,
    'GRAVESEN': 0,
    'GRAVETT': 0,
    'GRAVETTE': 0,
    'GRAVIER': 0,
    'GRAVIETT': 0,
    'GRAVIL': 0,
    'GRAVILLE': 0,
    'GRAVINA': 0,
    'GRAVINESE': 0,
    'GRAVINO': 0,
    'GRAVIS': 0,
    'GRAVISS': 0,
    'GRAVITT': 0,
    'GRAVITTE': 0,
    'GRAVITZ': 0,
    'GRAVIUS': 0,
    'GRAVLEE': 0,
    'GRAVLEY': 0,
    'GRAVLIN': 0,
    'GRAVNING': 0,
    'GRAVOIS': 0,
    'GRAW': 0,
    'GRAWBURG': 0,
    'GRAWE': 0,
    'GRAWEY': 0,
    'GRAY': 0,
    'GRAYBEAL': 0,
    'GRAYBILL': 0,
    'GRAYCE': 1,
    'GRAYDEN': 0,
    'GRAYDON': 0,
    'GRAYER': 0,
    'GRAYES': 0,
    'GRAYKOWSKI': 0,
    'GRAYLESS': 0,
    'GRAYMAN': 0,
    'GRAYS': 0,
    'GRAYSON': 0,
    'GRAYSTON': 0,
    'GRAYTON': 0,
    'GRAYUM': 0,
    'GRAZA': 0,
    'GRAZER': 0,
    'GRAZETTE': 0,
    'GRAZI': 0,
    'GRAZIA': 0,
    'GRAZIADEI': 0,
    'GRAZIAN': 0,
    'GRAZIANI': 0,
    'GRAZIANO': 0,
    'GRAZIER': 0,
    'GRAZIO': 0,
    'GRAZIOLI': 0,
    'GRAZIOSE': 0,
    'GRAZIOSI': 0,
    'GRAZIOSO': 0,
    'GRAZULIS': 0,
    'GRAZYNA': 1,
    'GRAZZINI': 0,
    'GRBAVAC': 0,
    'GRBIC': 0,
    'GRCIC': 0,
    'GRDEN': 0,
    'GRDINA': 0,
    'GREAGER': 0,
    'GREAK': 0,
    'GREALIS': 0,
    'GREALISH': 0,
    'GREALY': 0,
    'GREAM': 0,
    'GREANEY': 0,
    'GREANY': 0,
    'GREAR': 0,
    'GREASER': 0,
    'GREASON': 0,
    'GREATENS': 0,
    'GREATHEAD': 0,
    'GREATHOUSE': 0,
    'GREATOREX': 0,
    'GREAUX': 0,
    'GREAVER': 0,
    'GREAVES': 0,
    'GREB': 0,
    'GREBB': 0,
    'GREBE': 0,
    'GREBEL': 0,
    'GREBEN': 0,
    'GREBENC': 0,
    'GREBER': 0,
    'GREBIN': 0,
    'GREBNER': 0,
    'GRECA': 0,
    'GRECCO': 0,
    'GRECH': 0,
    'GRECI': 0,
    'GRECIAN': 0,
    'GRECK': 0,
    'GRECO': 0,
    'GRECU': 0,
    'GRECZEK': 0,
    'GREDELL': 0,
    'GREDER': 0,
    'GREDLER': 0,
    'GREDVIG': 0,
    'GREEAR': 0,
    'GREECE': 0,
    'GREED': 0,
    'GREEDY': 0,
    'GREEFF': 0,
    'GREEK': 0,
    'GREELEY': 0,
    'GREELISH': 0,
    'GREELY': 0,
    'GREEM': 0,
    'GREEMAN': 0,
    'GREEN': 0,
    'GREENACRE': 0,
    'GREENALL': 0,
    'GREENAMYER': 0,
    'GREENAN': 0,
    'GREENAWALD': 0,
    'GREENAWALT': 0,
    'GREENAWAY': 0,
    'GREENBANK': 0,
    'GREENBAUM': 0,
    'GREENBERG': 0,
    'GREENBERGER': 0,
    'GREENBLAT': 0,
    'GREENBLATT': 0,
    'GREENBLUM': 0,
    'GREENBURG': 0,
    'GREENBUSH': 0,
    'GREENE': 0,
    'GREENEBAUM': 0,
    'GREENER': 0,
    'GREENERT': 0,
    'GREENEY': 0,
    'GREENFELD': 0,
    'GREENFELDER': 0,
    'GREENFIELD': 0,
    'GREENGARD': 0,
    'GREENGRASS': 0,
    'GREENHAGEN': 0,
    'GREENHALGE': 0,
    'GREENHALGH': 0,
    'GREENHAM': 0,
    'GREENHAW': 0,
    'GREENHECK': 0,
    'GREENHILL': 0,
    'GREENHOE': 0,
    'GREENHOLT': 0,
    'GREENHOUSE': 0,
    'GREENHOW': 0,
    'GREENHUT': 0,
    'GREENIA': 0,
    'GREENIDGE': 0,
    'GREENIER': 0,
    'GREENIG': 0,
    'GREENING': 0,
    'GREENINGER': 0,
    'GREENLAND': 0,
    'GREENLAW': 0,
    'GREENLEAF': 0,
    'GREENLEE': 0,
    'GREENLEES': 0,
    'GREENLER': 0,
    'GREENLEY': 0,
    'GREENLIEF': 0,
    'GREENLOW': 0,
    'GREENLUND': 0,
    'GREENLY': 0,
    'GREENMAN': 0,
    'GREENMYER': 0,
    'GREENO': 0,
    'GREENOUGH': 0,
    'GREENPLATE': 0,
    'GREENQUIST': 0,
    'GREENSFELDER': 0,
    'GREENSHIELDS': 0,
    'GREENSIDE': 0,
    'GREENSLADE': 0,
    'GREENSLATE': 0,
    'GREENSLIT': 0,
    'GREENSMITH': 0,
    'GREENSPAN': 0,
    'GREENSPON': 0,
    'GREENSPOON': 0,
    'GREENSPUN': 0,
    'GREENSTEIN': 0,
    'GREENSTONE': 0,
    'GREENSTREET': 0,
    'GREENTREE': 0,
    'GREENUP': 0,
    'GREENVILLE': 0,
    'GREENWADE': 0,
    'GREENWALD': 0,
    'GREENWALDT': 0,
    'GREENWALL': 0,
    'GREENWALT': 0,
    'GREENWAY': 0,
    'GREENWELL': 0,
    'GREENWICH': 0,
    'GREENWOLD': 0,
    'GREENWOOD': 0,
    'GREENZWEIG': 0,
    'GREEP': 0,
    'GREER': 0,
    'GREESON': 0,
    'GREET': 0,
    'GREETAN': 0,
    'GREETHAM': 0,
    'GREEVER': 0,
    'GREEVES': 0,
    'GREFE': 0,
    'GREFF': 0,
    'GREFSRUD': 0,
    'GREG': 0.9978890807906352,
    'GREGA': 0,
    'GREGAN': 0,
    'GREGER': 0,
    'GREGERSEN': 0,
    'GREGERSON': 0,
    'GREGG': 0.7544224765868887,
    'GREGGO': 0,
    'GREGGS': 0,
    'GREGO': 0,
    'GREGOIRE': 0,
    'GREGONIS': 0,
    'GREGOR': 0,
    'GREGORASH': 0,
    'GREGORCYK': 0,
    'GREGORCZYK': 0,
    'GREGOREK': 0,
    'GREGORI': 0,
    'GREGORIA': 1,
    'GREGORIAN': 0,
    'GREGORICH': 0,
    'GREGORIE': 0,
    'GREGORIO': 0.9096816114359975,
    'GREGORIUS': 0,
    'GREGOROWICZ': 0,
    'GREGORSKI': 0,
    'GREGORY': 0.9306830624105112,
    'GREGOS': 0,
    'GREGOVICH': 0,
    'GREGSON': 0,
    'GREGSTON': 0,
    'GREGUREK': 0,
    'GREGURICH': 0,
    'GREGUS': 0,
    'GREGWARE': 0,
    'GREHAN': 0,
    'GREHL': 0,
    'GREIBER': 0,
    'GREICO': 0,
    'GREIDANUS': 0,
    'GREIDER': 0,
    'GREIER': 0,
    'GREIF': 0,
    'GREIFE': 0,
    'GREIFF': 0,
    'GREIFZU': 0,
    'GREIG': 0,
    'GREIL': 0,
    'GREILING': 0,
    'GREIM': 0,
    'GREIMAN': 0,
    'GREIMANN': 0,
    'GREIN': 0,
    'GREINER': 0,
    'GREINERT': 0,
    'GREINKE': 0,
    'GREIS': 0,
    'GREISCH': 0,
    'GREISE': 0,
    'GREISEN': 0,
    'GREISER': 0,
    'GREISING': 0,
    'GREISINGER': 0,
    'GREISMAN': 0,
    'GREISS': 0,
    'GREIST': 0,
    'GREITZER': 0,
    'GREIVE': 0,
    'GREIWE': 0,
    'GRELA': 0,
    'GRELL': 0,
    'GRELLA': 0,
    'GRELLE': 0,
    'GRELLER': 0,
    'GRELLNER': 0,
    'GRELLO': 0,
    'GREMAUD': 0,
    'GREMAUX': 0,
    'GREMEL': 0,
    'GREMER': 0,
    'GREMILLION': 0,
    'GREMINGER': 0,
    'GREMLING': 0,
    'GREMMEL': 0,
    'GREMMELS': 0,
    'GREMMER': 0,
    'GREMMINGER': 0,
    'GREMO': 0,
    'GREMORE': 0,
    'GREMS': 0,
    'GREN': 0,
    'GRENADE': 0,
    'GRENARD': 0,
    'GRENAWALT': 0,
    'GRENCI': 0,
    'GRENDA': 0,
    'GRENDAHL': 0,
    'GRENDELL': 0,
    'GRENDZINSKI': 0,
    'GRENE': 0,
    'GRENELL': 0,
    'GRENERT': 0,
    'GRENET': 0,
    'GRENFELL': 0,
    'GRENGA': 0,
    'GRENGS': 0,
    'GRENHAM': 0,
    'GRENIER': 0,
    'GRENINGER': 0,
    'GRENKE': 0,
    'GRENKO': 0,
    'GRENN': 0,
    'GRENNAN': 0,
    'GRENNELL': 0,
    'GRENNIER': 0,
    'GRENNON': 0,
    'GRENOBLE': 0,
    'GRENON': 0,
    'GRENTZ': 0,
    'GRENVILLE': 0,
    'GRENZ': 0,
    'GREPO': 0,
    'GRES': 0,
    'GRESCH': 0,
    'GRESCHNER': 0,
    'GRESCO': 0,
    'GRESENS': 0,
    'GRESETH': 0,
    'GRESH': 0,
    'GRESHAM': 0,
    'GRESIK': 0,
    'GRESKA': 0,
    'GRESKI': 0,
    'GRESKO': 0,
    'GRESKOWIAK': 0,
    'GRESLEY': 0,
    'GRESOCK': 0,
    'GRESS': 0,
    'GRESSEL': 0,
    'GRESSER': 0,
    'GRESSETT': 0,
    'GRESSICK': 0,
    'GRESSLER': 0,
    'GRESSLEY': 0,
    'GRESSMAN': 0,
    'GRESTY': 0,
    'GRETA': 1,
    'GRETCH': 0,
    'GRETCHEN': 0.9981285090455395,
    'GRETEMAN': 0,
    'GRETEN': 0,
    'GRETENCORD': 0,
    'GRETH': 0,
    'GRETHEN': 0,
    'GRETHER': 0,
    'GRETO': 0,
    'GRETSCH': 0,
    'GRETSINGER': 0,
    'GRETT': 0,
    'GRETTA': 1,
    'GRETTER': 0,
    'GRETZ': 0,
    'GRETZINGER': 0,
    'GREUBEL': 0,
    'GREUEL': 0,
    'GREUFE': 0,
    'GREULICH': 0,
    'GREULING': 0,
    'GREUNKE': 0,
    'GREUTER': 0,
    'GREVE': 0,
    'GREVEL': 0,
    'GREVEN': 0,
    'GREVER': 0,
    'GREVES': 0,
    'GREVING': 0,
    'GREVIOUS': 0,
    'GREW': 0,
    'GREWAL': 0,
    'GREWE': 0,
    'GREWELL': 0,
    'GREWING': 0,
    'GREY': 0,
    'GREYDANUS': 0,
    'GREYER': 0,
    'GREYERBIEHL': 0,
    'GREYEYES': 0,
    'GREYNOLDS': 0,
    'GREYSON': 0,
    'GREYTAK': 0,
    'GREZLIK': 0,
    'GRGAS': 0,
    'GRGIC': 0,
    'GRGICH': 0,
    'GRGURICH': 0,
    'GRHAM': 0,
    'GRIB': 0,
    'GRIBB': 0,
    'GRIBBEN': 0,
    'GRIBBIN': 0,
    'GRIBBINS': 0,
    'GRIBBLE': 0,
    'GRIBBON': 0,
    'GRIBBONS': 0,
    'GRIBLER': 0,
    'GRICAR': 0,
    'GRICE': 0,
    'GRICELDA': 1,
    'GRICH': 0,
    'GRICIUS': 0,
    'GRICUS': 0,
    'GRIDDINE': 0,
    'GRIDER': 0,
    'GRIDLEY': 0,
    'GRIEB': 0,
    'GRIEBE': 0,
    'GRIEBEL': 0,
    'GRIEBENOW': 0,
    'GRIEBLING': 0,
    'GRIECO': 0,
    'GRIEDER': 0,
    'GRIEF': 0,
    'GRIEFF': 0,
    'GRIEGER': 0,
    'GRIEGO': 0,
    'GRIEM': 0,
    'GRIEME': 0,
    'GRIENER': 0,
    'GRIEP': 0,
    'GRIEPENSTROH': 0,
    'GRIEPENTROG': 0,
    'GRIEPP': 0,
    'GRIER': 0,
    'GRIERSON': 0,
    'GRIES': 0,
    'GRIESBACH': 0,
    'GRIESBAUM': 0,
    'GRIESDORN': 0,
    'GRIESE': 0,
    'GRIESEDIECK': 0,
    'GRIESEL': 0,
    'GRIESEMER': 0,
    'GRIESENAUER': 0,
    'GRIESER': 0,
    'GRIESHABER': 0,
    'GRIESHEIMER': 0,
    'GRIESHOP': 0,
    'GRIESINGER': 0,
    'GRIESMAN': 0,
    'GRIESMER': 0,
    'GRIESMEYER': 0,
    'GRIESS': 0,
    'GRIESSE': 0,
    'GRIESSEL': 0,
    'GRIESSER': 0,
    'GRIEST': 0,
    'GRIEVE': 0,
    'GRIEVES': 0,
    'GRIEWAHN': 0,
    'GRIFALDO': 0,
    'GRIFE': 0,
    'GRIFF': 0,
    'GRIFFARD': 0,
    'GRIFFAW': 0,
    'GRIFFEE': 0,
    'GRIFFEL': 0,
    'GRIFFEN': 0,
    'GRIFFES': 0,
    'GRIFFETH': 0,
    'GRIFFEY': 0,
    'GRIFFIE': 0,
    'GRIFFIES': 0,
    'GRIFFIETH': 0,
    'GRIFFIN': 0,
    'GRIFFING': 0,
    'GRIFFINS': 0,
    'GRIFFIOEN': 0,
    'GRIFFIS': 0,
    'GRIFFITH': 0,
    'GRIFFITHS': 0,
    'GRIFFITT': 0,
    'GRIFFITTS': 0,
    'GRIFFO': 0,
    'GRIFFON': 0,
    'GRIFFOR': 0,
    'GRIFFORD': 0,
    'GRIFFORE': 0,
    'GRIFFTH': 0,
    'GRIFFUS': 0,
    'GRIFFY': 0,
    'GRIFIN': 0,
    'GRIFITH': 0,
    'GRIFKA': 0,
    'GRIFO': 0,
    'GRIGAITIS': 0,
    'GRIGAR': 0,
    'GRIGAS': 0,
    'GRIGER': 0,
    'GRIGG': 0,
    'GRIGGERS': 0,
    'GRIGGS': 0,
    'GRIGLAK': 0,
    'GRIGLEY': 0,
    'GRIGNON': 0,
    'GRIGOLI': 0,
    'GRIGONIS': 0,
    'GRIGOR': 0,
    'GRIGORE': 0,
    'GRIGORIAN': 0,
    'GRIGOROV': 0,
    'GRIGORYAN': 0,
    'GRIGORYEV': 0,
    'GRIGSBY': 0,
    'GRIGSON': 0,
    'GRIJALBA': 0,
    'GRIJALVA': 0,
    'GRILE': 0,
    'GRILES': 0,
    'GRILEY': 0,
    'GRILL': 0,
    'GRILLE': 0,
    'GRILLEY': 0,
    'GRILLI': 0,
    'GRILLIOT': 0,
    'GRILLO': 0,
    'GRILLONE': 0,
    'GRILLOT': 0,
    'GRILLS': 0,
    'GRILO': 0,
    'GRIM': 0,
    'GRIMA': 0,
    'GRIMALDI': 0,
    'GRIMALDO': 0,
    'GRIMARD': 0,
    'GRIMAUD': 0,
    'GRIMBALL': 0,
    'GRIMBERG': 0,
    'GRIMBLE': 0,
    'GRIME': 0,
    'GRIMES': 0,
    'GRIMLAND': 0,
    'GRIMLEY': 0,
    'GRIMM': 0,
    'GRIMMAGE': 0,
    'GRIMME': 0,
    'GRIMMER': 0,
    'GRIMMETT': 0,
    'GRIMMETTE': 0,
    'GRIMMINGER': 0,
    'GRIMMITT': 0,
    'GRIMMIUS': 0,
    'GRIMS': 0,
    'GRIMSBY': 0,
    'GRIMSEY': 0,
    'GRIMSHAW': 0,
    'GRIMSLEY': 0,
    'GRIMSON': 0,
    'GRIMSRUD': 0,
    'GRIMSTAD': 0,
    'GRIMSTEAD': 0,
    'GRIMWOOD': 0,
    'GRIN': 0,
    'GRINA': 0,
    'GRINAGE': 0,
    'GRINAGER': 0,
    'GRINBERG': 0,
    'GRINBLAT': 0,
    'GRINDALL': 0,
    'GRINDE': 0,
    'GRINDEL': 0,
    'GRINDELAND': 0,
    'GRINDELL': 0,
    'GRINDER': 0,
    'GRINDLE': 0,
    'GRINDLEY': 0,
    'GRINDROD': 0,
    'GRINDSTAFF': 0,
    'GRINDY': 0,
    'GRINE': 0,
    'GRINER': 0,
    'GRINES': 0,
    'GRINESTAFF': 0,
    'GRING': 0,
    'GRINKER': 0,
    'GRINLEY': 0,
    'GRINMAN': 0,
    'GRINNAGE': 0,
    'GRINNAN': 0,
    'GRINNELL': 0,
    'GRINNEN': 0,
    'GRINOLDS': 0,
    'GRINSELL': 0,
    'GRINSHPUN': 0,
    'GRINSTEAD': 0,
    'GRINSTEINER': 0,
    'GRINSTEINNER': 0,
    'GRINSTON': 0,
    'GRINTER': 0,
    'GRINWIS': 0,
    'GRIP': 0,
    'GRIPE': 0,
    'GRIPENTROG': 0,
    'GRIPKA': 0,
    'GRIPP': 0,
    'GRIPPA': 0,
    'GRIPPALDI': 0,
    'GRIPPANDO': 0,
    'GRIPPE': 0,
    'GRIPPEN': 0,
    'GRIPPER': 0,
    'GRIPPI': 0,
    'GRIPPIN': 0,
    'GRIPPO': 0,
    'GRIPSHOVER': 0,
    'GRISAFFI': 0,
    'GRISAFI': 0,
    'GRISALES': 0,
    'GRISAMORE': 0,
    'GRISANTI': 0,
    'GRISBY': 0,
    'GRISCHOW': 0,
    'GRISCOM': 0,
    'GRISDALE': 0,
    'GRISE': 0,
    'GRISEL': 0.9433962264150944,
    'GRISELDA': 1,
    'GRISELL': 0,
    'GRISER': 0,
    'GRISET': 0,
    'GRISEZ': 0,
    'GRISH': 0,
    'GRISHABER': 0,
    'GRISHAM': 0,
    'GRISHAW': 0,
    'GRISI': 0,
    'GRISIER': 0,
    'GRISKO': 0,
    'GRISMER': 0,
    'GRISMORE': 0,
    'GRISOLIA': 0,
    'GRISPINO': 0,
    'GRISS': 0,
    'GRISSAM': 0,
    'GRISSETT': 0,
    'GRISSETTE': 0,
    'GRISSINGER': 0,
    'GRISSMAN': 0,
    'GRISSO': 0,
    'GRISSOM': 0,
    'GRISSON': 0,
    'GRIST': 0,
    'GRISWALD': 0,
    'GRISWELL': 0,
    'GRISWOLD': 0,
    'GRIT': 0,
    'GRITMAN': 0,
    'GRITSCH': 0,
    'GRITT': 0,
    'GRITTEN': 0,
    'GRITTER': 0,
    'GRITTERS': 0,
    'GRITTMAN': 0,
    'GRITTNER': 0,
    'GRITTON': 0,
    'GRITTS': 0,
    'GRITZ': 0,
    'GRITZMACHER': 0,
    'GRITZMAKER': 0,
    'GRIVAS': 0,
    'GRIVETTE': 0,
    'GRIVETTI': 0,
    'GRIVNA': 0,
    'GRIVOIS': 0,
    'GRIX': 0,
    'GRIZZAFFI': 0,
    'GRIZZARD': 0,
    'GRIZZEL': 0,
    'GRIZZELL': 0,
    'GRIZZLE': 0,
    'GROAH': 0,
    'GROARK': 0,
    'GROAT': 0,
    'GROB': 0,
    'GROBBEL': 0,
    'GROBE': 0,
    'GROBELNY': 0,
    'GROBEN': 0,
    'GROBER': 0,
    'GROBERG': 0,
    'GROBLEWSKI': 0,
    'GROBMAN': 0,
    'GROBSTEIN': 0,
    'GROCCIA': 0,
    'GROCE': 0,
    'GROCH': 0,
    'GROCHALA': 0,
    'GROCHMAL': 0,
    'GROCHOCKI': 0,
    'GROCHOLSKI': 0,
    'GROCHOW': 0,
    'GROCHOWALSKI': 0,
    'GROCHOWSKI': 0,
    'GROCKI': 0,
    'GROCOTT': 0,
    'GROD': 0,
    'GRODE': 0,
    'GRODECKI': 0,
    'GRODEN': 0,
    'GRODER': 0,
    'GRODI': 0,
    'GRODIN': 0,
    'GRODMAN': 0,
    'GRODNER': 0,
    'GRODSKI': 0,
    'GRODSKY': 0,
    'GRODY': 0,
    'GRODZICKI': 0,
    'GRODZKI': 0,
    'GROE': 0,
    'GROEBE': 0,
    'GROEBER': 0,
    'GROEBNER': 0,
    'GROEGER': 0,
    'GROEHLER': 0,
    'GROELING': 0,
    'GROEN': 0,
    'GROENDYK': 0,
    'GROENDYKE': 0,
    'GROENE': 0,
    'GROENENBOOM': 0,
    'GROENENDYK': 0,
    'GROENER': 0,
    'GROENEVELD': 0,
    'GROENEWEG': 0,
    'GROENEWOLD': 0,
    'GROENING': 0,
    'GROENINGER': 0,
    'GROENKE': 0,
    'GROEPER': 0,
    'GROEPPER': 0,
    'GROESBECK': 0,
    'GROESCH': 0,
    'GROESCHEL': 0,
    'GROESCHEN': 0,
    'GROESSER': 0,
    'GROETHE': 0,
    'GROETKEN': 0,
    'GROETSCH': 0,
    'GROETZINGER': 0,
    'GROEZINGER': 0,
    'GROF': 0,
    'GROFF': 0,
    'GROFT': 0,
    'GROGAN': 0,
    'GROGER': 0,
    'GROGG': 0,
    'GROH': 0,
    'GROHALL': 0,
    'GROHE': 0,
    'GROHMAN': 0,
    'GROHMANN': 0,
    'GROHN': 0,
    'GROHOL': 0,
    'GROHOLSKI': 0,
    'GROHOSKI': 0,
    'GROHOWSKI': 0,
    'GROHS': 0,
    'GROJEAN': 0,
    'GROLEAU': 0,
    'GROLEMUND': 0,
    'GROLL': 0,
    'GROLLER': 0,
    'GROLLMAN': 0,
    'GROM': 0,
    'GROMACKI': 0,
    'GROMADA': 0,
    'GROMALA': 0,
    'GROMAN': 0,
    'GROMASKI': 0,
    'GROME': 0,
    'GROMEK': 0,
    'GROMELSKI': 0,
    'GROMER': 0,
    'GROMIS': 0,
    'GROMKO': 0,
    'GROMLEY': 0,
    'GROMLING': 0,
    'GROMMES': 0,
    'GROMMESH': 0,
    'GROMMET': 0,
    'GROMOLL': 0,
    'GROMOWSKI': 0,
    'GRON': 0,
    'GRONA': 0,
    'GRONAU': 0,
    'GRONBACH': 0,
    'GRONBECK': 0,
    'GRONBERG': 0,
    'GRONCKI': 0,
    'GRONDA': 0,
    'GRONDAHL': 0,
    'GRONDIN': 0,
    'GRONE': 0,
    'GRONECK': 0,
    'GRONEFELD': 0,
    'GRONEK': 0,
    'GRONEMAN': 0,
    'GRONEMEYER': 0,
    'GRONENTHAL': 0,
    'GRONER': 0,
    'GRONERT': 0,
    'GRONES': 0,
    'GRONEWALD': 0,
    'GRONEWOLD': 0,
    'GRONHOLM': 0,
    'GRONHOLZ': 0,
    'GRONINGA': 0,
    'GRONINGER': 0,
    'GRONKE': 0,
    'GRONKOWSKI': 0,
    'GRONLUND': 0,
    'GRONNIGER': 0,
    'GRONNING': 0,
    'GRONOWSKI': 0,
    'GRONQUIST': 0,
    'GRONROOS': 0,
    'GRONSETH': 0,
    'GRONSKI': 0,
    'GRONSKY': 0,
    'GRONVOLD': 0,
    'GROO': 0,
    'GROODY': 0,
    'GROOM': 0,
    'GROOME': 0,
    'GROOMER': 0,
    'GROOMES': 0,
    'GROOMS': 0,
    'GROOS': 0,
    'GROOSE': 0,
    'GROOT': 0,
    'GROOTERS': 0,
    'GROOTHUIS': 0,
    'GROOVER': 0,
    'GROPP': 0,
    'GROPPE': 0,
    'GROPPER': 0,
    'GROPPI': 0,
    'GROS': 0,
    'GROSBERG': 0,
    'GROSCH': 0,
    'GROSCHE': 0,
    'GROSCOST': 0,
    'GROSDIDIER': 0,
    'GROSE': 0,
    'GROSECLOSE': 0,
    'GROSENBACH': 0,
    'GROSENHEIDER': 0,
    'GROSENICK': 0,
    'GROSETH': 0,
    'GROSFIELD': 0,
    'GROSH': 0,
    'GROSHANS': 0,
    'GROSHEK': 0,
    'GROSHENS': 0,
    'GROSHON': 0,
    'GROSHONG': 0,
    'GROSJEAN': 0,
    'GROSKO': 0,
    'GROSKOPF': 0,
    'GROSKREUTZ': 0,
    'GROSKY': 0,
    'GROSLAND': 0,
    'GROSMAN': 0,
    'GROSNICK': 0,
    'GROSPE': 0,
    'GROSS': 0,
    'GROSSAINT': 0,
    'GROSSARTH': 0,
    'GROSSBARD': 0,
    'GROSSBAUER': 0,
    'GROSSBERG': 0,
    'GROSSCUP': 0,
    'GROSSE': 0,
    'GROSSELL': 0,
    'GROSSEN': 0,
    'GROSSENBACHER': 0,
    'GROSSER': 0,
    'GROSSETT': 0,
    'GROSSFELD': 0,
    'GROSSHANS': 0,
    'GROSSHEIM': 0,
    'GROSSHUESCH': 0,
    'GROSSI': 0,
    'GROSSIE': 0,
    'GROSSINGER': 0,
    'GROSSKLAUS': 0,
    'GROSSKOPF': 0,
    'GROSSKREUTZ': 0,
    'GROSSKURTH': 0,
    'GROSSMAN': 0,
    'GROSSMANN': 0,
    'GROSSNICKLAUS': 0,
    'GROSSNICKLE': 0,
    'GROSSO': 0,
    'GROSSWILER': 0,
    'GROSVENOR': 0,
    'GROSZ': 0,
    'GROSZEK': 0,
    'GROTA': 0,
    'GROTBERG': 0,
    'GROTE': 0,
    'GROTEFEND': 0,
    'GROTEGUT': 0,
    'GROTELUESCHEN': 0,
    'GROTELUSCHEN': 0,
    'GROTENHUIS': 0,
    'GROTERS': 0,
    'GROTEWOLD': 0,
    'GROTH': 0,
    'GROTHAUS': 0,
    'GROTHE': 0,
    'GROTHEER': 0,
    'GROTHEN': 0,
    'GROTHER': 0,
    'GROTHMAN': 0,
    'GROTHOFF': 0,
    'GROTHOUSE': 0,
    'GROTHUES': 0,
    'GROTJAHN': 0,
    'GROTJAN': 0,
    'GROTJOHN': 0,
    'GROTKE': 0,
    'GROTON': 0,
    'GROTRIAN': 0,
    'GROTSKY': 0,
    'GROTT': 0,
    'GROTTE': 0,
    'GROTTO': 0,
    'GROTTON': 0,
    'GROTTS': 0,
    'GROTZ': 0,
    'GROTZINGER': 0,
    'GROTZKE': 0,
    'GROULX': 0,
    'GROUND': 0,
    'GROUNDS': 0,
    'GROUNDWATER': 0,
    'GROUP': 0,
    'GROUS': 0,
    'GROUSE': 0,
    'GROUT': 0,
    'GROUX': 0,
    'GROVE': 0,
    'GROVEMAN': 0,
    'GROVEN': 0,
    'GROVENSTEIN': 0,
    'GROVER': 0.7226738934056007,
    'GROVES': 0,
    'GROW': 0,
    'GROWCOCK': 0,
    'GROWDEN': 0,
    'GROWE': 0,
    'GROWER': 0,
    'GROWN': 0,
    'GROWNEY': 0,
    'GROY': 0,
    'GROYSMAN': 0,
    'GROZA': 0,
    'GROZE': 0,
    'GROZIER': 0,
    'GRUB': 0,
    'GRUBA': 0,
    'GRUBAUGH': 0,
    'GRUBB': 0,
    'GRUBBA': 0,
    'GRUBBE': 0,
    'GRUBBS': 0,
    'GRUBE': 0,
    'GRUBEL': 0,
    'GRUBEN': 0,
    'GRUBENHOFF': 0,
    'GRUBER': 0,
    'GRUBERT': 0,
    'GRUBIC': 0,
    'GRUBICH': 0,
    'GRUBIN': 0,
    'GRUBMAN': 0,
    'GRUBS': 0,
    'GRUBY': 0,
    'GRUCA': 0,
    'GRUCHACZ': 0,
    'GRUCHALA': 0,
    'GRUCHOW': 0,
    'GRUCZA': 0,
    'GRUDA': 0,
    'GRUDEN': 0,
    'GRUDIER': 0,
    'GRUDOWSKI': 0,
    'GRUDZIEN': 0,
    'GRUDZINSKI': 0,
    'GRUE': 0,
    'GRUEBEL': 0,
    'GRUEBELE': 0,
    'GRUEBER': 0,
    'GRUEL': 0,
    'GRUELL': 0,
    'GRUELLE': 0,
    'GRUEN': 0,
    'GRUENBAUM': 0,
    'GRUENBERG': 0,
    'GRUENDER': 0,
    'GRUENDLER': 0,
    'GRUENEBERG': 0,
    'GRUENEICH': 0,
    'GRUENENFELDER': 0,
    'GRUENER': 0,
    'GRUENEWALD': 0,
    'GRUENFELDER': 0,
    'GRUENHAGEN': 0,
    'GRUENING': 0,
    'GRUENINGER': 0,
    'GRUENKE': 0,
    'GRUENLOH': 0,
    'GRUENSTEIN': 0,
    'GRUENWALD': 0,
    'GRUER': 0,
    'GRUESBECK': 0,
    'GRUESCHOW': 0,
    'GRUESER': 0,
    'GRUETER': 0,
    'GRUETT': 0,
    'GRUETTER': 0,
    'GRUETTNER': 0,
    'GRUETZMACHER': 0,
    'GRUETZNER': 0,
    'GRUFF': 0,
    'GRUGAN': 0,
    'GRUGEL': 0,
    'GRUHL': 0,
    'GRUHLER': 0,
    'GRUHLKE': 0,
    'GRUHN': 0,
    'GRUHOT': 0,
    'GRUICH': 0,
    'GRUIDL': 0,
    'GRUIS': 0,
    'GRULICH': 0,
    'GRULKE': 0,
    'GRULKOWSKI': 0,
    'GRULLON': 0,
    'GRUM': 0,
    'GRUMAN': 0,
    'GRUMBACH': 0,
    'GRUMBINE': 0,
    'GRUMBLES': 0,
    'GRUMBLING': 0,
    'GRUMET': 0,
    'GRUMLEY': 0,
    'GRUMM': 0,
    'GRUMMAN': 0,
    'GRUMMEL': 0,
    'GRUMMER': 0,
    'GRUMMERT': 0,
    'GRUMMONS': 0,
    'GRUN': 0,
    'GRUNAU': 0,
    'GRUNBAUM': 0,
    'GRUNBERG': 0,
    'GRUNBERGER': 0,
    'GRUND': 0,
    'GRUNDAHL': 0,
    'GRUNDBERG': 0,
    'GRUNDEL': 0,
    'GRUNDEN': 0,
    'GRUNDER': 0,
    'GRUNDHAUSER': 0,
    'GRUNDHOEFER': 0,
    'GRUNDLER': 0,
    'GRUNDMAN': 0,
    'GRUNDMANN': 0,
    'GRUNDMEIER': 0,
    'GRUNDMEYER': 0,
    'GRUNDNER': 0,
    'GRUNDON': 0,
    'GRUNDSTROM': 0,
    'GRUNDVIG': 0,
    'GRUNDY': 0,
    'GRUNEISEN': 0,
    'GRUNENWALD': 0,
    'GRUNER': 0,
    'GRUNERT': 0,
    'GRUNEWALD': 0,
    'GRUNFELD': 0,
    'GRUNHUT': 0,
    'GRUNIG': 0,
    'GRUNIN': 0,
    'GRUNINGER': 0,
    'GRUNKE': 0,
    'GRUNKEMEYER': 0,
    'GRUNKLEE': 0,
    'GRUNLOH': 0,
    'GRUNOW': 0,
    'GRUNSETH': 0,
    'GRUNST': 0,
    'GRUNSTEIN': 0,
    'GRUNTORAD': 0,
    'GRUNWALD': 0,
    'GRUNWALDT': 0,
    'GRUNWELL': 0,
    'GRUNZA': 0,
    'GRUNZWEIG': 0,
    'GRUPA': 0,
    'GRUPE': 0,
    'GRUPP': 0,
    'GRUPPEN': 0,
    'GRUPPO': 0,
    'GRUS': 0,
    'GRUSCHOW': 0,
    'GRUSE': 0,
    'GRUSENDORF': 0,
    'GRUSH': 0,
    'GRUSHKIN': 0,
    'GRUSKA': 0,
    'GRUSKIN': 0,
    'GRUSS': 0,
    'GRUSSENDORF': 0,
    'GRUSSING': 0,
    'GRUSZCZYNSKI': 0,
    'GRUSZECKI': 0,
    'GRUSZEWSKI': 0,
    'GRUSZKA': 0,
    'GRUSZYNSKI': 0,
    'GRUTMAN': 0,
    'GRUTSCH': 0,
    'GRUTTADAURIA': 0,
    'GRUTTER': 0,
    'GRUTZ': 0,
    'GRUTZA': 0,
    'GRUTZIUS': 0,
    'GRUTZMACHER': 0,
    'GRUVER': 0,
    'GRUWELL': 0,
    'GRUZ': 0,
    'GRYCH': 0,
    'GRYCZEWSKI': 0,
    'GRYDER': 0,
    'GRYGA': 0,
    'GRYGIEL': 0,
    'GRYGIER': 0,
    'GRYGO': 0,
    'GRYGORCEWICZ': 0,
    'GRYMES': 0,
    'GRYN': 0,
    'GRYNIEWICZ': 0,
    'GRYP': 0,
    'GRYS': 0,
    'GRYSKIEWICZ': 0,
    'GRYSKO': 0,
    'GRYWALSKI': 0,
    'GRZANICH': 0,
    'GRZANKA': 0,
    'GRZEBYK': 0,
    'GRZECH': 0,
    'GRZECHOWIAK': 0,
    'GRZEGORCZYK': 0,
    'GRZEGOREK': 0,
    'GRZEGORZEWSKI': 0,
    'GRZEJKA': 0,
    'GRZELAK': 0,
    'GRZENDA': 0,
    'GRZENIA': 0,
    'GRZESIAK': 0,
    'GRZESIK': 0,
    'GRZESKOWIAK': 0,
    'GRZESZCZAK': 0,
    'GRZYB': 0,
    'GRZYBEK': 0,
    'GRZYBOWSKI': 0,
    'GRZYCH': 0,
    'GRZYMALA': 0,
    'GRZYMKOWSKI': 0,
    'GRZYWA': 0,
    'GRZYWACZ': 0,
    'GRZYWINSKI': 0,
    'GRZYWNA': 0,
    'GSCHWEND': 0,
    'GSCHWIND': 0,
    'GSELL': 0,
    'GU': 0,
    'GUABA': 0,
    'GUADAGNA': 0,
    'GUADAGNI': 0,
    'GUADAGNINO': 0,
    'GUADAGNO': 0,
    'GUADAGNOLI': 0,
    'GUADAGNOLO': 0,
    'GUADALAJARA': 0,
    'GUADALUPE': 0.9841380108834087,
    'GUADAMUZ': 0,
    'GUADARAMA': 0,
    'GUADARRAMA': 0,
    'GUADERRAMA': 0,
    'GUADIAN': 0,
    'GUADIANA': 0,
    'GUADRON': 0,
    'GUAGENTI': 0,
    'GUAGLIANO': 0,
    'GUAGLIANONE': 0,
    'GUAGLIARDO': 0,
    'GUAJARDO': 0,
    'GUAL': 0,
    'GUALANDI': 0,
    'GUALANO': 0,
    'GUALBERTO': 0,
    'GUALCO': 0,
    'GUALDONI': 0,
    'GUALLPA': 0,
    'GUALPA': 0,
    'GUALTIER': 0,
    'GUALTIERI': 0,
    'GUAMAN': 0,
    'GUAN': 0,
    'GUANA': 0,
    'GUANAJUATO': 0,
    'GUANCHE': 0,
    'GUANCI': 0,
    'GUANDIQUE': 0,
    'GUANGA': 0,
    'GUANLAO': 0,
    'GUANTE': 0,
    'GUANZON': 0,
    'GUAPO': 0,
    'GUARA': 0,
    'GUARALDI': 0,
    'GUARASCI': 0,
    'GUARASCIO': 0,
    'GUARD': 0,
    'GUARDA': 0,
    'GUARDADO': 0,
    'GUARDALABENE': 0,
    'GUARDERAS': 0,
    'GUARDI': 0,
    'GUARDIA': 0,
    'GUARDIAN': 0,
    'GUARDIANI': 0,
    'GUARDIANO': 0,
    'GUARDINO': 0,
    'GUARDIOLA': 0,
    'GUARDIPEE': 0,
    'GUARDO': 0,
    'GUARE': 0,
    'GUARENTE': 0,
    'GUAREZ': 0,
    'GUARIGLIA': 0,
    'GUARIN': 0,
    'GUARINI': 0,
    'GUARINO': 0,
    'GUARISCO': 0,
    'GUARNA': 0,
    'GUARNACCIA': 0,
    'GUARNERA': 0,
    'GUARNERE': 0,
    'GUARNERI': 0,
    'GUARNERO': 0,
    'GUARNEROS': 0,
    'GUARNIERE': 0,
    'GUARNIERI': 0,
    'GUARRACINO': 0,
    'GUARRERA': 0,
    'GUARRIELLO': 0,
    'GUASCH': 0,
    'GUASCO': 0,
    'GUASP': 0,
    'GUASTAFERRO': 0,
    'GUASTAVINO': 0,
    'GUASTELLA': 0,
    'GUASTO': 0,
    'GUATEMALA': 0,
    'GUAY': 0,
    'GUBA': 0,
    'GUBALA': 0,
    'GUBBELS': 0,
    'GUBBINS': 0,
    'GUBER': 0,
    'GUBERMAN': 0,
    'GUBERNAT': 0,
    'GUBERNICK': 0,
    'GUBERT': 0,
    'GUBIN': 0,
    'GUBITOSI': 0,
    'GUBITZ': 0,
    'GUBLER': 0,
    'GUBRUD': 0,
    'GUBSER': 0,
    'GUCCIARDI': 0,
    'GUCCIARDO': 0,
    'GUCCIONE': 0,
    'GUCK': 0,
    'GUCKENBERGER': 0,
    'GUCKER': 0,
    'GUCKERT': 0,
    'GUCKES': 0,
    'GUCKIAN': 0,
    'GUCKIN': 0,
    'GUCMAN': 0,
    'GUCWA': 0,
    'GUDA': 0,
    'GUDAITIS': 0,
    'GUDAS': 0,
    'GUDAT': 0,
    'GUDDE': 0,
    'GUDE': 0,
    'GUDEL': 0,
    'GUDEMAN': 0,
    'GUDEN': 0,
    'GUDENAU': 0,
    'GUDENKAUF': 0,
    'GUDER': 0,
    'GUDERIAN': 0,
    'GUDERJAHN': 0,
    'GUDEX': 0,
    'GUDGEL': 0,
    'GUDGELL': 0,
    'GUDGEON': 0,
    'GUDGER': 0,
    'GUDIEL': 0,
    'GUDIM': 0,
    'GUDINAS': 0,
    'GUDINO': 0,
    'GUDIS': 0,
    'GUDKNECHT': 0,
    'GUDMUNDSEN': 0,
    'GUDMUNDSON': 0,
    'GUDMUNDSSON': 0,
    'GUDMUNSON': 0,
    'GUDORF': 0,
    'GUDRUN': 1,
    'GUDVANGEN': 0,
    'GUDZ': 0,
    'GUE': 0,
    'GUEBARA': 0,
    'GUEBERT': 0,
    'GUECO': 0,
    'GUEDEA': 0,
    'GUEDEL': 0,
    'GUEDES': 0,
    'GUEDRY': 0,
    'GUEHO': 0,
    'GUEITS': 0,
    'GUEL': 0,
    'GUELDA': 0,
    'GUELDE': 0,
    'GUELDNER': 0,
    'GUELI': 0,
    'GUELICH': 0,
    'GUELIG': 0,
    'GUELKER': 0,
    'GUELL': 0,
    'GUELZOW': 0,
    'GUEMPEL': 0,
    'GUENARD': 0,
    'GUENETTE': 0,
    'GUENGERICH': 0,
    'GUENIN': 0,
    'GUENOT': 0,
    'GUENTER': 0,
    'GUENTERT': 0,
    'GUENTHER': 0,
    'GUENTHNER': 0,
    'GUENTNER': 0,
    'GUENTZEL': 0,
    'GUENZEL': 0,
    'GUENZLER': 0,
    'GUEORGUIEV': 0,
    'GUERA': 0,
    'GUERARD': 0,
    'GUERBER': 0,
    'GUERCI': 0,
    'GUERCIA': 0,
    'GUERCIO': 0,
    'GUERECA': 0,
    'GUERENA': 0,
    'GUEREQUE': 0,
    'GUERERRI': 0,
    'GUERETTE': 0,
    'GUERIN': 0,
    'GUERINGER': 0,
    'GUERINI': 0,
    'GUERINO': 0,
    'GUERNSEY': 0,
    'GUERRA': 0,
    'GUERRANT': 0,
    'GUERRE': 0,
    'GUERREIRO': 0,
    'GUERREO': 0,
    'GUERRERA': 0,
    'GUERRERO': 0,
    'GUERRETTAZ': 0,
    'GUERRETTE': 0,
    'GUERRI': 0,
    'GUERRIDO': 0,
    'GUERRIER': 0,
    'GUERRIERE': 0,
    'GUERRIERI': 0,
    'GUERRIERO': 0,
    'GUERRIN': 0,
    'GUERRINI': 0,
    'GUERRY': 0,
    'GUERS': 0,
    'GUERTIN': 0,
    'GUERTLER': 0,
    'GUERUE': 0,
    'GUERZON': 0,
    'GUESE': 0,
    'GUESMAN': 0,
    'GUESS': 0,
    'GUESSFORD': 0,
    'GUEST': 0,
    'GUETA': 0,
    'GUETERSLOH': 0,
    'GUETHLEIN': 0,
    'GUETSCHOW': 0,
    'GUETTA': 0,
    'GUETTER': 0,
    'GUETTERMAN': 0,
    'GUETTLER': 0,
    'GUETZKE': 0,
    'GUETZKOW': 0,
    'GUETZLAFF': 0,
    'GUEVARA': 0,
    'GUEVAREZ': 0,
    'GUEVARRA': 0,
    'GUEVERA': 0,
    'GUEVIN': 0,
    'GUEVREMONT': 0,
    'GUEYE': 0,
    'GUFFEE': 0,
    'GUFFEY': 0,
    'GUFFIE': 0,
    'GUFFIN': 0,
    'GUFFY': 0,
    'GUGALA': 0,
    'GUGE': 0,
    'GUGEL': 0,
    'GUGENHEIM': 0,
    'GUGERTY': 0,
    'GUGGEMOS': 0,
    'GUGGENBERGER': 0,
    'GUGGENBILLER': 0,
    'GUGGENHEIM': 0,
    'GUGGENHEIMER': 0,
    'GUGGENMOS': 0,
    'GUGGER': 0,
    'GUGGINO': 0,
    'GUGGISBERG': 0,
    'GUGIN': 0,
    'GUGINO': 0,
    'GUGLER': 0,
    'GUGLIELMELLI': 0,
    'GUGLIELMETTI': 0,
    'GUGLIELMI': 0,
    'GUGLIELMINI': 0,
    'GUGLIELMINO': 0,
    'GUGLIELMO': 0,
    'GUGLIETTA': 0,
    'GUGLIOTTA': 0,
    'GUGLIOTTI': 0,
    'GUGLIUZZA': 0,
    'GUHA': 0,
    'GUHDE': 0,
    'GUHL': 0,
    'GUHLKE': 0,
    'GUHR': 0,
    'GUI': 0,
    'GUIA': 0,
    'GUIANG': 0,
    'GUIAO': 0,
    'GUIBERSON': 0,
    'GUIBERT': 0,
    'GUIBORD': 0,
    'GUICE': 0,
    'GUICHARD': 0,
    'GUICHARDO': 0,
    'GUICHET': 0,
    'GUICO': 0,
    'GUIDA': 0,
    'GUIDARA': 0,
    'GUIDARELLI': 0,
    'GUIDAS': 0,
    'GUIDE': 0,
    'GUIDEN': 0,
    'GUIDER': 0,
    'GUIDERA': 0,
    'GUIDETTI': 0,
    'GUIDI': 0,
    'GUIDICE': 0,
    'GUIDICI': 0,
    'GUIDINGER': 0,
    'GUIDISH': 0,
    'GUIDO': 0,
    'GUIDON': 0,
    'GUIDONE': 0,
    'GUIDOS': 0,
    'GUIDOTTI': 0,
    'GUIDROZ': 0,
    'GUIDRY': 0,
    'GUIDUCCI': 0,
    'GUIEB': 0,
    'GUIEL': 0,
    'GUIER': 0,
    'GUIETTE': 0,
    'GUIFARRO': 0,
    'GUIFFRE': 0,
    'GUIFFRIDA': 0,
    'GUIGAR': 0,
    'GUIGNARD': 0,
    'GUIHER': 0,
    'GUIJARRO': 0,
    'GUIJOSA': 0,
    'GUIKEMA': 0,
    'GUILAMO': 0,
    'GUILARTE': 0,
    'GUILBAULT': 0,
    'GUILBE': 0,
    'GUILBEAU': 0,
    'GUILBEAULT': 0,
    'GUILBEAUX': 0,
    'GUILBERT': 0,
    'GUILD': 0,
    'GUILDAY': 0,
    'GUILDER': 0,
    'GUILDNER': 0,
    'GUILDS': 0,
    'GUILE': 0,
    'GUILER': 0,
    'GUILES': 0,
    'GUILEY': 0,
    'GUILFOIL': 0,
    'GUILFORD': 0,
    'GUILFOY': 0,
    'GUILFOYLE': 0,
    'GUILHERME': 0,
    'GUILIAND': 0,
    'GUILIANI': 0,
    'GUILIANO': 0,
    'GUILIN': 0,
    'GUILINGER': 0,
    'GUILKEY': 0,
    'GUILL': 0,
    'GUILLARD': 0,
    'GUILLAUME': 0,
    'GUILLE': 0,
    'GUILLEBEAU': 0,
    'GUILLEMETTE': 0,
    'GUILLEMIN': 0,
    'GUILLEN': 0,
    'GUILLERMINA': 1,
    'GUILLERMO': 0.9711779448621554,
    'GUILLET': 0,
    'GUILLETTE': 0,
    'GUILLIAM': 0,
    'GUILLIAMS': 0,
    'GUILLIOT': 0,
    'GUILLORY': 0,
    'GUILLOT': 0,
    'GUILLOTTE': 0,
    'GUILLOU': 0,
    'GUILLOZET': 0,
    'GUILMAIN': 0,
    'GUILMET': 0,
    'GUILMETTE': 0,
    'GUIMARAES': 0,
    'GUIMBELLOT': 0,
    'GUIMOND': 0,
    'GUIMONT': 0,
    'GUIN': 0,
    'GUINA': 0,
    'GUINAN': 0,
    'GUINANE': 0,
    'GUINARD': 0,
    'GUINASSO': 0,
    'GUINDI': 0,
    'GUINDON': 0,
    'GUINEA': 0,
    'GUINED': 0,
    'GUINEE': 0,
    'GUINEY': 0,
    'GUINN': 0,
    'GUINNESS': 0,
    'GUINNIP': 0,
    'GUINS': 0,
    'GUINTA': 0,
    'GUINTER': 0,
    'GUINTHER': 0,
    'GUINTO': 0,
    'GUINTU': 0,
    'GUINUP': 0,
    'GUINYARD': 0,
    'GUIO': 0,
    'GUION': 0,
    'GUIONS': 0,
    'GUIOT': 0,
    'GUIRACOCHA': 0,
    'GUIRADO': 0,
    'GUIRAGOSSIAN': 0,
    'GUIRAND': 0,
    'GUIRE': 0,
    'GUIRGIS': 0,
    'GUIRGUIS': 0,
    'GUIROLA': 0,
    'GUIRY': 0,
    'GUISASOLA': 0,
    'GUISE': 0,
    'GUISEPPE': 0,
    'GUISER': 0,
    'GUISHARD': 0,
    'GUISINGER': 0,
    'GUIST': 0,
    'GUISTE': 0,
    'GUISTI': 0,
    'GUISTO': 0,
    'GUITAR': 0,
    'GUITARD': 0,
    'GUITE': 0,
    'GUITEAU': 0,
    'GUITER': 0,
    'GUITIAN': 0,
    'GUITIEREZ': 0,
    'GUITON': 0,
    'GUITREAU': 0,
    'GUITRON': 0,
    'GUITTAR': 0,
    'GUITTARD': 0,
    'GUITY': 0,
    'GUIZA': 0,
    'GUIZAR': 0,
    'GUIZZETTI': 0,
    'GUJRAL': 0,
    'GUKASYAN': 0,
    'GUKEISEN': 0,
    'GUL': 0,
    'GULA': 0,
    'GULAN': 0,
    'GULARTE': 0,
    'GULAS': 0,
    'GULASH': 0,
    'GULATI': 0,
    'GULBIN': 0,
    'GULBIS': 0,
    'GULBRANDSEN': 0,
    'GULBRANDSON': 0,
    'GULBRANSEN': 0,
    'GULBRANSON': 0,
    'GULBRONSON': 0,
    'GULCH': 0,
    'GULCZYNSKI': 0,
    'GULD': 0,
    'GULDAN': 0,
    'GULDE': 0,
    'GULDEN': 0,
    'GULDI': 0,
    'GULDIN': 0,
    'GULDNER': 0,
    'GULED': 0,
    'GULER': 0,
    'GULEZIAN': 0,
    'GULI': 0,
    'GULIAN': 0,
    'GULIANO': 0,
    'GULICH': 0,
    'GULICK': 0,
    'GULIK': 0,
    'GULINO': 0,
    'GULISANO': 0,
    'GULISH': 0,
    'GULIZIA': 0,
    'GULKE': 0,
    'GULKER': 0,
    'GULKO': 0,
    'GULL': 0,
    'GULLA': 0,
    'GULLACE': 0,
    'GULLAGE': 0,
    'GULLAND': 0,
    'GULLAPALLI': 0,
    'GULLATT': 0,
    'GULLATTE': 0,
    'GULLBERG': 0,
    'GULLEDGE': 0,
    'GULLEKSON': 0,
    'GULLEN': 0,
    'GULLER': 0,
    'GULLET': 0,
    'GULLETT': 0,
    'GULLETTE': 0,
    'GULLEY': 0,
    'GULLI': 0,
    'GULLICK': 0,
    'GULLICKSEN': 0,
    'GULLICKSON': 0,
    'GULLIFER': 0,
    'GULLIFORD': 0,
    'GULLIKSEN': 0,
    'GULLIKSON': 0,
    'GULLING': 0,
    'GULLION': 0,
    'GULLIVER': 0,
    'GULLIXSON': 0,
    'GULLO': 0,
    'GULLOTTA': 0,
    'GULLOTTI': 0,
    'GULLOTTO': 0,
    'GULLY': 0,
    'GULNAC': 0,
    'GULOTTA': 0,
    'GULSBY': 0,
    'GULSETH': 0,
    'GULSTON': 0,
    'GULSVIG': 0,
    'GULVAS': 0,
    'GULYA': 0,
    'GULYAS': 0,
    'GUM': 0,
    'GUMA': 0,
    'GUMAER': 0,
    'GUMAN': 0,
    'GUMATAOTAO': 0,
    'GUMB': 0,
    'GUMBAN': 0,
    'GUMBEL': 0,
    'GUMBER': 0,
    'GUMBERT': 0,
    'GUMBINER': 0,
    'GUMBLE': 0,
    'GUMBRECHT': 0,
    'GUMBS': 0,
    'GUMBY': 0,
    'GUMFORY': 0,
    'GUMIENNY': 0,
    'GUMIENY': 0,
    'GUMINA': 0,
    'GUMINSKI': 0,
    'GUMKE': 0,
    'GUMKOWSKI': 0,
    'GUMLAW': 0,
    'GUMM': 0,
    'GUMMEL': 0,
    'GUMMELT': 0,
    'GUMMER': 0,
    'GUMMERE': 0,
    'GUMMERSALL': 0,
    'GUMMERSHEIMER': 0,
    'GUMMERSON': 0,
    'GUMMERT': 0,
    'GUMMO': 0,
    'GUMMOW': 0,
    'GUMP': 0,
    'GUMPEL': 0,
    'GUMPERT': 0,
    'GUMPHER': 0,
    'GUMPPER': 0,
    'GUMPRECHT': 0,
    'GUMS': 0,
    'GUMTOW': 0,
    'GUMUCIO': 0,
    'GUMZ': 0,
    'GUN': 0,
    'GUNASEKERA': 0,
    'GUNAWAN': 0,
    'GUNAWARDENA': 0,
    'GUNBY': 0,
    'GUNCKEL': 0,
    'GUND': 0,
    'GUNDA': 0,
    'GUNDACKER': 0,
    'GUNDAKER': 0,
    'GUNDEL': 0,
    'GUNDELACH': 0,
    'GUNDELFINGER': 0,
    'GUNDEN': 0,
    'GUNDER': 0,
    'GUNDERMAN': 0,
    'GUNDERMANN': 0,
    'GUNDERSEN': 0,
    'GUNDERSON': 0,
    'GUNDLACH': 0,
    'GUNDLING': 0,
    'GUNDRUM': 0,
    'GUNDRY': 0,
    'GUNDY': 0,
    'GUNER': 0,
    'GUNG': 0,
    'GUNGOR': 0,
    'GUNHAMMER': 0,
    'GUNHUS': 0,
    'GUNIA': 0,
    'GUNION': 0,
    'GUNKEL': 0,
    'GUNKLE': 0,
    'GUNLOCK': 0,
    'GUNN': 0,
    'GUNNARSON': 0,
    'GUNNARSSON': 0,
    'GUNNELL': 0,
    'GUNNELLS': 0,
    'GUNNELS': 0,
    'GUNNER': 0,
    'GUNNERSON': 0,
    'GUNNESON': 0,
    'GUNNESS': 0,
    'GUNNET': 0,
    'GUNNETT': 0,
    'GUNNIN': 0,
    'GUNNING': 0,
    'GUNNINK': 0,
    'GUNNIP': 0,
    'GUNNISON': 0,
    'GUNNOE': 0,
    'GUNNS': 0,
    'GUNS': 0,
    'GUNSALLUS': 0,
    'GUNSALUS': 0,
    'GUNSCH': 0,
    'GUNSELL': 0,
    'GUNSELMAN': 0,
    'GUNSOLLEY': 0,
    'GUNSOLUS': 0,
    'GUNSON': 0,
    'GUNST': 0,
    'GUNSTREAM': 0,
    'GUNTER': 0,
    'GUNTERMAN': 0,
    'GUNTHARP': 0,
    'GUNTHER': 0,
    'GUNTHNER': 0,
    'GUNTHORPE': 0,
    'GUNTLE': 0,
    'GUNTNER': 0,
    'GUNTON': 0,
    'GUNTRUM': 0,
    'GUNTY': 0,
    'GUNTZ': 0,
    'GUNVILLE': 0,
    'GUNYON': 0,
    'GUNZALEZ': 0,
    'GUNZEL': 0,
    'GUNZELMAN': 0,
    'GUNZENHAUSER': 0,
    'GUO': 0,
    'GUPPY': 0,
    'GUPTA': 0,
    'GUPTE': 0,
    'GUPTILL': 0,
    'GUPTON': 0,
    'GUR': 0,
    'GURA': 0,
    'GURAK': 0,
    'GURAL': 0,
    'GURALNICK': 0,
    'GURALNIK': 0,
    'GURALSKI': 0,
    'GURAN': 0,
    'GURAY': 0,
    'GURBA': 0,
    'GURCHIEK': 0,
    'GURCIULLO': 0,
    'GURD': 0,
    'GURDA': 0,
    'GURDAK': 0,
    'GURDEN': 0,
    'GURDIAN': 0,
    'GURDON': 0,
    'GURECKI': 0,
    'GUREVICH': 0,
    'GUREVITZ': 0,
    'GUREWITZ': 0,
    'GURFINKEL': 0,
    'GURGA': 0,
    'GURGANIOUS': 0,
    'GURGANUS': 0,
    'GURGEL': 0,
    'GURGONE': 0,
    'GURGUL': 0,
    'GURIAN': 0,
    'GURICH': 0,
    'GURICK': 0,
    'GURIEL': 0,
    'GURIN': 0,
    'GURITZ': 0,
    'GURK': 0,
    'GURKA': 0,
    'GURKE': 0,
    'GURKIN': 0,
    'GURLEY': 0,
    'GURMAN': 0,
    'GURNARI': 0,
    'GURNEE': 0,
    'GURNER': 0,
    'GURNETT': 0,
    'GURNEY': 0,
    'GURNICK': 0,
    'GURNSEY': 0,
    'GURO': 0,
    'GUROVICH': 0,
    'GURR': 0,
    'GURRA': 0,
    'GURRERA': 0,
    'GURRERI': 0,
    'GURRERO': 0,
    'GURRIERI': 0,
    'GURROLA': 0,
    'GURRUSQUIETA': 0,
    'GURRY': 0,
    'GURSKE': 0,
    'GURSKI': 0,
    'GURSKY': 0,
    'GURSSLIN': 0,
    'GURTLER': 0,
    'GURTNER': 0,
    'GURTOWSKI': 0,
    'GURULE': 0,
    'GURUNG': 0,
    'GURVICH': 0,
    'GURVITZ': 0,
    'GURWELL': 0,
    'GURWITZ': 0,
    'GURZYNSKI': 0,
    'GUS': 0.9927797833935017,
    'GUSA': 0,
    'GUSCIORA': 0,
    'GUSCOTT': 0,
    'GUSE': 0,
    'GUSEK': 0,
    'GUSEMAN': 0,
    'GUSEVA': 0,
    'GUSEWELLE': 0,
    'GUSH': 0,
    'GUSHARD': 0,
    'GUSHEE': 0,
    'GUSHI': 0,
    'GUSHIKEN': 0,
    'GUSHLAW': 0,
    'GUSHUE': 0,
    'GUSHWA': 0,
    'GUSICH': 0,
    'GUSICK': 0,
    'GUSKE': 0,
    'GUSKI': 0,
    'GUSKY': 0,
    'GUSLER': 0,
    'GUSMAN': 0,
    'GUSMANO': 0,
    'GUSS': 0,
    'GUSSE': 0,
    'GUSSERT': 0,
    'GUSSIE': 1,
    'GUSSIN': 0,
    'GUSSLER': 0,
    'GUSSMAN': 0,
    'GUSSOW': 0,
    'GUST': 0,
    'GUSTA': 0,
    'GUSTAD': 0,
    'GUSTAF': 0,
    'GUSTAFSON': 0,
    'GUSTAFSSON': 0,
    'GUSTAITIS': 0,
    'GUSTAS': 0,
    'GUSTASON': 0,
    'GUSTAVE': 0,
    'GUSTAVESON': 0,
    'GUSTAVO': 1,
    'GUSTAVSEN': 0,
    'GUSTAVSON': 0,
    'GUSTAVSSON': 0,
    'GUSTAVUS': 0,
    'GUSTER': 0,
    'GUSTILO': 0,
    'GUSTIN': 0,
    'GUSTINA': 0,
    'GUSTINE': 0,
    'GUSTITUS': 0,
    'GUSTKE': 0,
    'GUSTKEY': 0,
    'GUSTMAN': 0,
    'GUSTOFSON': 0,
    'GUSTON': 0,
    'GUSTOVICH': 0,
    'GUSTUS': 0,
    'GUSTWILLER': 0,
    'GUSTY': 0,
    'GUT': 0,
    'GUTBERLET': 0,
    'GUTBROD': 0,
    'GUTCH': 0,
    'GUTCHER': 0,
    'GUTCHES': 0,
    'GUTCHESS': 0,
    'GUTE': 0,
    'GUTEKUNST': 0,
    'GUTELIUS': 0,
    'GUTENBERG': 0,
    'GUTENBERGER': 0,
    'GUTER': 0,
    'GUTEREZ': 0,
    'GUTERMAN': 0,
    'GUTERMUTH': 0,
    'GUTERRES': 0,
    'GUTERREZ': 0,
    'GUTFREUND': 0,
    'GUTGSELL': 0,
    'GUTH': 0,
    'GUTHALS': 0,
    'GUTHART': 0,
    'GUTHEIL': 0,
    'GUTHERIE': 0,
    'GUTHERY': 0,
    'GUTHIER': 0,
    'GUTHMAN': 0,
    'GUTHMANN': 0,
    'GUTHMILLER': 0,
    'GUTHREY': 0,
    'GUTHRIDGE': 0,
    'GUTHRIE': 0,
    'GUTHRO': 0,
    'GUTHY': 0,
    'GUTIC': 0,
    'GUTIERRE': 0,
    'GUTIERREC': 0,
    'GUTIERRES': 0,
    'GUTIERREZ': 0,
    'GUTIERRIZ': 0,
    'GUTIERRZ': 0,
    'GUTIN': 0,
    'GUTING': 0,
    'GUTIREZ': 0,
    'GUTJAHR': 0,
    'GUTKE': 0,
    'GUTKIN': 0,
    'GUTKNECHT': 0,
    'GUTKOWSKI': 0,
    'GUTLEBER': 0,
    'GUTMAN': 0,
    'GUTMANN': 0,
    'GUTNIK': 0,
    'GUTOSKI': 0,
    'GUTOWSKI': 0,
    'GUTOWSKY': 0,
    'GUTRICK': 0,
    'GUTRIDGE': 0,
    'GUTSCH': 0,
    'GUTSCHE': 0,
    'GUTSCHENRITTER': 0,
    'GUTSCHER': 0,
    'GUTSCHMIDT': 0,
    'GUTSCHOW': 0,
    'GUTSHALL': 0,
    'GUTSTEIN': 0,
    'GUTT': 0,
    'GUTTA': 0,
    'GUTTADAURO': 0,
    'GUTTENBERG': 0,
    'GUTTENTAG': 0,
    'GUTTER': 0,
    'GUTTERIDGE': 0,
    'GUTTERMAN': 0,
    'GUTTERREZ': 0,
    'GUTTERSON': 0,
    'GUTTERY': 0,
    'GUTTIERREZ': 0,
    'GUTTILLA': 0,
    'GUTTING': 0,
    'GUTTMAN': 0,
    'GUTTMANN': 0,
    'GUTTORMSEN': 0,
    'GUTTORMSON': 0,
    'GUTTRIDGE': 0,
    'GUTTRY': 0,
    'GUTTUSO': 0,
    'GUTWEIN': 0,
    'GUTZ': 0,
    'GUTZEIT': 0,
    'GUTZKE': 0,
    'GUTZLER': 0,
    'GUTZMAN': 0,
    'GUTZMANN': 0,
    'GUTZMER': 0,
    'GUTZWILLER': 0,
    'GUVEN': 0,
    'GUY': 0.8527572484366117,
    'GUYAN': 0,
    'GUYANT': 0,
    'GUYDON': 0,
    'GUYE': 0,
    'GUYER': 0,
    'GUYETT': 0,
    'GUYETTE': 0,
    'GUYLL': 0,
    'GUYMON': 0,
    'GUYN': 0,
    'GUYNES': 0,
    'GUYNN': 0,
    'GUYNUP': 0,
    'GUYON': 0,
    'GUYOT': 0,
    'GUYOTT': 0,
    'GUYOTTE': 0,
    'GUYRE': 0,
    'GUYSE': 0,
    'GUYTON': 0,
    'GUZ': 0,
    'GUZA': 0,
    'GUZAK': 0,
    'GUZAN': 0,
    'GUZEK': 0,
    'GUZEL': 0,
    'GUZEWICZ': 0,
    'GUZI': 0,
    'GUZIAK': 0,
    'GUZICK': 0,
    'GUZIEC': 0,
    'GUZIEWICZ': 0,
    'GUZIK': 0,
    'GUZIKOWSKI': 0,
    'GUZINSKI': 0,
    'GUZIOR': 0,
    'GUZMAN': 0,
    'GUZOWSKI': 0,
    'GUZY': 0,
    'GUZZARDI': 0,
    'GUZZARDO': 0,
    'GUZZETTA': 0,
    'GUZZETTI': 0,
    'GUZZI': 0,
    'GUZZINO': 0,
    'GUZZO': 0,
    'GUZZONE': 0,
    'GWALTNEY': 0,
    'GWARA': 0,
    'GWARTNEY': 0,
    'GWATHMEY': 0,
    'GWATHNEY': 0,
    'GWATNEY': 0,
    'GWEN': 0.9977470228516253,
    'GWENDA': 1,
    'GWENDOLYN': 1,
    'GWENN': 1,
    'GWERDER': 0,
    'GWIAZDA': 0,
    'GWIAZDOWSKI': 0,
    'GWIDT': 0,
    'GWILLIAM': 0,
    'GWILLIM': 0,
    'GWILT': 0,
    'GWIN': 0,
    'GWINN': 0,
    'GWINNER': 0,
    'GWINNUP': 0,
    'GWIRTZ': 0,
    'GWIZDAK': 0,
    'GWIZDALA': 0,
    'GWON': 0,
    'GWOREK': 0,
    'GWOZDZ': 0,
    'GWYN': 0.7117437722419929,
    'GWYNETH': 1,
    'GWYNN': 0,
    'GWYNNE': 0,
    'GWYTHER': 0,
    'GYAMFI': 0,
    'GYARMATI': 0,
    'GYASI': 0,
    'GYDE': 0,
    'GYDESEN': 0,
    'GYENES': 0,
    'GYGAX': 0,
    'GYGER': 0,
    'GYGI': 0,
    'GYIMAH': 0,
    'GYLES': 0,
    'GYLLING': 0,
    'GYNN': 0,
    'GYORI': 0,
    'GYORKE': 0,
    'GYORKOS': 0,
    'GYORY': 0,
    'GYR': 0,
    'GYSBERS': 0,
    'GYSEL': 0,
    'GYSIN': 0,
    'GYURE': 0,
    'GYURKO': 0,
    'HA': 0.2936857562408223,
    'HAAB': 0,
    'HAACK': 0,
    'HAACKE': 0,
    'HAACKER': 0,
    'HAAF': 0,
    'HAAG': 0,
    'HAAGA': 0,
    'HAAGE': 0,
    'HAAGEN': 0,
    'HAAGENSEN': 0,
    'HAAGENSON': 0,
    'HAAGER': 0,
    'HAAGSMA': 0,
    'HAAHR': 0,
    'HAAK': 0,
    'HAAKE': 0,
    'HAAKENSON': 0,
    'HAAKER': 0,
    'HAAKINSON': 0,
    'HAAKSMA': 0,
    'HAALA': 0,
    'HAALAND': 0,
    'HAAN': 0,
    'HAANEN': 0,
    'HAANPAA': 0,
    'HAAPALA': 0,
    'HAAPANEN': 0,
    'HAAR': 0,
    'HAARALA': 0,
    'HAARER': 0,
    'HAARMAN': 0,
    'HAARMANN': 0,
    'HAARMEYER': 0,
    'HAARS': 0,
    'HAARSMA': 0,
    'HAARSTAD': 0,
    'HAARSTICK': 0,
    'HAAS': 0,
    'HAASCH': 0,
    'HAASE': 0,
    'HAASER': 0,
    'HAASIS': 0,
    'HAASL': 0,
    'HAASS': 0,
    'HAASZ': 0,
    'HAATAJA': 0,
    'HAATS': 0,
    'HAAVE': 0,
    'HAAVISTO': 0,
    'HABA': 0,
    'HABAN': 0,
    'HABANA': 0,
    'HABAS': 0,
    'HABASH': 0,
    'HABASHI': 0,
    'HABBAL': 0,
    'HABBAS': 0,
    'HABBE': 0,
    'HABBEN': 0,
    'HABE': 0,
    'HABECK': 0,
    'HABECKER': 0,
    'HABEDANK': 0,
    'HABEEB': 0,
    'HABEGER': 0,
    'HABEGGER': 0,
    'HABEL': 0,
    'HABEN': 0,
    'HABENICHT': 0,
    'HABER': 0,
    'HABERBERGER': 0,
    'HABEREK': 0,
    'HABERER': 0,
    'HABERERN': 0,
    'HABERKAMP': 0,
    'HABERKERN': 0,
    'HABERKORN': 0,
    'HABERL': 0,
    'HABERLAND': 0,
    'HABERLE': 0,
    'HABERLEIN': 0,
    'HABERLI': 0,
    'HABERLIN': 0,
    'HABERLY': 0,
    'HABERMAN': 0,
    'HABERMANN': 0,
    'HABERMEHL': 0,
    'HABERN': 0,
    'HABERSETZER': 0,
    'HABERSHAM': 0,
    'HABERSHAW': 0,
    'HABERSKI': 0,
    'HABERSTICH': 0,
    'HABERSTOCK': 0,
    'HABERSTROH': 0,
    'HABERT': 0,
    'HABETLER': 0,
    'HABETS': 0,
    'HABETZ': 0,
    'HABHAB': 0,
    'HABIB': 0,
    'HABIBI': 0,
    'HABICH': 0,
    'HABICHT': 0,
    'HABIF': 0,
    'HABIG': 0,
    'HABIGER': 0,
    'HABIGHORST': 0,
    'HABINA': 0,
    'HABING': 0,
    'HABISCH': 0,
    'HABIT': 0,
    'HABLE': 0,
    'HABLEWITZ': 0,
    'HABLITZEL': 0,
    'HABON': 0,
    'HABOUSH': 0,
    'HABOWSKI': 0,
    'HABRAT': 0,
    'HABROCK': 0,
    'HABTE': 0,
    'HABTEMARIAM': 0,
    'HABY': 0,
    'HACH': 0,
    'HACHE': 0,
    'HACHEM': 0,
    'HACHEY': 0,
    'HACHIGIAN': 0,
    'HACHIYA': 0,
    'HACHMANN': 0,
    'HACHMEISTER': 0,
    'HACHTEL': 0,
    'HACK': 0,
    'HACKATHORN': 0,
    'HACKBART': 0,
    'HACKBARTH': 0,
    'HACKE': 0,
    'HACKEL': 0,
    'HACKEN': 0,
    'HACKENBERG': 0,
    'HACKENBERGER': 0,
    'HACKENBURG': 0,
    'HACKENMILLER': 0,
    'HACKENMUELLER': 0,
    'HACKENSON': 0,
    'HACKER': 0,
    'HACKERD': 0,
    'HACKERMAN': 0,
    'HACKEROTT': 0,
    'HACKERSON': 0,
    'HACKERT': 0,
    'HACKET': 0,
    'HACKETT': 0,
    'HACKEY': 0,
    'HACKFELD': 0,
    'HACKFORD': 0,
    'HACKING': 0,
    'HACKL': 0,
    'HACKLE': 0,
    'HACKLEMAN': 0,
    'HACKLER': 0,
    'HACKLEY': 0,
    'HACKMAN': 0,
    'HACKMANN': 0,
    'HACKNER': 0,
    'HACKNEY': 0,
    'HACKSHAW': 0,
    'HACKSTADT': 0,
    'HACKSTOCK': 0,
    'HACKWELL': 0,
    'HACKWITH': 0,
    'HACKWORTH': 0,
    'HACOPIAN': 0,
    'HAD': 0,
    'HADA': 0,
    'HADAC': 0,
    'HADAD': 0,
    'HADALA': 0,
    'HADALLER': 0,
    'HADAM': 0,
    'HADAR': 0,
    'HADASH': 0,
    'HADAWAY': 0,
    'HADCOCK': 0,
    'HADD': 0,
    'HADDAD': 0,
    'HADDADIN': 0,
    'HADDAN': 0,
    'HADDAWAY': 0,
    'HADDEN': 0,
    'HADDENHAM': 0,
    'HADDER': 0,
    'HADDICAN': 0,
    'HADDICK': 0,
    'HADDING': 0,
    'HADDIX': 0,
    'HADDLE': 0,
    'HADDOCK': 0,
    'HADDON': 0,
    'HADDOW': 0,
    'HADDOX': 0,
    'HADDY': 0,
    'HADE': 0,
    'HADEED': 0,
    'HADEL': 0,
    'HADEN': 0,
    'HADENFELDT': 0,
    'HADER': 0,
    'HADERER': 0,
    'HADERLIE': 0,
    'HADFIELD': 0,
    'HADI': 0,
    'HADICK': 0,
    'HADID': 0,
    'HADINGER': 0,
    'HADIX': 0,
    'HADJIS': 0,
    'HADL': 0,
    'HADLAND': 0,
    'HADLER': 0,
    'HADLEY': 0,
    'HADLOCK': 0,
    'HADLOW': 0,
    'HADNOT': 0,
    'HADNOTT': 0,
    'HADORN': 0,
    'HADRAVA': 0,
    'HADRICK': 0,
    'HADSALL': 0,
    'HADSELL': 0,
    'HADSOCK': 0,
    'HADUCH': 0,
    'HADUCK': 0,
    'HADWIGER': 0,
    'HADWIN': 0,
    'HADY': 0,
    'HADZIC': 0,
    'HADZIMA': 0,
    'HADZOVIC': 0,
    'HAE': 1,
    'HAEBERLE': 0,
    'HAEBERLIN': 0,
    'HAECK': 0,
    'HAECKEL': 0,
    'HAECKER': 0,
    'HAEDER': 0,
    'HAEDRICH': 0,
    'HAEDT': 0,
    'HAEFELE': 0,
    'HAEFELI': 0,
    'HAEFER': 0,
    'HAEFFNER': 0,
    'HAEFKE': 0,
    'HAEFLING': 0,
    'HAEFLINGER': 0,
    'HAEFNER': 0,
    'HAEFS': 0,
    'HAEG': 0,
    'HAEGE': 0,
    'HAEGELE': 0,
    'HAEGER': 0,
    'HAEHL': 0,
    'HAEHN': 0,
    'HAEHNEL': 0,
    'HAEMMERLE': 0,
    'HAEN': 0,
    'HAENDEL': 0,
    'HAENDIGES': 0,
    'HAENEL': 0,
    'HAENER': 0,
    'HAENISCH': 0,
    'HAENKE': 0,
    'HAENLEIN': 0,
    'HAENN': 0,
    'HAENNI': 0,
    'HAENSEL': 0,
    'HAER': 0,
    'HAERING': 0,
    'HAERLE': 0,
    'HAERR': 0,
    'HAERTEL': 0,
    'HAERTL': 0,
    'HAERTLING': 0,
    'HAES': 0,
    'HAESCHE': 0,
    'HAESE': 0,
    'HAESLER': 0,
    'HAESSIG': 0,
    'HAESSLER': 0,
    'HAESSLY': 0,
    'HAEUSER': 0,
    'HAEUSSLER': 0,
    'HAFEEZ': 0,
    'HAFELE': 0,
    'HAFELI': 0,
    'HAFEMAN': 0,
    'HAFEMANN': 0,
    'HAFEMEISTER': 0,
    'HAFEN': 0,
    'HAFENSTEIN': 0,
    'HAFER': 0,
    'HAFERKAMP': 0,
    'HAFERMAN': 0,
    'HAFERMANN': 0,
    'HAFERTEPE': 0,
    'HAFEY': 0,
    'HAFEZ': 0,
    'HAFEZI': 0,
    'HAFF': 0,
    'HAFFA': 0,
    'HAFFAR': 0,
    'HAFFENDEN': 0,
    'HAFFER': 0,
    'HAFFERKAMP': 0,
    'HAFFERTY': 0,
    'HAFFEY': 0,
    'HAFFKE': 0,
    'HAFFLEY': 0,
    'HAFFLY': 0,
    'HAFFNER': 0,
    'HAFFORD': 0,
    'HAFIZ': 0,
    'HAFLER': 0,
    'HAFLEY': 0,
    'HAFLICH': 0,
    'HAFLIGER': 0,
    'HAFLING': 0,
    'HAFNER': 0,
    'HAFOKA': 0,
    'HAFT': 0,
    'HAFTEL': 0,
    'HAFTER': 0,
    'HAFTL': 0,
    'HAG': 0,
    'HAGA': 0,
    'HAGADONE': 0,
    'HAGADORN': 0,
    'HAGAMAN': 0,
    'HAGAN': 0,
    'HAGANS': 0,
    'HAGAR': 0,
    'HAGARMAN': 0,
    'HAGARTY': 0,
    'HAGBERG': 0,
    'HAGE': 0,
    'HAGEBUSCH': 0,
    'HAGEDON': 0,
    'HAGEDORN': 0,
    'HAGEE': 0,
    'HAGEL': 0,
    'HAGELBERG': 0,
    'HAGELBERGER': 0,
    'HAGELE': 0,
    'HAGELGANS': 0,
    'HAGELIN': 0,
    'HAGELSTEIN': 0,
    'HAGEMAN': 0,
    'HAGEMANN': 0,
    'HAGEMEIER': 0,
    'HAGEMEISTER': 0,
    'HAGEMEYER': 0,
    'HAGEN': 0,
    'HAGENAH': 0,
    'HAGENBACH': 0,
    'HAGENBAUGH': 0,
    'HAGENBUCH': 0,
    'HAGENDORF': 0,
    'HAGENE': 0,
    'HAGENESS': 0,
    'HAGENHOFF': 0,
    'HAGENMAIER': 0,
    'HAGENOW': 0,
    'HAGENS': 0,
    'HAGENSEN': 0,
    'HAGENSICK': 0,
    'HAGENSON': 0,
    'HAGER': 0,
    'HAGERBAUMER': 0,
    'HAGERDON': 0,
    'HAGERICH': 0,
    'HAGERMAN': 0,
    'HAGEROTT': 0,
    'HAGERSTROM': 0,
    'HAGERT': 0,
    'HAGERTY': 0,
    'HAGERUP': 0,
    'HAGES': 0,
    'HAGESTAD': 0,
    'HAGEWOOD': 0,
    'HAGEY': 0,
    'HAGG': 0,
    'HAGGADONE': 0,
    'HAGGAN': 0,
    'HAGGANS': 0,
    'HAGGAR': 0,
    'HAGGARD': 0,
    'HAGGART': 0,
    'HAGGARTY': 0,
    'HAGGAS': 0,
    'HAGGBERG': 0,
    'HAGGE': 0,
    'HAGGEN': 0,
    'HAGGENMILLER': 0,
    'HAGGER': 0,
    'HAGGERMAKER': 0,
    'HAGGERTON': 0,
    'HAGGERTY': 0,
    'HAGGETT': 0,
    'HAGGIN': 0,
    'HAGGINS': 0,
    'HAGGIS': 0,
    'HAGGLUND': 0,
    'HAGGSTROM': 0,
    'HAGGY': 0,
    'HAGHANI': 0,
    'HAGHIGHAT': 0,
    'HAGHIGHI': 0,
    'HAGI': 0,
    'HAGIE': 0,
    'HAGIHARA': 0,
    'HAGIN': 0,
    'HAGINS': 0,
    'HAGIST': 0,
    'HAGIWARA': 0,
    'HAGL': 0,
    'HAGLAND': 0,
    'HAGLE': 0,
    'HAGLER': 0,
    'HAGLEY': 0,
    'HAGLIN': 0,
    'HAGLUND': 0,
    'HAGMAIER': 0,
    'HAGMAN': 0,
    'HAGMANN': 0,
    'HAGMEIER': 0,
    'HAGNER': 0,
    'HAGNESS': 0,
    'HAGON': 0,
    'HAGOOD': 0,
    'HAGOPIAN': 0,
    'HAGOS': 0,
    'HAGSTROM': 0,
    'HAGUE': 0,
    'HAGUEWOOD': 0,
    'HAGWOOD': 0,
    'HAGY': 0,
    'HAH': 0,
    'HAHL': 0,
    'HAHLBECK': 0,
    'HAHLEN': 0,
    'HAHLER': 0,
    'HAHM': 0,
    'HAHN': 0,
    'HAHNE': 0,
    'HAHNEL': 0,
    'HAHNER': 0,
    'HAHR': 0,
    'HAHS': 0,
    'HAI': 0.9478672985781991,
    'HAIAR': 0,
    'HAIBACH': 0,
    'HAIC': 0,
    'HAICK': 0,
    'HAID': 0,
    'HAIDAR': 0,
    'HAIDARI': 0,
    'HAIDEN': 0,
    'HAIDER': 0,
    'HAIDET': 0,
    'HAIDLE': 0,
    'HAIDUK': 0,
    'HAIFA': 0,
    'HAIFLEY': 0,
    'HAIFLICH': 0,
    'HAIG': 0,
    'HAIGH': 0,
    'HAIGHT': 0,
    'HAIGIS': 0,
    'HAIGLER': 0,
    'HAIGOOD': 0,
    'HAIGWOOD': 0,
    'HAIK': 0,
    'HAIKAL': 0,
    'HAIL': 0,
    'HAILE': 0,
    'HAILEMARIAM': 0,
    'HAILER': 0,
    'HAILES': 0,
    'HAILEY': 0.6060606060606061,
    'HAILI': 0,
    'HAILS': 0,
    'HAILSTOCK': 0,
    'HAILSTONE': 0,
    'HAILU': 0,
    'HAIM': 0,
    'HAIMA': 0,
    'HAIMAN': 0,
    'HAIME': 0,
    'HAIMES': 0,
    'HAIMOWITZ': 0,
    'HAIMS': 0,
    'HAIN': 0,
    'HAINE': 0,
    'HAINER': 0,
    'HAINES': 0,
    'HAINESWORTH': 0,
    'HAINEY': 0,
    'HAINING': 0,
    'HAINLEN': 0,
    'HAINLEY': 0,
    'HAINLINE': 0,
    'HAINS': 0,
    'HAINSEY': 0,
    'HAINSTOCK': 0,
    'HAINSWORTH': 0,
    'HAINZ': 0,
    'HAIR': 0,
    'HAIRABEDIAN': 0,
    'HAIRAPETIAN': 0,
    'HAIRE': 0,
    'HAIRELL': 0,
    'HAIRFIELD': 0,
    'HAIRGROVE': 0,
    'HAIRR': 0,
    'HAIRRELL': 0,
    'HAIRSINE': 0,
    'HAIRSTON': 0,
    'HAISCH': 0,
    'HAISE': 0,
    'HAISLER': 0,
    'HAISLET': 0,
    'HAISLEY': 0,
    'HAISLIP': 0,
    'HAISMA': 0,
    'HAISMAN': 0,
    'HAISS': 0,
    'HAIST': 0,
    'HAISTEN': 0,
    'HAIT': 0,
    'HAITH': 0,
    'HAITHCOAT': 0,
    'HAITHCOCK': 0,
    'HAITHCOX': 0,
    'HAITZ': 0,
    'HAIZLIP': 0,
    'HAJ': 0,
    'HAJDAREVIC': 0,
    'HAJDASZ': 0,
    'HAJDU': 0,
    'HAJDUK': 0,
    'HAJEC': 0,
    'HAJEK': 0,
    'HAJI': 0,
    'HAJIAN': 0,
    'HAJICEK': 0,
    'HAJJ': 0,
    'HAJJAR': 0,
    'HAJNY': 0,
    'HAJOVSKY': 0,
    'HAJRIC': 0,
    'HAK': 0,
    'HAKA': 0,
    'HAKALA': 0,
    'HAKANSON': 0,
    'HAKANSSON': 0,
    'HAKE': 0,
    'HAKEEM': 0,
    'HAKEL': 0,
    'HAKEMAN': 0,
    'HAKEN': 0,
    'HAKENSON': 0,
    'HAKER': 0,
    'HAKES': 0,
    'HAKEY': 0,
    'HAKIM': 0,
    'HAKIMI': 0,
    'HAKIMIAN': 0,
    'HAKIN': 0,
    'HAKINS': 0,
    'HAKKI': 0,
    'HAKKINEN': 0,
    'HAKMAN': 0,
    'HAKOBYAN': 0,
    'HAKOLA': 0,
    'HAKOPIAN': 0,
    'HAKOPYAN': 0,
    'HAL': 0.9931245225362872,
    'HALA': 0,
    'HALABI': 0,
    'HALABURDA': 0,
    'HALABY': 0,
    'HALAC': 0,
    'HALACY': 0,
    'HALADA': 0,
    'HALADAY': 0,
    'HALAJIAN': 0,
    'HALAL': 0,
    'HALAMA': 0,
    'HALAMICEK': 0,
    'HALAN': 0,
    'HALAS': 0,
    'HALASKA': 0,
    'HALASZ': 0,
    'HALAT': 0,
    'HALBACH': 0,
    'HALBAKKEN': 0,
    'HALBARDIER': 0,
    'HALBE': 0,
    'HALBEISEN': 0,
    'HALBERG': 0,
    'HALBERSTADT': 0,
    'HALBERSTAM': 0,
    'HALBERT': 0,
    'HALBIG': 0,
    'HALBLEIB': 0,
    'HALBMAIER': 0,
    'HALBRITTER': 0,
    'HALBROOK': 0,
    'HALBROOKS': 0,
    'HALBUR': 0,
    'HALBY': 0,
    'HALCHAK': 0,
    'HALCOM': 0,
    'HALCOMB': 0,
    'HALCON': 0,
    'HALCOTT': 0,
    'HALCROW': 0,
    'HALD': 0,
    'HALDA': 0,
    'HALDANE': 0,
    'HALDAR': 0,
    'HALDEMAN': 0,
    'HALDEN': 0,
    'HALDER': 0,
    'HALDERMAN': 0,
    'HALDERSON': 0,
    'HALDI': 0,
    'HALDIMAN': 0,
    'HALDONADO': 0,
    'HALDORSON': 0,
    'HALDY': 0,
    'HALE': 0,
    'HALECKI': 0,
    'HALEEM': 0,
    'HALEK': 0,
    'HALEM': 0,
    'HALEN': 0,
    'HALENAR': 0,
    'HALER': 0,
    'HALES': 0,
    'HALEVY': 0,
    'HALEY': 0.5089058524173028,
    'HALF': 0,
    'HALFACRE': 0,
    'HALFAKER': 0,
    'HALFEN': 0,
    'HALFERTY': 0,
    'HALFHILL': 0,
    'HALFIN': 0,
    'HALFMAN': 0,
    'HALFMANN': 0,
    'HALFON': 0,
    'HALFORD': 0,
    'HALFPAP': 0,
    'HALFPENNY': 0,
    'HALGAS': 0,
    'HALGREN': 0,
    'HALGRIMSON': 0,
    'HALIBURTON': 0,
    'HALICK': 0,
    'HALICKI': 0,
    'HALIDAY': 0,
    'HALIFAX': 0,
    'HALIK': 0,
    'HALIKIAS': 0,
    'HALILI': 0,
    'HALILOVIC': 0,
    'HALIM': 0,
    'HALIMI': 0,
    'HALIN': 0,
    'HALINA': 1,
    'HALING': 0,
    'HALINSKI': 0,
    'HALK': 0,
    'HALKA': 0,
    'HALKER': 0,
    'HALKETT': 0,
    'HALKIAS': 0,
    'HALKO': 0,
    'HALKYARD': 0,
    'HALL': 0,
    'HALLACK': 0,
    'HALLACY': 0,
    'HALLADA': 0,
    'HALLADAY': 0,
    'HALLAGAN': 0,
    'HALLAHAN': 0,
    'HALLAK': 0,
    'HALLAL': 0,
    'HALLAM': 0,
    'HALLAN': 0,
    'HALLAND': 0,
    'HALLANGER': 0,
    'HALLARAN': 0,
    'HALLAS': 0,
    'HALLATT': 0,
    'HALLAUER': 0,
    'HALLAWAY': 0,
    'HALLBACK': 0,
    'HALLBAUER': 0,
    'HALLBECK': 0,
    'HALLBERG': 0,
    'HALLDORSON': 0,
    'HALLE': 0,
    'HALLEAD': 0,
    'HALLECK': 0,
    'HALLEE': 0,
    'HALLEEN': 0,
    'HALLEMAN': 0,
    'HALLEMEIER': 0,
    'HALLEN': 0,
    'HALLENBECK': 0,
    'HALLENBERG': 0,
    'HALLER': 0,
    'HALLERAN': 0,
    'HALLERMAN': 0,
    'HALLESY': 0,
    'HALLET': 0,
    'HALLETT': 0,
    'HALLEY': 0.35587188612099646,
    'HALLFORD': 0,
    'HALLGARTH': 0,
    'HALLGREN': 0,
    'HALLGRIMSON': 0,
    'HALLIBURTON': 0,
    'HALLICK': 0,
    'HALLIDAY': 0,
    'HALLIE': 1,
    'HALLIER': 0,
    'HALLIFAX': 0,
    'HALLIGAN': 0,
    'HALLIHAN': 0,
    'HALLIMAN': 0,
    'HALLIN': 0,
    'HALLINAN': 0,
    'HALLING': 0,
    'HALLINGER': 0,
    'HALLINGSTAD': 0,
    'HALLIS': 0,
    'HALLISEY': 0,
    'HALLISSEY': 0,
    'HALLISY': 0,
    'HALLIWELL': 0,
    'HALLIWILL': 0,
    'HALLMAN': 0,
    'HALLMANN': 0,
    'HALLMARK': 0,
    'HALLMON': 0,
    'HALLOCK': 0,
    'HALLOM': 0,
    'HALLONQUIST': 0,
    'HALLORAN': 0,
    'HALLOW': 0,
    'HALLOWAY': 0,
    'HALLOWELL': 0,
    'HALLOWS': 0,
    'HALLQUIST': 0,
    'HALLS': 0,
    'HALLSTEAD': 0,
    'HALLSTED': 0,
    'HALLSTEIN': 0,
    'HALLSTEN': 0,
    'HALLSTROM': 0,
    'HALLUM': 0,
    'HALLUMS': 0,
    'HALLWOOD': 0,
    'HALLWORTH': 0,
    'HALLY': 0,
    'HALLYBURTON': 0,
    'HALM': 0,
    'HALMA': 0,
    'HALMAN': 0,
    'HALME': 0,
    'HALMI': 0,
    'HALMON': 0,
    'HALO': 0,
    'HALOG': 0,
    'HALON': 0,
    'HALONA': 0,
    'HALONEN': 0,
    'HALOUSKA': 0,
    'HALPAIN': 0,
    'HALPENNY': 0,
    'HALPER': 0,
    'HALPERIN': 0,
    'HALPERN': 0,
    'HALPERT': 0,
    'HALPHEN': 0,
    'HALPIN': 0,
    'HALPINE': 0,
    'HALPRIN': 0,
    'HALQUIST': 0,
    'HALS': 0,
    'HALSALL': 0,
    'HALSE': 0,
    'HALSELL': 0,
    'HALSEMA': 0,
    'HALSETH': 0,
    'HALSEY': 0,
    'HALSNE': 0,
    'HALSTAD': 0,
    'HALSTEAD': 0,
    'HALSTED': 0,
    'HALSTON': 0,
    'HALSTROM': 0,
    'HALT': 0,
    'HALTEMAN': 0,
    'HALTER': 0,
    'HALTERMAN': 0,
    'HALTINER': 0,
    'HALTIWANGER': 0,
    'HALTOM': 0,
    'HALTON': 0,
    'HALUCH': 0,
    'HALULA': 0,
    'HALUPA': 0,
    'HALUPKA': 0,
    'HALUPTZOK': 0,
    'HALUSKA': 0,
    'HALVARSON': 0,
    'HALVERSEN': 0,
    'HALVERSON': 0,
    'HALVERSTADT': 0,
    'HALVEY': 0,
    'HALVORSEN': 0,
    'HALVORSON': 0,
    'HALWEG': 0,
    'HALWOOD': 0,
    'HALY': 0,
    'HALYARD': 0,
    'HAM': 0,
    'HAMA': 0,
    'HAMACHER': 0,
    'HAMAD': 0,
    'HAMADA': 0,
    'HAMADANI': 0,
    'HAMADE': 0,
    'HAMADEH': 0,
    'HAMADY': 0,
    'HAMAGUCHI': 0,
    'HAMAI': 0,
    'HAMAKER': 0,
    'HAMALA': 0,
    'HAMALAINEN': 0,
    'HAMALIAN': 0,
    'HAMAMA': 0,
    'HAMAMOTO': 0,
    'HAMAMURA': 0,
    'HAMAN': 0,
    'HAMAND': 0,
    'HAMANN': 0,
    'HAMANO': 0,
    'HAMANT': 0,
    'HAMAR': 0,
    'HAMARA': 0,
    'HAMAS': 0,
    'HAMASAKI': 0,
    'HAMATI': 0,
    'HAMATY': 0,
    'HAMB': 0,
    'HAMBACH': 0,
    'HAMBEK': 0,
    'HAMBEL': 0,
    'HAMBELTON': 0,
    'HAMBER': 0,
    'HAMBERG': 0,
    'HAMBERGER': 0,
    'HAMBERLIN': 0,
    'HAMBEY': 0,
    'HAMBIDGE': 0,
    'HAMBLE': 0,
    'HAMBLEN': 0,
    'HAMBLET': 0,
    'HAMBLETON': 0,
    'HAMBLETT': 0,
    'HAMBLEY': 0,
    'HAMBLIN': 0,
    'HAMBLY': 0,
    'HAMBRECHT': 0,
    'HAMBRIC': 0,
    'HAMBRICK': 0,
    'HAMBRIGHT': 0,
    'HAMBROCK': 0,
    'HAMBROOK': 0,
    'HAMBURG': 0,
    'HAMBURGER': 0,
    'HAMBY': 0,
    'HAMDAN': 0,
    'HAMDANI': 0,
    'HAMDEN': 0,
    'HAMDI': 0,
    'HAMDORF': 0,
    'HAMDY': 0,
    'HAMED': 0,
    'HAMEED': 0,
    'HAMEEN': 0,
    'HAMEISTER': 0,
    'HAMEL': 0,
    'HAMELE': 0,
    'HAMELIN': 0,
    'HAMELINE': 0,
    'HAMELINK': 0,
    'HAMELL': 0,
    'HAMELTON': 0,
    'HAMEN': 0,
    'HAMENDE': 0,
    'HAMER': 0,
    'HAMERLINCK': 0,
    'HAMERLY': 0,
    'HAMERMAN': 0,
    'HAMERNICK': 0,
    'HAMERNIK': 0,
    'HAMERS': 0,
    'HAMERSKI': 0,
    'HAMERSKY': 0,
    'HAMERSLEY': 0,
    'HAMERSLY': 0,
    'HAMERSMA': 0,
    'HAMES': 0,
    'HAMET': 0,
    'HAMETT': 0,
    'HAMEY': 0,
    'HAMI': 0,
    'HAMIC': 0,
    'HAMID': 0,
    'HAMIDEH': 0,
    'HAMIDI': 0,
    'HAMIEL': 0,
    'HAMIK': 0,
    'HAMIL': 0,
    'HAMILL': 0,
    'HAMILLA': 0,
    'HAMILTON': 0,
    'HAMIN': 0,
    'HAMIT': 0,
    'HAMITER': 0,
    'HAMITON': 0,
    'HAMLEN': 0,
    'HAMLER': 0,
    'HAMLET': 0,
    'HAMLETT': 0,
    'HAMLETTE': 0,
    'HAMLEY': 0,
    'HAMLIN': 0,
    'HAMLING': 0,
    'HAMLOW': 0,
    'HAMLYN': 0,
    'HAMM': 0,
    'HAMMA': 0,
    'HAMMAC': 0,
    'HAMMACK': 0,
    'HAMMAD': 0,
    'HAMMAKER': 0,
    'HAMMAN': 0,
    'HAMMANG': 0,
    'HAMMANN': 0,
    'HAMMANS': 0,
    'HAMMAR': 0,
    'HAMMARGREN': 0,
    'HAMMARLUND': 0,
    'HAMMARSTROM': 0,
    'HAMMATT': 0,
    'HAMME': 0,
    'HAMMED': 0,
    'HAMMEKE': 0,
    'HAMMEL': 0,
    'HAMMELL': 0,
    'HAMMELMAN': 0,
    'HAMMEN': 0,
    'HAMMER': 0,
    'HAMMERAND': 0,
    'HAMMERBACHER': 0,
    'HAMMERBECK': 0,
    'HAMMERBERG': 0,
    'HAMMERGREN': 0,
    'HAMMERICH': 0,
    'HAMMERL': 0,
    'HAMMERLE': 0,
    'HAMMERLING': 0,
    'HAMMERLUND': 0,
    'HAMMERLY': 0,
    'HAMMERMAN': 0,
    'HAMMERMEISTER': 0,
    'HAMMERQUIST': 0,
    'HAMMERS': 0,
    'HAMMERSCHLAG': 0,
    'HAMMERSCHMIDT': 0,
    'HAMMERSLA': 0,
    'HAMMERSLEY': 0,
    'HAMMERSMITH': 0,
    'HAMMERSTAD': 0,
    'HAMMERSTEIN': 0,
    'HAMMERSTONE': 0,
    'HAMMERSTROM': 0,
    'HAMMERTON': 0,
    'HAMMES': 0,
    'HAMMET': 0,
    'HAMMETT': 0,
    'HAMMICK': 0,
    'HAMMIE': 0,
    'HAMMIEL': 0,
    'HAMMIL': 0,
    'HAMMILL': 0,
    'HAMMING': 0,
    'HAMMIT': 0,
    'HAMMITT': 0,
    'HAMMOCK': 0,
    'HAMMON': 0,
    'HAMMOND': 0,
    'HAMMONDS': 0,
    'HAMMONS': 0,
    'HAMMONTREE': 0,
    'HAMMOUD': 0,
    'HAMMOUDEH': 0,
    'HAMMRICH': 0,
    'HAMN': 0,
    'HAMNER': 0,
    'HAMOCK': 0,
    'HAMON': 0,
    'HAMOND': 0,
    'HAMONS': 0,
    'HAMOOD': 0,
    'HAMOR': 0,
    'HAMOUD': 0,
    'HAMOUDA': 0,
    'HAMOUI': 0,
    'HAMP': 0,
    'HAMPE': 0,
    'HAMPEL': 0,
    'HAMPER': 0,
    'HAMPL': 0,
    'HAMPLE': 0,
    'HAMPP': 0,
    'HAMPSEY': 0,
    'HAMPSHIRE': 0,
    'HAMPSON': 0,
    'HAMPSTEN': 0,
    'HAMPTON': 0,
    'HAMRA': 0,
    'HAMRAH': 0,
    'HAMRE': 0,
    'HAMREN': 0,
    'HAMRIC': 0,
    'HAMRICK': 0,
    'HAMRIN': 0,
    'HAMROCK': 0,
    'HAMS': 0,
    'HAMSHER': 0,
    'HAMSKI': 0,
    'HAMSLEY': 0,
    'HAMSON': 0,
    'HAMSTRA': 0,
    'HAMTON': 0,
    'HAMULA': 0,
    'HAMWAY': 0,
    'HAMWEY': 0,
    'HAMWI': 0,
    'HAMZA': 0,
    'HAMZE': 0,
    'HAMZEH': 0,
    'HAMZIC': 0,
    'HAN': 0.1172332942555686,
    'HANA': 0.8849557522123894,
    'HANABURGH': 0,
    'HANACEK': 0,
    'HANADA': 0,
    'HANAFI': 0,
    'HANAFIN': 0,
    'HANAGAN': 0,
    'HANAGRIFF': 0,
    'HANAHAN': 0,
    'HANAK': 0,
    'HANAMOTO': 0,
    'HANAN': 0,
    'HANANIA': 0,
    'HANAOKA': 0,
    'HANAS': 0,
    'HANASHIRO': 0,
    'HANAU': 0,
    'HANAUER': 0,
    'HANAVAN': 0,
    'HANAWALT': 0,
    'HANAWAY': 0,
    'HANBACK': 0,
    'HANBERG': 0,
    'HANBERRY': 0,
    'HANBURY': 0,
    'HANBY': 0,
    'HANCE': 0,
    'HANCEY': 0,
    'HANCHAR': 0,
    'HANCHARIK': 0,
    'HANCHER': 0,
    'HANCHETT': 0,
    'HANCHETTE': 0,
    'HANCHEY': 0,
    'HANCK': 0,
    'HANCOCK': 0,
    'HANCOX': 0,
    'HANCUFF': 0,
    'HANCY': 0,
    'HAND': 0,
    'HANDA': 0,
    'HANDAL': 0,
    'HANDBERG': 0,
    'HANDBERRY': 0,
    'HANDCOCK': 0,
    'HANDE': 0,
    'HANDEGARD': 0,
    'HANDEL': 0,
    'HANDELAND': 0,
    'HANDELMAN': 0,
    'HANDELONG': 0,
    'HANDELSMAN': 0,
    'HANDER': 0,
    'HANDERHAN': 0,
    'HANDERSON': 0,
    'HANDFIELD': 0,
    'HANDFORD': 0,
    'HANDING': 0,
    'HANDKE': 0,
    'HANDL': 0,
    'HANDLE': 0,
    'HANDLEMAN': 0,
    'HANDLEN': 0,
    'HANDLER': 0,
    'HANDLEY': 0,
    'HANDLIN': 0,
    'HANDLON': 0,
    'HANDLOS': 0,
    'HANDLOSER': 0,
    'HANDLY': 0,
    'HANDMAN': 0,
    'HANDO': 0,
    'HANDON': 0,
    'HANDORF': 0,
    'HANDRAHAN': 0,
    'HANDRAN': 0,
    'HANDREN': 0,
    'HANDRICH': 0,
    'HANDRICK': 0,
    'HANDS': 0,
    'HANDSAKER': 0,
    'HANDSCHKE': 0,
    'HANDSCHUH': 0,
    'HANDSCHUMACHER': 0,
    'HANDSHAW': 0,
    'HANDSHOE': 0,
    'HANDSHY': 0,
    'HANDSOME': 0,
    'HANDSON': 0,
    'HANDT': 0,
    'HANDWERGER': 0,
    'HANDWERK': 0,
    'HANDWERKER': 0,
    'HANDWORK': 0,
    'HANDY': 0,
    'HANDYSIDE': 0,
    'HANDZEL': 0,
    'HANDZLIK': 0,
    'HANDZO': 0,
    'HANE': 0,
    'HANEBERG': 0,
    'HANEBRINK': 0,
    'HANEBUTT': 0,
    'HANEEF': 0,
    'HANEFELD': 0,
    'HANEGAN': 0,
    'HANEK': 0,
    'HANEKAMP': 0,
    'HANEKE': 0,
    'HANEL': 0,
    'HANELINE': 0,
    'HANELY': 0,
    'HANEMAN': 0,
    'HANEMANN': 0,
    'HANEN': 0,
    'HANENBERG': 0,
    'HANENBERGER': 0,
    'HANENBURG': 0,
    'HANER': 0,
    'HANES': 0,
    'HANESWORTH': 0,
    'HANEWINKEL': 0,
    'HANEY': 0,
    'HANF': 0,
    'HANFF': 0,
    'HANFLING': 0,
    'HANFORD': 0,
    'HANFT': 0,
    'HANG': 0.3333333333333333,
    'HANGARTNER': 0,
    'HANGE': 0,
    'HANGEN': 0,
    'HANGER': 0,
    'HANGES': 0,
    'HANGEY': 0,
    'HANGGE': 0,
    'HANGGI': 0,
    'HANGSLEBEN': 0,
    'HANH': 1,
    'HANHAN': 0,
    'HANHART': 0,
    'HANI': 0,
    'HANIBLE': 0,
    'HANICH': 0,
    'HANICK': 0,
    'HANIE': 0,
    'HANIF': 0,
    'HANIFAN': 0,
    'HANIFEN': 0,
    'HANIFF': 0,
    'HANIFIN': 0,
    'HANIFORD': 0,
    'HANIFY': 0,
    'HANIG': 0,
    'HANIGAN': 0,
    'HANIK': 0,
    'HANIKA': 0,
    'HANIN': 0,
    'HANING': 0,
    'HANINGTON': 0,
    'HANIS': 0,
    'HANISCH': 0,
    'HANISH': 0,
    'HANISKO': 0,
    'HANK': 0.8771929824561403,
    'HANKA': 0,
    'HANKAL': 0,
    'HANKAMER': 0,
    'HANKAMMER': 0,
    'HANKE': 0,
    'HANKEE': 0,
    'HANKEL': 0,
    'HANKEMEIER': 0,
    'HANKEN': 0,
    'HANKER': 0,
    'HANKERD': 0,
    'HANKERSON': 0,
    'HANKES': 0,
    'HANKEY': 0,
    'HANKIN': 0,
    'HANKINS': 0,
    'HANKINSON': 0,
    'HANKISON': 0,
    'HANKLA': 0,
    'HANKLE': 0,
    'HANKO': 0,
    'HANKS': 0,
    'HANKTON': 0,
    'HANKWITZ': 0,
    'HANLAN': 0,
    'HANLE': 0,
    'HANLEN': 0,
    'HANLEY': 0,
    'HANLIN': 0,
    'HANLINE': 0,
    'HANLON': 0,
    'HANLY': 0,
    'HANMER': 0,
    'HANMORE': 0,
    'HANN': 0,
    'HANNA': 0.3465346534653466,
    'HANNABASS': 0,
    'HANNAFIN': 0,
    'HANNAFORD': 0,
    'HANNAGAN': 0,
    'HANNAH': 0.8637236084452975,
    'HANNAHAN': 0,
    'HANNAHS': 0,
    'HANNAM': 0,
    'HANNAMAN': 0,
    'HANNAN': 0,
    'HANNANS': 0,
    'HANNANT': 0,
    'HANNAS': 0,
    'HANNASCH': 0,
    'HANNAWAY': 0,
    'HANNAY': 0,
    'HANNE': 0,
    'HANNEBAUM': 0,
    'HANNEGAN': 0,
    'HANNEKE': 0,
    'HANNEKEN': 0,
    'HANNEL': 0,
    'HANNELORE': 1,
    'HANNEMAN': 0,
    'HANNEMANN': 0,
    'HANNEN': 0,
    'HANNER': 0,
    'HANNERS': 0,
    'HANNES': 0,
    'HANNESSON': 0,
    'HANNETT': 0,
    'HANNEY': 0,
    'HANNI': 0,
    'HANNIBAL': 0,
    'HANNIBLE': 0,
    'HANNICK': 0,
    'HANNIE': 0,
    'HANNIFAN': 0,
    'HANNIFIN': 0,
    'HANNIFORD': 0,
    'HANNIG': 0,
    'HANNIGAN': 0,
    'HANNINEN': 0,
    'HANNING': 0,
    'HANNINGTON': 0,
    'HANNIS': 0,
    'HANNO': 0,
    'HANNOLD': 0,
    'HANNON': 0,
    'HANNOSH': 0,
    'HANNOUSH': 0,
    'HANNS': 0,
    'HANNU': 0,
    'HANNULA': 0,
    'HANNUM': 0,
    'HANNUS': 0,
    'HANNY': 0,
    'HANO': 0,
    'HANOHANO': 0,
    'HANOLD': 0,
    'HANON': 0,
    'HANOR': 0,
    'HANOUSEK': 0,
    'HANOVER': 0,
    'HANRAHAN': 0,
    'HANRATH': 0,
    'HANRATTY': 0,
    'HANRIGHT': 0,
    'HANRY': 0,
    'HANS': 0.9101941747572815,
    'HANSAN': 0,
    'HANSANA': 0,
    'HANSARD': 0,
    'HANSBARGER': 0,
    'HANSBERGER': 0,
    'HANSBERRY': 0,
    'HANSBOROUGH': 0,
    'HANSBRO': 0,
    'HANSBROUGH': 0,
    'HANSBURY': 0,
    'HANSCH': 0,
    'HANSCHE': 0,
    'HANSCOM': 0,
    'HANSCOME': 0,
    'HANSE': 0,
    'HANSEL': 0,
    'HANSELL': 0,
    'HANSELMAN': 0,
    'HANSELMANN': 0,
    'HANSEN': 0,
    'HANSER': 0,
    'HANSERD': 0,
    'HANSES': 0,
    'HANSEY': 0,
    'HANSFORD': 0,
    'HANSGEN': 0,
    'HANSHAW': 0,
    'HANSHEW': 0,
    'HANSING': 0,
    'HANSINGER': 0,
    'HANSIS': 0,
    'HANSLER': 0,
    'HANSLEY': 0,
    'HANSLIK': 0,
    'HANSLIP': 0,
    'HANSMA': 0,
    'HANSMAN': 0,
    'HANSMANN': 0,
    'HANSMEIER': 0,
    'HANSMEYER': 0,
    'HANSOM': 0,
    'HANSON': 0,
    'HANSRAJ': 0,
    'HANSROTE': 0,
    'HANSS': 0,
    'HANSSEN': 0,
    'HANSSON': 0,
    'HANSTAD': 0,
    'HANSTEIN': 0,
    'HANTAK': 0,
    'HANTEN': 0,
    'HANTHORN': 0,
    'HANTKE': 0,
    'HANTMAN': 0,
    'HANTON': 0,
    'HANTZ': 0,
    'HANULA': 0,
    'HANUMAN': 0,
    'HANUS': 0,
    'HANUSA': 0,
    'HANUSCH': 0,
    'HANUSCHAK': 0,
    'HANVEY': 0,
    'HANVILLE': 0,
    'HANVY': 0,
    'HANWAY': 0,
    'HANWELL': 0,
    'HANY': 0,
    'HANYOK': 0,
    'HANYON': 0,
    'HANZ': 0,
    'HANZAL': 0,
    'HANZALIK': 0,
    'HANZAWA': 0,
    'HANZE': 0,
    'HANZEL': 0,
    'HANZELKA': 0,
    'HANZL': 0,
    'HANZLICEK': 0,
    'HANZLICK': 0,
    'HANZLIK': 0,
    'HANZY': 0,
    'HAO': 0,
    'HAPE': 0,
    'HAPEMAN': 0,
    'HAPER': 0,
    'HAPES': 0,
    'HAPGOOD': 0,
    'HAPKA': 0,
    'HAPKE': 0,
    'HAPNER': 0,
    'HAPNEY': 0,
    'HAPP': 0,
    'HAPPE': 0,
    'HAPPEL': 0,
    'HAPPENY': 0,
    'HAPPER': 0,
    'HAPPLE': 0,
    'HAPPOLD': 0,
    'HAPPOLDT': 0,
    'HAPPS': 0,
    'HAPPY': 0,
    'HAPTONSTALL': 0,
    'HAQ': 0,
    'HAQQ': 0,
    'HAQUE': 0,
    'HAR': 0,
    'HARA': 0,
    'HARABEDIAN': 0,
    'HARABURDA': 0,
    'HARACZ': 0,
    'HARADA': 0,
    'HARADEN': 0,
    'HARADER': 0,
    'HARADON': 0,
    'HARAGAN': 0,
    'HARAGUCHI': 0,
    'HARAJLI': 0,
    'HARAKAL': 0,
    'HARAKAS': 0,
    'HARALDSEN': 0,
    'HARALDSON': 0,
    'HARALSON': 0,
    'HARAMIS': 0,
    'HARAN': 0,
    'HARANG': 0,
    'HARANO': 0,
    'HARANT': 0,
    'HARARI': 0,
    'HARARY': 0,
    'HARAS': 0,
    'HARASIMOWICZ': 0,
    'HARASTY': 0,
    'HARAUGHTY': 0,
    'HARAWAY': 0,
    'HARAY': 0,
    'HARAYDA': 0,
    'HARAZIN': 0,
    'HARB': 0,
    'HARBACH': 0,
    'HARBACK': 0,
    'HARBAGE': 0,
    'HARBARGER': 0,
    'HARBART': 0,
    'HARBAUGH': 0,
    'HARBECK': 0,
    'HARBEN': 0,
    'HARBER': 0,
    'HARBERS': 0,
    'HARBERSON': 0,
    'HARBERT': 0,
    'HARBERTS': 0,
    'HARBERTSON': 0,
    'HARBESON': 0,
    'HARBEY': 0,
    'HARBICK': 0,
    'HARBIN': 0,
    'HARBINSON': 0,
    'HARBISON': 0,
    'HARBIT': 0,
    'HARBO': 0,
    'HARBOLD': 0,
    'HARBOLT': 0,
    'HARBOR': 0,
    'HARBORD': 0,
    'HARBORT': 0,
    'HARBORTH': 0,
    'HARBOTTLE': 0,
    'HARBOUR': 0,
    'HARBOURT': 0,
    'HARBRECHT': 0,
    'HARBRIDGE': 0,
    'HARBRON': 0,
    'HARBST': 0,
    'HARBUCK': 0,
    'HARBUT': 0,
    'HARBY': 0,
    'HARCAR': 0,
    'HARCARIK': 0,
    'HARCHAR': 0,
    'HARCHARIK': 0,
    'HARCLERODE': 0,
    'HARCOURT': 0,
    'HARCROW': 0,
    'HARCUM': 0,
    'HARCUS': 0,
    'HARD': 0,
    'HARDACKER': 0,
    'HARDACRE': 0,
    'HARDAGE': 0,
    'HARDAKER': 0,
    'HARDAMAN': 0,
    'HARDAMON': 0,
    'HARDAN': 0,
    'HARDAWAY': 0,
    'HARDBARGER': 0,
    'HARDCASTLE': 0,
    'HARDEBECK': 0,
    'HARDEE': 0,
    'HARDEGREE': 0,
    'HARDEKOPF': 0,
    'HARDEL': 0,
    'HARDELL': 0,
    'HARDEMAN': 0,
    'HARDEMON': 0,
    'HARDEN': 0,
    'HARDENBERGH': 0,
    'HARDENBROOK': 0,
    'HARDENBURG': 0,
    'HARDENBURGH': 0,
    'HARDENSTINE': 0,
    'HARDER': 0,
    'HARDERS': 0,
    'HARDESTER': 0,
    'HARDESTY': 0,
    'HARDEY': 0,
    'HARDGE': 0,
    'HARDGES': 0,
    'HARDGRAVE': 0,
    'HARDGRAVES': 0,
    'HARDGROVE': 0,
    'HARDI': 0,
    'HARDIAL': 0,
    'HARDICK': 0,
    'HARDIE': 0,
    'HARDIEK': 0,
    'HARDIES': 0,
    'HARDIG': 0,
    'HARDIGREE': 0,
    'HARDIMAN': 0,
    'HARDIMON': 0,
    'HARDIN': 0,
    'HARDINA': 0,
    'HARDINE': 0,
    'HARDING': 0,
    'HARDINGE': 0,
    'HARDINGER': 0,
    'HARDISKY': 0,
    'HARDISON': 0,
    'HARDISTER': 0,
    'HARDISTY': 0,
    'HARDLEY': 0,
    'HARDMAN': 0,
    'HARDMON': 0,
    'HARDNER': 0,
    'HARDNETT': 0,
    'HARDNEY': 0,
    'HARDNICK': 0,
    'HARDON': 0,
    'HARDRATH': 0,
    'HARDRICK': 0,
    'HARDRIDGE': 0,
    'HARDS': 0,
    'HARDT': 0,
    'HARDTKE': 0,
    'HARDWARE': 0,
    'HARDWAY': 0,
    'HARDWELL': 0,
    'HARDWICK': 0,
    'HARDWICKE': 0,
    'HARDY': 0,
    'HARDYMAN': 0,
    'HARDYMON': 0,
    'HARE': 0,
    'HAREL': 0,
    'HARELL': 0,
    'HARELSON': 0,
    'HAREMZA': 0,
    'HAREN': 0,
    'HARENBERG': 0,
    'HARENDA': 0,
    'HARENZA': 0,
    'HARER': 0,
    'HARES': 0,
    'HAREWOOD': 0,
    'HARFF': 0,
    'HARFIELD': 0,
    'HARFORD': 0,
    'HARFST': 0,
    'HARGADINE': 0,
    'HARGADON': 0,
    'HARGAN': 0,
    'HARGARTEN': 0,
    'HARGATE': 0,
    'HARGE': 0,
    'HARGENRADER': 0,
    'HARGENS': 0,
    'HARGER': 0,
    'HARGES': 0,
    'HARGESHEIMER': 0,
    'HARGEST': 0,
    'HARGET': 0,
    'HARGETT': 0,
    'HARGETTE': 0,
    'HARGIS': 0,
    'HARGISS': 0,
    'HARGITT': 0,
    'HARGON': 0,
    'HARGRAVE': 0,
    'HARGRAVES': 0,
    'HARGREAVES': 0,
    'HARGRETT': 0,
    'HARGRO': 0,
    'HARGRODER': 0,
    'HARGROVE': 0,
    'HARGROVES': 0,
    'HARGROW': 0,
    'HARGUESS': 0,
    'HARGUS': 0,
    'HARGUTH': 0,
    'HARI': 0,
    'HARIAN': 0,
    'HARICH': 0,
    'HARIG': 0,
    'HARIHARAN': 0,
    'HARIN': 0,
    'HARING': 0,
    'HARINGS': 0,
    'HARINGTON': 0,
    'HARIPRASAD': 0,
    'HARIRI': 0,
    'HARIS': 0,
    'HARISH': 0,
    'HARISON': 0,
    'HARISTON': 0,
    'HARITON': 0,
    'HARITOS': 0,
    'HARJES': 0,
    'HARJO': 0,
    'HARJU': 0,
    'HARJUNG': 0,
    'HARK': 0,
    'HARKABUS': 0,
    'HARKAVY': 0,
    'HARKCOM': 0,
    'HARKE': 0,
    'HARKEMA': 0,
    'HARKEN': 0,
    'HARKENRIDER': 0,
    'HARKER': 0,
    'HARKESS': 0,
    'HARKEY': 0,
    'HARKIN': 0,
    'HARKINS': 0,
    'HARKINSON': 0,
    'HARKLEROAD': 0,
    'HARKLESS': 0,
    'HARKLEY': 0,
    'HARKNESS': 0,
    'HARKONEN': 0,
    'HARKRADER': 0,
    'HARKREADER': 0,
    'HARKRIDER': 0,
    'HARKSEN': 0,
    'HARL': 0,
    'HARLA': 0,
    'HARLACHER': 0,
    'HARLACKER': 0,
    'HARLAMERT': 0,
    'HARLAN': 0.7782101167315175,
    'HARLAND': 0.814663951120163,
    'HARLANDER': 0,
    'HARLE': 0,
    'HARLEAUX': 0,
    'HARLEE': 0,
    'HARLEM': 0,
    'HARLEMAN': 0,
    'HARLEN': 0,
    'HARLER': 0,
    'HARLES': 0,
    'HARLESS': 0,
    'HARLESTON': 0,
    'HARLEY': 0.8007536504945831,
    'HARLIN': 0,
    'HARLINE': 0,
    'HARLING': 0,
    'HARLLEE': 0,
    'HARLOCK': 0,
    'HARLOFF': 0,
    'HARLON': 0,
    'HARLOR': 0,
    'HARLOS': 0,
    'HARLOW': 0,
    'HARLOWE': 0,
    'HARLSON': 0,
    'HARM': 0,
    'HARMA': 0,
    'HARMALA': 0,
    'HARMAN': 0,
    'HARMANN': 0,
    'HARMATZ': 0,
    'HARMEIER': 0,
    'HARMEL': 0,
    'HARMELING': 0,
    'HARMELINK': 0,
    'HARMEN': 0,
    'HARMENING': 0,
    'HARMER': 0,
    'HARMES': 0,
    'HARMESON': 0,
    'HARMEYER': 0,
    'HARMISON': 0,
    'HARMON': 0,
    'HARMONSON': 0,
    'HARMONY': 0.9259259259259258,
    'HARMOR': 0,
    'HARMS': 0,
    'HARMSEN': 0,
    'HARMSTON': 0,
    'HARMUTH': 0,
    'HARN': 0,
    'HARNACK': 0,
    'HARNAGE': 0,
    'HARNANDEZ': 0,
    'HARNAR': 0,
    'HARNDEN': 0,
    'HARNE': 0,
    'HARNED': 0,
    'HARNER': 0,
    'HARNES': 0,
    'HARNESS': 0,
    'HARNETIAUX': 0,
    'HARNETT': 0,
    'HARNEY': 0,
    'HARNICK': 0,
    'HARNISCH': 0,
    'HARNISH': 0,
    'HARNISHFEGER': 0,
    'HARNIST': 0,
    'HARNLY': 0,
    'HARNOIS': 0,
    'HARNS': 0,
    'HARNSBERGER': 0,
    'HARO': 0,
    'HAROIAN': 0,
    'HAROLD': 0.9936428228003633,
    'HAROLDSEN': 0,
    'HAROLDSON': 0,
    'HARON': 0,
    'HAROON': 0,
    'HAROOTUNIAN': 0,
    'HAROS': 0,
    'HAROUFF': 0,
    'HAROUN': 0,
    'HAROUTOUNIAN': 0,
    'HAROUTUNIAN': 0,
    'HAROY': 0,
    'HARP': 0,
    'HARPE': 0,
    'HARPEL': 0,
    'HARPELL': 0,
    'HARPENAU': 0,
    'HARPER': 0,
    'HARPHAM': 0,
    'HARPIN': 0,
    'HARPINE': 0,
    'HARPLE': 0,
    'HARPLEY': 0,
    'HARPOLD': 0,
    'HARPOLE': 0,
    'HARPOOL': 0,
    'HARPRING': 0,
    'HARPS': 0,
    'HARPST': 0,
    'HARPSTER': 0,
    'HARPSTRITE': 0,
    'HARR': 0,
    'HARRA': 0,
    'HARRADINE': 0,
    'HARRAH': 0,
    'HARRAL': 0,
    'HARRALD': 0,
    'HARRALL': 0,
    'HARRALSON': 0,
    'HARRAN': 0,
    'HARRAND': 0,
    'HARRAR': 0,
    'HARRAS': 0,
    'HARRAWAY': 0,
    'HARRAWOOD': 0,
    'HARRE': 0,
    'HARREII': 0,
    'HARREL': 0,
    'HARRELD': 0,
    'HARRELL': 0,
    'HARRELSON': 0,
    'HARREN': 0,
    'HARRENSTEIN': 0,
    'HARRER': 0,
    'HARRES': 0,
    'HARRETT': 0,
    'HARRI': 0,
    'HARRICHARAN': 0,
    'HARRICK': 0,
    'HARRIDGE': 0,
    'HARRIE': 0,
    'HARRIED': 0,
    'HARRIEL': 0,
    'HARRIELL': 0,
    'HARRIER': 0,
    'HARRIES': 0,
    'HARRIET': 0.9985734664764622,
    'HARRIETT': 0.9938837920489297,
    'HARRIETTE': 1,
    'HARRIG': 0,
    'HARRIGAN': 0,
    'HARRIGER': 0,
    'HARRIGILL': 0,
    'HARRILAL': 0,
    'HARRILL': 0,
    'HARRIMAN': 0,
    'HARRIN': 0,
    'HARRING': 0,
    'HARRINGTON': 0,
    'HARRINTON': 0,
    'HARRIOT': 0,
    'HARRIOTT': 0,
    'HARRIPERSAUD': 0,
    'HARRIS': 0.039297877914592605,
    'HARRISON': 0.17701352889113667,
    'HARRISS': 0,
    'HARRISSON': 0,
    'HARRISTON': 0,
    'HARRITT': 0,
    'HARRITY': 0,
    'HARRO': 0,
    'HARROD': 0,
    'HARROFF': 0,
    'HARROLD': 0,
    'HARROLLE': 0,
    'HARRON': 0,
    'HARROP': 0,
    'HARROUN': 0,
    'HARROW': 0,
    'HARROWER': 0,
    'HARRS': 0,
    'HARRSCH': 0,
    'HARRUFF': 0,
    'HARRUP': 0,
    'HARRY': 0.9871784787225675,
    'HARRYMAN': 0,
    'HARSANY': 0,
    'HARSANYI': 0,
    'HARSCH': 0,
    'HARSCHE': 0,
    'HARSELL': 0,
    'HARSEN': 0,
    'HARSEY': 0,
    'HARSH': 0,
    'HARSHA': 0,
    'HARSHAW': 0,
    'HARSHBARGER': 0,
    'HARSHBERGER': 0,
    'HARSHEY': 0,
    'HARSHFIELD': 0,
    'HARSHMAN': 0,
    'HARSIN': 0,
    'HARSLEY': 0,
    'HARSON': 0,
    'HARSTAD': 0,
    'HARSTINE': 0,
    'HARSTON': 0,
    'HARSY': 0,
    'HART': 0,
    'HARTAGE': 0,
    'HARTANTO': 0,
    'HARTBARGER': 0,
    'HARTBERGER': 0,
    'HARTDEGEN': 0,
    'HARTE': 0,
    'HARTEAU': 0,
    'HARTEIS': 0,
    'HARTEL': 0,
    'HARTELL': 0,
    'HARTEN': 0,
    'HARTENBACH': 0,
    'HARTENBERGER': 0,
    'HARTENSTEIN': 0,
    'HARTENSTINE': 0,
    'HARTER': 0,
    'HARTERT': 0,
    'HARTERY': 0,
    'HARTEY': 0,
    'HARTFELDER': 0,
    'HARTFIEL': 0,
    'HARTFIELD': 0,
    'HARTFORD': 0,
    'HARTGE': 0,
    'HARTGERINK': 0,
    'HARTGERS': 0,
    'HARTGRAVE': 0,
    'HARTGRAVES': 0,
    'HARTGROVE': 0,
    'HARTH': 0,
    'HARTHAN': 0,
    'HARTHCOCK': 0,
    'HARTHORN': 0,
    'HARTHORNE': 0,
    'HARTHUN': 0,
    'HARTIG': 0,
    'HARTIGAN': 0,
    'HARTILL': 0,
    'HARTIN': 0,
    'HARTINEZ': 0,
    'HARTING': 0,
    'HARTINGER': 0,
    'HARTINGS': 0,
    'HARTIS': 0,
    'HARTJE': 0,
    'HARTJEN': 0,
    'HARTJES': 0,
    'HARTKA': 0,
    'HARTKE': 0,
    'HARTKEMEYER': 0,
    'HARTKOPF': 0,
    'HARTKORN': 0,
    'HARTL': 0,
    'HARTLAGE': 0,
    'HARTLAND': 0,
    'HARTLAUB': 0,
    'HARTLE': 0,
    'HARTLEB': 0,
    'HARTLEBEN': 0,
    'HARTLEIN': 0,
    'HARTLEP': 0,
    'HARTLEROAD': 0,
    'HARTLERODE': 0,
    'HARTLESS': 0,
    'HARTLEY': 0,
    'HARTLIEB': 0,
    'HARTLINE': 0,
    'HARTLING': 0,
    'HARTLOFF': 0,
    'HARTLOVE': 0,
    'HARTLY': 0,
    'HARTMAN': 0,
    'HARTMANN': 0,
    'HARTMEYER': 0,
    'HARTNAGEL': 0,
    'HARTNAGLE': 0,
    'HARTNELL': 0,
    'HARTNER': 0,
    'HARTNESS': 0,
    'HARTNETT': 0,
    'HARTNEY': 0,
    'HARTO': 0,
    'HARTOG': 0,
    'HARTON': 0,
    'HARTONG': 0,
    'HARTONO': 0,
    'HARTOONIAN': 0,
    'HARTOUNIAN': 0,
    'HARTPENCE': 0,
    'HARTQUIST': 0,
    'HARTRANFT': 0,
    'HARTRICH': 0,
    'HARTRICK': 0,
    'HARTRIDGE': 0,
    'HARTRUM': 0,
    'HARTRY': 0,
    'HARTS': 0,
    'HARTSAW': 0,
    'HARTSBURG': 0,
    'HARTSEL': 0,
    'HARTSELL': 0,
    'HARTSELLE': 0,
    'HARTSFIELD': 0,
    'HARTSGROVE': 0,
    'HARTSHORN': 0,
    'HARTSHORNE': 0,
    'HARTSIG': 0,
    'HARTSOCK': 0,
    'HARTSOE': 0,
    'HARTSON': 0,
    'HARTSOOK': 0,
    'HARTSOUGH': 0,
    'HARTSTEIN': 0,
    'HARTSUFF': 0,
    'HARTT': 0,
    'HARTTER': 0,
    'HARTUNG': 0,
    'HARTUNIAN': 0,
    'HARTUP': 0,
    'HARTUPEE': 0,
    'HARTVIGSEN': 0,
    'HARTWAY': 0,
    'HARTWEG': 0,
    'HARTWELL': 0,
    'HARTWICH': 0,
    'HARTWICK': 0,
    'HARTWIG': 0,
    'HARTWIGSEN': 0,
    'HARTY': 0,
    'HARTZ': 0,
    'HARTZE': 0,
    'HARTZEL': 0,
    'HARTZELL': 0,
    'HARTZER': 0,
    'HARTZFELD': 0,
    'HARTZHEIM': 0,
    'HARTZLER': 0,
    'HARTZMAN': 0,
    'HARTZO': 0,
    'HARTZOG': 0,
    'HARUBIN': 0,
    'HARUN': 0,
    'HARUTUNIAN': 0,
    'HARUTYUNYAN': 0,
    'HARVALA': 0,
    'HARVAN': 0,
    'HARVANEK': 0,
    'HARVARD': 0,
    'HARVAT': 0,
    'HARVATH': 0,
    'HARVEL': 0,
    'HARVELL': 0,
    'HARVER': 0,
    'HARVES': 0,
    'HARVEST': 0,
    'HARVESTER': 0,
    'HARVESTON': 0,
    'HARVEY': 0.6339702386193538,
    'HARVICK': 0,
    'HARVIE': 0,
    'HARVIEUX': 0,
    'HARVILL': 0,
    'HARVILLA': 0,
    'HARVILLE': 0,
    'HARVIN': 0,
    'HARVIS': 0,
    'HARVISON': 0,
    'HARVLEY': 0,
    'HARVY': 0,
    'HARWARD': 0,
    'HARWELL': 0,
    'HARWICK': 0,
    'HARWIG': 0,
    'HARWIN': 0,
    'HARWOOD': 0,
    'HARWORTH': 0,
    'HARY': 0,
    'HARZ': 0,
    'HAS': 0,
    'HASAN': 0,
    'HASANI': 0,
    'HASANOVIC': 0,
    'HASAPIS': 0,
    'HASARA': 0,
    'HASBARGEN': 0,
    'HASBELL': 0,
    'HASBERRY': 0,
    'HASBROOK': 0,
    'HASBROUCK': 0,
    'HASBUN': 0,
    'HASCALL': 0,
    'HASCH': 0,
    'HASCHAK': 0,
    'HASCHE': 0,
    'HASCHER': 0,
    'HASCHKE': 0,
    'HASCUP': 0,
    'HASE': 0,
    'HASEBE': 0,
    'HASEGAWA': 0,
    'HASEK': 0,
    'HASEL': 0,
    'HASELBERGER': 0,
    'HASELDEN': 0,
    'HASELEU': 0,
    'HASELEY': 0,
    'HASELHORST': 0,
    'HASELHUHN': 0,
    'HASELMAN': 0,
    'HASELOFF': 0,
    'HASELOW': 0,
    'HASELRIG': 0,
    'HASELTINE': 0,
    'HASELTON': 0,
    'HASELWOOD': 0,
    'HASEMAN': 0,
    'HASEMANN': 0,
    'HASEMEYER': 0,
    'HASEN': 0,
    'HASENAUER': 0,
    'HASENBALG': 0,
    'HASENBANK': 0,
    'HASENBECK': 0,
    'HASENBEIN': 0,
    'HASENBERG': 0,
    'HASENFRATZ': 0,
    'HASENFUS': 0,
    'HASENFUSS': 0,
    'HASENJAEGER': 0,
    'HASENJAGER': 0,
    'HASENKAMP': 0,
    'HASENOEHRL': 0,
    'HASENOHRL': 0,
    'HASENOUR': 0,
    'HASENSTAB': 0,
    'HASENSTEIN': 0,
    'HASENYAGER': 0,
    'HASENZAHL': 0,
    'HASER': 0,
    'HASERT': 0,
    'HASETTE': 0,
    'HASEY': 0,
    'HASH': 0,
    'HASHA': 0,
    'HASHAGEN': 0,
    'HASHAM': 0,
    'HASHBARGER': 0,
    'HASHEIDER': 0,
    'HASHEM': 0,
    'HASHEMI': 0,
    'HASHEMIAN': 0,
    'HASHER': 0,
    'HASHEY': 0,
    'HASHI': 0,
    'HASHIGUCHI': 0,
    'HASHIM': 0,
    'HASHIMI': 0,
    'HASHIMOTO': 0,
    'HASHIZUME': 0,
    'HASHLEY': 0,
    'HASHMAN': 0,
    'HASHMI': 0,
    'HASIAK': 0,
    'HASIC': 0,
    'HASIK': 0,
    'HASKAMP': 0,
    'HASKE': 0,
    'HASKEL': 0,
    'HASKELL': 0,
    'HASKEN': 0,
    'HASKER': 0,
    'HASKETT': 0,
    'HASKEW': 0,
    'HASKEY': 0,
    'HASKIE': 0,
    'HASKILL': 0,
    'HASKIN': 0,
    'HASKINS': 0,
    'HASKO': 0,
    'HASKOVEC': 0,
    'HASLACH': 0,
    'HASLACKER': 0,
    'HASLAG': 0,
    'HASLAM': 0,
    'HASLEM': 0,
    'HASLER': 0,
    'HASLETT': 0,
    'HASLEY': 0,
    'HASLINGER': 0,
    'HASLIP': 0,
    'HASLUP': 0,
    'HASMAN': 0,
    'HASNAIN': 0,
    'HASNER': 0,
    'HASON': 0,
    'HASPEL': 0,
    'HASPER': 0,
    'HASS': 0,
    'HASSA': 0,
    'HASSALL': 0,
    'HASSAM': 0,
    'HASSAN': 0.5291005291005291,
    'HASSANALI': 0,
    'HASSANEIN': 0,
    'HASSANI': 0,
    'HASSANZADEH': 0,
    'HASSARD': 0,
    'HASSAY': 0,
    'HASSE': 0,
    'HASSEBROCK': 0,
    'HASSEBROEK': 0,
    'HASSEL': 0,
    'HASSELBACH': 0,
    'HASSELBACHER': 0,
    'HASSELBACK': 0,
    'HASSELBECK': 0,
    'HASSELBERG': 0,
    'HASSELBERGER': 0,
    'HASSELBLAD': 0,
    'HASSELBRING': 0,
    'HASSELBRINK': 0,
    'HASSELBUSCH': 0,
    'HASSELER': 0,
    'HASSELL': 0,
    'HASSELMAN': 0,
    'HASSELMANN': 0,
    'HASSELQUIST': 0,
    'HASSEMER': 0,
    'HASSEN': 0,
    'HASSENGER': 0,
    'HASSENPLUG': 0,
    'HASSENSTAB': 0,
    'HASSENZAHL': 0,
    'HASSER': 0,
    'HASSERT': 0,
    'HASSETT': 0,
    'HASSEVOORT': 0,
    'HASSEY': 0,
    'HASSID': 0,
    'HASSIE': 1,
    'HASSIG': 0,
    'HASSIN': 0,
    'HASSING': 0,
    'HASSINGER': 0,
    'HASSKAMP': 0,
    'HASSLER': 0,
    'HASSLINGER': 0,
    'HASSMAN': 0,
    'HASSMANN': 0,
    'HASSO': 0,
    'HASSOLD': 0,
    'HASSON': 0,
    'HASSOUN': 0,
    'HASSOUNEH': 0,
    'HASSTEDT': 0,
    'HAST': 0,
    'HASTE': 0,
    'HASTEDT': 0,
    'HASTEN': 0,
    'HASTERT': 0,
    'HASTEY': 0,
    'HASTIE': 0,
    'HASTIN': 0,
    'HASTING': 0,
    'HASTINGS': 0,
    'HASTON': 0,
    'HASTREITER': 0,
    'HASTY': 0,
    'HASWELL': 0,
    'HASZ': 0,
    'HATA': 0,
    'HATADA': 0,
    'HATAKEYAMA': 0,
    'HATALA': 0,
    'HATALLA': 0,
    'HATAMI': 0,
    'HATANAKA': 0,
    'HATANO': 0,
    'HATAWAY': 0,
    'HATCH': 0,
    'HATCHARD': 0,
    'HATCHEL': 0,
    'HATCHELL': 0,
    'HATCHER': 0,
    'HATCHET': 0,
    'HATCHETT': 0,
    'HATCHETTE': 0,
    'HATEFI': 0,
    'HATEM': 0,
    'HATER': 0,
    'HATFIELD': 0,
    'HATH': 0,
    'HATHAWAY': 0,
    'HATHCOAT': 0,
    'HATHCOCK': 0,
    'HATHCOX': 0,
    'HATHERILL': 0,
    'HATHERLEY': 0,
    'HATHEWAY': 0,
    'HATHHORN': 0,
    'HATHON': 0,
    'HATHORN': 0,
    'HATHORNE': 0,
    'HATHWAY': 0,
    'HATIN': 0,
    'HATKE': 0,
    'HATLE': 0,
    'HATLEE': 0,
    'HATLELI': 0,
    'HATLEN': 0,
    'HATLER': 0,
    'HATLESTAD': 0,
    'HATLEVIG': 0,
    'HATLEY': 0,
    'HATMAKER': 0,
    'HATMAN': 0,
    'HATON': 0,
    'HATORI': 0,
    'HATOUM': 0,
    'HATRICK': 0,
    'HATRIDGE': 0,
    'HATSTAT': 0,
    'HATT': 0,
    'HATTA': 0,
    'HATTABAUGH': 0,
    'HATTAN': 0,
    'HATTAR': 0,
    'HATTAWAY': 0,
    'HATTEBERG': 0,
    'HATTEL': 0,
    'HATTEM': 0,
    'HATTEMER': 0,
    'HATTEN': 0,
    'HATTENBACH': 0,
    'HATTENBURG': 0,
    'HATTENDORF': 0,
    'HATTENHAUER': 0,
    'HATTER': 0,
    'HATTERMAN': 0,
    'HATTERMANN': 0,
    'HATTERSLEY': 0,
    'HATTERY': 0,
    'HATTEY': 0,
    'HATTIE': 0.9991079393398752,
    'HATTIER': 0,
    'HATTING': 0,
    'HATTIS': 0,
    'HATTLEY': 0,
    'HATTMAN': 0,
    'HATTON': 0,
    'HATTORI': 0,
    'HATTRUP': 0,
    'HATTY': 0,
    'HATZ': 0,
    'HATZEL': 0,
    'HATZELL': 0,
    'HATZENBUEHLER': 0,
    'HATZENBUHLER': 0,
    'HATZIDAKIS': 0,
    'HATZINGER': 0,
    'HATZIS': 0,
    'HATZOPOULOS': 0,
    'HAU': 0,
    'HAUAN': 0,
    'HAUB': 0,
    'HAUBEN': 0,
    'HAUBENSTRICKER': 0,
    'HAUBER': 0,
    'HAUBERT': 0,
    'HAUBNER': 0,
    'HAUBOLD': 0,
    'HAUBRICH': 0,
    'HAUBRICK': 0,
    'HAUCH': 0,
    'HAUCK': 0,
    'HAUCKE': 0,
    'HAUDE': 0,
    'HAUDER': 0,
    'HAUEISEN': 0,
    'HAUENSTEIN': 0,
    'HAUER': 0,
    'HAUERSPERGER': 0,
    'HAUERT': 0,
    'HAUERWAS': 0,
    'HAUETER': 0,
    'HAUF': 0,
    'HAUFE': 0,
    'HAUFF': 0,
    'HAUFFE': 0,
    'HAUFLER': 0,
    'HAUG': 0,
    'HAUGAARD': 0,
    'HAUGABOOK': 0,
    'HAUGABROOK': 0,
    'HAUGAN': 0,
    'HAUGE': 0,
    'HAUGEN': 0,
    'HAUGER': 0,
    'HAUGERUD': 0,
    'HAUGH': 0,
    'HAUGHAWOUT': 0,
    'HAUGHEE': 0,
    'HAUGHEY': 0,
    'HAUGHIAN': 0,
    'HAUGHN': 0,
    'HAUGHNEY': 0,
    'HAUGHT': 0,
    'HAUGHTON': 0,
    'HAUGHWOUT': 0,
    'HAUGLAND': 0,
    'HAUGLID': 0,
    'HAUGLIE': 0,
    'HAUGO': 0,
    'HAUGRUD': 0,
    'HAUGSTAD': 0,
    'HAUK': 0,
    'HAUKAAS': 0,
    'HAUKAP': 0,
    'HAUKE': 0,
    'HAUKOM': 0,
    'HAUKOOS': 0,
    'HAUKOS': 0,
    'HAUL': 0,
    'HAULBROOK': 0,
    'HAULCY': 0,
    'HAULER': 0,
    'HAULK': 0,
    'HAULMAN': 0,
    'HAULSEE': 0,
    'HAUMAN': 0,
    'HAUMANN': 0,
    'HAUMESSER': 0,
    'HAUMSCHILD': 0,
    'HAUN': 0,
    'HAUNER': 0,
    'HAUNERT': 0,
    'HAUNG': 0,
    'HAUNGS': 0,
    'HAUNSCHILD': 0,
    'HAUPERT': 0,
    'HAUPRICHT': 0,
    'HAUPT': 0,
    'HAUPTLI': 0,
    'HAUPTLY': 0,
    'HAUPTMAN': 0,
    'HAUPTMANN': 0,
    'HAURI': 0,
    'HAURY': 0,
    'HAUS': 0,
    'HAUSAM': 0,
    'HAUSAUER': 0,
    'HAUSBECK': 0,
    'HAUSCH': 0,
    'HAUSCHEL': 0,
    'HAUSCHILD': 0,
    'HAUSCHILDT': 0,
    'HAUSE': 0,
    'HAUSEN': 0,
    'HAUSENFLUCK': 0,
    'HAUSER': 0,
    'HAUSERMAN': 0,
    'HAUSERMANN': 0,
    'HAUSEY': 0,
    'HAUSFELD': 0,
    'HAUSHALTER': 0,
    'HAUSKEN': 0,
    'HAUSKINS': 0,
    'HAUSKNECHT': 0,
    'HAUSLADEN': 0,
    'HAUSLE': 0,
    'HAUSLER': 0,
    'HAUSLEY': 0,
    'HAUSMAN': 0,
    'HAUSMANN': 0,
    'HAUSNER': 0,
    'HAUSRATH': 0,
    'HAUSS': 0,
    'HAUSSER': 0,
    'HAUSSLER': 0,
    'HAUSSMAN': 0,
    'HAUSSMANN': 0,
    'HAUSTEIN': 0,
    'HAUSWALD': 0,
    'HAUSWIRTH': 0,
    'HAUT': 0,
    'HAUTALA': 0,
    'HAUTAMAKI': 0,
    'HAUTANEN': 0,
    'HAUTAU': 0,
    'HAUTER': 0,
    'HAUTH': 0,
    'HAUTMAN': 0,
    'HAUTZINGER': 0,
    'HAUVER': 0,
    'HAUX': 0,
    'HAUXWELL': 0,
    'HAUZE': 0,
    'HAVA': 0,
    'HAVARD': 0,
    'HAVAS': 0,
    'HAVEARD': 0,
    'HAVEKOST': 0,
    'HAVEL': 0,
    'HAVELKA': 0,
    'HAVELOCK': 0,
    'HAVELY': 0,
    'HAVEMAN': 0,
    'HAVEMANN': 0,
    'HAVEMEIER': 0,
    'HAVEN': 0,
    'HAVENAR': 0,
    'HAVENER': 0,
    'HAVENHILL': 0,
    'HAVENNER': 0,
    'HAVENS': 0,
    'HAVENSTEIN': 0,
    'HAVENSTRITE': 0,
    'HAVER': 0,
    'HAVERCAMP': 0,
    'HAVERCROFT': 0,
    'HAVERDINK': 0,
    'HAVERFIELD': 0,
    'HAVERKAMP': 0,
    'HAVERLAH': 0,
    'HAVERLAND': 0,
    'HAVERLOCK': 0,
    'HAVERLY': 0,
    'HAVERMAN': 0,
    'HAVERMANN': 0,
    'HAVERN': 0,
    'HAVERS': 0,
    'HAVERSON': 0,
    'HAVERSTICK': 0,
    'HAVERSTOCK': 0,
    'HAVERT': 0,
    'HAVERTY': 0,
    'HAVERY': 0,
    'HAVES': 0,
    'HAVEY': 0,
    'HAVICAN': 0,
    'HAVICE': 0,
    'HAVIER': 0,
    'HAVIG': 0,
    'HAVILAND': 0,
    'HAVILI': 0,
    'HAVILL': 0,
    'HAVINS': 0,
    'HAVIRD': 0,
    'HAVIS': 0,
    'HAVLICEK': 0,
    'HAVLICK': 0,
    'HAVLIK': 0,
    'HAVLIN': 0,
    'HAVLOVIC': 0,
    'HAVNER': 0,
    'HAVRAN': 0,
    'HAVRANEK': 0,
    'HAVRILLA': 0,
    'HAVRON': 0,
    'HAW': 0,
    'HAWA': 0,
    'HAWARD': 0,
    'HAWARI': 0,
    'HAWATMEH': 0,
    'HAWBAKER': 0,
    'HAWBECKER': 0,
    'HAWCO': 0,
    'HAWE': 0,
    'HAWES': 0,
    'HAWFIELD': 0,
    'HAWHEE': 0,
    'HAWK': 0,
    'HAWKE': 0,
    'HAWKEN': 0,
    'HAWKENSON': 0,
    'HAWKER': 0,
    'HAWKES': 0,
    'HAWKESWORTH': 0,
    'HAWKEY': 0,
    'HAWKIN': 0,
    'HAWKINBERRY': 0,
    'HAWKING': 0,
    'HAWKINGS': 0,
    'HAWKINS': 0,
    'HAWKINSON': 0,
    'HAWKS': 0,
    'HAWKSLEY': 0,
    'HAWKSWORTH': 0,
    'HAWLEY': 0,
    'HAWMAN': 0,
    'HAWN': 0,
    'HAWORTH': 0,
    'HAWPE': 0,
    'HAWRYLAK': 0,
    'HAWRYLUK': 0,
    'HAWS': 0,
    'HAWSE': 0,
    'HAWSEY': 0,
    'HAWSON': 0,
    'HAWTHORN': 0,
    'HAWTHORNE': 0,
    'HAWTHRONE': 0,
    'HAWTIN': 0,
    'HAWTON': 0,
    'HAWVER': 0,
    'HAWXHURST': 0,
    'HAX': 0,
    'HAXBY': 0,
    'HAXEL': 0,
    'HAXTON': 0,
    'HAY': 0,
    'HAYA': 0,
    'HAYAG': 0,
    'HAYAKAWA': 0,
    'HAYAMA': 0,
    'HAYASAKA': 0,
    'HAYASE': 0,
    'HAYASHI': 0,
    'HAYASHIDA': 0,
    'HAYAT': 0,
    'HAYBURN': 0,
    'HAYCOCK': 0,
    'HAYCOOK': 0,
    'HAYCOX': 0,
    'HAYCRAFT': 0,
    'HAYDA': 0,
    'HAYDAR': 0,
    'HAYDE': 0,
    'HAYDEE': 1,
    'HAYDEL': 0,
    'HAYDEN': 0.2305475504322767,
    'HAYDOCK': 0,
    'HAYDON': 0,
    'HAYDT': 0,
    'HAYDU': 0,
    'HAYDUK': 0,
    'HAYDUKE': 0,
    'HAYE': 0,
    'HAYEK': 0,
    'HAYEN': 0,
    'HAYENGA': 0,
    'HAYER': 0,
    'HAYES': 0,
    'HAYFORD': 0,
    'HAYGOOD': 0,
    'HAYHOE': 0,
    'HAYHURST': 0,
    'HAYKO': 0,
    'HAYLE': 0,
    'HAYLES': 0,
    'HAYLETT': 0,
    'HAYLEY': 0.9541984732824428,
    'HAYLOCK': 0,
    'HAYMAKER': 0,
    'HAYMAN': 0,
    'HAYMANS': 0,
    'HAYMER': 0,
    'HAYMES': 0,
    'HAYMON': 0,
    'HAYMOND': 0,
    'HAYMORE': 0,
    'HAYN': 0,
    'HAYNAL': 0,
    'HAYNAM': 0,
    'HAYNE': 0,
    'HAYNER': 0,
    'HAYNES': 0,
    'HAYNESWORTH': 0,
    'HAYNIE': 0,
    'HAYNOR': 0,
    'HAYNOS': 0,
    'HAYNSWORTH': 0,
    'HAYON': 0,
    'HAYRE': 0,
    'HAYS': 0,
    'HAYSE': 0,
    'HAYSLETT': 0,
    'HAYSLETTE': 0,
    'HAYSLEY': 0,
    'HAYSLIP': 0,
    'HAYSON': 0,
    'HAYTER': 0,
    'HAYTH': 0,
    'HAYTHE': 0,
    'HAYTHORN': 0,
    'HAYTON': 0,
    'HAYUNGA': 0,
    'HAYWARD': 0,
    'HAYWOOD': 0.3816793893129771,
    'HAYWORTH': 0,
    'HAYZLETT': 0,
    'HAZA': 0,
    'HAZAMA': 0,
    'HAZAN': 0,
    'HAZARD': 0,
    'HAZARI': 0,
    'HAZBOUN': 0,
    'HAZE': 0,
    'HAZEKAMP': 0,
    'HAZEL': 0.9836265884652982,
    'HAZELBAKER': 0,
    'HAZELDINE': 0,
    'HAZELET': 0,
    'HAZELETT': 0,
    'HAZELGROVE': 0,
    'HAZELHURST': 0,
    'HAZELIP': 0,
    'HAZELL': 0,
    'HAZELLIEF': 0,
    'HAZELMAN': 0,
    'HAZELRIG': 0,
    'HAZELRIGG': 0,
    'HAZELTINE': 0,
    'HAZELTON': 0,
    'HAZELWOOD': 0,
    'HAZEN': 0,
    'HAZENSTAB': 0,
    'HAZER': 0,
    'HAZIM': 0,
    'HAZIME': 0,
    'HAZINSKI': 0,
    'HAZLE': 0,
    'HAZLEHURST': 0,
    'HAZLERIG': 0,
    'HAZLETON': 0,
    'HAZLETT': 0,
    'HAZLEWOOD': 0,
    'HAZLEY': 0,
    'HAZLIP': 0,
    'HAZLITT': 0,
    'HAZUDA': 0,
    'HAZUKA': 0,
    'HAZY': 0,
    'HAZZARD': 0,
    'HDIIAND': 0,
    'HE': 0,
    'HEA': 0,
    'HEABERLIN': 0,
    'HEACOCK': 0,
    'HEACOX': 0,
    'HEAD': 0,
    'HEADD': 0,
    'HEADDEN': 0,
    'HEADE': 0,
    'HEADEN': 0,
    'HEADING': 0,
    'HEADINGS': 0,
    'HEADINGTON': 0,
    'HEADLAM': 0,
    'HEADLAND': 0,
    'HEADLEE': 0,
    'HEADLEY': 0,
    'HEADLY': 0,
    'HEADMAN': 0,
    'HEADRICK': 0,
    'HEADS': 0,
    'HEADSPETH': 0,
    'HEADWORTH': 0,
    'HEADY': 0,
    'HEAFEY': 0,
    'HEAFNER': 0,
    'HEAGERTY': 0,
    'HEAGGANS': 0,
    'HEAGLE': 0,
    'HEAGNEY': 0,
    'HEAGY': 0,
    'HEAL': 0,
    'HEALAN': 0,
    'HEALD': 0,
    'HEALE': 0,
    'HEALEA': 0,
    'HEALER': 0,
    'HEALEY': 0,
    'HEALION': 0,
    'HEALTH': 0,
    'HEALY': 0,
    'HEAN': 0,
    'HEANEY': 0,
    'HEANG': 0,
    'HEANUE': 0,
    'HEANY': 0,
    'HEAP': 0,
    'HEAPE': 0,
    'HEAPHY': 0,
    'HEAPS': 0,
    'HEARD': 0,
    'HEARE': 0,
    'HEARIN': 0,
    'HEARING': 0,
    'HEARL': 0,
    'HEARLD': 0,
    'HEARLEY': 0,
    'HEARN': 0,
    'HEARNDON': 0,
    'HEARNE': 0,
    'HEARNS': 0,
    'HEARNSBERGER': 0,
    'HEAROD': 0,
    'HEAROLD': 0,
    'HEARON': 0,
    'HEARRELL': 0,
    'HEARRING': 0,
    'HEARRON': 0,
    'HEARST': 0,
    'HEART': 0,
    'HEARTFIELD': 0,
    'HEARTH': 0,
    'HEARTLEY': 0,
    'HEARTSILL': 0,
    'HEARTWELL': 0,
    'HEARTY': 0,
    'HEARVEY': 0,
    'HEARY': 0,
    'HEASER': 0,
    'HEASLET': 0,
    'HEASLEY': 0,
    'HEASLIP': 0,
    'HEASTER': 0,
    'HEASTON': 0,
    'HEASTY': 0,
    'HEATER': 0,
    'HEATH': 0.4768583450210379,
    'HEATHCOAT': 0,
    'HEATHCOCK': 0,
    'HEATHCOE': 0,
    'HEATHCOTE': 0,
    'HEATHCOTT': 0,
    'HEATHER': 0.9985185185185186,
    'HEATHERINGTON': 0,
    'HEATHERLY': 0,
    'HEATHERMAN': 0,
    'HEATHERTON': 0,
    'HEATHINGTON': 0,
    'HEATHMAN': 0,
    'HEATLEY': 0,
    'HEATLY': 0,
    'HEATON': 0,
    'HEATWOLE': 0,
    'HEAVEN': 0,
    'HEAVENER': 0,
    'HEAVENS': 0,
    'HEAVER': 0,
    'HEAVERLO': 0,
    'HEAVEY': 0,
    'HEAVILAND': 0,
    'HEAVILIN': 0,
    'HEAVIN': 0,
    'HEAVLIN': 0,
    'HEAVNER': 0,
    'HEAVRIN': 0,
    'HEAVYRUNNER': 0,
    'HEBARD': 0,
    'HEBB': 0,
    'HEBBARD': 0,
    'HEBBE': 0,
    'HEBBEL': 0,
    'HEBBELER': 0,
    'HEBBERD': 0,
    'HEBBERT': 0,
    'HEBBLE': 0,
    'HEBBLETHWAITE': 0,
    'HEBDA': 0,
    'HEBDEN': 0,
    'HEBDON': 0,
    'HEBEBRAND': 0,
    'HEBEIN': 0,
    'HEBEISEN': 0,
    'HEBEL': 0,
    'HEBELER': 0,
    'HEBENSTREIT': 0,
    'HEBER': 0,
    'HEBERER': 0,
    'HEBERGER': 0,
    'HEBERLE': 0,
    'HEBERLEIN': 0,
    'HEBERLIE': 0,
    'HEBERLIG': 0,
    'HEBERLING': 0,
    'HEBERLY': 0,
    'HEBERT': 0,
    'HEBL': 0,
    'HEBLE': 0,
    'HEBLER': 0,
    'HEBNER': 0,
    'HEBRANK': 0,
    'HEBRARD': 0,
    'HEBRINK': 0,
    'HEBROCK': 0,
    'HEBRON': 0,
    'HEBSON': 0,
    'HECHANOVA': 0,
    'HECHAVARRIA': 0,
    'HECHINGER': 0,
    'HECHLER': 0,
    'HECHT': 0,
    'HECHTER': 0,
    'HECHTMAN': 0,
    'HECIMOVICH': 0,
    'HECK': 0,
    'HECKADON': 0,
    'HECKAMAN': 0,
    'HECKARD': 0,
    'HECKART': 0,
    'HECKATHORN': 0,
    'HECKATHORNE': 0,
    'HECKE': 0,
    'HECKEL': 0,
    'HECKELMAN': 0,
    'HECKENBACH': 0,
    'HECKENBERG': 0,
    'HECKENDORF': 0,
    'HECKENDORN': 0,
    'HECKENKAMP': 0,
    'HECKENLAIBLE': 0,
    'HECKENLIVELY': 0,
    'HECKER': 0,
    'HECKERMAN': 0,
    'HECKERT': 0,
    'HECKETHORN': 0,
    'HECKINGER': 0,
    'HECKLE': 0,
    'HECKLER': 0,
    'HECKLEY': 0,
    'HECKLINGER': 0,
    'HECKMAN': 0,
    'HECKMANN': 0,
    'HECKNER': 0,
    'HECKROTH': 0,
    'HECKSEL': 0,
    'HECKSTALL': 0,
    'HECKT': 0,
    'HECOX': 0,
    'HECTOR': 0.9844993715961458,
    'HED': 0,
    'HEDA': 0,
    'HEDAYAT': 0,
    'HEDAYATI': 0,
    'HEDBERG': 0,
    'HEDBLOM': 0,
    'HEDDEN': 0,
    'HEDDENS': 0,
    'HEDDERICH': 0,
    'HEDDERICK': 0,
    'HEDDERMAN': 0,
    'HEDDIN': 0,
    'HEDDING': 0,
    'HEDDINGER': 0,
    'HEDDINGS': 0,
    'HEDDINS': 0,
    'HEDDLE': 0,
    'HEDDLESON': 0,
    'HEDDLESTEN': 0,
    'HEDDLESTON': 0,
    'HEDDON': 0,
    'HEDDY': 0,
    'HEDE': 0,
    'HEDEEN': 0,
    'HEDEGAARD': 0,
    'HEDEGARD': 0,
    'HEDEMAN': 0,
    'HEDEMANN': 0,
    'HEDEMARK': 0,
    'HEDEN': 0,
    'HEDENBERG': 0,
    'HEDER': 0,
    'HEDERMAN': 0,
    'HEDGCOCK': 0,
    'HEDGCOTH': 0,
    'HEDGE': 0,
    'HEDGEBETH': 0,
    'HEDGECOCK': 0,
    'HEDGECOKE': 0,
    'HEDGECOTH': 0,
    'HEDGEMAN': 0,
    'HEDGEPATH': 0,
    'HEDGEPETH': 0,
    'HEDGER': 0,
    'HEDGES': 0,
    'HEDGESPETH': 0,
    'HEDGLIN': 0,
    'HEDGPETH': 0,
    'HEDGSPETH': 0,
    'HEDIGER': 0,
    'HEDIN': 0,
    'HEDING': 0,
    'HEDINGER': 0,
    'HEDINGTON': 0,
    'HEDKE': 0,
    'HEDLAND': 0,
    'HEDLER': 0,
    'HEDLEY': 0,
    'HEDLIN': 0,
    'HEDLUND': 0,
    'HEDMAN': 0,
    'HEDQUIST': 0,
    'HEDRICH': 0,
    'HEDRICK': 0,
    'HEDRICKS': 0,
    'HEDRINGTON': 0,
    'HEDSPETH': 0,
    'HEDSTROM': 0,
    'HEDTKE': 0,
    'HEDWALL': 0,
    'HEDWIG': 1,
    'HEDY': 1,
    'HEE': 0.8196721311475409,
    'HEEB': 0,
    'HEEBNER': 0,
    'HEED': 0,
    'HEEDER': 0,
    'HEEFNER': 0,
    'HEEG': 0,
    'HEEGER': 0,
    'HEEKE': 0,
    'HEEKIN': 0,
    'HEELAN': 0,
    'HEELEY': 0,
    'HEELY': 0,
    'HEEMAN': 0,
    'HEEMSTRA': 0,
    'HEEN': 0,
    'HEENAN': 0,
    'HEENEY': 0,
    'HEEP': 0,
    'HEER': 0,
    'HEERDT': 0,
    'HEEREMA': 0,
    'HEEREN': 0,
    'HEERES': 0,
    'HEERING': 0,
    'HEERINGA': 0,
    'HEERLEIN': 0,
    'HEERMAN': 0,
    'HEERMANCE': 0,
    'HEERMANN': 0,
    'HEERMANS': 0,
    'HEERN': 0,
    'HEERS': 0,
    'HEERSCHAP': 0,
    'HEERSINK': 0,
    'HEERY': 0,
    'HEES': 0,
    'HEESACKER': 0,
    'HEESCH': 0,
    'HEESE': 0,
    'HEESEN': 0,
    'HEESTAND': 0,
    'HEET': 0,
    'HEETER': 0,
    'HEETHER': 0,
    'HEETLAND': 0,
    'HEEZEN': 0,
    'HEFEL': 0,
    'HEFELE': 0,
    'HEFELFINGER': 0,
    'HEFF': 0,
    'HEFFEL': 0,
    'HEFFELBOWER': 0,
    'HEFFELFINGER': 0,
    'HEFFELMIRE': 0,
    'HEFFENTRAGER': 0,
    'HEFFER': 0,
    'HEFFERAN': 0,
    'HEFFERMAN': 0,
    'HEFFERN': 0,
    'HEFFERNAN': 0,
    'HEFFERON': 0,
    'HEFFINGER': 0,
    'HEFFINGTON': 0,
    'HEFFLEFINGER': 0,
    'HEFFLER': 0,
    'HEFFLEY': 0,
    'HEFFLIN': 0,
    'HEFFLINGER': 0,
    'HEFFNER': 0,
    'HEFFREN': 0,
    'HEFFRON': 0,
    'HEFLER': 0,
    'HEFLEY': 0,
    'HEFLIN': 0,
    'HEFLING': 0,
    'HEFNER': 0,
    'HEFT': 0,
    'HEFTER': 0,
    'HEFTI': 0,
    'HEFTON': 0,
    'HEFTY': 0,
    'HEGAN': 0,
    'HEGAR': 0,
    'HEGARTY': 0,
    'HEGAZY': 0,
    'HEGBERG': 0,
    'HEGDAHL': 0,
    'HEGDE': 0,
    'HEGE': 0,
    'HEGEDUS': 0,
    'HEGEL': 0,
    'HEGELE': 0,
    'HEGEMAN': 0,
    'HEGEMANN': 0,
    'HEGEMIER': 0,
    'HEGENAUER': 0,
    'HEGENBART': 0,
    'HEGENER': 0,
    'HEGER': 0,
    'HEGERFELD': 0,
    'HEGERLE': 0,
    'HEGEWALD': 0,
    'HEGG': 0,
    'HEGGAN': 0,
    'HEGGE': 0,
    'HEGGEM': 0,
    'HEGGEMEIER': 0,
    'HEGGEN': 0,
    'HEGGENSTALLER': 0,
    'HEGGER': 0,
    'HEGGESTAD': 0,
    'HEGGIE': 0,
    'HEGGINS': 0,
    'HEGGS': 0,
    'HEGI': 0,
    'HEGINBOTHAM': 0,
    'HEGLAND': 0,
    'HEGLAR': 0,
    'HEGLE': 0,
    'HEGLER': 0,
    'HEGLIN': 0,
    'HEGLUND': 0,
    'HEGMAN': 0,
    'HEGMANN': 0,
    'HEGNA': 0,
    'HEGNER': 0,
    'HEGNEY': 0,
    'HEGRE': 0,
    'HEGSETH': 0,
    'HEGSTAD': 0,
    'HEGSTROM': 0,
    'HEGUY': 0,
    'HEGWER': 0,
    'HEGWOOD': 0,
    'HEGY': 0,
    'HEGYES': 0,
    'HEGYI': 0,
    'HEH': 0,
    'HEHEMANN': 0,
    'HEHER': 0,
    'HEHIR': 0,
    'HEHL': 0,
    'HEHMAN': 0,
    'HEHMEYER': 0,
    'HEHN': 0,
    'HEHNER': 0,
    'HEHR': 0,
    'HEI': 0,
    'HEIAR': 0,
    'HEIB': 0,
    'HEIBECK': 0,
    'HEIBEL': 0,
    'HEIBER': 0,
    'HEIBERG': 0,
    'HEIBERGER': 0,
    'HEIBERT': 0,
    'HEIBULT': 0,
    'HEIBY': 0,
    'HEICHEL': 0,
    'HEICHELBECH': 0,
    'HEICK': 0,
    'HEID': 0,
    'HEIDA': 0,
    'HEIDARI': 0,
    'HEIDBREDER': 0,
    'HEIDBRINK': 0,
    'HEIDE': 0.7326007326007327,
    'HEIDEBRECHT': 0,
    'HEIDEBRINK': 0,
    'HEIDECKER': 0,
    'HEIDEGGER': 0,
    'HEIDEL': 0,
    'HEIDELBERG': 0,
    'HEIDELBERGER': 0,
    'HEIDEMA': 0,
    'HEIDEMAN': 0,
    'HEIDEMANN': 0,
    'HEIDEN': 0,
    'HEIDENFELDER': 0,
    'HEIDENREICH': 0,
    'HEIDENRICH': 0,
    'HEIDENTHAL': 0,
    'HEIDER': 0,
    'HEIDERICH': 0,
    'HEIDERMAN': 0,
    'HEIDERSCHEIDT': 0,
    'HEIDERSCHEIT': 0,
    'HEIDGER': 0,
    'HEIDGERKEN': 0,
    'HEIDI': 1,
    'HEIDINGER': 0,
    'HEIDINGSFELDER': 0,
    'HEIDKAMP': 0,
    'HEIDKE': 0,
    'HEIDLE': 0,
    'HEIDLEBAUGH': 0,
    'HEIDLER': 0,
    'HEIDMAN': 0,
    'HEIDMANN': 0,
    'HEIDNER': 0,
    'HEIDORN': 0,
    'HEIDRICH': 0,
    'HEIDRICK': 0,
    'HEIDT': 0,
    'HEIDTKE': 0,
    'HEIDTMAN': 0,
    'HEIDY': 1,
    'HEIEN': 0,
    'HEIER': 0,
    'HEIFETZ': 0,
    'HEIFNER': 0,
    'HEIFORT': 0,
    'HEIGEL': 0,
    'HEIGERT': 0,
    'HEIGES': 0,
    'HEIGH': 0,
    'HEIGHES': 0,
    'HEIGHT': 0,
    'HEIGHTCHEW': 0,
    'HEIGHTON': 0,
    'HEIGHWAY': 0,
    'HEIGL': 0,
    'HEIGLE': 0,
    'HEIKE': 0.9009009009009009,
    'HEIKEN': 0,
    'HEIKENS': 0,
    'HEIKES': 0,
    'HEIKKILA': 0,
    'HEIKKINEN': 0,
    'HEIL': 0,
    'HEILAND': 0,
    'HEILBRON': 0,
    'HEILBRONNER': 0,
    'HEILBRUN': 0,
    'HEILBRUNN': 0,
    'HEILE': 0,
    'HEILEMAN': 0,
    'HEILEMANN': 0,
    'HEILER': 0,
    'HEILI': 0,
    'HEILIG': 0,
    'HEILIGER': 0,
    'HEILIGMAN': 0,
    'HEILING': 0,
    'HEILLE': 0,
    'HEILMAN': 0,
    'HEILMANN': 0,
    'HEILNER': 0,
    'HEIM': 0,
    'HEIMAN': 0,
    'HEIMANN': 0,
    'HEIMARK': 0,
    'HEIMBACH': 0,
    'HEIMBAUGH': 0,
    'HEIMBECKER': 0,
    'HEIMBERG': 0,
    'HEIMBERGER': 0,
    'HEIMBIGNER': 0,
    'HEIMBROCK': 0,
    'HEIMBUCH': 0,
    'HEIMBUCK': 0,
    'HEIMBURG': 0,
    'HEIMBURGER': 0,
    'HEIMDAL': 0,
    'HEIMEL': 0,
    'HEIMER': 0,
    'HEIMERDINGER': 0,
    'HEIMERL': 0,
    'HEIMERMAN': 0,
    'HEIMERMANN': 0,
    'HEIMES': 0,
    'HEIMGARTNER': 0,
    'HEIMILLER': 0,
    'HEIMKE': 0,
    'HEIMKES': 0,
    'HEIMLICH': 0,
    'HEIMOS': 0,
    'HEIMOWITZ': 0,
    'HEIMRICH': 0,
    'HEIMS': 0,
    'HEIMSOTH': 0,
    'HEIMULI': 0,
    'HEIN': 0,
    'HEINAMAN': 0,
    'HEINBACH': 0,
    'HEINBAUGH': 0,
    'HEINBERG': 0,
    'HEINBOCKEL': 0,
    'HEINBUCH': 0,
    'HEINDEL': 0,
    'HEINDL': 0,
    'HEINDSELMAN': 0,
    'HEINE': 0,
    'HEINECK': 0,
    'HEINECKE': 0,
    'HEINEKE': 0,
    'HEINEKEN': 0,
    'HEINEMAN': 0,
    'HEINEMANN': 0,
    'HEINEMEIER': 0,
    'HEINEMEYER': 0,
    'HEINEN': 0,
    'HEINER': 0,
    'HEINERT': 0,
    'HEINES': 0,
    'HEINEY': 0,
    'HEINICHEN': 0,
    'HEINICKE': 0,
    'HEINIG': 0,
    'HEINIGER': 0,
    'HEINING': 0,
    'HEININGER': 0,
    'HEINIS': 0,
    'HEINISCH': 0,
    'HEINITZ': 0,
    'HEINKE': 0,
    'HEINKEL': 0,
    'HEINL': 0,
    'HEINLE': 0,
    'HEINLEIN': 0,
    'HEINLEN': 0,
    'HEINLEY': 0,
    'HEINLY': 0,
    'HEINMILLER': 0,
    'HEINO': 0,
    'HEINOLD': 0,
    'HEINONEN': 0,
    'HEINRICH': 0,
    'HEINRICHS': 0,
    'HEINRITZ': 0,
    'HEINS': 0,
    'HEINSCH': 0,
    'HEINSELMAN': 0,
    'HEINSEN': 0,
    'HEINSOHN': 0,
    'HEINSON': 0,
    'HEINTSCHEL': 0,
    'HEINTZ': 0,
    'HEINTZE': 0,
    'HEINTZELMAN': 0,
    'HEINTZMAN': 0,
    'HEINY': 0,
    'HEINZ': 0,
    'HEINZE': 0,
    'HEINZEL': 0,
    'HEINZELMAN': 0,
    'HEINZELMANN': 0,
    'HEINZEN': 0,
    'HEINZER': 0,
    'HEINZERLING': 0,
    'HEINZEROTH': 0,
    'HEINZINGER': 0,
    'HEINZL': 0,
    'HEINZMAN': 0,
    'HEINZMANN': 0,
    'HEIPLE': 0,
    'HEIR': 0,
    'HEIRD': 0,
    'HEIRIGS': 0,
    'HEIRONIMUS': 0,
    'HEIS': 0,
    'HEISCH': 0,
    'HEISDORFFER': 0,
    'HEISE': 0,
    'HEISEL': 0,
    'HEISELMAN': 0,
    'HEISER': 0,
    'HEISERMAN': 0,
    'HEISEY': 0,
    'HEISHMAN': 0,
    'HEISIG': 0,
    'HEISING': 0,
    'HEISINGER': 0,
    'HEISKELL': 0,
    'HEISLER': 0,
    'HEISLEY': 0,
    'HEISMAN': 0,
    'HEISNER': 0,
    'HEISS': 0,
    'HEISSE': 0,
    'HEISSENBUTTEL': 0,
    'HEISSER': 0,
    'HEISSERER': 0,
    'HEISSLER': 0,
    'HEIST': 0,
    'HEISTAND': 0,
    'HEISTER': 0,
    'HEISTERKAMP': 0,
    'HEISTERMAN': 0,
    'HEISTON': 0,
    'HEISZ': 0,
    'HEIT': 0,
    'HEITER': 0,
    'HEITERT': 0,
    'HEITGER': 0,
    'HEITHAUS': 0,
    'HEITHOFF': 0,
    'HEITING': 0,
    'HEITKAMP': 0,
    'HEITKE': 0,
    'HEITKEMPER': 0,
    'HEITLAND': 0,
    'HEITMAN': 0,
    'HEITMANN': 0,
    'HEITMEIER': 0,
    'HEITMEYER': 0,
    'HEITNER': 0,
    'HEITSCH': 0,
    'HEITSCHMIDT': 0,
    'HEITSHUSEN': 0,
    'HEITSTUMAN': 0,
    'HEITZ': 0,
    'HEITZENRATER': 0,
    'HEITZER': 0,
    'HEITZIG': 0,
    'HEITZINGER': 0,
    'HEITZLER': 0,
    'HEITZMAN': 0,
    'HEITZMANN': 0,
    'HEIZER': 0,
    'HEIZLER': 0,
    'HEIZMAN': 0,
    'HEJAZI': 0,
    'HEJDUK': 0,
    'HEJL': 0,
    'HEJLIK': 0,
    'HEJNA': 0,
    'HEJNAL': 0,
    'HEJNY': 0,
    'HEJTMANEK': 0,
    'HEKIMIAN': 0,
    'HEKKER': 0,
    'HEKKING': 0,
    'HEKMAN': 0,
    'HEKMAT': 0,
    'HELAINE': 1,
    'HELAIRE': 0,
    'HELAL': 0,
    'HELANDER': 0,
    'HELBACH': 0,
    'HELBER': 0,
    'HELBERG': 0,
    'HELBERT': 0,
    'HELBIG': 0,
    'HELBING': 0,
    'HELBLE': 0,
    'HELBLING': 0,
    'HELBOCK': 0,
    'HELD': 0,
    'HELDENBRAND': 0,
    'HELDER': 0,
    'HELDERMAN': 0,
    'HELDING': 0,
    'HELDMAN': 0,
    'HELDMANN': 0,
    'HELDRETH': 0,
    'HELDSTAB': 0,
    'HELDT': 0,
    'HELEINE': 0,
    'HELEM': 0,
    'HELEMS': 0,
    'HELEN': 0.999728580475889,
    'HELENA': 0.9952606635071091,
    'HELENE': 1,
    'HELENEK': 0,
    'HELENIAK': 0,
    'HELENIUS': 0,
    'HELEY': 0,
    'HELF': 0,
    'HELFAND': 0,
    'HELFANT': 0,
    'HELFEN': 0,
    'HELFENBEIN': 0,
    'HELFENSTEIN': 0,
    'HELFER': 0,
    'HELFERICH': 0,
    'HELFERS': 0,
    'HELFERT': 0,
    'HELFFRICH': 0,
    'HELFGOTT': 0,
    'HELFINSTINE': 0,
    'HELFMAN': 0,
    'HELFRICH': 0,
    'HELFRICK': 0,
    'HELGA': 1,
    'HELGASON': 0,
    'HELGE': 0,
    'HELGELAND': 0,
    'HELGEMO': 0,
    'HELGEN': 0,
    'HELGER': 0,
    'HELGERSON': 0,
    'HELGERT': 0,
    'HELGESEN': 0,
    'HELGESON': 0,
    'HELGESTAD': 0,
    'HELGET': 0,
    'HELGOE': 0,
    'HELGOTH': 0,
    'HELGREN': 0,
    'HELGUERA': 0,
    'HELIE': 0,
    'HELIKER': 0,
    'HELIN': 0,
    'HELINE': 0,
    'HELING': 0,
    'HELINSKI': 0,
    'HELKA': 0,
    'HELKE': 0,
    'HELKENN': 0,
    'HELKER': 0,
    'HELKOWSKI': 0,
    'HELL': 0,
    'HELLA': 0,
    'HELLAM': 0,
    'HELLAMS': 0,
    'HELLAND': 0,
    'HELLAR': 0,
    'HELLARD': 0,
    'HELLBERG': 0,
    'HELLBUSCH': 0,
    'HELLE': 0,
    'HELLEBUSCH': 0,
    'HELLEBUYCK': 0,
    'HELLEIN': 0,
    'HELLEKSON': 0,
    'HELLEM': 0,
    'HELLEMS': 0,
    'HELLEN': 0.9541984732824428,
    'HELLENBERG': 0,
    'HELLENBRAND': 0,
    'HELLENGA': 0,
    'HELLENTHAL': 0,
    'HELLER': 0,
    'HELLERICH': 0,
    'HELLERMAN': 0,
    'HELLERMANN': 0,
    'HELLERSTEIN': 0,
    'HELLERUD': 0,
    'HELLEWELL': 0,
    'HELLEY': 0,
    'HELLGREN': 0,
    'HELLICKSON': 0,
    'HELLIE': 0,
    'HELLIER': 0,
    'HELLIGE': 0,
    'HELLING': 0,
    'HELLINGA': 0,
    'HELLINGER': 0,
    'HELLINGS': 0,
    'HELLIWELL': 0,
    'HELLMAN': 0,
    'HELLMANN': 0,
    'HELLMER': 0,
    'HELLMERS': 0,
    'HELLMICH': 0,
    'HELLMUND': 0,
    'HELLMUTH': 0,
    'HELLNER': 0,
    'HELLON': 0,
    'HELLRIEGEL': 0,
    'HELLRUNG': 0,
    'HELLSTERN': 0,
    'HELLSTROM': 0,
    'HELLUM': 0,
    'HELLUMS': 0,
    'HELLWARTH': 0,
    'HELLWEG': 0,
    'HELLWEGE': 0,
    'HELLWIG': 0,
    'HELLY': 0,
    'HELLYAR': 0,
    'HELLYER': 0,
    'HELM': 0,
    'HELMA': 0,
    'HELMAN': 0,
    'HELMANDOLLAR': 0,
    'HELMBERGER': 0,
    'HELMBOLD': 0,
    'HELMBOLDT': 0,
    'HELMBRECHT': 0,
    'HELMCAMP': 0,
    'HELME': 0,
    'HELMEN': 0,
    'HELMER': 0,
    'HELMERICH': 0,
    'HELMERICK': 0,
    'HELMERS': 0,
    'HELMES': 0,
    'HELMEY': 0,
    'HELMICH': 0,
    'HELMICK': 0,
    'HELMIG': 0,
    'HELMIN': 0,
    'HELMING': 0,
    'HELMINIAK': 0,
    'HELMINK': 0,
    'HELMINSKI': 0,
    'HELMINTOLLER': 0,
    'HELMKA': 0,
    'HELMKAMP': 0,
    'HELMKE': 0,
    'HELMLE': 0,
    'HELMLING': 0,
    'HELMLINGER': 0,
    'HELMLY': 0,
    'HELMOLD': 0,
    'HELMREICH': 0,
    'HELMRICH': 0,
    'HELMS': 0,
    'HELMSTADTER': 0,
    'HELMSTETLER': 0,
    'HELMSTETTER': 0,
    'HELMUELLER': 0,
    'HELMUS': 0,
    'HELMUTH': 0,
    'HELMY': 0,
    'HELO': 0,
    'HELOU': 0,
    'HELPER': 0,
    'HELPHENSTINE': 0,
    'HELPHINSTINE': 0,
    'HELPHREY': 0,
    'HELPINGSTINE': 0,
    'HELPS': 0,
    'HELQUIST': 0,
    'HELSABECK': 0,
    'HELSBY': 0,
    'HELSEL': 0,
    'HELSEN': 0,
    'HELSER': 0,
    'HELSETH': 0,
    'HELSEY': 0,
    'HELSING': 0,
    'HELSINGER': 0,
    'HELSLEY': 0,
    'HELSON': 0,
    'HELSPER': 0,
    'HELSTAD': 0,
    'HELSTEN': 0,
    'HELSTOWSKI': 0,
    'HELSTROM': 0,
    'HELT': 0,
    'HELTEMES': 0,
    'HELTEN': 0,
    'HELTER': 0,
    'HELTERBRAN': 0,
    'HELTERBRAND': 0,
    'HELTMAN': 0,
    'HELTON': 0,
    'HELTSLEY': 0,
    'HELTZ': 0,
    'HELTZEL': 0,
    'HELTZER': 0,
    'HELUS': 0,
    'HELVERSON': 0,
    'HELVESTON': 0,
    'HELVEY': 0,
    'HELVIE': 0,
    'HELVIG': 0,
    'HELVIK': 0,
    'HELVY': 0,
    'HELWEG': 0,
    'HELWICK': 0,
    'HELWIG': 0,
    'HELZER': 0,
    'HEM': 0,
    'HEMAN': 0,
    'HEMANI': 0,
    'HEMANN': 0,
    'HEMANS': 0,
    'HEMAUER': 0,
    'HEMBD': 0,
    'HEMBERGER': 0,
    'HEMBRE': 0,
    'HEMBREE': 0,
    'HEMBREY': 0,
    'HEMBROOK': 0,
    'HEMBROUGH': 0,
    'HEMBRY': 0,
    'HEMBY': 0,
    'HEMEL': 0,
    'HEMELT': 0,
    'HEMEN': 0,
    'HEMENEZ': 0,
    'HEMENWAY': 0,
    'HEMEON': 0,
    'HEMER': 0,
    'HEMESATH': 0,
    'HEMEYER': 0,
    'HEMING': 0,
    'HEMINGER': 0,
    'HEMINGSON': 0,
    'HEMINGWAY': 0,
    'HEMINWAY': 0,
    'HEMKE': 0,
    'HEMKEN': 0,
    'HEMKER': 0,
    'HEMLER': 0,
    'HEMLEY': 0,
    'HEMLING': 0,
    'HEMLOCK': 0,
    'HEMM': 0,
    'HEMMAH': 0,
    'HEMMAN': 0,
    'HEMMANN': 0,
    'HEMMANS': 0,
    'HEMMATI': 0,
    'HEMME': 0,
    'HEMMELGARN': 0,
    'HEMMEN': 0,
    'HEMMER': 0,
    'HEMMERICH': 0,
    'HEMMERLE': 0,
    'HEMMERLEIN': 0,
    'HEMMERLING': 0,
    'HEMMERLY': 0,
    'HEMMERSBACH': 0,
    'HEMMERT': 0,
    'HEMMES': 0,
    'HEMMESCH': 0,
    'HEMMETER': 0,
    'HEMMI': 0,
    'HEMMIG': 0,
    'HEMMILA': 0,
    'HEMMING': 0,
    'HEMMINGER': 0,
    'HEMMINGS': 0,
    'HEMMINGSEN': 0,
    'HEMMINGSON': 0,
    'HEMMINGWAY': 0,
    'HEMMIS': 0,
    'HEMMY': 0,
    'HEMOND': 0,
    'HEMP': 0,
    'HEMPE': 0,
    'HEMPEL': 0,
    'HEMPEN': 0,
    'HEMPERLEY': 0,
    'HEMPERLY': 0,
    'HEMPFLING': 0,
    'HEMPHILL': 0,
    'HEMPLE': 0,
    'HEMPLEMAN': 0,
    'HEMPLER': 0,
    'HEMPSTEAD': 0,
    'HEMPTON': 0,
    'HEMPY': 0,
    'HEMRAJ': 0,
    'HEMRIC': 0,
    'HEMRICH': 0,
    'HEMRICK': 0,
    'HEMRY': 0,
    'HEMS': 0,
    'HEMSATH': 0,
    'HEMSLEY': 0,
    'HEMSTAD': 0,
    'HEMSTOCK': 0,
    'HEMSTREET': 0,
    'HEMSWORTH': 0,
    'HEN': 0,
    'HENA': 0,
    'HENAD': 0,
    'HENAGAN': 0,
    'HENAGE': 0,
    'HENAGER': 0,
    'HENAGHAN': 0,
    'HENAK': 0,
    'HENAMAN': 0,
    'HENANDEZ': 0,
    'HENAO': 0,
    'HENARD': 0,
    'HENAULT': 0,
    'HENBEST': 0,
    'HENCE': 0,
    'HENCEY': 0,
    'HENCH': 0,
    'HENCHEL': 0,
    'HENCHEN': 0,
    'HENCHEY': 0,
    'HENCHY': 0,
    'HENCK': 0,
    'HENCKE': 0,
    'HENCKEL': 0,
    'HENCKEN': 0,
    'HENCY': 0,
    'HENDEE': 0,
    'HENDEL': 0,
    'HENDEN': 0,
    'HENDER': 0,
    'HENDERER': 0,
    'HENDERHAN': 0,
    'HENDERICKS': 0,
    'HENDERICKSON': 0,
    'HENDERLIGHT': 0,
    'HENDERLITE': 0,
    'HENDERLONG': 0,
    'HENDERLY': 0,
    'HENDERS': 0,
    'HENDERSEN': 0,
    'HENDERSHOT': 0,
    'HENDERSHOTT': 0,
    'HENDERSON': 0,
    'HENDESON': 0,
    'HENDEZ': 0,
    'HENDGES': 0,
    'HENDIN': 0,
    'HENDLER': 0,
    'HENDLEY': 0,
    'HENDON': 0,
    'HENDRA': 0,
    'HENDREN': 0,
    'HENDREX': 0,
    'HENDRIAN': 0,
    'HENDRICH': 0,
    'HENDRICK': 0,
    'HENDRICKS': 0,
    'HENDRICKSEN': 0,
    'HENDRICKSON': 0,
    'HENDRICKX': 0,
    'HENDRIE': 0,
    'HENDRIETH': 0,
    'HENDRIK': 0,
    'HENDRIKS': 0,
    'HENDRIKSE': 0,
    'HENDRIKSEN': 0,
    'HENDRIKSON': 0,
    'HENDRIX': 0,
    'HENDRIXSON': 0,
    'HENDRON': 0,
    'HENDRY': 0,
    'HENDRYX': 0,
    'HENDSBEE': 0,
    'HENDY': 0,
    'HENDZEL': 0,
    'HENEBRY': 0,
    'HENEGAN': 0,
    'HENEGAR': 0,
    'HENEGHAN': 0,
    'HENEHAN': 0,
    'HENEIN': 0,
    'HENELY': 0,
    'HENERSON': 0,
    'HENERY': 0,
    'HENES': 0,
    'HENESEY': 0,
    'HENESY': 0,
    'HENEVELD': 0,
    'HENEY': 0,
    'HENFLING': 0,
    'HENG': 0,
    'HENGEHOLD': 0,
    'HENGEL': 0,
    'HENGEN': 0,
    'HENGER': 0,
    'HENGES': 0,
    'HENGESBACH': 0,
    'HENGEVELD': 0,
    'HENGGELER': 0,
    'HENGL': 0,
    'HENGST': 0,
    'HENGSTEBECK': 0,
    'HENGSTLER': 0,
    'HENGY': 0,
    'HENICK': 0,
    'HENIFF': 0,
    'HENIFIN': 0,
    'HENIG': 0,
    'HENIGAN': 0,
    'HENIGE': 0,
    'HENIGHAN': 0,
    'HENIGIN': 0,
    'HENIGMAN': 0,
    'HENIK': 0,
    'HENIKA': 0,
    'HENIN': 0,
    'HENINGBURG': 0,
    'HENINGER': 0,
    'HENINGTON': 0,
    'HENIO': 0,
    'HENION': 0,
    'HENISER': 0,
    'HENIZE': 0,
    'HENJUM': 0,
    'HENK': 0,
    'HENKE': 0,
    'HENKEL': 0,
    'HENKELMAN': 0,
    'HENKELS': 0,
    'HENKEMEYER': 0,
    'HENKEN': 0,
    'HENKENIUS': 0,
    'HENKER': 0,
    'HENKES': 0,
    'HENKHAUS': 0,
    'HENKIN': 0,
    'HENKINS': 0,
    'HENKLE': 0,
    'HENLE': 0,
    'HENLEY': 0,
    'HENLINE': 0,
    'HENLY': 0,
    'HENMAN': 0,
    'HENN': 0,
    'HENNA': 0,
    'HENNAGER': 0,
    'HENNAGIR': 0,
    'HENNAN': 0,
    'HENNARD': 0,
    'HENNE': 0,
    'HENNEBERG': 0,
    'HENNEBERGER': 0,
    'HENNEBERRY': 0,
    'HENNEBURY': 0,
    'HENNECKE': 0,
    'HENNEFER': 0,
    'HENNEGAN': 0,
    'HENNEGHAN': 0,
    'HENNEK': 0,
    'HENNEKE': 0,
    'HENNEKES': 0,
    'HENNEL': 0,
    'HENNELLY': 0,
    'HENNEMAN': 0,
    'HENNEMANN': 0,
    'HENNEN': 0,
    'HENNENFENT': 0,
    'HENNER': 0,
    'HENNES': 0,
    'HENNESEY': 0,
    'HENNESS': 0,
    'HENNESSEE': 0,
    'HENNESSEY': 0,
    'HENNESSY': 0,
    'HENNESY': 0,
    'HENNEY': 0,
    'HENNICK': 0,
    'HENNICKE': 0,
    'HENNIE': 0,
    'HENNIES': 0,
    'HENNIG': 0,
    'HENNIGAN': 0,
    'HENNIGAR': 0,
    'HENNIGER': 0,
    'HENNIGH': 0,
    'HENNING': 0,
    'HENNINGER': 0,
    'HENNINGFELD': 0,
    'HENNINGS': 0,
    'HENNINGSEN': 0,
    'HENNINGSGAARD': 0,
    'HENNINGSON': 0,
    'HENNINGTON': 0,
    'HENNION': 0,
    'HENNIS': 0,
    'HENNIX': 0,
    'HENNON': 0,
    'HENNRICH': 0,
    'HENNUM': 0,
    'HENNY': 0,
    'HENO': 0,
    'HENOCH': 0,
    'HENON': 0,
    'HENRETTA': 0,
    'HENRETTY': 0,
    'HENREY': 0,
    'HENRI': 0,
    'HENRICH': 0,
    'HENRICHON': 0,
    'HENRICHS': 0,
    'HENRICHSEN': 0,
    'HENRICI': 0,
    'HENRICK': 0,
    'HENRICKS': 0,
    'HENRICKSEN': 0,
    'HENRICKSON': 0,
    'HENRIE': 0,
    'HENRIES': 0,
    'HENRIETTA': 1,
    'HENRIETTE': 1,
    'HENRIGUEZ': 0,
    'HENRIKSEN': 0,
    'HENRIKSON': 0,
    'HENRIKSSON': 0,
    'HENRIOD': 0,
    'HENRION': 0,
    'HENRIOTT': 0,
    'HENRIQUE': 0,
    'HENRIQUES': 0,
    'HENRIQUEZ': 0,
    'HENRRIQUEZ': 0,
    'HENRY': 0.8598270974392616,
    'HENRYHAND': 0,
    'HENS': 0,
    'HENSARLING': 0,
    'HENSCH': 0,
    'HENSCHEID': 0,
    'HENSCHEL': 0,
    'HENSCHELL': 0,
    'HENSCHEN': 0,
    'HENSCHKE': 0,
    'HENSE': 0,
    'HENSEL': 0,
    'HENSELER': 0,
    'HENSELL': 0,
    'HENSEN': 0,
    'HENSEY': 0,
    'HENSGEN': 0,
    'HENSGENS': 0,
    'HENSHALL': 0,
    'HENSHAW': 0,
    'HENSIAK': 0,
    'HENSIEK': 0,
    'HENSINGER': 0,
    'HENSKE': 0,
    'HENSLE': 0,
    'HENSLEE': 0,
    'HENSLEIGH': 0,
    'HENSLER': 0,
    'HENSLEY': 0,
    'HENSLIN': 0,
    'HENSLY': 0,
    'HENSMAN': 0,
    'HENSON': 0,
    'HENSRUD': 0,
    'HENSS': 0,
    'HENSZ': 0,
    'HENTGES': 0,
    'HENTHORN': 0,
    'HENTHORNE': 0,
    'HENTON': 0,
    'HENTRICH': 0,
    'HENTRUP': 0,
    'HENTSCH': 0,
    'HENTSCHEL': 0,
    'HENTY': 0,
    'HENTZ': 0,
    'HENTZE': 0,
    'HENTZEL': 0,
    'HENTZEN': 0,
    'HENWOOD': 0,
    'HENYAN': 0,
    'HENYARD': 0,
    'HENZ': 0,
    'HENZE': 0,
    'HENZEL': 0,
    'HENZI': 0,
    'HENZIE': 0,
    'HENZLER': 0,
    'HEO': 0,
    'HEON': 0,
    'HEPBURN': 0,
    'HEPFER': 0,
    'HEPFINGER': 0,
    'HEPFNER': 0,
    'HEPHNER': 0,
    'HEPINSTALL': 0,
    'HEPKER': 0,
    'HEPLER': 0,
    'HEPNER': 0,
    'HEPOKOSKI': 0,
    'HEPOLA': 0,
    'HEPP': 0,
    'HEPPARD': 0,
    'HEPPE': 0,
    'HEPPEL': 0,
    'HEPPELL': 0,
    'HEPPENSTALL': 0,
    'HEPPER': 0,
    'HEPPERLE': 0,
    'HEPPERMANN': 0,
    'HEPPLE': 0,
    'HEPPLER': 0,
    'HEPPNER': 0,
    'HEPTIG': 0,
    'HEPTING': 0,
    'HEPTINSTALL': 0,
    'HEPTNER': 0,
    'HEPWORTH': 0,
    'HER': 0,
    'HERA': 0,
    'HERAK': 0,
    'HERALD': 0,
    'HERALDEZ': 0,
    'HERALY': 0,
    'HERAN': 0,
    'HERANDEZ': 0,
    'HERARD': 0,
    'HERAS': 0,
    'HERATH': 0,
    'HERATY': 0,
    'HERAUF': 0,
    'HERAZO': 0,
    'HERB': 0.7766990291262136,
    'HERBACH': 0,
    'HERBAS': 0,
    'HERBAUGH': 0,
    'HERBE': 0,
    'HERBECK': 0,
    'HERBEIN': 0,
    'HERBEK': 0,
    'HERBEL': 0,
    'HERBELIN': 0,
    'HERBENER': 0,
    'HERBER': 0,
    'HERBERG': 0,
    'HERBERGER': 0,
    'HERBERHOLZ': 0,
    'HERBERS': 0,
    'HERBERT': 0.9431092181320353,
    'HERBERTSON': 0,
    'HERBES': 0,
    'HERBEST': 0,
    'HERBIG': 0,
    'HERBIN': 0,
    'HERBISON': 0,
    'HERBOLD': 0,
    'HERBOLSHEIMER': 0,
    'HERBON': 0,
    'HERBORT': 0,
    'HERBRAND': 0,
    'HERBRANSON': 0,
    'HERBRUCK': 0,
    'HERBST': 0,
    'HERBSTER': 0,
    'HERBSTMAN': 0,
    'HERBSTREIT': 0,
    'HERBSTREITH': 0,
    'HERBSTRITT': 0,
    'HERBURGER': 0,
    'HERBY': 0,
    'HERCEG': 0,
    'HERCHE': 0,
    'HERCHENBACH': 0,
    'HERCHENRODER': 0,
    'HERCHER': 0,
    'HERCIK': 0,
    'HERCULES': 0,
    'HERCZEG': 0,
    'HERD': 0,
    'HERDA': 0,
    'HERDE': 0,
    'HERDEGEN': 0,
    'HERDEN': 0,
    'HERDER': 0,
    'HERDINA': 0,
    'HERDING': 0,
    'HERDMAN': 0,
    'HERDOCIA': 0,
    'HERDON': 0,
    'HERDRICH': 0,
    'HERDT': 0,
    'HERDZIK': 0,
    'HEREBIA': 0,
    'HEREDIA': 0,
    'HEREFORD': 0,
    'HEREK': 0,
    'HEREN': 0,
    'HERENDEEN': 0,
    'HERENDEZ': 0,
    'HERES': 0,
    'HERETH': 0,
    'HEREVIA': 0,
    'HERFEL': 0,
    'HERFINDAHL': 0,
    'HERFORD': 0,
    'HERFORTH': 0,
    'HERFURTH': 0,
    'HERGE': 0,
    'HERGENRADER': 0,
    'HERGENRATHER': 0,
    'HERGENREDER': 0,
    'HERGENRETER': 0,
    'HERGENROEDER': 0,
    'HERGENROTHER': 0,
    'HERGER': 0,
    'HERGERT': 0,
    'HERGES': 0,
    'HERGESHEIMER': 0,
    'HERGET': 0,
    'HERGOTT': 0,
    'HERHOLD': 0,
    'HERI': 0,
    'HERIAN': 0,
    'HERIBERTO': 1,
    'HERIC': 0,
    'HERICKS': 0,
    'HERIFORD': 0,
    'HERIG': 0,
    'HERIGON': 0,
    'HERIGSTAD': 0,
    'HERIN': 0,
    'HERINCKX': 0,
    'HERING': 0,
    'HERINGER': 0,
    'HERINGTON': 0,
    'HERINK': 0,
    'HERION': 0,
    'HERIOT': 0,
    'HERITAGE': 0,
    'HERK': 0,
    'HERKE': 0,
    'HERKEL': 0,
    'HERKENHOFF': 0,
    'HERKER': 0,
    'HERKERT': 0,
    'HERKES': 0,
    'HERKIMER': 0,
    'HERKLOTZ': 0,
    'HERKNER': 0,
    'HERKO': 0,
    'HERL': 0,
    'HERLACHE': 0,
    'HERLAN': 0,
    'HERLAND': 0,
    'HERLEHY': 0,
    'HERLEIN': 0,
    'HERLEY': 0,
    'HERLICH': 0,
    'HERLIHY': 0,
    'HERLIN': 0,
    'HERLINDA': 1,
    'HERLINE': 0,
    'HERLING': 0,
    'HERLINGER': 0,
    'HERLITZ': 0,
    'HERLOCKER': 0,
    'HERLONG': 0,
    'HERM': 0,
    'HERMA': 1,
    'HERMAN': 0.8614564831261101,
    'HERMANCE': 0,
    'HERMANDEZ': 0,
    'HERMANEK': 0,
    'HERMANN': 0,
    'HERMANNS': 0,
    'HERMANO': 0,
    'HERMANOWSKI': 0,
    'HERMANS': 0,
    'HERMANSEN': 0,
    'HERMANSKI': 0,
    'HERMANSON': 0,
    'HERMANY': 0,
    'HERMEL': 0,
    'HERMELINDA': 1,
    'HERMELING': 0,
    'HERMEN': 0,
    'HERMENEGILDO': 0,
    'HERMENS': 0,
    'HERMES': 0,
    'HERMESCH': 0,
    'HERMEZ': 0,
    'HERMIDA': 0,
    'HERMILA': 1,
    'HERMILLER': 0,
    'HERMINA': 1,
    'HERMINE': 1,
    'HERMINIA': 1,
    'HERMIS': 0,
    'HERMISTON': 0,
    'HERMIZ': 0,
    'HERMO': 0,
    'HERMON': 0,
    'HERMOSA': 0,
    'HERMOSILLA': 0,
    'HERMOSILLO': 0,
    'HERMOSO': 0,
    'HERMOSURA': 0,
    'HERMRECK': 0,
    'HERMS': 0,
    'HERMSEN': 0,
    'HERMSMEYER': 0,
    'HERMSTAD': 0,
    'HERMUS': 0,
    'HERN': 0,
    'HERNADES': 0,
    'HERNAEZ': 0,
    'HERNAIZ': 0,
    'HERNAN': 0,
    'HERNANDAZ': 0,
    'HERNANDE': 0,
    'HERNANDEC': 0,
    'HERNANDEL': 0,
    'HERNANDER': 0,
    'HERNANDES': 0,
    'HERNANDEZ': 0,
    'HERNANDEZCRUZ': 0,
    'HERNANDEZDIAZ': 0,
    'HERNANDEZGARCI': 0,
    'HERNANDEZGOMEZ': 0,
    'HERNANDEZLOPEZ': 0,
    'HERNANDEZMARTI': 0,
    'HERNANDEZORTIZ': 0,
    'HERNANDEZPEREZ': 0,
    'HERNANDEZREYES': 0,
    'HERNANDEZTORRE': 0,
    'HERNANDO': 0,
    'HERNANDZ': 0,
    'HERNANEZ': 0,
    'HERNDEN': 0,
    'HERNDON': 0,
    'HERNE': 0,
    'HERNEDEZ': 0,
    'HERNER': 0,
    'HERNES': 0,
    'HERNESS': 0,
    'HERNING': 0,
    'HERNKE': 0,
    'HERNLEY': 0,
    'HERNLY': 0,
    'HERNON': 0,
    'HERNS': 0,
    'HERNTON': 0,
    'HERNY': 0,
    'HERO': 0,
    'HEROD': 0,
    'HEROFF': 0,
    'HEROLD': 0,
    'HEROMAN': 0,
    'HERON': 0,
    'HERONEMA': 0,
    'HERONEMUS': 0,
    'HEROUX': 0,
    'HEROY': 0,
    'HERP': 0,
    'HERPEL': 0,
    'HERPICH': 0,
    'HERPIN': 0,
    'HERPST': 0,
    'HERR': 0,
    'HERRA': 0,
    'HERRADA': 0,
    'HERRADOR': 0,
    'HERRALA': 0,
    'HERRALD': 0,
    'HERRAN': 0,
    'HERRARTE': 0,
    'HERRBOLDT': 0,
    'HERRE': 0,
    'HERREID': 0,
    'HERREJON': 0,
    'HERREL': 0,
    'HERRELL': 0,
    'HERREMA': 0,
    'HERREMAN': 0,
    'HERREN': 0,
    'HERRENBRUCK': 0,
    'HERRERA': 0,
    'HERRERG': 0,
    'HERRERIA': 0,
    'HERRERO': 0,
    'HERREROS': 0,
    'HERRERRA': 0,
    'HERRES': 0,
    'HERRETT': 0,
    'HERRIAGE': 0,
    'HERRICK': 0,
    'HERRICKS': 0,
    'HERRIDGE': 0,
    'HERRIED': 0,
    'HERRIFORD': 0,
    'HERRIG': 0,
    'HERRIGES': 0,
    'HERRIMAN': 0,
    'HERRIN': 0,
    'HERRING': 0,
    'HERRINGER': 0,
    'HERRINGSHAW': 0,
    'HERRINGTON': 0,
    'HERRION': 0,
    'HERRIOT': 0,
    'HERRIOTT': 0,
    'HERRIS': 0,
    'HERRITT': 0,
    'HERRITY': 0,
    'HERRITZ': 0,
    'HERRLE': 0,
    'HERRLICH': 0,
    'HERRLING': 0,
    'HERRLINGER': 0,
    'HERRMAN': 0,
    'HERRMANN': 0,
    'HERRNANDEZ': 0,
    'HERRO': 0,
    'HERROD': 0,
    'HERROLD': 0,
    'HERRON': 0,
    'HERRS': 0,
    'HERRSCHAFT': 0,
    'HERRSCHER': 0,
    'HERRY': 0,
    'HERSBERGER': 0,
    'HERSCH': 0,
    'HERSCHBACH': 0,
    'HERSCHBERGER': 0,
    'HERSCHEL': 0.9859154929577465,
    'HERSCHELL': 0,
    'HERSCHELMAN': 0,
    'HERSCHER': 0,
    'HERSCHLEB': 0,
    'HERSCHLER': 0,
    'HERSCHMAN': 0,
    'HERSEL': 0,
    'HERSEY': 0,
    'HERSH': 0,
    'HERSHA': 0,
    'HERSHBERG': 0,
    'HERSHBERGER': 0,
    'HERSHEL': 1,
    'HERSHELMAN': 0,
    'HERSHENSON': 0,
    'HERSHEY': 0,
    'HERSHFIELD': 0,
    'HERSHISER': 0,
    'HERSHKOVITZ': 0,
    'HERSHKOWITZ': 0,
    'HERSHMAN': 0,
    'HERSHNER': 0,
    'HERSHOCK': 0,
    'HERSI': 0,
    'HERSKO': 0,
    'HERSKOVIC': 0,
    'HERSKOVITS': 0,
    'HERSKOVITZ': 0,
    'HERSKOWITZ': 0,
    'HERSLEY': 0,
    'HERSMAN': 0,
    'HERSOM': 0,
    'HERSON': 0,
    'HERST': 0,
    'HERSTAD': 0,
    'HERSTEIN': 0,
    'HERSTINE': 0,
    'HERSTON': 0,
    'HERT': 0,
    'HERTA': 1,
    'HERTE': 0,
    'HERTEL': 0,
    'HERTENSTEIN': 0,
    'HERTER': 0,
    'HERTH': 0,
    'HERTHA': 1,
    'HERTHEL': 0,
    'HERTHER': 0,
    'HERTIG': 0,
    'HERTING': 0,
    'HERTL': 0,
    'HERTLE': 0,
    'HERTLEIN': 0,
    'HERTLER': 0,
    'HERTLING': 0,
    'HERTOG': 0,
    'HERTRICH': 0,
    'HERTWECK': 0,
    'HERTWIG': 0,
    'HERTZ': 0,
    'HERTZBERG': 0,
    'HERTZEL': 0,
    'HERTZFELD': 0,
    'HERTZIG': 0,
    'HERTZLER': 0,
    'HERTZMAN': 0,
    'HERTZOG': 0,
    'HERUBIN': 0,
    'HERUM': 0,
    'HERVAS': 0,
    'HERVERT': 0,
    'HERVEY': 0,
    'HERVIEUX': 0,
    'HERVOL': 0,
    'HERWECK': 0,
    'HERWEG': 0,
    'HERWEHE': 0,
    'HERWEYER': 0,
    'HERWICK': 0,
    'HERWIG': 0,
    'HERY': 0,
    'HERYFORD': 0,
    'HERZ': 0,
    'HERZBERG': 0,
    'HERZBERGER': 0,
    'HERZER': 0,
    'HERZFELD': 0,
    'HERZFELDT': 0,
    'HERZIG': 0,
    'HERZIK': 0,
    'HERZING': 0,
    'HERZINGER': 0,
    'HERZNER': 0,
    'HERZOG': 0,
    'HES': 0,
    'HESBY': 0,
    'HESCH': 0,
    'HESCHKE': 0,
    'HESCHT': 0,
    'HESCOCK': 0,
    'HESELTINE': 0,
    'HESELTON': 0,
    'HESEMAN': 0,
    'HESEMANN': 0,
    'HESER': 0,
    'HESFORD': 0,
    'HESHER': 0,
    'HESHMATI': 0,
    'HESKETH': 0,
    'HESKETT': 0,
    'HESKIN': 0,
    'HESLA': 0,
    'HESLEP': 0,
    'HESLER': 0,
    'HESLET': 0,
    'HESLEY': 0,
    'HESLIN': 0,
    'HESLINGA': 0,
    'HESLIP': 0,
    'HESLOP': 0,
    'HESPE': 0,
    'HESPEN': 0,
    'HESPRICH': 0,
    'HESS': 0,
    'HESSE': 0,
    'HESSEE': 0,
    'HESSEL': 0,
    'HESSELBACH': 0,
    'HESSELBACHER': 0,
    'HESSELBEIN': 0,
    'HESSELBERG': 0,
    'HESSELBROCK': 0,
    'HESSELGESSER': 0,
    'HESSELGRAVE': 0,
    'HESSELING': 0,
    'HESSELINK': 0,
    'HESSELL': 0,
    'HESSELMAN': 0,
    'HESSELTINE': 0,
    'HESSELTON': 0,
    'HESSEN': 0,
    'HESSENAUER': 0,
    'HESSENFLOW': 0,
    'HESSENIUS': 0,
    'HESSENTHALER': 0,
    'HESSER': 0,
    'HESSERT': 0,
    'HESSEY': 0,
    'HESSIAN': 0,
    'HESSING': 0,
    'HESSINGER': 0,
    'HESSION': 0,
    'HESSLER': 0,
    'HESSLING': 0,
    'HESSLINK': 0,
    'HESSMAN': 0,
    'HESSON': 0,
    'HESSONG': 0,
    'HEST': 0,
    'HESTAD': 0,
    'HESTAND': 0,
    'HESTEKIN': 0,
    'HESTER': 0.4118993135011441,
    'HESTERBERG': 0,
    'HESTERLEE': 0,
    'HESTERLY': 0,
    'HESTERMAN': 0,
    'HESTERMANN': 0,
    'HESTERS': 0,
    'HESTILOW': 0,
    'HESTON': 0,
    'HESTOR': 0,
    'HETCHLER': 0,
    'HETER': 0,
    'HETFIELD': 0,
    'HETH': 0,
    'HETHCOAT': 0,
    'HETHCOTE': 0,
    'HETHCOX': 0,
    'HETHER': 0,
    'HETHERINGTON': 0,
    'HETHERMAN': 0,
    'HETHERTON': 0,
    'HETKE': 0,
    'HETLAND': 0,
    'HETLER': 0,
    'HETMAN': 0,
    'HETRICK': 0,
    'HETT': 0,
    'HETTEL': 0,
    'HETTENBACH': 0,
    'HETTENHAUSEN': 0,
    'HETTERICH': 0,
    'HETTERSCHEIDT': 0,
    'HETTESHEIMER': 0,
    'HETTICH': 0,
    'HETTICK': 0,
    'HETTIE': 1,
    'HETTIG': 0,
    'HETTIGER': 0,
    'HETTINGA': 0,
    'HETTINGER': 0,
    'HETTLE': 0,
    'HETTLER': 0,
    'HETTMAN': 0,
    'HETTMANSPERGER': 0,
    'HETTRICH': 0,
    'HETTRICK': 0,
    'HETTWER': 0,
    'HETU': 0,
    'HETZ': 0,
    'HETZEL': 0,
    'HETZER': 0,
    'HETZLER': 0,
    'HETZNER': 0,
    'HEU': 0,
    'HEUBACH': 0,
    'HEUBEL': 0,
    'HEUBERGER': 0,
    'HEUBLEIN': 0,
    'HEUBNER': 0,
    'HEUCHERT': 0,
    'HEUCK': 0,
    'HEUER': 0,
    'HEUERMAN': 0,
    'HEUERMANN': 0,
    'HEUERTZ': 0,
    'HEUETT': 0,
    'HEUGEL': 0,
    'HEUGLY': 0,
    'HEUKER': 0,
    'HEULE': 0,
    'HEULITT': 0,
    'HEUMAN': 0,
    'HEUMANN': 0,
    'HEUN': 0,
    'HEUNG': 0,
    'HEUP': 0,
    'HEUPEL': 0,
    'HEURICH': 0,
    'HEURING': 0,
    'HEURUNG': 0,
    'HEUS': 0,
    'HEUSCHKEL': 0,
    'HEUSEL': 0,
    'HEUSER': 0,
    'HEUSINGER': 0,
    'HEUSINKVELD': 0,
    'HEUSLER': 0,
    'HEUSMAN': 0,
    'HEUSNER': 0,
    'HEUSS': 0,
    'HEUSSER': 0,
    'HEUSSNER': 0,
    'HEUSTED': 0,
    'HEUSTESS': 0,
    'HEUSTIS': 0,
    'HEUSTON': 0,
    'HEUTMAKER': 0,
    'HEUTON': 0,
    'HEUVEL': 0,
    'HEUVELMAN': 0,
    'HEVEL': 0,
    'HEVENER': 0,
    'HEVER': 0,
    'HEVERIN': 0,
    'HEVERLING': 0,
    'HEVERLY': 0,
    'HEVERON': 0,
    'HEVEY': 0,
    'HEVIA': 0,
    'HEVNER': 0,
    'HEVRON': 0,
    'HEW': 0,
    'HEWARD': 0,
    'HEWATT': 0,
    'HEWELL': 0,
    'HEWELT': 0,
    'HEWER': 0,
    'HEWERDINE': 0,
    'HEWES': 0,
    'HEWETT': 0,
    'HEWEY': 0,
    'HEWGLEY': 0,
    'HEWING': 0,
    'HEWINS': 0,
    'HEWISON': 0,
    'HEWIT': 0,
    'HEWITSON': 0,
    'HEWITT': 0,
    'HEWKIN': 0,
    'HEWKO': 0,
    'HEWLEN': 0,
    'HEWLETT': 0,
    'HEWLIN': 0,
    'HEWS': 0,
    'HEWSON': 0,
    'HEWSTON': 0,
    'HEXAMER': 0,
    'HEXOM': 0,
    'HEXT': 0,
    'HEXTER': 0,
    'HEXUM': 0,
    'HEY': 0,
    'HEYBOER': 0,
    'HEYBORNE': 0,
    'HEYBURN': 0,
    'HEYD': 0,
    'HEYDA': 0,
    'HEYDARI': 0,
    'HEYDE': 0,
    'HEYDEN': 0,
    'HEYDENBURG': 0,
    'HEYDENREICH': 0,
    'HEYDER': 0,
    'HEYDINGER': 0,
    'HEYDON': 0,
    'HEYDORN': 0,
    'HEYDT': 0,
    'HEYDUK': 0,
    'HEYE': 0,
    'HEYEN': 0,
    'HEYER': 0,
    'HEYERDAHL': 0,
    'HEYERLY': 0,
    'HEYES': 0,
    'HEYING': 0,
    'HEYKOOP': 0,
    'HEYL': 0,
    'HEYLAND': 0,
    'HEYLER': 0,
    'HEYLIGER': 0,
    'HEYM': 0,
    'HEYMAN': 0,
    'HEYMANN': 0,
    'HEYMANS': 0,
    'HEYN': 0,
    'HEYNE': 0,
    'HEYNEN': 0,
    'HEYNS': 0,
    'HEYOB': 0,
    'HEYREND': 0,
    'HEYRMAN': 0,
    'HEYS': 0,
    'HEYSE': 0,
    'HEYSER': 0,
    'HEYWARD': 0,
    'HEYWOOD': 0,
    'HEYWORTH': 0,
    'HEZEKIAH': 0,
    'HEZEL': 0,
    'HEZLEP': 0,
    'HG': 0,
    'HGUYEN': 0,
    'HI': 0,
    'HIAM': 0,
    'HIAR': 0,
    'HIATT': 0,
    'HIBBARD': 0,
    'HIBBELER': 0,
    'HIBBEN': 0,
    'HIBBERD': 0,
    'HIBBERT': 0,
    'HIBBERTS': 0,
    'HIBBETS': 0,
    'HIBBETT': 0,
    'HIBBETTS': 0,
    'HIBBING': 0,
    'HIBBITS': 0,
    'HIBBITT': 0,
    'HIBBITTS': 0,
    'HIBBLER': 0,
    'HIBBS': 0,
    'HIBDON': 0,
    'HIBEN': 0,
    'HIBER': 0,
    'HIBERT': 0,
    'HIBL': 0,
    'HIBLER': 0,
    'HIBMA': 0,
    'HIBNER': 0,
    'HIBSHMAN': 0,
    'HICE': 0,
    'HICHBORN': 0,
    'HICHEZ': 0,
    'HICIANO': 0,
    'HICK': 0,
    'HICKAM': 0,
    'HICKCOX': 0,
    'HICKE': 0,
    'HICKEL': 0,
    'HICKEN': 0,
    'HICKENBOTHAM': 0,
    'HICKENBOTTOM': 0,
    'HICKENLOOPER': 0,
    'HICKERNELL': 0,
    'HICKERSON': 0,
    'HICKERT': 0,
    'HICKETHIER': 0,
    'HICKEY': 0,
    'HICKIE': 0,
    'HICKIN': 0,
    'HICKINBOTHAM': 0,
    'HICKINGBOTTOM': 0,
    'HICKL': 0,
    'HICKLE': 0,
    'HICKLEN': 0,
    'HICKLIN': 0,
    'HICKLING': 0,
    'HICKMAN': 0,
    'HICKMANN': 0,
    'HICKMON': 0,
    'HICKMOTT': 0,
    'HICKNER': 0,
    'HICKOK': 0,
    'HICKORY': 0,
    'HICKOX': 0,
    'HICKS': 0,
    'HICKSON': 0,
    'HICKY': 0,
    'HICOK': 0,
    'HIDA': 0,
    'HIDAKA': 0,
    'HIDALGO': 0,
    'HIDALGOGATO': 0,
    'HIDAY': 0,
    'HIDAYAT': 0,
    'HIDDE': 0,
    'HIDDEN': 0,
    'HIDDLESON': 0,
    'HIDE': 0,
    'HIDER': 0,
    'HIDEY': 0,
    'HIDINGER': 0,
    'HIDLE': 0,
    'HIDLEBAUGH': 0,
    'HIDROGO': 0,
    'HIDY': 0,
    'HIE': 0,
    'HIEATT': 0,
    'HIEB': 0,
    'HIEBEL': 0,
    'HIEBER': 0,
    'HIEBERT': 0,
    'HIEBING': 0,
    'HIEBLER': 0,
    'HIEBNER': 0,
    'HIEDEMAN': 0,
    'HIEDI': 1,
    'HIEGEL': 0,
    'HIEGER': 0,
    'HIEL': 0,
    'HIELSCHER': 0,
    'HIEMENZ': 0,
    'HIEMER': 0,
    'HIEMSTRA': 0,
    'HIEN': 0.9345794392523364,
    'HIENEMAN': 0,
    'HIEPLER': 0,
    'HIER': 0,
    'HIERHOLZER': 0,
    'HIERL': 0,
    'HIERONIMUS': 0,
    'HIERONYMUS': 0,
    'HIERRO': 0,
    'HIERS': 0,
    'HIERSCHE': 0,
    'HIESTAND': 0,
    'HIESTER': 0,
    'HIETALA': 0,
    'HIETANEN': 0,
    'HIETBRINK': 0,
    'HIETER': 0,
    'HIETPAS': 0,
    'HIETT': 0,
    'HIGA': 0,
    'HIGAKI': 0,
    'HIGAREDA': 0,
    'HIGASHI': 0,
    'HIGBEE': 0,
    'HIGBIE': 0,
    'HIGBY': 0,
    'HIGDAY': 0,
    'HIGDEM': 0,
    'HIGDON': 0,
    'HIGEL': 0,
    'HIGER': 0,
    'HIGGASON': 0,
    'HIGGENBOTHAM': 0,
    'HIGGENBOTTOM': 0,
    'HIGGENS': 0,
    'HIGGERSON': 0,
    'HIGGIN': 0,
    'HIGGINBOTHAM': 0,
    'HIGGINBOTHAN': 0,
    'HIGGINBOTTOM': 0,
    'HIGGINS': 0,
    'HIGGINSON': 0,
    'HIGGS': 0,
    'HIGH': 0,
    'HIGHAM': 0,
    'HIGHBARGER': 0,
    'HIGHBAUGH': 0,
    'HIGHBERG': 0,
    'HIGHBERGER': 0,
    'HIGHELK': 0,
    'HIGHERS': 0,
    'HIGHET': 0,
    'HIGHFIELD': 0,
    'HIGHFILL': 0,
    'HIGHHOUSE': 0,
    'HIGHLAND': 0,
    'HIGHLANDER': 0,
    'HIGHLANDS': 0,
    'HIGHLEN': 0,
    'HIGHLEY': 0,
    'HIGHMAN': 0,
    'HIGHNOTE': 0,
    'HIGHSMITH': 0,
    'HIGHSTREET': 0,
    'HIGHT': 0,
    'HIGHTER': 0,
    'HIGHTON': 0,
    'HIGHTOWER': 0,
    'HIGHTREE': 0,
    'HIGHTSHOE': 0,
    'HIGHUM': 0,
    'HIGINBOTHAM': 0,
    'HIGLE': 0,
    'HIGLEY': 0,
    'HIGMAN': 0,
    'HIGNETT': 0,
    'HIGNEY': 0,
    'HIGNIGHT': 0,
    'HIGNITE': 0,
    'HIGNUTT': 0,
    'HIGSON': 0,
    'HIGUCHI': 0,
    'HIGUERA': 0,
    'HIGUEROS': 0,
    'HIJAR': 0,
    'HIJAZ': 0,
    'HIJAZI': 0,
    'HIKADE': 0,
    'HIKE': 0,
    'HIKES': 0,
    'HIKIDA': 0,
    'HIL': 0,
    'HILADO': 0,
    'HILAIRE': 0,
    'HILAL': 0,
    'HILAMAN': 0,
    'HILAND': 0,
    'HILARIA': 1,
    'HILARIO': 0.8431703204047217,
    'HILARY': 0.9964412811387899,
    'HILB': 0,
    'HILBELINK': 0,
    'HILBER': 0,
    'HILBERG': 0,
    'HILBERS': 0,
    'HILBERT': 0,
    'HILBIG': 0,
    'HILBISH': 0,
    'HILBORN': 0,
    'HILBOURN': 0,
    'HILBRAND': 0,
    'HILBRANDS': 0,
    'HILBRANDT': 0,
    'HILBRECHT': 0,
    'HILBRICH': 0,
    'HILBUN': 0,
    'HILBURGER': 0,
    'HILBURN': 0,
    'HILBY': 0,
    'HILCHEY': 0,
    'HILD': 0,
    'HILDA': 1,
    'HILDABRAND': 0,
    'HILDAGO': 0,
    'HILDAHL': 0,
    'HILDE': 0.9049773755656109,
    'HILDEBRAN': 0,
    'HILDEBRAND': 0,
    'HILDEBRANDT': 0,
    'HILDEBRANT': 0,
    'HILDEGARD': 1,
    'HILDEGARDE': 1,
    'HILDEN': 0,
    'HILDENBRAND': 0,
    'HILDENBRANDT': 0,
    'HILDER': 0,
    'HILDERBRAN': 0,
    'HILDERBRAND': 0,
    'HILDERBRANDT': 0,
    'HILDERBRANT': 0,
    'HILDERMAN': 0,
    'HILDING': 0,
    'HILDINGER': 0,
    'HILDITCH': 0,
    'HILDMAN': 0,
    'HILDNER': 0,
    'HILDRED': 1,
    'HILDRETH': 0,
    'HILDT': 0,
    'HILDUM': 0,
    'HILE': 0,
    'HILEMAN': 0,
    'HILER': 0,
    'HILERIO': 0,
    'HILES': 0,
    'HILEY': 0,
    'HILF': 0,
    'HILFER': 0,
    'HILFERTY': 0,
    'HILFIGER': 0,
    'HILFIKER': 0,
    'HILFINGER': 0,
    'HILGAR': 0,
    'HILGART': 0,
    'HILGEFORT': 0,
    'HILGEMAN': 0,
    'HILGEMANN': 0,
    'HILGEN': 0,
    'HILGENBERG': 0,
    'HILGENDORF': 0,
    'HILGENKAMP': 0,
    'HILGER': 0,
    'HILGERS': 0,
    'HILGERT': 0,
    'HILINSKI': 0,
    'HILK': 0,
    'HILKE': 0,
    'HILKEN': 0,
    'HILKER': 0,
    'HILKERT': 0,
    'HILKEY': 0,
    'HILKO': 0,
    'HILL': 0,
    'HILLABRAND': 0,
    'HILLAIRE': 0,
    'HILLAKER': 0,
    'HILLAM': 0,
    'HILLAN': 0,
    'HILLAND': 0,
    'HILLARD': 0,
    'HILLARY': 0.9701492537313433,
    'HILLAS': 0,
    'HILLBERG': 0,
    'HILLBERRY': 0,
    'HILLBURN': 0,
    'HILLE': 0,
    'HILLEARY': 0,
    'HILLEBRAND': 0,
    'HILLEBRANDT': 0,
    'HILLEBRECHT': 0,
    'HILLEGAS': 0,
    'HILLEGASS': 0,
    'HILLEGEIST': 0,
    'HILLEGONDS': 0,
    'HILLEL': 0,
    'HILLEMAN': 0,
    'HILLEMANN': 0,
    'HILLEN': 0,
    'HILLENBRAND': 0,
    'HILLENBURG': 0,
    'HILLER': 0,
    'HILLEREN': 0,
    'HILLERICH': 0,
    'HILLERMAN': 0,
    'HILLERS': 0,
    'HILLERT': 0,
    'HILLERY': 0,
    'HILLES': 0,
    'HILLESHEIM': 0,
    'HILLESHIEM': 0,
    'HILLESLAND': 0,
    'HILLESTAD': 0,
    'HILLEY': 0,
    'HILLGARTNER': 0,
    'HILLGER': 0,
    'HILLGROVE': 0,
    'HILLHOUSE': 0,
    'HILLIAN': 0,
    'HILLIAR': 0,
    'HILLIARD': 0,
    'HILLIE': 0,
    'HILLIER': 0,
    'HILLIG': 0,
    'HILLIGAS': 0,
    'HILLIGOSS': 0,
    'HILLIKER': 0,
    'HILLIMAN': 0,
    'HILLIN': 0,
    'HILLING': 0,
    'HILLINGER': 0,
    'HILLIS': 0,
    'HILLIUS': 0,
    'HILLJE': 0,
    'HILLMAN': 0,
    'HILLMANN': 0,
    'HILLMER': 0,
    'HILLMON': 0,
    'HILLNER': 0,
    'HILLOCK': 0,
    'HILLS': 0,
    'HILLSBERG': 0,
    'HILLSGROVE': 0,
    'HILLSMAN': 0,
    'HILLSON': 0,
    'HILLSTEAD': 0,
    'HILLSTROM': 0,
    'HILLUKKA': 0,
    'HILLWIG': 0,
    'HILLYARD': 0,
    'HILLYER': 0,
    'HILMA': 1,
    'HILMAN': 0,
    'HILMER': 0,
    'HILMES': 0,
    'HILMO': 0,
    'HILMOE': 0,
    'HILO': 0,
    'HILPERT': 0,
    'HILPIPRE': 0,
    'HILS': 0,
    'HILSABECK': 0,
    'HILSCHER': 0,
    'HILSE': 0,
    'HILSEN': 0,
    'HILSENBECK': 0,
    'HILSGEN': 0,
    'HILSHER': 0,
    'HILSINGER': 0,
    'HILSMAN': 0,
    'HILSON': 0,
    'HILST': 0,
    'HILSTAD': 0,
    'HILSTON': 0,
    'HILT': 0,
    'HILTABIDEL': 0,
    'HILTBRAND': 0,
    'HILTBRUNNER': 0,
    'HILTERBRAN': 0,
    'HILTERBRAND': 0,
    'HILTGEN': 0,
    'HILTNER': 0,
    'HILTON': 0.324254215304799,
    'HILTS': 0,
    'HILTUNEN': 0,
    'HILTY': 0,
    'HILTZ': 0,
    'HILVERS': 0,
    'HILYARD': 0,
    'HILYER': 0,
    'HILZ': 0,
    'HILZENDEGER': 0,
    'HILZER': 0,
    'HILZINGER': 0,
    'HIM': 0,
    'HIMAN': 0,
    'HIMBER': 0,
    'HIMBURG': 0,
    'HIME': 0,
    'HIMEBAUCH': 0,
    'HIMEBAUGH': 0,
    'HIMEL': 0,
    'HIMELFARB': 0,
    'HIMELICK': 0,
    'HIMELRICK': 0,
    'HIMELRIGHT': 0,
    'HIMELSTEIN': 0,
    'HIMENEZ': 0,
    'HIMES': 0,
    'HIMLE': 0,
    'HIMLER': 0,
    'HIMLEY': 0,
    'HIMMEL': 0,
    'HIMMELBERG': 0,
    'HIMMELBERGER': 0,
    'HIMMELEIN': 0,
    'HIMMELFARB': 0,
    'HIMMELHEBER': 0,
    'HIMMELMAN': 0,
    'HIMMELMANN': 0,
    'HIMMELREICH': 0,
    'HIMMELRIGHT': 0,
    'HIMMELSBACH': 0,
    'HIMMELSPACH': 0,
    'HIMMELSTEIN': 0,
    'HIMMELWRIGHT': 0,
    'HIMMER': 0,
    'HIMMERICH': 0,
    'HIMMLER': 0,
    'HIMROD': 0,
    'HIMSCHOOT': 0,
    'HIMSEL': 0,
    'HIMSL': 0,
    'HIMSTEDT': 0,
    'HIN': 0,
    'HINA': 0,
    'HINAMAN': 0,
    'HINCAPIE': 0,
    'HINCE': 0,
    'HINCH': 0,
    'HINCHBERGER': 0,
    'HINCHCLIFF': 0,
    'HINCHCLIFFE': 0,
    'HINCHEE': 0,
    'HINCHEN': 0,
    'HINCHER': 0,
    'HINCHEY': 0,
    'HINCHLEY': 0,
    'HINCHLIFF': 0,
    'HINCHLIFFE': 0,
    'HINCHMAN': 0,
    'HINCHY': 0,
    'HINCK': 0,
    'HINCKLE': 0,
    'HINCKLEY': 0,
    'HINCKS': 0,
    'HIND': 0,
    'HINDALL': 0,
    'HINDBAUGH': 0,
    'HINDE': 0,
    'HINDEL': 0,
    'HINDELANG': 0,
    'HINDEN': 0,
    'HINDENACH': 0,
    'HINDENLANG': 0,
    'HINDER': 0,
    'HINDERAKER': 0,
    'HINDERBERGER': 0,
    'HINDERER': 0,
    'HINDERKS': 0,
    'HINDERLITER': 0,
    'HINDERMAN': 0,
    'HINDERS': 0,
    'HINDES': 0,
    'HINDI': 0,
    'HINDIN': 0,
    'HINDLE': 0,
    'HINDLEY': 0,
    'HINDMAN': 0,
    'HINDMARCH': 0,
    'HINDMARSH': 0,
    'HINDMON': 0,
    'HINDS': 0,
    'HINDSLEY': 0,
    'HINDSMAN': 0,
    'HINDSON': 0,
    'HINDT': 0,
    'HINDY': 0,
    'HINE': 0,
    'HINEBAUGH': 0,
    'HINEGARDNER': 0,
    'HINELINE': 0,
    'HINELY': 0,
    'HINEMAN': 0,
    'HINEN': 0,
    'HINER': 0,
    'HINERMAN': 0,
    'HINES': 0,
    'HINESLEY': 0,
    'HINESLY': 0,
    'HINESTROZA': 0,
    'HINEY': 0,
    'HING': 0,
    'HINGA': 0,
    'HINGER': 0,
    'HINGLE': 0,
    'HINGLEY': 0,
    'HINGORANI': 0,
    'HINGSON': 0,
    'HINGST': 0,
    'HINGSTON': 0,
    'HINGTGEN': 0,
    'HINH': 0,
    'HINIKER': 0,
    'HINISH': 0,
    'HINJOSA': 0,
    'HINK': 0,
    'HINKE': 0,
    'HINKEBEIN': 0,
    'HINKEL': 0,
    'HINKELDEY': 0,
    'HINKELMAN': 0,
    'HINKEMEYER': 0,
    'HINKEN': 0,
    'HINKENS': 0,
    'HINKER': 0,
    'HINKES': 0,
    'HINKEY': 0,
    'HINKHOUSE': 0,
    'HINKIE': 0,
    'HINKINS': 0,
    'HINKLE': 0,
    'HINKLEMAN': 0,
    'HINKLEY': 0,
    'HINKLIN': 0,
    'HINKS': 0,
    'HINKSON': 0,
    'HINKSTON': 0,
    'HINLEY': 0,
    'HINMAN': 0,
    'HINMON': 0,
    'HINN': 0,
    'HINNANT': 0,
    'HINNAWI': 0,
    'HINNEN': 0,
    'HINNENKAMP': 0,
    'HINNERS': 0,
    'HINNERSHITZ': 0,
    'HINO': 0,
    'HINOJO': 0,
    'HINOJOS': 0,
    'HINOJOSA': 0,
    'HINOJOZA': 0,
    'HINOSTROZA': 0,
    'HINOTE': 0,
    'HINRICH': 0,
    'HINRICHS': 0,
    'HINRICHSEN': 0,
    'HINS': 0,
    'HINSCH': 0,
    'HINSCHBERGER': 0,
    'HINSDALE': 0,
    'HINSEY': 0,
    'HINSHAW': 0,
    'HINSLEY': 0,
    'HINSON': 0,
    'HINSPETER': 0,
    'HINSZ': 0,
    'HINT': 0,
    'HINTE': 0,
    'HINTEN': 0,
    'HINTERBERGER': 0,
    'HINTERGARDT': 0,
    'HINTERLONG': 0,
    'HINTERMEISTER': 0,
    'HINTHORN': 0,
    'HINTHORNE': 0,
    'HINTLIAN': 0,
    'HINTON': 0,
    'HINTSALA': 0,
    'HINTZ': 0,
    'HINTZE': 0,
    'HINTZEN': 0,
    'HINTZMAN': 0,
    'HINZ': 0,
    'HINZE': 0,
    'HINZMAN': 0,
    'HINZMANN': 0,
    'HINZO': 0,
    'HINZPETER': 0,
    'HIONIS': 0,
    'HIOS': 0,
    'HIOTIS': 0,
    'HIOTT': 0,
    'HIPES': 0,
    'HIPKE': 0,
    'HIPKINS': 0,
    'HIPKISS': 0,
    'HIPOL': 0,
    'HIPOLITO': 0.880281690140845,
    'HIPP': 0,
    'HIPPARD': 0,
    'HIPPE': 0,
    'HIPPELY': 0,
    'HIPPEN': 0,
    'HIPPENSTEEL': 0,
    'HIPPENSTIEL': 0,
    'HIPPERT': 0,
    'HIPPLE': 0,
    'HIPPLER': 0,
    'HIPPOLYTE': 0,
    'HIPPS': 0,
    'HIPSHER': 0,
    'HIPSHIRE': 0,
    'HIPSKIND': 0,
    'HIPSLEY': 0,
    'HIPSMAN': 0,
    'HIPWELL': 0,
    'HIRA': 0,
    'HIRABAYASHI': 0,
    'HIRACHETA': 0,
    'HIRAGA': 0,
    'HIRAHARA': 0,
    'HIRAI': 0,
    'HIRAKAWA': 0,
    'HIRAKI': 0,
    'HIRALDO': 0,
    'HIRALES': 0,
    'HIRAM': 1,
    'HIRAMATSU': 0,
    'HIRAMOTO': 0,
    'HIRANAKA': 0,
    'HIRANI': 0,
    'HIRANO': 0,
    'HIRAO': 0,
    'HIRAOKA': 0,
    'HIRASAWA': 0,
    'HIRASHIMA': 0,
    'HIRATA': 0,
    'HIRATSUKA': 0,
    'HIRAYAMA': 0,
    'HIRCHAK': 0,
    'HIRCHERT': 0,
    'HIRD': 0,
    'HIRDES': 0,
    'HIRDLER': 0,
    'HIRE': 0,
    'HIREMATH': 0,
    'HIRES': 0,
    'HIRJI': 0,
    'HIRKO': 0,
    'HIRL': 0,
    'HIRMAN': 0,
    'HIRMIZ': 0,
    'HIRN': 0,
    'HIRNEISEN': 0,
    'HIRNER': 0,
    'HIRNING': 0,
    'HIROKAWA': 0,
    'HIROKO': 1,
    'HIROMOTO': 0,
    'HIRONAKA': 0,
    'HIRONIMUS': 0,
    'HIRONS': 0,
    'HIROSE': 0,
    'HIROTA': 0,
    'HIRSBRUNNER': 0,
    'HIRSCH': 0,
    'HIRSCHAUER': 0,
    'HIRSCHBERG': 0,
    'HIRSCHBERGER': 0,
    'HIRSCHEL': 0,
    'HIRSCHEY': 0,
    'HIRSCHFELD': 0,
    'HIRSCHFIELD': 0,
    'HIRSCHHORN': 0,
    'HIRSCHI': 0,
    'HIRSCHKORN': 0,
    'HIRSCHL': 0,
    'HIRSCHLER': 0,
    'HIRSCHMAN': 0,
    'HIRSCHMANN': 0,
    'HIRSCHORN': 0,
    'HIRSCHY': 0,
    'HIRSH': 0,
    'HIRSHBERG': 0,
    'HIRSHEY': 0,
    'HIRSHFELD': 0,
    'HIRSHFIELD': 0,
    'HIRSHMAN': 0,
    'HIRSHON': 0,
    'HIRSHORN': 0,
    'HIRSI': 0,
    'HIRST': 0,
    'HIRSTEIN': 0,
    'HIRSTIUS': 0,
    'HIRT': 0,
    'HIRTE': 0,
    'HIRTH': 0,
    'HIRTLE': 0,
    'HIRTZ': 0,
    'HIRTZEL': 0,
    'HIRVELA': 0,
    'HIRZ': 0,
    'HIRZEL': 0,
    'HISAKO': 1,
    'HISAMOTO': 0,
    'HISATAKE': 0,
    'HISAW': 0,
    'HISCHKE': 0,
    'HISCOCK': 0,
    'HISCOCKS': 0,
    'HISCOX': 0,
    'HISE': 0,
    'HISEL': 0,
    'HISER': 0,
    'HISEROTE': 0,
    'HISEY': 0,
    'HISGEN': 0,
    'HISH': 0,
    'HISHMEH': 0,
    'HISKETT': 0,
    'HISKEY': 0,
    'HISLE': 0,
    'HISLER': 0,
    'HISLOP': 0,
    'HISLOPE': 0,
    'HISS': 0,
    'HISSAM': 0,
    'HISSEM': 0,
    'HISSEY': 0,
    'HISSOM': 0,
    'HISSONG': 0,
    'HISTAND': 0,
    'HISTED': 0,
    'HITA': 0,
    'HITCH': 0,
    'HITCHCOCK': 0,
    'HITCHCOX': 0,
    'HITCHELL': 0,
    'HITCHEN': 0,
    'HITCHENS': 0,
    'HITCHINGS': 0,
    'HITCHINS': 0,
    'HITCHLER': 0,
    'HITCHMAN': 0,
    'HITCHNER': 0,
    'HITE': 0,
    'HITER': 0,
    'HITES': 0,
    'HITESHEW': 0,
    'HITESMAN': 0,
    'HITHE': 0,
    'HITI': 0,
    'HITNER': 0,
    'HITOMI': 0,
    'HITSMAN': 0,
    'HITSON': 0,
    'HITT': 0,
    'HITTE': 0,
    'HITTEL': 0,
    'HITTER': 0,
    'HITTI': 0,
    'HITTIE': 0,
    'HITTINGER': 0,
    'HITTLE': 0,
    'HITTLER': 0,
    'HITTMAN': 0,
    'HITTNER': 0,
    'HITTS': 0,
    'HITTSON': 0,
    'HITZ': 0,
    'HITZEL': 0,
    'HITZELBERGER': 0,
    'HITZEMAN': 0,
    'HITZEMANN': 0,
    'HITZLER': 0,
    'HITZMAN': 0,
    'HIU': 0,
    'HIURA': 0,
    'HIVELEY': 0,
    'HIVELY': 0,
    'HIVES': 0,
    'HIVNER': 0,
    'HIX': 0,
    'HIXENBAUGH': 0,
    'HIXON': 0,
    'HIXSON': 0,
    'HIYAMA': 0,
    'HIZA': 0,
    'HIZER': 0,
    'HIZON': 0,
    'HJELLE': 0,
    'HJELM': 0,
    'HJELMELAND': 0,
    'HJELMSTAD': 0,
    'HJERMSTAD': 0,
    'HJERPE': 0,
    'HJORT': 0,
    'HJORTH': 0,
    'HLAD': 0,
    'HLADEK': 0,
    'HLADIK': 0,
    'HLADKY': 0,
    'HLAING': 0,
    'HLAS': 0,
    'HLATKY': 0,
    'HLAVA': 0,
    'HLAVAC': 0,
    'HLAVACEK': 0,
    'HLAVATY': 0,
    'HLAVENKA': 0,
    'HLAVIN': 0,
    'HLAVINKA': 0,
    'HLAVKA': 0,
    'HLAVSA': 0,
    'HLINAK': 0,
    'HLINKA': 0,
    'HLYWA': 0,
    'HMIELEWSKI': 0,
    'HNAT': 0,
    'HNATH': 0,
    'HNATIUK': 0,
    'HNATKO': 0,
    'HO': 0,
    'HOA': 0.970873786407767,
    'HOAC': 0,
    'HOAD': 0,
    'HOADLEY': 0,
    'HOAG': 0,
    'HOAGE': 0,
    'HOAGLAN': 0,
    'HOAGLAND': 0,
    'HOAGLIN': 0,
    'HOAGLUND': 0,
    'HOAGUE': 0,
    'HOAK': 0,
    'HOAKS': 0,
    'HOAL': 0,
    'HOAN': 0,
    'HOANG': 0,
    'HOAPILI': 0,
    'HOAR': 0,
    'HOARD': 0,
    'HOARE': 0,
    'HOARTY': 0,
    'HOATH': 0,
    'HOATS': 0,
    'HOATSON': 0,
    'HOBACK': 0,
    'HOBAICA': 0,
    'HOBAN': 0,
    'HOBART': 0,
    'HOBAUGH': 0,
    'HOBB': 0,
    'HOBBA': 0,
    'HOBBES': 0,
    'HOBBICK': 0,
    'HOBBIE': 0,
    'HOBBINS': 0,
    'HOBBLE': 0,
    'HOBBS': 0,
    'HOBBY': 0,
    'HOBDAY': 0,
    'HOBDEN': 0,
    'HOBDY': 0,
    'HOBE': 0,
    'HOBECK': 0,
    'HOBEL': 0,
    'HOBELMAN': 0,
    'HOBEN': 0,
    'HOBENSACK': 0,
    'HOBER': 0,
    'HOBERG': 0,
    'HOBERMAN': 0,
    'HOBERT': 0.9411764705882353,
    'HOBGOOD': 0,
    'HOBIN': 0,
    'HOBIZAL': 0,
    'HOBKIRK': 0,
    'HOBLER': 0,
    'HOBLEY': 0,
    'HOBLIN': 0,
    'HOBLIT': 0,
    'HOBLITZELL': 0,
    'HOBOCK': 0,
    'HOBROCK': 0,
    'HOBSON': 0,
    'HOBURG': 0,
    'HOBZA': 0,
    'HOCEVAR': 0,
    'HOCH': 0,
    'HOCHADEL': 0,
    'HOCHANADEL': 0,
    'HOCHARD': 0,
    'HOCHBAUM': 0,
    'HOCHBERG': 0,
    'HOCHBERGER': 0,
    'HOCHENDONER': 0,
    'HOCHEVAR': 0,
    'HOCHGESANG': 0,
    'HOCHHALTER': 0,
    'HOCHHAUSER': 0,
    'HOCHHEISER': 0,
    'HOCHMAN': 0,
    'HOCHMUTH': 0,
    'HOCHRADEL': 0,
    'HOCHREIN': 0,
    'HOCHREITER': 0,
    'HOCHSCHILD': 0,
    'HOCHSPRUNG': 0,
    'HOCHSTADT': 0,
    'HOCHSTATTER': 0,
    'HOCHSTEDLER': 0,
    'HOCHSTEIN': 0,
    'HOCHSTETLER': 0,
    'HOCHSTETTER': 0,
    'HOCHSTRASSER': 0,
    'HOCHULI': 0,
    'HOCHWALT': 0,
    'HOCK': 0,
    'HOCKADAY': 0,
    'HOCKE': 0,
    'HOCKEL': 0,
    'HOCKEMA': 0,
    'HOCKEMEYER': 0,
    'HOCKEN': 0,
    'HOCKENBERGER': 0,
    'HOCKENBERRY': 0,
    'HOCKENBERY': 0,
    'HOCKENBROCK': 0,
    'HOCKENBURY': 0,
    'HOCKENHULL': 0,
    'HOCKENSMITH': 0,
    'HOCKENSON': 0,
    'HOCKER': 0,
    'HOCKERS': 0,
    'HOCKERSMITH': 0,
    'HOCKERT': 0,
    'HOCKETT': 0,
    'HOCKEY': 0,
    'HOCKIN': 0,
    'HOCKING': 0,
    'HOCKINS': 0,
    'HOCKLESS': 0,
    'HOCKLEY': 0,
    'HOCKMAN': 0,
    'HOCKNEY': 0,
    'HOCKSTRA': 0,
    'HOCTOR': 0,
    'HOCUM': 0,
    'HOCUTT': 0,
    'HODA': 0,
    'HODACK': 0,
    'HODAK': 0,
    'HODAN': 0,
    'HODAPP': 0,
    'HODAS': 0,
    'HODD': 0,
    'HODDE': 0,
    'HODDER': 0,
    'HODDINOTT': 0,
    'HODDY': 0,
    'HODE': 0,
    'HODEK': 0,
    'HODEL': 0,
    'HODELL': 0,
    'HODEN': 0,
    'HODER': 0,
    'HODES': 0,
    'HODGDEN': 0,
    'HODGDON': 0,
    'HODGE': 0,
    'HODGEMAN': 0,
    'HODGEN': 0,
    'HODGENS': 0,
    'HODGERS': 0,
    'HODGES': 0,
    'HODGESON': 0,
    'HODGETTS': 0,
    'HODGIN': 0,
    'HODGINS': 0,
    'HODGKIN': 0,
    'HODGKINS': 0,
    'HODGKINSON': 0,
    'HODGKISS': 0,
    'HODGMAN': 0,
    'HODGSON': 0,
    'HODIL': 0,
    'HODKIEWICZ': 0,
    'HODKIN': 0,
    'HODKINS': 0,
    'HODKINSON': 0,
    'HODNE': 0,
    'HODNEFIELD': 0,
    'HODNETT': 0,
    'HODNIK': 0,
    'HODNY': 0,
    'HODO': 0,
    'HODOR': 0,
    'HODOROWSKI': 0,
    'HODOS': 0,
    'HODOUS': 0,
    'HODRICK': 0,
    'HODSDEN': 0,
    'HODSDON': 0,
    'HODSKINS': 0,
    'HODSON': 0,
    'HODULIK': 0,
    'HODUM': 0,
    'HODUR': 0,
    'HODZIC': 0,
    'HOE': 0,
    'HOEBBEL': 0,
    'HOEBEKE': 0,
    'HOEBEL': 0,
    'HOEBELHEINRICH': 0,
    'HOEBEN': 0,
    'HOEBER': 0,
    'HOEBING': 0,
    'HOECHERL': 0,
    'HOECHST': 0,
    'HOECK': 0,
    'HOECKER': 0,
    'HOEDEBECK': 0,
    'HOEDL': 0,
    'HOEFEL': 0,
    'HOEFER': 0,
    'HOEFERT': 0,
    'HOEFFEL': 0,
    'HOEFFER': 0,
    'HOEFFERLE': 0,
    'HOEFFLER': 0,
    'HOEFFLIN': 0,
    'HOEFFNER': 0,
    'HOEFGEN': 0,
    'HOEFKER': 0,
    'HOEFLE': 0,
    'HOEFLEIN': 0,
    'HOEFLER': 0,
    'HOEFLICH': 0,
    'HOEFLING': 0,
    'HOEFLINGER': 0,
    'HOEFNER': 0,
    'HOEFS': 0,
    'HOEFT': 0,
    'HOEG': 0,
    'HOEGEN': 0,
    'HOEGER': 0,
    'HOEGGER': 0,
    'HOEGH': 0,
    'HOEGLER': 0,
    'HOEH': 0,
    'HOEHL': 0,
    'HOEHLE': 0,
    'HOEHLER': 0,
    'HOEHN': 0,
    'HOEHNE': 0,
    'HOEHNER': 0,
    'HOEING': 0,
    'HOEK': 0,
    'HOEKE': 0,
    'HOEKEMA': 0,
    'HOEKENGA': 0,
    'HOEKMAN': 0,
    'HOEKSEMA': 0,
    'HOEKSTRA': 0,
    'HOEKWATER': 0,
    'HOEKZEMA': 0,
    'HOEL': 0,
    'HOELKER': 0,
    'HOELL': 0,
    'HOELLE': 0,
    'HOELLEIN': 0,
    'HOELLER': 0,
    'HOELSCHER': 0,
    'HOELTER': 0,
    'HOELTING': 0,
    'HOELTKE': 0,
    'HOELTZEL': 0,
    'HOELZ': 0,
    'HOELZEL': 0,
    'HOELZEMAN': 0,
    'HOELZER': 0,
    'HOELZLE': 0,
    'HOEM': 0,
    'HOEMAN': 0,
    'HOEMANN': 0,
    'HOEMBERG': 0,
    'HOEME': 0,
    'HOEMKE': 0,
    'HOEN': 0,
    'HOENE': 0,
    'HOENER': 0,
    'HOENES': 0,
    'HOENICKE': 0,
    'HOENIE': 0,
    'HOENIG': 0,
    'HOENING': 0,
    'HOENISCH': 0,
    'HOENKE': 0,
    'HOENSHELL': 0,
    'HOENSTINE': 0,
    'HOEPER': 0,
    'HOEPF': 0,
    'HOEPFL': 0,
    'HOEPFNER': 0,
    'HOEPKER': 0,
    'HOEPNER': 0,
    'HOEPPNER': 0,
    'HOER': 0,
    'HOERAUF': 0,
    'HOERCHLER': 0,
    'HOERGER': 0,
    'HOERIG': 0,
    'HOERING': 0,
    'HOERL': 0,
    'HOERLE': 0,
    'HOERMAN': 0,
    'HOERMANN': 0,
    'HOERNEMANN': 0,
    'HOERNER': 0,
    'HOERNIG': 0,
    'HOERNING': 0,
    'HOERNKE': 0,
    'HOERR': 0,
    'HOERSCH': 0,
    'HOERST': 0,
    'HOERSTEN': 0,
    'HOERSTER': 0,
    'HOERTER': 0,
    'HOERTH': 0,
    'HOERTZ': 0,
    'HOES': 0,
    'HOESCH': 0,
    'HOESCHELE': 0,
    'HOESCHEN': 0,
    'HOESE': 0,
    'HOESEL': 0,
    'HOESER': 0,
    'HOESING': 0,
    'HOESLEY': 0,
    'HOESLI': 0,
    'HOESLY': 0,
    'HOESMAN': 0,
    'HOETH': 0,
    'HOEVE': 0,
    'HOEVEL': 0,
    'HOEVET': 0,
    'HOEY': 0,
    'HOEYE': 0,
    'HOEZEE': 0,
    'HOF': 0,
    'HOFACKER': 0,
    'HOFACRE': 0,
    'HOFBAUER': 0,
    'HOFE': 0,
    'HOFECKER': 0,
    'HOFELDT': 0,
    'HOFELICH': 0,
    'HOFELING': 0,
    'HOFER': 0,
    'HOFERER': 0,
    'HOFERT': 0,
    'HOFF': 0,
    'HOFFA': 0,
    'HOFFACKER': 0,
    'HOFFARD': 0,
    'HOFFART': 0,
    'HOFFARTH': 0,
    'HOFFAY': 0,
    'HOFFBAUER': 0,
    'HOFFBECK': 0,
    'HOFFBERG': 0,
    'HOFFECKER': 0,
    'HOFFEDITZ': 0,
    'HOFFEE': 0,
    'HOFFELD': 0,
    'HOFFENBERG': 0,
    'HOFFENKAMP': 0,
    'HOFFER': 0,
    'HOFFERBER': 0,
    'HOFFERBERT': 0,
    'HOFFERT': 0,
    'HOFFERTH': 0,
    'HOFFHEINS': 0,
    'HOFFHINES': 0,
    'HOFFINE': 0,
    'HOFFLAND': 0,
    'HOFFLANDER': 0,
    'HOFFLER': 0,
    'HOFFMAN': 0,
    'HOFFMANN': 0,
    'HOFFMASTER': 0,
    'HOFFMEIER': 0,
    'HOFFMEISTER': 0,
    'HOFFMEYER': 0,
    'HOFFMIRE': 0,
    'HOFFNAGLE': 0,
    'HOFFNER': 0,
    'HOFFORD': 0,
    'HOFFPAUIR': 0,
    'HOFFPAVIR': 0,
    'HOFFROGGE': 0,
    'HOFFSCHNEIDER': 0,
    'HOFFSES': 0,
    'HOFFSTADT': 0,
    'HOFFSTATTER': 0,
    'HOFFSTETTER': 0,
    'HOFHEINS': 0,
    'HOFHEINZ': 0,
    'HOFHERR': 0,
    'HOFILENA': 0,
    'HOFIUS': 0,
    'HOFLAND': 0,
    'HOFLER': 0,
    'HOFMAN': 0,
    'HOFMANN': 0,
    'HOFMASTER': 0,
    'HOFMEISTER': 0,
    'HOFMEYER': 0,
    'HOFNER': 0,
    'HOFRICHTER': 0,
    'HOFSCHULTE': 0,
    'HOFSOMMER': 0,
    'HOFSTAD': 0,
    'HOFSTADTER': 0,
    'HOFSTATTER': 0,
    'HOFSTEDE': 0,
    'HOFSTEDT': 0,
    'HOFSTEE': 0,
    'HOFSTETTER': 0,
    'HOFSTRA': 0,
    'HOFSTRAND': 0,
    'HOFT': 0,
    'HOFTIEZER': 0,
    'HOGABOOM': 0,
    'HOGAN': 0,
    'HOGANCAMP': 0,
    'HOGANS': 0,
    'HOGANSON': 0,
    'HOGARD': 0,
    'HOGARTH': 0,
    'HOGARTY': 0,
    'HOGATE': 0,
    'HOGBERG': 0,
    'HOGBIN': 0,
    'HOGDEN': 0,
    'HOGE': 0,
    'HOGEBOOM': 0,
    'HOGEL': 0,
    'HOGELAND': 0,
    'HOGEN': 0,
    'HOGENCAMP': 0,
    'HOGENKAMP': 0,
    'HOGENMILLER': 0,
    'HOGENSON': 0,
    'HOGER': 0,
    'HOGG': 0,
    'HOGGAN': 0,
    'HOGGARD': 0,
    'HOGGARTH': 0,
    'HOGGATT': 0,
    'HOGGE': 0,
    'HOGGES': 0,
    'HOGGINS': 0,
    'HOGGLE': 0,
    'HOGGS': 0,
    'HOGIE': 0,
    'HOGIN': 0,
    'HOGLAN': 0,
    'HOGLAND': 0,
    'HOGLE': 0,
    'HOGLEN': 0,
    'HOGLIN': 0,
    'HOGLUND': 0,
    'HOGNER': 0,
    'HOGNESS': 0,
    'HOGOBOOM': 0,
    'HOGREBE': 0,
    'HOGREFE': 0,
    'HOGSED': 0,
    'HOGSETT': 0,
    'HOGSHEAD': 0,
    'HOGSHOOTER': 0,
    'HOGSTAD': 0,
    'HOGSTEN': 0,
    'HOGSTON': 0,
    'HOGSTROM': 0,
    'HOGUE': 0,
    'HOGUES': 0,
    'HOGUET': 0,
    'HOGWOOD': 0,
    'HOGYA': 0,
    'HOH': 0,
    'HOHBACH': 0,
    'HOHBEIN': 0,
    'HOHE': 0,
    'HOHEISEL': 0,
    'HOHENADEL': 0,
    'HOHENBERGER': 0,
    'HOHENBRINK': 0,
    'HOHENSEE': 0,
    'HOHENSTEIN': 0,
    'HOHENWARTER': 0,
    'HOHERTZ': 0,
    'HOHF': 0,
    'HOHIMER': 0,
    'HOHL': 0,
    'HOHLBEIN': 0,
    'HOHLE': 0,
    'HOHLEN': 0,
    'HOHLER': 0,
    'HOHLFELD': 0,
    'HOHLSTEIN': 0,
    'HOHLT': 0,
    'HOHM': 0,
    'HOHMAN': 0,
    'HOHMANN': 0,
    'HOHMEIER': 0,
    'HOHN': 0,
    'HOHNBAUM': 0,
    'HOHNE': 0,
    'HOHNER': 0,
    'HOHNSTEIN': 0,
    'HOHOL': 0,
    'HOHOLIK': 0,
    'HOHSTADT': 0,
    'HOHULIN': 0,
    'HOI': 0,
    'HOIDA': 0,
    'HOIDAL': 0,
    'HOIER': 0,
    'HOIG': 0,
    'HOILAND': 0,
    'HOILE': 0,
    'HOILES': 0,
    'HOILETT': 0,
    'HOILMAN': 0,
    'HOIN': 0,
    'HOINES': 0,
    'HOINESS': 0,
    'HOING': 0,
    'HOINS': 0,
    'HOISETH': 0,
    'HOISINGTON': 0,
    'HOIST': 0,
    'HOIT': 0,
    'HOITINK': 0,
    'HOITT': 0,
    'HOIUM': 0,
    'HOJARA': 0,
    'HOJEM': 0,
    'HOJNACKI': 0,
    'HOJNICKI': 0,
    'HOJNOWSKI': 0,
    'HOK': 0,
    'HOKAMA': 0,
    'HOKAMP': 0,
    'HOKANSON': 0,
    'HOKE': 0,
    'HOKENSON': 0,
    'HOKER': 0,
    'HOKES': 0,
    'HOKETT': 0,
    'HOKIT': 0,
    'HOKKANEN': 0,
    'HOKOANA': 0,
    'HOKSBERGEN': 0,
    'HOL': 0,
    'HOLA': 0,
    'HOLADAY': 0,
    'HOLAHAN': 0,
    'HOLAK': 0,
    'HOLAN': 0,
    'HOLAND': 0,
    'HOLAPPA': 0,
    'HOLAS': 0,
    'HOLASEK': 0,
    'HOLAWAY': 0,
    'HOLBA': 0,
    'HOLBACH': 0,
    'HOLBACK': 0,
    'HOLBECK': 0,
    'HOLBEIN': 0,
    'HOLBEN': 0,
    'HOLBERG': 0,
    'HOLBERT': 0,
    'HOLBERTON': 0,
    'HOLBIRD': 0,
    'HOLBORN': 0,
    'HOLBROOK': 0,
    'HOLBROOKS': 0,
    'HOLBY': 0,
    'HOLCK': 0,
    'HOLCOM': 0,
    'HOLCOMB': 0,
    'HOLCOMBE': 0,
    'HOLCROFT': 0,
    'HOLD': 0,
    'HOLDA': 0,
    'HOLDAHL': 0,
    'HOLDAWAY': 0,
    'HOLDBROOK': 0,
    'HOLDBROOKS': 0,
    'HOLDCRAFT': 0,
    'HOLDCROFT': 0,
    'HOLDEFER': 0,
    'HOLDEMAN': 0,
    'HOLDEN': 0,
    'HOLDENER': 0,
    'HOLDER': 0,
    'HOLDERBAUM': 0,
    'HOLDERBY': 0,
    'HOLDERFIELD': 0,
    'HOLDERMAN': 0,
    'HOLDERNESS': 0,
    'HOLDERREAD': 0,
    'HOLDGATE': 0,
    'HOLDGRAFER': 0,
    'HOLDIMAN': 0,
    'HOLDINESS': 0,
    'HOLDING': 0,
    'HOLDITCH': 0,
    'HOLDMAN': 0,
    'HOLDMEYER': 0,
    'HOLDORF': 0,
    'HOLDREDGE': 0,
    'HOLDREN': 0,
    'HOLDRIDGE': 0,
    'HOLDSCLAW': 0,
    'HOLDSWORTH': 0,
    'HOLDT': 0,
    'HOLDWAY': 0,
    'HOLDWICK': 0,
    'HOLE': 0,
    'HOLEC': 0,
    'HOLECEK': 0,
    'HOLECHEK': 0,
    'HOLEKAMP': 0,
    'HOLEM': 0,
    'HOLEMAN': 0,
    'HOLEN': 0,
    'HOLES': 0,
    'HOLESAPPLE': 0,
    'HOLETON': 0,
    'HOLETS': 0,
    'HOLEVA': 0,
    'HOLEVAS': 0,
    'HOLEWA': 0,
    'HOLEWINSKI': 0,
    'HOLEY': 0,
    'HOLEYFIELD': 0,
    'HOLFELDER': 0,
    'HOLFELTZ': 0,
    'HOLFORD': 0,
    'HOLGADO': 0,
    'HOLGATE': 0,
    'HOLGERSON': 0,
    'HOLGIN': 0,
    'HOLGUIN': 0,
    'HOLI': 0,
    'HOLIAN': 0,
    'HOLIBAUGH': 0,
    'HOLIC': 0,
    'HOLICK': 0,
    'HOLICKY': 0,
    'HOLIDAY': 0,
    'HOLIEN': 0,
    'HOLIFIELD': 0,
    'HOLIHAN': 0,
    'HOLIK': 0,
    'HOLIMAN': 0,
    'HOLINA': 0,
    'HOLINESS': 0,
    'HOLINKA': 0,
    'HOLIWAY': 0,
    'HOLK': 0,
    'HOLKA': 0,
    'HOLKE': 0,
    'HOLKER': 0,
    'HOLKO': 0,
    'HOLL': 0,
    'HOLLABAUGH': 0,
    'HOLLADA': 0,
    'HOLLADAY': 0,
    'HOLLAHAN': 0,
    'HOLLAMAN': 0,
    'HOLLAMON': 0,
    'HOLLAN': 0,
    'HOLLAND': 0,
    'HOLLANDER': 0,
    'HOLLANDS': 0,
    'HOLLANDSWORTH': 0,
    'HOLLAR': 0,
    'HOLLARD': 0,
    'HOLLARS': 0,
    'HOLLAS': 0,
    'HOLLATZ': 0,
    'HOLLAWAY': 0,
    'HOLLBERG': 0,
    'HOLLCRAFT': 0,
    'HOLLCROFT': 0,
    'HOLLE': 0,
    'HOLLEMAN': 0,
    'HOLLEMBEAK': 0,
    'HOLLEN': 0,
    'HOLLENBACH': 0,
    'HOLLENBACK': 0,
    'HOLLENBAUGH': 0,
    'HOLLENBECK': 0,
    'HOLLENBERG': 0,
    'HOLLENBERGER': 0,
    'HOLLENDER': 0,
    'HOLLENHORST': 0,
    'HOLLENKAMP': 0,
    'HOLLENQUEST': 0,
    'HOLLENSBE': 0,
    'HOLLENSHEAD': 0,
    'HOLLENSTEIN': 0,
    'HOLLENSTEINER': 0,
    'HOLLER': 0,
    'HOLLERAN': 0,
    'HOLLERBACH': 0,
    'HOLLERICH': 0,
    'HOLLERMAN': 0,
    'HOLLERMANN': 0,
    'HOLLERN': 0,
    'HOLLERS': 0,
    'HOLLETT': 0,
    'HOLLEY': 0.15588464536243182,
    'HOLLFELDER': 0,
    'HOLLI': 1,
    'HOLLIBAUGH': 0,
    'HOLLICK': 0,
    'HOLLIDAY': 0,
    'HOLLIDGE': 0,
    'HOLLIE': 0.9211873080859775,
    'HOLLIEN': 0,
    'HOLLIER': 0,
    'HOLLIFIELD': 0,
    'HOLLIGAN': 0,
    'HOLLIGER': 0,
    'HOLLIHAN': 0,
    'HOLLIMAN': 0,
    'HOLLIMON': 0,
    'HOLLIN': 0,
    'HOLLINDEN': 0,
    'HOLLINESS': 0,
    'HOLLING': 0,
    'HOLLINGER': 0,
    'HOLLINGHEAD': 0,
    'HOLLINGS': 0,
    'HOLLINGSEAD': 0,
    'HOLLINGSHEAD': 0,
    'HOLLINGSHED': 0,
    'HOLLINGSWORTH': 0,
    'HOLLINGTON': 0,
    'HOLLINGWORTH': 0,
    'HOLLINQUEST': 0,
    'HOLLINRAKE': 0,
    'HOLLINS': 0,
    'HOLLINSHEAD': 0,
    'HOLLINSHED': 0,
    'HOLLINSWORTH': 0,
    'HOLLIS': 0.5181347150259067,
    'HOLLIST': 0,
    'HOLLISTER': 0,
    'HOLLIWAY': 0,
    'HOLLMAN': 0,
    'HOLLMANN': 0,
    'HOLLMER': 0,
    'HOLLMON': 0,
    'HOLLNAGEL': 0,
    'HOLLO': 0,
    'HOLLOBAUGH': 0,
    'HOLLOCK': 0,
    'HOLLOMAN': 0,
    'HOLLOMON': 0,
    'HOLLON': 0,
    'HOLLOPETER': 0,
    'HOLLORAN': 0,
    'HOLLOW': 0,
    'HOLLOWAY': 0,
    'HOLLOWELL': 0,
    'HOLLOWHORN': 0,
    'HOLLOWOOD': 0,
    'HOLLOWS': 0,
    'HOLLRAH': 0,
    'HOLLSTEIN': 0,
    'HOLLUB': 0,
    'HOLLUMS': 0,
    'HOLLWAY': 0,
    'HOLLWEDEL': 0,
    'HOLLY': 0.972730295976056,
    'HOLLYDAY': 0,
    'HOLLYER': 0,
    'HOLLYFIELD': 0,
    'HOLLYWOOD': 0,
    'HOLM': 0,
    'HOLMAN': 0,
    'HOLMBECK': 0,
    'HOLMBERG': 0,
    'HOLMBLAD': 0,
    'HOLMBOE': 0,
    'HOLME': 0,
    'HOLMEN': 0,
    'HOLMER': 0,
    'HOLMES': 0,
    'HOLMGREEN': 0,
    'HOLMGREN': 0,
    'HOLMLUND': 0,
    'HOLMON': 0,
    'HOLMQUEST': 0,
    'HOLMQUIST': 0,
    'HOLMS': 0,
    'HOLMSTEAD': 0,
    'HOLMSTEDT': 0,
    'HOLMSTROM': 0,
    'HOLMWOOD': 0,
    'HOLNESS': 0,
    'HOLOBAUGH': 0,
    'HOLOCKER': 0,
    'HOLOD': 0,
    'HOLODNAK': 0,
    'HOLODY': 0,
    'HOLOHAN': 0,
    'HOLOMAN': 0,
    'HOLOMON': 0,
    'HOLOTA': 0,
    'HOLOUBEK': 0,
    'HOLOVACH': 0,
    'HOLOWACH': 0,
    'HOLOWATY': 0,
    'HOLOWAY': 0,
    'HOLOWKA': 0,
    'HOLP': 0,
    'HOLPER': 0,
    'HOLPP': 0,
    'HOLPUCH': 0,
    'HOLQUIN': 0,
    'HOLQUIST': 0,
    'HOLROYD': 0,
    'HOLSAPPLE': 0,
    'HOLSCHBACH': 0,
    'HOLSCHER': 0,
    'HOLSCHUH': 0,
    'HOLSCLAW': 0,
    'HOLSEN': 0,
    'HOLSENBACK': 0,
    'HOLSENBECK': 0,
    'HOLSER': 0,
    'HOLSEY': 0,
    'HOLSHOUSER': 0,
    'HOLSHUE': 0,
    'HOLSING': 0,
    'HOLSINGER': 0,
    'HOLSMAN': 0,
    'HOLSOMBACK': 0,
    'HOLSON': 0,
    'HOLSONBACK': 0,
    'HOLSOPPLE': 0,
    'HOLST': 0,
    'HOLSTAD': 0,
    'HOLSTE': 0,
    'HOLSTEAD': 0,
    'HOLSTED': 0,
    'HOLSTEGE': 0,
    'HOLSTEIN': 0,
    'HOLSTEN': 0,
    'HOLSTER': 0,
    'HOLSTIEN': 0,
    'HOLSTINE': 0,
    'HOLSTON': 0,
    'HOLSTROM': 0,
    'HOLSWORTH': 0,
    'HOLT': 0,
    'HOLTAN': 0,
    'HOLTBERG': 0,
    'HOLTBY': 0,
    'HOLTCAMP': 0,
    'HOLTE': 0,
    'HOLTEL': 0,
    'HOLTEN': 0,
    'HOLTER': 0,
    'HOLTERMAN': 0,
    'HOLTERMANN': 0,
    'HOLTGRAVE': 0,
    'HOLTGREFE': 0,
    'HOLTGREWE': 0,
    'HOLTGRIEVE': 0,
    'HOLTH': 0,
    'HOLTHAM': 0,
    'HOLTHAUS': 0,
    'HOLTHE': 0,
    'HOLTHOUSE': 0,
    'HOLTHOUSER': 0,
    'HOLTHUS': 0,
    'HOLTHUSEN': 0,
    'HOLTJE': 0,
    'HOLTKAMP': 0,
    'HOLTMAN': 0,
    'HOLTMANN': 0,
    'HOLTMEIER': 0,
    'HOLTMEYER': 0,
    'HOLTOM': 0,
    'HOLTON': 0,
    'HOLTORF': 0,
    'HOLTQUIST': 0,
    'HOLTREY': 0,
    'HOLTROP': 0,
    'HOLTRY': 0,
    'HOLTS': 0,
    'HOLTSBERRY': 0,
    'HOLTSCHLAG': 0,
    'HOLTSCHNEIDER': 0,
    'HOLTSCLAW': 0,
    'HOLTSLANDER': 0,
    'HOLTWICK': 0,
    'HOLTY': 0,
    'HOLTZ': 0,
    'HOLTZAPFEL': 0,
    'HOLTZAPPLE': 0,
    'HOLTZCLAW': 0,
    'HOLTZE': 0,
    'HOLTZEN': 0,
    'HOLTZER': 0,
    'HOLTZINGER': 0,
    'HOLTZLANDER': 0,
    'HOLTZMAN': 0,
    'HOLTZMANN': 0,
    'HOLUB': 0,
    'HOLUBAR': 0,
    'HOLUBEC': 0,
    'HOLUBEK': 0,
    'HOLUBIK': 0,
    'HOLUM': 0,
    'HOLUP': 0,
    'HOLVECK': 0,
    'HOLVERSON': 0,
    'HOLVEY': 0,
    'HOLWAY': 0,
    'HOLWEG': 0,
    'HOLWEGER': 0,
    'HOLWEGNER': 0,
    'HOLWELL': 0,
    'HOLWERDA': 0,
    'HOLWICK': 0,
    'HOLY': 0,
    'HOLYAN': 0,
    'HOLYBEE': 0,
    'HOLYCROSS': 0,
    'HOLYFIELD': 0,
    'HOLYOAK': 0,
    'HOLYOKE': 0,
    'HOLZ': 0,
    'HOLZAPFEL': 0,
    'HOLZBACH': 0,
    'HOLZBAUER': 0,
    'HOLZBAUR': 0,
    'HOLZBERG': 0,
    'HOLZBERGER': 0,
    'HOLZE': 0,
    'HOLZEM': 0,
    'HOLZEMER': 0,
    'HOLZENDORF': 0,
    'HOLZER': 0,
    'HOLZERLAND': 0,
    'HOLZHAUER': 0,
    'HOLZHAUSEN': 0,
    'HOLZHAUSER': 0,
    'HOLZHEIMER': 0,
    'HOLZHUETER': 0,
    'HOLZINGER': 0,
    'HOLZKNECHT': 0,
    'HOLZMACHER': 0,
    'HOLZMAN': 0,
    'HOLZMANN': 0,
    'HOLZMEISTER': 0,
    'HOLZMER': 0,
    'HOLZMILLER': 0,
    'HOLZNAGEL': 0,
    'HOLZNER': 0,
    'HOLZRICHTER': 0,
    'HOLZSCHUH': 0,
    'HOLZUM': 0,
    'HOLZWART': 0,
    'HOLZWARTH': 0,
    'HOLZWORTH': 0,
    'HOM': 0,
    'HOMA': 0,
    'HOMAN': 0,
    'HOMANN': 0,
    'HOMANS': 0,
    'HOMAR': 0,
    'HOMB': 0,
    'HOMBERG': 0,
    'HOMBERGER': 0,
    'HOMBS': 0,
    'HOMBURG': 0,
    'HOME': 0,
    'HOMEIER': 0,
    'HOMEISTER': 0,
    'HOMEL': 0,
    'HOMEN': 0,
    'HOMER': 0.947193937958797,
    'HOMERDING': 0,
    'HOMES': 0,
    'HOMESLEY': 0,
    'HOMESTEAD': 0,
    'HOMEWOOD': 0,
    'HOMEYER': 0,
    'HOMFELD': 0,
    'HOMIAK': 0,
    'HOMICH': 0,
    'HOMICK': 0,
    'HOMIER': 0,
    'HOMITZ': 0,
    'HOMLER': 0,
    'HOMLES': 0,
    'HOMMA': 0,
    'HOMMAN': 0,
    'HOMME': 0,
    'HOMMEL': 0,
    'HOMMEN': 0,
    'HOMMER': 0,
    'HOMMERDING': 0,
    'HOMMES': 0,
    'HOMMINGA': 0,
    'HOMOKI': 0,
    'HOMOL': 0,
    'HOMOLA': 0,
    'HOMOLKA': 0,
    'HOMRICH': 0,
    'HOMRIGHAUSEN': 0,
    'HOMS': 0,
    'HOMSEY': 0,
    'HOMSHER': 0,
    'HOMSI': 0,
    'HOMSLEY': 0,
    'HOMSOMBATH': 0,
    'HOMSTAD': 0,
    'HOMSY': 0,
    'HOMUTH': 0,
    'HOMYAK': 0,
    'HOMZA': 0,
    'HON': 0,
    'HONADEL': 0,
    'HONAKER': 0,
    'HONAN': 0,
    'HONANIE': 0,
    'HONARD': 0,
    'HONAS': 0,
    'HONCHELL': 0,
    'HONCOOP': 0,
    'HONDA': 0,
    'HONDEL': 0,
    'HONDL': 0,
    'HONDO': 0,
    'HONDROS': 0,
    'HONE': 0,
    'HONEA': 0,
    'HONEBRINK': 0,
    'HONECK': 0,
    'HONECKER': 0,
    'HONEGGER': 0,
    'HONEMAN': 0,
    'HONER': 0,
    'HONERKAMP': 0,
    'HONES': 0,
    'HONESTO': 0,
    'HONESTY': 0,
    'HONEY': 0.6644518272425249,
    'HONEYCHURCH': 0,
    'HONEYCUT': 0,
    'HONEYCUTT': 0,
    'HONEYFIELD': 0,
    'HONEYMAN': 0,
    'HONEYSETT': 0,
    'HONEYSUCKLE': 0,
    'HONEYWELL': 0,
    'HONEYWOOD': 0,
    'HONG': 0.47337278106508873,
    'HONGO': 0,
    'HONGSERMEIER': 0,
    'HONICAN': 0,
    'HONICK': 0,
    'HONICKER': 0,
    'HONIE': 0,
    'HONIG': 0,
    'HONIGFORD': 0,
    'HONIGMAN': 0,
    'HONIOUS': 0,
    'HONISH': 0,
    'HONKALA': 0,
    'HONKANEN': 0,
    'HONKE': 0,
    'HONKEN': 0,
    'HONKOMP': 0,
    'HONKONEN': 0,
    'HONL': 0,
    'HONMA': 0,
    'HONN': 0,
    'HONNEN': 0,
    'HONNOLD': 0,
    'HONNOLL': 0,
    'HONOHAN': 0,
    'HONOLD': 0,
    'HONOMICHL': 0,
    'HONOR': 0,
    'HONORA': 0,
    'HONORABLE': 0,
    'HONORAT': 0,
    'HONORATO': 0,
    'HONORE': 0,
    'HONORIO': 0,
    'HONOUR': 0,
    'HONRADO': 0,
    'HONRATH': 0,
    'HONRINE': 0,
    'HONRUD': 0,
    'HONS': 0,
    'HONSA': 0,
    'HONSAKER': 0,
    'HONSBERGER': 0,
    'HONSE': 0,
    'HONSEY': 0,
    'HONSINGER': 0,
    'HONSON': 0,
    'HONSTEIN': 0,
    'HONTS': 0,
    'HONTZ': 0,
    'HONZA': 0,
    'HONZELL': 0,
    'HONZIK': 0,
    'HOO': 0,
    'HOOBER': 0,
    'HOOBLER': 0,
    'HOOCK': 0,
    'HOOD': 0,
    'HOODA': 0,
    'HOODENPYLE': 0,
    'HOODY': 0,
    'HOOE': 0,
    'HOOEY': 0,
    'HOOF': 0,
    'HOOFARD': 0,
    'HOOFMAN': 0,
    'HOOFNAGLE': 0,
    'HOOG': 0,
    'HOOGASIAN': 0,
    'HOOGE': 0,
    'HOOGENBOOM': 0,
    'HOOGENDOORN': 0,
    'HOOGERHYDE': 0,
    'HOOGERWERF': 0,
    'HOOGESTRAAT': 0,
    'HOOGEVEEN': 0,
    'HOOGEWIND': 0,
    'HOOGHEEM': 0,
    'HOOGLAND': 0,
    'HOOGSTRA': 0,
    'HOOHULI': 0,
    'HOOK': 0,
    'HOOKANO': 0,
    'HOOKE': 0,
    'HOOKER': 0,
    'HOOKEY': 0,
    'HOOKFIN': 0,
    'HOOKHAM': 0,
    'HOOKOM': 0,
    'HOOKS': 0,
    'HOOKWAY': 0,
    'HOOL': 0,
    'HOOLAHAN': 0,
    'HOOLE': 0,
    'HOOLEY': 0,
    'HOOLIHAN': 0,
    'HOOLSEMA': 0,
    'HOOMES': 0,
    'HOON': 0,
    'HOONG': 0,
    'HOOP': 0,
    'HOOPAI': 0,
    'HOOPAUGH': 0,
    'HOOPENGARDNER': 0,
    'HOOPENGARNER': 0,
    'HOOPER': 0,
    'HOOPES': 0,
    'HOOPII': 0,
    'HOOPINGARNER': 0,
    'HOOPLE': 0,
    'HOOPMAN': 0,
    'HOOPS': 0,
    'HOORMANN': 0,
    'HOORN': 0,
    'HOORNSTRA': 0,
    'HOOS': 0,
    'HOOSE': 0,
    'HOOSEIN': 0,
    'HOOSER': 0,
    'HOOSHMAND': 0,
    'HOOSIER': 0,
    'HOOT': 0,
    'HOOTEN': 0,
    'HOOTER': 0,
    'HOOTMAN': 0,
    'HOOTON': 0,
    'HOOTS': 0,
    'HOOVEN': 0,
    'HOOVER': 0,
    'HOOVLER': 0,
    'HOOYER': 0,
    'HOOYMAN': 0,
    'HOP': 0,
    'HOPCROFT': 0,
    'HOPCUS': 0,
    'HOPE': 0.8459815874595671,
    'HOPECK': 0,
    'HOPELY': 0,
    'HOPEN': 0,
    'HOPER': 0,
    'HOPES': 0,
    'HOPEWELL': 0,
    'HOPEY': 0,
    'HOPF': 0,
    'HOPFAUF': 0,
    'HOPFE': 0,
    'HOPFENSPERGER': 0,
    'HOPFER': 0,
    'HOPFINGER': 0,
    'HOPFNER': 0,
    'HOPGOOD': 0,
    'HOPKA': 0,
    'HOPKE': 0,
    'HOPKIN': 0,
    'HOPKINS': 0,
    'HOPKINSON': 0,
    'HOPKO': 0,
    'HOPLER': 0,
    'HOPLEY': 0,
    'HOPMAN': 0,
    'HOPMANN': 0,
    'HOPP': 0,
    'HOPPA': 0,
    'HOPPE': 0,
    'HOPPEL': 0,
    'HOPPEN': 0,
    'HOPPENJAN': 0,
    'HOPPENJANS': 0,
    'HOPPENRATH': 0,
    'HOPPENS': 0,
    'HOPPENSTEDT': 0,
    'HOPPENWORTH': 0,
    'HOPPER': 0,
    'HOPPERS': 0,
    'HOPPERSTAD': 0,
    'HOPPERT': 0,
    'HOPPERTON': 0,
    'HOPPES': 0,
    'HOPPIE': 0,
    'HOPPIN': 0,
    'HOPPING': 0,
    'HOPPINS': 0,
    'HOPPIS': 0,
    'HOPPLE': 0,
    'HOPPMAN': 0,
    'HOPPMANN': 0,
    'HOPPOCK': 0,
    'HOPPOUGH': 0,
    'HOPPS': 0,
    'HOPSON': 0,
    'HOPSTER': 0,
    'HOPTA': 0,
    'HOPTON': 0,
    'HOPTOWIT': 0,
    'HOPWOOD': 0,
    'HOQUE': 0,
    'HOR': 0,
    'HORA': 0,
    'HORACE': 0.9822646657571623,
    'HORACEK': 0,
    'HORACIO': 1,
    'HORACK': 0,
    'HORAK': 0,
    'HORAL': 0,
    'HORALES': 0,
    'HORAN': 0,
    'HORATH': 0,
    'HORBACH': 0,
    'HORBAL': 0,
    'HORBERT': 0,
    'HORCASITAS': 0,
    'HORCH': 0,
    'HORCHAK': 0,
    'HORCHEM': 0,
    'HORCHER': 0,
    'HORCHLER': 0,
    'HORD': 0,
    'HORDE': 0,
    'HORDEN': 0,
    'HORDGE': 0,
    'HORDYK': 0,
    'HORE': 0,
    'HOREIS': 0,
    'HOREJS': 0,
    'HOREJSI': 0,
    'HOREL': 0,
    'HORELICA': 0,
    'HORELICK': 0,
    'HOREN': 0,
    'HORENSKY': 0,
    'HORENSTEIN': 0,
    'HORES': 0,
    'HORETSKI': 0,
    'HOREY': 0,
    'HORGAN': 0,
    'HORGEN': 0,
    'HORGER': 0,
    'HORI': 0,
    'HORICK': 0,
    'HORIE': 0,
    'HORIGAN': 0,
    'HORIHAN': 0,
    'HORII': 0,
    'HORIKAWA': 0,
    'HORIMOTO': 0,
    'HORIN': 0,
    'HORINE': 0,
    'HORINEK': 0,
    'HORIO': 0,
    'HORIST': 0,
    'HORITA': 0,
    'HORIUCHI': 0,
    'HORKA': 0,
    'HORKAN': 0,
    'HORKEY': 0,
    'HORKMAN': 0,
    'HORKY': 0,
    'HORLACHER': 0,
    'HORLANDER': 0,
    'HORLBACK': 0,
    'HORLEY': 0,
    'HORLICK': 0,
    'HORM': 0,
    'HORMAN': 0,
    'HORMANN': 0,
    'HORMEL': 0,
    'HORMELL': 0,
    'HORMOZI': 0,
    'HORMUTH': 0,
    'HORN': 0,
    'HORNA': 0,
    'HORNACEK': 0,
    'HORNACK': 0,
    'HORNADAY': 0,
    'HORNAK': 0,
    'HORNBACH': 0,
    'HORNBACHER': 0,
    'HORNBACK': 0,
    'HORNBAKER': 0,
    'HORNBEAK': 0,
    'HORNBECK': 0,
    'HORNBERG': 0,
    'HORNBERGER': 0,
    'HORNBLOWER': 0,
    'HORNBOSTEL': 0,
    'HORNBROOK': 0,
    'HORNBUCKLE': 0,
    'HORNBURG': 0,
    'HORNBY': 0,
    'HORNE': 0,
    'HORNECK': 0,
    'HORNECKER': 0,
    'HORNEDO': 0,
    'HORNEMAN': 0,
    'HORNER': 0,
    'HORNES': 0,
    'HORNESS': 0,
    'HORNEY': 0,
    'HORNFECK': 0,
    'HORNG': 0,
    'HORNIAK': 0,
    'HORNIBROOK': 0,
    'HORNICK': 0,
    'HORNICKEL': 0,
    'HORNIG': 0,
    'HORNIK': 0,
    'HORNING': 0,
    'HORNISH': 0,
    'HORNKOHL': 0,
    'HORNOF': 0,
    'HORNOR': 0,
    'HORNS': 0,
    'HORNSBY': 0,
    'HORNSETH': 0,
    'HORNSEY': 0,
    'HORNSTEIN': 0,
    'HORNSTRA': 0,
    'HORNUNG': 0,
    'HORNY': 0,
    'HORNYAK': 0,
    'HORODYSKI': 0,
    'HOROHO': 0,
    'HORONZY': 0,
    'HOROS': 0,
    'HOROSCHAK': 0,
    'HOROVITZ': 0,
    'HOROWITZ': 0,
    'HORR': 0,
    'HORRALL': 0,
    'HORRAS': 0,
    'HORRELL': 0,
    'HORRIDGE': 0,
    'HORRIGAN': 0,
    'HORRIS': 0,
    'HORRISON': 0,
    'HORROCKS': 0,
    'HORRY': 0,
    'HORSBURGH': 0,
    'HORSCH': 0,
    'HORSE': 0,
    'HORSEFIELD': 0,
    'HORSEMAN': 0,
    'HORSEY': 0,
    'HORSFALL': 0,
    'HORSFIELD': 0,
    'HORSFORD': 0,
    'HORSKY': 0,
    'HORSLEY': 0,
    'HORSMAN': 0,
    'HORSMON': 0,
    'HORSPOOL': 0,
    'HORST': 0,
    'HORSTING': 0,
    'HORSTKAMP': 0,
    'HORSTMAN': 0,
    'HORSTMANN': 0,
    'HORSTMEIER': 0,
    'HORSTMEYER': 0,
    'HORSWILL': 0,
    'HORT': 0,
    'HORTA': 0,
    'HORTEN': 0,
    'HORTENCIA': 1,
    'HORTENSE': 1,
    'HORTENSIA': 1,
    'HORTENSTINE': 0,
    'HORTER': 0,
    'HORTH': 0,
    'HORTIN': 0,
    'HORTING': 0,
    'HORTMAN': 0,
    'HORTON': 0,
    'HORVAT': 0,
    'HORVATH': 0,
    'HORVATICH': 0,
    'HORVATIN': 0,
    'HORVITZ': 0,
    'HORWAT': 0,
    'HORWATH': 0,
    'HORWATT': 0,
    'HORWEDEL': 0,
    'HORWICH': 0,
    'HORWITZ': 0,
    'HORWOOD': 0,
    'HOSA': 0,
    'HOSACK': 0,
    'HOSAFLOOK': 0,
    'HOSAIN': 0,
    'HOSAKA': 0,
    'HOSAN': 0,
    'HOSANG': 0,
    'HOSBACH': 0,
    'HOSBEIN': 0,
    'HOSCH': 0,
    'HOSCHAR': 0,
    'HOSCHEID': 0,
    'HOSCHEIT': 0,
    'HOSCHOUER': 0,
    'HOSE': 0,
    'HOSEA': 0.8583690987124464,
    'HOSEIN': 0,
    'HOSEK': 0,
    'HOSELTON': 0,
    'HOSEMANN': 0,
    'HOSENFELD': 0,
    'HOSER': 0,
    'HOSETH': 0,
    'HOSEY': 0,
    'HOSFELD': 0,
    'HOSFELT': 0,
    'HOSFIELD': 0,
    'HOSFORD': 0,
    'HOSGOOD': 0,
    'HOSHAL': 0,
    'HOSHALL': 0,
    'HOSHAW': 0,
    'HOSHI': 0,
    'HOSHINO': 0,
    'HOSHOR': 0,
    'HOSICK': 0,
    'HOSIE': 0,
    'HOSIER': 0,
    'HOSINO': 0,
    'HOSINSKI': 0,
    'HOSKEN': 0,
    'HOSKER': 0,
    'HOSKEY': 0,
    'HOSKIE': 0,
    'HOSKIN': 0,
    'HOSKING': 0,
    'HOSKINS': 0,
    'HOSKINSON': 0,
    'HOSKISON': 0,
    'HOSKO': 0,
    'HOSLER': 0,
    'HOSLEY': 0,
    'HOSMAN': 0,
    'HOSMER': 0,
    'HOSNER': 0,
    'HOSODA': 0,
    'HOSOKAWA': 0,
    'HOSP': 0,
    'HOSPEDALES': 0,
    'HOSPELHORN': 0,
    'HOSPODAR': 0,
    'HOSS': 0,
    'HOSSACK': 0,
    'HOSSAIN': 0,
    'HOSSE': 0,
    'HOSSEIN': 0,
    'HOSSEINI': 0,
    'HOSSEINZADEH': 0,
    'HOSSFELD': 0,
    'HOSSLER': 0,
    'HOSSLEY': 0,
    'HOSSMAN': 0,
    'HOST': 0,
    'HOSTA': 0,
    'HOSTAK': 0,
    'HOSTE': 0,
    'HOSTEEN': 0,
    'HOSTEN': 0,
    'HOSTER': 0,
    'HOSTERMAN': 0,
    'HOSTERT': 0,
    'HOSTETLER': 0,
    'HOSTETTER': 0,
    'HOSTETTLER': 0,
    'HOSTLER': 0,
    'HOSTO': 0,
    'HOSTON': 0,
    'HOSTRANDER': 0,
    'HOSTUTLER': 0,
    'HOSTY': 0,
    'HOT': 0,
    'HOTA': 0,
    'HOTALEN': 0,
    'HOTALING': 0,
    'HOTARD': 0,
    'HOTCH': 0,
    'HOTCHKIN': 0,
    'HOTCHKISS': 0,
    'HOTELLING': 0,
    'HOTH': 0,
    'HOTHAM': 0,
    'HOTHAN': 0,
    'HOTHEM': 0,
    'HOTHI': 0,
    'HOTI': 0,
    'HOTLE': 0,
    'HOTMER': 0,
    'HOTOP': 0,
    'HOTOPP': 0,
    'HOTOVEC': 0,
    'HOTOVY': 0,
    'HOTRUM': 0,
    'HOTSINPILLER': 0,
    'HOTSON': 0,
    'HOTT': 0,
    'HOTTA': 0,
    'HOTTE': 0,
    'HOTTEL': 0,
    'HOTTELL': 0,
    'HOTTEN': 0,
    'HOTTENDORF': 0,
    'HOTTENSTEIN': 0,
    'HOTTER': 0,
    'HOTTINGER': 0,
    'HOTTLE': 0,
    'HOTTMAN': 0,
    'HOTTMANN': 0,
    'HOTTOIS': 0,
    'HOTTON': 0,
    'HOTTOVY': 0,
    'HOTVEDT': 0,
    'HOTZ': 0,
    'HOTZE': 0,
    'HOTZEL': 0,
    'HOTZLER': 0,
    'HOU': 0,
    'HOUBEN': 0,
    'HOUCHEN': 0,
    'HOUCHENS': 0,
    'HOUCHIN': 0,
    'HOUCHINS': 0,
    'HOUCK': 0,
    'HOUDA': 0,
    'HOUDASHELT': 0,
    'HOUDE': 0,
    'HOUDEK': 0,
    'HOUDESHELL': 0,
    'HOUDYSHELL': 0,
    'HOUF': 0,
    'HOUFEK': 0,
    'HOUFF': 0,
    'HOUG': 0,
    'HOUGAARD': 0,
    'HOUGAN': 0,
    'HOUGARDY': 0,
    'HOUGAS': 0,
    'HOUGE': 0,
    'HOUGEN': 0,
    'HOUGH': 0,
    'HOUGHAM': 0,
    'HOUGHLAND': 0,
    'HOUGHT': 0,
    'HOUGHTALEN': 0,
    'HOUGHTALIN': 0,
    'HOUGHTALING': 0,
    'HOUGHTBY': 0,
    'HOUGHTELING': 0,
    'HOUGHTELLING': 0,
    'HOUGHTLEN': 0,
    'HOUGHTLING': 0,
    'HOUGHTON': 0,
    'HOUGLAND': 0,
    'HOUGLUM': 0,
    'HOUIN': 0,
    'HOUK': 0,
    'HOUKE': 0,
    'HOULAHAN': 0,
    'HOULAND': 0,
    'HOULBERG': 0,
    'HOULD': 0,
    'HOULDEN': 0,
    'HOULDSWORTH': 0,
    'HOULE': 0,
    'HOULETTE': 0,
    'HOULIHAN': 0,
    'HOULIS': 0,
    'HOULT': 0,
    'HOULTON': 0,
    'HOUMAN': 0,
    'HOUMES': 0,
    'HOUN': 0,
    'HOUNCHELL': 0,
    'HOUNG': 0,
    'HOUNSELL': 0,
    'HOUNSHELL': 0,
    'HOUP': 0,
    'HOUPE': 0,
    'HOUPPERT': 0,
    'HOUPT': 0,
    'HOUR': 0,
    'HOURANI': 0,
    'HOURICAN': 0,
    'HOURIGAN': 0,
    'HOURIHAN': 0,
    'HOUSAND': 0,
    'HOUSCH': 0,
    'HOUSDEN': 0,
    'HOUSE': 0,
    'HOUSEAL': 0,
    'HOUSEHOLDER': 0,
    'HOUSEKEEPER': 0,
    'HOUSEKNECHT': 0,
    'HOUSEL': 0,
    'HOUSELOG': 0,
    'HOUSEMAN': 0,
    'HOUSEN': 0,
    'HOUSENGA': 0,
    'HOUSEPIAN': 0,
    'HOUSER': 0,
    'HOUSERIGHT': 0,
    'HOUSETON': 0,
    'HOUSEWEART': 0,
    'HOUSEWORTH': 0,
    'HOUSEWRIGHT': 0,
    'HOUSEY': 0,
    'HOUSH': 0,
    'HOUSHMAND': 0,
    'HOUSHOLDER': 0,
    'HOUSKA': 0,
    'HOUSKEEPER': 0,
    'HOUSLER': 0,
    'HOUSLEY': 0,
    'HOUSMAN': 0,
    'HOUSNER': 0,
    'HOUST': 0,
    'HOUSTON': 0.28540849090260434,
    'HOUSWORTH': 0,
    'HOUT': 0,
    'HOUTCHENS': 0,
    'HOUTH': 0,
    'HOUTMAN': 0,
    'HOUTON': 0,
    'HOUTS': 0,
    'HOUTSMA': 0,
    'HOUTZ': 0,
    'HOUVENER': 0,
    'HOUX': 0,
    'HOUY': 0,
    'HOUZE': 0,
    'HOUZENGA': 0,
    'HOVAGIMIAN': 0,
    'HOVAN': 0,
    'HOVANCIK': 0,
    'HOVANEC': 0,
    'HOVANES': 0,
    'HOVANESIAN': 0,
    'HOVANESSIAN': 0,
    'HOVARTER': 0,
    'HOVATER': 0,
    'HOVATTER': 0,
    'HOVDA': 0,
    'HOVDE': 0,
    'HOVDEN': 0,
    'HOVE': 0,
    'HOVEKAMP': 0,
    'HOVEL': 0,
    'HOVELAND': 0,
    'HOVELL': 0,
    'HOVEN': 0,
    'HOVENCAMP': 0,
    'HOVENDEN': 0,
    'HOVENDICK': 0,
    'HOVENGA': 0,
    'HOVER': 0,
    'HOVERMALE': 0,
    'HOVERMAN': 0,
    'HOVERSON': 0,
    'HOVERSTEN': 0,
    'HOVERTER': 0,
    'HOVEST': 0,
    'HOVET': 0,
    'HOVEY': 0,
    'HOVHANNISYAN': 0,
    'HOVICK': 0,
    'HOVIK': 0,
    'HOVIND': 0,
    'HOVING': 0,
    'HOVINGA': 0,
    'HOVIOUS': 0,
    'HOVIS': 0,
    'HOVLAND': 0,
    'HOVNANIAN': 0,
    'HOVORKA': 0,
    'HOVSEPIAN': 0,
    'HOW': 0,
    'HOWA': 0,
    'HOWALD': 0,
    'HOWANIEC': 0,
    'HOWANITZ': 0,
    'HOWAR': 0,
    'HOWARD': 0.7088919710278934,
    'HOWARTER': 0,
    'HOWARTH': 0,
    'HOWAT': 0,
    'HOWATT': 0,
    'HOWAY': 0,
    'HOWBERT': 0,
    'HOWCROFT': 0,
    'HOWD': 0,
    'HOWDEN': 0,
    'HOWDER': 0,
    'HOWDERSHELT': 0,
    'HOWDESHELL': 0,
    'HOWDYSHELL': 0,
    'HOWE': 0,
    'HOWEL': 0,
    'HOWELL': 0,
    'HOWELLS': 0,
    'HOWEN': 0,
    'HOWENSTEIN': 0,
    'HOWENSTINE': 0,
    'HOWER': 0,
    'HOWERIN': 0,
    'HOWERTER': 0,
    'HOWERTON': 0,
    'HOWERY': 0,
    'HOWES': 0,
    'HOWETH': 0,
    'HOWETT': 0,
    'HOWEY': 0,
    'HOWICK': 0,
    'HOWIE': 0,
    'HOWIESON': 0,
    'HOWILER': 0,
    'HOWINGTON': 0,
    'HOWISON': 0,
    'HOWITT': 0,
    'HOWITZ': 0,
    'HOWK': 0,
    'HOWKINS': 0,
    'HOWL': 0,
    'HOWLAND': 0,
    'HOWLE': 0,
    'HOWLES': 0,
    'HOWLETT': 0,
    'HOWLEY': 0,
    'HOWLIN': 0,
    'HOWLING': 0,
    'HOWMAN': 0,
    'HOWORTH': 0,
    'HOWREN': 0,
    'HOWREY': 0,
    'HOWRIGAN': 0,
    'HOWRY': 0,
    'HOWSARE': 0,
    'HOWSDEN': 0,
    'HOWSE': 0,
    'HOWSER': 0,
    'HOWSLEY': 0,
    'HOWSMON': 0,
    'HOWSON': 0,
    'HOWTON': 0,
    'HOWZE': 0,
    'HOXHA': 0,
    'HOXIE': 0,
    'HOXIT': 0,
    'HOXSEY': 0,
    'HOXSIE': 0,
    'HOXTER': 0,
    'HOXWORTH': 0,
    'HOY': 0,
    'HOYA': 0,
    'HOYAL': 0,
    'HOYD': 0,
    'HOYDA': 0,
    'HOYE': 0,
    'HOYEM': 0,
    'HOYER': 0,
    'HOYES': 0,
    'HOYETT': 0,
    'HOYING': 0,
    'HOYLAND': 0,
    'HOYLE': 0,
    'HOYLER': 0,
    'HOYLES': 0,
    'HOYLMAN': 0,
    'HOYMAN': 0,
    'HOYME': 0,
    'HOYNE': 0,
    'HOYNES': 0,
    'HOYNG': 0,
    'HOYNOSKI': 0,
    'HOYO': 0,
    'HOYOS': 0,
    'HOYSRADT': 0,
    'HOYT': 0.34246575342465757,
    'HOYTE': 0,
    'HOYUM': 0,
    'HOZA': 0,
    'HOZE': 0,
    'HOZEMPA': 0,
    'HOZEY': 0,
    'HOZIAN': 0,
    'HRAB': 0,
    'HRABAK': 0,
    'HRABAL': 0,
    'HRABAN': 0,
    'HRABAR': 0,
    'HRABE': 0,
    'HRABIK': 0,
    'HRABOSKY': 0,
    'HRABOVSKY': 0,
    'HRACH': 0,
    'HRADECKY': 0,
    'HRADEK': 0,
    'HRADSKY': 0,
    'HRANAC': 0,
    'HRANEK': 0,
    'HRANICKY': 0,
    'HRBACEK': 0,
    'HRBEK': 0,
    'HRDINA': 0,
    'HRDLICKA': 0,
    'HRDY': 0,
    'HREHA': 0,
    'HREN': 0,
    'HRENCHIR': 0,
    'HRENKO': 0,
    'HRESKO': 0,
    'HRIBAL': 0,
    'HRIBAR': 0,
    'HRIC': 0,
    'HRICIK': 0,
    'HRICKO': 0,
    'HRIN': 0,
    'HRINDA': 0,
    'HRINKO': 0,
    'HRISTOV': 0,
    'HRITZ': 0,
    'HRIVNAK': 0,
    'HRNCIR': 0,
    'HRNCIRIK': 0,
    'HROBAK': 0,
    'HROBOWSKI': 0,
    'HROBSKY': 0,
    'HROCH': 0,
    'HROMADA': 0,
    'HROMADKA': 0,
    'HROMAS': 0,
    'HROMEK': 0,
    'HROMYAK': 0,
    'HRON': 0,
    'HRONCICH': 0,
    'HRONEC': 0,
    'HRONEK': 0,
    'HRONIS': 0,
    'HROUDA': 0,
    'HROVAT': 0,
    'HRUBES': 0,
    'HRUBY': 0,
    'HRUSKA': 0,
    'HRUSOVSKY': 0,
    'HRUZ': 0,
    'HRUZA': 0,
    'HRVATIN': 0,
    'HRYB': 0,
    'HRYCENKO': 0,
    'HRYCKO': 0,
    'HRYCYK': 0,
    'HRYNIEWICKI': 0,
    'HRYNIEWICZ': 0,
    'HRYNKO': 0,
    'HSI': 0,
    'HSIA': 0,
    'HSIANG': 0,
    'HSIAO': 0,
    'HSIEH': 0,
    'HSIN': 0,
    'HSING': 0,
    'HSIU': 1,
    'HSIUNG': 0,
    'HSU': 0,
    'HSUEH': 0,
    'HTAY': 0,
    'HU': 0,
    'HUA': 0,
    'HUACUJA': 0,
    'HUAMAN': 0,
    'HUAMANI': 0,
    'HUAN': 0,
    'HUANG': 0,
    'HUANOSTA': 0,
    'HUANTE': 0,
    'HUAPAYA': 0,
    'HUARACHA': 0,
    'HUARD': 0,
    'HUARTE': 0,
    'HUB': 0,
    'HUBA': 0,
    'HUBACEK': 0,
    'HUBACH': 0,
    'HUBACHER': 0,
    'HUBAL': 0,
    'HUBAND': 0,
    'HUBANKS': 0,
    'HUBARD': 0,
    'HUBARTT': 0,
    'HUBATCH': 0,
    'HUBAY': 0,
    'HUBB': 0,
    'HUBBARD': 0,
    'HUBBART': 0,
    'HUBBARTT': 0,
    'HUBBEL': 0,
    'HUBBELL': 0,
    'HUBBER': 0,
    'HUBBERT': 0,
    'HUBBLE': 0,
    'HUBBS': 0,
    'HUBBUCH': 0,
    'HUBBY': 0,
    'HUBE': 0,
    'HUBEL': 0,
    'HUBELE': 0,
    'HUBEN': 0,
    'HUBENAK': 0,
    'HUBENER': 0,
    'HUBENTHAL': 0,
    'HUBENY': 0,
    'HUBER': 0,
    'HUBERMAN': 0,
    'HUBERS': 0,
    'HUBERT': 0.9135628952916374,
    'HUBERTS': 0,
    'HUBERTUS': 0,
    'HUBERTY': 0,
    'HUBERTZ': 0,
    'HUBIAK': 0,
    'HUBIN': 0,
    'HUBING': 0,
    'HUBINGER': 0,
    'HUBKA': 0,
    'HUBL': 0,
    'HUBLE': 0,
    'HUBLER': 0,
    'HUBLEY': 0,
    'HUBMAN': 0,
    'HUBNER': 0,
    'HUBRED': 0,
    'HUBRICH': 0,
    'HUBSCH': 0,
    'HUBSCHER': 0,
    'HUBSCHMAN': 0,
    'HUBSCHMITT': 0,
    'HUCEK': 0,
    'HUCH': 0,
    'HUCHEL': 0,
    'HUCHINGSON': 0,
    'HUCK': 0,
    'HUCKABA': 0,
    'HUCKABAA': 0,
    'HUCKABAY': 0,
    'HUCKABEE': 0,
    'HUCKABEY': 0,
    'HUCKABONE': 0,
    'HUCKABY': 0,
    'HUCKE': 0,
    'HUCKEBA': 0,
    'HUCKEBY': 0,
    'HUCKELBERRY': 0,
    'HUCKELBY': 0,
    'HUCKER': 0,
    'HUCKESTEIN': 0,
    'HUCKFELDT': 0,
    'HUCKINS': 0,
    'HUCKLE': 0,
    'HUCKLEBERRY': 0,
    'HUCKLEBY': 0,
    'HUCKO': 0,
    'HUCKS': 0,
    'HUCKSTADT': 0,
    'HUCKSTEP': 0,
    'HUD': 0,
    'HUDA': 0,
    'HUDACEK': 0,
    'HUDACHEK': 0,
    'HUDACK': 0,
    'HUDACKO': 0,
    'HUDAK': 0,
    'HUDALLA': 0,
    'HUDD': 0,
    'HUDDLE': 0,
    'HUDDLESON': 0,
    'HUDDLESTON': 0,
    'HUDDLESTUN': 0,
    'HUDDY': 0,
    'HUDE': 0,
    'HUDEC': 0,
    'HUDECEK': 0,
    'HUDEK': 0,
    'HUDELSON': 0,
    'HUDEPOHL': 0,
    'HUDES': 0,
    'HUDGEL': 0,
    'HUDGEN': 0,
    'HUDGENS': 0,
    'HUDGEONS': 0,
    'HUDGES': 0,
    'HUDGIN': 0,
    'HUDGINS': 0,
    'HUDIBURG': 0,
    'HUDICK': 0,
    'HUDIK': 0,
    'HUDKINS': 0,
    'HUDLER': 0,
    'HUDLEY': 0,
    'HUDLIN': 0,
    'HUDLOW': 0,
    'HUDMAN': 0,
    'HUDMON': 0,
    'HUDNALL': 0,
    'HUDNELL': 0,
    'HUDNUT': 0,
    'HUDOBA': 0,
    'HUDOCK': 0,
    'HUDON': 0,
    'HUDSON': 0,
    'HUDSPETH': 0,
    'HUDY': 0,
    'HUDYMA': 0,
    'HUDZIAK': 0,
    'HUDZIK': 0,
    'HUDZINSKI': 0,
    'HUE': 0.7936507936507936,
    'HUEBBE': 0,
    'HUEBEL': 0,
    'HUEBENER': 0,
    'HUEBER': 0,
    'HUEBERT': 0,
    'HUEBL': 0,
    'HUEBLER': 0,
    'HUEBNER': 0,
    'HUEBSCH': 0,
    'HUEBSCHER': 0,
    'HUEBSCHMAN': 0,
    'HUECK': 0,
    'HUECKER': 0,
    'HUEDEPOHL': 0,
    'HUEFNER': 0,
    'HUEFTLE': 0,
    'HUEGEL': 0,
    'HUEGERICH': 0,
    'HUEHN': 0,
    'HUELL': 0,
    'HUELLE': 0,
    'HUELS': 0,
    'HUELSBECK': 0,
    'HUELSENBECK': 0,
    'HUELSING': 0,
    'HUELSKAMP': 0,
    'HUELSMAN': 0,
    'HUELSMANN': 0,
    'HUELSTER': 0,
    'HUEMANN': 0,
    'HUEMMER': 0,
    'HUEMOELLER': 0,
    'HUEMPFNER': 0,
    'HUEN': 0,
    'HUENE': 0,
    'HUENEFELD': 0,
    'HUENEKE': 0,
    'HUENERGARDT': 0,
    'HUENING': 0,
    'HUENINK': 0,
    'HUENNEKENS': 0,
    'HUEPENBECKER': 0,
    'HUERAMO': 0,
    'HUERD': 0,
    'HUERECA': 0,
    'HUERGO': 0,
    'HUERKAMP': 0,
    'HUERTA': 0,
    'HUERTAS': 0,
    'HUERTER': 0,
    'HUERTERO': 0,
    'HUERTH': 0,
    'HUERTO': 0,
    'HUERY': 0,
    'HUES': 0,
    'HUESCA': 0,
    'HUESER': 0,
    'HUESERS': 0,
    'HUESGEN': 0,
    'HUESING': 0,
    'HUESKE': 0,
    'HUESMAN': 0,
    'HUESMANN': 0,
    'HUESO': 0,
    'HUESSER': 0,
    'HUESTIS': 0,
    'HUESTON': 0,
    'HUET': 0,
    'HUETE': 0,
    'HUETER': 0,
    'HUETH': 0,
    'HUETHER': 0,
    'HUETT': 0,
    'HUETTE': 0,
    'HUETTEL': 0,
    'HUETTEMAN': 0,
    'HUETTER': 0,
    'HUETTL': 0,
    'HUETTNER': 0,
    'HUEWE': 0,
    'HUEWITT': 0,
    'HUEY': 0.5773672055427251,
    'HUEZO': 0,
    'HUF': 0,
    'HUFANA': 0,
    'HUFENDICK': 0,
    'HUFF': 0,
    'HUFFAKER': 0,
    'HUFFARD': 0,
    'HUFFER': 0,
    'HUFFERD': 0,
    'HUFFHINES': 0,
    'HUFFIN': 0,
    'HUFFINE': 0,
    'HUFFINES': 0,
    'HUFFINGTON': 0,
    'HUFFMAN': 0,
    'HUFFMASTER': 0,
    'HUFFMON': 0,
    'HUFFNAGLE': 0,
    'HUFFNER': 0,
    'HUFFORD': 0,
    'HUFFSMITH': 0,
    'HUFFSTETLER': 0,
    'HUFFSTICKLER': 0,
    'HUFFSTUTLER': 0,
    'HUFFSTUTTER': 0,
    'HUFFT': 0,
    'HUFFTY': 0,
    'HUFHAM': 0,
    'HUFMAN': 0,
    'HUFNAGEL': 0,
    'HUFNAGLE': 0,
    'HUFSTEDLER': 0,
    'HUFSTETLER': 0,
    'HUFT': 0,
    'HUFTON': 0,
    'HUFTY': 0,
    'HUG': 0,
    'HUGABOOM': 0,
    'HUGAN': 0,
    'HUGAR': 0,
    'HUGDAHL': 0,
    'HUGE': 0,
    'HUGEBACK': 0,
    'HUGEE': 0,
    'HUGEL': 0,
    'HUGEN': 0,
    'HUGENBERG': 0,
    'HUGER': 0,
    'HUGG': 0,
    'HUGGANS': 0,
    'HUGGARD': 0,
    'HUGGER': 0,
    'HUGGETT': 0,
    'HUGGHINS': 0,
    'HUGGIN': 0,
    'HUGGINS': 0,
    'HUGGLER': 0,
    'HUGGS': 0,
    'HUGH': 0.9920634920634921,
    'HUGHAN': 0,
    'HUGHART': 0,
    'HUGHBANKS': 0,
    'HUGHE': 0,
    'HUGHEN': 0,
    'HUGHES': 0,
    'HUGHETT': 0,
    'HUGHEY': 0,
    'HUGHIE': 0,
    'HUGHITT': 0,
    'HUGHLETT': 0,
    'HUGHLEY': 0,
    'HUGHS': 0,
    'HUGHSON': 0,
    'HUGHSTON': 0,
    'HUGI': 0,
    'HUGIE': 0,
    'HUGILL': 0,
    'HUGLE': 0,
    'HUGLEY': 0,
    'HUGO': 0.9551495016611296,
    'HUGUE': 0,
    'HUGUELET': 0,
    'HUGUELEY': 0,
    'HUGUELY': 0,
    'HUGUENARD': 0,
    'HUGUENIN': 0,
    'HUGUES': 0,
    'HUGUET': 0,
    'HUGUEZ': 0,
    'HUGULEY': 0,
    'HUGUNIN': 0,
    'HUGUS': 0,
    'HUH': 0,
    'HUHMAN': 0,
    'HUHN': 0,
    'HUHNKE': 0,
    'HUHTA': 0,
    'HUHTALA': 0,
    'HUI': 0.6048387096774194,
    'HUIBREGTSE': 0,
    'HUICHAPA': 0,
    'HUICOCHEA': 0,
    'HUIE': 0,
    'HUIETT': 0,
    'HUIHUI': 0,
    'HUINKER': 0,
    'HUIRAS': 0,
    'HUISENGA': 0,
    'HUISH': 0,
    'HUISINGA': 0,
    'HUISINGH': 0,
    'HUISKEN': 0,
    'HUISMAN': 0,
    'HUISMANN': 0,
    'HUIT': 0,
    'HUITING': 0,
    'HUITRON': 0,
    'HUITT': 0,
    'HUITZ': 0,
    'HUITZIL': 0,
    'HUIZAR': 0,
    'HUIZENGA': 0,
    'HUIZING': 0,
    'HUIZINGA': 0,
    'HUJAR': 0,
    'HUK': 0,
    'HUKARI': 0,
    'HUKE': 0,
    'HUKIC': 0,
    'HUKILL': 0,
    'HUKLE': 0,
    'HUKRIEDE': 0,
    'HUL': 0,
    'HULA': 0,
    'HULAK': 0,
    'HULAN': 0,
    'HULBERT': 0,
    'HULBURT': 0,
    'HULCE': 0,
    'HULCHER': 0,
    'HULCY': 0,
    'HULDA': 1,
    'HULEN': 0,
    'HULES': 0,
    'HULET': 0,
    'HULETT': 0,
    'HULETTE': 0,
    'HULEY': 0,
    'HULFACHOR': 0,
    'HULFORD': 0,
    'HULGAN': 0,
    'HULICK': 0,
    'HULIHAN': 0,
    'HULIN': 0,
    'HULING': 0,
    'HULINGS': 0,
    'HULINSKY': 0,
    'HULIT': 0,
    'HULITT': 0,
    'HULKA': 0,
    'HULKE': 0,
    'HULKER': 0,
    'HULL': 0,
    'HULLA': 0,
    'HULLABY': 0,
    'HULLANDER': 0,
    'HULLENDER': 0,
    'HULLER': 0,
    'HULLETT': 0,
    'HULLETTE': 0,
    'HULLEY': 0,
    'HULLFISH': 0,
    'HULLIBERGER': 0,
    'HULLIHAN': 0,
    'HULLIHEN': 0,
    'HULLINGER': 0,
    'HULLINGS': 0,
    'HULLMAN': 0,
    'HULLS': 0,
    'HULLUM': 0,
    'HULM': 0,
    'HULME': 0,
    'HULMES': 0,
    'HULON': 0,
    'HULQUIST': 0,
    'HULS': 0,
    'HULSART': 0,
    'HULSCHER': 0,
    'HULSE': 0,
    'HULSEBERG': 0,
    'HULSEBUS': 0,
    'HULSEMAN': 0,
    'HULSEN': 0,
    'HULSER': 0,
    'HULSEY': 0,
    'HULSHIZER': 0,
    'HULSHOF': 0,
    'HULSING': 0,
    'HULSIZER': 0,
    'HULSLANDER': 0,
    'HULSMAN': 0,
    'HULST': 0,
    'HULSTEIN': 0,
    'HULSTINE': 0,
    'HULSTROM': 0,
    'HULT': 0,
    'HULTBERG': 0,
    'HULTEEN': 0,
    'HULTEN': 0,
    'HULTGREN': 0,
    'HULTIN': 0,
    'HULTINE': 0,
    'HULTING': 0,
    'HULTMAN': 0,
    'HULTON': 0,
    'HULTQUIST': 0,
    'HULTS': 0,
    'HULTSTRAND': 0,
    'HULTZ': 0,
    'HULVER': 0,
    'HULVEY': 0,
    'HUM': 0,
    'HUMA': 0,
    'HUMAN': 0,
    'HUMANN': 0,
    'HUMASON': 0,
    'HUMAYUN': 0,
    'HUMBACH': 0,
    'HUMBARD': 0,
    'HUMBARGER': 0,
    'HUMBEL': 0,
    'HUMBER': 0,
    'HUMBERD': 0,
    'HUMBERGER': 0,
    'HUMBERS': 0,
    'HUMBERSON': 0,
    'HUMBERSTONE': 0,
    'HUMBERT': 0,
    'HUMBERTO': 0.9977827050997782,
    'HUMBERTSON': 0,
    'HUMBIRD': 0,
    'HUMBLE': 0,
    'HUMBLES': 0,
    'HUMBURG': 0,
    'HUMBYRD': 0,
    'HUME': 0,
    'HUMEL': 0,
    'HUMEN': 0,
    'HUMENICK': 0,
    'HUMENIK': 0,
    'HUMENIUK': 0,
    'HUMER': 0,
    'HUMERICK': 0,
    'HUMERICKHOUSE': 0,
    'HUMES': 0,
    'HUMESTON': 0,
    'HUMFELD': 0,
    'HUMFLEET': 0,
    'HUMINSKI': 0,
    'HUMISTON': 0,
    'HUMKE': 0,
    'HUML': 0,
    'HUMLICEK': 0,
    'HUMM': 0,
    'HUMMEL': 0,
    'HUMMELL': 0,
    'HUMMER': 0,
    'HUMMERT': 0,
    'HUMMINGBIRD': 0,
    'HUMMON': 0,
    'HUMMONS': 0,
    'HUMPAL': 0,
    'HUMPERT': 0,
    'HUMPHERY': 0,
    'HUMPHERYS': 0,
    'HUMPHRES': 0,
    'HUMPHRESS': 0,
    'HUMPHREVILLE': 0,
    'HUMPHREY': 0,
    'HUMPHREYS': 0,
    'HUMPHRIES': 0,
    'HUMPHRIS': 0,
    'HUMPHRY': 0,
    'HUMPHRYES': 0,
    'HUMPHRYS': 0,
    'HUMPREY': 0,
    'HUMPRIES': 0,
    'HUMRICH': 0,
    'HUMS': 0,
    'HUMSTON': 0,
    'HUN': 0,
    'HUNCKLER': 0,
    'HUND': 0,
    'HUNDAL': 0,
    'HUNDELT': 0,
    'HUNDEMER': 0,
    'HUNDERTMARK': 0,
    'HUNDL': 0,
    'HUNDLEY': 0,
    'HUNDRED': 0,
    'HUNDT': 0,
    'HUNE': 0,
    'HUNEKE': 0,
    'HUNER': 0,
    'HUNEYCUTT': 0,
    'HUNG': 0.7774538386783285,
    'HUNGATE': 0,
    'HUNGER': 0,
    'HUNGERFORD': 0,
    'HUNGERMAN': 0,
    'HUNGLER': 0,
    'HUNGRIA': 0,
    'HUNING': 0,
    'HUNINGHAKE': 0,
    'HUNKA': 0,
    'HUNKAPILLER': 0,
    'HUNKE': 0,
    'HUNKELE': 0,
    'HUNKELER': 0,
    'HUNKER': 0,
    'HUNKIN': 0,
    'HUNKINS': 0,
    'HUNKLER': 0,
    'HUNLEY': 0,
    'HUNN': 0,
    'HUNNEL': 0,
    'HUNNELL': 0,
    'HUNNEWELL': 0,
    'HUNNICUT': 0,
    'HUNNICUTT': 0,
    'HUNNINGS': 0,
    'HUNOLD': 0,
    'HUNOLT': 0,
    'HUNSAKER': 0,
    'HUNSBERGER': 0,
    'HUNSCHE': 0,
    'HUNSECKER': 0,
    'HUNSICKER': 0,
    'HUNSINGER': 0,
    'HUNSLEY': 0,
    'HUNSPERGER': 0,
    'HUNSTAD': 0,
    'HUNSTIGER': 0,
    'HUNSUCKER': 0,
    'HUNT': 0,
    'HUNTE': 0,
    'HUNTEMAN': 0,
    'HUNTER': 0.13586956521739127,
    'HUNTIMER': 0,
    'HUNTING': 0,
    'HUNTINGTON': 0,
    'HUNTLEY': 0,
    'HUNTLY': 0,
    'HUNTON': 0,
    'HUNTOON': 0,
    'HUNTRESS': 0,
    'HUNTS': 0,
    'HUNTSBERGER': 0,
    'HUNTSBERRY': 0,
    'HUNTSINGER': 0,
    'HUNTSMAN': 0,
    'HUNTT': 0,
    'HUNTTING': 0,
    'HUNTWORK': 0,
    'HUNTZ': 0,
    'HUNTZBERRY': 0,
    'HUNTZINGER': 0,
    'HUNYADI': 0,
    'HUNYADY': 0,
    'HUNZEKER': 0,
    'HUNZIKER': 0,
    'HUNZINGER': 0,
    'HUO': 0,
    'HUON': 0,
    'HUONG': 0.970873786407767,
    'HUOT': 0,
    'HUOTARI': 0,
    'HUOVINEN': 0,
    'HUPE': 0,
    'HUPERT': 0,
    'HUPF': 0,
    'HUPFELD': 0,
    'HUPFER': 0,
    'HUPKA': 0,
    'HUPKE': 0,
    'HUPMAN': 0,
    'HUPP': 0,
    'HUPPE': 0,
    'HUPPENTHAL': 0,
    'HUPPER': 0,
    'HUPPERT': 0,
    'HUPPMAN': 0,
    'HUPRICH': 0,
    'HUQ': 0,
    'HUR': 0,
    'HURA': 0,
    'HURBAN': 0,
    'HURBERT': 0,
    'HURD': 0,
    'HURDA': 0,
    'HURDER': 0,
    'HURDLE': 0,
    'HURDT': 0,
    'HUREWITZ': 0,
    'HUREY': 0,
    'HURFF': 0,
    'HURFORD': 0,
    'HURKMANS': 0,
    'HURL': 0,
    'HURLA': 0,
    'HURLBERT': 0,
    'HURLBURT': 0,
    'HURLBUT': 0,
    'HURLBUTT': 0,
    'HURLEBAUS': 0,
    'HURLER': 0,
    'HURLES': 0,
    'HURLESS': 0,
    'HURLEY': 0,
    'HURLIMAN': 0,
    'HURLING': 0,
    'HURLOCK': 0,
    'HURLOCKER': 0,
    'HURLOW': 0,
    'HURM': 0,
    'HURN': 0,
    'HURNDON': 0,
    'HURNE': 0,
    'HURNER': 0,
    'HURNEY': 0,
    'HURNI': 0,
    'HURNS': 0,
    'HURO': 0,
    'HURON': 0,
    'HUROWITZ': 0,
    'HURR': 0,
    'HURRAY': 0,
    'HURRELBRINK': 0,
    'HURRELL': 0,
    'HURREN': 0,
    'HURREY': 0,
    'HURRLE': 0,
    'HURRY': 0,
    'HURSE': 0,
    'HURSEY': 0,
    'HURSH': 0,
    'HURSHMAN': 0,
    'HURSMAN': 0,
    'HURSON': 0,
    'HURST': 0,
    'HURSTON': 0,
    'HURT': 0,
    'HURTA': 0,
    'HURTADO': 0,
    'HURTARTE': 0,
    'HURTE': 0,
    'HURTEAU': 0,
    'HURTER': 0,
    'HURTGEN': 0,
    'HURTH': 0,
    'HURTIG': 0,
    'HURTON': 0,
    'HURTS': 0,
    'HURTT': 0,
    'HURTUBISE': 0,
    'HURTZ': 0,
    'HURVITZ': 0,
    'HURWITZ': 0,
    'HURYN': 0,
    'HURYSZ': 0,
    'HURZELER': 0,
    'HUS': 0,
    'HUSA': 0,
    'HUSAIN': 0,
    'HUSAK': 0,
    'HUSAR': 0,
    'HUSARIK': 0,
    'HUSARY': 0,
    'HUSBAND': 0,
    'HUSBANDS': 0,
    'HUSBY': 0,
    'HUSCH': 0,
    'HUSCHER': 0,
    'HUSCHKA': 0,
    'HUSCHKE': 0,
    'HUSCHLE': 0,
    'HUSE': 0,
    'HUSEBY': 0,
    'HUSEIN': 0,
    'HUSEINOVIC': 0,
    'HUSEK': 0,
    'HUSELTON': 0,
    'HUSEMAN': 0,
    'HUSEMANN': 0,
    'HUSEN': 0,
    'HUSER': 0,
    'HUSET': 0,
    'HUSETH': 0,
    'HUSFELT': 0,
    'HUSH': 0,
    'HUSHER': 0,
    'HUSHOUR': 0,
    'HUSIC': 0,
    'HUSICK': 0,
    'HUSIDIC': 0,
    'HUSING': 0,
    'HUSK': 0,
    'HUSKA': 0,
    'HUSKE': 0,
    'HUSKETH': 0,
    'HUSKEY': 0,
    'HUSKIC': 0,
    'HUSKIE': 0,
    'HUSKIN': 0,
    'HUSKINS': 0,
    'HUSKINSON': 0,
    'HUSKISSON': 0,
    'HUSKO': 0,
    'HUSKY': 0,
    'HUSLER': 0,
    'HUSLEY': 0,
    'HUSLIG': 0,
    'HUSMAN': 0,
    'HUSMANN': 0,
    'HUSNICK': 0,
    'HUSNIK': 0,
    'HUSO': 0,
    'HUSOM': 0,
    'HUSON': 0,
    'HUSONG': 0,
    'HUSS': 0,
    'HUSSAIN': 0,
    'HUSSAINI': 0,
    'HUSSAN': 0,
    'HUSSAR': 0,
    'HUSSEIN': 0,
    'HUSSEINI': 0,
    'HUSSELL': 0,
    'HUSSEN': 0,
    'HUSSER': 0,
    'HUSSEY': 0,
    'HUSSIAN': 0,
    'HUSSIEN': 0,
    'HUSSIN': 0,
    'HUSSING': 0,
    'HUSSLEIN': 0,
    'HUSSMAN': 0,
    'HUSSMANN': 0,
    'HUSSON': 0,
    'HUSSONG': 0,
    'HUSSUNG': 0,
    'HUST': 0,
    'HUSTAD': 0,
    'HUSTAK': 0,
    'HUSTEAD': 0,
    'HUSTED': 0,
    'HUSTEDDE': 0,
    'HUSTEDT': 0,
    'HUSTER': 0,
    'HUSTING': 0,
    'HUSTIS': 0,
    'HUSTLER': 0,
    'HUSTON': 0,
    'HUSTUS': 0,
    'HUSZAR': 0,
    'HUT': 0,
    'HUTCH': 0,
    'HUTCHASON': 0,
    'HUTCHCRAFT': 0,
    'HUTCHCROFT': 0,
    'HUTCHEN': 0,
    'HUTCHENS': 0,
    'HUTCHEON': 0,
    'HUTCHERSON': 0,
    'HUTCHES': 0,
    'HUTCHESON': 0,
    'HUTCHIN': 0,
    'HUTCHING': 0,
    'HUTCHINGS': 0,
    'HUTCHINGSON': 0,
    'HUTCHINS': 0,
    'HUTCHINSON': 0,
    'HUTCHISON': 0,
    'HUTCHISSON': 0,
    'HUTCHKO': 0,
    'HUTCHSON': 0,
    'HUTE': 0,
    'HUTER': 0,
    'HUTFLES': 0,
    'HUTFLESS': 0,
    'HUTH': 0,
    'HUTHER': 0,
    'HUTHMACHER': 0,
    'HUTKA': 0,
    'HUTKOWSKI': 0,
    'HUTLEY': 0,
    'HUTMACHER': 0,
    'HUTMAN': 0,
    'HUTNER': 0,
    'HUTNICK': 0,
    'HUTNIK': 0,
    'HUTSELL': 0,
    'HUTSENPILLER': 0,
    'HUTSKO': 0,
    'HUTSLAR': 0,
    'HUTSLER': 0,
    'HUTSON': 0,
    'HUTT': 0,
    'HUTTA': 0,
    'HUTTEN': 0,
    'HUTTER': 0,
    'HUTTERER': 0,
    'HUTTING': 0,
    'HUTTINGER': 0,
    'HUTTMAN': 0,
    'HUTTNER': 0,
    'HUTTO': 0,
    'HUTTON': 0,
    'HUTTS': 0,
    'HUTTUNEN': 0,
    'HUTYRA': 0,
    'HUTZ': 0,
    'HUTZEL': 0,
    'HUTZELL': 0,
    'HUTZELMAN': 0,
    'HUTZENBILER': 0,
    'HUTZLER': 0,
    'HUTZLEY': 0,
    'HUUS': 0,
    'HUVAL': 0,
    'HUVANE': 0,
    'HUVER': 0,
    'HUWA': 0,
    'HUWE': 0,
    'HUWER': 0,
    'HUX': 0,
    'HUXEL': 0,
    'HUXFORD': 0,
    'HUXHOLD': 0,
    'HUXLEY': 0,
    'HUXMAN': 0,
    'HUXOLL': 0,
    'HUXTABLE': 0,
    'HUY': 0,
    'HUYARD': 0,
    'HUYCK': 0,
    'HUYCKE': 0,
    'HUYEN': 0,
    'HUYETT': 0,
    'HUYGHE': 0,
    'HUYLER': 0,
    'HUYNA': 0,
    'HUYNH': 0,
    'HUYS': 0,
    'HUYSER': 0,
    'HUYSMAN': 0,
    'HUZAR': 0,
    'HUZZIE': 0,
    'HVEZDA': 0,
    'HVIDSTEN': 0,
    'HVIZDAK': 0,
    'HVIZDOS': 0,
    'HWA': 0.9090909090909091,
    'HWANG': 0,
    'HWANGBO': 0,
    'HWEE': 0,
    'HWONG': 0,
    'HWU': 0,
    'HY': 0,
    'HYACINTH': 0.9803921568627452,
    'HYACINTHE': 0,
    'HYAMS': 0,
    'HYATT': 0,
    'HYATTE': 0,
    'HYBARGER': 0,
    'HYBERGER': 0,
    'HYBL': 0,
    'HYBNER': 0,
    'HYCHE': 0,
    'HYDAR': 0,
    'HYDE': 0,
    'HYDEN': 0,
    'HYDER': 0,
    'HYDES': 0,
    'HYDO': 0,
    'HYDOCK': 0,
    'HYDORN': 0,
    'HYDRICK': 0,
    'HYDRO': 0,
    'HYDUK': 0,
    'HYDUKE': 0,
    'HYE': 0.9523809523809523,
    'HYER': 0,
    'HYERS': 0,
    'HYETT': 0,
    'HYING': 0,
    'HYINK': 0,
    'HYJEK': 0,
    'HYKE': 0,
    'HYKEL': 0,
    'HYKES': 0,
    'HYLA': 0,
    'HYLAN': 0,
    'HYLAND': 0,
    'HYLANDER': 0,
    'HYLBERT': 0,
    'HYLE': 0,
    'HYLEMON': 0,
    'HYLEN': 0,
    'HYLER': 0,
    'HYLES': 0,
    'HYLINSKI': 0,
    'HYLKEMA': 0,
    'HYLLA': 0,
    'HYLLAND': 0,
    'HYLTON': 0,
    'HYMA': 0,
    'HYMAN': 0.48721071863581,
    'HYMANS': 0,
    'HYMANSON': 0,
    'HYMAS': 0,
    'HYMEL': 0,
    'HYMEN': 0,
    'HYMER': 0,
    'HYMERS': 0,
    'HYMES': 0,
    'HYMON': 0,
    'HYMORE': 0,
    'HYMOWITZ': 0,
    'HYND': 0,
    'HYNDMAN': 0,
    'HYNDS': 0,
    'HYNE': 0,
    'HYNEK': 0,
    'HYNEMAN': 0,
    'HYNES': 0,
    'HYNICK': 0,
    'HYNSON': 0,
    'HYNUM': 0,
    'HYO': 1,
    'HYON': 0.9389671361502347,
    'HYPES': 0,
    'HYPOLITE': 0,
    'HYPPOLITE': 0,
    'HYRE': 0,
    'HYRKAS': 0,
    'HYRNE': 0,
    'HYSAW': 0,
    'HYSELL': 0,
    'HYSENI': 0,
    'HYSER': 0,
    'HYSINGER': 0,
    'HYSKA': 0,
    'HYSLER': 0,
    'HYSLIP': 0,
    'HYSLOP': 0,
    'HYSLOPE': 0,
    'HYSMITH': 0,
    'HYSOM': 0,
    'HYSON': 0,
    'HYSONG': 0,
    'HYSTAD': 0,
    'HYTE': 0,
    'HYTEN': 0,
    'HYTER': 0,
    'HYTINEN': 0,
    'HYTREK': 0,
    'HYUN': 0.7490636704119851,
    'HYVARINEN': 0,
    'HYVONEN': 0,
    'HYZER': 0,
    'HYZY': 0,
    'IABONI': 0,
    'IACAMPO': 0,
    'IACCARINO': 0,
    'IACCINO': 0,
    'IACHETTA': 0,
    'IACINO': 0,
    'IACOBACCI': 0,
    'IACOBELLI': 0,
    'IACOBELLIS': 0,
    'IACOBONI': 0,
    'IACOBUCCI': 0,
    'IACONA': 0,
    'IACONE': 0,
    'IACONELLI': 0,
    'IACONETTI': 0,
    'IACONIS': 0,
    'IACONO': 0,
    'IACOPELLI': 0,
    'IACOVELLI': 0,
    'IACOVETTA': 0,
    'IACOVETTI': 0,
    'IACOVIELLO': 0,
    'IACOVINO': 0,
    'IACOVONE': 0,
    'IACULLO': 0,
    'IADANZA': 0,
    'IADAROLA': 0,
    'IADEVAIA': 0,
    'IADICICCO': 0,
    'IADONISI': 0,
    'IAEA': 0,
    'IAFELICE': 0,
    'IAFRATE': 0,
    'IAGULLI': 0,
    'IAIA': 0,
    'IAMELE': 0,
    'IAMES': 0,
    'IAMMARINO': 0,
    'IAMS': 0,
    'IAN': 0.9991079393398752,
    'IANACONE': 0,
    'IANCU': 0,
    'IANDOLI': 0,
    'IANDOLO': 0,
    'IANELLI': 0,
    'IANELLO': 0,
    'IANIRO': 0,
    'IANNACCI': 0,
    'IANNACCONE': 0,
    'IANNACO': 0,
    'IANNACONE': 0,
    'IANNARELLI': 0,
    'IANNARINO': 0,
    'IANNARONE': 0,
    'IANNAZZI': 0,
    'IANNAZZO': 0,
    'IANNELLA': 0,
    'IANNELLI': 0,
    'IANNELLO': 0,
    'IANNETTA': 0,
    'IANNI': 0,
    'IANNICELLI': 0,
    'IANNIELLO': 0,
    'IANNINI': 0,
    'IANNITELLI': 0,
    'IANNITTI': 0,
    'IANNO': 0,
    'IANNONE': 0,
    'IANNOTTA': 0,
    'IANNOTTI': 0,
    'IANNUCCI': 0,
    'IANNUCCILLI': 0,
    'IANNUZZELLI': 0,
    'IANNUZZI': 0,
    'IANNUZZO': 0,
    'IANSON': 0,
    'IANTORNO': 0,
    'IANTOSCA': 0,
    'IANUZZI': 0,
    'IAPALUCCI': 0,
    'IAQUINTA': 0,
    'IAQUINTO': 0,
    'IARIA': 0,
    'IAROCCI': 0,
    'IAROSSI': 0,
    'IARROBINO': 0,
    'IARUSSI': 0,
    'IASIELLO': 0,
    'IAVARONE': 0,
    'IAZZETTA': 0,
    'IBA': 0,
    'IBACH': 0,
    'IBANA': 0,
    'IBANES': 0,
    'IBANEZ': 0,
    'IBARA': 0,
    'IBARGUEN': 0,
    'IBARRA': 0,
    'IBARRIA': 0,
    'IBARROLA': 0,
    'IBARRONDO': 0,
    'IBAY': 0,
    'IBBERSON': 0,
    'IBBETSON': 0,
    'IBBITSON': 0,
    'IBBOTSON': 0,
    'IBBS': 0,
    'IBE': 0,
    'IBEH': 0,
    'IBEKWE': 0,
    'IBEN': 0,
    'IBERG': 0,
    'IBERT': 0,
    'IBEY': 0,
    'IBISON': 0,
    'IBOA': 0,
    'IBOLD': 0,
    'IBRAGIMOV': 0,
    'IBRAHAM': 0,
    'IBRAHEEM': 0,
    'IBRAHIM': 0,
    'IBRAHIMI': 0,
    'IBRAHIMOVIC': 0,
    'IBSEN': 0,
    'IBUADO': 0,
    'IBURG': 0,
    'ICARD': 0,
    'ICART': 0,
    'ICASIANO': 0,
    'ICAZA': 0,
    'ICE': 0,
    'ICEMAN': 0,
    'ICENHOUR': 0,
    'ICENHOWER': 0,
    'ICENOGLE': 0,
    'ICHIKAWA': 0,
    'ICHIMURA': 0,
    'ICHINOSE': 0,
    'ICHIYAMA': 0,
    'ICKE': 0,
    'ICKERT': 0,
    'ICKES': 0,
    'ICKLER': 0,
    'IDA': 0.9982235005498687,
    'IDALGO': 0,
    'IDALIA': 1,
    'IDALSKI': 0,
    'IDARRAGA': 0,
    'IDDEEN': 0,
    'IDDINGS': 0,
    'IDDINS': 0,
    'IDE': 0,
    'IDEHEN': 0,
    'IDEKER': 0,
    'IDELL': 0.9302325581395349,
    'IDELLA': 1,
    'IDELSON': 0,
    'IDEMA': 0,
    'IDEMOTO': 0,
    'IDEN': 0,
    'IDEUS': 0,
    'IDIAQUEZ': 0,
    'IDICA': 0,
    'IDING': 0,
    'IDLAND': 0,
    'IDLE': 0,
    'IDLEBIRD': 0,
    'IDLEMAN': 0,
    'IDLER': 0,
    'IDLETT': 0,
    'IDLEWINE': 0,
    'IDOL': 0,
    'IDOM': 0,
    'IDONE': 0,
    'IDONI': 0,
    'IDOWU': 0,
    'IDREES': 0,
    'IDRIS': 0,
    'IDRISS': 0,
    'IDRIZI': 0,
    'IDROGO': 0,
    'IDROVO': 0,
    'IDSO': 0,
    'IDZIAK': 0,
    'IDZIK': 0,
    'IDZIKOWSKI': 0,
    'IE': 0,
    'IEE': 0,
    'IEHL': 0,
    'IEM': 0,
    'IEMMA': 0,
    'IENG': 0,
    'IERACI': 0,
    'IERARDI': 0,
    'IEREMIA': 0,
    'IERONIMO': 0,
    'IERVOLINO': 0,
    'IESHA': 1,
    'IEZZI': 0,
    'IFFERT': 0,
    'IFFLAND': 0,
    'IFFRIG': 0,
    'IFFT': 0,
    'IFILL': 0,
    'IFKOVITS': 0,
    'IFLAND': 0,
    'IFTIKHAR': 0,
    'IGARASHI': 0,
    'IGARTA': 0,
    'IGARTUA': 0,
    'IGAWA': 0,
    'IGBOKWE': 0,
    'IGE': 0,
    'IGEL': 0,
    'IGIELSKI': 0,
    'IGL': 0,
    'IGLEHART': 0,
    'IGLEHEART': 0,
    'IGLER': 0,
    'IGLESIA': 0,
    'IGLESIAS': 0,
    'IGNACE': 0,
    'IGNACIA': 1,
    'IGNACIO': 0.9338205440519691,
    'IGNACZAK': 0,
    'IGNAGNI': 0,
    'IGNARSKI': 0,
    'IGNAS': 0,
    'IGNASH': 0,
    'IGNASIAK': 0,
    'IGNASZEWSKI': 0,
    'IGNAT': 0,
    'IGNATIUS': 0,
    'IGNATOV': 0,
    'IGNATOVICH': 0,
    'IGNATOWICZ': 0,
    'IGNATOWSKI': 0,
    'IGNATZ': 0,
    'IGNELZI': 0,
    'IGNERI': 0,
    'IGNOFFO': 0,
    'IGNOWSKI': 0,
    'IGO': 0,
    'IGOE': 0,
    'IGOU': 0,
    'IGUCHI': 0,
    'IGWE': 0,
    'IHA': 0,
    'IHARA': 0,
    'IHASZ': 0,
    'IHDE': 0,
    'IHEANACHO': 0,
    'IHLE': 0,
    'IHLENFELD': 0,
    'IHLENFELDT': 0,
    'IHLER': 0,
    'IHLI': 0,
    'IHM': 0,
    'IHNAT': 0,
    'IHNEN': 0,
    'IHNKEN': 0,
    'IHNS': 0,
    'IHRIE': 0,
    'IHRIG': 0,
    'IHRKE': 0,
    'IHRY': 0,
    'II': 0,
    'IIAMS': 0,
    'IIDA': 0,
    'III': 0,
    'IIJIMA': 0,
    'IIZUKA': 0,
    'IJAMES': 0,
    'IJAMS': 0,
    'IJAZ': 0,
    'IKA': 0,
    'IKARD': 0,
    'IKARI': 0,
    'IKE': 0.9049773755656109,
    'IKEDA': 0,
    'IKEGAMI': 0,
    'IKEHARA': 0,
    'IKELER': 0,
    'IKEMIRE': 0,
    'IKEMOTO': 0,
    'IKEN': 0,
    'IKENBERRY': 0,
    'IKER': 0,
    'IKERD': 0,
    'IKNER': 0,
    'IKOLA': 0,
    'IKRAM': 0,
    'IKUTA': 0,
    'ILA': 1,
    'ILACQUA': 0,
    'ILAGAN': 0,
    'ILAN': 0,
    'ILANA': 1,
    'ILANO': 0,
    'ILAO': 0,
    'ILAR': 0,
    'ILARDI': 0,
    'ILARDO': 0,
    'ILARIA': 0,
    'ILARRAZA': 0,
    'ILAS': 0,
    'ILDA': 1,
    'ILDEFONSO': 0,
    'ILDERTON': 0,
    'ILE': 0,
    'ILEANA': 1,
    'ILEEN': 1,
    'ILENE': 1,
    'ILER': 0,
    'ILES': 0,
    'ILEY': 0,
    'ILG': 0,
    'ILGEN': 0,
    'ILGENFRITZ': 0,
    'ILGES': 0,
    'ILI': 0,
    'ILIANA': 1,
    'ILIC': 0,
    'ILICH': 0,
    'ILIE': 0,
    'ILIESCU': 0,
    'ILIEV': 0,
    'ILIEVSKI': 0,
    'ILIFF': 0,
    'ILIN': 0,
    'ILIOPOULOS': 0,
    'ILJAZI': 0,
    'ILK': 0,
    'ILKO': 0,
    'ILL': 0,
    'ILLA': 0.9090909090909091,
    'ILLAN': 0,
    'ILLAS': 0,
    'ILLE': 0,
    'ILLER': 0,
    'ILLES': 0,
    'ILLESCAS': 0,
    'ILLG': 0,
    'ILLGEN': 0,
    'ILLI': 0,
    'ILLIAN': 0,
    'ILLIANO': 0,
    'ILLICH': 0,
    'ILLICK': 0,
    'ILLIDGE': 0,
    'ILLIES': 0,
    'ILLIG': 0,
    'ILLING': 0,
    'ILLINGSWORTH': 0,
    'ILLINGWORTH': 0,
    'ILLMAN': 0,
    'ILLSLEY': 0,
    'ILLUM': 0,
    'ILLUZZI': 0,
    'ILLY': 0,
    'ILLYES': 0,
    'ILNICKI': 0,
    'ILOG': 0,
    'ILONA': 1,
    'ILSE': 0.9803921568627452,
    'ILSLEY': 0,
    'ILSTRUP': 0,
    'ILTEN': 0,
    'ILTIS': 0,
    'ILUMINADA': 1,
    'ILUSTRE': 0,
    'ILVENTO': 0,
    'ILYAS': 0,
    'ILYAYEV': 0,
    'IM': 0,
    'IMA': 1,
    'IMADA': 0,
    'IMAI': 0,
    'IMAIZUMI': 0,
    'IMAM': 0,
    'IMAMOTO': 0,
    'IMAMOVIC': 0,
    'IMAMURA': 0,
    'IMAN': 0,
    'IMANI': 0,
    'IMBACH': 0,
    'IMBER': 0,
    'IMBERI': 0,
    'IMBERT': 0,
    'IMBERY': 0,
    'IMBESI': 0,
    'IMBIMBO': 0,
    'IMBLER': 0,
    'IMBODEN': 0,
    'IMBODY': 0,
    'IMBORNONE': 0,
    'IMBRAGUGLIO': 0,
    'IMBRIACO': 0,
    'IMBRIALE': 0,
    'IMBRIANI': 0,
    'IMBRIANO': 0,
    'IMBRIGLIO': 0,
    'IMBRO': 0,
    'IMBROGNO': 0,
    'IMBRUGLIA': 0,
    'IMBURGIA': 0,
    'IMBUS': 0,
    'IMDIEKE': 0,
    'IMEL': 0,
    'IMELDA': 1,
    'IMER': 0,
    'IMERI': 0,
    'IMES': 0,
    'IMESON': 0,
    'IMFELD': 0,
    'IMGRUND': 0,
    'IMHOF': 0,
    'IMHOFF': 0,
    'IMHOLT': 0,
    'IMHOLTE': 0,
    'IMIG': 0,
    'IMLACH': 0,
    'IMLAY': 0,
    'IMLER': 0,
    'IMM': 0,
    'IMME': 0,
    'IMMEDIATO': 0,
    'IMMEKUS': 0,
    'IMMEL': 0,
    'IMMELL': 0,
    'IMMENSCHUH': 0,
    'IMMER': 0,
    'IMMERFALL': 0,
    'IMMERMAN': 0,
    'IMMING': 0,
    'IMMLER': 0,
    'IMMONEN': 0,
    'IMMOOS': 0,
    'IMMORDINO': 0,
    'IMMORMINO': 0,
    'IMO': 0,
    'IMOGENE': 1,
    'IMONDI': 0,
    'IMOTO': 0,
    'IMPAGLIAZZO': 0,
    'IMPARATO': 0,
    'IMPASTATO': 0,
    'IMPELLIZERI': 0,
    'IMPELLIZZERI': 0,
    'IMPERATI': 0,
    'IMPERATO': 0,
    'IMPERATORE': 0,
    'IMPERATRICE': 0,
    'IMPERIAL': 0,
    'IMPERIALE': 0,
    'IMPERIO': 0,
    'IMPEY': 0,
    'IMPINK': 0,
    'IMPOLA': 0,
    'IMPROTA': 0,
    'IMPSON': 0,
    'IMRAN': 0,
    'IMRE': 0,
    'IMRIE': 0,
    'IMS': 0,
    'IMSDAHL': 0,
    'IMSLAND': 0,
    'IMTIAZ': 0,
    'IMURA': 0,
    'IMUS': 0,
    'IMWALLE': 0,
    'IN': 0.8771929824561404,
    'INA': 0.996102208748376,
    'INABA': 0,
    'INABINET': 0,
    'INABINETT': 0,
    'INABINETTE': 0,
    'INABNIT': 0,
    'INABNITT': 0,
    'INACIO': 0,
    'INADA': 0,
    'INAFUKU': 0,
    'INAGAKI': 0,
    'INAMA': 0,
    'INAMAGUA': 0,
    'INAMDAR': 0,
    'INAMINE': 0,
    'INBODEN': 0,
    'INBODY': 0,
    'INCANDELA': 0,
    'INCANTALUPO': 0,
    'INCARDONA': 0,
    'INCARNATO': 0,
    'INCE': 0,
    'INCERTO': 0,
    'INCH': 0,
    'INCHAUSTI': 0,
    'INCHES': 0,
    'INCIONG': 0,
    'INCITTI': 0,
    'INCLAN': 0,
    'INCOGNITO': 0,
    'INCOLLINGO': 0,
    'INCONTRO': 0,
    'INCORVAIA': 0,
    'INCORVIA': 0,
    'INDA': 0,
    'INDAHL': 0,
    'INDALECIO': 0,
    'INDELICATO': 0,
    'INDERBITZEN': 0,
    'INDERBITZIN': 0,
    'INDERLIED': 0,
    'INDERMILL': 0,
    'INDERMUEHLE': 0,
    'INDERRIEDEN': 0,
    'INDIA': 0.9917355371900827,
    'INDIG': 0,
    'INDIHAR': 0,
    'INDIRA': 1,
    'INDORATO': 0,
    'INDORF': 0,
    'INDOVINA': 0,
    'INDOVINO': 0,
    'INDRA': 0,
    'INDYK': 0,
    'INEICHEN': 0,
    'INELL': 1,
    'INES': 0.9584664536741214,
    'INESON': 0,
    'INESS': 0,
    'INESTROZA': 0,
    'INEZ': 0.9983047654925599,
    'INFANGER': 0,
    'INFANTE': 0,
    'INFANTES': 0,
    'INFANTI': 0,
    'INFANTINO': 0,
    'INFANTOLINO': 0,
    'INFANZON': 0,
    'INFELD': 0,
    'INFELISE': 0,
    'INFERRERA': 0,
    'INFIELD': 0,
    'INFINGER': 0,
    'INFRANCA': 0,
    'INFURNA': 0,
    'INFUSINO': 0,
    'ING': 0,
    'INGA': 0.9287925696594428,
    'INGALA': 0,
    'INGALL': 0,
    'INGALLS': 0,
    'INGALSBE': 0,
    'INGAMELLS': 0,
    'INGARGIOLA': 0,
    'INGBER': 0,
    'INGBERG': 0,
    'INGBRETSON': 0,
    'INGE': 0.8350730688935282,
    'INGEBORG': 1,
    'INGEBRETSEN': 0,
    'INGEBRETSON': 0,
    'INGEBRIGTSEN': 0,
    'INGEBRITSON': 0,
    'INGEGNERI': 0,
    'INGEL': 0,
    'INGELS': 0,
    'INGEMAN': 0,
    'INGEMI': 0,
    'INGENITO': 0,
    'INGENTHRON': 0,
    'INGER': 0.9523809523809523,
    'INGERICK': 0,
    'INGERMAN': 0,
    'INGERSOL': 0,
    'INGERSOLL': 0,
    'INGERSON': 0,
    'INGHAM': 0,
    'INGHRAM': 0,
    'INGINO': 0,
    'INGISON': 0,
    'INGLAND': 0,
    'INGLE': 0,
    'INGLEBY': 0,
    'INGLEDUE': 0,
    'INGLEHART': 0,
    'INGLES': 0,
    'INGLESBY': 0,
    'INGLESE': 0,
    'INGLESTON': 0,
    'INGLET': 0,
    'INGLETON': 0,
    'INGLETT': 0,
    'INGLEY': 0,
    'INGLIMA': 0,
    'INGLIN': 0,
    'INGLING': 0,
    'INGLIS': 0,
    'INGLISH': 0,
    'INGMAN': 0,
    'INGMIRE': 0,
    'INGO': 0,
    'INGOGLIA': 0,
    'INGOLD': 0,
    'INGOLDSBY': 0,
    'INGOLIA': 0,
    'INGRAFFIA': 0,
    'INGRAHAM': 0,
    'INGRAHM': 0,
    'INGRALDI': 0,
    'INGRAM': 0,
    'INGRAN': 0,
    'INGRANDE': 0,
    'INGRAO': 0,
    'INGRASSIA': 0,
    'INGRID': 1,
    'INGRIM': 0,
    'INGRO': 0,
    'INGRUM': 0,
    'INGS': 0,
    'INGSTAD': 0,
    'INGUAGGIATO': 0,
    'INGUANZO': 0,
    'INGUI': 0,
    'INGUITO': 0,
    'INGVALSON': 0,
    'INGWELL': 0,
    'INGWERSEN': 0,
    'INGWERSON': 0,
    'INIESTRA': 0,
    'INIGO': 0,
    'INIGUEZ': 0,
    'INIQUEZ': 0,
    'INIRIO': 0,
    'INK': 0,
    'INKEL': 0,
    'INKELAAR': 0,
    'INKLEBARGER': 0,
    'INKLEY': 0,
    'INKPEN': 0,
    'INKROTT': 0,
    'INKS': 0,
    'INKSTER': 0,
    'INLOES': 0,
    'INLOW': 0,
    'INMAN': 0,
    'INMATE': 0,
    'INMON': 0,
    'INN': 0,
    'INNAMORATO': 0,
    'INNELLA': 0,
    'INNERARITY': 0,
    'INNERS': 0,
    'INNERST': 0,
    'INNES': 0,
    'INNESS': 0,
    'INNIGER': 0,
    'INNIS': 0,
    'INNISS': 0,
    'INNOCENT': 0,
    'INNOCENTI': 0,
    'INNOCENZI': 0,
    'INNS': 0,
    'INO': 0,
    'INOA': 0,
    'INOCENCIA': 1,
    'INOCENCIO': 0,
    'INOCENTE': 0,
    'INOCENTES': 0,
    'INOJOSA': 0,
    'INOSTROZA': 0,
    'INOUE': 0,
    'INOUYE': 0,
    'INSALACO': 0,
    'INSALL': 0,
    'INSANA': 0,
    'INSCHO': 0,
    'INSCO': 0,
    'INSCOE': 0,
    'INSCORE': 0,
    'INSEL': 0,
    'INSELMAN': 0,
    'INSELMANN': 0,
    'INSERRA': 0,
    'INSIGNARES': 0,
    'INSINGA': 0,
    'INSINNA': 0,
    'INSIXIENGMAY': 0,
    'INSKEEP': 0,
    'INSKIP': 0,
    'INSKO': 0,
    'INSLEE': 0,
    'INSLEY': 0,
    'INSOGNA': 0,
    'INSTONE': 0,
    'INSUA': 0,
    'INTAGLIATA': 0,
    'INTAL': 0,
    'INTELISANO': 0,
    'INTEMANN': 0,
    'INTERDONATO': 0,
    'INTERIAN': 0,
    'INTERIAND': 0,
    'INTERIANO': 0,
    'INTERLANDI': 0,
    'INTERMILL': 0,
    'INTERNICOLA': 0,
    'INTERRANTE': 0,
    'INTHAVONG': 0,
    'INTHAVONGSA': 0,
    'INTHIRATH': 0,
    'INTHISANE': 0,
    'INTHISONE': 0,
    'INTIHAR': 0,
    'INTILE': 0,
    'INTILI': 0,
    'INTRAVAIA': 0,
    'INTRAVIA': 0,
    'INTRIAGO': 0,
    'INTRIERI': 0,
    'INTROCASO': 0,
    'INTVELD': 0,
    'INVERSO': 0,
    'INWARDS': 0,
    'INWOOD': 0,
    'INYANG': 0,
    'INZANA': 0,
    'INZANO': 0,
    'INZER': 0,
    'INZERILLO': 0,
    'INZINNA': 0,
    'INZUNZA': 0,
    'IOANE': 0,
    'IOANNIDES': 0,
    'IOANNIDIS': 0,
    'IOANNOU': 0,
    'IOBST': 0,
    'IOCCA': 0,
    'IOCCO': 0,
    'IODICE': 0,
    'IOERGER': 0,
    'IOFFE': 0,
    'IOLA': 1,
    'IOLI': 0,
    'ION': 0,
    'IONA': 0.9929078014184397,
    'IONADI': 0,
    'IONE': 1,
    'IONESCU': 0,
    'IONGI': 0,
    'IONITA': 0,
    'IONTA': 0,
    'IOPPOLO': 0,
    'IORG': 0,
    'IORI': 0,
    'IORILLO': 0,
    'IORIO': 0,
    'IORIZZO': 0,
    'IOSEFA': 0,
    'IOSSI': 0,
    'IOSUA': 0,
    'IOSUE': 0,
    'IOTT': 0,
    'IOVANNA': 0,
    'IOVINE': 0,
    'IOVINELLI': 0,
    'IOVINO': 0,
    'IOZZI': 0,
    'IOZZIA': 0,
    'IOZZO': 0,
    'IP': 0,
    'IPARRAGUIRRE': 0,
    'IPEMA': 0,
    'IPINA': 0,
    'IPOCK': 0,
    'IPPEL': 0,
    'IPPOLITI': 0,
    'IPPOLITO': 0,
    'IPSEN': 0,
    'IPSON': 0,
    'IQBAL': 0,
    'IRA': 0.9969325153374233,
    'IRACE': 0,
    'IRACHETA': 0,
    'IRACI': 0,
    'IRAETA': 0,
    'IRAGGI': 0,
    'IRAHETA': 0,
    'IRAIDA': 1,
    'IRAN': 0,
    'IRANI': 0,
    'IRAOLA': 0,
    'IRAVANI': 0,
    'IRBY': 0,
    'IREDALE': 0,
    'IRELAN': 0,
    'IRELAND': 0,
    'IRENA': 1,
    'IRENE': 0.9994447529150472,
    'IRESON': 0,
    'IRETA': 0,
    'IRETON': 0,
    'IREY': 0,
    'IRFAN': 0,
    'IRGANG': 0,
    'IRGENS': 0,
    'IRIARTE': 0,
    'IRIAS': 0,
    'IRIBARREN': 0,
    'IRIBE': 0,
    'IRICK': 0,
    'IRIE': 0,
    'IRIGOYEN': 0,
    'IRINA': 1,
    'IRINEO': 0,
    'IRION': 0,
    'IRIONS': 0,
    'IRIS': 0.9981851179673321,
    'IRISH': 0.42826552462526774,
    'IRIZARRI': 0,
    'IRIZARRY': 0,
    'IRIZARY': 0,
    'IRLA': 0,
    'IRLAND': 0,
    'IRLANDA': 0,
    'IRLAS': 0,
    'IRLBECK': 0,
    'IRLE': 0,
    'IRLMEIER': 0,
    'IRMA': 1,
    'IRMEN': 0,
    'IRMER': 0,
    'IRMGARD': 1,
    'IRMITER': 0,
    'IRMSCHER': 0,
    'IRON': 0,
    'IRONCLOUD': 0,
    'IRONHAWK': 0,
    'IRONMONGER': 0,
    'IRONS': 0,
    'IRONSHELL': 0,
    'IRONSIDE': 0,
    'IRR': 0,
    'IRRA': 0,
    'IRRER': 0,
    'IRRERA': 0,
    'IRRGANG': 0,
    'IRRIZARRY': 0,
    'IRRIZARY': 0,
    'IRSHAD': 0,
    'IRSIK': 0,
    'IRUEGAS': 0,
    'IRVAN': 0,
    'IRVEN': 0,
    'IRVIN': 0.7220216606498195,
    'IRVINE': 0,
    'IRVING': 0.833600512984931,
    'IRWIN': 0.41398344066237347,
    'IRZYK': 0,
    'ISA': 0.8733624454148472,
    'ISAAC': 0.8939526730937774,
    'ISAACKS': 0,
    'ISAACMAN': 0,
    'ISAACS': 0,
    'ISAACSON': 0,
    'ISAAK': 0,
    'ISABEL': 0.9935506362210214,
    'ISABELL': 0.9132420091324202,
    'ISABELLA': 0.9557945041816011,
    'ISABELLE': 0.9803921568627451,
    'ISAC': 0,
    'ISACCO': 0,
    'ISACKSON': 0,
    'ISACSON': 0,
    'ISADORA': 1,
    'ISADORE': 0,
    'ISAGUIRRE': 0,
    'ISAIA': 0,
    'ISAIAH': 0.9847806624888094,
    'ISAIAS': 0.9881422924901185,
    'ISAIS': 0,
    'ISAK': 0,
    'ISAKOV': 0,
    'ISAKOVIC': 0,
    'ISAKSEN': 0,
    'ISAKSON': 0,
    'ISAKSSON': 0,
    'ISALES': 0,
    'ISALY': 0,
    'ISAM': 0,
    'ISAMAN': 0,
    'ISAS': 0,
    'ISASI': 0,
    'ISAURA': 1,
    'ISAYAN': 0,
    'ISAZA': 0,
    'ISBEL': 0,
    'ISBELL': 0,
    'ISBERG': 0,
    'ISBERNER': 0,
    'ISBILL': 0,
    'ISBISTER': 0,
    'ISBY': 0,
    'ISCH': 0,
    'ISCHE': 0,
    'ISCHY': 0,
    'ISDELL': 0,
    'ISE': 0,
    'ISELA': 1,
    'ISELE': 0,
    'ISELER': 0,
    'ISELEY': 0,
    'ISELI': 0,
    'ISELIN': 0,
    'ISELT': 0,
    'ISELY': 0,
    'ISEMAN': 0,
    'ISEMANN': 0,
    'ISEMINGER': 0,
    'ISEN': 0,
    'ISENBARGER': 0,
    'ISENBART': 0,
    'ISENBERG': 0,
    'ISENBERGER': 0,
    'ISENBURG': 0,
    'ISENHART': 0,
    'ISENHOUR': 0,
    'ISENHOWER': 0,
    'ISENNOCK': 0,
    'ISENSEE': 0,
    'ISER': 0,
    'ISERI': 0,
    'ISERMAN': 0,
    'ISERMANN': 0,
    'ISERN': 0,
    'ISERNIA': 0,
    'ISERT': 0,
    'ISETT': 0,
    'ISGAR': 0,
    'ISGETT': 0,
    'ISGITT': 0,
    'ISGRIG': 0,
    'ISGRIGG': 0,
    'ISGRO': 0,
    'ISH': 0,
    'ISHAK': 0,
    'ISHAM': 0,
    'ISHAQ': 0,
    'ISHAQUE': 0,
    'ISHEE': 0,
    'ISHERWOOD': 0,
    'ISHIBASHI': 0,
    'ISHIDA': 0,
    'ISHIGURO': 0,
    'ISHIHARA': 0,
    'ISHII': 0,
    'ISHIKAWA': 0,
    'ISHIKI': 0,
    'ISHIMARU': 0,
    'ISHIMOTO': 0,
    'ISHINO': 0,
    'ISHIYAMA': 0,
    'ISHIZAKI': 0,
    'ISHIZU': 0,
    'ISHIZUKA': 0,
    'ISHKANIAN': 0,
    'ISHLER': 0,
    'ISHMAEL': 0,
    'ISHMAN': 0,
    'ISHMON': 0,
    'ISHO': 0,
    'ISIAH': 1,
    'ISIDOR': 0,
    'ISIDORE': 0,
    'ISIDORO': 0,
    'ISIDRA': 1,
    'ISIDRO': 0.9523809523809523,
    'ISIK': 0,
    'ISIMINGER': 0,
    'ISING': 0,
    'ISIORDIA': 0,
    'ISIP': 0,
    'ISIS': 1,
    'ISITT': 0,
    'ISKANDAR': 0,
    'ISKANDER': 0,
    'ISKE': 0,
    'ISKENDERIAN': 0,
    'ISKHAKOV': 0,
    'ISKI': 0,
    'ISKOWITZ': 0,
    'ISKRA': 0,
    'ISLA': 0,
    'ISLAM': 0,
    'ISLAMI': 0,
    'ISLAMOVIC': 0,
    'ISLAND': 0,
    'ISLAR': 0,
    'ISLAS': 0,
    'ISLAVA': 0,
    'ISLE': 0,
    'ISLEIB': 0,
    'ISLER': 0,
    'ISLES': 0,
    'ISLEY': 0,
    'ISMA': 0,
    'ISMAEL': 0.9896907216494845,
    'ISMAIL': 0,
    'ISMAILI': 0,
    'ISMAN': 0,
    'ISME': 0,
    'ISMERT': 0,
    'ISNER': 0,
    'ISOBE': 0,
    'ISOBEL': 1,
    'ISODA': 0,
    'ISOLA': 0,
    'ISOLDI': 0,
    'ISOM': 0,
    'ISOME': 0,
    'ISON': 0,
    'ISONO': 0,
    'ISORDIA': 0,
    'ISPAS': 0,
    'ISQUIERDO': 0,
    'ISRAEL': 0.889453621346887,
    'ISRAELI': 0,
    'ISRAELS': 0,
    'ISRAELSEN': 0,
    'ISRAELSON': 0,
    'ISRAILOV': 0,
    'ISRANI': 0,
    'ISREAL': 0.9216589861751152,
    'ISRINGHAUSEN': 0,
    'ISROW': 0,
    'ISSA': 0,
    'ISSAC': 0.9587727708533078,
    'ISSACS': 0,
    'ISSAK': 0,
    'ISSE': 0,
    'ISSEL': 0,
    'ISSLER': 0,
    'ISTA': 0,
    'ISTAS': 0,
    'ISTRE': 0,
    'ISTVAN': 0,
    'ISZARD': 0,
    'ISZLER': 0,
    'ITA': 0,
    'ITAGAKI': 0,
    'ITALIA': 0,
    'ITALIANO': 0,
    'ITAMI': 0,
    'ITANI': 0,
    'ITCHON': 0,
    'ITEN': 0,
    'ITES': 0,
    'ITH': 0,
    'ITHIER': 0,
    'ITKIN': 0,
    'ITNYRE': 0,
    'ITO': 0,
    'ITOH': 0,
    'ITOW': 0,
    'ITRI': 0,
    'ITSCHNER': 0,
    'ITSKOVICH': 0,
    'ITSON': 0,
    'ITTEL': 0,
    'ITTER': 0,
    'ITTERLY': 0,
    'ITTNER': 0,
    'ITTY': 0,
    'ITUARTE': 0,
    'ITURBE': 0,
    'ITURBIDE': 0,
    'ITURRALDE': 0,
    'ITURRIAGA': 0,
    'ITURRINO': 0,
    'ITWARU': 0,
    'ITZ': 0,
    'ITZEN': 0,
    'ITZKOWITZ': 0,
    'IU': 0,
    'IULA': 0,
    'IULIANO': 0,
    'IULIUCCI': 0,
    'IULO': 0,
    'IURATO': 0,
    'IUZZOLINO': 0,
    'IV': 0,
    'IVA': 1,
    'IVALDI': 0,
    'IVAN': 0.9899140829286515,
    'IVANA': 1,
    'IVANCIC': 0,
    'IVANCICH': 0,
    'IVANEZ': 0,
    'IVANHOE': 0,
    'IVANIC': 0,
    'IVANKOVICH': 0,
    'IVANOFF': 0,
    'IVANOV': 0,
    'IVANOVA': 0,
    'IVANOVIC': 0,
    'IVANOVICH': 0,
    'IVANS': 0,
    'IVANY': 0,
    'IVARSON': 0,
    'IVASKA': 0,
    'IVELISSE': 1,
    'IVEN': 0,
    'IVENER': 0,
    'IVENS': 0,
    'IVERS': 0,
    'IVERSEN': 0,
    'IVERSON': 0,
    'IVERY': 0,
    'IVES': 0,
    'IVESON': 0,
    'IVESTER': 0,
    'IVETTE': 1,
    'IVEY': 0.10683760683760685,
    'IVEZAJ': 0,
    'IVEZIC': 0,
    'IVIE': 0,
    'IVINS': 0,
    'IVISON': 0,
    'IVKOVIC': 0,
    'IVKOVICH': 0,
    'IVONE': 0,
    'IVONNE': 1,
    'IVORY': 0.8172362555720655,
    'IVY': 0.7718282682103231,
    'IWABUCHI': 0,
    'IWAHASHI': 0,
    'IWAI': 0,
    'IWAKI': 0,
    'IWAMASA': 0,
    'IWAMI': 0,
    'IWAMOTO': 0,
    'IWAMURA': 0,
    'IWAN': 0,
    'IWANAGA': 0,
    'IWANE': 0,
    'IWANICKI': 0,
    'IWANIEC': 0,
    'IWANIUK': 0,
    'IWANOW': 0,
    'IWANOWSKI': 0,
    'IWANSKI': 0,
    'IWASA': 0,
    'IWASAKI': 0,
    'IWASE': 0,
    'IWASHITA': 0,
    'IWASKO': 0,
    'IWATA': 0,
    'IWEMA': 0,
    'IWEN': 0,
    'IWINSKI': 0,
    'IX': 0,
    'IXCOY': 0,
    'IXTA': 0,
    'IYENGAR': 0,
    'IYER': 0,
    'IZA': 0,
    'IZADI': 0,
    'IZAGUIRRE': 0,
    'IZAK': 0,
    'IZARD': 0,
    'IZARRARAS': 0,
    'IZARRARAZ': 0,
    'IZATT': 0,
    'IZAWA': 0,
    'IZAZAGA': 0,
    'IZBICKI': 0,
    'IZDEBSKI': 0,
    'IZELL': 0,
    'IZEN': 0,
    'IZER': 0,
    'IZETTA': 1,
    'IZLAR': 0,
    'IZOLA': 1,
    'IZON': 0,
    'IZOR': 0,
    'IZQUIERDO': 0,
    'IZRAILOV': 0,
    'IZSAK': 0,
    'IZUMI': 0,
    'IZURIETA': 0,
    'IZYK': 0,
    'IZZARD': 0,
    'IZZI': 0,
    'IZZO': 0,
    'JA': 0.9174311926605505,
    'JAACKS': 0,
    'JAAFAR': 0,
    'JAAP': 0,
    'JABAAY': 0,
    'JABALI': 0,
    'JABAR': 0,
    'JABARA': 0,
    'JABARI': 0,
    'JABAUT': 0,
    'JABBAR': 0,
    'JABBARI': 0,
    'JABBIE': 0,
    'JABBOUR': 0,
    'JABEEN': 0,
    'JABER': 0,
    'JABERG': 0,
    'JABIN': 0,
    'JABLECKI': 0,
    'JABLON': 0,
    'JABLONKA': 0,
    'JABLONOWSKI': 0,
    'JABLONSKI': 0,
    'JABLONSKY': 0,
    'JABLOW': 0,
    'JABOUIN': 0,
    'JABOUR': 0,
    'JABR': 0,
    'JABRI': 0,
    'JABRO': 0,
    'JABS': 0,
    'JABUSCH': 0,
    'JACA': 0,
    'JACALYN': 1,
    'JACARUSO': 0,
    'JACAS': 0,
    'JACCARD': 0,
    'JACCARINO': 0,
    'JACE': 0,
    'JACEK': 0,
    'JACELYN': 1,
    'JACH': 0,
    'JACHETTA': 0,
    'JACHIM': 0,
    'JACHIMIAK': 0,
    'JACHIMOWICZ': 0,
    'JACHYM': 0,
    'JACINDA': 1,
    'JACINTA': 1,
    'JACINTHO': 0,
    'JACINTO': 0.7168458781362007,
    'JACK': 0.9838413400168124,
    'JACKA': 0,
    'JACKE': 0,
    'JACKEL': 0,
    'JACKELEN': 0,
    'JACKELINE': 1,
    'JACKELS': 0,
    'JACKELYN': 1,
    'JACKETT': 0,
    'JACKEY': 0,
    'JACKI': 1,
    'JACKIE': 0.9993237658727177,
    'JACKIEWICZ': 0,
    'JACKINS': 0,
    'JACKLE': 0,
    'JACKLEY': 0,
    'JACKLIN': 0,
    'JACKLING': 0,
    'JACKLITCH': 0,
    'JACKLYN': 0.995575221238938,
    'JACKMAN': 0,
    'JACKMON': 0,
    'JACKO': 0,
    'JACKOLA': 0,
    'JACKON': 0,
    'JACKOSN': 0,
    'JACKOVICH': 0,
    'JACKOWIAK': 0,
    'JACKOWITZ': 0,
    'JACKOWSKI': 0,
    'JACKQUELINE': 1,
    'JACKS': 0,
    'JACKSOM': 0,
    'JACKSON': 0.04634457189201715,
    'JACKY': 0,
    'JACLYN': 1,
    'JACO': 0,
    'JACOB': 0.9541984732824428,
    'JACOBA': 0,
    'JACOBE': 0,
    'JACOBELLI': 0,
    'JACOBELLIS': 0,
    'JACOBER': 0,
    'JACOBI': 0,
    'JACOBITZ': 0,
    'JACOBO': 0,
    'JACOBOSKI': 0,
    'JACOBOWITZ': 0,
    'JACOBS': 0,
    'JACOBSEN': 0,
    'JACOBSMA': 0,
    'JACOBSMEYER': 0,
    'JACOBSOHN': 0,
    'JACOBSON': 0,
    'JACOBSSON': 0,
    'JACOBUCCI': 0,
    'JACOBUS': 0,
    'JACOBY': 0,
    'JACOCKS': 0,
    'JACOME': 0,
    'JACOMET': 0,
    'JACOMINO': 0,
    'JACONETTI': 0,
    'JACONSKI': 0,
    'JACOT': 0,
    'JACOVINO': 0,
    'JACOWAY': 0,
    'JACOX': 0,
    'JACOY': 0,
    'JACQUALINE': 1,
    'JACQUARD': 0,
    'JACQUART': 0,
    'JACQUAY': 0,
    'JACQUE': 0.9560229445506692,
    'JACQUELIN': 1,
    'JACQUELINE': 0.9997807498355623,
    'JACQUELYN': 1,
    'JACQUELYNE': 1,
    'JACQUELYNN': 1,
    'JACQUEMIN': 0,
    'JACQUES': 0.625,
    'JACQUET': 0,
    'JACQUETTA': 1,
    'JACQUETTE': 0,
    'JACQUEZ': 0,
    'JACQUI': 1,
    'JACQUIE': 1,
    'JACQUILINE': 1,
    'JACQUIN': 0,
    'JACQUINOT': 0,
    'JACQULINE': 1,
    'JACQULYN': 1,
    'JACQUOT': 0,
    'JACSON': 0,
    'JACUINDE': 0,
    'JACUNSKI': 0,
    'JADA': 0.9876543209876544,
    'JADACH': 0,
    'JADALLAH': 0,
    'JADAN': 0,
    'JADAV': 0,
    'JADCZAK': 0,
    'JADE': 0.9937888198757764,
    'JADEJA': 0,
    'JADHAV': 0,
    'JADICK': 0,
    'JADIN': 0,
    'JADOO': 0,
    'JADOS': 0,
    'JADOTTE': 0,
    'JADUS': 0,
    'JADWIGA': 1,
    'JADWIN': 0,
    'JAE': 0.9884678747940692,
    'JAEB': 0,
    'JAECK': 0,
    'JAECKEL': 0,
    'JAECKELS': 0,
    'JAECKLE': 0,
    'JAECKS': 0,
    'JAEGER': 0,
    'JAEGERS': 0,
    'JAEGGI': 0,
    'JAEGLE': 0,
    'JAEHN': 0,
    'JAEHNE': 0,
    'JAEHNIG': 0,
    'JAEKEL': 0,
    'JAEN': 0,
    'JAENICKE': 0,
    'JAENISCH': 0,
    'JAENKE': 0,
    'JAENSCH': 0,
    'JAESCHKE': 0,
    'JAFAR': 0,
    'JAFARI': 0,
    'JAFFA': 0,
    'JAFFAR': 0,
    'JAFFARIAN': 0,
    'JAFFE': 0,
    'JAFFEE': 0,
    'JAFFER': 0,
    'JAFFERY': 0,
    'JAFFKE': 0,
    'JAFFRAY': 0,
    'JAFFREY': 0,
    'JAFFRI': 0,
    'JAFRI': 0,
    'JAGANNATH': 0,
    'JAGANNATHAN': 0,
    'JAGDEO': 0,
    'JAGEL': 0,
    'JAGELS': 0,
    'JAGEMAN': 0,
    'JAGER': 0,
    'JAGERS': 0,
    'JAGERSON': 0,
    'JAGGAR': 0,
    'JAGGARD': 0,
    'JAGGARS': 0,
    'JAGGER': 0,
    'JAGGERNAUTH': 0,
    'JAGGERS': 0,
    'JAGGI': 0,
    'JAGGIE': 0,
    'JAGHAB': 0,
    'JAGIELLO': 0,
    'JAGIELO': 0,
    'JAGIELSKI': 0,
    'JAGLA': 0,
    'JAGLOWSKI': 0,
    'JAGMOHAN': 0,
    'JAGNE': 0,
    'JAGNEAUX': 0,
    'JAGO': 0,
    'JAGODA': 0,
    'JAGODZINSKI': 0,
    'JAGOE': 0,
    'JAGOW': 0,
    'JAGROOP': 0,
    'JAGTIANI': 0,
    'JAGUSCH': 0,
    'JAH': 0,
    'JAHAN': 0,
    'JAHANGIR': 0,
    'JAHANGIRI': 0,
    'JAHELKA': 0,
    'JAHIC': 0,
    'JAHN': 0,
    'JAHNCKE': 0,
    'JAHNER': 0,
    'JAHNIGEN': 0,
    'JAHNKE': 0,
    'JAHNS': 0,
    'JAHNSEN': 0,
    'JAHNZ': 0,
    'JAHODA': 0,
    'JAHR': 0,
    'JAHRAUS': 0,
    'JAHRLING': 0,
    'JAHROMI': 0,
    'JAI': 0,
    'JAIKARAN': 0,
    'JAILLET': 0,
    'JAIMAN': 0,
    'JAIME': 0.9561567164179104,
    'JAIMEE': 1,
    'JAIMES': 0,
    'JAIMEZ': 0,
    'JAIMIE': 1,
    'JAIN': 0,
    'JAINDL': 0,
    'JAIRAM': 0,
    'JAISWAL': 0,
    'JAITEH': 0,
    'JAJE': 0,
    'JAJKO': 0,
    'JAJO': 0,
    'JAJOU': 0,
    'JAKAB': 0,
    'JAKACKI': 0,
    'JAKAITIS': 0,
    'JAKE': 0.9877518767285657,
    'JAKEL': 0,
    'JAKEMAN': 0,
    'JAKES': 0,
    'JAKEWAY': 0,
    'JAKIEL': 0,
    'JAKIELA': 0,
    'JAKINS': 0,
    'JAKL': 0,
    'JAKLITSCH': 0,
    'JAKOB': 0,
    'JAKOBI': 0,
    'JAKOBOWSKI': 0,
    'JAKOBS': 0,
    'JAKOBSEN': 0,
    'JAKOBSON': 0,
    'JAKOBY': 0,
    'JAKOUBEK': 0,
    'JAKOVAC': 0,
    'JAKOVICH': 0,
    'JAKS': 0,
    'JAKSA': 0,
    'JAKSHA': 0,
    'JAKSIC': 0,
    'JAKSON': 0,
    'JAKUB': 0,
    'JAKUBCZAK': 0,
    'JAKUBCZYK': 0,
    'JAKUBEC': 0,
    'JAKUBEK': 0,
    'JAKUBIAK': 0,
    'JAKUBIEC': 0,
    'JAKUBIK': 0,
    'JAKUBISIN': 0,
    'JAKUBOWICZ': 0,
    'JAKUBOWSKI': 0,
    'JAKUPI': 0,
    'JAKUPOVIC': 0,
    'JAKUS': 0,
    'JAKUSZ': 0,
    'JAKWAY': 0,
    'JALAL': 0,
    'JALALI': 0,
    'JALAS': 0,
    'JALBERT': 0,
    'JALDIN': 0,
    'JALEEL': 0,
    'JALEESA': 1,
    'JALETTE': 0,
    'JALIL': 0,
    'JALILI': 0,
    'JALISA': 1,
    'JALLAD': 0,
    'JALLAH': 0,
    'JALLO': 0,
    'JALLOH': 0,
    'JALLOW': 0,
    'JALOMA': 0,
    'JALOMO': 0,
    'JALOVEC': 0,
    'JALOWIEC': 0,
    'JALOWY': 0,
    'JALUFKA': 0,
    'JAM': 0,
    'JAMA': 0.6896551724137931,
    'JAMAAL': 1,
    'JAMAICA': 0,
    'JAMAIL': 0,
    'JAMAL': 0.9549795361527967,
    'JAMALI': 0,
    'JAMAN': 0,
    'JAMAR': 0.9630818619582665,
    'JAMASON': 0,
    'JAMBOIS': 0,
    'JAMBON': 0,
    'JAMBOR': 0,
    'JAME': 0.9900990099009902,
    'JAMEE': 1,
    'JAMEEL': 0,
    'JAMEISON': 0,
    'JAMEL': 0.9929078014184397,
    'JAMELE': 0,
    'JAMELL': 0,
    'JAMERO': 0,
    'JAMERSON': 0,
    'JAMES': 0.10366991499066971,
    'JAMESON': 0,
    'JAMESSON': 0,
    'JAMEY': 1,
    'JAMEYSON': 0,
    'JAMGOCHIAN': 0,
    'JAMGOTCHIAN': 0,
    'JAMI': 0.9950248756218906,
    'JAMIE': 0.9991787571858746,
    'JAMIEL': 0,
    'JAMIESON': 0,
    'JAMIKA': 1,
    'JAMIL': 0,
    'JAMILA': 1,
    'JAMILI': 0,
    'JAMIN': 0,
    'JAMINET': 0,
    'JAMIOLKOWSKI': 0,
    'JAMIR': 0,
    'JAMIS': 0,
    'JAMISON': 0.337609723160027,
    'JAMMAL': 0,
    'JAMMER': 0,
    'JAMMES': 0,
    'JAMMIE': 1,
    'JAMNIK': 0,
    'JAMON': 0,
    'JAMORA': 0,
    'JAMROG': 0,
    'JAMROS': 0,
    'JAMROZ': 0,
    'JAMROZIK': 0,
    'JAMROZY': 0,
    'JAMSHIDI': 0,
    'JAN': 0.9905193151266449,
    'JANA': 0.9964641594342655,
    'JANAC': 0,
    'JANACEK': 0,
    'JANACK': 0,
    'JANAE': 1,
    'JANAK': 0,
    'JANAKIRAMAN': 0,
    'JANAS': 0,
    'JANASIK': 0,
    'JANATA': 0,
    'JANAY': 1,
    'JANCA': 0,
    'JANCE': 0,
    'JANCEK': 0,
    'JANCEWICZ': 0,
    'JANCI': 0,
    'JANCIK': 0,
    'JANCO': 0,
    'JANCZAK': 0,
    'JANCZEWSKI': 0,
    'JANCZYK': 0,
    'JANDA': 0,
    'JANDER': 0,
    'JANDIK': 0,
    'JANDL': 0,
    'JANDREAU': 0,
    'JANDRES': 0,
    'JANDREW': 0,
    'JANDREY': 0,
    'JANDRIN': 0,
    'JANDRO': 0,
    'JANDRON': 0,
    'JANDT': 0,
    'JANDURA': 0,
    'JANE': 0.9988812529966438,
    'JANEAN': 1,
    'JANECEK': 0,
    'JANECKA': 0,
    'JANECKE': 0,
    'JANECKI': 0,
    'JANECZEK': 0,
    'JANECZKO': 0,
    'JANEE': 1,
    'JANEEN': 1,
    'JANEIRO': 0,
    'JANEK': 0,
    'JANEL': 1,
    'JANELL': 1,
    'JANELLA': 1,
    'JANELLE': 0.990916597853014,
    'JANELLI': 0,
    'JANENE': 1,
    'JANER': 0,
    'JANES': 0,
    'JANESE': 0,
    'JANESKI': 0,
    'JANESKO': 0,
    'JANESKY': 0,
    'JANESSA': 1,
    'JANET': 0.9995516522931667,
    'JANETH': 1,
    'JANETOS': 0,
    'JANETT': 1,
    'JANETTA': 1,
    'JANETTE': 0.9972801450589303,
    'JANETZKE': 0,
    'JANEWAY': 0,
    'JANEY': 0.9287925696594428,
    'JANEZIC': 0,
    'JANG': 0,
    'JANGULA': 0,
    'JANI': 0.7042253521126761,
    'JANIA': 0,
    'JANIAK': 0,
    'JANICE': 0.9991936332082881,
    'JANICEK': 0,
    'JANICH': 0,
    'JANICK': 0,
    'JANICKE': 0,
    'JANICKI': 0,
    'JANICZEK': 0,
    'JANIE': 1,
    'JANIEC': 0,
    'JANIECE': 1,
    'JANIFER': 0,
    'JANIGA': 0,
    'JANIGIAN': 0,
    'JANIK': 0,
    'JANIKOWSKI': 0,
    'JANIN': 0,
    'JANINA': 1,
    'JANINE': 1,
    'JANIS': 0.9601807399039819,
    'JANISCH': 0,
    'JANISE': 0.9009009009009009,
    'JANISH': 0,
    'JANISSE': 0,
    'JANISZEWSKI': 0,
    'JANITA': 1,
    'JANITZ': 0,
    'JANJUA': 0,
    'JANK': 0,
    'JANKA': 0,
    'JANKAUSKAS': 0,
    'JANKE': 0,
    'JANKIEWICZ': 0,
    'JANKINS': 0,
    'JANKO': 0,
    'JANKORD': 0,
    'JANKOSKI': 0,
    'JANKOVIAK': 0,
    'JANKOVIC': 0,
    'JANKOVICH': 0,
    'JANKOVSKY': 0,
    'JANKOWIAK': 0,
    'JANKOWITZ': 0,
    'JANKOWSKI': 0,
    'JANKOWSKY': 0,
    'JANKS': 0,
    'JANKURA': 0,
    'JANKUS': 0,
    'JANKY': 0,
    'JANN': 0.9009009009009009,
    'JANNA': 1,
    'JANNACE': 0,
    'JANNARONE': 0,
    'JANNASCH': 0,
    'JANNAZZO': 0,
    'JANNECK': 0,
    'JANNELLI': 0,
    'JANNER': 0,
    'JANNET': 1,
    'JANNETT': 0,
    'JANNETTA': 0,
    'JANNETTE': 0.9861932938856016,
    'JANNETTI': 0,
    'JANNETTY': 0,
    'JANNEY': 0,
    'JANNI': 0,
    'JANNICELLI': 0,
    'JANNIE': 1,
    'JANNING': 0,
    'JANNINGS': 0,
    'JANNISE': 0,
    'JANNONE': 0,
    'JANNOTTA': 0,
    'JANNOTTI': 0,
    'JANNSEN': 0,
    'JANNUSCH': 0,
    'JANNUZZI': 0,
    'JANNY': 0,
    'JANO': 0,
    'JANOCHA': 0,
    'JANOE': 0,
    'JANOFF': 0,
    'JANOFSKY': 0,
    'JANOS': 0,
    'JANOSEK': 0,
    'JANOSIK': 0,
    'JANOSKI': 0,
    'JANOSKO': 0,
    'JANOSKY': 0,
    'JANOSZ': 0,
    'JANOTA': 0,
    'JANOUSEK': 0,
    'JANOV': 0,
    'JANOVEC': 0,
    'JANOVICH': 0,
    'JANOVICK': 0,
    'JANOVSKY': 0,
    'JANOW': 0,
    'JANOWIAK': 0,
    'JANOWICZ': 0,
    'JANOWIECKI': 0,
    'JANOWITZ': 0,
    'JANOWSKI': 0,
    'JANOWSKY': 0,
    'JANQUART': 0,
    'JANS': 0,
    'JANSA': 0,
    'JANSCH': 0,
    'JANSE': 0,
    'JANSEN': 0,
    'JANSING': 0,
    'JANSKI': 0,
    'JANSKY': 0,
    'JANSMA': 0,
    'JANSON': 0,
    'JANSONS': 0,
    'JANSS': 0,
    'JANSSEN': 0,
    'JANSSENS': 0,
    'JANSSON': 0,
    'JANSZEN': 0,
    'JANT': 0,
    'JANTON': 0,
    'JANTSCH': 0,
    'JANTZ': 0,
    'JANTZEN': 0,
    'JANTZER': 0,
    'JANTZI': 0,
    'JANUARIO': 0,
    'JANUARY': 0.5347593582887701,
    'JANUCHOWSKI': 0,
    'JANULEWICZ': 0,
    'JANULIS': 0,
    'JANUS': 0,
    'JANUSCH': 0,
    'JANUSKA': 0,
    'JANUSZ': 0,
    'JANUSZEWSKI': 0,
    'JANUSZKIEWICZ': 0,
    'JANUZZI': 0,
    'JANVIER': 0,
    'JANVRIN': 0,
    'JANWAY': 0,
    'JANY': 0,
    'JANYCE': 1,
    'JANYSEK': 0,
    'JANZ': 0,
    'JANZEN': 0,
    'JANZER': 0,
    'JAO': 0,
    'JAPHET': 0,
    'JAPP': 0,
    'JAPPE': 0,
    'JAPS': 0,
    'JAQUA': 0,
    'JAQUAY': 0,
    'JAQUAYS': 0,
    'JAQUELINE': 1,
    'JAQUELYN': 1,
    'JAQUES': 0,
    'JAQUESS': 0,
    'JAQUET': 0,
    'JAQUETTE': 0,
    'JAQUEZ': 0,
    'JAQUILLARD': 0,
    'JAQUIN': 0,
    'JAQUISH': 0,
    'JAQUITH': 0,
    'JARA': 0,
    'JARABEK': 0,
    'JARACUARO': 0,
    'JARACZ': 0,
    'JARACZEWSKI': 0,
    'JARADAT': 0,
    'JARAL': 0,
    'JARAMILLO': 0,
    'JARANILLA': 0,
    'JARAS': 0,
    'JARBEAU': 0,
    'JARBO': 0,
    'JARBOE': 0,
    'JARCHOW': 0,
    'JARCZYK': 0,
    'JARDEE': 0,
    'JARDEL': 0,
    'JARDELEZA': 0,
    'JARDEN': 0,
    'JARDIM': 0,
    'JARDIN': 0,
    'JARDINA': 0,
    'JARDINE': 0,
    'JARDINES': 0,
    'JARDING': 0,
    'JARDON': 0,
    'JARDOT': 0,
    'JARECKE': 0,
    'JARECKI': 0,
    'JARED': 0.9910664433277498,
    'JAREK': 0,
    'JAREMA': 0,
    'JAREMKO': 0,
    'JARES': 0,
    'JAREST': 0,
    'JARET': 0,
    'JARETT': 0,
    'JARILLO': 0,
    'JARIN': 0,
    'JARIWALA': 0,
    'JARJOUR': 0,
    'JARJOURA': 0,
    'JARKA': 0,
    'JARL': 0,
    'JARMA': 0,
    'JARMAN': 0,
    'JARMER': 0,
    'JARMILLO': 0,
    'JARMIN': 0,
    'JARMOLOWICZ': 0,
    'JARMON': 0,
    'JARMUSZ': 0,
    'JARMUZ': 0,
    'JARNAGIN': 0,
    'JARNIGAN': 0,
    'JARNOT': 0,
    'JARO': 0,
    'JAROCH': 0,
    'JAROCKI': 0,
    'JAROD': 1,
    'JAROLIMEK': 0,
    'JAROMIN': 0,
    'JARON': 0,
    'JARONCZYK': 0,
    'JAROS': 0,
    'JAROSCAK': 0,
    'JAROSCH': 0,
    'JAROSEK': 0,
    'JAROSH': 0,
    'JAROSIEWICZ': 0,
    'JAROSIK': 0,
    'JAROSINSKI': 0,
    'JAROSZ': 0,
    'JAROSZEWICZ': 0,
    'JAROSZEWSKI': 0,
    'JARQUIN': 0,
    'JARR': 0,
    'JARRA': 0,
    'JARRAD': 0,
    'JARRAH': 0,
    'JARRAR': 0,
    'JARRARD': 0,
    'JARRATT': 0,
    'JARREAU': 0,
    'JARRED': 0.9771986970684039,
    'JARREL': 0,
    'JARRELL': 0,
    'JARRELLS': 0,
    'JARRELS': 0,
    'JARRET': 0,
    'JARRETT': 0.4801097393689986,
    'JARRETTE': 0,
    'JARRIEL': 0,
    'JARRIN': 0,
    'JARROD': 1,
    'JARROTT': 0,
    'JARROW': 0,
    'JARRY': 0,
    'JARSKI': 0,
    'JARSTAD': 0,
    'JARUS': 0,
    'JARUZEL': 0,
    'JARVAIS': 0,
    'JARVELA': 0,
    'JARVEY': 0,
    'JARVI': 0,
    'JARVIE': 0,
    'JARVINEN': 0,
    'JARVIS': 0.44208664898320066,
    'JARY': 0,
    'JARZAB': 0,
    'JARZABEK': 0,
    'JARZEMBOWSKI': 0,
    'JARZOMBEK': 0,
    'JARZYNA': 0,
    'JARZYNKA': 0,
    'JARZYNSKI': 0,
    'JAS': 0,
    'JASA': 0,
    'JASAITIS': 0,
    'JASANI': 0,
    'JASAREVIC': 0,
    'JASCH': 0,
    'JASCHKE': 0,
    'JASEK': 0,
    'JASEN': 0,
    'JASER': 0,
    'JASHARI': 0,
    'JASHINSKY': 0,
    'JASIAK': 0,
    'JASICKI': 0,
    'JASIEWICZ': 0,
    'JASIK': 0,
    'JASIN': 0,
    'JASINA': 0,
    'JASINSKI': 0,
    'JASIONOWSKI': 0,
    'JASKA': 0,
    'JASKE': 0,
    'JASKEN': 0,
    'JASKI': 0,
    'JASKIEWICZ': 0,
    'JASKO': 0,
    'JASKOLKA': 0,
    'JASKOLSKI': 0,
    'JASKOT': 0,
    'JASKOWIAK': 0,
    'JASKOWSKI': 0,
    'JASKULA': 0,
    'JASKULSKI': 0,
    'JASLOW': 0,
    'JASMAN': 0,
    'JASMER': 0,
    'JASMIN': 0.9291521486643438,
    'JASMINE': 0.9955462405030129,
    'JASMUND': 0,
    'JASNOCH': 0,
    'JASO': 0,
    'JASON': 0.9977693374329294,
    'JASPAL': 0,
    'JASPAN': 0,
    'JASPER': 0.8161044613710554,
    'JASPERING': 0,
    'JASPERS': 0,
    'JASPERSE': 0,
    'JASPERSEN': 0,
    'JASPERSON': 0,
    'JASS': 0,
    'JASSAL': 0,
    'JASSO': 0,
    'JASTER': 0,
    'JASTI': 0,
    'JASTRAB': 0,
    'JASTRAM': 0,
    'JASTREMSKI': 0,
    'JASTROW': 0,
    'JASTRZEBSKI': 0,
    'JASTRZEMBSKI': 0,
    'JASTRZEMSKI': 0,
    'JASWAL': 0,
    'JASZCZAK': 0,
    'JASZEWSKI': 0,
    'JATCZAK': 0,
    'JATHO': 0,
    'JATIVA': 0,
    'JATTA': 0,
    'JATZLAU': 0,
    'JAUBERT': 0,
    'JAUCH': 0,
    'JAUDON': 0,
    'JAUER': 0,
    'JAUME': 0,
    'JAUNITA': 1,
    'JAUQUET': 0,
    'JAURE': 0,
    'JAUREGUI': 0,
    'JAUREQUI': 0,
    'JAUREZ': 0,
    'JAURIGUE': 0,
    'JAURIGUI': 0,
    'JAURIQUE': 0,
    'JAURON': 0,
    'JAUS': 0,
    'JAUSS': 0,
    'JAUSSI': 0,
    'JAVA': 0,
    'JAVADI': 0,
    'JAVAHERI': 0,
    'JAVAHERIAN': 0,
    'JAVAID': 0,
    'JAVALERA': 0,
    'JAVAN': 0,
    'JAVAR': 0,
    'JAVAUX': 0,
    'JAVED': 0,
    'JAVELLANA': 0,
    'JAVENS': 0,
    'JAVER': 0,
    'JAVERNICK': 0,
    'JAVERS': 0,
    'JAVERY': 0,
    'JAVID': 0,
    'JAVIER': 0.9638196915776986,
    'JAVINS': 0,
    'JAVIS': 0,
    'JAVOR': 0,
    'JAVOREK': 0,
    'JAVORSKI': 0,
    'JAVORSKY': 0,
    'JAVUREK': 0,
    'JAW': 0,
    'JAWAD': 0,
    'JAWAHIR': 0,
    'JAWAID': 0,
    'JAWARA': 0,
    'JAWED': 0,
    'JAWOR': 0,
    'JAWOREK': 0,
    'JAWOROWICZ': 0,
    'JAWOROWSKI': 0,
    'JAWORSKI': 0,
    'JAWORSKY': 0,
    'JAX': 0,
    'JAY': 0.9709516931471674,
    'JAYA': 0,
    'JAYAKUMAR': 0,
    'JAYARAM': 0,
    'JAYARAMAN': 0,
    'JAYASINGHE': 0,
    'JAYASURIYA': 0,
    'JAYCOX': 0,
    'JAYE': 0.7751937984496124,
    'JAYES': 0,
    'JAYJOHN': 0,
    'JAYKO': 0,
    'JAYME': 0.9803921568627452,
    'JAYMES': 0,
    'JAYMIE': 1,
    'JAYNA': 1,
    'JAYNE': 0.9394572025052191,
    'JAYNES': 0,
    'JAYO': 0,
    'JAYROE': 0,
    'JAYSON': 0.984251968503937,
    'JAZAYERI': 0,
    'JAZDZEWSKI': 0,
    'JAZMIN': 0.9803921568627452,
    'JAZMINE': 1,
    'JAZO': 0,
    'JAZWIECKI': 0,
    'JAZWINSKI': 0,
    'JC': 1,
    'JE': 0,
    'JEAKINS': 0,
    'JEAKLE': 0,
    'JEAN': 0.9840305892937472,
    'JEANA': 1,
    'JEANBAPTIST': 0,
    'JEANBAPTISTE': 0,
    'JEANBART': 0,
    'JEANBATISTE': 0,
    'JEANBLANC': 0,
    'JEANCHARLES': 0,
    'JEANCLAUDE': 0,
    'JEANDRON': 0,
    'JEANE': 0.9546539379474941,
    'JEANELLE': 1,
    'JEANENE': 1,
    'JEANES': 0,
    'JEANETT': 1,
    'JEANETTA': 1,
    'JEANETTE': 0.998697351280938,
    'JEANFELIX': 0,
    'JEANFRANCOIS': 0,
    'JEANFREAU': 0,
    'JEANGILLES': 0,
    'JEANICE': 1,
    'JEANIE': 1,
    'JEANINE': 1,
    'JEANIS': 0,
    'JEANJACQUES': 0,
    'JEANJOSEPH': 0,
    'JEANLOUIS': 0,
    'JEANMARIE': 0.8403361344537815,
    'JEANMARY': 0,
    'JEANMICHEL': 0,
    'JEANNA': 1,
    'JEANNE': 1,
    'JEANNERET': 0,
    'JEANNETTA': 1,
    'JEANNETTE': 0.9967497291440954,
    'JEANNIE': 1,
    'JEANNIN': 0,
    'JEANNINE': 1,
    'JEANNITON': 0,
    'JEANNOEL': 0,
    'JEANNOT': 0,
    'JEANNOTTE': 0,
    'JEANOTTE': 0,
    'JEANPAUL': 0,
    'JEANPHILIPPE': 0,
    'JEANPIERRE': 0,
    'JEANQUART': 0,
    'JEANS': 0,
    'JEANSIMON': 0,
    'JEANSON': 0,
    'JEANSONNE': 0,
    'JEANTY': 0,
    'JEAVONS': 0,
    'JEBB': 0,
    'JEBBIA': 0,
    'JEBENS': 0,
    'JECH': 0,
    'JECK': 0,
    'JECKEL': 0,
    'JECKELL': 0,
    'JECKER': 0,
    'JECKLIN': 0,
    'JED': 1,
    'JEDD': 0,
    'JEDELE': 0,
    'JEDINAK': 0,
    'JEDLICKA': 0,
    'JEDLICKI': 0,
    'JEDLOWSKI': 0,
    'JEDREY': 0,
    'JEDRZEJCZYK': 0,
    'JEDRZEJEK': 0,
    'JEDRZEJEWSKI': 0,
    'JEDYNAK': 0,
    'JEDZINIAK': 0,
    'JEE': 0,
    'JEFCOAT': 0,
    'JEFF': 0.9977760413536094,
    'JEFFARES': 0,
    'JEFFCOAT': 0,
    'JEFFCOATS': 0,
    'JEFFCOTT': 0,
    'JEFFER': 0,
    'JEFFERDS': 0,
    'JEFFEREY': 1,
    'JEFFERIES': 0,
    'JEFFERIS': 0,
    'JEFFERS': 0,
    'JEFFERSON': 0.3443526170798898,
    'JEFFERY': 0.9802184824328314,
    'JEFFERYS': 0,
    'JEFFIE': 1,
    'JEFFORD': 0,
    'JEFFORDS': 0,
    'JEFFRES': 0,
    'JEFFRESS': 0,
    'JEFFREY': 0.9932052680144283,
    'JEFFREYS': 0,
    'JEFFRIE': 0,
    'JEFFRIES': 0,
    'JEFFRIS': 0,
    'JEFFRY': 0.9950248756218906,
    'JEFFRYES': 0,
    'JEFFS': 0,
    'JEFFUS': 0,
    'JEFSON': 0,
    'JEFTS': 0,
    'JEGEDE': 0,
    'JEGLINSKI': 0,
    'JEGLUM': 0,
    'JEHAN': 0,
    'JEHL': 0,
    'JEHLE': 0,
    'JEHN': 0,
    'JEKA': 0,
    'JEKEL': 0,
    'JEKINS': 0,
    'JELDEN': 0,
    'JELEN': 0,
    'JELENIC': 0,
    'JELENIEWSKI': 0,
    'JELIC': 0,
    'JELICH': 0,
    'JELINEK': 0,
    'JELINSKI': 0,
    'JELKS': 0,
    'JELLE': 0,
    'JELLEMA': 0,
    'JELLEN': 0,
    'JELLERSON': 0,
    'JELLEY': 0,
    'JELLIFF': 0,
    'JELLIFFE': 0,
    'JELLINEK': 0,
    'JELLINGS': 0,
    'JELLIS': 0,
    'JELLISON': 0,
    'JELLUM': 0,
    'JELLY': 0,
    'JELONEK': 0,
    'JELSMA': 0,
    'JELTEMA': 0,
    'JEMAL': 0,
    'JEMERSON': 0,
    'JEMES': 0,
    'JEMINEZ': 0,
    'JEMIOLO': 0,
    'JEMISON': 0,
    'JEMMETT': 0,
    'JEMMOTT': 0,
    'JEN': 0.8097165991902835,
    'JENA': 0.9873060648801129,
    'JENAE': 1,
    'JENCKES': 0,
    'JENCKS': 0,
    'JENCO': 0,
    'JENDER': 0,
    'JENDRAS': 0,
    'JENDRO': 0,
    'JENDRUSCH': 0,
    'JENDRZEJEWSKI': 0,
    'JENE': 1,
    'JENEE': 1,
    'JENEI': 0,
    'JENELL': 1,
    'JENELLE': 1,
    'JENEMA': 0,
    'JENERETTE': 0,
    'JENES': 0,
    'JENETTE': 1,
    'JENEVA': 1,
    'JENEWEIN': 0,
    'JENEY': 0,
    'JENG': 0,
    'JENGO': 0,
    'JENI': 1,
    'JENICE': 1,
    'JENICEK': 0,
    'JENIFER': 0.9918068132815869,
    'JENIFFER': 1,
    'JENIK': 0,
    'JENINE': 1,
    'JENIS': 0,
    'JENISCH': 0,
    'JENISE': 1,
    'JENISON': 0,
    'JENISTA': 0,
    'JENKE': 0,
    'JENKEL': 0,
    'JENKENS': 0,
    'JENKERSON': 0,
    'JENKIN': 0,
    'JENKINS': 0,
    'JENKINSON': 0,
    'JENKO': 0,
    'JENKS': 0,
    'JENN': 0,
    'JENNA': 0.9983361064891847,
    'JENNE': 0,
    'JENNEFER': 1,
    'JENNELL': 0.9523809523809523,
    'JENNELLE': 0,
    'JENNEMAN': 0,
    'JENNEMANN': 0,
    'JENNEN': 0,
    'JENNER': 0,
    'JENNERJOHN': 0,
    'JENNES': 0,
    'JENNESS': 0,
    'JENNETT': 0,
    'JENNETTE': 0.8676789587852495,
    'JENNEWEIN': 0,
    'JENNEY': 0,
    'JENNI': 0.9828009828009829,
    'JENNIE': 0.9994523548740416,
    'JENNIFER': 0.9998283556470993,
    'JENNIFERL': 0,
    'JENNIFFER': 1,
    'JENNIGES': 0,
    'JENNIGS': 0,
    'JENNINE': 1,
    'JENNING': 0,
    'JENNINGS': 0,
    'JENNINS': 0,
    'JENNIS': 0,
    'JENNISON': 0,
    'JENNISSEN': 0,
    'JENNRICH': 0,
    'JENNY': 0.9921213889699445,
    'JENO': 0,
    'JENQUIN': 0,
    'JENRETTE': 0,
    'JENRICH': 0,
    'JENS': 0,
    'JENSCHKE': 0,
    'JENSEMA': 0,
    'JENSEN': 0,
    'JENSON': 0,
    'JENSRUD': 0,
    'JENSSEN': 0,
    'JENSVOLD': 0,
    'JENT': 0,
    'JENTRY': 0,
    'JENTSCH': 0,
    'JENTZ': 0,
    'JENTZEN': 0,
    'JENTZSCH': 0,
    'JENUWINE': 0,
    'JENZEN': 0,
    'JEON': 0,
    'JEONG': 0,
    'JEPHSON': 0,
    'JEPPE': 0,
    'JEPPERSON': 0,
    'JEPPESEN': 0,
    'JEPPSEN': 0,
    'JEPPSON': 0,
    'JEPSEN': 0,
    'JEPSON': 0,
    'JERABEK': 0,
    'JERALD': 0.9952854897852279,
    'JERALDINE': 1,
    'JERALDS': 0,
    'JERAMY': 1,
    'JERARD': 0,
    'JERAULD': 0,
    'JERDAN': 0,
    'JERDE': 0,
    'JERDEE': 0,
    'JERDEN': 0,
    'JERDON': 0,
    'JERE': 1,
    'JEREB': 0,
    'JERECZEK': 0,
    'JEREMIAH': 0.9891662741403674,
    'JEREMIAS': 0,
    'JEREMIE': 0,
    'JEREMY': 0.9995064165844029,
    'JEREW': 0,
    'JEREZ': 0,
    'JERGE': 0,
    'JERGENS': 0,
    'JERGENSEN': 0,
    'JERGENSON': 0,
    'JERGER': 0,
    'JERGINS': 0,
    'JERI': 1,
    'JERIC': 0,
    'JERICA': 1,
    'JERICH': 0,
    'JERICHO': 0,
    'JERIDO': 0,
    'JERILYN': 1,
    'JERIN': 0,
    'JERINA': 0,
    'JERKE': 0,
    'JERKINS': 0,
    'JERKOVICH': 0,
    'JERLENE': 1,
    'JERLES': 0,
    'JERMAIN': 0,
    'JERMAINE': 1,
    'JERMAN': 0,
    'JERMANN': 0,
    'JERMANY': 0,
    'JERMSTAD': 0,
    'JERMYN': 0,
    'JERN': 0,
    'JERNAGAN': 0,
    'JERNBERG': 0,
    'JERNEGAN': 0,
    'JERNIGAN': 0,
    'JERNSTROM': 0,
    'JERO': 0,
    'JEROLD': 1,
    'JEROME': 0.9727100783572007,
    'JEROMY': 1,
    'JERONIMO': 0,
    'JERONIMUS': 0,
    'JEROR': 0,
    'JEROUSEK': 0,
    'JEROZAL': 0,
    'JERRAM': 0,
    'JERRED': 0,
    'JERREL': 0,
    'JERRELL': 0.9132420091324202,
    'JERRELLS': 0,
    'JERRELS': 0,
    'JERRETT': 0,
    'JERRI': 1,
    'JERRICA': 1,
    'JERRICK': 0,
    'JERRIE': 1,
    'JERRO': 0,
    'JERROD': 1,
    'JERROLD': 1,
    'JERROLDS': 0,
    'JERRY': 0.9978825967473083,
    'JERSEY': 0,
    'JERSILD': 0,
    'JERUE': 0,
    'JERVE': 0,
    'JERVEY': 0,
    'JERVIS': 0,
    'JERZ': 0,
    'JERZAK': 0,
    'JERZEWSKI': 0,
    'JERZYK': 0,
    'JESBERG': 0,
    'JESBERGER': 0,
    'JESCH': 0,
    'JESCHKE': 0,
    'JESENIA': 1,
    'JESERITZ': 0,
    'JESICA': 1,
    'JESIOLOWSKI': 0,
    'JESIONOWSKI': 0,
    'JESKA': 0,
    'JESKE': 0,
    'JESKEY': 0,
    'JESKI': 0,
    'JESKO': 0,
    'JESME': 0,
    'JESMER': 0,
    'JESPERSEN': 0,
    'JESPERSON': 0,
    'JESS': 0.968783638320775,
    'JESSAMY': 0,
    'JESSE': 0.993680739994505,
    'JESSEE': 0,
    'JESSEL': 0,
    'JESSELL': 0,
    'JESSEMAN': 0,
    'JESSEN': 0,
    'JESSENIA': 1,
    'JESSEPH': 0,
    'JESSER': 0,
    'JESSEY': 0,
    'JESSI': 1,
    'JESSIA': 1,
    'JESSICA': 0.9998367613450866,
    'JESSICK': 0,
    'JESSIE': 0.9913635810728622,
    'JESSIKA': 1,
    'JESSING': 0,
    'JESSIP': 0,
    'JESSMER': 0,
    'JESSO': 0,
    'JESSON': 0,
    'JESSOP': 0,
    'JESSUP': 0,
    'JESSWEIN': 0,
    'JESTER': 0,
    'JESTES': 0,
    'JESTICE': 0,
    'JESTINE': 1,
    'JESTIS': 0,
    'JESTUS': 0,
    'JESUS': 0.9958769425943546,
    'JESUSA': 1,
    'JESUSITA': 1,
    'JESWALD': 0,
    'JETER': 0,
    'JETHRO': 0,
    'JETHWA': 0,
    'JETMORE': 0,
    'JETSON': 0,
    'JETT': 0,
    'JETTA': 1,
    'JETTE': 0,
    'JETTER': 0,
    'JETTIE': 1,
    'JETTON': 0,
    'JETTY': 0,
    'JEU': 0,
    'JEUDI': 0,
    'JEUDY': 0,
    'JEUN': 0,
    'JEUNE': 0,
    'JEUNG': 0,
    'JEURISSEN': 0,
    'JEVNE': 0,
    'JEVONS': 0,
    'JEVTIC': 0,
    'JEW': 0,
    'JEWART': 0,
    'JEWEII': 0,
    'JEWEL': 0.989423404981235,
    'JEWELL': 0.7444907683144728,
    'JEWELS': 0,
    'JEWERS': 0,
    'JEWETT': 0,
    'JEWISON': 0,
    'JEWITT': 0,
    'JEWKES': 0,
    'JEWS': 0,
    'JEWSBURY': 0,
    'JEWSON': 0,
    'JEX': 0,
    'JEYS': 0,
    'JEZ': 0,
    'JEZAK': 0,
    'JEZEK': 0,
    'JEZESKI': 0,
    'JEZEWSKI': 0,
    'JEZIERSKI': 0,
    'JEZIK': 0,
    'JEZIOR': 0,
    'JEZIORO': 0,
    'JEZIORSKI': 0,
    'JEZOWSKI': 0,
    'JEZUIT': 0,
    'JHA': 0,
    'JHAVERI': 0,
    'JHON': 0,
    'JHONS': 0,
    'JHUN': 0,
    'JI': 0.5617977528089888,
    'JIA': 0,
    'JIAN': 0,
    'JIANG': 0,
    'JIAO': 0,
    'JIBBEN': 0,
    'JIBRIL': 0,
    'JIBSON': 0,
    'JICHA': 0,
    'JIE': 0,
    'JIGGETTS': 0,
    'JIH': 0,
    'JIHAD': 0,
    'JIJON': 0,
    'JIL': 0,
    'JILANI': 0,
    'JILBERT': 0,
    'JILEK': 0,
    'JILES': 0,
    'JILG': 0,
    'JILK': 0,
    'JILKA': 0,
    'JILL': 0.9995072851411276,
    'JILLIAN': 1,
    'JILLSON': 0,
    'JIM': 0.9896838044116414,
    'JIMBO': 0,
    'JIMENES': 0,
    'JIMENEZ': 0,
    'JIMENEZGARCIA': 0,
    'JIMENEZLOPEZ': 0,
    'JIMENIZ': 0,
    'JIMENO': 0,
    'JIMENZ': 0,
    'JIMERSON': 0,
    'JIMESON': 0,
    'JIMEZ': 0,
    'JIMINEZ': 0,
    'JIMINIAN': 0,
    'JIMISON': 0,
    'JIMMENEZ': 0,
    'JIMMERSON': 0,
    'JIMMIE': 0.9982696659124185,
    'JIMMISON': 0,
    'JIMMO': 0,
    'JIMMY': 0.9993786246893124,
    'JIMOH': 0,
    'JIMS': 0,
    'JIMSON': 0,
    'JIN': 0.5102040816326531,
    'JINA': 1,
    'JINDAL': 0,
    'JINDRA': 0,
    'JINDRICH': 0,
    'JINENEZ': 0,
    'JINES': 0,
    'JING': 0,
    'JINGLES': 0,
    'JINKENS': 0,
    'JINKERSON': 0,
    'JINKINS': 0,
    'JINKS': 0,
    'JINNAH': 0,
    'JINNETTE': 0,
    'JINNY': 1,
    'JINRIGHT': 0,
    'JINZO': 0,
    'JIO': 0,
    'JIPP': 0,
    'JIPPING': 0,
    'JIPSON': 0,
    'JIRA': 0,
    'JIRAK': 0,
    'JIRAN': 0,
    'JIRASEK': 0,
    'JIRIK': 0,
    'JIRKA': 0,
    'JIRKOVSKY': 0,
    'JIRON': 0,
    'JIROUSEK': 0,
    'JIROVEC': 0,
    'JIRSA': 0,
    'JIRSCHELE': 0,
    'JISA': 0,
    'JISKRA': 0,
    'JIT': 0,
    'JIVAN': 0,
    'JIVANI': 0,
    'JIVIDEN': 0,
    'JIWANI': 0,
    'JNBAPTISTE': 0,
    'JO': 0.9889193375431908,
    'JOA': 0,
    'JOACHIM': 0,
    'JOACHIN': 0,
    'JOAN': 0.9996498042087167,
    'JOANA': 1,
    'JOANE': 1,
    'JOANIE': 1,
    'JOANIS': 0,
    'JOANN': 1,
    'JOANNA': 1,
    'JOANNE': 1,
    'JOANNIDES': 0,
    'JOANNIE': 1,
    'JOANNOU': 0,
    'JOANS': 0,
    'JOAO': 0,
    'JOAQUIM': 0,
    'JOAQUIN': 0.9358288770053477,
    'JOAQUINA': 1,
    'JOAS': 0,
    'JOB': 0,
    'JOBANPUTRA': 0,
    'JOBB': 0,
    'JOBBINS': 0,
    'JOBE': 0,
    'JOBES': 0,
    'JOBGEN': 0,
    'JOBIN': 0,
    'JOBLIN': 0,
    'JOBMAN': 0,
    'JOBS': 0,
    'JOBSON': 0,
    'JOBST': 0,
    'JOCELYN': 0.9900990099009901,
    'JOCHEM': 0,
    'JOCHEMS': 0,
    'JOCHEN': 0,
    'JOCHENS': 0,
    'JOCHIM': 0,
    'JOCHIMS': 0,
    'JOCHIMSEN': 0,
    'JOCHMAN': 0,
    'JOCHUM': 0,
    'JOCK': 0,
    'JOCKEL': 0,
    'JOCKERS': 0,
    'JOCKISCH': 0,
    'JOCOY': 0,
    'JOCSON': 0,
    'JODEE': 1,
    'JODI': 1,
    'JODICE': 0,
    'JODIE': 1,
    'JODLOWSKI': 0,
    'JODOIN': 0,
    'JODON': 0,
    'JODREY': 0,
    'JODRY': 0,
    'JODWAY': 0,
    'JODY': 0.9988722410182053,
    'JOE': 0.9905502719455501,
    'JOEANN': 1,
    'JOECKEL': 0,
    'JOECKS': 0,
    'JOEHNK': 0,
    'JOEL': 0.9970864357397217,
    'JOELL': 0,
    'JOELLA': 1,
    'JOELLE': 1,
    'JOELLEN': 1,
    'JOELSON': 0,
    'JOENS': 0,
    'JOERG': 0,
    'JOERGER': 0,
    'JOERN': 0,
    'JOERRES': 0,
    'JOERS': 0,
    'JOERSZ': 0,
    'JOESPH': 1,
    'JOEST': 0,
    'JOESTEN': 0,
    'JOESTING': 0,
    'JOETTA': 1,
    'JOETTE': 1,
    'JOEY': 0.998914223669924,
    'JOFFE': 0,
    'JOFFRE': 0,
    'JOFFRION': 0,
    'JOFRE': 0,
    'JOG': 0,
    'JOGAN': 0,
    'JOGERST': 0,
    'JOGGERST': 0,
    'JOGLEKAR': 0,
    'JOH': 0,
    'JOHAL': 0,
    'JOHAN': 0,
    'JOHANA': 1,
    'JOHANEK': 0,
    'JOHANN': 0,
    'JOHANNA': 1,
    'JOHANNE': 1,
    'JOHANNECK': 0,
    'JOHANNES': 0,
    'JOHANNESEN': 0,
    'JOHANNESON': 0,
    'JOHANNESSEN': 0,
    'JOHANNESSON': 0,
    'JOHANNING': 0,
    'JOHANNINGMEIER': 0,
    'JOHANNINGSMEIER': 0,
    'JOHANNS': 0,
    'JOHANNSEN': 0,
    'JOHANNSON': 0,
    'JOHANSEN': 0,
    'JOHANSON': 0,
    'JOHANSSON': 0,
    'JOHANTGEN': 0,
    'JOHAR': 0,
    'JOHES': 0,
    'JOHL': 0,
    'JOHLE': 0,
    'JOHLER': 0,
    'JOHLL': 0,
    'JOHN': 0.9968875730661202,
    'JOHNA': 0.9615384615384616,
    'JOHNAKIN': 0,
    'JOHNATHAN': 0.9988249118683901,
    'JOHNATHON': 1,
    'JOHNBAPTISTE': 0,
    'JOHNCOCK': 0,
    'JOHNCOX': 0,
    'JOHNDRO': 0,
    'JOHNDROW': 0,
    'JOHNE': 0,
    'JOHNER': 0,
    'JOHNES': 0,
    'JOHNESE': 0,
    'JOHNETTA': 1,
    'JOHNETTE': 1,
    'JOHNICAN': 0,
    'JOHNIE': 1,
    'JOHNIGAN': 0,
    'JOHNIKIN': 0,
    'JOHNK': 0,
    'JOHNKE': 0,
    'JOHNNA': 1,
    'JOHNNIE': 0.9987926682032708,
    'JOHNNY': 0.9992934288886646,
    'JOHNOSN': 0,
    'JOHNROE': 0,
    'JOHNS': 0,
    'JOHNSEN': 0,
    'JOHNSEY': 0,
    'JOHNSIE': 1,
    'JOHNSON': 0.005776673791231009,
    'JOHNSONBAUGH': 0,
    'JOHNSONBEY': 0,
    'JOHNSONBROWN': 0,
    'JOHNSONLEE': 0,
    'JOHNSONSMITH': 0,
    'JOHNSONWILLIAM': 0,
    'JOHNSRUD': 0,
    'JOHNSSON': 0,
    'JOHNSTAD': 0,
    'JOHNSTON': 0,
    'JOHNSTONBAUGH': 0,
    'JOHNSTONE': 0,
    'JOHNSTUN': 0,
    'JOHNWELL': 0,
    'JOHONSON': 0,
    'JOHS': 0,
    'JOHSTON': 0,
    'JOI': 1,
    'JOICE': 0,
    'JOIE': 1,
    'JOINER': 0,
    'JOINES': 0,
    'JOINS': 0,
    'JOINT': 0,
    'JOINTER': 0,
    'JOINVILLE': 0,
    'JOJO': 0,
    'JOJOLA': 0,
    'JOKELA': 0,
    'JOKERST': 0,
    'JOKI': 0,
    'JOKIC': 0,
    'JOKINEN': 0,
    'JOKISCH': 0,
    'JOLANDA': 1,
    'JOLDERSMA': 0,
    'JOLE': 0,
    'JOLEEN': 1,
    'JOLENE': 1,
    'JOLES': 0,
    'JOLET': 0,
    'JOLIAT': 0,
    'JOLIBOIS': 0,
    'JOLICOEUR': 0,
    'JOLIE': 0.9615384615384616,
    'JOLIET': 0,
    'JOLIN': 0,
    'JOLINE': 0.9433962264150944,
    'JOLING': 0,
    'JOLISSAINT': 0,
    'JOLITZ': 0,
    'JOLIVET': 0,
    'JOLIVETTE': 0,
    'JOLL': 0,
    'JOLLA': 0,
    'JOLLAY': 0,
    'JOLLES': 0,
    'JOLLEY': 0,
    'JOLLIE': 0,
    'JOLLIFF': 0,
    'JOLLIFFE': 0,
    'JOLLIMORE': 0,
    'JOLLS': 0,
    'JOLLY': 0,
    'JOLMA': 0,
    'JOLSON': 0,
    'JOLY': 0,
    'JOLYN': 1,
    'JOLYNN': 1,
    'JOMAA': 0,
    'JOMES': 0,
    'JON': 0.9985366273564603,
    'JONA': 0.9803921568627452,
    'JONAH': 0.984251968503937,
    'JONAITIS': 0,
    'JONAK': 0,
    'JONAS': 0.68762278978389,
    'JONASEN': 0,
    'JONASON': 0,
    'JONASSAINT': 0,
    'JONASSEN': 0,
    'JONASSON': 0,
    'JONATHAN': 0.99939333950637,
    'JONATHON': 1,
    'JONCAS': 0,
    'JONCZAK': 0,
    'JONDAHL': 0,
    'JONDLE': 0,
    'JONE': 0.591715976331361,
    'JONELL': 1,
    'JONELLE': 1,
    'JONEN': 0,
    'JONER': 0,
    'JONES': 0,
    'JONESJOHNSON': 0,
    'JONESLEE': 0,
    'JONESON': 0,
    'JONESSMITH': 0,
    'JONET': 0,
    'JONG': 0.7194244604316546,
    'JONGELING': 0,
    'JONGEWARD': 0,
    'JONGS': 0,
    'JONGSMA': 0,
    'JONI': 1,
    'JONIAK': 0,
    'JONIE': 1,
    'JONIEC': 0,
    'JONIS': 0,
    'JONKE': 0,
    'JONKER': 0,
    'JONKMAN': 0,
    'JONNA': 0.986842105263158,
    'JONNALAGADDA': 0,
    'JONNIE': 1,
    'JONNSON': 0,
    'JONOVICH': 0,
    'JONS': 0,
    'JONSGAARD': 0,
    'JONSON': 0,
    'JONSSON': 0,
    'JONSTON': 0,
    'JONTE': 0,
    'JONTZ': 0,
    'JOO': 0,
    'JOOS': 0,
    'JOOST': 0,
    'JOOSTEN': 0,
    'JOPE': 0,
    'JOPEK': 0,
    'JOPLIN': 0,
    'JOPLING': 0,
    'JOPP': 0,
    'JOPPA': 0,
    'JOPPY': 0,
    'JOPSON': 0,
    'JORALEMON': 0,
    'JORAN': 0,
    'JORAY': 0,
    'JORDA': 0,
    'JORDAHL': 0,
    'JORDAL': 0,
    'JORDAN': 0.4818935582169938,
    'JORDANO': 0,
    'JORDE': 0,
    'JORDEN': 0,
    'JORDET': 0,
    'JORDHEIM': 0,
    'JORDI': 0,
    'JORDIN': 0,
    'JORDING': 0,
    'JORDISON': 0,
    'JORDON': 0.6768189509306262,
    'JORDT': 0,
    'JORDY': 0,
    'JORE': 0,
    'JORENBY': 0,
    'JORG': 0,
    'JORGE': 0.9829867674858223,
    'JORGENS': 0,
    'JORGENSEN': 0,
    'JORGENSON': 0,
    'JORGES': 0,
    'JORIS': 0,
    'JORISSEN': 0,
    'JORN': 0,
    'JORNS': 0,
    'JORQUERA': 0,
    'JORRIN': 0,
    'JORRIS': 0,
    'JORRITSMA': 0,
    'JORS': 0,
    'JORSTAD': 0,
    'JORY': 0,
    'JOSA': 0,
    'JOSAFAT': 0,
    'JOSAN': 0,
    'JOSAPHAT': 0,
    'JOSCELYN': 0,
    'JOSE': 0.9955716456023531,
    'JOSEF': 0.9819967266775776,
    'JOSEFA': 1,
    'JOSEFIAK': 0,
    'JOSEFINA': 1,
    'JOSEFINE': 1,
    'JOSEFSON': 0,
    'JOSELYN': 0.9803921568627452,
    'JOSENHANS': 0,
    'JOSEPH': 0.9793767855032773,
    'JOSEPHINA': 1,
    'JOSEPHINE': 1,
    'JOSEPHS': 0,
    'JOSEPHSEN': 0,
    'JOSEPHSON': 0,
    'JOSETTE': 1,
    'JOSEY': 0,
    'JOSH': 0.9943795936013835,
    'JOSHI': 0,
    'JOSHLIN': 0,
    'JOSHUA': 0.9975747037020088,
    'JOSI': 0,
    'JOSIAH': 0.9771986970684039,
    'JOSIE': 0.995850622406639,
    'JOSKI': 0,
    'JOSLEN': 0,
    'JOSLIN': 0,
    'JOSLYN': 0.6802721088435374,
    'JOSON': 0,
    'JOSPEH': 1,
    'JOSPHINE': 1,
    'JOSS': 0,
    'JOSSART': 0,
    'JOSSELYN': 0,
    'JOSSERAND': 0,
    'JOSSI': 0,
    'JOST': 0,
    'JOSTAD': 0,
    'JOSTEN': 0,
    'JOSTES': 0,
    'JOSTOCK': 0,
    'JOSUE': 0.9803921568627452,
    'JOSWIAK': 0,
    'JOSWICK': 0,
    'JOU': 0,
    'JOUBERT': 0,
    'JOUBRAN': 0,
    'JOUDEH': 0,
    'JOUDREY': 0,
    'JOUETT': 0,
    'JOULE': 0,
    'JOUNG': 0,
    'JOUPPI': 0,
    'JOURDAIN': 0,
    'JOURDAN': 0,
    'JOURDEN': 0,
    'JOURNAGAN': 0,
    'JOURNEAY': 0,
    'JOURNELL': 0,
    'JOURNET': 0,
    'JOURNEY': 0,
    'JOURNIGAN': 0,
    'JOUSMA': 0,
    'JOUSTRA': 0,
    'JOVA': 0,
    'JOVAN': 0.9433962264150944,
    'JOVANELLY': 0,
    'JOVANOV': 0,
    'JOVANOVIC': 0,
    'JOVANOVICH': 0,
    'JOVANOVSKI': 0,
    'JOVE': 0,
    'JOVEL': 0,
    'JOVELLANOS': 0,
    'JOVEN': 0,
    'JOVER': 0,
    'JOVES': 0,
    'JOVIC': 0,
    'JOVICIC': 0,
    'JOVIN': 0,
    'JOVITA': 1,
    'JOW': 0,
    'JOWDY': 0,
    'JOWELL': 0,
    'JOWERS': 0,
    'JOWES': 0,
    'JOWETT': 0,
    'JOY': 0.9506895110739658,
    'JOYA': 0.5988023952095809,
    'JOYAL': 0,
    'JOYCE': 0.966671092816359,
    'JOYCELYN': 1,
    'JOYE': 0.8196721311475409,
    'JOYER': 0,
    'JOYNER': 0,
    'JOYNES': 0,
    'JOYNT': 0,
    'JOZA': 0,
    'JOZEFCZYK': 0,
    'JOZEFIAK': 0,
    'JOZEFOWICZ': 0,
    'JOZSA': 0,
    'JOZWIAK': 0,
    'JOZWICK': 0,
    'JOZWIK': 0,
    'JR': 0,
    'JRJOHNSON': 0,
    'JRJONES': 0,
    'JRSMITH': 0,
    'JU': 0,
    'JUAIRE': 0,
    'JUAN': 0.994451025625039,
    'JUANA': 1,
    'JUANES': 0,
    'JUANG': 0,
    'JUANICO': 0,
    'JUANILLO': 0,
    'JUANITA': 1,
    'JUARBE': 0,
    'JUAREZ': 0,
    'JUBA': 0,
    'JUBAN': 0,
    'JUBB': 0,
    'JUBECK': 0,
    'JUBENVILLE': 0,
    'JUBER': 0,
    'JUBERA': 0,
    'JUBERT': 0,
    'JUBIC': 0,
    'JUBIE': 0,
    'JUBILEE': 0,
    'JUBIN': 0,
    'JUBINVILLE': 0,
    'JUBRAN': 0,
    'JUBREY': 0,
    'JUBY': 0,
    'JUCA': 0,
    'JUCHA': 0,
    'JUCHEM': 0,
    'JUCHNIEWICZ': 0,
    'JUCKEM': 0,
    'JUCKETT': 0,
    'JUCO': 0,
    'JUD': 0,
    'JUDA': 0,
    'JUDAH': 0,
    'JUDAS': 0,
    'JUDAY': 0,
    'JUDD': 0,
    'JUDE': 0.8445945945945946,
    'JUDEH': 0,
    'JUDEN': 0,
    'JUDGE': 0,
    'JUDI': 1,
    'JUDICE': 0,
    'JUDIE': 0.967741935483871,
    'JUDISCH': 0,
    'JUDISH': 0,
    'JUDITH': 0.999865338001616,
    'JUDKINS': 0,
    'JUDNICK': 0,
    'JUDON': 0,
    'JUDSON': 0.79155672823219,
    'JUDT': 0,
    'JUDWARE': 0,
    'JUDY': 0.9910233393177739,
    'JUDYCKI': 0,
    'JUE': 0,
    'JUEDES': 0,
    'JUEL': 0,
    'JUELFS': 0,
    'JUELICH': 0,
    'JUELL': 0,
    'JUEN': 0,
    'JUENEMAN': 0,
    'JUENEMANN': 0,
    'JUENGEL': 0,
    'JUENGER': 0,
    'JUENGLING': 0,
    'JUENGST': 0,
    'JUENKE': 0,
    'JUERGENS': 0,
    'JUERGENSEN': 0,
    'JUERS': 0,
    'JUETT': 0,
    'JUETTEN': 0,
    'JUETTNER': 0,
    'JUFFER': 0,
    'JUGAN': 0,
    'JUGE': 0,
    'JUGENHEIMER': 0,
    'JUGO': 0,
    'JUHAN': 0,
    'JUHAS': 0,
    'JUHASZ': 0,
    'JUHL': 0,
    'JUHLIN': 0,
    'JUHN': 0,
    'JUHNKE': 0,
    'JUHOLA': 0,
    'JUILFS': 0,
    'JUILLERAT': 0,
    'JUKER': 0,
    'JUKES': 0,
    'JUKIC': 0,
    'JUKICH': 0,
    'JULA': 0,
    'JULANDER': 0,
    'JULCA': 0,
    'JULE': 0.9345794392523364,
    'JULEE': 1,
    'JULENE': 1,
    'JULES': 0.8875739644970414,
    'JULI': 1,
    'JULIA': 0.9983882521489972,
    'JULIAN': 0.9087849209020532,
    'JULIANA': 0.9865470852017938,
    'JULIANE': 1,
    'JULIANI': 0,
    'JULIANN': 1,
    'JULIANNA': 1,
    'JULIANNE': 1,
    'JULIANO': 0,
    'JULIAO': 0,
    'JULIAR': 0,
    'JULIAS': 0,
    'JULICH': 0,
    'JULIE': 0.9997988910276668,
    'JULIEANN': 1,
    'JULIEN': 0,
    'JULIENNE': 1,
    'JULIET': 1,
    'JULIETA': 1,
    'JULIETTA': 1,
    'JULIETTE': 0.9950248756218906,
    'JULIN': 0,
    'JULIO': 0.9948702005285247,
    'JULIOT': 0,
    'JULIOUS': 0,
    'JULISSA': 1,
    'JULIUS': 0.970873786407767,
    'JULIUSSEN': 0,
    'JULKA': 0,
    'JULKOWSKI': 0,
    'JULL': 0,
    'JULSETH': 0,
    'JULSON': 0,
    'JULY': 0,
    'JUMA': 0,
    'JUMALON': 0,
    'JUMAN': 0,
    'JUMAWAN': 0,
    'JUMBO': 0,
    'JUMONVILLE': 0,
    'JUMP': 0,
    'JUMPER': 0,
    'JUMPP': 0,
    'JUMPS': 0,
    'JUN': 0,
    'JUNA': 0,
    'JUNAID': 0,
    'JUNAK': 0,
    'JUNCAJ': 0,
    'JUNCAL': 0,
    'JUNCK': 0,
    'JUNCKER': 0,
    'JUNCO': 0,
    'JUND': 0,
    'JUNDI': 0,
    'JUNDT': 0,
    'JUNE': 0.9886893933401882,
    'JUNEAU': 0,
    'JUNEJA': 0,
    'JUNEK': 0,
    'JUNELL': 0,
    'JUNEMAN': 0,
    'JUNEMANN': 0,
    'JUNES': 0,
    'JUNEZ': 0,
    'JUNG': 0.48192771084337355,
    'JUNGA': 0,
    'JUNGBAUER': 0,
    'JUNGBLUT': 0,
    'JUNGBLUTH': 0,
    'JUNGCK': 0,
    'JUNGCLAUS': 0,
    'JUNGE': 0,
    'JUNGELS': 0,
    'JUNGEMANN': 0,
    'JUNGEN': 0,
    'JUNGER': 0,
    'JUNGERMANN': 0,
    'JUNGERS': 0,
    'JUNGHANS': 0,
    'JUNGK': 0,
    'JUNGLAS': 0,
    'JUNGLES': 0,
    'JUNGLING': 0,
    'JUNGMAN': 0,
    'JUNGMANN': 0,
    'JUNGMEYER': 0,
    'JUNGO': 0,
    'JUNGQUIST': 0,
    'JUNGREIS': 0,
    'JUNGWIRTH': 0,
    'JUNI': 0,
    'JUNIE': 1,
    'JUNIEL': 0,
    'JUNIO': 0,
    'JUNIOR': 0.9557945041816011,
    'JUNIOUS': 0,
    'JUNIPER': 0,
    'JUNITA': 1,
    'JUNIUS': 0,
    'JUNK': 0,
    'JUNKER': 0,
    'JUNKERSFELD': 0,
    'JUNKERT': 0,
    'JUNKIN': 0,
    'JUNKINS': 0,
    'JUNKMAN': 0,
    'JUNKO': 1,
    'JUNN': 0,
    'JUNO': 0,
    'JUNOD': 0,
    'JUNOR': 0,
    'JUNOT': 0,
    'JUNQUERA': 0,
    'JUNTA': 0,
    'JUNTILLA': 0,
    'JUNTTI': 0,
    'JUNTUNEN': 0,
    'JUPE': 0,
    'JUPIN': 0,
    'JUPINA': 0,
    'JUPITER': 0,
    'JUPP': 0,
    'JURA': 0,
    'JURACEK': 0,
    'JURADO': 0,
    'JURAK': 0,
    'JURAN': 0,
    'JURANEK': 0,
    'JURAS': 0,
    'JURASEK': 0,
    'JURASIN': 0,
    'JURATOVAC': 0,
    'JURBALA': 0,
    'JURCA': 0,
    'JURCAK': 0,
    'JURCZAK': 0,
    'JURCZYK': 0,
    'JURDEN': 0,
    'JURDI': 0,
    'JURE': 0,
    'JURECKA': 0,
    'JURECKI': 0,
    'JUREK': 0,
    'JURENA': 0,
    'JURENKA': 0,
    'JUREWICZ': 0,
    'JUREY': 0,
    'JUREZ': 0,
    'JURGEN': 0,
    'JURGENS': 0,
    'JURGENSEN': 0,
    'JURGENSMEIER': 0,
    'JURGENSMEYER': 0,
    'JURGENSON': 0,
    'JURGIELEWICZ': 0,
    'JURI': 0,
    'JURIC': 0,
    'JURICA': 0,
    'JURICEK': 0,
    'JURICH': 0,
    'JURICIC': 0,
    'JURICK': 0,
    'JURIGA': 0,
    'JURIK': 0,
    'JURIN': 0,
    'JURINA': 0,
    'JURIS': 0,
    'JURISCH': 0,
    'JURISIC': 0,
    'JURISICH': 0,
    'JURIST': 0,
    'JURK': 0,
    'JURKIEWICZ': 0,
    'JURKOVIC': 0,
    'JURKOVICH': 0,
    'JURKOWSKI': 0,
    'JURMAN': 0,
    'JURMU': 0,
    'JURNEY': 0,
    'JURON': 0,
    'JURRENS': 0,
    'JURRIES': 0,
    'JURS': 0,
    'JURSKI': 0,
    'JURSS': 0,
    'JURUS': 0,
    'JURY': 0,
    'JUSCZAK': 0,
    'JUSIC': 0,
    'JUSINO': 0,
    'JUSKA': 0,
    'JUSKIEWICZ': 0,
    'JUSKO': 0,
    'JUSSAUME': 0,
    'JUSSEAUME': 0,
    'JUSSEL': 0,
    'JUSSILA': 0,
    'JUST': 0,
    'JUSTA': 0.9615384615384616,
    'JUSTE': 0,
    'JUSTEN': 0,
    'JUSTER': 0,
    'JUSTESEN': 0,
    'JUSTI': 0,
    'JUSTIC': 0,
    'JUSTICE': 0,
    'JUSTILIEN': 0,
    'JUSTIN': 0.9967200585931281,
    'JUSTINA': 1,
    'JUSTINE': 0.996483001172333,
    'JUSTINGER': 0,
    'JUSTINIANO': 0,
    'JUSTINO': 0,
    'JUSTIS': 0,
    'JUSTISON': 0,
    'JUSTISS': 0,
    'JUSTIZ': 0,
    'JUSTMAN': 0,
    'JUSTMANN': 0,
    'JUSTO': 0,
    'JUSTUS': 0,
    'JUSUFI': 0,
    'JUSZCZAK': 0,
    'JUSZCZYK': 0,
    'JUSZKIEWICZ': 0,
    'JUTILA': 0,
    'JUTRAS': 0,
    'JUTSON': 0,
    'JUTTA': 1,
    'JUTTE': 0,
    'JUTTING': 0,
    'JUTTON': 0,
    'JUTZ': 0,
    'JUTZI': 0,
    'JUUL': 0,
    'JUVAN': 0,
    'JUVE': 0,
    'JUVENAL': 0,
    'JUVERA': 0,
    'JUVINALL': 0,
    'JUZA': 0,
    'JUZWIAK': 0,
    'KA': 0.8264462809917356,
    'KAAE': 0,
    'KAAHANUI': 0,
    'KAAI': 0,
    'KAAIHUE': 0,
    'KAAKE': 0,
    'KAAN': 0,
    'KAAPANA': 0,
    'KAAR': 0,
    'KAAS': 0,
    'KAASA': 0,
    'KAASE': 0,
    'KAAT': 0,
    'KAATZ': 0,
    'KAAUAMO': 0,
    'KAAUWAI': 0,
    'KAAWA': 0,
    'KAAZ': 0,
    'KABA': 0,
    'KABACINSKI': 0,
    'KABACK': 0,
    'KABAK': 0,
    'KABALA': 0,
    'KABANA': 0,
    'KABANI': 0,
    'KABANUK': 0,
    'KABARA': 0,
    'KABAT': 0,
    'KABAY': 0,
    'KABBA': 0,
    'KABBANI': 0,
    'KABBARA': 0,
    'KABBES': 0,
    'KABE': 0,
    'KABEL': 0,
    'KABER': 0,
    'KABERLINE': 0,
    'KABES': 0,
    'KABIA': 0,
    'KABIGTING': 0,
    'KABIR': 0,
    'KABIRI': 0,
    'KABISCH': 0,
    'KABLE': 0,
    'KABLER': 0,
    'KABO': 0,
    'KABOT': 0,
    'KABRICH': 0,
    'KABRICK': 0,
    'KACALA': 0,
    'KACENA': 0,
    'KACER': 0,
    'KACEY': 1,
    'KACH': 0,
    'KACHADOORIAN': 0,
    'KACHEL': 0,
    'KACHELE': 0,
    'KACHELMEIER': 0,
    'KACHELMEYER': 0,
    'KACHELRIES': 0,
    'KACHER': 0,
    'KACHIGIAN': 0,
    'KACHIK': 0,
    'KACHINSKI': 0,
    'KACHINSKY': 0,
    'KACHLINE': 0,
    'KACHMAN': 0,
    'KACHMAR': 0,
    'KACHMARIK': 0,
    'KACHUR': 0,
    'KACHURAK': 0,
    'KACI': 1,
    'KACIC': 0,
    'KACIE': 1,
    'KACIN': 0,
    'KACIR': 0,
    'KACK': 0,
    'KACKLEY': 0,
    'KACKMAN': 0,
    'KACMAR': 0,
    'KACMARCIK': 0,
    'KACPROWICZ': 0,
    'KACPRZAK': 0,
    'KACSUR': 0,
    'KACVINSKY': 0,
    'KACY': 1,
    'KACZANOWSKI': 0,
    'KACZENSKI': 0,
    'KACZINSKI': 0,
    'KACZKA': 0,
    'KACZKOWSKI': 0,
    'KACZMAR': 0,
    'KACZMARCZYK': 0,
    'KACZMAREK': 0,
    'KACZMARK': 0,
    'KACZMAROWSKI': 0,
    'KACZMARSKI': 0,
    'KACZOR': 0,
    'KACZOROWSKI': 0,
    'KACZOWKA': 0,
    'KACZUR': 0,
    'KACZYNSKI': 0,
    'KADA': 0,
    'KADAKIA': 0,
    'KADAM': 0,
    'KADAN': 0,
    'KADAR': 0,
    'KADAS': 0,
    'KADAVY': 0,
    'KADDATZ': 0,
    'KADDOURA': 0,
    'KADE': 0,
    'KADEL': 0,
    'KADELL': 0,
    'KADEN': 0,
    'KADER': 0,
    'KADERA': 0,
    'KADERABEK': 0,
    'KADERKA': 0,
    'KADERLI': 0,
    'KADERLIK': 0,
    'KADERLY': 0,
    'KADET': 0,
    'KADI': 0,
    'KADIC': 0,
    'KADIN': 0,
    'KADING': 0,
    'KADINGER': 0,
    'KADIR': 0,
    'KADIRI': 0,
    'KADIS': 0,
    'KADISH': 0,
    'KADISON': 0,
    'KADIYALA': 0,
    'KADLE': 0,
    'KADLEC': 0,
    'KADLECEK': 0,
    'KADLECIK': 0,
    'KADLETZ': 0,
    'KADLICK': 0,
    'KADLUBOWSKI': 0,
    'KADNER': 0,
    'KADO': 0,
    'KADOLPH': 0,
    'KADOR': 0,
    'KADOSH': 0,
    'KADOTA': 0,
    'KADOW': 0,
    'KADOWAKI': 0,
    'KADRI': 0,
    'KADRIC': 0,
    'KADRICH': 0,
    'KADRLIK': 0,
    'KADRMAS': 0,
    'KADUCE': 0,
    'KADUK': 0,
    'KADWELL': 0,
    'KADY': 0,
    'KAE': 0,
    'KAEB': 0,
    'KAEBISCH': 0,
    'KAECH': 0,
    'KAECHELE': 0,
    'KAECK': 0,
    'KAEDING': 0,
    'KAEFER': 0,
    'KAEGI': 0,
    'KAEHLER': 0,
    'KAEHN': 0,
    'KAEHR': 0,
    'KAELBER': 0,
    'KAELBERER': 0,
    'KAELIN': 0,
    'KAEMMER': 0,
    'KAEMMERER': 0,
    'KAEMMERLING': 0,
    'KAEMPF': 0,
    'KAEMPFE': 0,
    'KAEMPFER': 0,
    'KAEO': 0,
    'KAEPPEL': 0,
    'KAER': 0,
    'KAERCHER': 0,
    'KAES': 0,
    'KAESEMEYER': 0,
    'KAESER': 0,
    'KAESS': 0,
    'KAESTNER': 0,
    'KAETTERHENRY': 0,
    'KAETZEL': 0,
    'KAFANTARIS': 0,
    'KAFEL': 0,
    'KAFER': 0,
    'KAFF': 0,
    'KAFFENBERGER': 0,
    'KAFFER': 0,
    'KAFFKA': 0,
    'KAFKA': 0,
    'KAFTAN': 0,
    'KAFTON': 0,
    'KAGAN': 0,
    'KAGANOVICH': 0,
    'KAGARICE': 0,
    'KAGARISE': 0,
    'KAGAWA': 0,
    'KAGAY': 0,
    'KAGE': 0,
    'KAGEL': 0,
    'KAGEN': 0,
    'KAGER': 0,
    'KAGEY': 0,
    'KAGEYAMA': 0,
    'KAGLE': 0,
    'KAGLEY': 0,
    'KAGY': 0,
    'KAH': 0,
    'KAHABKA': 0,
    'KAHALA': 0,
    'KAHALE': 0,
    'KAHALEWAI': 0,
    'KAHAN': 0,
    'KAHANA': 0,
    'KAHANE': 0,
    'KAHANEK': 0,
    'KAHANU': 0,
    'KAHAPEA': 0,
    'KAHAWAI': 0,
    'KAHELE': 0,
    'KAHEN': 0,
    'KAHIKINA': 0,
    'KAHIL': 0,
    'KAHILL': 0,
    'KAHKONEN': 0,
    'KAHL': 0,
    'KAHLA': 0,
    'KAHLE': 0,
    'KAHLENBERG': 0,
    'KAHLER': 0,
    'KAHLERT': 0,
    'KAHLES': 0,
    'KAHLEY': 0,
    'KAHLHAMER': 0,
    'KAHLICH': 0,
    'KAHLIG': 0,
    'KAHLKE': 0,
    'KAHLON': 0,
    'KAHLOW': 0,
    'KAHLSTORF': 0,
    'KAHM': 0,
    'KAHMANN': 0,
    'KAHN': 0,
    'KAHNE': 0,
    'KAHNG': 0,
    'KAHNKE': 0,
    'KAHNY': 0,
    'KAHO': 0,
    'KAHOE': 0,
    'KAHOOKELE': 0,
    'KAHOONEI': 0,
    'KAHOUN': 0,
    'KAHR': 0,
    'KAHRAMAN': 0,
    'KAHRE': 0,
    'KAHRIG': 0,
    'KAHRS': 0,
    'KAHSAY': 0,
    'KAHUE': 0,
    'KAHUT': 0,
    'KAI': 0.7407407407407407,
    'KAIB': 0,
    'KAID': 0,
    'KAIDEN': 0,
    'KAIDER': 0,
    'KAIER': 0,
    'KAIGHIN': 0,
    'KAIGHN': 0,
    'KAIGLER': 0,
    'KAIL': 0,
    'KAILA': 0.9615384615384616,
    'KAILER': 0,
    'KAILEY': 0,
    'KAILI': 0,
    'KAILING': 0,
    'KAIM': 0,
    'KAIMAN': 0,
    'KAIMANN': 0,
    'KAIN': 0,
    'KAINA': 0,
    'KAINE': 0,
    'KAINER': 0,
    'KAING': 0,
    'KAINTZ': 0,
    'KAINZ': 0,
    'KAIO': 0,
    'KAIRIS': 0,
    'KAIRYS': 0,
    'KAIS': 0,
    'KAISER': 0,
    'KAISERMAN': 0,
    'KAISLER': 0,
    'KAISNER': 0,
    'KAITLIN': 1,
    'KAITLYN': 1,
    'KAITZ': 0,
    'KAIWI': 0,
    'KAIZER': 0,
    'KAJA': 0,
    'KAJER': 0,
    'KAJFASZ': 0,
    'KAJI': 0,
    'KAJIKAWA': 0,
    'KAJIOKA': 0,
    'KAJITA': 0,
    'KAJIWARA': 0,
    'KAJIYAMA': 0,
    'KAJTAZOVIC': 0,
    'KAJTEZOVIC': 0,
    'KAJY': 0,
    'KAKALIA': 0,
    'KAKAR': 0,
    'KAKAREKA': 0,
    'KAKAZU': 0,
    'KAKER': 0,
    'KAKISH': 0,
    'KAKKAR': 0,
    'KAKO': 0,
    'KAKOS': 0,
    'KAKU': 0,
    'KAKUDA': 0,
    'KAKUK': 0,
    'KAL': 0,
    'KALA': 0.9592326139088729,
    'KALAF': 0,
    'KALAFATIS': 0,
    'KALAFUT': 0,
    'KALAGHER': 0,
    'KALAGIAN': 0,
    'KALAHAR': 0,
    'KALAHER': 0,
    'KALAHIKI': 0,
    'KALAI': 0,
    'KALAITZIDIS': 0,
    'KALAJ': 0,
    'KALAJIAN': 0,
    'KALAKAY': 0,
    'KALAL': 0,
    'KALAM': 0,
    'KALAMA': 0,
    'KALAMARAS': 0,
    'KALAN': 0,
    'KALANI': 0,
    'KALANQUIN': 0,
    'KALANTARI': 0,
    'KALANTAROVA': 0,
    'KALANTZIS': 0,
    'KALAPOS': 0,
    'KALAR': 0,
    'KALAS': 0,
    'KALASH': 0,
    'KALASHIAN': 0,
    'KALASKY': 0,
    'KALAT': 0,
    'KALATA': 0,
    'KALAW': 0,
    'KALAYDJIAN': 0,
    'KALAYJIAN': 0,
    'KALB': 0,
    'KALBACH': 0,
    'KALBACHER': 0,
    'KALBAUGH': 0,
    'KALBER': 0,
    'KALBERER': 0,
    'KALBERG': 0,
    'KALBFELL': 0,
    'KALBFLEISCH': 0,
    'KALBUS': 0,
    'KALCEVIC': 0,
    'KALCHBRENNER': 0,
    'KALCHIK': 0,
    'KALCHTHALER': 0,
    'KALCIC': 0,
    'KALCICH': 0,
    'KALDAHL': 0,
    'KALDAS': 0,
    'KALDENBERG': 0,
    'KALDIS': 0,
    'KALDOR': 0,
    'KALE': 0,
    'KALEAL': 0,
    'KALEBAUGH': 0,
    'KALEDA': 0,
    'KALEEL': 0,
    'KALEEM': 0,
    'KALEIGH': 1,
    'KALEIKINI': 0,
    'KALEITA': 0,
    'KALEM': 0,
    'KALEMBA': 0,
    'KALEMBER': 0,
    'KALEN': 0,
    'KALENDA': 0,
    'KALENDER': 0,
    'KALEO': 0,
    'KALER': 0,
    'KALES': 0,
    'KALET': 0,
    'KALETA': 0,
    'KALETTA': 0,
    'KALEY': 0.8695652173913043,
    'KALFAS': 0,
    'KALFAYAN': 0,
    'KALFUS': 0,
    'KALGREN': 0,
    'KALHORN': 0,
    'KALI': 0.9523809523809523,
    'KALIA': 0,
    'KALIAN': 0,
    'KALICH': 0,
    'KALICHARAN': 0,
    'KALICK': 0,
    'KALICKI': 0,
    'KALIDINDI': 0,
    'KALIE': 0,
    'KALIES': 0,
    'KALIHER': 0,
    'KALIK': 0,
    'KALIKA': 0,
    'KALIL': 0,
    'KALILI': 0,
    'KALILIKANE': 0,
    'KALIMA': 0,
    'KALIN': 0,
    'KALINA': 0,
    'KALINE': 0,
    'KALINEC': 0,
    'KALINICH': 0,
    'KALININ': 0,
    'KALINKA': 0,
    'KALINOSKI': 0,
    'KALINOWSKI': 0,
    'KALINSKI': 0,
    'KALINSKY': 0,
    'KALINYAK': 0,
    'KALIS': 0,
    'KALISCH': 0,
    'KALISEK': 0,
    'KALISH': 0,
    'KALISKI': 0,
    'KALISTA': 0,
    'KALISZ': 0,
    'KALISZEWSKI': 0,
    'KALITA': 0,
    'KALIVAS': 0,
    'KALIVODA': 0,
    'KALK': 0,
    'KALKA': 0,
    'KALKAT': 0,
    'KALKBRENNER': 0,
    'KALKE': 0,
    'KALKHOFF': 0,
    'KALKMAN': 0,
    'KALKOFEN': 0,
    'KALKOWSKI': 0,
    'KALKSTEIN': 0,
    'KALKWARF': 0,
    'KALL': 0,
    'KALLA': 0,
    'KALLABAT': 0,
    'KALLAHER': 0,
    'KALLAL': 0,
    'KALLAM': 0,
    'KALLAN': 0,
    'KALLAND': 0,
    'KALLANDER': 0,
    'KALLAS': 0,
    'KALLAUS': 0,
    'KALLAY': 0,
    'KALLBERG': 0,
    'KALLE': 0,
    'KALLEM': 0,
    'KALLEMEYN': 0,
    'KALLEN': 0,
    'KALLENBACH': 0,
    'KALLENBERG': 0,
    'KALLENBERGER': 0,
    'KALLENBORN': 0,
    'KALLER': 0,
    'KALLESTAD': 0,
    'KALLESTEWA': 0,
    'KALLEVIG': 0,
    'KALLEY': 0,
    'KALLFELZ': 0,
    'KALLGREN': 0,
    'KALLHOFF': 0,
    'KALLIE': 0.9523809523809523,
    'KALLIES': 0,
    'KALLIN': 0,
    'KALLINA': 0,
    'KALLINEN': 0,
    'KALLIO': 0,
    'KALLIS': 0,
    'KALLISH': 0,
    'KALLMAN': 0,
    'KALLMANN': 0,
    'KALLMEYER': 0,
    'KALLNER': 0,
    'KALLO': 0,
    'KALLOCH': 0,
    'KALLOK': 0,
    'KALLON': 0,
    'KALLOO': 0,
    'KALLOS': 0,
    'KALLSEN': 0,
    'KALLSTROM': 0,
    'KALLUNKI': 0,
    'KALLUS': 0,
    'KALLWEIT': 0,
    'KALM': 0,
    'KALMA': 0,
    'KALMAN': 0,
    'KALMANSON': 0,
    'KALMAR': 0,
    'KALMBACH': 0,
    'KALMER': 0,
    'KALMES': 0,
    'KALMON': 0,
    'KALMUS': 0,
    'KALNA': 0,
    'KALNAS': 0,
    'KALNINS': 0,
    'KALO': 0,
    'KALOGERAS': 0,
    'KALOGEROPOULOS': 0,
    'KALOS': 0,
    'KALOSKY': 0,
    'KALOTA': 0,
    'KALOUDIS': 0,
    'KALOUS': 0,
    'KALOUSEK': 0,
    'KALOUSTIAN': 0,
    'KALP': 0,
    'KALPAKOFF': 0,
    'KALPIN': 0,
    'KALRA': 0,
    'KALSBEEK': 0,
    'KALSCHEUER': 0,
    'KALSCHEUR': 0,
    'KALSI': 0,
    'KALSKI': 0,
    'KALSON': 0,
    'KALSOW': 0,
    'KALSTAD': 0,
    'KALSTROM': 0,
    'KALT': 0,
    'KALTENBACH': 0,
    'KALTENBAUGH': 0,
    'KALTENBERG': 0,
    'KALTER': 0,
    'KALTHOFF': 0,
    'KALTMAN': 0,
    'KALTREIDER': 0,
    'KALTSAS': 0,
    'KALTWASSER': 0,
    'KALTZ': 0,
    'KALU': 0,
    'KALUA': 0,
    'KALUGIN': 0,
    'KALUHIOKALANI': 0,
    'KALUNA': 0,
    'KALUPA': 0,
    'KALUS': 0,
    'KALUSH': 0,
    'KALUSTIAN': 0,
    'KALUZA': 0,
    'KALUZNY': 0,
    'KALVAITIS': 0,
    'KALVELAGE': 0,
    'KALVIG': 0,
    'KALVIN': 0,
    'KALVODA': 0,
    'KALWA': 0,
    'KALWEIT': 0,
    'KALYAN': 0,
    'KALYN': 1,
    'KAM': 0.617283950617284,
    'KAMA': 0,
    'KAMADA': 0,
    'KAMAE': 0,
    'KAMAHELE': 0,
    'KAMAI': 0,
    'KAMAKA': 0,
    'KAMAL': 0,
    'KAMALA': 1,
    'KAMALI': 0,
    'KAMALII': 0,
    'KAMALU': 0,
    'KAMAN': 0,
    'KAMANI': 0,
    'KAMANN': 0,
    'KAMANU': 0,
    'KAMAR': 0,
    'KAMARA': 0,
    'KAMAS': 0,
    'KAMAT': 0,
    'KAMATA': 0,
    'KAMATH': 0,
    'KAMAU': 0,
    'KAMB': 0,
    'KAMBA': 0,
    'KAMBEITZ': 0,
    'KAMBER': 0,
    'KAMBIC': 0,
    'KAMBLE': 0,
    'KAMBOJ': 0,
    'KAMBOURIS': 0,
    'KAMDAR': 0,
    'KAME': 0,
    'KAMEDA': 0,
    'KAMEI': 0,
    'KAMEL': 0,
    'KAMEN': 0,
    'KAMENAR': 0,
    'KAMENETSKY': 0,
    'KAMENICKY': 0,
    'KAMENS': 0,
    'KAMENSKI': 0,
    'KAMENSKY': 0,
    'KAMER': 0,
    'KAMERER': 0,
    'KAMERLING': 0,
    'KAMERMAN': 0,
    'KAMEROFF': 0,
    'KAMERON': 0,
    'KAMERY': 0,
    'KAMHI': 0,
    'KAMHOLZ': 0,
    'KAMI': 0.9828009828009829,
    'KAMIEN': 0,
    'KAMIENIECKI': 0,
    'KAMIENSKI': 0,
    'KAMIKAWA': 0,
    'KAMIL': 0,
    'KAMILAH': 1,
    'KAMIMURA': 0,
    'KAMIN': 0,
    'KAMINE': 0,
    'KAMINER': 0,
    'KAMINS': 0,
    'KAMINSKA': 0,
    'KAMINSKAS': 0,
    'KAMINSKAYA': 0,
    'KAMINSKE': 0,
    'KAMINSKI': 0,
    'KAMINSKY': 0,
    'KAMIS': 0,
    'KAMISATO': 0,
    'KAMISH': 0,
    'KAMIYA': 0,
    'KAMIYAMA': 0,
    'KAMKA': 0,
    'KAMKAR': 0,
    'KAMKE': 0,
    'KAML': 0,
    'KAMLA': 0,
    'KAMLER': 0,
    'KAMLET': 0,
    'KAMM': 0,
    'KAMMAN': 0,
    'KAMMANN': 0,
    'KAMMEL': 0,
    'KAMMER': 0,
    'KAMMERAAD': 0,
    'KAMMERDIENER': 0,
    'KAMMERER': 0,
    'KAMMERMAN': 0,
    'KAMMERS': 0,
    'KAMMERUD': 0,
    'KAMMERZELL': 0,
    'KAMMES': 0,
    'KAMMEYER': 0,
    'KAMMINGA': 0,
    'KAMMLER': 0,
    'KAMO': 0,
    'KAMON': 0,
    'KAMOWSKI': 0,
    'KAMP': 0,
    'KAMPA': 0,
    'KAMPAS': 0,
    'KAMPBELL': 0,
    'KAMPE': 0,
    'KAMPEL': 0,
    'KAMPEN': 0,
    'KAMPER': 0,
    'KAMPERMAN': 0,
    'KAMPERT': 0,
    'KAMPF': 0,
    'KAMPFE': 0,
    'KAMPFER': 0,
    'KAMPH': 0,
    'KAMPHAUS': 0,
    'KAMPHUIS': 0,
    'KAMPLAIN': 0,
    'KAMPMAN': 0,
    'KAMPMANN': 0,
    'KAMPMEIER': 0,
    'KAMPMEYER': 0,
    'KAMPPI': 0,
    'KAMPRATH': 0,
    'KAMPS': 0,
    'KAMPSCHROEDER': 0,
    'KAMPSEN': 0,
    'KAMPWERTH': 0,
    'KAMRAD': 0,
    'KAMRADT': 0,
    'KAMRAN': 0,
    'KAMRATH': 0,
    'KAMROWSKI': 0,
    'KAMSTRA': 0,
    'KAMUDA': 0,
    'KAMUF': 0,
    'KAMYSZ': 0,
    'KAMYSZEK': 0,
    'KAN': 0,
    'KANA': 0,
    'KANAAN': 0,
    'KANABLE': 0,
    'KANABY': 0,
    'KANACH': 0,
    'KANACK': 0,
    'KANADA': 0,
    'KANADAY': 0,
    'KANADY': 0,
    'KANAE': 0,
    'KANAGA': 0,
    'KANAGY': 0,
    'KANAHELE': 0,
    'KANAI': 0,
    'KANAK': 0,
    'KANAKIS': 0,
    'KANALEY': 0,
    'KANALY': 0,
    'KANAMORI': 0,
    'KANAN': 0,
    'KANANEN': 0,
    'KANANI': 0,
    'KANAR': 0,
    'KANARD': 0,
    'KANAREK': 0,
    'KANARIS': 0,
    'KANARR': 0,
    'KANARY': 0,
    'KANAS': 0,
    'KANASKIE': 0,
    'KANATZAR': 0,
    'KANAVEL': 0,
    'KANAVOS': 0,
    'KANAVY': 0,
    'KANAZAWA': 0,
    'KANDA': 0,
    'KANDACE': 1,
    'KANDAH': 0,
    'KANDARIAN': 0,
    'KANDASAMY': 0,
    'KANDEFER': 0,
    'KANDEL': 0,
    'KANDELL': 0,
    'KANDER': 0,
    'KANDI': 1,
    'KANDICE': 1,
    'KANDIL': 0,
    'KANDIS': 1,
    'KANDL': 0,
    'KANDLE': 0,
    'KANDLER': 0,
    'KANDO': 0,
    'KANDOLA': 0,
    'KANDOLL': 0,
    'KANDRA': 0.9259259259259258,
    'KANDRAC': 0,
    'KANDT': 0,
    'KANDY': 1,
    'KANE': 0,
    'KANEAKUA': 0,
    'KANEASTER': 0,
    'KANEDA': 0,
    'KANEFSKY': 0,
    'KANEHAILUA': 0,
    'KANEHL': 0,
    'KANEKO': 0,
    'KANEKOA': 0,
    'KANEL': 0,
    'KANELLIS': 0,
    'KANELLOPOULOS': 0,
    'KANELLOS': 0,
    'KANELOS': 0,
    'KANEMITSU': 0,
    'KANEMOTO': 0,
    'KANER': 0,
    'KANERVA': 0,
    'KANES': 0,
    'KANESHA': 1,
    'KANESHIGE': 0,
    'KANESHIRO': 0,
    'KANESKI': 0,
    'KANETA': 0,
    'KANEVSKY': 0,
    'KANEY': 0,
    'KANFER': 0,
    'KANG': 0,
    'KANGAS': 0,
    'KANGER': 0,
    'KANGISER': 0,
    'KANHAI': 0,
    'KANI': 0,
    'KANIA': 0,
    'KANICKI': 0,
    'KANIECKI': 0,
    'KANIES': 0,
    'KANIESKI': 0,
    'KANIEWSKI': 0,
    'KANIHO': 0,
    'KANIK': 0,
    'KANIPE': 0,
    'KANIS': 0,
    'KANISHA': 1,
    'KANITZ': 0,
    'KANJI': 0,
    'KANKA': 0,
    'KANKE': 0,
    'KANKEL': 0,
    'KANN': 0,
    'KANNA': 0,
    'KANNADY': 0,
    'KANNAN': 0,
    'KANNAPEL': 0,
    'KANNARD': 0,
    'KANNAS': 0,
    'KANNE': 0,
    'KANNEGIETER': 0,
    'KANNEL': 0,
    'KANNENBERG': 0,
    'KANNER': 0,
    'KANNEY': 0,
    'KANNIARD': 0,
    'KANNING': 0,
    'KANNO': 0,
    'KANNON': 0,
    'KANO': 0,
    'KANOA': 0,
    'KANODE': 0,
    'KANOFF': 0,
    'KANOFSKY': 0,
    'KANOHO': 0,
    'KANOS': 0,
    'KANOUFF': 0,
    'KANOUSE': 0,
    'KANOWITZ': 0,
    'KANOY': 0,
    'KANOZA': 0,
    'KANSAL': 0,
    'KANSARA': 0,
    'KANSAS': 0,
    'KANSIER': 0,
    'KANSKI': 0,
    'KANSKY': 0,
    'KANSTEINER': 0,
    'KANT': 0,
    'KANTA': 0,
    'KANTAK': 0,
    'KANTAR': 0,
    'KANTAREVIC': 0,
    'KANTE': 0,
    'KANTER': 0,
    'KANTERMAN': 0,
    'KANTHACK': 0,
    'KANTHAK': 0,
    'KANTNER': 0,
    'KANTOLA': 0,
    'KANTOR': 0,
    'KANTOROVICH': 0,
    'KANTOROWSKI': 0,
    'KANTORSKI': 0,
    'KANTOWSKI': 0,
    'KANTROWITZ': 0,
    'KANTZ': 0,
    'KANTZER': 0,
    'KANU': 0,
    'KANUCH': 0,
    'KANUCK': 0,
    'KANUHA': 0,
    'KANUHO': 0,
    'KANUPP': 0,
    'KANWAL': 0,
    'KANWAR': 0,
    'KANWISCHER': 0,
    'KANY': 0,
    'KANYA': 0,
    'KANYO': 0,
    'KANYUCK': 0,
    'KANZ': 0,
    'KANZAKI': 0,
    'KANZENBACH': 0,
    'KANZIG': 0,
    'KANZLER': 0,
    'KAO': 0,
    'KAOPUA': 0,
    'KAOPUIKI': 0,
    'KAOUD': 0,
    'KAOUGH': 0,
    'KAP': 0,
    'KAPA': 0,
    'KAPADIA': 0,
    'KAPALA': 0,
    'KAPALKA': 0,
    'KAPALKO': 0,
    'KAPANKE': 0,
    'KAPANOWSKI': 0,
    'KAPASI': 0,
    'KAPAUN': 0,
    'KAPCZYNSKI': 0,
    'KAPEL': 0,
    'KAPELA': 0,
    'KAPELL': 0,
    'KAPELLA': 0,
    'KAPELLEN': 0,
    'KAPELLER': 0,
    'KAPER': 0,
    'KAPES': 0,
    'KAPETANAKIS': 0,
    'KAPETANOVIC': 0,
    'KAPFER': 0,
    'KAPFHAMMER': 0,
    'KAPHINGST': 0,
    'KAPIC': 0,
    'KAPICA': 0,
    'KAPIL': 0,
    'KAPILA': 0,
    'KAPING': 0,
    'KAPINOS': 0,
    'KAPINUS': 0,
    'KAPIT': 0,
    'KAPITAN': 0,
    'KAPITULA': 0,
    'KAPKA': 0,
    'KAPKE': 0,
    'KAPLA': 0,
    'KAPLAN': 0,
    'KAPLANIS': 0,
    'KAPLANSKY': 0,
    'KAPLE': 0,
    'KAPLER': 0,
    'KAPLIN': 0,
    'KAPLINSKI': 0,
    'KAPLON': 0,
    'KAPLOW': 0,
    'KAPLOWITZ': 0,
    'KAPLUN': 0,
    'KAPNER': 0,
    'KAPNICK': 0,
    'KAPOLKA': 0,
    'KAPOOR': 0,
    'KAPP': 0,
    'KAPPA': 0,
    'KAPPAS': 0,
    'KAPPAUF': 0,
    'KAPPE': 0,
    'KAPPEL': 0,
    'KAPPELER': 0,
    'KAPPELL': 0,
    'KAPPELMAN': 0,
    'KAPPELMANN': 0,
    'KAPPEN': 0,
    'KAPPENMAN': 0,
    'KAPPER': 0,
    'KAPPERMAN': 0,
    'KAPPERS': 0,
    'KAPPES': 0,
    'KAPPESSER': 0,
    'KAPPHAHN': 0,
    'KAPPLE': 0,
    'KAPPLER': 0,
    'KAPPMEYER': 0,
    'KAPPOS': 0,
    'KAPPS': 0,
    'KAPPUS': 0,
    'KAPRAL': 0,
    'KAPRAUN': 0,
    'KAPRELIAN': 0,
    'KAPRIELIAN': 0,
    'KAPRON': 0,
    'KAPS': 0,
    'KAPSA': 0,
    'KAPSALIS': 0,
    'KAPSCH': 0,
    'KAPSNER': 0,
    'KAPTAIN': 0,
    'KAPTEIN': 0,
    'KAPTEYN': 0,
    'KAPTUR': 0,
    'KAPU': 0,
    'KAPUA': 0,
    'KAPULE': 0,
    'KAPUR': 0,
    'KAPUS': 0,
    'KAPUSCINSKI': 0,
    'KAPUSTA': 0,
    'KAPUSTIN': 0,
    'KAPUSTKA': 0,
    'KAPUT': 0,
    'KAPUTA': 0,
    'KAQUATOSH': 0,
    'KAR': 0,
    'KARA': 0.9903381642512078,
    'KARABA': 0,
    'KARABATSOS': 0,
    'KARABEGOVIC': 0,
    'KARABELAS': 0,
    'KARABETSOS': 0,
    'KARABIN': 0,
    'KARABINOS': 0,
    'KARADIMAS': 0,
    'KARADSHEH': 0,
    'KARAFA': 0,
    'KARAFFA': 0,
    'KARAGEORGE': 0,
    'KARAGIANIS': 0,
    'KARAGIANNIS': 0,
    'KARAGOZIAN': 0,
    'KARAHALIOS': 0,
    'KARAJIC': 0,
    'KARAKAS': 0,
    'KARAKASHIAN': 0,
    'KARAKO': 0,
    'KARALEKAS': 0,
    'KARALES': 0,
    'KARALIS': 0,
    'KARALIUS': 0,
    'KARALUS': 0,
    'KARAM': 0,
    'KARAMAN': 0,
    'KARAMANOS': 0,
    'KARAMBELAS': 0,
    'KARAMI': 0,
    'KARAN': 0.9202453987730062,
    'KARANDIKAR': 0,
    'KARANJA': 0,
    'KARAPETIAN': 0,
    'KARAPETYAN': 0,
    'KARAS': 0,
    'KARASCH': 0,
    'KARASEK': 0,
    'KARASH': 0,
    'KARASICK': 0,
    'KARASIEWICZ': 0,
    'KARASIK': 0,
    'KARASINSKI': 0,
    'KARASZEWSKI': 0,
    'KARATZAS': 0,
    'KARAU': 0,
    'KARAUS': 0,
    'KARAVAS': 0,
    'KARAYAN': 0,
    'KARBACH': 0,
    'KARBAN': 0,
    'KARBER': 0,
    'KARBERG': 0,
    'KARBO': 0,
    'KARBON': 0,
    'KARBOSKI': 0,
    'KARBOWSKI': 0,
    'KARCH': 0,
    'KARCHER': 0,
    'KARCHMER': 0,
    'KARCHNER': 0,
    'KARCICH': 0,
    'KARCZ': 0,
    'KARCZEWSKI': 0,
    'KARD': 0,
    'KARDARAS': 0,
    'KARDAS': 0,
    'KARDASH': 0,
    'KARDASZ': 0,
    'KARDATZKE': 0,
    'KARDEL': 0,
    'KARDELL': 0,
    'KARDON': 0,
    'KARDOS': 0,
    'KARDYS': 0,
    'KARE': 0,
    'KARECKI': 0,
    'KAREEM': 0.9724473257698543,
    'KAREEN': 1,
    'KAREL': 0,
    'KARELL': 0,
    'KARELS': 0,
    'KAREM': 0,
    'KAREN': 0.9995504270942603,
    'KARENA': 1,
    'KARENBAUER': 0,
    'KARES': 0,
    'KARESH': 0,
    'KAREY': 0.9708737864077669,
    'KARG': 0,
    'KARGBO': 0,
    'KARGE': 0,
    'KARGEL': 0,
    'KARGER': 0,
    'KARGES': 0,
    'KARGL': 0,
    'KARGOL': 0,
    'KARGUS': 0,
    'KARHOFF': 0,
    'KARHU': 0,
    'KARI': 0.993103448275862,
    'KARIA': 0,
    'KARIAN': 0,
    'KARIBIAN': 0,
    'KARIC': 0,
    'KARICH': 0,
    'KARICKHOFF': 0,
    'KARIDES': 0,
    'KARIDIS': 0,
    'KARIE': 0.986842105263158,
    'KARIKARI': 0,
    'KARIM': 0,
    'KARIMA': 1,
    'KARIMI': 0,
    'KARIMIAN': 0,
    'KARIN': 0.9962640099626401,
    'KARINA': 1,
    'KARINE': 1,
    'KARINEN': 0,
    'KARINS': 0,
    'KARIOTIS': 0,
    'KARIS': 0,
    'KARISA': 1,
    'KARISH': 0,
    'KARISSA': 1,
    'KARIUKI': 0,
    'KARIUS': 0,
    'KARIYA': 0,
    'KARJALA': 0,
    'KARK': 0,
    'KARKER': 0,
    'KARKI': 0,
    'KARKLINS': 0,
    'KARKOS': 0,
    'KARKOSKA': 0,
    'KARKOSKI': 0,
    'KARKOWSKI': 0,
    'KARKULA': 0,
    'KARKUT': 0,
    'KARL': 0.9690186979664256,
    'KARLA': 0.9988649262202043,
    'KARLAK': 0,
    'KARLAN': 0,
    'KARLBERG': 0,
    'KARLE': 0,
    'KARLEEN': 1,
    'KARLEN': 0,
    'KARLENE': 1,
    'KARLESKINT': 0,
    'KARLEY': 0,
    'KARLI': 0,
    'KARLIC': 0,
    'KARLIK': 0,
    'KARLIN': 0,
    'KARLING': 0,
    'KARLINSEY': 0,
    'KARLINSKI': 0,
    'KARLINSKY': 0,
    'KARLIS': 0,
    'KARLL': 0,
    'KARLO': 0,
    'KARLOFF': 0,
    'KARLOVIC': 0,
    'KARLOVICH': 0,
    'KARLOWICZ': 0,
    'KARLOWSKI': 0,
    'KARLS': 0,
    'KARLSEN': 0,
    'KARLSON': 0,
    'KARLSSON': 0,
    'KARLSTAD': 0,
    'KARLSTROM': 0,
    'KARLY': 1,
    'KARLYN': 1,
    'KARM': 0,
    'KARMA': 1,
    'KARMAN': 0,
    'KARMANN': 0,
    'KARMAZIN': 0,
    'KARMAZYN': 0,
    'KARMEL': 0,
    'KARMEN': 0.9803921568627452,
    'KARMO': 0,
    'KARN': 0,
    'KARNA': 0,
    'KARNAFEL': 0,
    'KARNAS': 0,
    'KARNATH': 0,
    'KARNATZ': 0,
    'KARNAVAS': 0,
    'KARNBACH': 0,
    'KARNEHM': 0,
    'KARNER': 0,
    'KARNES': 0,
    'KARNEY': 0,
    'KARNEZIS': 0,
    'KARNICK': 0,
    'KARNIK': 0,
    'KARNIS': 0,
    'KARNISH': 0,
    'KARNITZ': 0,
    'KARNO': 0,
    'KARNOPP': 0,
    'KARNOWSKI': 0,
    'KARNS': 0,
    'KARNUTH': 0,
    'KARO': 0,
    'KAROL': 0.922509225092251,
    'KAROLAK': 0,
    'KAROLCZAK': 0,
    'KAROLE': 1,
    'KAROLEWICZ': 0,
    'KAROLEWSKI': 0,
    'KAROLINE': 1,
    'KAROLY': 0,
    'KAROLYI': 0,
    'KAROLYN': 1,
    'KARON': 0.9727626459143969,
    'KAROS': 0,
    'KAROUNOS': 0,
    'KAROUTSOS': 0,
    'KAROW': 0,
    'KARP': 0,
    'KARPA': 0,
    'KARPAN': 0,
    'KARPE': 0,
    'KARPEL': 0,
    'KARPEN': 0,
    'KARPENKO': 0,
    'KARPER': 0,
    'KARPF': 0,
    'KARPIAK': 0,
    'KARPIEL': 0,
    'KARPIK': 0,
    'KARPIN': 0,
    'KARPINEN': 0,
    'KARPINSKI': 0,
    'KARPINSKY': 0,
    'KARPMAN': 0,
    'KARPOFF': 0,
    'KARPOV': 0,
    'KARPOVICH': 0,
    'KARPOWICH': 0,
    'KARPOWICZ': 0,
    'KARPPINEN': 0,
    'KARPUK': 0,
    'KARPUS': 0,
    'KARR': 0,
    'KARRA': 0,
    'KARRAKER': 0,
    'KARRAM': 0,
    'KARRAS': 0,
    'KARRASCH': 0,
    'KARRATTI': 0,
    'KARRE': 0,
    'KARRELS': 0,
    'KARREN': 0.8928571428571428,
    'KARRER': 0,
    'KARRES': 0,
    'KARRH': 0,
    'KARRI': 0.986842105263158,
    'KARRICK': 0,
    'KARRIE': 1,
    'KARRIEM': 0,
    'KARRIGAN': 0,
    'KARRIKER': 0,
    'KARRIS': 0,
    'KARROW': 0,
    'KARRY': 0.9433962264150944,
    'KARSCH': 0,
    'KARSCHNER': 0,
    'KARSCHNIK': 0,
    'KARSEN': 0,
    'KARSH': 0,
    'KARSHNER': 0,
    'KARSJENS': 0,
    'KARSKI': 0,
    'KARSKY': 0,
    'KARSNER': 0,
    'KARSON': 0,
    'KARST': 0,
    'KARSTAEDT': 0,
    'KARSTEDT': 0,
    'KARSTEN': 0,
    'KARSTENS': 0,
    'KARSTETTER': 0,
    'KART': 0,
    'KARTAK': 0,
    'KARTCHNER': 0,
    'KARTEN': 0,
    'KARTER': 0,
    'KARTES': 0,
    'KARTH': 0,
    'KARTHEISER': 0,
    'KARTHIKEYAN': 0,
    'KARTMAN': 0,
    'KARTY': 0,
    'KARTZ': 0,
    'KARUNAKARAN': 0,
    'KARUNARATNE': 0,
    'KARVELAS': 0,
    'KARVELIS': 0,
    'KARVER': 0,
    'KARVONEN': 0,
    'KARWACKI': 0,
    'KARWAN': 0,
    'KARWOSKI': 0,
    'KARWOWSKI': 0,
    'KARY': 0.7575757575757576,
    'KARYL': 1,
    'KARYN': 1,
    'KARZAI': 0,
    'KAS': 0,
    'KASA': 0,
    'KASABIAN': 0,
    'KASAHARA': 0,
    'KASAI': 0,
    'KASAK': 0,
    'KASAL': 0,
    'KASANDRA': 1,
    'KASARDA': 0,
    'KASARJIAN': 0,
    'KASBARIAN': 0,
    'KASBERG': 0,
    'KASBOHM': 0,
    'KASCAK': 0,
    'KASCH': 0,
    'KASCHAK': 0,
    'KASCHALK': 0,
    'KASCHMITTER': 0,
    'KASCHNER': 0,
    'KASCSAK': 0,
    'KASDAN': 0,
    'KASDORF': 0,
    'KASE': 0,
    'KASEL': 0,
    'KASEM': 0,
    'KASEMAN': 0,
    'KASEN': 0,
    'KASER': 0,
    'KASERMAN': 0,
    'KASETA': 0,
    'KASEY': 0.9784735812133073,
    'KASH': 0,
    'KASHA': 0.9259259259259258,
    'KASHANI': 0,
    'KASHANIAN': 0,
    'KASHAT': 0,
    'KASHDAN': 0,
    'KASHEM': 0,
    'KASHER': 0,
    'KASHI': 0,
    'KASHIAN': 0,
    'KASHIF': 0,
    'KASHIMA': 0,
    'KASHIN': 0,
    'KASHISHIAN': 0,
    'KASHIWABARA': 0,
    'KASHIWAGI': 0,
    'KASHMER': 0,
    'KASHNER': 0,
    'KASHOU': 0,
    'KASHTAN': 0,
    'KASHUBA': 0,
    'KASHYAP': 0,
    'KASI': 0.9523809523809523,
    'KASIAN': 0,
    'KASIC': 0,
    'KASICA': 0,
    'KASICK': 0,
    'KASIE': 1,
    'KASIK': 0,
    'KASIM': 0,
    'KASIN': 0,
    'KASINGER': 0,
    'KASINSKI': 0,
    'KASISCHKE': 0,
    'KASK': 0,
    'KASKA': 0,
    'KASKE': 0,
    'KASKEL': 0,
    'KASKEY': 0,
    'KASKI': 0,
    'KASKIE': 0,
    'KASKO': 0,
    'KASKY': 0,
    'KASL': 0,
    'KASLE': 0,
    'KASLER': 0,
    'KASLOW': 0,
    'KASMAN': 0,
    'KASMAR': 0,
    'KASMER': 0,
    'KASMIKHA': 0,
    'KASNER': 0,
    'KASOFF': 0,
    'KASON': 0,
    'KASOWSKI': 0,
    'KASPAR': 0,
    'KASPAREK': 0,
    'KASPARI': 0,
    'KASPARIAN': 0,
    'KASPER': 0,
    'KASPERBAUER': 0,
    'KASPEREK': 0,
    'KASPEROWICZ': 0,
    'KASPERSKI': 0,
    'KASPERSON': 0,
    'KASPRAK': 0,
    'KASPRICK': 0,
    'KASPROWICZ': 0,
    'KASPRZAK': 0,
    'KASPRZYCKI': 0,
    'KASPRZYK': 0,
    'KASPUTIS': 0,
    'KASS': 0,
    'KASSA': 0,
    'KASSAB': 0,
    'KASSABIAN': 0,
    'KASSAHN': 0,
    'KASSAHUN': 0,
    'KASSAI': 0,
    'KASSAL': 0,
    'KASSAM': 0,
    'KASSAN': 0,
    'KASSANDRA': 1,
    'KASSAR': 0,
    'KASSAY': 0,
    'KASSAYE': 0,
    'KASSE': 0,
    'KASSEBAUM': 0,
    'KASSEES': 0,
    'KASSEL': 0,
    'KASSELL': 0,
    'KASSELMAN': 0,
    'KASSEM': 0,
    'KASSEN': 0,
    'KASSENS': 0,
    'KASSER': 0,
    'KASSERMAN': 0,
    'KASSICK': 0,
    'KASSIE': 1,
    'KASSIK': 0,
    'KASSIM': 0,
    'KASSIN': 0,
    'KASSING': 0,
    'KASSINGER': 0,
    'KASSIR': 0,
    'KASSIS': 0,
    'KASSLER': 0,
    'KASSMAN': 0,
    'KASSNER': 0,
    'KASSOFF': 0,
    'KASSON': 0,
    'KASSOUF': 0,
    'KASSUBA': 0,
    'KASSUBE': 0,
    'KAST': 0,
    'KASTAN': 0,
    'KASTANEK': 0,
    'KASTANIS': 0,
    'KASTBERG': 0,
    'KASTE': 0,
    'KASTEIN': 0,
    'KASTEL': 0,
    'KASTELER': 0,
    'KASTELIC': 0,
    'KASTEN': 0,
    'KASTENBAUM': 0,
    'KASTENDIECK': 0,
    'KASTENHOLZ': 0,
    'KASTENHUBER': 0,
    'KASTENS': 0,
    'KASTENSCHMIDT': 0,
    'KASTER': 0,
    'KASTIGAR': 0,
    'KASTING': 0,
    'KASTL': 0,
    'KASTLE': 0,
    'KASTLER': 0,
    'KASTNER': 0,
    'KASTNING': 0,
    'KASTON': 0,
    'KASTOR': 0,
    'KASTRATI': 0,
    'KASTRUP': 0,
    'KASTURI': 0,
    'KASUBA': 0,
    'KASUBOSKI': 0,
    'KASUN': 0,
    'KASUNIC': 0,
    'KASUSKE': 0,
    'KASZA': 0,
    'KASZAS': 0,
    'KASZOWSKI': 0,
    'KASZUBA': 0,
    'KASZUBOWSKI': 0,
    'KASZUBSKI': 0,
    'KASZYCKI': 0,
    'KASZYNSKI': 0,
    'KAT': 0,
    'KATA': 0,
    'KATAFIASZ': 0,
    'KATAGIRI': 0,
    'KATALINICH': 0,
    'KATAN': 0,
    'KATANA': 0,
    'KATAOKA': 0,
    'KATARIA': 0,
    'KATAYAMA': 0,
    'KATCH': 0,
    'KATCHEN': 0,
    'KATCHER': 0,
    'KATCHMAR': 0,
    'KATCHMARK': 0,
    'KATCHUR': 0,
    'KATE': 0.995879120879121,
    'KATECHIS': 0,
    'KATEHIS': 0,
    'KATELEY': 0,
    'KATELIN': 1,
    'KATELY': 0,
    'KATELYN': 1,
    'KATELYNN': 1,
    'KATEN': 0,
    'KATER': 0,
    'KATERBERG': 0,
    'KATERINE': 1,
    'KATERS': 0,
    'KATES': 0,
    'KATH': 0,
    'KATHALEEN': 1,
    'KATHAN': 0,
    'KATHARINA': 1,
    'KATHARINE': 1,
    'KATHARYN': 1,
    'KATHE': 0.9756097560975611,
    'KATHELEEN': 1,
    'KATHER': 0,
    'KATHERIN': 1,
    'KATHERINA': 1,
    'KATHERINE': 0.999712542719346,
    'KATHERMAN': 0,
    'KATHERN': 1,
    'KATHERYN': 1,
    'KATHEY': 1,
    'KATHI': 1,
    'KATHIE': 1,
    'KATHLEEN': 0.9998585105881244,
    'KATHLENE': 1,
    'KATHLINE': 1,
    'KATHLYN': 1,
    'KATHMAN': 0,
    'KATHMANN': 0,
    'KATHOL': 0,
    'KATHREIN': 0,
    'KATHRENS': 0,
    'KATHRIN': 1,
    'KATHRINE': 1,
    'KATHRYN': 1,
    'KATHRYNE': 1,
    'KATHURIA': 0,
    'KATHY': 0.9998529627995884,
    'KATHYRN': 1,
    'KATI': 1,
    'KATIA': 1,
    'KATIC': 0,
    'KATICH': 0,
    'KATIE': 0.9996461429582448,
    'KATIGBAK': 0,
    'KATIN': 0,
    'KATINA': 1,
    'KATINAS': 0,
    'KATIS': 0,
    'KATKA': 0,
    'KATKE': 0,
    'KATKO': 0,
    'KATLIN': 0,
    'KATLYN': 1,
    'KATNER': 0,
    'KATNIK': 0,
    'KATO': 0,
    'KATOA': 0,
    'KATON': 0,
    'KATONA': 0,
    'KATOPODIS': 0,
    'KATOR': 0,
    'KATRA': 0,
    'KATRAGADDA': 0,
    'KATRICE': 1,
    'KATRINA': 1,
    'KATRIS': 0,
    'KATS': 0,
    'KATSANOS': 0,
    'KATSAROS': 0,
    'KATSCHKE': 0,
    'KATSIKAS': 0,
    'KATSIKIS': 0,
    'KATSIS': 0,
    'KATSMA': 0,
    'KATSMAN': 0,
    'KATSNELSON': 0,
    'KATSOS': 0,
    'KATSOULIS': 0,
    'KATSUMATA': 0,
    'KATSURA': 0,
    'KATT': 0,
    'KATTA': 0,
    'KATTAN': 0,
    'KATTAU': 0,
    'KATTE': 0,
    'KATTELMAN': 0,
    'KATTENHORN': 0,
    'KATTER': 0,
    'KATTERHEINRICH': 0,
    'KATTERHENRY': 0,
    'KATTERMAN': 0,
    'KATTIE': 1,
    'KATTNER': 0,
    'KATULA': 0,
    'KATUS': 0,
    'KATY': 1,
    'KATYAL': 0,
    'KATYNSKI': 0,
    'KATZ': 0,
    'KATZBERG': 0,
    'KATZE': 0,
    'KATZEL': 0,
    'KATZEN': 0,
    'KATZENBACH': 0,
    'KATZENBERG': 0,
    'KATZENBERGER': 0,
    'KATZENMEIER': 0,
    'KATZENMEYER': 0,
    'KATZENSTEIN': 0,
    'KATZER': 0,
    'KATZFEY': 0,
    'KATZIN': 0,
    'KATZMAN': 0,
    'KATZMANN': 0,
    'KATZMAREK': 0,
    'KATZMARK': 0,
    'KATZNER': 0,
    'KATZOFF': 0,
    'KATZUNG': 0,
    'KAU': 0,
    'KAUAHI': 0,
    'KAUB': 0,
    'KAUBLE': 0,
    'KAUCHAK': 0,
    'KAUCHER': 0,
    'KAUCIC': 0,
    'KAUDER': 0,
    'KAUDERER': 0,
    'KAUER': 0,
    'KAUF': 0,
    'KAUFENBERG': 0,
    'KAUFER': 0,
    'KAUFF': 0,
    'KAUFFELD': 0,
    'KAUFFMAN': 0,
    'KAUFFMANN': 0,
    'KAUFHOLD': 0,
    'KAUFLIN': 0,
    'KAUFMAN': 0,
    'KAUFMANN': 0,
    'KAUFOLD': 0,
    'KAUFUSI': 0,
    'KAUHANE': 0,
    'KAUHI': 0,
    'KAUI': 0,
    'KAUK': 0,
    'KAUKER': 0,
    'KAUL': 0,
    'KAULAITY': 0,
    'KAULBACK': 0,
    'KAULFERS': 0,
    'KAULIA': 0,
    'KAULLEN': 0,
    'KAUMANS': 0,
    'KAUMEYER': 0,
    'KAUN': 0,
    'KAUNE': 0,
    'KAUNITZ': 0,
    'KAUP': 0,
    'KAUPA': 0,
    'KAUPAS': 0,
    'KAUPE': 0,
    'KAUPER': 0,
    'KAUPP': 0,
    'KAUPPI': 0,
    'KAUPPILA': 0,
    'KAUPPINEN': 0,
    'KAUPU': 0,
    'KAUR': 0,
    'KAURA': 0,
    'KAURICH': 0,
    'KAUS': 0,
    'KAUSAR': 0,
    'KAUSCH': 0,
    'KAUSE': 0,
    'KAUSER': 0,
    'KAUSHAL': 0,
    'KAUSHIK': 0,
    'KAUSS': 0,
    'KAUT': 0,
    'KAUTEN': 0,
    'KAUTH': 0,
    'KAUTSKY': 0,
    'KAUTZ': 0,
    'KAUTZER': 0,
    'KAUTZKY': 0,
    'KAUTZMAN': 0,
    'KAUTZMANN': 0,
    'KAUVAKA': 0,
    'KAUWE': 0,
    'KAUZLARICH': 0,
    'KAVA': 0,
    'KAVADAS': 0,
    'KAVAL': 0,
    'KAVALAUSKAS': 0,
    'KAVAN': 0,
    'KAVANAGH': 0,
    'KAVANAH': 0,
    'KAVANAUGH': 0,
    'KAVE': 0,
    'KAVEH': 0,
    'KAVEN': 0,
    'KAVENEY': 0,
    'KAVENY': 0,
    'KAVERMAN': 0,
    'KAVIANI': 0,
    'KAVICH': 0,
    'KAVIN': 0,
    'KAVKA': 0,
    'KAVOURAS': 0,
    'KAVR': 0,
    'KAVULICH': 0,
    'KAW': 0,
    'KAWA': 0,
    'KAWABATA': 0,
    'KAWABE': 0,
    'KAWACHI': 0,
    'KAWADA': 0,
    'KAWAGUCHI': 0,
    'KAWAHARA': 0,
    'KAWAI': 0,
    'KAWAJA': 0,
    'KAWAKAMI': 0,
    'KAWALEC': 0,
    'KAWALEK': 0,
    'KAWALSKI': 0,
    'KAWAMATA': 0,
    'KAWAMOTO': 0,
    'KAWAMURA': 0,
    'KAWANA': 0,
    'KAWANO': 0,
    'KAWAOKA': 0,
    'KAWAR': 0,
    'KAWAS': 0,
    'KAWASAKI': 0,
    'KAWASE': 0,
    'KAWASH': 0,
    'KAWASHIMA': 0,
    'KAWATA': 0,
    'KAWATE': 0,
    'KAWAZOE': 0,
    'KAWCZYNSKI': 0,
    'KAWECKI': 0,
    'KAWELL': 0,
    'KAWELO': 0,
    'KAWIECKI': 0,
    'KAWKA': 0,
    'KAWLESKI': 0,
    'KAWLEWSKI': 0,
    'KAWSKI': 0,
    'KAWULA': 0,
    'KAY': 0.8919597989949748,
    'KAYA': 0,
    'KAYAL': 0,
    'KAYALI': 0,
    'KAYANI': 0,
    'KAYCE': 1,
    'KAYCEE': 1,
    'KAYDEN': 0,
    'KAYE': 0.7724719101123595,
    'KAYED': 0,
    'KAYES': 0,
    'KAYFES': 0,
    'KAYHART': 0,
    'KAYL': 0,
    'KAYLA': 1,
    'KAYLE': 0,
    'KAYLEE': 1,
    'KAYLEEN': 1,
    'KAYLEIGH': 1,
    'KAYLENE': 1,
    'KAYLER': 0,
    'KAYLOR': 0,
    'KAYNE': 0,
    'KAYNER': 0,
    'KAYNOR': 0,
    'KAYO': 0,
    'KAYR': 0,
    'KAYROUZ': 0,
    'KAYS': 0,
    'KAYSE': 0,
    'KAYSEN': 0,
    'KAYSER': 0,
    'KAYTON': 0,
    'KAYWOOD': 0,
    'KAYYALI': 0,
    'KAZ': 0,
    'KAZA': 0,
    'KAZAK': 0,
    'KAZAKOS': 0,
    'KAZAKOV': 0,
    'KAZAMA': 0,
    'KAZAN': 0,
    'KAZANAS': 0,
    'KAZANCHYAN': 0,
    'KAZANDJIAN': 0,
    'KAZANECKI': 0,
    'KAZANJIAN': 0,
    'KAZANOWSKI': 0,
    'KAZAR': 0,
    'KAZARIAN': 0,
    'KAZARYAN': 0,
    'KAZAZIAN': 0,
    'KAZDA': 0,
    'KAZE': 0,
    'KAZEE': 0,
    'KAZEL': 0,
    'KAZEM': 0,
    'KAZEMBA': 0,
    'KAZEMI': 0,
    'KAZEN': 0,
    'KAZER': 0,
    'KAZI': 0,
    'KAZIK': 0,
    'KAZIM': 0,
    'KAZIMER': 0,
    'KAZIMI': 0,
    'KAZIMIR': 0,
    'KAZIN': 0,
    'KAZLAUSKAS': 0,
    'KAZMAIER': 0,
    'KAZMAR': 0,
    'KAZMARK': 0,
    'KAZMER': 0,
    'KAZMERSKI': 0,
    'KAZMI': 0,
    'KAZMIER': 0,
    'KAZMIERCZAK': 0,
    'KAZMIERSKI': 0,
    'KAZMIERZAK': 0,
    'KAZMIR': 0,
    'KAZMIRSKI': 0,
    'KAZNOWSKI': 0,
    'KAZOR': 0,
    'KAZUKO': 1,
    'KAZY': 0,
    'KC': 0,
    'KE': 0,
    'KEA': 0,
    'KEABLE': 0,
    'KEACH': 0,
    'KEADLE': 0,
    'KEADY': 0,
    'KEAFER': 0,
    'KEAGLE': 0,
    'KEAGY': 0,
    'KEAHEY': 0,
    'KEAHI': 0,
    'KEAHON': 0,
    'KEAIRNS': 0,
    'KEAL': 0,
    'KEALA': 0,
    'KEALEY': 0,
    'KEALIHER': 0,
    'KEALLY': 0,
    'KEALOHA': 0,
    'KEALY': 0,
    'KEAM': 0,
    'KEAMS': 0,
    'KEAN': 0,
    'KEANE': 0,
    'KEANEY': 0,
    'KEANINI': 0,
    'KEANY': 0,
    'KEAR': 0,
    'KEARBEY': 0,
    'KEARBY': 0,
    'KEARCE': 0,
    'KEARFOTT': 0,
    'KEARIN': 0,
    'KEARL': 0,
    'KEARLEY': 0,
    'KEARN': 0,
    'KEARNES': 0,
    'KEARNEY': 0,
    'KEARNS': 0,
    'KEARNY': 0,
    'KEARSE': 0,
    'KEARSLEY': 0,
    'KEARSON': 0,
    'KEARY': 0,
    'KEAS': 0,
    'KEASER': 0,
    'KEASEY': 0,
    'KEASLER': 0,
    'KEASLING': 0,
    'KEAST': 0,
    'KEASTER': 0,
    'KEAT': 0,
    'KEATE': 0,
    'KEATEN': 0,
    'KEATES': 0,
    'KEATH': 0,
    'KEATHLEY': 0,
    'KEATING': 0,
    'KEATLEY': 0,
    'KEATON': 0,
    'KEATOR': 0,
    'KEATS': 0,
    'KEATTS': 0,
    'KEATY': 0,
    'KEAVENEY': 0,
    'KEAVENY': 0,
    'KEAVNEY': 0,
    'KEAWE': 0,
    'KEAY': 0,
    'KEAYS': 0,
    'KEB': 0,
    'KEBA': 0,
    'KEBE': 0,
    'KEBEDE': 0,
    'KEBER': 0,
    'KEBERLEIN': 0,
    'KEBERT': 0,
    'KEBLER': 0,
    'KEBLISH': 0,
    'KEBODEAUX': 0,
    'KEBSCHULL': 0,
    'KECHICHIAN': 0,
    'KECHTER': 0,
    'KECIA': 1,
    'KECK': 0,
    'KECKEISEN': 0,
    'KECKLER': 0,
    'KECKLEY': 0,
    'KECSKES': 0,
    'KEDAR': 0,
    'KEDDELL': 0,
    'KEDDIE': 0,
    'KEDDINGTON': 0,
    'KEDDY': 0,
    'KEDIA': 0,
    'KEDING': 0,
    'KEDLEY': 0,
    'KEDRA': 0,
    'KEDROWSKI': 0,
    'KEDZIE': 0,
    'KEDZIERSKI': 0,
    'KEDZIOR': 0,
    'KEDZIORA': 0,
    'KEE': 0,
    'KEEBAUGH': 0,
    'KEEBLE': 0,
    'KEEBLER': 0,
    'KEECH': 0,
    'KEEDER': 0,
    'KEEDY': 0,
    'KEEF': 0,
    'KEEFAUVER': 0,
    'KEEFE': 0,
    'KEEFER': 0,
    'KEEFFE': 0,
    'KEEFNER': 0,
    'KEEFOVER': 0,
    'KEEGAN': 0,
    'KEEGSTRA': 0,
    'KEEHAN': 0,
    'KEEHN': 0,
    'KEEHNER': 0,
    'KEEHR': 0,
    'KEEL': 0,
    'KEELAN': 0,
    'KEELAND': 0,
    'KEELE': 0,
    'KEELEAN': 0,
    'KEELEN': 0,
    'KEELER': 0,
    'KEELEY': 0.34246575342465757,
    'KEELIN': 0,
    'KEELING': 0,
    'KEELS': 0,
    'KEELTY': 0,
    'KEELY': 0.8676789587852495,
    'KEEM': 0,
    'KEEME': 0,
    'KEEMER': 0,
    'KEEN': 0,
    'KEENA': 0.8658008658008658,
    'KEENAN': 0.411522633744856,
    'KEENE': 0,
    'KEENEN': 0,
    'KEENER': 0,
    'KEENEY': 0,
    'KEENOM': 0,
    'KEENON': 0,
    'KEENOY': 0,
    'KEENS': 0,
    'KEENUM': 0,
    'KEENY': 0,
    'KEEP': 0,
    'KEEPER': 0,
    'KEEPERS': 0,
    'KEEPES': 0,
    'KEEPING': 0,
    'KEER': 0,
    'KEERAN': 0,
    'KEERS': 0,
    'KEERY': 0,
    'KEES': 0,
    'KEESE': 0,
    'KEESECKER': 0,
    'KEESEE': 0,
    'KEESER': 0,
    'KEESEY': 0,
    'KEESHA': 1,
    'KEESHAN': 0,
    'KEESLAR': 0,
    'KEESLER': 0,
    'KEESLING': 0,
    'KEESTER': 0,
    'KEESY': 0,
    'KEET': 0,
    'KEETCH': 0,
    'KEETER': 0,
    'KEETH': 0,
    'KEETHLER': 0,
    'KEETON': 0,
    'KEETS': 0,
    'KEETSO': 0,
    'KEEVAN': 0,
    'KEEVE': 0,
    'KEEVEN': 0,
    'KEEVER': 0,
    'KEEVIL': 0,
    'KEEYS': 0,
    'KEEZER': 0,
    'KEFALAS': 0,
    'KEFAUVER': 0,
    'KEFER': 0,
    'KEFFELER': 0,
    'KEFFER': 0,
    'KEFFLER': 0,
    'KEGAN': 0,
    'KEGARISE': 0,
    'KEGEBEIN': 0,
    'KEGEL': 0,
    'KEGERREIS': 0,
    'KEGG': 0,
    'KEGLER': 0,
    'KEGLEY': 0,
    'KEGLOVITS': 0,
    'KEH': 0,
    'KEHAGIAS': 0,
    'KEHE': 0,
    'KEHELEY': 0,
    'KEHL': 0,
    'KEHLE': 0,
    'KEHLENBECK': 0,
    'KEHLER': 0,
    'KEHM': 0,
    'KEHN': 0,
    'KEHNE': 0,
    'KEHNER': 0,
    'KEHOE': 0,
    'KEHR': 0,
    'KEHRBERG': 0,
    'KEHREN': 0,
    'KEHRER': 0,
    'KEHRES': 0,
    'KEHRING': 0,
    'KEHRLI': 0,
    'KEHRT': 0,
    'KEHS': 0,
    'KEI': 0,
    'KEIB': 0,
    'KEIBER': 0,
    'KEIBLER': 0,
    'KEICH': 0,
    'KEICHER': 0,
    'KEIDEL': 0,
    'KEIDERLING': 0,
    'KEIERLEBER': 0,
    'KEIF': 0,
    'KEIFENHEIM': 0,
    'KEIFER': 0,
    'KEIFFER': 0,
    'KEIG': 0,
    'KEIGER': 0,
    'KEIGHER': 0,
    'KEIGHLEY': 0,
    'KEIGHTLEY': 0,
    'KEIGLEY': 0,
    'KEIHL': 0,
    'KEIHN': 0,
    'KEIKO': 1,
    'KEIL': 0,
    'KEILA': 1,
    'KEILBACH': 0,
    'KEILEN': 0,
    'KEILER': 0,
    'KEILERS': 0,
    'KEILEY': 0,
    'KEILHOLTZ': 0,
    'KEILHOLZ': 0,
    'KEILING': 0,
    'KEILL': 0,
    'KEILLOR': 0,
    'KEILMAN': 0,
    'KEILS': 0,
    'KEILSON': 0,
    'KEILTY': 0,
    'KEILY': 0,
    'KEIM': 0,
    'KEIME': 0,
    'KEIMIG': 0,
    'KEIN': 0,
    'KEINATH': 0,
    'KEINER': 0,
    'KEINTZ': 0,
    'KEIP': 0,
    'KEIPER': 0,
    'KEIPERT': 0,
    'KEIPPER': 0,
    'KEIR': 0,
    'KEIRA': 1,
    'KEIRAN': 0,
    'KEIRN': 0,
    'KEIRNAN': 0,
    'KEIRNS': 0,
    'KEIRSEY': 0,
    'KEIRSTEAD': 0,
    'KEIS': 0,
    'KEISEL': 0,
    'KEISER': 0,
    'KEISHA': 1,
    'KEISKER': 0,
    'KEISLER': 0,
    'KEISLING': 0,
    'KEISMAN': 0,
    'KEISS': 0,
    'KEISTER': 0,
    'KEISTLER': 0,
    'KEITA': 0,
    'KEITEL': 0,
    'KEITER': 0,
    'KEITGES': 0,
    'KEITH': 0.9468942481537095,
    'KEITHA': 1,
    'KEITHAN': 0,
    'KEITHLEY': 0,
    'KEITHLINE': 0,
    'KEITHLY': 0,
    'KEITT': 0,
    'KEITZ': 0,
    'KEIZER': 0,
    'KEKAHUNA': 0,
    'KEKAUOHA': 0,
    'KEKEL': 0,
    'KEKIC': 0,
    'KEKICH': 0,
    'KEKLAK': 0,
    'KEKOA': 0,
    'KEKONA': 0,
    'KELA': 0,
    'KELAHAN': 0,
    'KELAHER': 0,
    'KELASH': 0,
    'KELBAUGH': 0,
    'KELBEL': 0,
    'KELBER': 0,
    'KELBLE': 0,
    'KELBLEY': 0,
    'KELBY': 0,
    'KELCE': 0,
    'KELCH': 0,
    'KELCHEN': 0,
    'KELCHER': 0,
    'KELCHNER': 0,
    'KELDER': 0,
    'KELDERHOUSE': 0,
    'KELDERMAN': 0,
    'KELDSEN': 0,
    'KELEDJIAN': 0,
    'KELEHAN': 0,
    'KELEHER': 0,
    'KELEMAN': 0,
    'KELEMEN': 0,
    'KELESHIAN': 0,
    'KELETA': 0,
    'KELHOFFER': 0,
    'KELI': 1,
    'KELIHER': 0,
    'KELII': 0,
    'KELIIHOOMALU': 0,
    'KELIIKOA': 0,
    'KELIN': 0,
    'KELING': 0,
    'KELK': 0,
    'KELKAR': 0,
    'KELKENBERG': 0,
    'KELKER': 0,
    'KELL': 0,
    'KELLA': 0,
    'KELLAGHER': 0,
    'KELLAHER': 0,
    'KELLAM': 0,
    'KELLAMS': 0,
    'KELLAN': 0,
    'KELLAND': 0,
    'KELLAR': 0,
    'KELLAS': 0,
    'KELLAWAY': 0,
    'KELLE': 0.9433962264150944,
    'KELLEBREW': 0,
    'KELLEE': 1,
    'KELLEHER': 0,
    'KELLEM': 0,
    'KELLEMAN': 0,
    'KELLEMS': 0,
    'KELLEN': 0,
    'KELLENBENZ': 0,
    'KELLENBERGER': 0,
    'KELLER': 0,
    'KELLERHALS': 0,
    'KELLERHOUSE': 0,
    'KELLERMAN': 0,
    'KELLERMANN': 0,
    'KELLERMEIER': 0,
    'KELLERMEYER': 0,
    'KELLERS': 0,
    'KELLERSTRASS': 0,
    'KELLERT': 0,
    'KELLETT': 0,
    'KELLEY': 0.40702407256657747,
    'KELLI': 1,
    'KELLICK': 0,
    'KELLIE': 0.9948542024013722,
    'KELLIHER': 0,
    'KELLIN': 0,
    'KELLING': 0,
    'KELLINGER': 0,
    'KELLINGTON': 0,
    'KELLIS': 0,
    'KELLISH': 0,
    'KELLISON': 0,
    'KELLMAN': 0,
    'KELLMER': 0,
    'KELLN': 0,
    'KELLNER': 0,
    'KELLO': 0,
    'KELLOCK': 0,
    'KELLOG': 0,
    'KELLOGG': 0,
    'KELLOM': 0,
    'KELLON': 0,
    'KELLOUGH': 0,
    'KELLOW': 0,
    'KELLOWAY': 0,
    'KELLS': 0,
    'KELLSTROM': 0,
    'KELLUM': 0,
    'KELLUMS': 0,
    'KELLY': 0.78188556449426,
    'KELLYE': 1,
    'KELLYWOOD': 0,
    'KELM': 0,
    'KELMAN': 0,
    'KELMER': 0,
    'KELNER': 0,
    'KELNHOFER': 0,
    'KELONE': 0,
    'KELP': 0,
    'KELPE': 0,
    'KELPIN': 0,
    'KELSALL': 0,
    'KELSAW': 0,
    'KELSAY': 0,
    'KELSCH': 0,
    'KELSEN': 0,
    'KELSER': 0,
    'KELSEY': 0.82389289392379,
    'KELSH': 0,
    'KELSHAW': 0,
    'KELSHEIMER': 0,
    'KELSI': 1,
    'KELSIE': 1,
    'KELSO': 0,
    'KELSOE': 0,
    'KELSON': 0,
    'KELT': 0,
    'KELTCH': 0,
    'KELTER': 0,
    'KELTGEN': 0,
    'KELTING': 0,
    'KELTNER': 0,
    'KELTON': 0,
    'KELTS': 0,
    'KELTY': 0,
    'KELTZ': 0,
    'KELVER': 0,
    'KELVIN': 0.9979454065159964,
    'KELVINGTON': 0,
    'KELZ': 0,
    'KELZENBERG': 0,
    'KELZER': 0,
    'KEM': 0,
    'KEMBEL': 0,
    'KEMBERLING': 0,
    'KEMBERLY': 1,
    'KEMBLE': 0,
    'KEMEN': 0,
    'KEMENY': 0,
    'KEMER': 0,
    'KEMERER': 0,
    'KEMERLING': 0,
    'KEMERLY': 0,
    'KEMERY': 0,
    'KEMINK': 0,
    'KEMKER': 0,
    'KEMLER': 0,
    'KEMLING': 0,
    'KEMM': 0,
    'KEMME': 0,
    'KEMMER': 0,
    'KEMMERER': 0,
    'KEMMERLE': 0,
    'KEMMERLIN': 0,
    'KEMMERLING': 0,
    'KEMMERLY': 0,
    'KEMMET': 0,
    'KEMMETT': 0,
    'KEMMIS': 0,
    'KEMMISH': 0,
    'KEMMLER': 0,
    'KEMNA': 0,
    'KEMNER': 0,
    'KEMNETZ': 0,
    'KEMNITZ': 0,
    'KEMNITZER': 0,
    'KEMP': 0,
    'KEMPA': 0,
    'KEMPE': 0,
    'KEMPEL': 0,
    'KEMPEMA': 0,
    'KEMPEN': 0,
    'KEMPENICH': 0,
    'KEMPER': 0,
    'KEMPERS': 0,
    'KEMPERT': 0,
    'KEMPF': 0,
    'KEMPFER': 0,
    'KEMPFERT': 0,
    'KEMPFF': 0,
    'KEMPH': 0,
    'KEMPHER': 0,
    'KEMPIN': 0,
    'KEMPINSKI': 0,
    'KEMPISTY': 0,
    'KEMPKA': 0,
    'KEMPKE': 0,
    'KEMPKEN': 0,
    'KEMPKER': 0,
    'KEMPKES': 0,
    'KEMPLE': 0,
    'KEMPLER': 0,
    'KEMPLIN': 0,
    'KEMPNER': 0,
    'KEMPPAINEN': 0,
    'KEMPS': 0,
    'KEMPSKI': 0,
    'KEMPSON': 0,
    'KEMPSTER': 0,
    'KEMPSTON': 0,
    'KEMPT': 0,
    'KEMPTER': 0,
    'KEMPTHORNE': 0,
    'KEMPTON': 0,
    'KEMSLEY': 0,
    'KEN': 0.9970993473531544,
    'KENA': 1,
    'KENADY': 0,
    'KENAGA': 0,
    'KENAGY': 0,
    'KENAN': 0,
    'KENAR': 0,
    'KENARD': 0,
    'KENARY': 0,
    'KENAS': 0,
    'KENASTON': 0,
    'KENAWELL': 0,
    'KENCH': 0,
    'KENDA': 0.9433962264150944,
    'KENDAL': 0.9009009009009009,
    'KENDALL': 0.6464124111182935,
    'KENDEL': 0,
    'KENDELL': 0,
    'KENDER': 0,
    'KENDERDINE': 0,
    'KENDERES': 0,
    'KENDHAMMER': 0,
    'KENDIG': 0,
    'KENDL': 0,
    'KENDLE': 0,
    'KENDLER': 0,
    'KENDRA': 0.9916492693110647,
    'KENDREW': 0,
    'KENDRICK': 0.5716798592788038,
    'KENDRICKS': 0,
    'KENDRIX': 0,
    'KENDRO': 0,
    'KENDZIERSKI': 0,
    'KENDZIOR': 0,
    'KENDZIORA': 0,
    'KENDZIORSKI': 0,
    'KENDZORA': 0,
    'KENEALLY': 0,
    'KENEALY': 0,
    'KENEBREW': 0,
    'KENEDY': 0,
    'KENEFICK': 0,
    'KENEHAN': 0,
    'KENEIPP': 0,
    'KENEL': 0,
    'KENEMER': 0,
    'KENEMORE': 0,
    'KENEPP': 0,
    'KENER': 0,
    'KENERLY': 0,
    'KENERSON': 0,
    'KENETH': 1,
    'KENEY': 0,
    'KENFIELD': 0,
    'KENG': 0,
    'KENIA': 0.9615384615384616,
    'KENIG': 0,
    'KENIGSBERG': 0,
    'KENIK': 0,
    'KENIMER': 0,
    'KENION': 0,
    'KENIS': 0,
    'KENISHA': 1,
    'KENISON': 0,
    'KENISTON': 0,
    'KENITZ': 0,
    'KENITZER': 0,
    'KENKEL': 0,
    'KENLEY': 0,
    'KENLINE': 0,
    'KENLY': 0,
    'KENMORE': 0,
    'KENN': 0,
    'KENNA': 0.8241758241758241,
    'KENNADY': 0,
    'KENNAH': 0,
    'KENNAMER': 0,
    'KENNAMORE': 0,
    'KENNAN': 0,
    'KENNARD': 0,
    'KENNAUGH': 0,
    'KENNDEY': 0,
    'KENNE': 0,
    'KENNEALLY': 0,
    'KENNEALY': 0,
    'KENNEBECK': 0,
    'KENNEBREW': 0,
    'KENNEDA': 0,
    'KENNEDY': 0,
    'KENNEFICK': 0,
    'KENNEL': 0,
    'KENNELL': 0,
    'KENNELLEY': 0,
    'KENNELLY': 0,
    'KENNEMER': 0,
    'KENNEMORE': 0,
    'KENNEMUR': 0,
    'KENNEN': 0,
    'KENNER': 0,
    'KENNERKNECHT': 0,
    'KENNERLEY': 0,
    'KENNERLY': 0,
    'KENNERSON': 0,
    'KENNESON': 0,
    'KENNETH': 0.999710228919154,
    'KENNETT': 0,
    'KENNEWAY': 0,
    'KENNEWEG': 0,
    'KENNEY': 0,
    'KENNEYBREW': 0,
    'KENNICK': 0,
    'KENNICKER': 0,
    'KENNICOTT': 0,
    'KENNICUTT': 0,
    'KENNIE': 0,
    'KENNIMER': 0,
    'KENNING': 0,
    'KENNINGTON': 0,
    'KENNIS': 0,
    'KENNISH': 0,
    'KENNISON': 0,
    'KENNISTON': 0,
    'KENNITH': 1,
    'KENNON': 0,
    'KENNY': 0.862259562237453,
    'KENO': 0,
    'KENOL': 0,
    'KENON': 0,
    'KENOW': 0,
    'KENOWSKI': 0,
    'KENOYER': 0,
    'KENRICK': 0,
    'KENSER': 0,
    'KENSEY': 0,
    'KENSICKI': 0,
    'KENSIL': 0,
    'KENSINGER': 0,
    'KENSKI': 0,
    'KENSLER': 0,
    'KENSLOW': 0,
    'KENSON': 0,
    'KENSY': 0,
    'KENT': 0.7524690390343314,
    'KENTALA': 0,
    'KENTCH': 0,
    'KENTER': 0,
    'KENTFIELD': 0,
    'KENTISH': 0,
    'KENTNER': 0,
    'KENTON': 0.8944543828264758,
    'KENTOPP': 0,
    'KENTROS': 0,
    'KENTY': 0,
    'KENVILLE': 0,
    'KENWARD': 0,
    'KENWOOD': 0,
    'KENWORTHY': 0,
    'KENY': 0,
    'KENYA': 1,
    'KENYATTA': 0.9771986970684039,
    'KENYETTA': 1,
    'KENYON': 0,
    'KENZIE': 0,
    'KENZY': 0,
    'KEO': 0,
    'KEODARA': 0,
    'KEOGAN': 0,
    'KEOGH': 0,
    'KEOHAN': 0,
    'KEOHANE': 0,
    'KEOHAVONG': 0,
    'KEOLA': 0,
    'KEOLANUI': 0,
    'KEOMANIVONG': 0,
    'KEOMANY': 0,
    'KEON': 0,
    'KEOPRASEUTH': 0,
    'KEOUGH': 0,
    'KEOVILAY': 0,
    'KEOVONGSA': 0,
    'KEOWN': 0,
    'KEPA': 0,
    'KEPES': 0,
    'KEPFORD': 0,
    'KEPHART': 0,
    'KEPIC': 0,
    'KEPICH': 0,
    'KEPICS': 0,
    'KEPKA': 0,
    'KEPKE': 0,
    'KEPLAR': 0,
    'KEPLER': 0,
    'KEPLEY': 0,
    'KEPLIN': 0,
    'KEPLINGER': 0,
    'KEPNER': 0,
    'KEPP': 0,
    'KEPPEL': 0,
    'KEPPELER': 0,
    'KEPPEN': 0,
    'KEPPER': 0,
    'KEPPERS': 0,
    'KEPPINGER': 0,
    'KEPPLE': 0,
    'KEPPLER': 0,
    'KEPPLEY': 0,
    'KEPPNER': 0,
    'KEPPY': 0,
    'KER': 0,
    'KERA': 1,
    'KERAMIDAS': 0,
    'KERAN': 0,
    'KERANEN': 0,
    'KERANS': 0,
    'KERBAUGH': 0,
    'KERBEL': 0,
    'KERBER': 0,
    'KERBO': 0,
    'KERBOW': 0,
    'KERBS': 0,
    'KERBY': 0,
    'KERBYSON': 0,
    'KERCADO': 0,
    'KERCE': 0,
    'KERCH': 0,
    'KERCHER': 0,
    'KERCHEVAL': 0,
    'KERCHNER': 0,
    'KERCKHOFF': 0,
    'KERECMAN': 0,
    'KERECZ': 0,
    'KEREK': 0,
    'KEREKES': 0,
    'KEREN': 0.9345794392523364,
    'KERENS': 0,
    'KERESEY': 0,
    'KERESTES': 0,
    'KERESZTES': 0,
    'KEREZSI': 0,
    'KERFELD': 0,
    'KERFIEN': 0,
    'KERFOOT': 0,
    'KERG': 0,
    'KERGER': 0,
    'KERI': 0.9950248756218906,
    'KERIAN': 0,
    'KERIN': 0,
    'KERINS': 0,
    'KERIVAN': 0,
    'KERK': 0,
    'KERKAU': 0,
    'KERKEMEYER': 0,
    'KERKER': 0,
    'KERKES': 0,
    'KERKHOF': 0,
    'KERKHOFF': 0,
    'KERKHOVE': 0,
    'KERKMAN': 0,
    'KERKOVE': 0,
    'KERKOW': 0,
    'KERKSTRA': 0,
    'KERKVLIET': 0,
    'KERL': 0,
    'KERLE': 0,
    'KERLEE': 0,
    'KERLER': 0,
    'KERLEY': 0,
    'KERLICK': 0,
    'KERLIN': 0,
    'KERLING': 0,
    'KERMAN': 0,
    'KERMANI': 0,
    'KERMEEN': 0,
    'KERMES': 0,
    'KERMIT': 1,
    'KERMODE': 0,
    'KERN': 0,
    'KERNAGHAN': 0,
    'KERNAHAN': 0,
    'KERNAN': 0,
    'KERNDT': 0,
    'KERNELL': 0,
    'KERNEN': 0,
    'KERNER': 0,
    'KERNES': 0,
    'KERNEY': 0,
    'KERNICK': 0,
    'KERNIZAN': 0,
    'KERNODIE': 0,
    'KERNODLE': 0,
    'KERNOHAN': 0,
    'KERNS': 0,
    'KERNSTOCK': 0,
    'KERO': 0,
    'KEROACK': 0,
    'KEROUAC': 0,
    'KERPAN': 0,
    'KERPER': 0,
    'KERPERIEN': 0,
    'KERR': 0,
    'KERRI': 1,
    'KERRICK': 0,
    'KERRIDGE': 0,
    'KERRIE': 1,
    'KERRIGAN': 0,
    'KERRINS': 0,
    'KERRISON': 0,
    'KERRY': 0.9898064706751366,
    'KERSAINT': 0,
    'KERSBERGEN': 0,
    'KERSCH': 0,
    'KERSCHBAUM': 0,
    'KERSCHEN': 0,
    'KERSCHER': 0,
    'KERSCHNER': 0,
    'KERSENBROCK': 0,
    'KERSEY': 0,
    'KERSH': 0,
    'KERSHAW': 0,
    'KERSHISNIK': 0,
    'KERSHNER': 0,
    'KERSJES': 0,
    'KERSKA': 0,
    'KERSLAKE': 0,
    'KERSON': 0,
    'KERST': 0,
    'KERSTEIN': 0,
    'KERSTEN': 0,
    'KERSTETTER': 0,
    'KERSTIENS': 0,
    'KERSTIN': 1,
    'KERSTING': 0,
    'KERSTNER': 0,
    'KERSWILL': 0,
    'KERT': 0,
    'KERTES': 0,
    'KERTESZ': 0,
    'KERTH': 0,
    'KERTIS': 0,
    'KERTON': 0,
    'KERTSCHER': 0,
    'KERTZ': 0,
    'KERTZMAN': 0,
    'KERVER': 0,
    'KERVICK': 0,
    'KERVIN': 0,
    'KERWICK': 0,
    'KERWIN': 0,
    'KERWOOD': 0,
    'KERY': 0,
    'KERZMAN': 0,
    'KERZNER': 0,
    'KES': 0,
    'KESAVAN': 0,
    'KESECKER': 0,
    'KESEE': 0,
    'KESEL': 0,
    'KESELMAN': 0,
    'KESER': 0,
    'KESEY': 0,
    'KESHA': 1,
    'KESHAVARZ': 0,
    'KESHIA': 1,
    'KESHISHIAN': 0,
    'KESHISHYAN': 0,
    'KESHNER': 0,
    'KESIC': 0,
    'KESINGER': 0,
    'KESKA': 0,
    'KESKE': 0,
    'KESKEY': 0,
    'KESKINEN': 0,
    'KESKITALO': 0,
    'KESL': 0,
    'KESLAR': 0,
    'KESLER': 0,
    'KESLIN': 0,
    'KESLING': 0,
    'KESNER': 0,
    'KESS': 0,
    'KESSAY': 0,
    'KESSE': 0,
    'KESSEE': 0,
    'KESSEL': 0,
    'KESSELER': 0,
    'KESSELL': 0,
    'KESSELMAN': 0,
    'KESSELRING': 0,
    'KESSEN': 0,
    'KESSENICH': 0,
    'KESSENS': 0,
    'KESSER': 0,
    'KESSIE': 0,
    'KESSIER': 0,
    'KESSING': 0,
    'KESSINGER': 0,
    'KESSLER': 0,
    'KESSLING': 0,
    'KESSMAN': 0,
    'KESSNER': 0,
    'KESSOCK': 0,
    'KESSON': 0,
    'KEST': 0,
    'KESTEL': 0,
    'KESTELL': 0,
    'KESTELOOT': 0,
    'KESTEN': 0,
    'KESTENBAUM': 0,
    'KESTER': 0,
    'KESTERKE': 0,
    'KESTERSON': 0,
    'KESTI': 0,
    'KESTIN': 0,
    'KESTING': 0,
    'KESTLE': 0,
    'KESTLER': 0,
    'KESTNER': 0,
    'KESWANI': 0,
    'KESWICK': 0,
    'KESZLER': 0,
    'KET': 0,
    'KETCH': 0,
    'KETCHAM': 0,
    'KETCHEL': 0,
    'KETCHEM': 0,
    'KETCHEN': 0,
    'KETCHENS': 0,
    'KETCHER': 0,
    'KETCHERSID': 0,
    'KETCHERSIDE': 0,
    'KETCHIE': 0,
    'KETCHMARK': 0,
    'KETCHUM': 0,
    'KETEL': 0,
    'KETELAAR': 0,
    'KETELBOETER': 0,
    'KETELHUT': 0,
    'KETELS': 0,
    'KETELSEN': 0,
    'KETEMA': 0,
    'KETH': 0,
    'KETHLEY': 0,
    'KETLER': 0,
    'KETNER': 0,
    'KETO': 0,
    'KETOLA': 0,
    'KETRING': 0,
    'KETRON': 0,
    'KETROW': 0,
    'KETT': 0,
    'KETTEL': 0,
    'KETTELER': 0,
    'KETTELHUT': 0,
    'KETTELKAMP': 0,
    'KETTELL': 0,
    'KETTEMAN': 0,
    'KETTENHOFEN': 0,
    'KETTENRING': 0,
    'KETTER': 0,
    'KETTERER': 0,
    'KETTERHAGEN': 0,
    'KETTERING': 0,
    'KETTERLING': 0,
    'KETTERMAN': 0,
    'KETTINGER': 0,
    'KETTLE': 0,
    'KETTLER': 0,
    'KETTLES': 0,
    'KETTLESON': 0,
    'KETTLEWELL': 0,
    'KETTMAN': 0,
    'KETTMANN': 0,
    'KETTNER': 0,
    'KETTUNEN': 0,
    'KETTWIG': 0,
    'KETURAH': 1,
    'KETZ': 0,
    'KETZER': 0,
    'KETZLER': 0,
    'KETZNER': 0,
    'KEUL': 0,
    'KEULER': 0,
    'KEUM': 0,
    'KEUNE': 0,
    'KEUNG': 0,
    'KEUNING': 0,
    'KEUP': 0,
    'KEUPER': 0,
    'KEUR': 0,
    'KEUSCH': 0,
    'KEUTER': 0,
    'KEUTZER': 0,
    'KEVA': 1,
    'KEVAN': 0,
    'KEVEN': 1,
    'KEVER': 0,
    'KEVERN': 0,
    'KEVIL': 0,
    'KEVILLE': 0,
    'KEVIN': 0.9997920194907448,
    'KEVORKIAN': 0,
    'KEW': 0,
    'KEWIN': 0,
    'KEWISH': 0,
    'KEWLEY': 0,
    'KEXEL': 0,
    'KEY': 0,
    'KEYE': 0,
    'KEYER': 0,
    'KEYES': 0,
    'KEYLER': 0,
    'KEYLON': 0,
    'KEYLOR': 0,
    'KEYMON': 0,
    'KEYONNIE': 0,
    'KEYS': 0,
    'KEYSE': 0,
    'KEYSER': 0,
    'KEYSOR': 0,
    'KEYT': 0,
    'KEYTE': 0,
    'KEYTON': 0,
    'KEYWORTH': 0,
    'KEYZER': 0,
    'KEZAR': 0,
    'KEZELE': 0,
    'KEZER': 0,
    'KEZIAH': 0,
    'KFOURY': 0,
    'KHA': 0,
    'KHABBAZ': 0,
    'KHACHATOURIAN': 0,
    'KHACHATRIAN': 0,
    'KHACHATRYAN': 0,
    'KHACHIKIAN': 0,
    'KHACHIKYAN': 0,
    'KHADEM': 0,
    'KHADEMI': 0,
    'KHADER': 0,
    'KHADIJAH': 1,
    'KHAIMOV': 0,
    'KHAIR': 0,
    'KHAIRA': 0,
    'KHAIRALLAH': 0,
    'KHAIT': 0,
    'KHAJA': 0,
    'KHAKI': 0,
    'KHAL': 0,
    'KHALAF': 0,
    'KHALED': 0,
    'KHALEEL': 0,
    'KHALFAN': 0,
    'KHALID': 0,
    'KHALIF': 0,
    'KHALIFA': 0,
    'KHALIFE': 0,
    'KHALIFEH': 0,
    'KHALIL': 0,
    'KHALILAH': 1,
    'KHALILI': 0,
    'KHALIQ': 0,
    'KHALIQUE': 0,
    'KHALSA': 0,
    'KHAM': 0,
    'KHAMIS': 0,
    'KHAMMANIVONG': 0,
    'KHAMO': 0,
    'KHAMPHOUMY': 0,
    'KHAMSOUK': 0,
    'KHAMVONGSA': 0,
    'KHAN': 0,
    'KHANAM': 0,
    'KHANDAKER': 0,
    'KHANDEKAR': 0,
    'KHANDELWAL': 0,
    'KHANG': 0,
    'KHANGURA': 0,
    'KHANI': 0,
    'KHANIN': 0,
    'KHANNA': 0,
    'KHANOM': 0,
    'KHANUM': 0,
    'KHARA': 0,
    'KHARCHENKO': 0,
    'KHARE': 0,
    'KHARITONOV': 0,
    'KHATAMI': 0,
    'KHATCHADOURIAN': 0,
    'KHATER': 0,
    'KHATIB': 0,
    'KHATIBI': 0,
    'KHATOON': 0,
    'KHATRI': 0,
    'KHATTAB': 0,
    'KHATTAK': 0,
    'KHATTAR': 0,
    'KHATUN': 0,
    'KHAU': 0,
    'KHAVARI': 0,
    'KHAW': 0,
    'KHAWAJA': 0,
    'KHAYAT': 0,
    'KHAYKIN': 0,
    'KHAZAN': 0,
    'KHEIR': 0,
    'KHEM': 0,
    'KHEMRAJ': 0,
    'KHEN': 0,
    'KHENG': 0,
    'KHER': 0,
    'KHERA': 0,
    'KHEYFETS': 0,
    'KHIEU': 0,
    'KHIEV': 0,
    'KHIM': 0,
    'KHIMANI': 0,
    'KHIN': 0,
    'KHO': 0,
    'KHOE': 0,
    'KHOJA': 0,
    'KHOKHAR': 0,
    'KHOLODENKO': 0,
    'KHON': 0,
    'KHONG': 0,
    'KHOO': 0,
    'KHOR': 0,
    'KHORRAM': 0,
    'KHORRAMI': 0,
    'KHORSANDI': 0,
    'KHOSHABA': 0,
    'KHOSHNAW': 0,
    'KHOSLA': 0,
    'KHOSRAVI': 0,
    'KHOU': 0,
    'KHOUN': 0,
    'KHOURI': 0,
    'KHOURY': 0,
    'KHOV': 0,
    'KHUAT': 0,
    'KHUC': 0,
    'KHULLAR': 0,
    'KHUN': 0,
    'KHUON': 0,
    'KHUONG': 0,
    'KHURANA': 0,
    'KHURI': 0,
    'KHURSHID': 0,
    'KHUT': 0,
    'KHUTH': 0,
    'KHUU': 0,
    'KHWAJA': 0,
    'KHY': 0,
    'KI': 0,
    'KIA': 0.9708737864077669,
    'KIAH': 0,
    'KIAN': 0,
    'KIANA': 1,
    'KIANG': 0,
    'KIANI': 0,
    'KIARA': 1,
    'KIBBE': 0,
    'KIBBEE': 0,
    'KIBBEY': 0,
    'KIBBIE': 0,
    'KIBBLE': 0,
    'KIBBLER': 0,
    'KIBBONS': 0,
    'KIBBY': 0,
    'KIBE': 0,
    'KIBEL': 0,
    'KIBLER': 0,
    'KIBLIN': 0,
    'KIBLING': 0,
    'KIBLINGER': 0,
    'KIBODEAUX': 0,
    'KIBORT': 0,
    'KIBRIA': 0,
    'KIBURZ': 0,
    'KICAK': 0,
    'KICE': 0,
    'KICH': 0,
    'KICHLER': 0,
    'KICHLINE': 0,
    'KICINSKI': 0,
    'KICK': 0,
    'KICKBUSCH': 0,
    'KICKBUSH': 0,
    'KICKEL': 0,
    'KICKER': 0,
    'KICKERT': 0,
    'KICKERY': 0,
    'KICKHAM': 0,
    'KICKLIGHTER': 0,
    'KICKLITER': 0,
    'KICZEK': 0,
    'KID': 0,
    'KIDA': 0,
    'KIDANE': 0,
    'KIDANI': 0,
    'KIDD': 0,
    'KIDDER': 0,
    'KIDDIE': 0,
    'KIDDLE': 0,
    'KIDDOO': 0,
    'KIDDY': 0,
    'KIDMAN': 0,
    'KIDNER': 0,
    'KIDNEY': 0,
    'KIDO': 0,
    'KIDRICK': 0,
    'KIDWAI': 0,
    'KIDWELL': 0,
    'KIDWILER': 0,
    'KIE': 0,
    'KIEBACH': 0,
    'KIEBER': 0,
    'KIEBLER': 0,
    'KIECK': 0,
    'KIECKBUSCH': 0,
    'KIECKER': 0,
    'KIECKHAFER': 0,
    'KIECKHEFER': 0,
    'KIEDAISCH': 0,
    'KIEDROWSKI': 0,
    'KIEF': 0,
    'KIEFABER': 0,
    'KIEFAT': 0,
    'KIEFEL': 0,
    'KIEFER': 0,
    'KIEFERT': 0,
    'KIEFF': 0,
    'KIEFFABER': 0,
    'KIEFFER': 0,
    'KIEFFNER': 0,
    'KIEFNER': 0,
    'KIEFT': 0,
    'KIEGER': 0,
    'KIEHL': 0,
    'KIEHLE': 0,
    'KIEHLMEIER': 0,
    'KIEHM': 0,
    'KIEHN': 0,
    'KIEHNAU': 0,
    'KIEHNE': 0,
    'KIEKE': 0,
    'KIEKHAEFER': 0,
    'KIEL': 0,
    'KIELAR': 0,
    'KIELAS': 0,
    'KIELB': 0,
    'KIELBASA': 0,
    'KIELBLOCK': 0,
    'KIELCZEWSKI': 0,
    'KIELE': 0,
    'KIELER': 0,
    'KIELEY': 0,
    'KIELHORN': 0,
    'KIELIAN': 0,
    'KIELICH': 0,
    'KIELING': 0,
    'KIELISZEWSKI': 0,
    'KIELMA': 0,
    'KIELMAN': 0,
    'KIELMEYER': 0,
    'KIELPINSKI': 0,
    'KIELTY': 0,
    'KIELTYKA': 0,
    'KIELY': 0,
    'KIEM': 0,
    'KIEMELE': 0,
    'KIEN': 0,
    'KIENAST': 0,
    'KIENBAUM': 0,
    'KIENE': 0,
    'KIENER': 0,
    'KIENG': 0,
    'KIENHOLZ': 0,
    'KIENINGER': 0,
    'KIENITZ': 0,
    'KIENLE': 0,
    'KIENLEN': 0,
    'KIENOW': 0,
    'KIENTZ': 0,
    'KIENTZY': 0,
    'KIENZLE': 0,
    'KIENZLER': 0,
    'KIEP': 0,
    'KIEPE': 0,
    'KIEPER': 0,
    'KIEPERT': 0,
    'KIEPKE': 0,
    'KIER': 0,
    'KIERA': 1,
    'KIERAN': 0,
    'KIERAS': 0,
    'KIERCE': 0,
    'KIEREN': 0,
    'KIERNAN': 0,
    'KIERNICKI': 0,
    'KIERS': 0,
    'KIERSEY': 0,
    'KIERSTEAD': 0,
    'KIERSTEN': 1,
    'KIERZEK': 0,
    'KIERZKOWSKI': 0,
    'KIES': 0,
    'KIESAU': 0,
    'KIESCHNICK': 0,
    'KIESEL': 0,
    'KIESELBACH': 0,
    'KIESELHORST': 0,
    'KIESER': 0,
    'KIESEWETTER': 0,
    'KIESGEN': 0,
    'KIESHA': 1,
    'KIESLER': 0,
    'KIESLICH': 0,
    'KIESLING': 0,
    'KIESNER': 0,
    'KIESOW': 0,
    'KIESS': 0,
    'KIESSEL': 0,
    'KIESSLING': 0,
    'KIEST': 0,
    'KIESTER': 0,
    'KIESTLER': 0,
    'KIESZ': 0,
    'KIETA': 0,
    'KIETH': 0.9819967266775776,
    'KIETZER': 0,
    'KIETZMAN': 0,
    'KIETZMANN': 0,
    'KIEU': 0,
    'KIEVIT': 0,
    'KIEWEL': 0,
    'KIEWIET': 0,
    'KIEWIT': 0,
    'KIEWRA': 0,
    'KIFER': 0,
    'KIFF': 0,
    'KIFFE': 0,
    'KIFFER': 0,
    'KIFFMEYER': 0,
    'KIFLE': 0,
    'KIGAR': 0,
    'KIGER': 0,
    'KIGGANS': 0,
    'KIGGINS': 0,
    'KIGHT': 0,
    'KIGHTLINGER': 0,
    'KIHARA': 0,
    'KIHL': 0,
    'KIHLE': 0,
    'KIHLSTROM': 0,
    'KIHM': 0,
    'KIHN': 0,
    'KIJAK': 0,
    'KIJANKA': 0,
    'KIJEK': 0,
    'KIJEWSKI': 0,
    'KIJOWSKI': 0,
    'KIK': 0,
    'KIKEL': 0,
    'KIKENDALL': 0,
    'KIKER': 0,
    'KIKKERT': 0,
    'KIKO': 0,
    'KIKTA': 0,
    'KIKUCHI': 0,
    'KIKUTA': 0,
    'KIL': 0,
    'KILA': 0,
    'KILANDER': 0,
    'KILANOWSKI': 0,
    'KILAR': 0,
    'KILB': 0,
    'KILBANE': 0,
    'KILBARGER': 0,
    'KILBER': 0,
    'KILBERG': 0,
    'KILBERT': 0,
    'KILBEY': 0,
    'KILBORN': 0,
    'KILBOURN': 0,
    'KILBOURNE': 0,
    'KILBREATH': 0,
    'KILBRETH': 0,
    'KILBRIDE': 0,
    'KILBURG': 0,
    'KILBURN': 0,
    'KILBURY': 0,
    'KILBY': 0,
    'KILCHENSTEIN': 0,
    'KILCHER': 0,
    'KILCHRIST': 0,
    'KILCLINE': 0,
    'KILCOIN': 0,
    'KILCOLLINS': 0,
    'KILCOMMONS': 0,
    'KILCOURSE': 0,
    'KILCOYNE': 0,
    'KILCREASE': 0,
    'KILCULLEN': 0,
    'KILCUP': 0,
    'KILDAHL': 0,
    'KILDARE': 0,
    'KILDAY': 0,
    'KILDE': 0,
    'KILDEA': 0,
    'KILDOW': 0,
    'KILDUFF': 0,
    'KILE': 0,
    'KILEN': 0,
    'KILER': 0,
    'KILES': 0,
    'KILEY': 0.49627791563275436,
    'KILFEATHER': 0,
    'KILFOIL': 0,
    'KILFOY': 0,
    'KILFOYLE': 0,
    'KILGALLEN': 0,
    'KILGALLON': 0,
    'KILGANNON': 0,
    'KILGARIFF': 0,
    'KILGAS': 0,
    'KILGER': 0,
    'KILGO': 0,
    'KILGORE': 0,
    'KILGOUR': 0,
    'KILGUS': 0,
    'KILHEFFER': 0,
    'KILHEFNER': 0,
    'KILHOFFER': 0,
    'KILIAN': 0,
    'KILIANY': 0,
    'KILIC': 0,
    'KILICHOWSKI': 0,
    'KILIMNIK': 0,
    'KILINSKI': 0,
    'KILKEARY': 0,
    'KILKELLY': 0,
    'KILKENNY': 0,
    'KILKER': 0,
    'KILL': 0,
    'KILLACKEY': 0,
    'KILLAM': 0,
    'KILLE': 0,
    'KILLEBREW': 0,
    'KILLEEN': 0,
    'KILLELEA': 0,
    'KILLEN': 0,
    'KILLENS': 0,
    'KILLER': 0,
    'KILLETT': 0,
    'KILLETTE': 0,
    'KILLEWALD': 0,
    'KILLEY': 0,
    'KILLGO': 0,
    'KILLGORE': 0,
    'KILLHAM': 0,
    'KILLIAN': 0,
    'KILLIANY': 0,
    'KILLICK': 0,
    'KILLIEBREW': 0,
    'KILLILEA': 0,
    'KILLIN': 0,
    'KILLING': 0,
    'KILLINGBECK': 0,
    'KILLINGER': 0,
    'KILLINGS': 0,
    'KILLINGSWORTH': 0,
    'KILLINGWORTH': 0,
    'KILLINS': 0,
    'KILLION': 0,
    'KILLIP': 0,
    'KILLIPS': 0,
    'KILLIUS': 0,
    'KILLMAN': 0,
    'KILLMER': 0,
    'KILLMEYER': 0,
    'KILLMON': 0,
    'KILLORAN': 0,
    'KILLOREN': 0,
    'KILLOUGH': 0,
    'KILLOY': 0,
    'KILLPACK': 0,
    'KILLPATRICK': 0,
    'KILLSNIGHT': 0,
    'KILLY': 0,
    'KILMAN': 0,
    'KILMARTIN': 0,
    'KILMER': 0,
    'KILMON': 0,
    'KILMURRAY': 0,
    'KILNER': 0,
    'KILO': 0,
    'KILP': 0,
    'KILPACK': 0,
    'KILPATRIC': 0,
    'KILPATRICK': 0,
    'KILPELA': 0,
    'KILPONEN': 0,
    'KILPS': 0,
    'KILRAIN': 0,
    'KILROY': 0,
    'KILSBY': 0,
    'KILSDONK': 0,
    'KILSON': 0,
    'KILSTROM': 0,
    'KILTHAU': 0,
    'KILTON': 0,
    'KILTS': 0,
    'KILTY': 0,
    'KILTZ': 0,
    'KILUK': 0,
    'KILWEIN': 0,
    'KILZER': 0,
    'KIM': 0.7411671583795064,
    'KIMAK': 0,
    'KIMANI': 0,
    'KIMATA': 0,
    'KIMBAL': 0,
    'KIMBALL': 0,
    'KIMBEL': 0,
    'KIMBELL': 0,
    'KIMBER': 0.6369426751592356,
    'KIMBERELY': 1,
    'KIMBERLAIN': 0,
    'KIMBERLEE': 1,
    'KIMBERLEY': 0.9924385633270321,
    'KIMBERLI': 1,
    'KIMBERLIE': 1,
    'KIMBERLIN': 0,
    'KIMBERLING': 0,
    'KIMBERLY': 0.9982372397948068,
    'KIMBERY': 1,
    'KIMBLE': 0,
    'KIMBLER': 0,
    'KIMBLEY': 0,
    'KIMBRA': 1,
    'KIMBREL': 0,
    'KIMBRELL': 0,
    'KIMBREW': 0,
    'KIMBRIEL': 0,
    'KIMBRIL': 0,
    'KIMBRO': 0,
    'KIMBROUGH': 0,
    'KIMBROW': 0,
    'KIME': 0,
    'KIMEL': 0,
    'KIMELMAN': 0,
    'KIMERER': 0,
    'KIMERLING': 0,
    'KIMERY': 0,
    'KIMES': 0,
    'KIMI': 1,
    'KIMICH': 0,
    'KIMIKO': 1,
    'KIMLER': 0,
    'KIMLIN': 0,
    'KIMLING': 0,
    'KIMLINGER': 0,
    'KIMM': 0,
    'KIMME': 0,
    'KIMMEL': 0,
    'KIMMELL': 0,
    'KIMMELMAN': 0,
    'KIMMER': 0,
    'KIMMERLE': 0,
    'KIMMERLING': 0,
    'KIMMERLY': 0,
    'KIMMES': 0,
    'KIMMET': 0,
    'KIMMETT': 0,
    'KIMMEY': 0,
    'KIMMICH': 0,
    'KIMMICK': 0,
    'KIMMINAU': 0,
    'KIMMINS': 0,
    'KIMMITT': 0,
    'KIMMONS': 0,
    'KIMMY': 0,
    'KIMOTO': 0,
    'KIMP': 0,
    'KIMPEL': 0,
    'KIMPLE': 0,
    'KIMPSON': 0,
    'KIMPTON': 0,
    'KIMREY': 0,
    'KIMSEY': 0,
    'KIMURA': 0,
    'KIMZEY': 0,
    'KIN': 0,
    'KINA': 0.8403361344537815,
    'KINABREW': 0,
    'KINAHAN': 0,
    'KINAL': 0,
    'KINANE': 0,
    'KINARD': 0,
    'KINART': 0,
    'KINAS': 0,
    'KINAST': 0,
    'KINBACK': 0,
    'KINBERG': 0,
    'KINBERGER': 0,
    'KINCADE': 0,
    'KINCAID': 0,
    'KINCAIDE': 0,
    'KINCANNON': 0,
    'KINCANON': 0,
    'KINCART': 0,
    'KINCEL': 0,
    'KINCER': 0,
    'KINCEY': 0,
    'KINCH': 0,
    'KINCHELOE': 0,
    'KINCHEN': 0,
    'KINCY': 0,
    'KIND': 0,
    'KINDALL': 0,
    'KINDBERG': 0,
    'KINDE': 0,
    'KINDEL': 0,
    'KINDELAN': 0,
    'KINDELAY': 0,
    'KINDELBERGER': 0,
    'KINDELL': 0,
    'KINDELSPIRE': 0,
    'KINDEM': 0,
    'KINDER': 0,
    'KINDERKNECHT': 0,
    'KINDERMAN': 0,
    'KINDERMANN': 0,
    'KINDERVATER': 0,
    'KINDHART': 0,
    'KINDIG': 0,
    'KINDINGER': 0,
    'KINDL': 0,
    'KINDLE': 0,
    'KINDLER': 0,
    'KINDLEY': 0,
    'KINDNESS': 0,
    'KINDOLL': 0,
    'KINDRA': 1,
    'KINDRED': 0,
    'KINDRICK': 0,
    'KINDS': 0,
    'KINDSCHI': 0,
    'KINDSCHUH': 0,
    'KINDSCHY': 0,
    'KINDSETH': 0,
    'KINDSFATER': 0,
    'KINDSFATHER': 0,
    'KINDSVATER': 0,
    'KINDT': 0,
    'KINDY': 0,
    'KINDYA': 0,
    'KINE': 0,
    'KINEALY': 0,
    'KINEL': 0,
    'KINER': 0,
    'KINERK': 0,
    'KINES': 0,
    'KING': 0.023990883464283574,
    'KINGAN': 0,
    'KINGBIRD': 0,
    'KINGCADE': 0,
    'KINGDOM': 0,
    'KINGDON': 0,
    'KINGEN': 0,
    'KINGER': 0,
    'KINGERY': 0,
    'KINGFISHER': 0,
    'KINGHAM': 0,
    'KINGHORN': 0,
    'KINGLAND': 0,
    'KINGMA': 0,
    'KINGMAN': 0,
    'KINGREA': 0,
    'KINGREE': 0,
    'KINGREY': 0,
    'KINGRY': 0,
    'KINGS': 0,
    'KINGSBERRY': 0,
    'KINGSBOROUGH': 0,
    'KINGSBURY': 0,
    'KINGSBY': 0,
    'KINGSEED': 0,
    'KINGSFORD': 0,
    'KINGSLAND': 0,
    'KINGSLEY': 0,
    'KINGSMILL': 0,
    'KINGSMORE': 0,
    'KINGSOLVER': 0,
    'KINGSTON': 0,
    'KINGTON': 0,
    'KINGWOOD': 0,
    'KINI': 0,
    'KINIKIN': 0,
    'KINIKINI': 0,
    'KINIMAKA': 0,
    'KINION': 0,
    'KINIRY': 0,
    'KINISON': 0,
    'KINJERSKI': 0,
    'KINJO': 0,
    'KINK': 0,
    'KINKADE': 0,
    'KINKAID': 0,
    'KINKEAD': 0,
    'KINKEL': 0,
    'KINKELA': 0,
    'KINKELAAR': 0,
    'KINKENNON': 0,
    'KINKER': 0,
    'KINKLE': 0,
    'KINKOPF': 0,
    'KINLAW': 0,
    'KINLER': 0,
    'KINLEY': 0,
    'KINLIN': 0,
    'KINLOCH': 0,
    'KINLOCK': 0,
    'KINLOW': 0,
    'KINMAN': 0,
    'KINMON': 0,
    'KINN': 0,
    'KINNA': 0,
    'KINNAIRD': 0,
    'KINNALLY': 0,
    'KINNAMAN': 0,
    'KINNAMON': 0,
    'KINNAN': 0,
    'KINNANE': 0,
    'KINNARD': 0,
    'KINNAS': 0,
    'KINNE': 0,
    'KINNEAR': 0,
    'KINNEBERG': 0,
    'KINNEBREW': 0,
    'KINNEE': 0,
    'KINNEER': 0,
    'KINNEL': 0,
    'KINNELL': 0,
    'KINNEMAN': 0,
    'KINNEN': 0,
    'KINNER': 0,
    'KINNERSLEY': 0,
    'KINNETT': 0,
    'KINNETZ': 0,
    'KINNEY': 0,
    'KINNIBURGH': 0,
    'KINNICK': 0,
    'KINNICUTT': 0,
    'KINNIE': 0,
    'KINNIER': 0,
    'KINNIN': 0,
    'KINNING': 0,
    'KINNINGER': 0,
    'KINNISON': 0,
    'KINNON': 0,
    'KINNUNEN': 0,
    'KINNY': 0,
    'KINO': 0,
    'KINOSHITA': 0,
    'KINOWSKI': 0,
    'KINROSS': 0,
    'KINS': 0,
    'KINSAUL': 0,
    'KINSCH': 0,
    'KINSEL': 0,
    'KINSELL': 0,
    'KINSELLA': 0,
    'KINSER': 0,
    'KINSETH': 0,
    'KINSEY': 0,
    'KINSFATHER': 0,
    'KINSINGER': 0,
    'KINSKY': 0,
    'KINSLAND': 0,
    'KINSLER': 0,
    'KINSLEY': 0,
    'KINSLOW': 0,
    'KINSMAN': 0,
    'KINSOLVING': 0,
    'KINSON': 0,
    'KINSTLE': 0,
    'KINSTLER': 0,
    'KINT': 0,
    'KINTANAR': 0,
    'KINTER': 0,
    'KINTIGH': 0,
    'KINTNER': 0,
    'KINTON': 0,
    'KINTOP': 0,
    'KINTZ': 0,
    'KINTZEL': 0,
    'KINTZELE': 0,
    'KINTZER': 0,
    'KINTZLE': 0,
    'KINTZLER': 0,
    'KINVILLE': 0,
    'KINWORTHY': 0,
    'KINYANJUI': 0,
    'KINYON': 0,
    'KINZ': 0,
    'KINZALOW': 0,
    'KINZEL': 0,
    'KINZER': 0,
    'KINZEY': 0,
    'KINZIE': 0,
    'KINZIG': 0,
    'KINZINGER': 0,
    'KINZLE': 0,
    'KINZLER': 0,
    'KINZY': 0,
    'KIO': 0,
    'KIOLBASA': 0,
    'KIOLBASSA': 0,
    'KIOS': 0,
    'KIOUS': 0,
    'KIP': 0.984251968503937,
    'KIPE': 0,
    'KIPER': 0,
    'KIPFER': 0,
    'KIPFMILLER': 0,
    'KIPHART': 0,
    'KIPKA': 0,
    'KIPKE': 0,
    'KIPKER': 0,
    'KIPLE': 0,
    'KIPLEY': 0,
    'KIPLING': 0,
    'KIPLINGER': 0,
    'KIPNIS': 0,
    'KIPP': 0,
    'KIPPEN': 0,
    'KIPPENBERGER': 0,
    'KIPPENBROCK': 0,
    'KIPPENHAN': 0,
    'KIPPER': 0,
    'KIPPERMAN': 0,
    'KIPPES': 0,
    'KIPPING': 0,
    'KIPPLE': 0,
    'KIPPLEY': 0,
    'KIPPS': 0,
    'KIRA': 0.9852216748768473,
    'KIRACOFE': 0,
    'KIRAKOSIAN': 0,
    'KIRAKOSYAN': 0,
    'KIRAL': 0,
    'KIRALY': 0,
    'KIRAN': 0,
    'KIRBACH': 0,
    'KIRBERGER': 0,
    'KIRBO': 0,
    'KIRBOW': 0,
    'KIRBY': 0.361247947454844,
    'KIRCH': 0,
    'KIRCHBERG': 0,
    'KIRCHBERGER': 0,
    'KIRCHDORFER': 0,
    'KIRCHEN': 0,
    'KIRCHENBAUER': 0,
    'KIRCHER': 0,
    'KIRCHGESSNER': 0,
    'KIRCHHARR': 0,
    'KIRCHHEIMER': 0,
    'KIRCHHOEFER': 0,
    'KIRCHHOF': 0,
    'KIRCHHOFER': 0,
    'KIRCHHOFF': 0,
    'KIRCHMAN': 0,
    'KIRCHMANN': 0,
    'KIRCHMEIER': 0,
    'KIRCHMER': 0,
    'KIRCHMEYER': 0,
    'KIRCHNER': 0,
    'KIRCHOFER': 0,
    'KIRCHOFF': 0,
    'KIRCKOF': 0,
    'KIRCUS': 0,
    'KIRETA': 0,
    'KIRGAN': 0,
    'KIRGIS': 0,
    'KIRIAKOS': 0,
    'KIRIAN': 0,
    'KIRIAZIS': 0,
    'KIRICHENKO': 0,
    'KIRIHARA': 0,
    'KIRIK': 0,
    'KIRILA': 0,
    'KIRILUK': 0,
    'KIRIN': 0,
    'KIRINCIC': 0,
    'KIRISITS': 0,
    'KIRITSIS': 0,
    'KIRK': 0.7174231332357247,
    'KIRKALDIE': 0,
    'KIRKALDY': 0,
    'KIRKBRIDE': 0,
    'KIRKBY': 0,
    'KIRKCONNELL': 0,
    'KIRKE': 0,
    'KIRKEBY': 0,
    'KIRKEENG': 0,
    'KIRKEGAARD': 0,
    'KIRKEIDE': 0,
    'KIRKELIE': 0,
    'KIRKENDALL': 0,
    'KIRKENDOLL': 0,
    'KIRKER': 0,
    'KIRKES': 0,
    'KIRKEY': 0,
    'KIRKHAM': 0,
    'KIRKHART': 0,
    'KIRKHOFF': 0,
    'KIRKHUFF': 0,
    'KIRKING': 0,
    'KIRKISH': 0,
    'KIRKLAND': 0,
    'KIRKLEN': 0,
    'KIRKLEY': 0,
    'KIRKLIN': 0,
    'KIRKLING': 0,
    'KIRKMAN': 0,
    'KIRKNER': 0,
    'KIRKNESS': 0,
    'KIRKORIAN': 0,
    'KIRKPATRICK': 0,
    'KIRKS': 0,
    'KIRKSEY': 0,
    'KIRKTON': 0,
    'KIRKUM': 0,
    'KIRKUP': 0,
    'KIRKUS': 0,
    'KIRKWOOD': 0,
    'KIRL': 0,
    'KIRLAND': 0,
    'KIRLEW': 0,
    'KIRLEY': 0,
    'KIRLIN': 0,
    'KIRMA': 0,
    'KIRMAN': 0,
    'KIRMANI': 0,
    'KIRMER': 0,
    'KIRMSE': 0,
    'KIRN': 0,
    'KIRNER': 0,
    'KIRNON': 0,
    'KIROS': 0,
    'KIROUAC': 0,
    'KIRPALANI': 0,
    'KIRPATRICK': 0,
    'KIRRANE': 0,
    'KIRSCH': 0,
    'KIRSCHBAUM': 0,
    'KIRSCHENBAUM': 0,
    'KIRSCHENHEITER': 0,
    'KIRSCHENMAN': 0,
    'KIRSCHENMANN': 0,
    'KIRSCHER': 0,
    'KIRSCHKE': 0,
    'KIRSCHLING': 0,
    'KIRSCHMAN': 0,
    'KIRSCHMANN': 0,
    'KIRSCHNER': 0,
    'KIRSCHT': 0,
    'KIRSH': 0,
    'KIRSHBAUM': 0,
    'KIRSHENBAUM': 0,
    'KIRSHMAN': 0,
    'KIRSHNER': 0,
    'KIRSHY': 0,
    'KIRSNER': 0,
    'KIRSON': 0,
    'KIRSOP': 0,
    'KIRST': 0,
    'KIRSTE': 0,
    'KIRSTEIN': 0,
    'KIRSTEN': 0.9873834339001646,
    'KIRSTIE': 1,
    'KIRSTIN': 1,
    'KIRSTINE': 0,
    'KIRT': 0,
    'KIRTLAND': 0,
    'KIRTLEY': 0,
    'KIRTMAN': 0,
    'KIRTNER': 0,
    'KIRTON': 0,
    'KIRTS': 0,
    'KIRTZ': 0,
    'KIRVAN': 0,
    'KIRVEN': 0,
    'KIRVIN': 0,
    'KIRWAN': 0,
    'KIRWIN': 0,
    'KIRZNER': 0,
    'KIS': 0,
    'KISABETH': 0,
    'KISALA': 0,
    'KISAMORE': 0,
    'KISBY': 0,
    'KISCH': 0,
    'KISE': 0,
    'KISEL': 0,
    'KISELA': 0,
    'KISELEV': 0,
    'KISELICA': 0,
    'KISER': 0,
    'KISH': 0,
    'KISHA': 0.9933774834437086,
    'KISHABA': 0,
    'KISHBAUGH': 0,
    'KISHEL': 0,
    'KISHI': 0,
    'KISHIDA': 0,
    'KISHIMOTO': 0,
    'KISHIYAMA': 0,
    'KISHMAN': 0,
    'KISHORE': 0,
    'KISHPAUGH': 0,
    'KISHUN': 0,
    'KISIAH': 0,
    'KISIC': 0,
    'KISICKI': 0,
    'KISIEL': 0,
    'KISIELEWSKI': 0,
    'KISINGER': 0,
    'KISKA': 0,
    'KISKADDEN': 0,
    'KISKADEN': 0,
    'KISKER': 0,
    'KISKIS': 0,
    'KISKO': 0,
    'KISLER': 0,
    'KISLEY': 0,
    'KISLING': 0,
    'KISNER': 0,
    'KISO': 0,
    'KISON': 0,
    'KISOR': 0,
    'KISPERT': 0,
    'KISS': 0,
    'KISSACK': 0,
    'KISSAM': 0,
    'KISSANE': 0,
    'KISSEBERTH': 0,
    'KISSEE': 0,
    'KISSEL': 0,
    'KISSELBURG': 0,
    'KISSELL': 0,
    'KISSER': 0,
    'KISSI': 0,
    'KISSIAH': 0,
    'KISSICK': 0,
    'KISSINGER': 0,
    'KISSLER': 0,
    'KISSLING': 0,
    'KISSLINGER': 0,
    'KISSMAN': 0,
    'KISSNER': 0,
    'KISSOCK': 0,
    'KISSOON': 0,
    'KIST': 0,
    'KISTE': 0,
    'KISTENMACHER': 0,
    'KISTER': 0,
    'KISTING': 0,
    'KISTLER': 0,
    'KISTNER': 0,
    'KISTO': 0,
    'KISWANI': 0,
    'KISZKA': 0,
    'KIT': 0.9174311926605505,
    'KITA': 0,
    'KITAGAWA': 0,
    'KITAHARA': 0,
    'KITAJIMA': 0,
    'KITAMURA': 0,
    'KITANO': 0,
    'KITAOKA': 0,
    'KITASHIMA': 0,
    'KITAY': 0,
    'KITAYAMA': 0,
    'KITCH': 0,
    'KITCHEL': 0,
    'KITCHELL': 0,
    'KITCHEN': 0,
    'KITCHENER': 0,
    'KITCHENMAN': 0,
    'KITCHENMASTER': 0,
    'KITCHENS': 0,
    'KITCHER': 0,
    'KITCHIN': 0,
    'KITCHING': 0,
    'KITCHINGS': 0,
    'KITCHNER': 0,
    'KITE': 0,
    'KITELEY': 0,
    'KITELINGER': 0,
    'KITER': 0,
    'KITH': 0,
    'KITHCART': 0,
    'KITKA': 0,
    'KITKO': 0,
    'KITLER': 0,
    'KITLEY': 0,
    'KITNER': 0,
    'KITO': 0,
    'KITOWSKI': 0,
    'KITRELL': 0,
    'KITSCH': 0,
    'KITSELMAN': 0,
    'KITSIS': 0,
    'KITSMILLER': 0,
    'KITSON': 0,
    'KITSOS': 0,
    'KITT': 0,
    'KITTA': 0,
    'KITTAY': 0,
    'KITTEL': 0,
    'KITTELBERGER': 0,
    'KITTELL': 0,
    'KITTELSON': 0,
    'KITTEN': 0,
    'KITTER': 0,
    'KITTERMAN': 0,
    'KITTIE': 1,
    'KITTILSON': 0,
    'KITTING': 0,
    'KITTINGER': 0,
    'KITTLE': 0,
    'KITTLEMAN': 0,
    'KITTLER': 0,
    'KITTLES': 0,
    'KITTLESON': 0,
    'KITTNER': 0,
    'KITTO': 0,
    'KITTOCK': 0,
    'KITTOE': 0,
    'KITTREDGE': 0,
    'KITTRELL': 0,
    'KITTRIDGE': 0,
    'KITTS': 0,
    'KITTSON': 0,
    'KITTY': 1,
    'KITZ': 0,
    'KITZAN': 0,
    'KITZEROW': 0,
    'KITZINGER': 0,
    'KITZKE': 0,
    'KITZLER': 0,
    'KITZMAN': 0,
    'KITZMANN': 0,
    'KITZMILLER': 0,
    'KITZROW': 0,
    'KIU': 0,
    'KIVEL': 0,
    'KIVELA': 0,
    'KIVELL': 0,
    'KIVETT': 0,
    'KIVI': 0,
    'KIVIAT': 0,
    'KIVISTO': 0,
    'KIVLEHAN': 0,
    'KIVLEN': 0,
    'KIVLER': 0,
    'KIVLIN': 0,
    'KIWAK': 0,
    'KIWALA': 0,
    'KIXMILLER': 0,
    'KIYABU': 0,
    'KIYAN': 0,
    'KIYOHARA': 0,
    'KIYOKO': 1,
    'KIYOTA': 0,
    'KIYUNA': 0,
    'KIZER': 0,
    'KIZEWSKI': 0,
    'KIZIAH': 0,
    'KIZIOR': 0,
    'KIZIRIAN': 0,
    'KIZIS': 0,
    'KIZNER': 0,
    'KIZY': 0,
    'KIZZAR': 0,
    'KIZZEE': 0,
    'KIZZIA': 0,
    'KIZZIAH': 0,
    'KIZZIAR': 0,
    'KIZZIE': 0.8928571428571428,
    'KIZZIRE': 0,
    'KIZZY': 1,
    'KJAER': 0,
    'KJAR': 0,
    'KJELDGAARD': 0,
    'KJELDSEN': 0,
    'KJELLAND': 0,
    'KJELLANDER': 0,
    'KJELLBERG': 0,
    'KJELLMAN': 0,
    'KJELLSEN': 0,
    'KJENSTAD': 0,
    'KJER': 0,
    'KJERGAARD': 0,
    'KJERSTAD': 0,
    'KJOME': 0,
    'KJONAAS': 0,
    'KJOS': 0,
    'KLAAS': 0,
    'KLAASEN': 0,
    'KLAASSEN': 0,
    'KLABEN': 0,
    'KLABER': 0,
    'KLABO': 0,
    'KLABUNDE': 0,
    'KLACIK': 0,
    'KLADDER': 0,
    'KLADE': 0,
    'KLADIS': 0,
    'KLAEHN': 0,
    'KLAER': 0,
    'KLAERS': 0,
    'KLAES': 0,
    'KLAFEHN': 0,
    'KLAFF': 0,
    'KLAFKA': 0,
    'KLAFT': 0,
    'KLAFTER': 0,
    'KLAG': 0,
    'KLAGER': 0,
    'KLAGES': 0,
    'KLAHN': 0,
    'KLAHR': 0,
    'KLAHRE': 0,
    'KLAIBER': 0,
    'KLAICH': 0,
    'KLAIN': 0,
    'KLAIR': 0,
    'KLAISS': 0,
    'KLAK': 0,
    'KLAKAMP': 0,
    'KLAM': 0,
    'KLAMAN': 0,
    'KLAMAR': 0,
    'KLAMER': 0,
    'KLAMERT': 0,
    'KLAMERUS': 0,
    'KLAMFOTH': 0,
    'KLAMM': 0,
    'KLAMMER': 0,
    'KLAMPE': 0,
    'KLAMUT': 0,
    'KLAN': 0,
    'KLANDER': 0,
    'KLANDERUD': 0,
    'KLANE': 0,
    'KLANG': 0,
    'KLANK': 0,
    'KLANKE': 0,
    'KLANN': 0,
    'KLAP': 0,
    'KLAPAK': 0,
    'KLAPATCH': 0,
    'KLAPHAKE': 0,
    'KLAPHEKE': 0,
    'KLAPKA': 0,
    'KLAPMAN': 0,
    'KLAPP': 0,
    'KLAPPENBACH': 0,
    'KLAPPER': 0,
    'KLAPPERICH': 0,
    'KLAPPROTH': 0,
    'KLAPROTH': 0,
    'KLAR': 0,
    'KLARA': 0.9615384615384616,
    'KLARE': 0,
    'KLAREN': 0,
    'KLARENBEEK': 0,
    'KLARER': 0,
    'KLARIC': 0,
    'KLARICH': 0,
    'KLARK': 0,
    'KLARKOWSKI': 0,
    'KLARMAN': 0,
    'KLARMANN': 0,
    'KLARNER': 0,
    'KLAS': 0,
    'KLASE': 0,
    'KLASEK': 0,
    'KLASEN': 0,
    'KLASING': 0,
    'KLASINSKI': 0,
    'KLASKY': 0,
    'KLASS': 0,
    'KLASSEN': 0,
    'KLASSY': 0,
    'KLATKA': 0,
    'KLATT': 0,
    'KLATTE': 0,
    'KLAU': 0,
    'KLAUBER': 0,
    'KLAUCK': 0,
    'KLAUDER': 0,
    'KLAUDT': 0,
    'KLAUER': 0,
    'KLAUK': 0,
    'KLAUKA': 0,
    'KLAUKE': 0,
    'KLAUS': 0,
    'KLAUSE': 0,
    'KLAUSEN': 0,
    'KLAUSER': 0,
    'KLAUSING': 0,
    'KLAUSMAN': 0,
    'KLAUSMEIER': 0,
    'KLAUSMEYER': 0,
    'KLAUSNER': 0,
    'KLAUSS': 0,
    'KLAUSTERMEIER': 0,
    'KLAVE': 0,
    'KLAVER': 0,
    'KLAVERKAMP': 0,
    'KLAVINS': 0,
    'KLAVON': 0,
    'KLAWINSKI': 0,
    'KLAWITER': 0,
    'KLAWITTER': 0,
    'KLAWON': 0,
    'KLAWONN': 0,
    'KLAWUHN': 0,
    'KLAY': 0,
    'KLAYBOR': 0,
    'KLAYMAN': 0,
    'KLCO': 0,
    'KLEAR': 0,
    'KLEB': 0,
    'KLEBA': 0,
    'KLEBAN': 0,
    'KLEBANOFF': 0,
    'KLEBANOV': 0,
    'KLEBBA': 0,
    'KLEBE': 0,
    'KLEBENOW': 0,
    'KLEBER': 0,
    'KLEBES': 0,
    'KLEBS': 0,
    'KLECAN': 0,
    'KLECHA': 0,
    'KLECK': 0,
    'KLECKA': 0,
    'KLECKER': 0,
    'KLECKLER': 0,
    'KLECKLEY': 0,
    'KLECKNER': 0,
    'KLECZKA': 0,
    'KLECZKOWSKI': 0,
    'KLECZYNSKI': 0,
    'KLEDZIK': 0,
    'KLEE': 0,
    'KLEEB': 0,
    'KLEEBERG': 0,
    'KLEEBERGER': 0,
    'KLEEFISCH': 0,
    'KLEEHAMMER': 0,
    'KLEEKAMP': 0,
    'KLEEMAN': 0,
    'KLEEMANN': 0,
    'KLEEMEYER': 0,
    'KLEEN': 0,
    'KLEER': 0,
    'KLEES': 0,
    'KLEESCHULTE': 0,
    'KLEESE': 0,
    'KLEESPIES': 0,
    'KLEEVES': 0,
    'KLEFFMAN': 0,
    'KLEFFNER': 0,
    'KLEFSTAD': 0,
    'KLEGER': 0,
    'KLEHM': 0,
    'KLEHN': 0,
    'KLEHR': 0,
    'KLEI': 0,
    'KLEIBER': 0,
    'KLEIBOEKER': 0,
    'KLEID': 0,
    'KLEIDON': 0,
    'KLEIER': 0,
    'KLEIFGEN': 0,
    'KLEIKAMP': 0,
    'KLEIM': 0,
    'KLEIMAN': 0,
    'KLEIMANN': 0,
    'KLEIMOLA': 0,
    'KLEIN': 0,
    'KLEINBACH': 0,
    'KLEINBAUM': 0,
    'KLEINBECK': 0,
    'KLEINBERG': 0,
    'KLEINBERGER': 0,
    'KLEINDIENST': 0,
    'KLEINDL': 0,
    'KLEINE': 0,
    'KLEINER': 0,
    'KLEINERMAN': 0,
    'KLEINERT': 0,
    'KLEINFELD': 0,
    'KLEINFELDER': 0,
    'KLEINFELDT': 0,
    'KLEINFELTER': 0,
    'KLEINGARTNER': 0,
    'KLEINHANS': 0,
    'KLEINHARDT': 0,
    'KLEINHAUS': 0,
    'KLEINHEIDER': 0,
    'KLEINHEINZ': 0,
    'KLEINHEKSEL': 0,
    'KLEINHENZ': 0,
    'KLEINHESSELINK': 0,
    'KLEINHOLZ': 0,
    'KLEINJAN': 0,
    'KLEINKAUF': 0,
    'KLEINKE': 0,
    'KLEINKNECHT': 0,
    'KLEINKOPF': 0,
    'KLEINLEIN': 0,
    'KLEINMAN': 0,
    'KLEINMANN': 0,
    'KLEINMEYER': 0,
    'KLEINOW': 0,
    'KLEINPETER': 0,
    'KLEINSASSER': 0,
    'KLEINSCHMIDT': 0,
    'KLEINSCHMIT': 0,
    'KLEINSCHRODT': 0,
    'KLEINSMITH': 0,
    'KLEINSORGE': 0,
    'KLEINTOP': 0,
    'KLEINWACHTER': 0,
    'KLEINWOLTERINK': 0,
    'KLEINZ': 0,
    'KLEIS': 0,
    'KLEISER': 0,
    'KLEISS': 0,
    'KLEIST': 0,
    'KLEITSCH': 0,
    'KLEITZ': 0,
    'KLEKAMP': 0,
    'KLEKAR': 0,
    'KLEKOTKA': 0,
    'KLEM': 0,
    'KLEMA': 0,
    'KLEMAN': 0,
    'KLEMANN': 0,
    'KLEMAS': 0,
    'KLEMCZAK': 0,
    'KLEMENCIC': 0,
    'KLEMENS': 0,
    'KLEMENT': 0,
    'KLEMENTOWSKI': 0,
    'KLEMENTS': 0,
    'KLEMENZ': 0,
    'KLEMER': 0,
    'KLEMETSON': 0,
    'KLEMICK': 0,
    'KLEMIN': 0,
    'KLEMISH': 0,
    'KLEMKE': 0,
    'KLEMM': 0,
    'KLEMME': 0,
    'KLEMMENSEN': 0,
    'KLEMMER': 0,
    'KLEMP': 0,
    'KLEMPA': 0,
    'KLEMPAY': 0,
    'KLEMPEL': 0,
    'KLEMPKE': 0,
    'KLEMPNER': 0,
    'KLEMS': 0,
    'KLEMZ': 0,
    'KLEN': 0,
    'KLENA': 0,
    'KLENCK': 0,
    'KLENDA': 0,
    'KLENDER': 0,
    'KLENE': 0,
    'KLENK': 0,
    'KLENKE': 0,
    'KLENNER': 0,
    'KLENNERT': 0,
    'KLENSKE': 0,
    'KLENTZ': 0,
    'KLENZ': 0,
    'KLEOPFER': 0,
    'KLEOPPEL': 0,
    'KLEPAC': 0,
    'KLEPACH': 0,
    'KLEPACKI': 0,
    'KLEPACZ': 0,
    'KLEPADLO': 0,
    'KLEPFER': 0,
    'KLEPINGER': 0,
    'KLEPP': 0,
    'KLEPPE': 0,
    'KLEPPER': 0,
    'KLEPPIN': 0,
    'KLEPPINGER': 0,
    'KLEPS': 0,
    'KLEPSER': 0,
    'KLEPZIG': 0,
    'KLER': 0,
    'KLESEL': 0,
    'KLESH': 0,
    'KLESS': 0,
    'KLESSIG': 0,
    'KLETKE': 0,
    'KLETT': 0,
    'KLETTE': 0,
    'KLETTER': 0,
    'KLETTKE': 0,
    'KLETZ': 0,
    'KLETZIEN': 0,
    'KLEVA': 0,
    'KLEVAN': 0,
    'KLEVE': 0,
    'KLEVEN': 0,
    'KLEVER': 0,
    'KLEWENO': 0,
    'KLEWER': 0,
    'KLEWICKI': 0,
    'KLEWIN': 0,
    'KLEY': 0,
    'KLEYLA': 0,
    'KLEYMAN': 0,
    'KLEYN': 0,
    'KLEYNER': 0,
    'KLEYPAS': 0,
    'KLIBER': 0,
    'KLIBERT': 0,
    'KLICH': 0,
    'KLICK': 0,
    'KLICKA': 0,
    'KLICKER': 0,
    'KLIE': 0,
    'KLIEBERT': 0,
    'KLIEFOTH': 0,
    'KLIEGL': 0,
    'KLIEM': 0,
    'KLIEMAN': 0,
    'KLIEMANN': 0,
    'KLIEN': 0,
    'KLIER': 0,
    'KLIES': 0,
    'KLIESCH': 0,
    'KLIETHERMES': 0,
    'KLIEVER': 0,
    'KLIEWER': 0,
    'KLIGER': 0,
    'KLIGERMAN': 0,
    'KLIGMAN': 0,
    'KLIKA': 0,
    'KLIM': 0,
    'KLIMA': 0,
    'KLIMAN': 0,
    'KLIMAS': 0,
    'KLIMASZEWSKI': 0,
    'KLIMCHAK': 0,
    'KLIMCZAK': 0,
    'KLIMCZYK': 0,
    'KLIMECK': 0,
    'KLIMEK': 0,
    'KLIMENKO': 0,
    'KLIMENT': 0,
    'KLIMES': 0,
    'KLIMESH': 0,
    'KLIMKE': 0,
    'KLIMKIEWICZ': 0,
    'KLIMKO': 0,
    'KLIMKOWSKI': 0,
    'KLIMM': 0,
    'KLIMMEK': 0,
    'KLIMO': 0,
    'KLIMOV': 0,
    'KLIMOVICH': 0,
    'KLIMOWICZ': 0,
    'KLIMOWSKI': 0,
    'KLIMP': 0,
    'KLIMPEL': 0,
    'KLIN': 0,
    'KLINCK': 0,
    'KLINDT': 0,
    'KLINDWORTH': 0,
    'KLINE': 0,
    'KLINECT': 0,
    'KLINEDINST': 0,
    'KLINEFELTER': 0,
    'KLINEPETER': 0,
    'KLINER': 0,
    'KLINESMITH': 0,
    'KLINETOBE': 0,
    'KLING': 0,
    'KLINGAMAN': 0,
    'KLINGBEIL': 0,
    'KLINGBERG': 0,
    'KLINGBIEL': 0,
    'KLINGE': 0,
    'KLINGEBIEL': 0,
    'KLINGEL': 0,
    'KLINGELE': 0,
    'KLINGELHOEFER': 0,
    'KLINGELHOETS': 0,
    'KLINGELHOFER': 0,
    'KLINGELSMITH': 0,
    'KLINGEMAN': 0,
    'KLINGEMANN': 0,
    'KLINGENBERG': 0,
    'KLINGENBERGER': 0,
    'KLINGENSMITH': 0,
    'KLINGENSTEIN': 0,
    'KLINGER': 0,
    'KLINGERMAN': 0,
    'KLINGES': 0,
    'KLINGHAGEN': 0,
    'KLINGHOFFER': 0,
    'KLINGINSMITH': 0,
    'KLINGLE': 0,
    'KLINGLER': 0,
    'KLINGLESMITH': 0,
    'KLINGMAN': 0,
    'KLINGNER': 0,
    'KLINGSHIRN': 0,
    'KLINGSMITH': 0,
    'KLINGSPORN': 0,
    'KLINK': 0,
    'KLINKE': 0,
    'KLINKEL': 0,
    'KLINKENBERG': 0,
    'KLINKENBORG': 0,
    'KLINKER': 0,
    'KLINKERMAN': 0,
    'KLINKERT': 0,
    'KLINKHAMER': 0,
    'KLINKHAMMER': 0,
    'KLINKMAN': 0,
    'KLINKNER': 0,
    'KLINKO': 0,
    'KLINNER': 0,
    'KLINNERT': 0,
    'KLINSKI': 0,
    'KLINSKY': 0,
    'KLINT': 0,
    'KLINTWORTH': 0,
    'KLINZING': 0,
    'KLIPA': 0,
    'KLIPFEL': 0,
    'KLIPP': 0,
    'KLIPPEL': 0,
    'KLIPPENSTEIN': 0,
    'KLIPPER': 0,
    'KLIPPERT': 0,
    'KLIPPLE': 0,
    'KLIPSCH': 0,
    'KLIPSTEIN': 0,
    'KLIPSTINE': 0,
    'KLIS': 0,
    'KLISCH': 0,
    'KLISE': 0,
    'KLISH': 0,
    'KLISIEWICZ': 0,
    'KLISS': 0,
    'KLISTER': 0,
    'KLISZ': 0,
    'KLITSCH': 0,
    'KLITZ': 0,
    'KLITZING': 0,
    'KLITZKA': 0,
    'KLITZKE': 0,
    'KLITZMAN': 0,
    'KLITZNER': 0,
    'KLIX': 0,
    'KLJAJIC': 0,
    'KLOB': 0,
    'KLOBAS': 0,
    'KLOBE': 0,
    'KLOBERDANZ': 0,
    'KLOBNAK': 0,
    'KLOBUCAR': 0,
    'KLOBUCHAR': 0,
    'KLOBUCHER': 0,
    'KLOC': 0,
    'KLOCEK': 0,
    'KLOCH': 0,
    'KLOCK': 0,
    'KLOCKE': 0,
    'KLOCKENGA': 0,
    'KLOCKER': 0,
    'KLOCKNER': 0,
    'KLOCKO': 0,
    'KLOCKOW': 0,
    'KLOCKOWSKI': 0,
    'KLODA': 0,
    'KLODT': 0,
    'KLODZINSKI': 0,
    'KLOECKER': 0,
    'KLOECKNER': 0,
    'KLOEHN': 0,
    'KLOEKER': 0,
    'KLOEMPKEN': 0,
    'KLOEPFER': 0,
    'KLOEPPEL': 0,
    'KLOEPPER': 0,
    'KLOEPPING': 0,
    'KLOER': 0,
    'KLOES': 0,
    'KLOESEL': 0,
    'KLOESS': 0,
    'KLOET': 0,
    'KLOEWER': 0,
    'KLOFT': 0,
    'KLOHA': 0,
    'KLOHN': 0,
    'KLOHR': 0,
    'KLOIBER': 0,
    'KLOK': 0,
    'KLOKE': 0,
    'KLOKOW': 0,
    'KLOMAN': 0,
    'KLOMP': 0,
    'KLOMPARENS': 0,
    'KLONOSKI': 0,
    'KLONOWSKI': 0,
    'KLONTZ': 0,
    'KLOOCK': 0,
    'KLOOR': 0,
    'KLOOS': 0,
    'KLOOSTER': 0,
    'KLOOSTERMAN': 0,
    'KLOOSTRA': 0,
    'KLOOTWYK': 0,
    'KLOOZ': 0,
    'KLOP': 0,
    'KLOPE': 0,
    'KLOPF': 0,
    'KLOPFENSTEIN': 0,
    'KLOPFER': 0,
    'KLOPMAN': 0,
    'KLOPOTEK': 0,
    'KLOPP': 0,
    'KLOPPE': 0,
    'KLOPPENBORG': 0,
    'KLOPPENBURG': 0,
    'KLOPPER': 0,
    'KLOPPING': 0,
    'KLOPSTEIN': 0,
    'KLOS': 0,
    'KLOSE': 0,
    'KLOSEK': 0,
    'KLOSER': 0,
    'KLOSINSKI': 0,
    'KLOSKA': 0,
    'KLOSKOWSKI': 0,
    'KLOSKY': 0,
    'KLOSNER': 0,
    'KLOSOWSKI': 0,
    'KLOSS': 0,
    'KLOSSNER': 0,
    'KLOSTER': 0,
    'KLOSTERMAN': 0,
    'KLOSTERMANN': 0,
    'KLOTER': 0,
    'KLOTH': 0,
    'KLOTT': 0,
    'KLOTTER': 0,
    'KLOTZ': 0,
    'KLOTZBACH': 0,
    'KLOTZER': 0,
    'KLOUDA': 0,
    'KLOUS': 0,
    'KLOUSE': 0,
    'KLOUSER': 0,
    'KLOVER': 0,
    'KLOVSTAD': 0,
    'KLUBA': 0,
    'KLUBEK': 0,
    'KLUBER': 0,
    'KLUBERTANZ': 0,
    'KLUCAS': 0,
    'KLUCK': 0,
    'KLUCKER': 0,
    'KLUCKMAN': 0,
    'KLUCZNIK': 0,
    'KLUCZYNSKI': 0,
    'KLUDING': 0,
    'KLUDT': 0,
    'KLUDY': 0,
    'KLUEBER': 0,
    'KLUEH': 0,
    'KLUEMPER': 0,
    'KLUENDER': 0,
    'KLUESENER': 0,
    'KLUESNER': 0,
    'KLUEVER': 0,
    'KLUG': 0,
    'KLUGA': 0,
    'KLUGE': 0,
    'KLUGER': 0,
    'KLUGH': 0,
    'KLUGMAN': 0,
    'KLUK': 0,
    'KLUKA': 0,
    'KLUKAS': 0,
    'KLUKOWSKI': 0,
    'KLUM': 0,
    'KLUMB': 0,
    'KLUMP': 0,
    'KLUMPE': 0,
    'KLUMPER': 0,
    'KLUMPH': 0,
    'KLUMPP': 0,
    'KLUN': 0,
    'KLUND': 0,
    'KLUNDER': 0,
    'KLUNDT': 0,
    'KLUNE': 0,
    'KLUNK': 0,
    'KLUPP': 0,
    'KLUS': 0,
    'KLUSEK': 0,
    'KLUSKA': 0,
    'KLUSMAN': 0,
    'KLUSMANN': 0,
    'KLUSMEIER': 0,
    'KLUSMEYER': 0,
    'KLUSS': 0,
    'KLUSSMANN': 0,
    'KLUSTY': 0,
    'KLUTE': 0,
    'KLUTH': 0,
    'KLUTHE': 0,
    'KLUTING': 0,
    'KLUTTS': 0,
    'KLUTTZ': 0,
    'KLUTZ': 0,
    'KLUVER': 0,
    'KLUZ': 0,
    'KLUZA': 0,
    'KLUZAK': 0,
    'KLYCE': 0,
    'KLYCZEK': 0,
    'KLYM': 0,
    'KLYN': 0,
    'KLYNSTRA': 0,
    'KMAK': 0,
    'KMAN': 0,
    'KMEC': 0,
    'KMENT': 0,
    'KMET': 0,
    'KMETT': 0,
    'KMETZ': 0,
    'KMIEC': 0,
    'KMIECIAK': 0,
    'KMIECIK': 0,
    'KMIOTEK': 0,
    'KMOCH': 0,
    'KNAACK': 0,
    'KNAAK': 0,
    'KNAB': 0,
    'KNABB': 0,
    'KNABE': 0,
    'KNABEL': 0,
    'KNABLE': 0,
    'KNACK': 0,
    'KNACKSTEDT': 0,
    'KNADLE': 0,
    'KNADLER': 0,
    'KNAEBEL': 0,
    'KNAEBLE': 0,
    'KNAFEL': 0,
    'KNAFF': 0,
    'KNAFLA': 0,
    'KNAGGS': 0,
    'KNAKAL': 0,
    'KNAKE': 0,
    'KNALL': 0,
    'KNAP': 0,
    'KNAPCZYK': 0,
    'KNAPE': 0,
    'KNAPEK': 0,
    'KNAPHUS': 0,
    'KNAPIC': 0,
    'KNAPICK': 0,
    'KNAPIK': 0,
    'KNAPKE': 0,
    'KNAPP': 0,
    'KNAPPE': 0,
    'KNAPPEN': 0,
    'KNAPPENBERGER': 0,
    'KNAPPER': 0,
    'KNAPPS': 0,
    'KNAPSTEIN': 0,
    'KNAPTON': 0,
    'KNARR': 0,
    'KNASEL': 0,
    'KNASIAK': 0,
    'KNASTER': 0,
    'KNATT': 0,
    'KNATZ': 0,
    'KNAUB': 0,
    'KNAUBER': 0,
    'KNAUER': 0,
    'KNAUF': 0,
    'KNAUFF': 0,
    'KNAUL': 0,
    'KNAUP': 0,
    'KNAUS': 0,
    'KNAUSE': 0,
    'KNAUSS': 0,
    'KNAUST': 0,
    'KNAUTH': 0,
    'KNAUTZ': 0,
    'KNAVEL': 0,
    'KNEAFSEY': 0,
    'KNEALE': 0,
    'KNEBEL': 0,
    'KNEBL': 0,
    'KNECHEL': 0,
    'KNECHT': 0,
    'KNECHTEL': 0,
    'KNECHTGES': 0,
    'KNEDLER': 0,
    'KNEE': 0,
    'KNEEBONE': 0,
    'KNEECE': 0,
    'KNEEDLER': 0,
    'KNEELAND': 0,
    'KNEEN': 0,
    'KNEER': 0,
    'KNEESE': 0,
    'KNEESHAW': 0,
    'KNEESKERN': 0,
    'KNEFEL': 0,
    'KNEFELKAMP': 0,
    'KNEFF': 0,
    'KNEHANS': 0,
    'KNEHR': 0,
    'KNEIB': 0,
    'KNEIFEL': 0,
    'KNEIFL': 0,
    'KNEIP': 0,
    'KNEIPP': 0,
    'KNEISEL': 0,
    'KNEISLER': 0,
    'KNEISLEY': 0,
    'KNEISLY': 0,
    'KNEISS': 0,
    'KNELL': 0,
    'KNELLER': 0,
    'KNELLINGER': 0,
    'KNELSEN': 0,
    'KNEPLER': 0,
    'KNEPLEY': 0,
    'KNEPP': 0,
    'KNEPPER': 0,
    'KNEPPLE': 0,
    'KNEPSHIELD': 0,
    'KNERR': 0,
    'KNESE': 0,
    'KNESEK': 0,
    'KNESEL': 0,
    'KNESS': 0,
    'KNESTRICK': 0,
    'KNETSCH': 0,
    'KNETTEL': 0,
    'KNETTER': 0,
    'KNETZER': 0,
    'KNEUER': 0,
    'KNEUPPER': 0,
    'KNEZ': 0,
    'KNEZEK': 0,
    'KNEZEVIC': 0,
    'KNEZEVICH': 0,
    'KNEZOVICH': 0,
    'KNIAZ': 0,
    'KNIBB': 0,
    'KNIBBE': 0,
    'KNIBBS': 0,
    'KNICELEY': 0,
    'KNICELY': 0,
    'KNICHEL': 0,
    'KNICK': 0,
    'KNICKELBEIN': 0,
    'KNICKER': 0,
    'KNICKERBOCKER': 0,
    'KNICKMAN': 0,
    'KNICKMEYER': 0,
    'KNICKREHM': 0,
    'KNICLEY': 0,
    'KNIE': 0,
    'KNIEF': 0,
    'KNIEFEL': 0,
    'KNIELING': 0,
    'KNIEP': 0,
    'KNIEPER': 0,
    'KNIER': 0,
    'KNIERIEM': 0,
    'KNIERIEMEN': 0,
    'KNIERIM': 0,
    'KNIES': 0,
    'KNIESS': 0,
    'KNIEVEL': 0,
    'KNIFE': 0,
    'KNIFFEN': 0,
    'KNIFFIN': 0,
    'KNIFLEY': 0,
    'KNIFONG': 0,
    'KNIGGE': 0,
    'KNIGHT': 0,
    'KNIGHTEN': 0,
    'KNIGHTING': 0,
    'KNIGHTLY': 0,
    'KNIGHTNER': 0,
    'KNIGHTON': 0,
    'KNIGHTS': 0,
    'KNILL': 0,
    'KNIOLA': 0,
    'KNIPE': 0,
    'KNIPFEL': 0,
    'KNIPFER': 0,
    'KNIPMEYER': 0,
    'KNIPP': 0,
    'KNIPPA': 0,
    'KNIPPEL': 0,
    'KNIPPEN': 0,
    'KNIPPENBERG': 0,
    'KNIPPER': 0,
    'KNIPPERS': 0,
    'KNIPPING': 0,
    'KNIPPLE': 0,
    'KNIPPLING': 0,
    'KNIPS': 0,
    'KNIPSTEIN': 0,
    'KNISEL': 0,
    'KNISELEY': 0,
    'KNISELY': 0,
    'KNISH': 0,
    'KNISKERN': 0,
    'KNISLEY': 0,
    'KNISPEL': 0,
    'KNISS': 0,
    'KNITT': 0,
    'KNITTEL': 0,
    'KNITTER': 0,
    'KNITTLE': 0,
    'KNIZE': 0,
    'KNIZEK': 0,
    'KNIZNER': 0,
    'KNOB': 0,
    'KNOBBE': 0,
    'KNOBEL': 0,
    'KNOBELOCH': 0,
    'KNOBLACH': 0,
    'KNOBLAUCH': 0,
    'KNOBLE': 0,
    'KNOBLER': 0,
    'KNOBLETT': 0,
    'KNOBLICH': 0,
    'KNOBLOCH': 0,
    'KNOBLOCK': 0,
    'KNOCH': 0,
    'KNOCHE': 0,
    'KNOCHEL': 0,
    'KNOCHENMUS': 0,
    'KNOCK': 0,
    'KNOCKE': 0,
    'KNOCKEL': 0,
    'KNOCKUM': 0,
    'KNODE': 0,
    'KNODEL': 0,
    'KNODELL': 0,
    'KNODERER': 0,
    'KNODLE': 0,
    'KNODT': 0,
    'KNOEBEL': 0,
    'KNOECK': 0,
    'KNOEDLER': 0,
    'KNOEFLER': 0,
    'KNOELL': 0,
    'KNOELLER': 0,
    'KNOEPFEL': 0,
    'KNOEPFLE': 0,
    'KNOEPFLER': 0,
    'KNOEPKE': 0,
    'KNOEPPEL': 0,
    'KNOER': 0,
    'KNOERNSCHILD': 0,
    'KNOERR': 0,
    'KNOERZER': 0,
    'KNOFF': 0,
    'KNOKE': 0,
    'KNOL': 0,
    'KNOLES': 0,
    'KNOLHOFF': 0,
    'KNOLL': 0,
    'KNOLLE': 0,
    'KNOLLENBERG': 0,
    'KNOLLMAN': 0,
    'KNOLLS': 0,
    'KNOLTON': 0,
    'KNOOP': 0,
    'KNOP': 0,
    'KNOPE': 0,
    'KNOPER': 0,
    'KNOPES': 0,
    'KNOPF': 0,
    'KNOPFLER': 0,
    'KNOPH': 0,
    'KNOPICK': 0,
    'KNOPIK': 0,
    'KNOPKE': 0,
    'KNOPP': 0,
    'KNOPPEL': 0,
    'KNOPPS': 0,
    'KNOPS': 0,
    'KNOPSNIDER': 0,
    'KNOPSNYDER': 0,
    'KNOR': 0,
    'KNOROWSKI': 0,
    'KNORPP': 0,
    'KNORR': 0,
    'KNOSE': 0,
    'KNOSP': 0,
    'KNOSPE': 0,
    'KNOST': 0,
    'KNOSTMAN': 0,
    'KNOT': 0,
    'KNOTE': 0,
    'KNOTEK': 0,
    'KNOTEN': 0,
    'KNOTH': 0,
    'KNOTHE': 0,
    'KNOTT': 0,
    'KNOTTS': 0,
    'KNOUF': 0,
    'KNOUFF': 0,
    'KNOUS': 0,
    'KNOUSE': 0,
    'KNOW': 0,
    'KNOWER': 0,
    'KNOWLAN': 0,
    'KNOWLAND': 0,
    'KNOWLDEN': 0,
    'KNOWLEN': 0,
    'KNOWLER': 0,
    'KNOWLES': 0,
    'KNOWLIN': 0,
    'KNOWLING': 0,
    'KNOWLTON': 0,
    'KNOWSKI': 0,
    'KNOX': 0,
    'KNOY': 0,
    'KNUCKEY': 0,
    'KNUCKLES': 0,
    'KNUDSEN': 0,
    'KNUDSON': 0,
    'KNUDSVIG': 0,
    'KNUDTSON': 0,
    'KNUE': 0,
    'KNUEPPEL': 0,
    'KNUEVEN': 0,
    'KNULL': 0,
    'KNUPP': 0,
    'KNUPPEL': 0,
    'KNUREK': 0,
    'KNUST': 0,
    'KNUTESON': 0,
    'KNUTH': 0,
    'KNUTSEN': 0,
    'KNUTSON': 0,
    'KNUTT': 0,
    'KNUTTER': 0,
    'KNUTTI': 0,
    'KNUTZ': 0,
    'KNUTZEN': 0,
    'KNYCH': 0,
    'KO': 0,
    'KOA': 0,
    'KOACH': 0,
    'KOAN': 0,
    'KOAY': 0,
    'KOB': 0,
    'KOBA': 0,
    'KOBACK': 0,
    'KOBAK': 0,
    'KOBAL': 0,
    'KOBAN': 0,
    'KOBASA': 0,
    'KOBASHI': 0,
    'KOBASHIGAWA': 0,
    'KOBASIC': 0,
    'KOBATA': 0,
    'KOBAYASHI': 0,
    'KOBB': 0,
    'KOBBE': 0,
    'KOBE': 0,
    'KOBECK': 0,
    'KOBEISSI': 0,
    'KOBEL': 0,
    'KOBELSKI': 0,
    'KOBELT': 0,
    'KOBER': 0,
    'KOBERG': 0,
    'KOBERLEIN': 0,
    'KOBERNA': 0,
    'KOBERNICK': 0,
    'KOBERNIK': 0,
    'KOBERSTEIN': 0,
    'KOBERT': 0,
    'KOBES': 0,
    'KOBESKI': 0,
    'KOBETITSCH': 0,
    'KOBI': 0,
    'KOBIALKA': 0,
    'KOBIE': 0,
    'KOBIELA': 0,
    'KOBILKA': 0,
    'KOBIN': 0,
    'KOBLE': 0,
    'KOBLENTZ': 0,
    'KOBLER': 0,
    'KOBLICK': 0,
    'KOBLINSKI': 0,
    'KOBLISKA': 0,
    'KOBLITZ': 0,
    'KOBOLD': 0,
    'KOBOS': 0,
    'KOBREN': 0,
    'KOBRICK': 0,
    'KOBRIGER': 0,
    'KOBRIN': 0,
    'KOBRYN': 0,
    'KOBS': 0,
    'KOBUS': 0,
    'KOBUSSEN': 0,
    'KOBY': 0,
    'KOBYLANSKI': 0,
    'KOBYLARCZYK': 0,
    'KOBYLARZ': 0,
    'KOBYLINSKI': 0,
    'KOBYLSKI': 0,
    'KOBZA': 0,
    'KOBZEFF': 0,
    'KOC': 0,
    'KOCA': 0,
    'KOCAB': 0,
    'KOCAJ': 0,
    'KOCAK': 0,
    'KOCAN': 0,
    'KOCANDA': 0,
    'KOCAR': 0,
    'KOCEJA': 0,
    'KOCEN': 0,
    'KOCER': 0,
    'KOCEVAR': 0,
    'KOCH': 0,
    'KOCHA': 0,
    'KOCHAN': 0,
    'KOCHANEK': 0,
    'KOCHANOWICZ': 0,
    'KOCHANOWSKI': 0,
    'KOCHANSKI': 0,
    'KOCHAR': 0,
    'KOCHARYAN': 0,
    'KOCHE': 0,
    'KOCHEL': 0,
    'KOCHELL': 0,
    'KOCHEN': 0,
    'KOCHENASH': 0,
    'KOCHENDERFER': 0,
    'KOCHENDORFER': 0,
    'KOCHENOUR': 0,
    'KOCHENSPARGER': 0,
    'KOCHER': 0,
    'KOCHERA': 0,
    'KOCHERHANS': 0,
    'KOCHERSPERGER': 0,
    'KOCHERT': 0,
    'KOCHES': 0,
    'KOCHEVAR': 0,
    'KOCHHAR': 0,
    'KOCHHEISER': 0,
    'KOCHI': 0,
    'KOCHIE': 0,
    'KOCHIN': 0,
    'KOCHIS': 0,
    'KOCHISS': 0,
    'KOCHMAN': 0,
    'KOCHMANN': 0,
    'KOCI': 0,
    'KOCIAN': 0,
    'KOCIEMBA': 0,
    'KOCIENSKI': 0,
    'KOCIK': 0,
    'KOCINA': 0,
    'KOCINSKI': 0,
    'KOCIOLEK': 0,
    'KOCIS': 0,
    'KOCIUBA': 0,
    'KOCJAN': 0,
    'KOCK': 0,
    'KOCKA': 0,
    'KOCKEN': 0,
    'KOCKLER': 0,
    'KOCKS': 0,
    'KOCOL': 0,
    'KOCON': 0,
    'KOCOT': 0,
    'KOCOUR': 0,
    'KOCOUREK': 0,
    'KOCSIS': 0,
    'KOCUR': 0,
    'KOCUREK': 0,
    'KOCZAN': 0,
    'KOCZERA': 0,
    'KOCZUR': 0,
    'KOCZWARA': 0,
    'KODA': 0,
    'KODAK': 0,
    'KODALI': 0,
    'KODAMA': 0,
    'KODANI': 0,
    'KODER': 0,
    'KODESH': 0,
    'KODET': 0,
    'KODIS': 0,
    'KODISH': 0,
    'KODL': 0,
    'KODNER': 0,
    'KODRA': 0,
    'KODRICH': 0,
    'KODURI': 0,
    'KODY': 0,
    'KOE': 0,
    'KOEBBE': 0,
    'KOEBEL': 0,
    'KOEBELE': 0,
    'KOEBER': 0,
    'KOEBERL': 0,
    'KOEBERLE': 0,
    'KOEBERLEIN': 0,
    'KOEBERNICK': 0,
    'KOEBKE': 0,
    'KOEBLER': 0,
    'KOECHEL': 0,
    'KOECHER': 0,
    'KOECHNER': 0,
    'KOECK': 0,
    'KOEDAM': 0,
    'KOEDEL': 0,
    'KOEDYKER': 0,
    'KOEGEL': 0,
    'KOEGLER': 0,
    'KOEHL': 0,
    'KOEHLE': 0,
    'KOEHLER': 0,
    'KOEHLING': 0,
    'KOEHLINGER': 0,
    'KOEHLMOOS': 0,
    'KOEHLY': 0,
    'KOEHMSTEDT': 0,
    'KOEHN': 0,
    'KOEHNE': 0,
    'KOEHNEN': 0,
    'KOEHNKE': 0,
    'KOEHNLEIN': 0,
    'KOEL': 0,
    'KOELBEL': 0,
    'KOELBL': 0,
    'KOELE': 0,
    'KOELEWYN': 0,
    'KOELKER': 0,
    'KOELLE': 0,
    'KOELLER': 0,
    'KOELLIKER': 0,
    'KOELLING': 0,
    'KOELLN': 0,
    'KOELLNER': 0,
    'KOELMEL': 0,
    'KOELSCH': 0,
    'KOELZER': 0,
    'KOEMAN': 0,
    'KOEMPEL': 0,
    'KOEN': 0,
    'KOENCK': 0,
    'KOENECKE': 0,
    'KOENEKE': 0,
    'KOENEMAN': 0,
    'KOENEMANN': 0,
    'KOENEN': 0,
    'KOENES': 0,
    'KOENIG': 0,
    'KOENIGER': 0,
    'KOENIGS': 0,
    'KOENIGSBERG': 0,
    'KOENIGSFELD': 0,
    'KOENIGSKNECHT': 0,
    'KOENING': 0,
    'KOENINGER': 0,
    'KOENINGS': 0,
    'KOENITZER': 0,
    'KOENKE': 0,
    'KOENNECKE': 0,
    'KOENNING': 0,
    'KOENS': 0,
    'KOEP': 0,
    'KOEPER': 0,
    'KOEPF': 0,
    'KOEPFER': 0,
    'KOEPKE': 0,
    'KOEPL': 0,
    'KOEPLIN': 0,
    'KOEPNICK': 0,
    'KOEPP': 0,
    'KOEPPE': 0,
    'KOEPPEL': 0,
    'KOEPPEN': 0,
    'KOEPPER': 0,
    'KOEPPL': 0,
    'KOEPPLIN': 0,
    'KOEPPLINGER': 0,
    'KOEPSEL': 0,
    'KOEPSELL': 0,
    'KOERBEL': 0,
    'KOERBER': 0,
    'KOERING': 0,
    'KOERKENMEIER': 0,
    'KOERNER': 0,
    'KOERPER': 0,
    'KOERPERICH': 0,
    'KOERS': 0,
    'KOERSELMAN': 0,
    'KOERT': 0,
    'KOERTGE': 0,
    'KOERTH': 0,
    'KOERWITZ': 0,
    'KOES': 0,
    'KOESEL': 0,
    'KOESER': 0,
    'KOESHALL': 0,
    'KOESLER': 0,
    'KOESSEL': 0,
    'KOESTEL': 0,
    'KOESTER': 0,
    'KOESTERER': 0,
    'KOESTERS': 0,
    'KOESTLER': 0,
    'KOESTNER': 0,
    'KOETH': 0,
    'KOETHE': 0,
    'KOETHER': 0,
    'KOETJE': 0,
    'KOETS': 0,
    'KOETSIER': 0,
    'KOETT': 0,
    'KOETTER': 0,
    'KOETTERS': 0,
    'KOETTING': 0,
    'KOETZ': 0,
    'KOETZLE': 0,
    'KOEWLER': 0,
    'KOFAHL': 0,
    'KOFF': 0,
    'KOFFARNUS': 0,
    'KOFFEL': 0,
    'KOFFER': 0,
    'KOFFI': 0,
    'KOFFLER': 0,
    'KOFFMAN': 0,
    'KOFFORD': 0,
    'KOFLER': 0,
    'KOFMAN': 0,
    'KOFMEHL': 0,
    'KOFOD': 0,
    'KOFOED': 0,
    'KOFOID': 0,
    'KOFORD': 0,
    'KOFRON': 0,
    'KOFROTH': 0,
    'KOFSKY': 0,
    'KOFSTAD': 0,
    'KOGA': 0,
    'KOGAN': 0,
    'KOGEL': 0,
    'KOGELMAN': 0,
    'KOGELSCHATZ': 0,
    'KOGEN': 0,
    'KOGER': 0,
    'KOGLER': 0,
    'KOGLIN': 0,
    'KOGOS': 0,
    'KOGUT': 0,
    'KOH': 0,
    'KOHAGEN': 0,
    'KOHAKE': 0,
    'KOHAN': 0,
    'KOHANEK': 0,
    'KOHANIM': 0,
    'KOHANSKI': 0,
    'KOHARA': 0,
    'KOHART': 0,
    'KOHATSU': 0,
    'KOHBERGER': 0,
    'KOHEL': 0,
    'KOHEN': 0,
    'KOHER': 0,
    'KOHL': 0,
    'KOHLBACHER': 0,
    'KOHLBECK': 0,
    'KOHLBERG': 0,
    'KOHLBRECHER': 0,
    'KOHLBRENNER': 0,
    'KOHLE': 0,
    'KOHLENBERG': 0,
    'KOHLENBERGER': 0,
    'KOHLER': 0,
    'KOHLES': 0,
    'KOHLEY': 0,
    'KOHLHAAS': 0,
    'KOHLHAGEN': 0,
    'KOHLHASE': 0,
    'KOHLHEPP': 0,
    'KOHLHOFF': 0,
    'KOHLHORST': 0,
    'KOHLI': 0,
    'KOHLMAN': 0,
    'KOHLMANN': 0,
    'KOHLMEIER': 0,
    'KOHLMEYER': 0,
    'KOHLOFF': 0,
    'KOHLS': 0,
    'KOHLSTEDT': 0,
    'KOHLWEY': 0,
    'KOHM': 0,
    'KOHMAN': 0,
    'KOHMETSCHER': 0,
    'KOHN': 0,
    'KOHNE': 0,
    'KOHNEN': 0,
    'KOHNER': 0,
    'KOHNERT': 0,
    'KOHNHORST': 0,
    'KOHNKE': 0,
    'KOHNLE': 0,
    'KOHNS': 0,
    'KOHORST': 0,
    'KOHOUT': 0,
    'KOHOUTEK': 0,
    'KOHR': 0,
    'KOHRING': 0,
    'KOHRMAN': 0,
    'KOHRMANN': 0,
    'KOHRS': 0,
    'KOHRT': 0,
    'KOHS': 0,
    'KOHTZ': 0,
    'KOHUT': 0,
    'KOHUTEK': 0,
    'KOHUTH': 0,
    'KOI': 0,
    'KOIDE': 0,
    'KOIKE': 0,
    'KOINER': 0,
    'KOINZAN': 0,
    'KOIS': 0,
    'KOISTINEN': 0,
    'KOIVISTO': 0,
    'KOIVU': 0,
    'KOIZUMI': 0,
    'KOJA': 0,
    'KOJETIN': 0,
    'KOJIMA': 0,
    'KOJIS': 0,
    'KOJO': 0,
    'KOK': 0,
    'KOKA': 0,
    'KOKAL': 0,
    'KOKAS': 0,
    'KOKE': 0,
    'KOKEL': 0,
    'KOKEN': 0,
    'KOKENGE': 0,
    'KOKER': 0,
    'KOKERNAK': 0,
    'KOKES': 0,
    'KOKESCH': 0,
    'KOKESH': 0,
    'KOKI': 0,
    'KOKINDA': 0,
    'KOKINOS': 0,
    'KOKKELER': 0,
    'KOKKINOS': 0,
    'KOKKO': 0,
    'KOKO': 0,
    'KOKOCINSKI': 0,
    'KOKOLIS': 0,
    'KOKORIS': 0,
    'KOKORUDA': 0,
    'KOKOS': 0,
    'KOKOSINSKI': 0,
    'KOKOSKA': 0,
    'KOKOSKI': 0,
    'KOKOSZKA': 0,
    'KOKOT': 0,
    'KOKOTOVICH': 0,
    'KOKOTT': 0,
    'KOKSAL': 0,
    'KOKUBUN': 0,
    'KOKX': 0,
    'KOL': 0,
    'KOLA': 0,
    'KOLACEK': 0,
    'KOLACKI': 0,
    'KOLACZ': 0,
    'KOLAFA': 0,
    'KOLAK': 0,
    'KOLAKOSKI': 0,
    'KOLAKOWSKI': 0,
    'KOLAN': 0,
    'KOLAND': 0,
    'KOLANDA': 0,
    'KOLANDER': 0,
    'KOLANKO': 0,
    'KOLANO': 0,
    'KOLANOWSKI': 0,
    'KOLAR': 0,
    'KOLARICH': 0,
    'KOLARIK': 0,
    'KOLAS': 0,
    'KOLASA': 0,
    'KOLASINSKI': 0,
    'KOLASKI': 0,
    'KOLASSA': 0,
    'KOLAT': 0,
    'KOLATA': 0,
    'KOLAWOLE': 0,
    'KOLB': 0,
    'KOLBA': 0,
    'KOLBE': 0,
    'KOLBECK': 0,
    'KOLBER': 0,
    'KOLBERG': 0,
    'KOLBERT': 0,
    'KOLBET': 0,
    'KOLBO': 0,
    'KOLBOW': 0,
    'KOLBUS': 0,
    'KOLBUSZ': 0,
    'KOLBY': 0,
    'KOLCUN': 0,
    'KOLCZ': 0,
    'KOLCZYNSKI': 0,
    'KOLDA': 0,
    'KOLDE': 0,
    'KOLDEN': 0,
    'KOLDER': 0,
    'KOLDYS': 0,
    'KOLE': 0,
    'KOLEAN': 0,
    'KOLECKI': 0,
    'KOLEDA': 0,
    'KOLEFF': 0,
    'KOLEGA': 0,
    'KOLEHMAINEN': 0,
    'KOLEK': 0,
    'KOLEN': 0,
    'KOLENC': 0,
    'KOLENDA': 0,
    'KOLENICH': 0,
    'KOLENKO': 0,
    'KOLENO': 0,
    'KOLENOVIC': 0,
    'KOLER': 0,
    'KOLES': 0,
    'KOLESA': 0,
    'KOLESAR': 0,
    'KOLESKE': 0,
    'KOLESKI': 0,
    'KOLESNIK': 0,
    'KOLESNIKOV': 0,
    'KOLESSAR': 0,
    'KOLESZAR': 0,
    'KOLEV': 0,
    'KOLEY': 0,
    'KOLF': 0,
    'KOLHOFF': 0,
    'KOLI': 0,
    'KOLIAS': 0,
    'KOLIBA': 0,
    'KOLIBAS': 0,
    'KOLIC': 0,
    'KOLICH': 0,
    'KOLIN': 0,
    'KOLINEK': 0,
    'KOLINS': 0,
    'KOLINSKI': 0,
    'KOLINSKY': 0,
    'KOLIOPOULOS': 0,
    'KOLIS': 0,
    'KOLISH': 0,
    'KOLK': 0,
    'KOLKA': 0,
    'KOLKE': 0,
    'KOLKER': 0,
    'KOLKHORST': 0,
    'KOLKMAN': 0,
    'KOLKMEIER': 0,
    'KOLKMEYER': 0,
    'KOLKO': 0,
    'KOLL': 0,
    'KOLLA': 0,
    'KOLLAR': 0,
    'KOLLARS': 0,
    'KOLLASCH': 0,
    'KOLLATH': 0,
    'KOLLBAUM': 0,
    'KOLLE': 0,
    'KOLLEN': 0,
    'KOLLER': 0,
    'KOLLES': 0,
    'KOLLEY': 0,
    'KOLLHOFF': 0,
    'KOLLI': 0,
    'KOLLIAS': 0,
    'KOLLIE': 0,
    'KOLLIN': 0,
    'KOLLING': 0,
    'KOLLINGER': 0,
    'KOLLINS': 0,
    'KOLLMAN': 0,
    'KOLLMANN': 0,
    'KOLLMANSBERGER': 0,
    'KOLLMAR': 0,
    'KOLLMER': 0,
    'KOLLMEYER': 0,
    'KOLLMORGEN': 0,
    'KOLLN': 0,
    'KOLLOCK': 0,
    'KOLLROSS': 0,
    'KOLLS': 0,
    'KOLLURI': 0,
    'KOLM': 0,
    'KOLMAN': 0,
    'KOLMER': 0,
    'KOLMETZ': 0,
    'KOLNIK': 0,
    'KOLO': 0,
    'KOLODGE': 0,
    'KOLODNY': 0,
    'KOLODY': 0,
    'KOLODZIEJ': 0,
    'KOLODZIEJCZAK': 0,
    'KOLODZIEJCZYK': 0,
    'KOLODZIEJSKI': 0,
    'KOLODZIK': 0,
    'KOLODZINSKI': 0,
    'KOLOGY': 0,
    'KOLOS': 0,
    'KOLOSKI': 0,
    'KOLOSKY': 0,
    'KOLOSOV': 0,
    'KOLOSSO': 0,
    'KOLOVICH': 0,
    'KOLOVOS': 0,
    'KOLOWSKI': 0,
    'KOLP': 0,
    'KOLPACK': 0,
    'KOLPAK': 0,
    'KOLPIEN': 0,
    'KOLPIN': 0,
    'KOLSKI': 0,
    'KOLSKY': 0,
    'KOLSON': 0,
    'KOLSRUD': 0,
    'KOLSTAD': 0,
    'KOLSTER': 0,
    'KOLT': 0,
    'KOLTER': 0,
    'KOLTERMAN': 0,
    'KOLTERMANN': 0,
    'KOLTES': 0,
    'KOLTHOFF': 0,
    'KOLTISKA': 0,
    'KOLTON': 0,
    'KOLTS': 0,
    'KOLTUN': 0,
    'KOLTZ': 0,
    'KOLUCH': 0,
    'KOLVA': 0,
    'KOLVE': 0,
    'KOLVEK': 0,
    'KOLWICZ': 0,
    'KOLWYCK': 0,
    'KOLZ': 0,
    'KOLZE': 0,
    'KOLZOW': 0,
    'KOM': 0,
    'KOMA': 0,
    'KOMADA': 0,
    'KOMADINA': 0,
    'KOMAN': 0,
    'KOMAR': 0,
    'KOMARA': 0,
    'KOMAREK': 0,
    'KOMARNICKI': 0,
    'KOMAROMI': 0,
    'KOMAROV': 0,
    'KOMAS': 0,
    'KOMATSU': 0,
    'KOMATZ': 0,
    'KOMEN': 0,
    'KOMENDA': 0,
    'KOMER': 0,
    'KOMES': 0,
    'KOMINEK': 0,
    'KOMINOS': 0,
    'KOMINSKI': 0,
    'KOMINSKY': 0,
    'KOMIS': 0,
    'KOMISAR': 0,
    'KOMISAREK': 0,
    'KOMIVES': 0,
    'KOMIYAMA': 0,
    'KOMLOS': 0,
    'KOMM': 0,
    'KOMMA': 0,
    'KOMMER': 0,
    'KOMMES': 0,
    'KOMNICK': 0,
    'KOMO': 0,
    'KOMODA': 0,
    'KOMOR': 0,
    'KOMORA': 0,
    'KOMOREK': 0,
    'KOMORI': 0,
    'KOMORNIK': 0,
    'KOMOROSKI': 0,
    'KOMOROWSKI': 0,
    'KOMOSA': 0,
    'KOMOSINSKI': 0,
    'KOMOTO': 0,
    'KOMP': 0,
    'KOMPARE': 0,
    'KOMPELIEN': 0,
    'KOMPERDA': 0,
    'KOMRO': 0,
    'KOMSA': 0,
    'KOMULA': 0,
    'KON': 0,
    'KONA': 0,
    'KONADU': 0,
    'KONAN': 0,
    'KONAR': 0,
    'KONARIK': 0,
    'KONARSKI': 0,
    'KONARZEWSKI': 0,
    'KONAS': 0,
    'KONATE': 0,
    'KONCABA': 0,
    'KONCAR': 0,
    'KONCELIK': 0,
    'KONCHAN': 0,
    'KONCHAR': 0,
    'KONCSOL': 0,
    'KONCZ': 0,
    'KONCZAK': 0,
    'KONCZAL': 0,
    'KONCZYK': 0,
    'KONDA': 0,
    'KONDAS': 0,
    'KONDASH': 0,
    'KONDEK': 0,
    'KONDEL': 0,
    'KONDIK': 0,
    'KONDO': 0,
    'KONDOR': 0,
    'KONDOS': 0,
    'KONDRACKI': 0,
    'KONDRAT': 0,
    'KONDRATH': 0,
    'KONDRATOWICZ': 0,
    'KONDRATYUK': 0,
    'KONDZIELA': 0,
    'KONE': 0,
    'KONECHNE': 0,
    'KONECKI': 0,
    'KONECKY': 0,
    'KONECNY': 0,
    'KONECZNY': 0,
    'KONEFAL': 0,
    'KONEK': 0,
    'KONEMANN': 0,
    'KONEN': 0,
    'KONERT': 0,
    'KONERU': 0,
    'KONESKI': 0,
    'KONESKY': 0,
    'KONET': 0,
    'KONETSKI': 0,
    'KONEVAL': 0,
    'KONEY': 0,
    'KONFRST': 0,
    'KONG': 0,
    'KONIAK': 0,
    'KONICEK': 0,
    'KONICHEK': 0,
    'KONICK': 0,
    'KONICKE': 0,
    'KONICKI': 0,
    'KONIECKI': 0,
    'KONIECZKA': 0,
    'KONIECZKI': 0,
    'KONIECZKO': 0,
    'KONIECZNY': 0,
    'KONIG': 0,
    'KONIGSBERG': 0,
    'KONIK': 0,
    'KONIKOWSKI': 0,
    'KONING': 0,
    'KONIOR': 0,
    'KONISHI': 0,
    'KONITZER': 0,
    'KONJA': 0,
    'KONKE': 0,
    'KONKEL': 0,
    'KONKEN': 0,
    'KONKLE': 0,
    'KONKLER': 0,
    'KONKOL': 0,
    'KONKOWSKI': 0,
    'KONKUS': 0,
    'KONN': 0,
    'KONNER': 0,
    'KONNERTH': 0,
    'KONNICK': 0,
    'KONNO': 0,
    'KONO': 0,
    'KONOLD': 0,
    'KONON': 0,
    'KONONENKO': 0,
    'KONOP': 0,
    'KONOPA': 0,
    'KONOPACKI': 0,
    'KONOPASEK': 0,
    'KONOPINSKI': 0,
    'KONOPKA': 0,
    'KONOPKO': 0,
    'KONOPSKI': 0,
    'KONOSKE': 0,
    'KONOVALOV': 0,
    'KONOW': 0,
    'KONOWAL': 0,
    'KONOWITZ': 0,
    'KONRAD': 0,
    'KONRADE': 0,
    'KONRADI': 0,
    'KONRADY': 0,
    'KONRARDY': 0,
    'KONRATH': 0,
    'KONS': 0,
    'KONSCHAK': 0,
    'KONSHAK': 0,
    'KONST': 0,
    'KONSTANT': 0,
    'KONSTANTIN': 0,
    'KONSTANTINIDIS': 0,
    'KONSTANTINOV': 0,
    'KONSTANTOPOULOS': 0,
    'KONSTANTY': 0,
    'KONSTANZER': 0,
    'KONTAK': 0,
    'KONTE': 0,
    'KONTER': 0,
    'KONTNY': 0,
    'KONTOGIANNIS': 0,
    'KONTOR': 0,
    'KONTOS': 0,
    'KONTRA': 0,
    'KONTUR': 0,
    'KONTZ': 0,
    'KONVALIN': 0,
    'KONVALINKA': 0,
    'KONVICKA': 0,
    'KONWINSKI': 0,
    'KONYA': 0,
    'KONYHA': 0,
    'KONYK': 0,
    'KONYN': 0,
    'KONYNDYK': 0,
    'KONZ': 0,
    'KONZAL': 0,
    'KONZE': 0,
    'KONZELMAN': 0,
    'KONZEM': 0,
    'KONZEN': 0,
    'KOO': 0,
    'KOOB': 0,
    'KOOGLE': 0,
    'KOOGLER': 0,
    'KOOI': 0,
    'KOOIENGA': 0,
    'KOOIKER': 0,
    'KOOIMA': 0,
    'KOOIMAN': 0,
    'KOOISTRA': 0,
    'KOOK': 0,
    'KOOKEN': 0,
    'KOOKER': 0,
    'KOOL': 0,
    'KOOLE': 0,
    'KOOLMAN': 0,
    'KOOLSTRA': 0,
    'KOOMEN': 0,
    'KOOMSON': 0,
    'KOON': 0,
    'KOONCE': 0,
    'KOONE': 0,
    'KOONER': 0,
    'KOONS': 0,
    'KOONSE': 0,
    'KOONSMAN': 0,
    'KOONTS': 0,
    'KOONTZ': 0,
    'KOONZ': 0,
    'KOOP': 0,
    'KOOPER': 0,
    'KOOPMAN': 0,
    'KOOPMANN': 0,
    'KOOPMANS': 0,
    'KOOPMEINERS': 0,
    'KOOPS': 0,
    'KOORS': 0,
    'KOORY': 0,
    'KOOS': 0,
    'KOOSER': 0,
    'KOOSMAN': 0,
    'KOOSMANN': 0,
    'KOOT': 0,
    'KOOTZ': 0,
    'KOOY': 0,
    'KOOYENGA': 0,
    'KOOYERS': 0,
    'KOOYMAN': 0,
    'KOOZER': 0,
    'KOP': 0,
    'KOPA': 0,
    'KOPAC': 0,
    'KOPACEK': 0,
    'KOPACH': 0,
    'KOPACK': 0,
    'KOPACKA': 0,
    'KOPACKI': 0,
    'KOPACZ': 0,
    'KOPACZEWSKI': 0,
    'KOPALA': 0,
    'KOPAN': 0,
    'KOPANSKI': 0,
    'KOPAS': 0,
    'KOPASKA': 0,
    'KOPASZ': 0,
    'KOPATICH': 0,
    'KOPATZ': 0,
    'KOPCA': 0,
    'KOPCHA': 0,
    'KOPCHAK': 0,
    'KOPCHICK': 0,
    'KOPCHIK': 0,
    'KOPCHINSKI': 0,
    'KOPCHO': 0,
    'KOPCZYK': 0,
    'KOPCZYNSKI': 0,
    'KOPE': 0,
    'KOPEC': 0,
    'KOPECK': 0,
    'KOPECKI': 0,
    'KOPECKY': 0,
    'KOPEK': 0,
    'KOPEL': 0,
    'KOPELMAN': 0,
    'KOPENSKI': 0,
    'KOPER': 0,
    'KOPERA': 0,
    'KOPERNA': 0,
    'KOPERSKI': 0,
    'KOPESKY': 0,
    'KOPET': 0,
    'KOPETSKY': 0,
    'KOPETZ': 0,
    'KOPETZKY': 0,
    'KOPF': 0,
    'KOPFER': 0,
    'KOPFF': 0,
    'KOPFMAN': 0,
    'KOPICKI': 0,
    'KOPIETZ': 0,
    'KOPIN': 0,
    'KOPINSKI': 0,
    'KOPINSKY': 0,
    'KOPIS': 0,
    'KOPISCHKE': 0,
    'KOPISH': 0,
    'KOPIT': 0,
    'KOPITZKE': 0,
    'KOPKA': 0,
    'KOPKE': 0,
    'KOPKO': 0,
    'KOPLAN': 0,
    'KOPLIK': 0,
    'KOPLIN': 0,
    'KOPLITZ': 0,
    'KOPLOW': 0,
    'KOPLOWITZ': 0,
    'KOPMAN': 0,
    'KOPNICKY': 0,
    'KOPONEN': 0,
    'KOPP': 0,
    'KOPPA': 0,
    'KOPPANG': 0,
    'KOPPE': 0,
    'KOPPEL': 0,
    'KOPPELMAN': 0,
    'KOPPELMANN': 0,
    'KOPPEN': 0,
    'KOPPENAAL': 0,
    'KOPPENHAFER': 0,
    'KOPPENHAVER': 0,
    'KOPPENHEFFER': 0,
    'KOPPENHOEFER': 0,
    'KOPPENHOFER': 0,
    'KOPPER': 0,
    'KOPPERS': 0,
    'KOPPERT': 0,
    'KOPPERUD': 0,
    'KOPPES': 0,
    'KOPPI': 0,
    'KOPPIN': 0,
    'KOPPING': 0,
    'KOPPINGER': 0,
    'KOPPLE': 0,
    'KOPPLIN': 0,
    'KOPPMAN': 0,
    'KOPPS': 0,
    'KOPPY': 0,
    'KOPREK': 0,
    'KOPRIVA': 0,
    'KOPROWSKI': 0,
    'KOPS': 0,
    'KOPSA': 0,
    'KOPSTEIN': 0,
    'KOPTA': 0,
    'KOPULOS': 0,
    'KOPY': 0,
    'KOPYCINSKI': 0,
    'KOPYDLOWSKI': 0,
    'KOR': 0,
    'KORA': 0,
    'KORAB': 0,
    'KORACH': 0,
    'KORAL': 0,
    'KORALEWSKI': 0,
    'KORAN': 0,
    'KORANDA': 0,
    'KORANDO': 0,
    'KORANEK': 0,
    'KORB': 0,
    'KORBA': 0,
    'KORBAL': 0,
    'KORBAR': 0,
    'KORBAS': 0,
    'KORBE': 0,
    'KORBEL': 0,
    'KORBELIK': 0,
    'KORBER': 0,
    'KORBY': 0,
    'KORCH': 0,
    'KORCHAK': 0,
    'KORCZ': 0,
    'KORCZAK': 0,
    'KORCZYK': 0,
    'KORCZYNSKI': 0,
    'KORD': 0,
    'KORDA': 0,
    'KORDAS': 0,
    'KORDECKI': 0,
    'KORDEK': 0,
    'KORDELL': 0,
    'KORDENBROCK': 0,
    'KORDES': 0,
    'KORDIAK': 0,
    'KORDIC': 0,
    'KORDICH': 0,
    'KORDICK': 0,
    'KORDIK': 0,
    'KORDIS': 0,
    'KORDISH': 0,
    'KORDON': 0,
    'KORDONOWY': 0,
    'KORDOSKY': 0,
    'KORDOWSKI': 0,
    'KORDSMEIER': 0,
    'KORDUS': 0,
    'KORE': 0,
    'KORECKI': 0,
    'KORECKY': 0,
    'KOREEN': 0,
    'KOREK': 0,
    'KORELL': 0,
    'KOREN': 0,
    'KORENEK': 0,
    'KORENKIEWICZ': 0,
    'KORES': 0,
    'KORESKI': 0,
    'KORESKO': 0,
    'KORESSEL': 0,
    'KORETSKY': 0,
    'KORETZ': 0,
    'KOREY': 0.966183574879227,
    'KORF': 0,
    'KORFF': 0,
    'KORFHAGE': 0,
    'KORGAN': 0,
    'KORGER': 0,
    'KORHONEN': 0,
    'KORHORN': 0,
    'KORI': 0.9852216748768473,
    'KORICH': 0,
    'KORIN': 0,
    'KORINEK': 0,
    'KORINKO': 0,
    'KORIS': 0,
    'KORISH': 0,
    'KORKIS': 0,
    'KORKMAZ': 0,
    'KORKOSZ': 0,
    'KORKOW': 0,
    'KORKOWSKI': 0,
    'KORKUS': 0,
    'KORLESKI': 0,
    'KORMAN': 0,
    'KORMANIK': 0,
    'KORMANN': 0,
    'KORMOS': 0,
    'KORN': 0,
    'KORNACK': 0,
    'KORNACKI': 0,
    'KORNAFEL': 0,
    'KORNAHRENS': 0,
    'KORNAK': 0,
    'KORNAS': 0,
    'KORNBAU': 0,
    'KORNBERG': 0,
    'KORNBLATT': 0,
    'KORNBLAU': 0,
    'KORNBLUH': 0,
    'KORNBLUM': 0,
    'KORNBLUTH': 0,
    'KORNEGAY': 0,
    'KORNELE': 0,
    'KORNELIS': 0,
    'KORNELL': 0,
    'KORNELY': 0,
    'KORNER': 0,
    'KORNET': 0,
    'KORNEY': 0,
    'KORNFEIND': 0,
    'KORNFELD': 0,
    'KORNFIELD': 0,
    'KORNGOLD': 0,
    'KORNHAUS': 0,
    'KORNHAUSER': 0,
    'KORNICK': 0,
    'KORNMAN': 0,
    'KORNMANN': 0,
    'KORNMEYER': 0,
    'KORNOELJE': 0,
    'KORNOWSKI': 0,
    'KORNREICH': 0,
    'KORNRUMPF': 0,
    'KORNS': 0,
    'KORNSTEIN': 0,
    'KOROBKIN': 0,
    'KORODY': 0,
    'KOROL': 0,
    'KOROLESKI': 0,
    'KOROLEV': 0,
    'KOROLY': 0,
    'KOROM': 0,
    'KOROMA': 0,
    'KORONA': 0,
    'KORONKA': 0,
    'KORONKIEWICZ': 0,
    'KOROS': 0,
    'KOROSEC': 0,
    'KORP': 0,
    'KORPAL': 0,
    'KORPALSKI': 0,
    'KORPELA': 0,
    'KORPI': 0,
    'KORPICS': 0,
    'KORR': 0,
    'KORRELL': 0,
    'KORS': 0,
    'KORSAK': 0,
    'KORSCH': 0,
    'KORSEN': 0,
    'KORSGAARD': 0,
    'KORSLUND': 0,
    'KORSMEYER': 0,
    'KORSMO': 0,
    'KORSON': 0,
    'KORST': 0,
    'KORSTAD': 0,
    'KORSUNSKY': 0,
    'KORT': 0,
    'KORTA': 0,
    'KORTAN': 0,
    'KORTAS': 0,
    'KORTBEIN': 0,
    'KORTE': 0,
    'KORTEKAAS': 0,
    'KORTEN': 0,
    'KORTENDICK': 0,
    'KORTES': 0,
    'KORTGE': 0,
    'KORTH': 0,
    'KORTHALS': 0,
    'KORTHAUER': 0,
    'KORTHUIS': 0,
    'KORTKAMP': 0,
    'KORTLEVER': 0,
    'KORTMAN': 0,
    'KORTNEY': 1,
    'KORTRIGHT': 0,
    'KORTUEM': 0,
    'KORTUM': 0,
    'KORTUS': 0,
    'KORTY': 0,
    'KORTZ': 0,
    'KORUS': 0,
    'KORVER': 0,
    'KORWEK': 0,
    'KORWIN': 0,
    'KORY': 0.9689922480620156,
    'KORYCKI': 0,
    'KORYNTA': 0,
    'KORYTKOWSKI': 0,
    'KORZAN': 0,
    'KORZEC': 0,
    'KORZEKWA': 0,
    'KORZEN': 0,
    'KORZENIEWSKI': 0,
    'KORZENIOWSKI': 0,
    'KORZON': 0,
    'KORZUN': 0,
    'KOS': 0,
    'KOSA': 0,
    'KOSACK': 0,
    'KOSAK': 0,
    'KOSAKA': 0,
    'KOSAKOWSKI': 0,
    'KOSAL': 0,
    'KOSAN': 0,
    'KOSANKE': 0,
    'KOSANOVIC': 0,
    'KOSANOVICH': 0,
    'KOSAR': 0,
    'KOSAREFF': 0,
    'KOSAREK': 0,
    'KOSBAB': 0,
    'KOSBERG': 0,
    'KOSCAK': 0,
    'KOSCH': 0,
    'KOSCHAK': 0,
    'KOSCHE': 0,
    'KOSCHEL': 0,
    'KOSCHER': 0,
    'KOSCHNICK': 0,
    'KOSCHO': 0,
    'KOSCIELAK': 0,
    'KOSCIELNIAK': 0,
    'KOSCIELNY': 0,
    'KOSCIELSKI': 0,
    'KOSCIK': 0,
    'KOSCINSKI': 0,
    'KOSCIOLEK': 0,
    'KOSCIUK': 0,
    'KOSCO': 0,
    'KOSE': 0,
    'KOSEC': 0,
    'KOSECKI': 0,
    'KOSEK': 0,
    'KOSEL': 0,
    'KOSELKE': 0,
    'KOSEN': 0,
    'KOSER': 0,
    'KOSH': 0,
    'KOSHAK': 0,
    'KOSHAR': 0,
    'KOSHAREK': 0,
    'KOSHER': 0,
    'KOSHI': 0,
    'KOSHINSKI': 0,
    'KOSHINSKY': 0,
    'KOSHIOL': 0,
    'KOSHKO': 0,
    'KOSHT': 0,
    'KOSHY': 0,
    'KOSIAK': 0,
    'KOSIARA': 0,
    'KOSIBA': 0,
    'KOSIC': 0,
    'KOSICH': 0,
    'KOSICK': 0,
    'KOSICKI': 0,
    'KOSIDOWSKI': 0,
    'KOSIEK': 0,
    'KOSIER': 0,
    'KOSIK': 0,
    'KOSIKOWSKI': 0,
    'KOSIN': 0,
    'KOSINA': 0,
    'KOSINSKI': 0,
    'KOSIOR': 0,
    'KOSIOREK': 0,
    'KOSIR': 0,
    'KOSIROG': 0,
    'KOSIS': 0,
    'KOSITZKE': 0,
    'KOSKA': 0,
    'KOSKE': 0,
    'KOSKELA': 0,
    'KOSKEY': 0,
    'KOSKI': 0,
    'KOSKIE': 0,
    'KOSKINAS': 0,
    'KOSKINEN': 0,
    'KOSKINIEMI': 0,
    'KOSKO': 0,
    'KOSKOVICH': 0,
    'KOSKY': 0,
    'KOSLA': 0,
    'KOSLAN': 0,
    'KOSLER': 0,
    'KOSLOFF': 0,
    'KOSLOSKE': 0,
    'KOSLOSKI': 0,
    'KOSLOSKY': 0,
    'KOSLOW': 0,
    'KOSLOWSKI': 0,
    'KOSLOWSKY': 0,
    'KOSMA': 0,
    'KOSMACH': 0,
    'KOSMAL': 0,
    'KOSMALA': 0,
    'KOSMALSKI': 0,
    'KOSMAN': 0,
    'KOSMAS': 0,
    'KOSMATKA': 0,
    'KOSMERL': 0,
    'KOSMICKI': 0,
    'KOSMIDER': 0,
    'KOSMIN': 0,
    'KOSMO': 0,
    'KOSMOS': 0,
    'KOSMOSKI': 0,
    'KOSMOWSKI': 0,
    'KOSNIK': 0,
    'KOSO': 0,
    'KOSOBUCKI': 0,
    'KOSOBUD': 0,
    'KOSOFF': 0,
    'KOSOFSKY': 0,
    'KOSOLA': 0,
    'KOSON': 0,
    'KOSOSKI': 0,
    'KOSOVICH': 0,
    'KOSOWICZ': 0,
    'KOSOWSKI': 0,
    'KOSOWSKY': 0,
    'KOSOY': 0,
    'KOSS': 0,
    'KOSSACK': 0,
    'KOSSAK': 0,
    'KOSSAKOWSKI': 0,
    'KOSSE': 0,
    'KOSSEL': 0,
    'KOSSEN': 0,
    'KOSSICK': 0,
    'KOSSIN': 0,
    'KOSSLER': 0,
    'KOSSMAN': 0,
    'KOSSMANN': 0,
    'KOSSOFF': 0,
    'KOSSOW': 0,
    'KOSSUTH': 0,
    'KOST': 0,
    'KOSTA': 0,
    'KOSTADINOV': 0,
    'KOSTAK': 0,
    'KOSTAKIS': 0,
    'KOSTAL': 0,
    'KOSTAN': 0,
    'KOSTAS': 0,
    'KOSTE': 0,
    'KOSTECKA': 0,
    'KOSTECKI': 0,
    'KOSTECKY': 0,
    'KOSTEK': 0,
    'KOSTEL': 0,
    'KOSTELAC': 0,
    'KOSTELEC': 0,
    'KOSTELECKY': 0,
    'KOSTELIC': 0,
    'KOSTELNIK': 0,
    'KOSTELNY': 0,
    'KOSTEN': 0,
    'KOSTENBADER': 0,
    'KOSTENKO': 0,
    'KOSTER': 0,
    'KOSTERMAN': 0,
    'KOSTERS': 0,
    'KOSTIC': 0,
    'KOSTICH': 0,
    'KOSTICK': 0,
    'KOSTIK': 0,
    'KOSTIN': 0,
    'KOSTIS': 0,
    'KOSTIUK': 0,
    'KOSTIVAL': 0,
    'KOSTKA': 0,
    'KOSTMAN': 0,
    'KOSTNER': 0,
    'KOSTO': 0,
    'KOSTOFF': 0,
    'KOSTOHRYZ': 0,
    'KOSTOLANSKY': 0,
    'KOSTON': 0,
    'KOSTOPOULOS': 0,
    'KOSTOS': 0,
    'KOSTOV': 0,
    'KOSTREBA': 0,
    'KOSTREVA': 0,
    'KOSTRO': 0,
    'KOSTROSKI': 0,
    'KOSTRZEWA': 0,
    'KOSTRZEWSKI': 0,
    'KOSTUCH': 0,
    'KOSTUCK': 0,
    'KOSTUK': 0,
    'KOSTUR': 0,
    'KOSTURA': 0,
    'KOSTY': 0,
    'KOSTYK': 0,
    'KOSTYO': 0,
    'KOSUB': 0,
    'KOSUDA': 0,
    'KOSUT': 0,
    'KOSYDAR': 0,
    'KOSZALKA': 0,
    'KOSZAREK': 0,
    'KOSZELA': 0,
    'KOSZEWSKI': 0,
    'KOSZUTA': 0,
    'KOSZYK': 0,
    'KOT': 0,
    'KOTA': 0,
    'KOTAJARVI': 0,
    'KOTAK': 0,
    'KOTAKE': 0,
    'KOTAL': 0,
    'KOTALIK': 0,
    'KOTANI': 0,
    'KOTANSKY': 0,
    'KOTAR': 0,
    'KOTARA': 0,
    'KOTARBA': 0,
    'KOTARSKI': 0,
    'KOTARY': 0,
    'KOTAS': 0,
    'KOTASEK': 0,
    'KOTASKA': 0,
    'KOTCH': 0,
    'KOTCHER': 0,
    'KOTE': 0,
    'KOTECHA': 0,
    'KOTECKI': 0,
    'KOTEK': 0,
    'KOTEL': 0,
    'KOTELES': 0,
    'KOTENKO': 0,
    'KOTERA': 0,
    'KOTERAS': 0,
    'KOTERBA': 0,
    'KOTEWA': 0,
    'KOTEY': 0,
    'KOTH': 0,
    'KOTHA': 0,
    'KOTHARI': 0,
    'KOTHE': 0,
    'KOTHEIMER': 0,
    'KOTHENBEUTEL': 0,
    'KOTHMAN': 0,
    'KOTHMANN': 0,
    'KOTHS': 0,
    'KOTICK': 0,
    'KOTIK': 0,
    'KOTILA': 0,
    'KOTIN': 0,
    'KOTIS': 0,
    'KOTKE': 0,
    'KOTKIN': 0,
    'KOTKOWSKI': 0,
    'KOTLAR': 0,
    'KOTLARCZYK': 0,
    'KOTLAREK': 0,
    'KOTLARZ': 0,
    'KOTLER': 0,
    'KOTLINSKI': 0,
    'KOTLOWSKI': 0,
    'KOTLYAR': 0,
    'KOTNIK': 0,
    'KOTOFF': 0,
    'KOTORA': 0,
    'KOTOUCH': 0,
    'KOTOV': 0,
    'KOTOWICZ': 0,
    'KOTOWSKI': 0,
    'KOTRBA': 0,
    'KOTRLA': 0,
    'KOTROUS': 0,
    'KOTSAKIS': 0,
    'KOTSCH': 0,
    'KOTSCHWAR': 0,
    'KOTSIS': 0,
    'KOTSONIS': 0,
    'KOTT': 0,
    'KOTTA': 0,
    'KOTTAS': 0,
    'KOTTCAMP': 0,
    'KOTTE': 0,
    'KOTTEMANN': 0,
    'KOTTEN': 0,
    'KOTTENSTETTE': 0,
    'KOTTER': 0,
    'KOTTERMAN': 0,
    'KOTTKAMP': 0,
    'KOTTKE': 0,
    'KOTTLER': 0,
    'KOTTMAN': 0,
    'KOTTMANN': 0,
    'KOTTMEIER': 0,
    'KOTTMYER': 0,
    'KOTTRE': 0,
    'KOTTS': 0,
    'KOTTWITZ': 0,
    'KOTULA': 0,
    'KOTULAK': 0,
    'KOTULSKI': 0,
    'KOTUN': 0,
    'KOTVAL': 0,
    'KOTWAL': 0,
    'KOTWICA': 0,
    'KOTWICKI': 0,
    'KOTY': 0,
    'KOTYK': 0,
    'KOTZ': 0,
    'KOTZEN': 0,
    'KOTZER': 0,
    'KOTZIAN': 0,
    'KOTZIN': 0,
    'KOTZUR': 0,
    'KOU': 0,
    'KOUASSI': 0,
    'KOUBA': 0,
    'KOUBEK': 0,
    'KOUCH': 0,
    'KOUCHI': 0,
    'KOUDELA': 0,
    'KOUDELKA': 0,
    'KOUFOS': 0,
    'KOUGH': 0,
    'KOUGHER': 0,
    'KOUGIAS': 0,
    'KOUGL': 0,
    'KOUKAL': 0,
    'KOUKOL': 0,
    'KOUKOS': 0,
    'KOUL': 0,
    'KOULIANOS': 0,
    'KOULOURIS': 0,
    'KOUMA': 0,
    'KOUMAS': 0,
    'KOUNS': 0,
    'KOUNTZ': 0,
    'KOUPAL': 0,
    'KOUR': 0,
    'KOURAFAS': 0,
    'KOURI': 0,
    'KOURIS': 0,
    'KOUROS': 0,
    'KOURT': 0,
    'KOURTIS': 0,
    'KOURTNEY': 1,
    'KOURY': 0,
    'KOUSSA': 0,
    'KOUTNIK': 0,
    'KOUTNY': 0,
    'KOUTRAS': 0,
    'KOUTROS': 0,
    'KOUTS': 0,
    'KOUTSIS': 0,
    'KOUTSKY': 0,
    'KOUTSOUKOS': 0,
    'KOUTZ': 0,
    'KOUYATE': 0,
    'KOUYOUMDJIAN': 0,
    'KOUYOUMJIAN': 0,
    'KOUZNETSOV': 0,
    'KOVAC': 0,
    'KOVACEVIC': 0,
    'KOVACEVICH': 0,
    'KOVACH': 0,
    'KOVACHEVICH': 0,
    'KOVACIC': 0,
    'KOVACICH': 0,
    'KOVACIK': 0,
    'KOVACK': 0,
    'KOVACS': 0,
    'KOVAK': 0,
    'KOVAL': 0,
    'KOVALAK': 0,
    'KOVALASKE': 0,
    'KOVALCHICK': 0,
    'KOVALCHIK': 0,
    'KOVALCHUK': 0,
    'KOVALCIK': 0,
    'KOVALENKO': 0,
    'KOVALESKI': 0,
    'KOVALESKY': 0,
    'KOVALEV': 0,
    'KOVALEVICH': 0,
    'KOVALICK': 0,
    'KOVALIK': 0,
    'KOVALL': 0,
    'KOVALOVSKY': 0,
    'KOVALSKI': 0,
    'KOVALSKY': 0,
    'KOVALY': 0,
    'KOVANDA': 0,
    'KOVAR': 0,
    'KOVARI': 0,
    'KOVARIK': 0,
    'KOVARY': 0,
    'KOVASH': 0,
    'KOVATCH': 0,
    'KOVATS': 0,
    'KOVEL': 0,
    'KOVELESKI': 0,
    'KOVELL': 0,
    'KOVEN': 0,
    'KOVER': 0,
    'KOVERMAN': 0,
    'KOVIAK': 0,
    'KOVIC': 0,
    'KOVICH': 0,
    'KOVICK': 0,
    'KOVITCH': 0,
    'KOVITZ': 0,
    'KOVNER': 0,
    'KOVTUN': 0,
    'KOW': 0,
    'KOWACH': 0,
    'KOWAL': 0,
    'KOWALAK': 0,
    'KOWALCHICK': 0,
    'KOWALCHIK': 0,
    'KOWALCHUK': 0,
    'KOWALCHYK': 0,
    'KOWALCYK': 0,
    'KOWALCZIK': 0,
    'KOWALCZUK': 0,
    'KOWALCZYK': 0,
    'KOWALEC': 0,
    'KOWALENKO': 0,
    'KOWALESKI': 0,
    'KOWALEWSKI': 0,
    'KOWALICK': 0,
    'KOWALIK': 0,
    'KOWALK': 0,
    'KOWALKE': 0,
    'KOWALKOWSKI': 0,
    'KOWALL': 0,
    'KOWALLIS': 0,
    'KOWALSKA': 0,
    'KOWALSKE': 0,
    'KOWALSKI': 0,
    'KOWALSKY': 0,
    'KOWALYK': 0,
    'KOWALZEK': 0,
    'KOWARSCH': 0,
    'KOWATCH': 0,
    'KOWELL': 0,
    'KOWING': 0,
    'KOWIS': 0,
    'KOWITZ': 0,
    'KOWLESSAR': 0,
    'KOWN': 0,
    'KOWNACKI': 0,
    'KOWSKI': 0,
    'KOWTKO': 0,
    'KOX': 0,
    'KOY': 0,
    'KOYA': 0,
    'KOYAMA': 0,
    'KOYANAGI': 0,
    'KOYFMAN': 0,
    'KOYL': 0,
    'KOYLE': 0,
    'KOZ': 0,
    'KOZA': 0,
    'KOZACEK': 0,
    'KOZACK': 0,
    'KOZACZKA': 0,
    'KOZAK': 0,
    'KOZAKIEWICZ': 0,
    'KOZAKOWSKI': 0,
    'KOZAL': 0,
    'KOZAN': 0,
    'KOZAR': 0,
    'KOZDRON': 0,
    'KOZEE': 0,
    'KOZEK': 0,
    'KOZEL': 0,
    'KOZELEK': 0,
    'KOZELKA': 0,
    'KOZELL': 0,
    'KOZELUH': 0,
    'KOZEMCHAK': 0,
    'KOZEN': 0,
    'KOZENY': 0,
    'KOZER': 0,
    'KOZERA': 0,
    'KOZERSKI': 0,
    'KOZEY': 0,
    'KOZIAK': 0,
    'KOZIAR': 0,
    'KOZIARA': 0,
    'KOZIARSKI': 0,
    'KOZIARZ': 0,
    'KOZIATEK': 0,
    'KOZIC': 0,
    'KOZICH': 0,
    'KOZICK': 0,
    'KOZICKI': 0,
    'KOZICZKOWSKI': 0,
    'KOZIEL': 0,
    'KOZIELEC': 0,
    'KOZIELSKI': 0,
    'KOZIK': 0,
    'KOZIKOWSKI': 0,
    'KOZIMOR': 0,
    'KOZIN': 0,
    'KOZINA': 0,
    'KOZINSKI': 0,
    'KOZIOL': 0,
    'KOZIOLEK': 0,
    'KOZISEK': 0,
    'KOZLAK': 0,
    'KOZLIK': 0,
    'KOZLOFF': 0,
    'KOZLOSKI': 0,
    'KOZLOSKY': 0,
    'KOZLOV': 0,
    'KOZLOVA': 0,
    'KOZLOVSKY': 0,
    'KOZLOW': 0,
    'KOZLOWICZ': 0,
    'KOZLOWSKI': 0,
    'KOZLOWSKY': 0,
    'KOZMA': 0,
    'KOZMAN': 0,
    'KOZMINSKI': 0,
    'KOZO': 0,
    'KOZOL': 0,
    'KOZORA': 0,
    'KOZUB': 0,
    'KOZUBAL': 0,
    'KOZUCH': 0,
    'KOZUL': 0,
    'KOZUMA': 0,
    'KOZUMPLIK': 0,
    'KOZUP': 0,
    'KOZUSKO': 0,
    'KOZUSZEK': 0,
    'KOZY': 0,
    'KOZYRA': 0,
    'KRAABEL': 0,
    'KRAACK': 0,
    'KRAAI': 0,
    'KRAAK': 0,
    'KRAATZ': 0,
    'KRAAY': 0,
    'KRAAYENBRINK': 0,
    'KRABACHER': 0,
    'KRABBE': 0,
    'KRABBENHOFT': 0,
    'KRABER': 0,
    'KRABILL': 0,
    'KRACH': 0,
    'KRACHER': 0,
    'KRACHT': 0,
    'KRACK': 0,
    'KRACKE': 0,
    'KRACKER': 0,
    'KRACL': 0,
    'KRADEL': 0,
    'KRAEER': 0,
    'KRAEGER': 0,
    'KRAEMER': 0,
    'KRAETSCH': 0,
    'KRAEUTER': 0,
    'KRAFCIK': 0,
    'KRAFFT': 0,
    'KRAFKA': 0,
    'KRAFT': 0,
    'KRAFTHEFER': 0,
    'KRAFTON': 0,
    'KRAG': 0,
    'KRAGE': 0,
    'KRAGEL': 0,
    'KRAGENBRINK': 0,
    'KRAGER': 0,
    'KRAGH': 0,
    'KRAGNESS': 0,
    'KRAGT': 0,
    'KRAH': 0,
    'KRAHAM': 0,
    'KRAHE': 0,
    'KRAHEL': 0,
    'KRAHENBUHL': 0,
    'KRAHL': 0,
    'KRAHLING': 0,
    'KRAHMER': 0,
    'KRAHN': 0,
    'KRAHULEC': 0,
    'KRAICH': 0,
    'KRAIG': 0.9756097560975611,
    'KRAIL': 0,
    'KRAIMER': 0,
    'KRAIN': 0,
    'KRAINER': 0,
    'KRAINES': 0,
    'KRAINIK': 0,
    'KRAINSKI': 0,
    'KRAINZ': 0,
    'KRAISINGER': 0,
    'KRAISS': 0,
    'KRAJA': 0,
    'KRAJACIC': 0,
    'KRAJCA': 0,
    'KRAJCI': 0,
    'KRAJCIK': 0,
    'KRAJCIR': 0,
    'KRAJCOVIC': 0,
    'KRAJECKI': 0,
    'KRAJENKA': 0,
    'KRAJESKI': 0,
    'KRAJEWSKI': 0,
    'KRAJICEK': 0,
    'KRAJNAK': 0,
    'KRAJNIAK': 0,
    'KRAJNIK': 0,
    'KRAK': 0,
    'KRAKAU': 0,
    'KRAKAUER': 0,
    'KRAKE': 0,
    'KRAKER': 0,
    'KRAKLOW': 0,
    'KRAKOFF': 0,
    'KRAKORA': 0,
    'KRAKOSKY': 0,
    'KRAKOW': 0,
    'KRAKOWER': 0,
    'KRAKOWIAK': 0,
    'KRAKOWSKI': 0,
    'KRAL': 0,
    'KRALEY': 0,
    'KRALICEK': 0,
    'KRALICK': 0,
    'KRALIK': 0,
    'KRALJ': 0,
    'KRALJIC': 0,
    'KRALL': 0,
    'KRALLMAN': 0,
    'KRALOVEC': 0,
    'KRALOVETZ': 0,
    'KRALOVIC': 0,
    'KRALY': 0,
    'KRAM': 0,
    'KRAMAR': 0,
    'KRAMARCZYK': 0,
    'KRAMARZ': 0,
    'KRAMB': 0,
    'KRAMBECK': 0,
    'KRAMBEER': 0,
    'KRAMER': 0,
    'KRAML': 0,
    'KRAMLICH': 0,
    'KRAMM': 0,
    'KRAMME': 0,
    'KRAMMER': 0,
    'KRAMMES': 0,
    'KRAMP': 0,
    'KRAMPE': 0,
    'KRAMPEN': 0,
    'KRAMPER': 0,
    'KRAMPERT': 0,
    'KRAMPF': 0,
    'KRAMPITZ': 0,
    'KRAMS': 0,
    'KRAN': 0,
    'KRANCE': 0,
    'KRANE': 0,
    'KRANENBURG': 0,
    'KRANENDONK': 0,
    'KRANER': 0,
    'KRANICH': 0,
    'KRANICK': 0,
    'KRANIG': 0,
    'KRANIK': 0,
    'KRANING': 0,
    'KRANIS': 0,
    'KRANITZ': 0,
    'KRANK': 0,
    'KRANKER': 0,
    'KRANS': 0,
    'KRANT': 0,
    'KRANTZ': 0,
    'KRANYAK': 0,
    'KRANZ': 0,
    'KRANZLER': 0,
    'KRANZUSCH': 0,
    'KRAPE': 0,
    'KRAPES': 0,
    'KRAPF': 0,
    'KRAPFL': 0,
    'KRAPOHL': 0,
    'KRAPP': 0,
    'KRAS': 0,
    'KRASA': 0,
    'KRASE': 0,
    'KRASINSKI': 0,
    'KRASK': 0,
    'KRASKA': 0,
    'KRASKE': 0,
    'KRASKO': 0,
    'KRASKY': 0,
    'KRASLEY': 0,
    'KRASNE': 0,
    'KRASNER': 0,
    'KRASNEY': 0,
    'KRASNICK': 0,
    'KRASNICKI': 0,
    'KRASNIQI': 0,
    'KRASNOFF': 0,
    'KRASNOV': 0,
    'KRASNOW': 0,
    'KRASNY': 0,
    'KRASON': 0,
    'KRASOVEC': 0,
    'KRASOVIC': 0,
    'KRASOWSKI': 0,
    'KRASS': 0,
    'KRASSELT': 0,
    'KRASSNER': 0,
    'KRASSOW': 0,
    'KRASUCKI': 0,
    'KRASUSKI': 0,
    'KRASZEWSKI': 0,
    'KRATCHMAN': 0,
    'KRATER': 0,
    'KRATINA': 0,
    'KRATKA': 0,
    'KRATKY': 0,
    'KRATOCHVIL': 0,
    'KRATOCHWILL': 0,
    'KRATOFIL': 0,
    'KRATOVIL': 0,
    'KRATSAS': 0,
    'KRATT': 0,
    'KRATTIGER': 0,
    'KRATTLI': 0,
    'KRATZ': 0,
    'KRATZBERG': 0,
    'KRATZENBERG': 0,
    'KRATZER': 0,
    'KRATZERT': 0,
    'KRATZKE': 0,
    'KRAUCH': 0,
    'KRAUEL': 0,
    'KRAUKLIS': 0,
    'KRAUS': 0,
    'KRAUSCH': 0,
    'KRAUSE': 0,
    'KRAUSER': 0,
    'KRAUSERT': 0,
    'KRAUSHAAR': 0,
    'KRAUSHAR': 0,
    'KRAUSKOPF': 0,
    'KRAUSMAN': 0,
    'KRAUSS': 0,
    'KRAUSSE': 0,
    'KRAUSZ': 0,
    'KRAUT': 0,
    'KRAUTBAUER': 0,
    'KRAUTER': 0,
    'KRAUTH': 0,
    'KRAUTHAMER': 0,
    'KRAUTHEIM': 0,
    'KRAUTKRAMER': 0,
    'KRAUTKREMER': 0,
    'KRAUTTER': 0,
    'KRAVCHENKO': 0,
    'KRAVCHUK': 0,
    'KRAVEC': 0,
    'KRAVET': 0,
    'KRAVETS': 0,
    'KRAVETZ': 0,
    'KRAVIK': 0,
    'KRAVIS': 0,
    'KRAVIT': 0,
    'KRAVITZ': 0,
    'KRAVTSOV': 0,
    'KRAWCHUK': 0,
    'KRAWCZAK': 0,
    'KRAWCZUK': 0,
    'KRAWCZYK': 0,
    'KRAWCZYNSKI': 0,
    'KRAWEC': 0,
    'KRAWETZ': 0,
    'KRAWIEC': 0,
    'KRAWIECKI': 0,
    'KRAWIETZ': 0,
    'KRAWITZ': 0,
    'KRAXBERGER': 0,
    'KRAY': 0,
    'KRAYBILL': 0,
    'KRAYER': 0,
    'KRAYESKI': 0,
    'KRAYNAK': 0,
    'KRAYNICK': 0,
    'KRAYNIK': 0,
    'KRC': 0,
    'KREADY': 0,
    'KREAGER': 0,
    'KREAIS': 0,
    'KREAMER': 0,
    'KREB': 0,
    'KREBBS': 0,
    'KREBEL': 0,
    'KREBER': 0,
    'KREBILL': 0,
    'KREBS': 0,
    'KREBSBACH': 0,
    'KRECEK': 0,
    'KRECH': 0,
    'KRECHEL': 0,
    'KRECK': 0,
    'KRECKEL': 0,
    'KRECKER': 0,
    'KRECKLOW': 0,
    'KRECKMAN': 0,
    'KRECZMER': 0,
    'KREDER': 0,
    'KREEGER': 0,
    'KREFFT': 0,
    'KREFT': 0,
    'KREFTING': 0,
    'KREGAR': 0,
    'KREGE': 0,
    'KREGEL': 0,
    'KREGER': 0,
    'KREGLOW': 0,
    'KREH': 0,
    'KREHBIEL': 0,
    'KREHEL': 0,
    'KREHER': 0,
    'KREHL': 0,
    'KREHMEYER': 0,
    'KREI': 0,
    'KREIBICH': 0,
    'KREIDEL': 0,
    'KREIDER': 0,
    'KREIDERMACHER': 0,
    'KREIDLER': 0,
    'KREIE': 0,
    'KREIER': 0,
    'KREIFELS': 0,
    'KREIG': 0,
    'KREIGER': 0,
    'KREIGH': 0,
    'KREIGHBAUM': 0,
    'KREIKEMEIER': 0,
    'KREIL': 0,
    'KREILEIN': 0,
    'KREILICK': 0,
    'KREILING': 0,
    'KREILKAMP': 0,
    'KREIMAN': 0,
    'KREIMER': 0,
    'KREIMEYER': 0,
    'KREIN': 0,
    'KREINBERG': 0,
    'KREINBRING': 0,
    'KREINBRINK': 0,
    'KREINBROOK': 0,
    'KREINDLER': 0,
    'KREINER': 0,
    'KREINHEDER': 0,
    'KREIS': 0,
    'KREISBERG': 0,
    'KREISCHER': 0,
    'KREISEL': 0,
    'KREISER': 0,
    'KREISHER': 0,
    'KREISLE': 0,
    'KREISLER': 0,
    'KREISMAN': 0,
    'KREISS': 0,
    'KREITER': 0,
    'KREITINGER': 0,
    'KREITLER': 0,
    'KREITLOW': 0,
    'KREITMAN': 0,
    'KREITNER': 0,
    'KREITZ': 0,
    'KREITZBERG': 0,
    'KREITZER': 0,
    'KREITZMAN': 0,
    'KREIZENBECK': 0,
    'KREJCAREK': 0,
    'KREJCI': 0,
    'KREJSA': 0,
    'KREK': 0,
    'KREKE': 0,
    'KREKEL': 0,
    'KREKELBERG': 0,
    'KREKELER': 0,
    'KREKLAU': 0,
    'KREKLOW': 0,
    'KREKORIAN': 0,
    'KRELL': 0,
    'KRELLER': 0,
    'KREMBS': 0,
    'KREMEN': 0,
    'KREMER': 0,
    'KREMERS': 0,
    'KREMIN': 0,
    'KREMINSKI': 0,
    'KREML': 0,
    'KREMLING': 0,
    'KREMM': 0,
    'KREMMEL': 0,
    'KREMP': 0,
    'KREMPA': 0,
    'KREMPASKY': 0,
    'KREMPEL': 0,
    'KREMS': 0,
    'KREMSER': 0,
    'KREMSKI': 0,
    'KREMSREITER': 0,
    'KREN': 0,
    'KRENCIK': 0,
    'KRENEK': 0,
    'KRENGEL': 0,
    'KRENIK': 0,
    'KRENING': 0,
    'KRENISKY': 0,
    'KRENITSKY': 0,
    'KRENK': 0,
    'KRENKE': 0,
    'KRENKEL': 0,
    'KRENN': 0,
    'KRENNING': 0,
    'KRENTZ': 0,
    'KRENTZMAN': 0,
    'KRENZ': 0,
    'KRENZEL': 0,
    'KRENZER': 0,
    'KRENZKE': 0,
    'KREPEL': 0,
    'KREPELA': 0,
    'KREPP': 0,
    'KREPPEIN': 0,
    'KREPPEL': 0,
    'KREPPS': 0,
    'KREPS': 0,
    'KRESAK': 0,
    'KRESAL': 0,
    'KRESCH': 0,
    'KRESEN': 0,
    'KRESGE': 0,
    'KRESH': 0,
    'KRESHA': 0,
    'KRESIN': 0,
    'KRESKE': 0,
    'KRESKI': 0,
    'KRESKY': 0,
    'KRESL': 0,
    'KRESNAK': 0,
    'KRESS': 0,
    'KRESSE': 0,
    'KRESSEL': 0,
    'KRESSER': 0,
    'KRESSIN': 0,
    'KRESSLER': 0,
    'KRESSLEY': 0,
    'KRESSLY': 0,
    'KRESSMAN': 0,
    'KREST': 0,
    'KRESTA': 0,
    'KRET': 0,
    'KRETCHMAN': 0,
    'KRETCHMAR': 0,
    'KRETCHMER': 0,
    'KRETER': 0,
    'KRETH': 0,
    'KRETLOW': 0,
    'KRETSCH': 0,
    'KRETSCHMAN': 0,
    'KRETSCHMANN': 0,
    'KRETSCHMAR': 0,
    'KRETSCHMER': 0,
    'KRETSER': 0,
    'KRETSINGER': 0,
    'KRETT': 0,
    'KRETZ': 0,
    'KRETZER': 0,
    'KRETZINGER': 0,
    'KRETZLER': 0,
    'KRETZMANN': 0,
    'KRETZMER': 0,
    'KRETZSCHMAR': 0,
    'KRETZSCHMER': 0,
    'KREUDER': 0,
    'KREUGER': 0,
    'KREUL': 0,
    'KREUN': 0,
    'KREUSCH': 0,
    'KREUSCHER': 0,
    'KREUSEL': 0,
    'KREUSER': 0,
    'KREUTER': 0,
    'KREUTNER': 0,
    'KREUTTER': 0,
    'KREUTZ': 0,
    'KREUTZBERG': 0,
    'KREUTZER': 0,
    'KREUTZIGER': 0,
    'KREUZ': 0,
    'KREUZER': 0,
    'KREUZIGER': 0,
    'KREWER': 0,
    'KREWSON': 0,
    'KREY': 0,
    'KREYE': 0,
    'KREYER': 0,
    'KREYKES': 0,
    'KREYLING': 0,
    'KREYMER': 0,
    'KREZEL': 0,
    'KRIBBS': 0,
    'KRIBS': 0,
    'KRICH': 0,
    'KRICHBAUM': 0,
    'KRICHEVSKY': 0,
    'KRICHMAR': 0,
    'KRICHTEN': 0,
    'KRICK': 0,
    'KRIDER': 0,
    'KRIDLER': 0,
    'KRIDNER': 0,
    'KRIEBEL': 0,
    'KRIEBLE': 0,
    'KRIECH': 0,
    'KRIECHBAUM': 0,
    'KRIEDEMAN': 0,
    'KRIEG': 0,
    'KRIEGBAUM': 0,
    'KRIEGE': 0,
    'KRIEGEL': 0,
    'KRIEGER': 0,
    'KRIEGH': 0,
    'KRIEGLER': 0,
    'KRIEGSHAUSER': 0,
    'KRIEGSMAN': 0,
    'KRIEHN': 0,
    'KRIEL': 0,
    'KRIEN': 0,
    'KRIENER': 0,
    'KRIENERT': 0,
    'KRIENKE': 0,
    'KRIENS': 0,
    'KRIER': 0,
    'KRIES': 0,
    'KRIESCHER': 0,
    'KRIESE': 0,
    'KRIESEL': 0,
    'KRIESER': 0,
    'KRIETE': 0,
    'KRIETEMEYER': 0,
    'KRIETER': 0,
    'KRIETZ': 0,
    'KRIEWALD': 0,
    'KRIEWALDT': 0,
    'KRIEWALL': 0,
    'KRIGBAUM': 0,
    'KRIGER': 0,
    'KRIHA': 0,
    'KRIKKE': 0,
    'KRIKORIAN': 0,
    'KRILE': 0,
    'KRILEY': 0,
    'KRILL': 0,
    'KRIM': 0,
    'KRIMM': 0,
    'KRIMMEL': 0,
    'KRIMMER': 0,
    'KRIMMINGER': 0,
    'KRIMSKY': 0,
    'KRINER': 0,
    'KRING': 0,
    'KRINGEL': 0,
    'KRINGEN': 0,
    'KRINGLE': 0,
    'KRINGS': 0,
    'KRINKE': 0,
    'KRINN': 0,
    'KRINOCK': 0,
    'KRINSKY': 0,
    'KRIPALANI': 0,
    'KRIPPEL': 0,
    'KRIPPENDORF': 0,
    'KRIPPNER': 0,
    'KRIPS': 0,
    'KRIS': 0.9950248756218906,
    'KRISA': 0,
    'KRISAK': 0,
    'KRISANDA': 0,
    'KRISCH': 0,
    'KRISCHE': 0,
    'KRISCHER': 0,
    'KRISCHKE': 0,
    'KRISE': 0,
    'KRISEL': 0,
    'KRISELL': 0,
    'KRISER': 0,
    'KRISH': 0,
    'KRISHAN': 0,
    'KRISHER': 0,
    'KRISHNA': 0.7692307692307693,
    'KRISHNAKUMAR': 0,
    'KRISHNAMOORTHY': 0,
    'KRISHNAMURTHY': 0,
    'KRISHNAN': 0,
    'KRISHNASWAMY': 0,
    'KRISIK': 0,
    'KRISKA': 0,
    'KRISKE': 0,
    'KRISKO': 0,
    'KRISLE': 0,
    'KRISMAN': 0,
    'KRISMER': 0,
    'KRISPIN': 0,
    'KRISS': 0,
    'KRISSINGER': 0,
    'KRISSY': 1,
    'KRIST': 0,
    'KRISTA': 0.998003992015968,
    'KRISTAL': 0.986842105263158,
    'KRISTAN': 0.970873786407767,
    'KRISTEEN': 1,
    'KRISTEK': 0,
    'KRISTEL': 0.9756097560975611,
    'KRISTEN': 0.9992797983435362,
    'KRISTENSEN': 0,
    'KRISTENSON': 0,
    'KRISTI': 1,
    'KRISTIAN': 0.9771986970684039,
    'KRISTIANSEN': 0,
    'KRISTICH': 0,
    'KRISTIE': 0.9970457902511077,
    'KRISTIN': 0.9993943064809208,
    'KRISTINA': 1,
    'KRISTINE': 1,
    'KRISTJANSON': 0,
    'KRISTLE': 1,
    'KRISTO': 0,
    'KRISTOF': 0,
    'KRISTOFER': 1,
    'KRISTOFF': 0,
    'KRISTOFFERSEN': 0,
    'KRISTOFFERSON': 0,
    'KRISTOFIK': 0,
    'KRISTON': 0,
    'KRISTOPHER': 1,
    'KRISTOVICH': 0,
    'KRISTUFEK': 0,
    'KRISTY': 0.9975062344139651,
    'KRISTYN': 1,
    'KRISTYNIK': 0,
    'KRITES': 0,
    'KRITIKOS': 0,
    'KRITNER': 0,
    'KRITZ': 0,
    'KRITZER': 0,
    'KRITZLER': 0,
    'KRITZMAN': 0,
    'KRIVAK': 0,
    'KRIVANEC': 0,
    'KRIVANEK': 0,
    'KRIVDA': 0,
    'KRIVENKO': 0,
    'KRIVITSKY': 0,
    'KRIZ': 0,
    'KRIZAN': 0,
    'KRIZEK': 0,
    'KRIZMAN': 0,
    'KRIZMANICH': 0,
    'KRMPOTICH': 0,
    'KROAH': 0,
    'KROB': 0,
    'KROBATH': 0,
    'KROBOT': 0,
    'KROBOTH': 0,
    'KROC': 0,
    'KROCHMAL': 0,
    'KROCHTA': 0,
    'KROCK': 0,
    'KROCKER': 0,
    'KRODEL': 0,
    'KROEBER': 0,
    'KROECK': 0,
    'KROECKEL': 0,
    'KROEGER': 0,
    'KROEHLER': 0,
    'KROEKER': 0,
    'KROELL': 0,
    'KROELLS': 0,
    'KROEMER': 0,
    'KROEN': 0,
    'KROENCKE': 0,
    'KROENER': 0,
    'KROENING': 0,
    'KROENKE': 0,
    'KROEPEL': 0,
    'KROEPLIN': 0,
    'KROES': 0,
    'KROESE': 0,
    'KROESEN': 0,
    'KROETCH': 0,
    'KROETSCH': 0,
    'KROETZ': 0,
    'KROEZE': 0,
    'KROFCHECK': 0,
    'KROFF': 0,
    'KROFFT': 0,
    'KROFT': 0,
    'KROFTA': 0,
    'KROG': 0,
    'KROGEL': 0,
    'KROGEN': 0,
    'KROGER': 0,
    'KROGH': 0,
    'KROGMAN': 0,
    'KROGMANN': 0,
    'KROGMEIER': 0,
    'KROGSTAD': 0,
    'KROGULSKI': 0,
    'KROH': 0,
    'KROHA': 0,
    'KROHE': 0,
    'KROHMER': 0,
    'KROHN': 0,
    'KROHNE': 0,
    'KROIS': 0,
    'KROISS': 0,
    'KROK': 0,
    'KROKER': 0,
    'KROKOS': 0,
    'KROKOWSKI': 0,
    'KROL': 0,
    'KROLAK': 0,
    'KROLCZYK': 0,
    'KROLEWSKI': 0,
    'KROLICK': 0,
    'KROLICKI': 0,
    'KROLIK': 0,
    'KROLIKOWSKI': 0,
    'KROLL': 0,
    'KROM': 0,
    'KROMA': 0,
    'KROMAH': 0,
    'KROMAN': 0,
    'KROMBACH': 0,
    'KROME': 0,
    'KROMER': 0,
    'KROMHOUT': 0,
    'KROMKA': 0,
    'KROMM': 0,
    'KROMMENHOEK': 0,
    'KROMMINGA': 0,
    'KROMREY': 0,
    'KRON': 0,
    'KRONBERG': 0,
    'KRONBERGER': 0,
    'KRONCKE': 0,
    'KRONE': 0,
    'KRONEBERGER': 0,
    'KRONEBUSCH': 0,
    'KRONEMAN': 0,
    'KRONEMEYER': 0,
    'KRONEN': 0,
    'KRONENBERG': 0,
    'KRONENBERGER': 0,
    'KRONENFELD': 0,
    'KRONENWETTER': 0,
    'KRONER': 0,
    'KRONES': 0,
    'KRONEWITTER': 0,
    'KRONFELD': 0,
    'KRONHOLM': 0,
    'KRONICK': 0,
    'KRONING': 0,
    'KRONINGER': 0,
    'KRONISH': 0,
    'KRONK': 0,
    'KRONLAGE': 0,
    'KRONMAN': 0,
    'KRONMILLER': 0,
    'KRONNER': 0,
    'KRONQUIST': 0,
    'KRONSBERG': 0,
    'KRONSCHNABEL': 0,
    'KRONSTEDT': 0,
    'KRONTZ': 0,
    'KRONYAK': 0,
    'KRONZ': 0,
    'KROOK': 0,
    'KROON': 0,
    'KROOP': 0,
    'KROOS': 0,
    'KROOT': 0,
    'KROP': 0,
    'KROPA': 0,
    'KROPELNICKI': 0,
    'KROPF': 0,
    'KROPFF': 0,
    'KROPIDLOWSKI': 0,
    'KROPIEWNICKI': 0,
    'KROPIK': 0,
    'KROPOG': 0,
    'KROPP': 0,
    'KROS': 0,
    'KROSCH': 0,
    'KROSCHEL': 0,
    'KROSHUS': 0,
    'KROSKA': 0,
    'KROSKE': 0,
    'KROSKY': 0,
    'KROSS': 0,
    'KROSSCHELL': 0,
    'KROST': 0,
    'KROT': 0,
    'KROTH': 0,
    'KROTT': 0,
    'KROTZ': 0,
    'KROTZER': 0,
    'KROUCH': 0,
    'KROUGH': 0,
    'KROULIK': 0,
    'KROUPA': 0,
    'KROUS': 0,
    'KROUSE': 0,
    'KROUSKOP': 0,
    'KROUT': 0,
    'KROUTH': 0,
    'KROUTIL': 0,
    'KROW': 0,
    'KROWICKI': 0,
    'KROWL': 0,
    'KROWN': 0,
    'KROYER': 0,
    'KROZEL': 0,
    'KRPAN': 0,
    'KRPATA': 0,
    'KRSKA': 0,
    'KRSTEVSKI': 0,
    'KRSTIC': 0,
    'KRUBSACK': 0,
    'KRUCHTEN': 0,
    'KRUCK': 0,
    'KRUCKEBERG': 0,
    'KRUCKENBERG': 0,
    'KRUCKMAN': 0,
    'KRUCKOW': 0,
    'KRUCZEK': 0,
    'KRUCZKOWSKI': 0,
    'KRUCZYNSKI': 0,
    'KRUDOP': 0,
    'KRUDWIG': 0,
    'KRUECK': 0,
    'KRUECKEBERG': 0,
    'KRUEGEL': 0,
    'KRUEGER': 0,
    'KRUEL': 0,
    'KRUEP': 0,
    'KRUER': 0,
    'KRUESEL': 0,
    'KRUETH': 0,
    'KRUFT': 0,
    'KRUG': 0,
    'KRUGEL': 0,
    'KRUGER': 0,
    'KRUGGEL': 0,
    'KRUGGER': 0,
    'KRUGH': 0,
    'KRUGLE': 0,
    'KRUGLER': 0,
    'KRUGMAN': 0,
    'KRUHM': 0,
    'KRUIS': 0,
    'KRUISE': 0,
    'KRUIT': 0,
    'KRUITHOF': 0,
    'KRUITHOFF': 0,
    'KRUIZE': 0,
    'KRUIZENGA': 0,
    'KRUK': 0,
    'KRUKAR': 0,
    'KRUKOW': 0,
    'KRUKOWSKI': 0,
    'KRUL': 0,
    'KRULA': 0,
    'KRULIK': 0,
    'KRULIKOWSKI': 0,
    'KRULISH': 0,
    'KRULL': 0,
    'KRUM': 0,
    'KRUMBACH': 0,
    'KRUMBEIN': 0,
    'KRUMBHOLZ': 0,
    'KRUMEL': 0,
    'KRUMENACKER': 0,
    'KRUMENAUER': 0,
    'KRUMHOLTZ': 0,
    'KRUMHOLZ': 0,
    'KRUMINS': 0,
    'KRUML': 0,
    'KRUMLAND': 0,
    'KRUMLAUF': 0,
    'KRUMM': 0,
    'KRUMME': 0,
    'KRUMMEL': 0,
    'KRUMMEN': 0,
    'KRUMNOW': 0,
    'KRUMP': 0,
    'KRUMPE': 0,
    'KRUMPELMAN': 0,
    'KRUMREI': 0,
    'KRUMREY': 0,
    'KRUMRIE': 0,
    'KRUMRINE': 0,
    'KRUMROY': 0,
    'KRUMSIEK': 0,
    'KRUMWIEDE': 0,
    'KRUP': 0,
    'KRUPA': 0,
    'KRUPANSKY': 0,
    'KRUPAR': 0,
    'KRUPCZAK': 0,
    'KRUPER': 0,
    'KRUPICKA': 0,
    'KRUPIN': 0,
    'KRUPINSKI': 0,
    'KRUPKA': 0,
    'KRUPKE': 0,
    'KRUPNICK': 0,
    'KRUPNIK': 0,
    'KRUPP': 0,
    'KRUPPA': 0,
    'KRUPPENBACHER': 0,
    'KRUPSKI': 0,
    'KRUPSKY': 0,
    'KRUS': 0,
    'KRUSCH': 0,
    'KRUSCHKE': 0,
    'KRUSCHWITZ': 0,
    'KRUSE': 0,
    'KRUSELL': 0,
    'KRUSEMARK': 0,
    'KRUSEN': 0,
    'KRUSER': 0,
    'KRUSH': 0,
    'KRUSHINSKI': 0,
    'KRUSINSKI': 0,
    'KRUSKA': 0,
    'KRUSKAMP': 0,
    'KRUSKIE': 0,
    'KRUSS': 0,
    'KRUSSOW': 0,
    'KRUSZ': 0,
    'KRUSZEWSKI': 0,
    'KRUSZKA': 0,
    'KRUSZYNSKI': 0,
    'KRUT': 0,
    'KRUTA': 0,
    'KRUTE': 0,
    'KRUTH': 0,
    'KRUTSCH': 0,
    'KRUTSINGER': 0,
    'KRUTY': 0,
    'KRUTZ': 0,
    'KRUZAN': 0,
    'KRUZE': 0,
    'KRUZEL': 0,
    'KRUZIC': 0,
    'KRUZICH': 0,
    'KRUZINSKI': 0,
    'KRY': 0,
    'KRYCH': 0,
    'KRYDER': 0,
    'KRYGER': 0,
    'KRYGIER': 0,
    'KRYGOWSKI': 0,
    'KRYK': 0,
    'KRYNICKI': 0,
    'KRYNOCK': 0,
    'KRYNSKI': 0,
    'KRYPEL': 0,
    'KRYS': 0,
    'KRYSA': 0,
    'KRYSHAK': 0,
    'KRYSIAK': 0,
    'KRYSINSKI': 0,
    'KRYSKA': 0,
    'KRYSL': 0,
    'KRYSTA': 1,
    'KRYSTAL': 1,
    'KRYSTEK': 0,
    'KRYSTEN': 1,
    'KRYSTIN': 1,
    'KRYSTINA': 1,
    'KRYSTLE': 1,
    'KRYSTOFIAK': 0,
    'KRYSTOFIK': 0,
    'KRYSTON': 0,
    'KRYSTOSEK': 0,
    'KRYSTYNA': 1,
    'KRYSTYNIAK': 0,
    'KRYSZAK': 0,
    'KRYZA': 0,
    'KRYZAK': 0,
    'KRYZER': 0,
    'KRZAK': 0,
    'KRZAN': 0,
    'KRZANOWSKI': 0,
    'KRZECZKOWSKI': 0,
    'KRZEMIEN': 0,
    'KRZEMINSKI': 0,
    'KRZESINSKI': 0,
    'KRZEWINSKI': 0,
    'KRZMARZICK': 0,
    'KRZNARICH': 0,
    'KRZYCKI': 0,
    'KRZYKOWSKI': 0,
    'KRZYMINSKI': 0,
    'KRZYNOWEK': 0,
    'KRZYS': 0,
    'KRZYSIAK': 0,
    'KRZYSIK': 0,
    'KRZYSTON': 0,
    'KRZYWDA': 0,
    'KRZYWICKI': 0,
    'KRZYZAK': 0,
    'KRZYZANIAK': 0,
    'KRZYZANOWSKI': 0,
    'KRZYZEWSKI': 0,
    'KSIAZEK': 0,
    'KSIAZKIEWICZ': 0,
    'KSOR': 0,
    'KU': 0,
    'KUA': 0,
    'KUAM': 0,
    'KUAMME': 0,
    'KUAMOO': 0,
    'KUAN': 0,
    'KUANG': 0,
    'KUAR': 0,
    'KUB': 0,
    'KUBA': 0,
    'KUBACAK': 0,
    'KUBACH': 0,
    'KUBACKI': 0,
    'KUBAL': 0,
    'KUBALA': 0,
    'KUBALL': 0,
    'KUBAN': 0,
    'KUBAS': 0,
    'KUBASEK': 0,
    'KUBASIAK': 0,
    'KUBASIK': 0,
    'KUBASTA': 0,
    'KUBAT': 0,
    'KUBE': 0,
    'KUBEC': 0,
    'KUBECK': 0,
    'KUBECKA': 0,
    'KUBECZKA': 0,
    'KUBEK': 0,
    'KUBEL': 0,
    'KUBELKA': 0,
    'KUBENA': 0,
    'KUBENKA': 0,
    'KUBER': 0,
    'KUBERA': 0,
    'KUBERSKI': 0,
    'KUBERT': 0,
    'KUBES': 0,
    'KUBESH': 0,
    'KUBIAK': 0,
    'KUBIC': 0,
    'KUBICA': 0,
    'KUBICEK': 0,
    'KUBICHEK': 0,
    'KUBICK': 0,
    'KUBICKA': 0,
    'KUBICKI': 0,
    'KUBICZ': 0,
    'KUBIE': 0,
    'KUBIK': 0,
    'KUBILIUS': 0,
    'KUBILUS': 0,
    'KUBIN': 0,
    'KUBINA': 0,
    'KUBINEC': 0,
    'KUBINSKI': 0,
    'KUBIS': 0,
    'KUBISCH': 0,
    'KUBISH': 0,
    'KUBISIAK': 0,
    'KUBISTA': 0,
    'KUBISZEWSKI': 0,
    'KUBIT': 0,
    'KUBITSCHEK': 0,
    'KUBITZ': 0,
    'KUBITZA': 0,
    'KUBLER': 0,
    'KUBLI': 0,
    'KUBLIN': 0,
    'KUBLY': 0,
    'KUBO': 0,
    'KUBON': 0,
    'KUBOTA': 0,
    'KUBOW': 0,
    'KUBOYAMA': 0,
    'KUBRAK': 0,
    'KUBSCH': 0,
    'KUBU': 0,
    'KUBUS': 0,
    'KUBY': 0,
    'KUC': 0,
    'KUCA': 0,
    'KUCABA': 0,
    'KUCALA': 0,
    'KUCAN': 0,
    'KUCEK': 0,
    'KUCEL': 0,
    'KUCENSKI': 0,
    'KUCER': 0,
    'KUCERA': 0,
    'KUCH': 0,
    'KUCHAN': 0,
    'KUCHAR': 0,
    'KUCHARCZYK': 0,
    'KUCHAREK': 0,
    'KUCHARIK': 0,
    'KUCHARSKI': 0,
    'KUCHEL': 0,
    'KUCHENBECKER': 0,
    'KUCHENBROD': 0,
    'KUCHENMEISTER': 0,
    'KUCHER': 0,
    'KUCHERA': 0,
    'KUCHINKA': 0,
    'KUCHINSKI': 0,
    'KUCHINSKY': 0,
    'KUCHLER': 0,
    'KUCHMA': 0,
    'KUCHMAN': 0,
    'KUCHNICKI': 0,
    'KUCHTA': 0,
    'KUCIA': 0,
    'KUCICH': 0,
    'KUCIK': 0,
    'KUCINSKAS': 0,
    'KUCINSKI': 0,
    'KUCK': 0,
    'KUCKELMAN': 0,
    'KUCKER': 0,
    'KUCKO': 0,
    'KUCKUCK': 0,
    'KUCZEK': 0,
    'KUCZENSKI': 0,
    'KUCZERA': 0,
    'KUCZEWSKI': 0,
    'KUCZINSKI': 0,
    'KUCZKA': 0,
    'KUCZKOWSKI': 0,
    'KUCZMA': 0,
    'KUCZMARSKI': 0,
    'KUCZWARA': 0,
    'KUCZYNSKI': 0,
    'KUDA': 0,
    'KUDEJ': 0,
    'KUDELA': 0,
    'KUDELKA': 0,
    'KUDER': 0,
    'KUDERA': 0,
    'KUDERER': 0,
    'KUDICK': 0,
    'KUDIRKA': 0,
    'KUDLA': 0,
    'KUDLAC': 0,
    'KUDLACEK': 0,
    'KUDLACIK': 0,
    'KUDLACZ': 0,
    'KUDLAK': 0,
    'KUDLER': 0,
    'KUDO': 0,
    'KUDRA': 0,
    'KUDRICK': 0,
    'KUDRNA': 0,
    'KUDRON': 0,
    'KUDUK': 0,
    'KUDZIA': 0,
    'KUE': 0,
    'KUEBEL': 0,
    'KUEBELBECK': 0,
    'KUEBER': 0,
    'KUEBLER': 0,
    'KUEBRICH': 0,
    'KUECHENMEISTER': 0,
    'KUECHLE': 0,
    'KUECHLER': 0,
    'KUECK': 0,
    'KUECKEN': 0,
    'KUECKER': 0,
    'KUEFFER': 0,
    'KUEFFNER': 0,
    'KUEFLER': 0,
    'KUEFNER': 0,
    'KUEGLER': 0,
    'KUEHL': 0,
    'KUEHLER': 0,
    'KUEHLING': 0,
    'KUEHN': 0,
    'KUEHNE': 0,
    'KUEHNEL': 0,
    'KUEHNER': 0,
    'KUEHNERT': 0,
    'KUEHNI': 0,
    'KUEHNL': 0,
    'KUEHNLE': 0,
    'KUEKER': 0,
    'KUELBS': 0,
    'KUELKER': 0,
    'KUELPER': 0,
    'KUEMMEL': 0,
    'KUEMMERLE': 0,
    'KUEMPEL': 0,
    'KUEMPER': 0,
    'KUEN': 0,
    'KUENEMAN': 0,
    'KUENN': 0,
    'KUENNE': 0,
    'KUENNEN': 0,
    'KUENNING': 0,
    'KUENSTER': 0,
    'KUENSTLER': 0,
    'KUENTZ': 0,
    'KUENY': 0,
    'KUENZ': 0,
    'KUENZEL': 0,
    'KUENZER': 0,
    'KUENZI': 0,
    'KUENZLE': 0,
    'KUENZLER': 0,
    'KUENZLI': 0,
    'KUEPER': 0,
    'KUEPFER': 0,
    'KUEPPER': 0,
    'KUEPPERS': 0,
    'KUERBITZ': 0,
    'KUERSCHNER': 0,
    'KUES': 0,
    'KUESEL': 0,
    'KUESER': 0,
    'KUESPERT': 0,
    'KUEST': 0,
    'KUESTER': 0,
    'KUETER': 0,
    'KUETHE': 0,
    'KUETHER': 0,
    'KUETTEL': 0,
    'KUFAHL': 0,
    'KUFEL': 0,
    'KUFELDT': 0,
    'KUFFEL': 0,
    'KUFFER': 0,
    'KUFFLER': 0,
    'KUFFNER': 0,
    'KUFNER': 0,
    'KUFRIN': 0,
    'KUFTA': 0,
    'KUGA': 0,
    'KUGEL': 0,
    'KUGELMAN': 0,
    'KUGLE': 0,
    'KUGLER': 0,
    'KUGLIN': 0,
    'KUH': 0,
    'KUHA': 0,
    'KUHANECK': 0,
    'KUHAR': 0,
    'KUHARICH': 0,
    'KUHARIK': 0,
    'KUHARSKI': 0,
    'KUHBANDER': 0,
    'KUHEL': 0,
    'KUHENS': 0,
    'KUHFAHL': 0,
    'KUHFUSS': 0,
    'KUHL': 0,
    'KUHLE': 0,
    'KUHLEMEIER': 0,
    'KUHLENSCHMIDT': 0,
    'KUHLER': 0,
    'KUHLERS': 0,
    'KUHLKE': 0,
    'KUHLMAN': 0,
    'KUHLMANN': 0,
    'KUHLMEIER': 0,
    'KUHLMEY': 0,
    'KUHLOW': 0,
    'KUHLS': 0,
    'KUHLWEIN': 0,
    'KUHMAN': 0,
    'KUHN': 0,
    'KUHNAU': 0,
    'KUHNE': 0,
    'KUHNEL': 0,
    'KUHNELL': 0,
    'KUHNEN': 0,
    'KUHNER': 0,
    'KUHNERT': 0,
    'KUHNHAUSEN': 0,
    'KUHNHENN': 0,
    'KUHNKE': 0,
    'KUHNLE': 0,
    'KUHNLY': 0,
    'KUHNS': 0,
    'KUHR': 0,
    'KUHRE': 0,
    'KUHRT': 0,
    'KUHS': 0,
    'KUHSE': 0,
    'KUHTA': 0,
    'KUI': 0,
    'KUIK': 0,
    'KUIKEN': 0,
    'KUILAN': 0,
    'KUIPER': 0,
    'KUIPERS': 0,
    'KUISLE': 0,
    'KUJAK': 0,
    'KUJALA': 0,
    'KUJAN': 0,
    'KUJAT': 0,
    'KUJATH': 0,
    'KUJAVA': 0,
    'KUJAWA': 0,
    'KUJAWSKI': 0,
    'KUK': 0,
    'KUKA': 0,
    'KUKACKA': 0,
    'KUKAHIKO': 0,
    'KUKAJ': 0,
    'KUKAL': 0,
    'KUKAN': 0,
    'KUKAWSKI': 0,
    'KUKER': 0,
    'KUKES': 0,
    'KUKIC': 0,
    'KUKICH': 0,
    'KUKIELKA': 0,
    'KUKKONEN': 0,
    'KUKLA': 0,
    'KUKLENSKI': 0,
    'KUKLEWICZ': 0,
    'KUKLINSKI': 0,
    'KUKLIS': 0,
    'KUKLISH': 0,
    'KUKLOK': 0,
    'KUKOL': 0,
    'KUKOR': 0,
    'KUKOWSKI': 0,
    'KUKRAL': 0,
    'KUKREJA': 0,
    'KUKTA': 0,
    'KUKUCHKA': 0,
    'KUKUCKA': 0,
    'KUKUK': 0,
    'KUKULA': 0,
    'KUKULKA': 0,
    'KUKULSKI': 0,
    'KUKURA': 0,
    'KULA': 0,
    'KULACH': 0,
    'KULACZ': 0,
    'KULAGA': 0,
    'KULAK': 0,
    'KULAKOWSKI': 0,
    'KULAS': 0,
    'KULASA': 0,
    'KULAWIAK': 0,
    'KULB': 0,
    'KULBACK': 0,
    'KULBACKI': 0,
    'KULBERG': 0,
    'KULBETH': 0,
    'KULCHAR': 0,
    'KULCSAR': 0,
    'KULCZAK': 0,
    'KULCZYCKI': 0,
    'KULCZYK': 0,
    'KULE': 0,
    'KULEK': 0,
    'KULENKAMP': 0,
    'KULESA': 0,
    'KULESZ': 0,
    'KULESZA': 0,
    'KULHA': 0,
    'KULHANEK': 0,
    'KULHAVY': 0,
    'KULICH': 0,
    'KULICK': 0,
    'KULIG': 0,
    'KULIGOWSKI': 0,
    'KULIK': 0,
    'KULIKOV': 0,
    'KULIKOWSKI': 0,
    'KULIN': 0,
    'KULINA': 0,
    'KULINSKI': 0,
    'KULIS': 0,
    'KULISEK': 0,
    'KULISH': 0,
    'KULJANIN': 0,
    'KULJIS': 0,
    'KULJU': 0,
    'KULKA': 0,
    'KULKARNI': 0,
    'KULL': 0,
    'KULLA': 0,
    'KULLANDER': 0,
    'KULLAR': 0,
    'KULLAS': 0,
    'KULLBERG': 0,
    'KULLE': 0,
    'KULLEN': 0,
    'KULLER': 0,
    'KULLGREN': 0,
    'KULLING': 0,
    'KULLMAN': 0,
    'KULLMANN': 0,
    'KULM': 0,
    'KULMA': 0,
    'KULMAN': 0,
    'KULON': 0,
    'KULOVITZ': 0,
    'KULOW': 0,
    'KULP': 0,
    'KULPA': 0,
    'KULPER': 0,
    'KULPINSKI': 0,
    'KULSETH': 0,
    'KULSTAD': 0,
    'KULT': 0,
    'KULTGEN': 0,
    'KULWICKI': 0,
    'KULYK': 0,
    'KULYNYCH': 0,
    'KULZER': 0,
    'KUM': 0.9584664536741214,
    'KUMA': 0,
    'KUMAGAI': 0,
    'KUMAI': 0,
    'KUMAMOTO': 0,
    'KUMAR': 0,
    'KUMARAN': 0,
    'KUMARI': 0,
    'KUMASAKA': 0,
    'KUMBALEK': 0,
    'KUMBERA': 0,
    'KUMBIER': 0,
    'KUME': 0,
    'KUMER': 0,
    'KUMFER': 0,
    'KUMI': 0,
    'KUMIEGA': 0,
    'KUMIN': 0,
    'KUMKE': 0,
    'KUMLE': 0,
    'KUMLER': 0,
    'KUMLIEN': 0,
    'KUMLIN': 0,
    'KUMM': 0,
    'KUMMER': 0,
    'KUMMERER': 0,
    'KUMMERFELDT': 0,
    'KUMMEROW': 0,
    'KUMMET': 0,
    'KUMNICK': 0,
    'KUMOR': 0,
    'KUMP': 0,
    'KUMPE': 0,
    'KUMPEL': 0,
    'KUMPF': 0,
    'KUMPULA': 0,
    'KUMRO': 0,
    'KUMROW': 0,
    'KUN': 0,
    'KUNA': 0,
    'KUNAK': 0,
    'KUNAR': 0,
    'KUNARD': 0,
    'KUNATH': 0,
    'KUNAU': 0,
    'KUNBERGER': 0,
    'KUNC': 0,
    'KUNCE': 0,
    'KUNCH': 0,
    'KUNCL': 0,
    'KUNDA': 0,
    'KUNDE': 0,
    'KUNDEL': 0,
    'KUNDER': 0,
    'KUNDERT': 0,
    'KUNDINGER': 0,
    'KUNDLA': 0,
    'KUNDRA': 0,
    'KUNDRAT': 0,
    'KUNDTZ': 0,
    'KUNDU': 0,
    'KUNEMAN': 0,
    'KUNER': 0,
    'KUNERT': 0,
    'KUNERTH': 0,
    'KUNES': 0,
    'KUNESH': 0,
    'KUNEY': 0,
    'KUNG': 0,
    'KUNHARDT': 0,
    'KUNI': 0,
    'KUNICH': 0,
    'KUNICK': 0,
    'KUNICKI': 0,
    'KUNIHIRO': 0,
    'KUNIK': 0,
    'KUNIMOTO': 0,
    'KUNIMURA': 0,
    'KUNIN': 0,
    'KUNIS': 0,
    'KUNISAKI': 0,
    'KUNISCH': 0,
    'KUNISH': 0,
    'KUNISHIGE': 0,
    'KUNITAKE': 0,
    'KUNITZ': 0,
    'KUNIYOSHI': 0,
    'KUNK': 0,
    'KUNKA': 0,
    'KUNKE': 0,
    'KUNKEL': 0,
    'KUNKLE': 0,
    'KUNKLEMAN': 0,
    'KUNKLER': 0,
    'KUNN': 0,
    'KUNNATH': 0,
    'KUNNEMANN': 0,
    'KUNNEN': 0,
    'KUNO': 0,
    'KUNS': 0,
    'KUNSCH': 0,
    'KUNSELMAN': 0,
    'KUNSHIER': 0,
    'KUNSMAN': 0,
    'KUNST': 0,
    'KUNSTLER': 0,
    'KUNSTMAN': 0,
    'KUNSTMANN': 0,
    'KUNTER': 0,
    'KUNTZ': 0,
    'KUNTZE': 0,
    'KUNTZELMAN': 0,
    'KUNTZMAN': 0,
    'KUNTZSCH': 0,
    'KUNY': 0,
    'KUNZ': 0,
    'KUNZA': 0,
    'KUNZE': 0,
    'KUNZELMAN': 0,
    'KUNZER': 0,
    'KUNZI': 0,
    'KUNZIE': 0,
    'KUNZLER': 0,
    'KUNZMAN': 0,
    'KUNZMANN': 0,
    'KUNZWEILER': 0,
    'KUO': 0,
    'KUOCH': 0,
    'KUON': 0,
    'KUONEN': 0,
    'KUPAU': 0,
    'KUPCHIK': 0,
    'KUPCHO': 0,
    'KUPCZAK': 0,
    'KUPCZYK': 0,
    'KUPEC': 0,
    'KUPELIAN': 0,
    'KUPER': 0,
    'KUPERBERG': 0,
    'KUPERMAN': 0,
    'KUPERSMITH': 0,
    'KUPERSTEIN': 0,
    'KUPERUS': 0,
    'KUPETZ': 0,
    'KUPFER': 0,
    'KUPFERBERG': 0,
    'KUPFERER': 0,
    'KUPFERMAN': 0,
    'KUPFERSCHMID': 0,
    'KUPFERSCHMIDT': 0,
    'KUPFNER': 0,
    'KUPHAL': 0,
    'KUPIEC': 0,
    'KUPINSKI': 0,
    'KUPISZEWSKI': 0,
    'KUPITZ': 0,
    'KUPKA': 0,
    'KUPKE': 0,
    'KUPNIEWSKI': 0,
    'KUPP': 0,
    'KUPPER': 0,
    'KUPPERMAN': 0,
    'KUPPINGER': 0,
    'KUPPLER': 0,
    'KUPRES': 0,
    'KUPRIS': 0,
    'KUPSCH': 0,
    'KUPSKI': 0,
    'KUPSKY': 0,
    'KUPSTAS': 0,
    'KUPTZ': 0,
    'KUR': 0,
    'KURA': 0,
    'KURAK': 0,
    'KURAMOTO': 0,
    'KURAN': 0,
    'KURANI': 0,
    'KURANT': 0,
    'KURAS': 0,
    'KURASH': 0,
    'KURASHIGE': 0,
    'KURASHIMA': 0,
    'KURASZ': 0,
    'KURATA': 0,
    'KURBAN': 0,
    'KURBIS': 0,
    'KURCZ': 0,
    'KURCZEWSKI': 0,
    'KURDI': 0,
    'KURDYLA': 0,
    'KURDZIEL': 0,
    'KURE': 0,
    'KUREK': 0,
    'KURETICH': 0,
    'KUREY': 0,
    'KURFESS': 0,
    'KURFMAN': 0,
    'KURGAN': 0,
    'KURI': 0,
    'KURIA': 0,
    'KURIAKOSE': 0,
    'KURIAN': 0,
    'KURIC': 0,
    'KURIEN': 0,
    'KURIGER': 0,
    'KURIHARA': 0,
    'KURILKO': 0,
    'KURILLA': 0,
    'KURIN': 0,
    'KURINSKY': 0,
    'KURISH': 0,
    'KURISU': 0,
    'KURITA': 0,
    'KURITZ': 0,
    'KURIYAMA': 0,
    'KURK': 0,
    'KURKA': 0,
    'KURKER': 0,
    'KURKIEWICZ': 0,
    'KURKJIAN': 0,
    'KURKO': 0,
    'KURKOSKI': 0,
    'KURKOWSKI': 0,
    'KURLAND': 0,
    'KURLANDER': 0,
    'KURLE': 0,
    'KURLEY': 0,
    'KURLINSKI': 0,
    'KURMAN': 0,
    'KURN': 0,
    'KURNAT': 0,
    'KURNIAWAN': 0,
    'KURNICK': 0,
    'KURNIK': 0,
    'KURNS': 0,
    'KURODA': 0,
    'KUROIWA': 0,
    'KUROKAWA': 0,
    'KUROKI': 0,
    'KURON': 0,
    'KUROSAKI': 0,
    'KUROSAWA': 0,
    'KUROSE': 0,
    'KUROSKI': 0,
    'KUROSKY': 0,
    'KUROSU': 0,
    'KUROWSKI': 0,
    'KURPIEL': 0,
    'KURPIEWSKI': 0,
    'KURR': 0,
    'KURRASCH': 0,
    'KURRE': 0,
    'KURRLE': 0,
    'KURRUS': 0,
    'KURRY': 0,
    'KURSCHNER': 0,
    'KURSZEWSKI': 0,
    'KURT': 0.9927942353883107,
    'KURTA': 0,
    'KURTEN': 0,
    'KURTENBACH': 0,
    'KURTH': 0,
    'KURTI': 0,
    'KURTIC': 0,
    'KURTIN': 0,
    'KURTIS': 0.9857612267250822,
    'KURTOVIC': 0,
    'KURTS': 0,
    'KURTTI': 0,
    'KURTY': 0,
    'KURTYKA': 0,
    'KURTZ': 0,
    'KURTZE': 0,
    'KURTZER': 0,
    'KURTZHALS': 0,
    'KURTZMAN': 0,
    'KURTZWEIL': 0,
    'KURUC': 0,
    'KURUCZ': 0,
    'KURUP': 0,
    'KURUTZ': 0,
    'KURUVILLA': 0,
    'KURVERS': 0,
    'KURY': 0,
    'KURYLA': 0,
    'KURYLO': 0,
    'KURZ': 0,
    'KURZAWA': 0,
    'KURZAWSKI': 0,
    'KURZDORFER': 0,
    'KURZEJA': 0,
    'KURZENBERGER': 0,
    'KURZENDOERFER': 0,
    'KURZER': 0,
    'KURZHAL': 0,
    'KURZHALS': 0,
    'KURZINSKI': 0,
    'KURZMAN': 0,
    'KURZWEIL': 0,
    'KURZYNA': 0,
    'KURZYNSKI': 0,
    'KUS': 0,
    'KUSA': 0,
    'KUSAK': 0,
    'KUSAKA': 0,
    'KUSANO': 0,
    'KUSAR': 0,
    'KUSCH': 0,
    'KUSCHE': 0,
    'KUSCHEL': 0,
    'KUSE': 0,
    'KUSEK': 0,
    'KUSEL': 0,
    'KUSER': 0,
    'KUSH': 0,
    'KUSHEL': 0,
    'KUSHER': 0,
    'KUSHI': 0,
    'KUSHION': 0,
    'KUSHLAN': 0,
    'KUSHMAN': 0,
    'KUSHMAUL': 0,
    'KUSHNER': 0,
    'KUSHNICK': 0,
    'KUSHNIR': 0,
    'KUSI': 0,
    'KUSIAK': 0,
    'KUSIC': 0,
    'KUSICK': 0,
    'KUSIK': 0,
    'KUSILEK': 0,
    'KUSKA': 0,
    'KUSKE': 0,
    'KUSKIE': 0,
    'KUSKO': 0,
    'KUSKOWSKI': 0,
    'KUSKY': 0,
    'KUSLER': 0,
    'KUSMA': 0,
    'KUSMAN': 0,
    'KUSMIERSKI': 0,
    'KUSMIERZ': 0,
    'KUSNER': 0,
    'KUSNIER': 0,
    'KUSNIERZ': 0,
    'KUSNIR': 0,
    'KUSPA': 0,
    'KUSPER': 0,
    'KUSS': 0,
    'KUSSEROW': 0,
    'KUSSMAN': 0,
    'KUSSMANN': 0,
    'KUSSMAUL': 0,
    'KUSSOW': 0,
    'KUSSY': 0,
    'KUST': 0,
    'KUSTER': 0,
    'KUSTERER': 0,
    'KUSTERS': 0,
    'KUSTES': 0,
    'KUSTIN': 0,
    'KUSTKA': 0,
    'KUSTRA': 0,
    'KUSUMA': 0,
    'KUSUMOTO': 0,
    'KUSUNOKI': 0,
    'KUSY': 0,
    'KUSZ': 0,
    'KUSZAK': 0,
    'KUSZEWSKI': 0,
    'KUSZMAUL': 0,
    'KUSZYNSKI': 0,
    'KUT': 0,
    'KUTA': 0,
    'KUTAC': 0,
    'KUTACH': 0,
    'KUTAS': 0,
    'KUTAY': 0,
    'KUTCH': 0,
    'KUTCHER': 0,
    'KUTCHERA': 0,
    'KUTCHEY': 0,
    'KUTCHMAN': 0,
    'KUTE': 0,
    'KUTELLA': 0,
    'KUTER': 0,
    'KUTH': 0,
    'KUTI': 0,
    'KUTIL': 0,
    'KUTILEK': 0,
    'KUTINA': 0,
    'KUTIS': 0,
    'KUTKA': 0,
    'KUTLER': 0,
    'KUTNER': 0,
    'KUTNEY': 0,
    'KUTSAR': 0,
    'KUTSCH': 0,
    'KUTSCHBACH': 0,
    'KUTSCHE': 0,
    'KUTSCHER': 0,
    'KUTSCHERA': 0,
    'KUTSCHKE': 0,
    'KUTSKO': 0,
    'KUTT': 0,
    'KUTTER': 0,
    'KUTTLER': 0,
    'KUTTNER': 0,
    'KUTTY': 0,
    'KUTY': 0,
    'KUTYLA': 0,
    'KUTZ': 0,
    'KUTZER': 0,
    'KUTZKE': 0,
    'KUTZLER': 0,
    'KUTZLI': 0,
    'KUTZMAN': 0,
    'KUTZNER': 0,
    'KUUSISTO': 0,
    'KUWABARA': 0,
    'KUWADA': 0,
    'KUWAHARA': 0,
    'KUWATA': 0,
    'KUWAYE': 0,
    'KUWIK': 0,
    'KUXHAUSEN': 0,
    'KUY': 0,
    'KUYERS': 0,
    'KUYKENDALL': 0,
    'KUYKENDOLL': 0,
    'KUYLEN': 0,
    'KUYPER': 0,
    'KUYPERS': 0,
    'KUYRKENDALL': 0,
    'KUZA': 0,
    'KUZAK': 0,
    'KUZARA': 0,
    'KUZAVA': 0,
    'KUZDZAL': 0,
    'KUZEL': 0,
    'KUZELKA': 0,
    'KUZEMCHAK': 0,
    'KUZEMKA': 0,
    'KUZIA': 0,
    'KUZIAK': 0,
    'KUZIEL': 0,
    'KUZIO': 0,
    'KUZMA': 0,
    'KUZMAK': 0,
    'KUZMAN': 0,
    'KUZMENKO': 0,
    'KUZMIAK': 0,
    'KUZMIC': 0,
    'KUZMICH': 0,
    'KUZMICK': 0,
    'KUZMICKI': 0,
    'KUZMIK': 0,
    'KUZMIN': 0,
    'KUZMINSKI': 0,
    'KUZNAR': 0,
    'KUZNETSOV': 0,
    'KUZNETSOVA': 0,
    'KUZNIA': 0,
    'KUZNIAR': 0,
    'KUZNICKI': 0,
    'KUZNIEWSKI': 0,
    'KUZNIK': 0,
    'KUZO': 0,
    'KUZYK': 0,
    'KVALE': 0,
    'KVALHEIM': 0,
    'KVAM': 0,
    'KVAMME': 0,
    'KVAPIL': 0,
    'KVASNICKA': 0,
    'KVETON': 0,
    'KVIDERA': 0,
    'KVISTAD': 0,
    'KVITEK': 0,
    'KWA': 0,
    'KWAAK': 0,
    'KWAIT': 0,
    'KWAK': 0,
    'KWAKYE': 0,
    'KWAN': 0,
    'KWANG': 0,
    'KWANT': 0,
    'KWAPICH': 0,
    'KWAPIS': 0,
    'KWARCIANY': 0,
    'KWARTA': 0,
    'KWARTENG': 0,
    'KWARTLER': 0,
    'KWAS': 0,
    'KWASIGROCH': 0,
    'KWASNIAK': 0,
    'KWASNICKI': 0,
    'KWASNIEWSKI': 0,
    'KWASNIK': 0,
    'KWASNY': 0,
    'KWAST': 0,
    'KWEDER': 0,
    'KWEE': 0,
    'KWEI': 0,
    'KWEK': 0,
    'KWEKEL': 0,
    'KWEON': 0,
    'KWIAT': 0,
    'KWIATEK': 0,
    'KWIATKOSKI': 0,
    'KWIATKOWSKI': 0,
    'KWIECIEN': 0,
    'KWIECINSKI': 0,
    'KWIEK': 0,
    'KWIK': 0,
    'KWILOS': 0,
    'KWIT': 0,
    'KWITOWSKI': 0,
    'KWOCK': 0,
    'KWOK': 0,
    'KWOKA': 0,
    'KWOLEK': 0,
    'KWON': 0,
    'KWONG': 0,
    'KWUN': 0,
    'KY': 0,
    'KYAN': 0,
    'KYAW': 0,
    'KYBURZ': 0,
    'KYDD': 0,
    'KYE': 0,
    'KYEI': 0,
    'KYER': 0,
    'KYES': 0,
    'KYGER': 0,
    'KYHL': 0,
    'KYHN': 0,
    'KYI': 0,
    'KYKER': 0,
    'KYLA': 1,
    'KYLANDER': 0,
    'KYLE': 0.961425724000469,
    'KYLEE': 1,
    'KYLER': 0,
    'KYLES': 0,
    'KYLIE': 1,
    'KYLLO': 0,
    'KYLLONEN': 0,
    'KYM': 1,
    'KYMBERLY': 1,
    'KYMER': 0,
    'KYNARD': 0,
    'KYNASTON': 0,
    'KYNE': 0,
    'KYNER': 0,
    'KYNERD': 0,
    'KYOKO': 1,
    'KYONG': 0.99009900990099,
    'KYPER': 0,
    'KYRA': 1,
    'KYRE': 0,
    'KYRIACOU': 0,
    'KYRIAKAKIS': 0,
    'KYRIAKIDES': 0,
    'KYRIAKOPOULOS': 0,
    'KYRIAKOS': 0,
    'KYRIAZIS': 0,
    'KYRISS': 0,
    'KYRO': 0,
    'KYROS': 0,
    'KYSAR': 0,
    'KYSER': 0,
    'KYSOR': 0,
    'KYTE': 0,
    'KYTLE': 0,
    'KYTOLA': 0,
    'KYTTA': 0,
    'KYTTLE': 0,
    'KYU': 0,
    'KYUNG': 0.9779951100244498,
    'KYZAR': 0,
    'KYZER': 0,
    'LA': 0,
    'LAA': 0,
    'LAABS': 0,
    'LAACK': 0,
    'LAAK': 0,
    'LAAKE': 0,
    'LAAKER': 0,
    'LAAKSO': 0,
    'LAAKSONEN': 0,
    'LAARMAN': 0,
    'LAAS': 0,
    'LAASE': 0,
    'LAATSCH': 0,
    'LAATZ': 0,
    'LAB': 0,
    'LABA': 0,
    'LABABIDI': 0,
    'LABADIE': 0,
    'LABADY': 0,
    'LABAFF': 0,
    'LABAHN': 0,
    'LABAJ': 0,
    'LABAK': 0,
    'LABAN': 0,
    'LABANCA': 0,
    'LABANOWSKI': 0,
    'LABANT': 0,
    'LABAO': 0,
    'LABAR': 0,
    'LABARBA': 0,
    'LABARBARA': 0,
    'LABARBERA': 0,
    'LABARCA': 0,
    'LABARE': 0,
    'LABARGE': 0,
    'LABARR': 0,
    'LABARRE': 0,
    'LABARRIE': 0,
    'LABAS': 0,
    'LABASAN': 0,
    'LABASH': 0,
    'LABASS': 0,
    'LABASTIDA': 0,
    'LABAT': 0,
    'LABATE': 0,
    'LABATO': 0,
    'LABATT': 0,
    'LABATTE': 0,
    'LABATUT': 0,
    'LABAU': 0,
    'LABAUVE': 0,
    'LABAW': 0,
    'LABAY': 0,
    'LABAYEN': 0,
    'LABB': 0,
    'LABBADIA': 0,
    'LABBAN': 0,
    'LABBATE': 0,
    'LABBE': 0,
    'LABBEE': 0,
    'LABBIE': 0,
    'LABBY': 0,
    'LABE': 0,
    'LABEAN': 0,
    'LABEAU': 0,
    'LABEAUD': 0,
    'LABECK': 0,
    'LABEDZ': 0,
    'LABEE': 0,
    'LABEFF': 0,
    'LABEL': 0,
    'LABELL': 0,
    'LABELLA': 0,
    'LABELLARTE': 0,
    'LABELLE': 0,
    'LABELLO': 0,
    'LABENNE': 0,
    'LABENSKI': 0,
    'LABENZ': 0,
    'LABER': 0,
    'LABERDEE': 0,
    'LABERGE': 0,
    'LABERT': 0,
    'LABERTA': 0,
    'LABERTEW': 0,
    'LABES': 0,
    'LABETH': 0,
    'LABHART': 0,
    'LABIAK': 0,
    'LABIANCA': 0,
    'LABIANCO': 0,
    'LABIB': 0,
    'LABICHE': 0,
    'LABIER': 0,
    'LABIK': 0,
    'LABIN': 0,
    'LABINE': 0,
    'LABINSKI': 0,
    'LABIOSA': 0,
    'LABISSIERE': 0,
    'LABISSONIERE': 0,
    'LABIT': 0,
    'LABITA': 0,
    'LABLANC': 0,
    'LABLANCE': 0,
    'LABLUE': 0,
    'LABNO': 0,
    'LABO': 0,
    'LABOARD': 0,
    'LABODA': 0,
    'LABOE': 0,
    'LABOISSONNIERE': 0,
    'LABOMBARD': 0,
    'LABON': 0,
    'LABONNE': 0,
    'LABONTE': 0,
    'LABONTY': 0,
    'LABONVILLE': 0,
    'LABOO': 0,
    'LABOON': 0,
    'LABOONE': 0,
    'LABOR': 0,
    'LABORDE': 0,
    'LABORE': 0,
    'LABORIE': 0,
    'LABORIN': 0,
    'LABORN': 0,
    'LABORTE': 0,
    'LABOSCO': 0,
    'LABOSKY': 0,
    'LABOSSIERE': 0,
    'LABOUBE': 0,
    'LABOUNTY': 0,
    'LABOUR': 0,
    'LABOURDETTE': 0,
    'LABOUVE': 0,
    'LABOVE': 0,
    'LABOVITZ': 0,
    'LABOW': 0,
    'LABOWSKI': 0,
    'LABOY': 0,
    'LABOZZETTA': 0,
    'LABRA': 0,
    'LABRADA': 0,
    'LABRADO': 0,
    'LABRADOR': 0,
    'LABRAKE': 0,
    'LABRANCH': 0,
    'LABRANCHE': 0,
    'LABRANT': 0,
    'LABRASCA': 0,
    'LABRASH': 0,
    'LABRE': 0,
    'LABREC': 0,
    'LABRECHE': 0,
    'LABRECK': 0,
    'LABRECQUE': 0,
    'LABREE': 0,
    'LABRENZ': 0,
    'LABRIE': 0,
    'LABRIER': 0,
    'LABRIOLA': 0,
    'LABRON': 0,
    'LABROSSE': 0,
    'LABROT': 0,
    'LABROUSSE': 0,
    'LABROZZI': 0,
    'LABRUM': 0,
    'LABRUNA': 0,
    'LABRUNO': 0,
    'LABRUYERE': 0,
    'LABRUZZO': 0,
    'LABRY': 0,
    'LABRYER': 0,
    'LABS': 0,
    'LABUA': 0,
    'LABUDA': 0,
    'LABUDDE': 0,
    'LABUE': 0,
    'LABUFF': 0,
    'LABUGUEN': 0,
    'LABUHN': 0,
    'LABUN': 0,
    'LABUNSKI': 0,
    'LABUS': 0,
    'LABUTE': 0,
    'LABUZ': 0,
    'LAC': 0,
    'LACA': 0,
    'LACADEN': 0,
    'LACAGNINA': 0,
    'LACAILLADE': 0,
    'LACAILLE': 0,
    'LACALAMITA': 0,
    'LACAMBRA': 0,
    'LACAMERA': 0,
    'LACANILAO': 0,
    'LACANLALE': 0,
    'LACANNE': 0,
    'LACAP': 0,
    'LACAPRA': 0,
    'LACAPRIA': 0,
    'LACAR': 0,
    'LACARA': 0,
    'LACARIA': 0,
    'LACARRA': 0,
    'LACARRUBBA': 0,
    'LACARTE': 0,
    'LACAS': 0,
    'LACASCIA': 0,
    'LACASSE': 0,
    'LACATENA': 0,
    'LACAVA': 0,
    'LACAVERA': 0,
    'LACAYO': 0,
    'LACAZE': 0,
    'LACE': 0,
    'LACEFIELD': 0,
    'LACEK': 0,
    'LACELLE': 0,
    'LACEN': 0,
    'LACER': 0,
    'LACERDA': 0,
    'LACERENZA': 0,
    'LACERNA': 0,
    'LACERRA': 0,
    'LACERTE': 0,
    'LACEWELL': 0,
    'LACEY': 0.7317073170731708,
    'LACH': 0,
    'LACHANCE': 0,
    'LACHAPELL': 0,
    'LACHAPELLE': 0,
    'LACHAPPELLE': 0,
    'LACHARITE': 0,
    'LACHAT': 0,
    'LACHCIK': 0,
    'LACHELLE': 1,
    'LACHER': 0,
    'LACHEY': 0,
    'LACHICA': 0,
    'LACHINA': 0,
    'LACHINO': 0,
    'LACHMAN': 0,
    'LACHMANN': 0,
    'LACHNER': 0,
    'LACHNEY': 0,
    'LACHNIT': 0,
    'LACHOWICZ': 0,
    'LACHOWITZER': 0,
    'LACHOWSKI': 0,
    'LACHOWSKY': 0,
    'LACHUT': 0,
    'LACI': 1,
    'LACIE': 1,
    'LACINA': 0,
    'LACINSKI': 0,
    'LACIS': 0,
    'LACIVITA': 0,
    'LACK': 0,
    'LACKAS': 0,
    'LACKE': 0,
    'LACKER': 0,
    'LACKEY': 0,
    'LACKI': 0,
    'LACKIE': 0,
    'LACKLAND': 0,
    'LACKMAN': 0,
    'LACKMANN': 0,
    'LACKNER': 0,
    'LACKNEY': 0,
    'LACKO': 0,
    'LACKORE': 0,
    'LACKOVIC': 0,
    'LACKOWSKI': 0,
    'LACKS': 0,
    'LACKY': 0,
    'LACLAIR': 0,
    'LACLAIRE': 0,
    'LACNY': 0,
    'LACO': 0,
    'LACOCK': 0,
    'LACOE': 0,
    'LACOGNATA': 0,
    'LACOLLA': 0,
    'LACOMB': 0,
    'LACOMBE': 0,
    'LACOME': 0,
    'LACON': 0,
    'LACONTE': 0,
    'LACOPPOLA': 0,
    'LACORAZZA': 0,
    'LACORE': 0,
    'LACORTE': 0,
    'LACOSS': 0,
    'LACOSSE': 0,
    'LACOST': 0,
    'LACOSTA': 0,
    'LACOSTE': 0,
    'LACOUNT': 0,
    'LACOUR': 0,
    'LACOURSE': 0,
    'LACOURSIERE': 0,
    'LACOURT': 0,
    'LACOUTURE': 0,
    'LACOVARA': 0,
    'LACOY': 0,
    'LACQUEMENT': 0,
    'LACRESHA': 1,
    'LACROCE': 0,
    'LACROIX': 0,
    'LACRONE': 0,
    'LACROSS': 0,
    'LACROSSE': 0,
    'LACRUE': 0,
    'LACRUZ': 0,
    'LACSAMANA': 0,
    'LACSINA': 0,
    'LACSON': 0,
    'LACUE': 0,
    'LACUESTA': 0,
    'LACY': 0.6117647058823529,
    'LACZ': 0,
    'LACZKO': 0,
    'LACZKOWSKI': 0,
    'LACZYNSKI': 0,
    'LAD': 0,
    'LADA': 0,
    'LADAGE': 0,
    'LADANYI': 0,
    'LADAO': 0,
    'LADAS': 0,
    'LADAWN': 1,
    'LADAY': 0,
    'LADD': 0,
    'LADDEN': 0,
    'LADDUSAW': 0,
    'LADE': 0,
    'LADEAU': 0,
    'LADEAUX': 0,
    'LADEHOFF': 0,
    'LADEIRA': 0,
    'LADELFA': 0,
    'LADELL': 0,
    'LADELY': 0,
    'LADEMAN': 0,
    'LADEMANN': 0,
    'LADEN': 0,
    'LADENBURG': 0,
    'LADENBURGER': 0,
    'LADENDORF': 0,
    'LADENHEIM': 0,
    'LADENSACK': 0,
    'LADER': 0,
    'LADERA': 0,
    'LADERACH': 0,
    'LADERER': 0,
    'LADERMAN': 0,
    'LADEROUTE': 0,
    'LADESIC': 0,
    'LADEW': 0,
    'LADEWIG': 0,
    'LADHA': 0,
    'LADHANI': 0,
    'LADIA': 0,
    'LADICK': 0,
    'LADIEU': 0,
    'LADIG': 0,
    'LADIK': 0,
    'LADIKA': 0,
    'LADIN': 0,
    'LADINES': 0,
    'LADING': 0,
    'LADINO': 0,
    'LADISH': 0,
    'LADLEE': 0,
    'LADLEY': 0,
    'LADMIRAULT': 0,
    'LADNER': 0,
    'LADNIER': 0,
    'LADO': 0,
    'LADONNA': 1,
    'LADOUCER': 0,
    'LADOUCEUR': 0,
    'LADOUX': 0,
    'LADOW': 0,
    'LADOWSKI': 0,
    'LADRA': 0,
    'LADRACH': 0,
    'LADRIDO': 0,
    'LADSON': 0,
    'LADU': 0,
    'LADUC': 0,
    'LADUCA': 0,
    'LADUCER': 0,
    'LADUE': 0,
    'LADUKE': 0,
    'LADWIG': 0,
    'LADY': 0.8333333333333334,
    'LADYGA': 0,
    'LADYMAN': 0,
    'LADZINSKI': 0,
    'LAE': 0,
    'LAEGER': 0,
    'LAEHN': 0,
    'LAEL': 0.9174311926605505,
    'LAEMMLE': 0,
    'LAES': 0,
    'LAESCH': 0,
    'LAESSIG': 0,
    'LAETHEM': 0,
    'LAETSCH': 0,
    'LAFACE': 0,
    'LAFAILLE': 0,
    'LAFAIRE': 0,
    'LAFAIVE': 0,
    'LAFALCE': 0,
    'LAFARGA': 0,
    'LAFARGE': 0,
    'LAFARGUE': 0,
    'LAFARY': 0,
    'LAFASO': 0,
    'LAFATA': 0,
    'LAFAUCI': 0,
    'LAFAURIE': 0,
    'LAFAVE': 0,
    'LAFAVER': 0,
    'LAFAVERS': 0,
    'LAFAVOR': 0,
    'LAFAVRE': 0,
    'LAFAY': 0,
    'LAFAYE': 0,
    'LAFAYETTE': 0,
    'LAFAZIA': 0,
    'LAFEBRE': 0,
    'LAFEMINA': 0,
    'LAFER': 0,
    'LAFERLA': 0,
    'LAFERNEY': 0,
    'LAFERRARA': 0,
    'LAFERRIERE': 0,
    'LAFERTE': 0,
    'LAFERTY': 0,
    'LAFEVER': 0,
    'LAFEVERS': 0,
    'LAFEVRE': 0,
    'LAFF': 0,
    'LAFFAN': 0,
    'LAFFER': 0,
    'LAFFERRE': 0,
    'LAFFERTY': 0,
    'LAFFEY': 0,
    'LAFFIN': 0,
    'LAFFITTE': 0,
    'LAFFLER': 0,
    'LAFFOON': 0,
    'LAFFREY': 0,
    'LAFIELD': 0,
    'LAFITTE': 0,
    'LAFKO': 0,
    'LAFLAIR': 0,
    'LAFLAM': 0,
    'LAFLAME': 0,
    'LAFLAMME': 0,
    'LAFLASH': 0,
    'LAFLECHE': 0,
    'LAFLEN': 0,
    'LAFLER': 0,
    'LAFLESH': 0,
    'LAFLEUR': 0,
    'LAFLEY': 0,
    'LAFLIN': 0,
    'LAFLOWER': 0,
    'LAFLUER': 0,
    'LAFNEAR': 0,
    'LAFOE': 0,
    'LAFOLLETT': 0,
    'LAFOLLETTE': 0,
    'LAFON': 0,
    'LAFOND': 0,
    'LAFONE': 0,
    'LAFONT': 0,
    'LAFONTAINE': 0,
    'LAFONTANT': 0,
    'LAFOON': 0,
    'LAFORCE': 0,
    'LAFORD': 0,
    'LAFORE': 0,
    'LAFOREST': 0,
    'LAFORET': 0,
    'LAFORGE': 0,
    'LAFORGIA': 0,
    'LAFORME': 0,
    'LAFORTE': 0,
    'LAFORTEZA': 0,
    'LAFORTUNE': 0,
    'LAFOSSE': 0,
    'LAFOUNTAIN': 0,
    'LAFOUNTAINE': 0,
    'LAFOUR': 0,
    'LAFOY': 0,
    'LAFRAMBOISE': 0,
    'LAFRANCA': 0,
    'LAFRANCE': 0,
    'LAFRANCHI': 0,
    'LAFRANCHISE': 0,
    'LAFRANCIS': 0,
    'LAFRANCOIS': 0,
    'LAFRATTA': 0,
    'LAFRENIER': 0,
    'LAFRENIERE': 0,
    'LAFRENTZ': 0,
    'LAFRENZ': 0,
    'LAFRINIERE': 0,
    'LAFROMBOIS': 0,
    'LAFROMBOISE': 0,
    'LAFUENTE': 0,
    'LAFUZE': 0,
    'LAGA': 0,
    'LAGACE': 0,
    'LAGACY': 0,
    'LAGALA': 0,
    'LAGALO': 0,
    'LAGALY': 0,
    'LAGAMBA': 0,
    'LAGAMBINA': 0,
    'LAGAN': 0,
    'LAGANA': 0,
    'LAGANIERE': 0,
    'LAGANO': 0,
    'LAGARD': 0,
    'LAGARDA': 0,
    'LAGARDE': 0,
    'LAGARES': 0,
    'LAGAS': 0,
    'LAGASCA': 0,
    'LAGASSE': 0,
    'LAGATTA': 0,
    'LAGATTUTA': 0,
    'LAGAZO': 0,
    'LAGE': 0,
    'LAGEMAN': 0,
    'LAGEMANN': 0,
    'LAGEN': 0,
    'LAGENOUR': 0,
    'LAGER': 0,
    'LAGERBERG': 0,
    'LAGERGREN': 0,
    'LAGERMAN': 0,
    'LAGERQUIST': 0,
    'LAGERSTEDT': 0,
    'LAGERSTROM': 0,
    'LAGERWEY': 0,
    'LAGES': 0,
    'LAGESON': 0,
    'LAGESSE': 0,
    'LAGESTEE': 0,
    'LAGGE': 0,
    'LAGGER': 0,
    'LAGIER': 0,
    'LAGINESS': 0,
    'LAGIOIA': 0,
    'LAGIOS': 0,
    'LAGLE': 0,
    'LAGLER': 0,
    'LAGMAN': 0,
    'LAGMAY': 0,
    'LAGNEAUX': 0,
    'LAGNESE': 0,
    'LAGO': 0,
    'LAGOA': 0,
    'LAGODA': 0,
    'LAGOE': 0,
    'LAGOMARSINO': 0,
    'LAGON': 0,
    'LAGONI': 0,
    'LAGOR': 0,
    'LAGORE': 0,
    'LAGORIO': 0,
    'LAGOS': 0,
    'LAGOW': 0,
    'LAGOWSKI': 0,
    'LAGOY': 0,
    'LAGPACAN': 0,
    'LAGRAND': 0,
    'LAGRANDE': 0,
    'LAGRANDEUR': 0,
    'LAGRANGE': 0,
    'LAGRANT': 0,
    'LAGRASSA': 0,
    'LAGRASTA': 0,
    'LAGRAVE': 0,
    'LAGRECA': 0,
    'LAGREE': 0,
    'LAGREGA': 0,
    'LAGREW': 0,
    'LAGRIMAS': 0,
    'LAGRO': 0,
    'LAGRONE': 0,
    'LAGROTTA': 0,
    'LAGROTTERIA': 0,
    'LAGROU': 0,
    'LAGROW': 0,
    'LAGRUA': 0,
    'LAGRUTTA': 0,
    'LAGUA': 0,
    'LAGUANA': 0,
    'LAGUARDIA': 0,
    'LAGUATAN': 0,
    'LAGUE': 0,
    'LAGUER': 0,
    'LAGUERRE': 0,
    'LAGUEUX': 0,
    'LAGUIRE': 0,
    'LAGUNA': 0,
    'LAGUNAS': 0,
    'LAGUNES': 0,
    'LAH': 0,
    'LAHA': 0,
    'LAHAIE': 0,
    'LAHAIR': 0,
    'LAHAISE': 0,
    'LAHALE': 0,
    'LAHAM': 0,
    'LAHANN': 0,
    'LAHAR': 0,
    'LAHART': 0,
    'LAHAY': 0,
    'LAHAYE': 0,
    'LAHDE': 0,
    'LAHENS': 0,
    'LAHER': 0,
    'LAHERA': 0,
    'LAHEY': 0,
    'LAHIFF': 0,
    'LAHIRI': 0,
    'LAHL': 0,
    'LAHM': 0,
    'LAHMAN': 0,
    'LAHMANN': 0,
    'LAHMERS': 0,
    'LAHMEYER': 0,
    'LAHMON': 0,
    'LAHN': 0,
    'LAHNA': 0,
    'LAHNER': 0,
    'LAHO': 0,
    'LAHODA': 0,
    'LAHODNY': 0,
    'LAHOMA': 1,
    'LAHOOD': 0,
    'LAHOUD': 0,
    'LAHOZ': 0,
    'LAHR': 0,
    'LAHREN': 0,
    'LAHRMAN': 0,
    'LAHRS': 0,
    'LAHTI': 0,
    'LAHTINEN': 0,
    'LAHUE': 0,
    'LAI': 0.34324942791762014,
    'LAIACONA': 0,
    'LAIB': 0,
    'LAIBLE': 0,
    'LAICH': 0,
    'LAICHE': 0,
    'LAICO': 0,
    'LAIDACKER': 0,
    'LAIDIG': 0,
    'LAIDLAW': 0,
    'LAIDLER': 0,
    'LAIDLEY': 0,
    'LAIDMAN': 0,
    'LAIER': 0,
    'LAIGO': 0,
    'LAIL': 0,
    'LAILA': 1,
    'LAILER': 0,
    'LAIN': 0,
    'LAINE': 0.4484304932735426,
    'LAINER': 0,
    'LAINES': 0,
    'LAINEZ': 0,
    'LAING': 0,
    'LAINHART': 0,
    'LAINO': 0,
    'LAINSON': 0,
    'LAIOSA': 0,
    'LAIPPLE': 0,
    'LAIPPLY': 0,
    'LAIR': 0,
    'LAIRAMORE': 0,
    'LAIRD': 0,
    'LAIRE': 0,
    'LAIRMORE': 0,
    'LAIRSEY': 0,
    'LAIRSON': 0,
    'LAIS': 0,
    'LAISE': 0,
    'LAISURE': 0,
    'LAIT': 0,
    'LAITALA': 0,
    'LAITE': 0,
    'LAITINEN': 0,
    'LAITURI': 0,
    'LAITY': 0,
    'LAIZER': 0,
    'LAIZURE': 0,
    'LAJARA': 0,
    'LAJAUNIE': 0,
    'LAJEUNESSE': 0,
    'LAJEWSKI': 0,
    'LAJINESS': 0,
    'LAJOICE': 0,
    'LAJOIE': 0,
    'LAJOY': 0,
    'LAJUANA': 1,
    'LAJUETT': 0,
    'LAK': 0,
    'LAKAMP': 0,
    'LAKANEN': 0,
    'LAKAS': 0,
    'LAKATOS': 0,
    'LAKATOSH': 0,
    'LAKDAWALA': 0,
    'LAKE': 0,
    'LAKEESHA': 1,
    'LAKEISHA': 1,
    'LAKEMAN': 0,
    'LAKEN': 0,
    'LAKENDRA': 1,
    'LAKENYA': 1,
    'LAKER': 0,
    'LAKES': 0,
    'LAKESHA': 1,
    'LAKESHIA': 1,
    'LAKEY': 0,
    'LAKHAN': 0,
    'LAKHANI': 0,
    'LAKIA': 1,
    'LAKIC': 0,
    'LAKIESHA': 1,
    'LAKIN': 0,
    'LAKINS': 0,
    'LAKIS': 0,
    'LAKISHA': 1,
    'LAKITA': 1,
    'LAKNER': 0,
    'LAKO': 0,
    'LAKODUK': 0,
    'LAKOMSKI': 0,
    'LAKOMY': 0,
    'LAKOS': 0,
    'LAKOSKY': 0,
    'LAKOTA': 0,
    'LAKOWSKI': 0,
    'LAKRITZ': 0,
    'LAKS': 0,
    'LAKSHMANAN': 0,
    'LAKSO': 0,
    'LAKY': 0,
    'LAL': 0,
    'LALA': 0.7246376811594204,
    'LALAMA': 0,
    'LALANCETTE': 0,
    'LALANDE': 0,
    'LALANI': 0,
    'LALANNE': 0,
    'LALAS': 0,
    'LALE': 0,
    'LALEMAN': 0,
    'LALENA': 0,
    'LALIBERTE': 0,
    'LALIBERTY': 0,
    'LALIC': 0,
    'LALICATA': 0,
    'LALICH': 0,
    'LALICKER': 0,
    'LALIK': 0,
    'LALIM': 0,
    'LALIMA': 0,
    'LALIME': 0,
    'LALIN': 0,
    'LALINDE': 0,
    'LALJI': 0,
    'LALK': 0,
    'LALKA': 0,
    'LALKO': 0,
    'LALL': 0,
    'LALLA': 0,
    'LALLAS': 0,
    'LALLATHIN': 0,
    'LALLAVE': 0,
    'LALLEMAND': 0,
    'LALLEMENT': 0,
    'LALLEY': 0,
    'LALLI': 0,
    'LALLIER': 0,
    'LALLMAN': 0,
    'LALLO': 0,
    'LALLY': 0,
    'LALO': 0,
    'LALOGGIA': 0,
    'LALOMIA': 0,
    'LALOND': 0,
    'LALONDE': 0,
    'LALONE': 0,
    'LALOR': 0,
    'LALOS': 0,
    'LALUMANDIER': 0,
    'LALUMIA': 0,
    'LALUMIERE': 0,
    'LALUNA': 0,
    'LALUZ': 0,
    'LALUZERNE': 0,
    'LALWANI': 0,
    'LAM': 0,
    'LAMA': 0,
    'LAMACCHIA': 0,
    'LAMACH': 0,
    'LAMACK': 0,
    'LAMADELEINE': 0,
    'LAMADRID': 0,
    'LAMAGNA': 0,
    'LAMAINA': 0,
    'LAMAIRE': 0,
    'LAMAL': 0,
    'LAMALFA': 0,
    'LAMAN': 0,
    'LAMANA': 0,
    'LAMANCE': 0,
    'LAMANCUSA': 0,
    'LAMANNA': 0,
    'LAMANNO': 0,
    'LAMANO': 0,
    'LAMANSKY': 0,
    'LAMANTIA': 0,
    'LAMAR': 0.8369868473495415,
    'LAMARCA': 0,
    'LAMARCHE': 0,
    'LAMARCO': 0,
    'LAMARE': 0,
    'LAMARK': 0,
    'LAMARQUE': 0,
    'LAMARR': 0,
    'LAMARRA': 0,
    'LAMARRE': 0,
    'LAMARSH': 0,
    'LAMARTINA': 0,
    'LAMARTINIERE': 0,
    'LAMAS': 0,
    'LAMASCUS': 0,
    'LAMASON': 0,
    'LAMASTER': 0,
    'LAMASTERS': 0,
    'LAMASTRA': 0,
    'LAMASTUS': 0,
    'LAMATTINA': 0,
    'LAMAY': 0,
    'LAMB': 0,
    'LAMBA': 0,
    'LAMBACH': 0,
    'LAMBARD': 0,
    'LAMBAREN': 0,
    'LAMBARENA': 0,
    'LAMBART': 0,
    'LAMBDEN': 0,
    'LAMBDIN': 0,
    'LAMBE': 0,
    'LAMBECK': 0,
    'LAMBER': 0,
    'LAMBERG': 0,
    'LAMBERGER': 0,
    'LAMBERS': 0,
    'LAMBERSON': 0,
    'LAMBERT': 0,
    'LAMBERTH': 0,
    'LAMBERTI': 0,
    'LAMBERTO': 0,
    'LAMBERTON': 0,
    'LAMBERTS': 0,
    'LAMBERTSEN': 0,
    'LAMBERTSON': 0,
    'LAMBERTUS': 0,
    'LAMBERTY': 0,
    'LAMBERTZ': 0,
    'LAMBES': 0,
    'LAMBETH': 0,
    'LAMBEY': 0,
    'LAMBIASE': 0,
    'LAMBIE': 0,
    'LAMBING': 0,
    'LAMBIOTTE': 0,
    'LAMBIRTH': 0,
    'LAMBKA': 0,
    'LAMBKE': 0,
    'LAMBKIN': 0,
    'LAMBLE': 0,
    'LAMBLIN': 0,
    'LAMBO': 0,
    'LAMBOLEY': 0,
    'LAMBORN': 0,
    'LAMBORNE': 0,
    'LAMBOS': 0,
    'LAMBOURNE': 0,
    'LAMBOY': 0,
    'LAMBRECHT': 0,
    'LAMBRECHTS': 0,
    'LAMBRIGHT': 0,
    'LAMBRINOS': 0,
    'LAMBRIX': 0,
    'LAMBROPOULOS': 0,
    'LAMBROS': 0,
    'LAMBROSE': 0,
    'LAMBROU': 0,
    'LAMBSON': 0,
    'LAMBUTH': 0,
    'LAMCZYK': 0,
    'LAME': 0,
    'LAMEE': 0,
    'LAMELA': 0,
    'LAMELAS': 0,
    'LAMELL': 0,
    'LAMEMAN': 0,
    'LAMENDOLA': 0,
    'LAMER': 0,
    'LAMERE': 0,
    'LAMERS': 0,
    'LAMERSON': 0,
    'LAMEY': 0,
    'LAMEYER': 0,
    'LAMFERS': 0,
    'LAMI': 0,
    'LAMIA': 0,
    'LAMICA': 0,
    'LAMIE': 0,
    'LAMIN': 0,
    'LAMINACK': 0,
    'LAMING': 0,
    'LAMIRAND': 0,
    'LAMIRANDE': 0,
    'LAMISON': 0,
    'LAMITIE': 0,
    'LAMKA': 0,
    'LAMKE': 0,
    'LAMKEN': 0,
    'LAMKEY': 0,
    'LAMKIN': 0,
    'LAMKINS': 0,
    'LAMLE': 0,
    'LAMLEY': 0,
    'LAMM': 0,
    'LAMMA': 0,
    'LAMME': 0,
    'LAMMER': 0,
    'LAMMERDING': 0,
    'LAMMERS': 0,
    'LAMMERT': 0,
    'LAMMEY': 0,
    'LAMMI': 0,
    'LAMMIE': 0,
    'LAMMING': 0,
    'LAMMLE': 0,
    'LAMMON': 0,
    'LAMMONS': 0,
    'LAMMY': 0,
    'LAMNECK': 0,
    'LAMO': 0,
    'LAMON': 0,
    'LAMONACA': 0,
    'LAMOND': 0,
    'LAMONDA': 0,
    'LAMONDE': 0,
    'LAMONDS': 0,
    'LAMONE': 0,
    'LAMONICA': 0.5347593582887701,
    'LAMONS': 0,
    'LAMONT': 0.8758371973209687,
    'LAMONTAGNE': 0,
    'LAMONTE': 0,
    'LAMORA': 0,
    'LAMORE': 0,
    'LAMOREAU': 0,
    'LAMOREAUX': 0,
    'LAMOREE': 0,
    'LAMORENA': 0,
    'LAMOREUX': 0,
    'LAMORGESE': 0,
    'LAMORIE': 0,
    'LAMORTE': 0,
    'LAMOS': 0,
    'LAMOTHE': 0,
    'LAMOTT': 0,
    'LAMOTTA': 0,
    'LAMOTTE': 0,
    'LAMOUNTAIN': 0,
    'LAMOUR': 0,
    'LAMOURE': 0,
    'LAMOUREAUX': 0,
    'LAMOUREUX': 0,
    'LAMOURT': 0,
    'LAMOY': 0,
    'LAMP': 0,
    'LAMPA': 0,
    'LAMPARD': 0,
    'LAMPARELLI': 0,
    'LAMPARSKI': 0,
    'LAMPART': 0,
    'LAMPARTER': 0,
    'LAMPASONA': 0,
    'LAMPE': 0,
    'LAMPEL': 0,
    'LAMPELA': 0,
    'LAMPEN': 0,
    'LAMPER': 0,
    'LAMPERT': 0,
    'LAMPERTI': 0,
    'LAMPH': 0,
    'LAMPHEAR': 0,
    'LAMPHERE': 0,
    'LAMPHIEAR': 0,
    'LAMPHIER': 0,
    'LAMPI': 0,
    'LAMPINEN': 0,
    'LAMPING': 0,
    'LAMPITT': 0,
    'LAMPKE': 0,
    'LAMPKIN': 0,
    'LAMPKINS': 0,
    'LAMPL': 0,
    'LAMPLE': 0,
    'LAMPLEY': 0,
    'LAMPLUGH': 0,
    'LAMPMAN': 0,
    'LAMPO': 0,
    'LAMPONE': 0,
    'LAMPORT': 0,
    'LAMPOS': 0,
    'LAMPP': 0,
    'LAMPPA': 0,
    'LAMPRECHT': 0,
    'LAMPREY': 0,
    'LAMPROE': 0,
    'LAMPRON': 0,
    'LAMPROPOULOS': 0,
    'LAMPROS': 0,
    'LAMPSHIRE': 0,
    'LAMPSON': 0,
    'LAMPTEY': 0,
    'LAMPTON': 0,
    'LAMROUEX': 0,
    'LAMS': 0,
    'LAMSON': 0,
    'LAMUG': 0,
    'LAMUNION': 0,
    'LAMUNYON': 0,
    'LAMURA': 0,
    'LAMUSGA': 0,
    'LAMY': 0,
    'LAMZ': 0,
    'LAN': 0.8561643835616438,
    'LANA': 0.9887487214456188,
    'LANAGAN': 0,
    'LANAGHAN': 0,
    'LANAHAN': 0,
    'LANAM': 0,
    'LANARO': 0,
    'LANAS': 0,
    'LANASA': 0,
    'LANATA': 0,
    'LANAUX': 0,
    'LANAVILLE': 0,
    'LANC': 0,
    'LANCASHIRE': 0,
    'LANCASTER': 0,
    'LANCE': 0.9304386353566682,
    'LANCELIN': 0,
    'LANCELLOTTA': 0,
    'LANCELLOTTI': 0,
    'LANCELOT': 0,
    'LANCER': 0,
    'LANCETTE': 0,
    'LANCEY': 0,
    'LANCI': 0,
    'LANCIA': 0,
    'LANCIANESE': 0,
    'LANCIANI': 0,
    'LANCIANO': 0,
    'LANCIAULT': 0,
    'LANCIERI': 0,
    'LANCIONE': 0,
    'LANCIOTTI': 0,
    'LANCLOS': 0,
    'LANCON': 0,
    'LANCOR': 0,
    'LANCOUR': 0,
    'LANCTO': 0,
    'LANCTOT': 0,
    'LANCY': 0,
    'LAND': 0,
    'LANDA': 0,
    'LANDAAL': 0,
    'LANDACRE': 0,
    'LANDAETA': 0,
    'LANDAHL': 0,
    'LANDAICHE': 0,
    'LANDAKER': 0,
    'LANDAN': 0,
    'LANDAS': 0,
    'LANDAU': 0,
    'LANDAUER': 0,
    'LANDAVAZO': 0,
    'LANDAVERDE': 0,
    'LANDAY': 0,
    'LANDAZURI': 0,
    'LANDBERG': 0,
    'LANDCASTER': 0,
    'LANDE': 0,
    'LANDECHE': 0,
    'LANDECK': 0,
    'LANDEEN': 0,
    'LANDEFELD': 0,
    'LANDEIS': 0,
    'LANDEL': 0,
    'LANDELL': 0,
    'LANDEN': 0,
    'LANDENBERGER': 0,
    'LANDER': 0,
    'LANDERMAN': 0,
    'LANDERO': 0,
    'LANDEROS': 0,
    'LANDERS': 0,
    'LANDES': 0,
    'LANDESBERG': 0,
    'LANDESMAN': 0,
    'LANDESS': 0,
    'LANDESTOY': 0,
    'LANDETA': 0,
    'LANDEY': 0,
    'LANDEZ': 0,
    'LANDFAIR': 0,
    'LANDFIELD': 0,
    'LANDFORD': 0,
    'LANDFRIED': 0,
    'LANDGRAF': 0,
    'LANDGRAFF': 0,
    'LANDGRAVE': 0,
    'LANDGREBE': 0,
    'LANDGREN': 0,
    'LANDHEER': 0,
    'LANDHERR': 0,
    'LANDHOLM': 0,
    'LANDHOLT': 0,
    'LANDI': 0,
    'LANDICHO': 0,
    'LANDIN': 0,
    'LANDING': 0,
    'LANDINGHAM': 0,
    'LANDINGIN': 0,
    'LANDINI': 0,
    'LANDINO': 0,
    'LANDIS': 0,
    'LANDIVAR': 0,
    'LANDKAMER': 0,
    'LANDKAMMER': 0,
    'LANDMAN': 0,
    'LANDMANN': 0,
    'LANDMARK': 0,
    'LANDMEIER': 0,
    'LANDMESSER': 0,
    'LANDO': 0,
    'LANDOLFI': 0,
    'LANDOLINA': 0,
    'LANDOLL': 0,
    'LANDOLT': 0,
    'LANDON': 0.7162041181736796,
    'LANDOR': 0,
    'LANDORF': 0,
    'LANDOW': 0,
    'LANDOWSKI': 0,
    'LANDRAM': 0,
    'LANDRAU': 0,
    'LANDRE': 0,
    'LANDREE': 0,
    'LANDRENEAU': 0,
    'LANDRESS': 0,
    'LANDRETH': 0,
    'LANDREVILLE': 0,
    'LANDREY': 0,
    'LANDRIAN': 0,
    'LANDRIE': 0,
    'LANDRIGAN': 0,
    'LANDRIO': 0,
    'LANDRITH': 0,
    'LANDRO': 0,
    'LANDROCHE': 0,
    'LANDRON': 0,
    'LANDRUM': 0,
    'LANDRUS': 0,
    'LANDRY': 0,
    'LANDS': 0,
    'LANDSAW': 0,
    'LANDSBERG': 0,
    'LANDSBERGER': 0,
    'LANDSCHOOT': 0,
    'LANDSEM': 0,
    'LANDSIEDEL': 0,
    'LANDSKROENER': 0,
    'LANDSMAN': 0,
    'LANDSTEINER': 0,
    'LANDSTROM': 0,
    'LANDSVERK': 0,
    'LANDT': 0,
    'LANDTROOP': 0,
    'LANDUA': 0,
    'LANDUCCI': 0,
    'LANDUYT': 0,
    'LANDVATTER': 0,
    'LANDWEHR': 0,
    'LANDWER': 0,
    'LANDWERLEN': 0,
    'LANDY': 0,
    'LANE': 0.18732970027247955,
    'LANEAR': 0,
    'LANEAUX': 0,
    'LANEGAN': 0,
    'LANEHART': 0,
    'LANELL': 1,
    'LANELLE': 1,
    'LANENGA': 0,
    'LANER': 0,
    'LANES': 0,
    'LANESE': 0,
    'LANETTE': 1,
    'LANEVE': 0,
    'LANEVILLE': 0,
    'LANEY': 0,
    'LANFAIR': 0,
    'LANFEAR': 0,
    'LANFORD': 0,
    'LANFRANCHI': 0,
    'LANFRANCO': 0,
    'LANG': 0.04314063848144953,
    'LANGA': 0,
    'LANGAGER': 0,
    'LANGAN': 0,
    'LANGARICA': 0,
    'LANGAS': 0,
    'LANGBECKER': 0,
    'LANGBEHN': 0,
    'LANGBEIN': 0,
    'LANGBERG': 0,
    'LANGDALE': 0,
    'LANGDEAU': 0,
    'LANGDELL': 0,
    'LANGDON': 0,
    'LANGE': 0,
    'LANGEBERG': 0,
    'LANGEFELD': 0,
    'LANGEHENNIG': 0,
    'LANGEL': 0,
    'LANGELAND': 0,
    'LANGELIER': 0,
    'LANGELIERS': 0,
    'LANGELL': 0,
    'LANGELLA': 0,
    'LANGELLIER': 0,
    'LANGELLO': 0,
    'LANGEMEIER': 0,
    'LANGEMO': 0,
    'LANGEN': 0,
    'LANGENBACH': 0,
    'LANGENBACHER': 0,
    'LANGENBAHN': 0,
    'LANGENBERG': 0,
    'LANGENBRUNNER': 0,
    'LANGENBURG': 0,
    'LANGENDERFER': 0,
    'LANGENDOERFER': 0,
    'LANGENDORF': 0,
    'LANGENDORFER': 0,
    'LANGENEGGER': 0,
    'LANGENFELD': 0,
    'LANGENFELDER': 0,
    'LANGENHEIM': 0,
    'LANGENHORST': 0,
    'LANGENKAMP': 0,
    'LANGENSTEIN': 0,
    'LANGENWALTER': 0,
    'LANGER': 0,
    'LANGERAK': 0,
    'LANGERMAN': 0,
    'LANGERT': 0,
    'LANGERUD': 0,
    'LANGEVIN': 0,
    'LANGEWISCH': 0,
    'LANGFELD': 0,
    'LANGFELDT': 0,
    'LANGFIELD': 0,
    'LANGFITT': 0,
    'LANGFORD': 0,
    'LANGGUTH': 0,
    'LANGHALS': 0,
    'LANGHAM': 0,
    'LANGHAMMER': 0,
    'LANGHANS': 0,
    'LANGHART': 0,
    'LANGHAUSER': 0,
    'LANGHEIM': 0,
    'LANGHOFER': 0,
    'LANGHOFF': 0,
    'LANGHOLZ': 0,
    'LANGHORN': 0,
    'LANGHORNE': 0,
    'LANGHORST': 0,
    'LANGHURST': 0,
    'LANGI': 0,
    'LANGIEWICZ': 0,
    'LANGILL': 0,
    'LANGILLE': 0,
    'LANGIN': 0,
    'LANGIS': 0,
    'LANGIT': 0,
    'LANGJAHR': 0,
    'LANGKAMP': 0,
    'LANGKAU': 0,
    'LANGLAIS': 0,
    'LANGLAND': 0,
    'LANGLANDS': 0,
    'LANGLE': 0,
    'LANGLEY': 0,
    'LANGLIE': 0,
    'LANGLINAIS': 0,
    'LANGLITZ': 0,
    'LANGLO': 0,
    'LANGLOIS': 0,
    'LANGLOTZ': 0,
    'LANGMACK': 0,
    'LANGMADE': 0,
    'LANGMAID': 0,
    'LANGMAN': 0,
    'LANGMEAD': 0,
    'LANGMEIER': 0,
    'LANGMEYER': 0,
    'LANGNER': 0,
    'LANGNESS': 0,
    'LANGO': 0,
    'LANGOHR': 0,
    'LANGOLF': 0,
    'LANGON': 0,
    'LANGONE': 0,
    'LANGOWSKI': 0,
    'LANGRECK': 0,
    'LANGREDER': 0,
    'LANGREHR': 0,
    'LANGRELL': 0,
    'LANGREN': 0,
    'LANGRIDGE': 0,
    'LANGRILL': 0,
    'LANGROCK': 0,
    'LANGS': 0,
    'LANGSAM': 0,
    'LANGSDALE': 0,
    'LANGSDORF': 0,
    'LANGSETH': 0,
    'LANGSFORD': 0,
    'LANGSHAW': 0,
    'LANGSNER': 0,
    'LANGSTAFF': 0,
    'LANGSTON': 0,
    'LANGSTRAAT': 0,
    'LANGTEAU': 0,
    'LANGTON': 0,
    'LANGTRY': 0,
    'LANGUELL': 0,
    'LANGUIRAND': 0,
    'LANGUM': 0,
    'LANGUREN': 0,
    'LANGUS': 0,
    'LANGWAY': 0,
    'LANGWELL': 0,
    'LANGWORTHY': 0,
    'LANHAM': 0,
    'LANHAN': 0,
    'LANHART': 0,
    'LANI': 0.9646302250803858,
    'LANIADO': 0,
    'LANICH': 0,
    'LANIE': 0.9009009009009009,
    'LANIER': 0,
    'LANIEWSKI': 0,
    'LANIG': 0,
    'LANIGAN': 0,
    'LANIK': 0,
    'LANIN': 0,
    'LANING': 0,
    'LANINGA': 0,
    'LANINGHAM': 0,
    'LANINI': 0,
    'LANIS': 0,
    'LANITA': 1,
    'LANIUS': 0,
    'LANK': 0,
    'LANKA': 0,
    'LANKARD': 0,
    'LANKE': 0,
    'LANKENAU': 0,
    'LANKER': 0,
    'LANKES': 0,
    'LANKEY': 0,
    'LANKFORD': 0,
    'LANKHAAR': 0,
    'LANKIN': 0,
    'LANKO': 0,
    'LANKOW': 0,
    'LANKSTER': 0,
    'LANKSTON': 0,
    'LANKTON': 0,
    'LANMAN': 0,
    'LANN': 0,
    'LANNA': 0,
    'LANNAN': 0,
    'LANNEN': 0,
    'LANNER': 0,
    'LANNERS': 0,
    'LANNERT': 0,
    'LANNES': 0,
    'LANNI': 0,
    'LANNIE': 0.9433962264150944,
    'LANNIGAN': 0,
    'LANNIN': 0,
    'LANNING': 0,
    'LANNO': 0,
    'LANNOM': 0,
    'LANNON': 0,
    'LANNOO': 0,
    'LANNOYE': 0,
    'LANNUTTI': 0,
    'LANNY': 1,
    'LANO': 0,
    'LANOIE': 0,
    'LANOIX': 0,
    'LANORA': 1,
    'LANORE': 0,
    'LANOS': 0,
    'LANOU': 0,
    'LANOUE': 0,
    'LANOUETTE': 0,
    'LANOUX': 0,
    'LANPHAR': 0,
    'LANPHEAR': 0,
    'LANPHER': 0,
    'LANPHERE': 0,
    'LANPHIER': 0,
    'LANS': 0,
    'LANSANG': 0,
    'LANSANGAN': 0,
    'LANSAW': 0,
    'LANSBERRY': 0,
    'LANSBURG': 0,
    'LANSDALE': 0,
    'LANSDELL': 0,
    'LANSDEN': 0,
    'LANSDON': 0,
    'LANSDOWN': 0,
    'LANSDOWNE': 0,
    'LANSER': 0,
    'LANSEY': 0,
    'LANSFORD': 0,
    'LANSING': 0,
    'LANSINGER': 0,
    'LANSINK': 0,
    'LANSKI': 0,
    'LANSKY': 0,
    'LANSMAN': 0,
    'LANSON': 0,
    'LANT': 0,
    'LANTAGNE': 0,
    'LANTEIGNE': 0,
    'LANTER': 0,
    'LANTERI': 0,
    'LANTERMAN': 0,
    'LANTGEN': 0,
    'LANTHIER': 0,
    'LANTHORN': 0,
    'LANTHRIP': 0,
    'LANTIER': 0,
    'LANTIERI': 0,
    'LANTIGUA': 0,
    'LANTIN': 0,
    'LANTING': 0,
    'LANTIS': 0,
    'LANTO': 0,
    'LANTON': 0,
    'LANTOS': 0,
    'LANTOW': 0,
    'LANTRIP': 0,
    'LANTRY': 0,
    'LANTSMAN': 0,
    'LANTTO': 0,
    'LANTZ': 0,
    'LANTZER': 0,
    'LANTZY': 0,
    'LANUM': 0,
    'LANUS': 0,
    'LANUTO': 0,
    'LANUZA': 0,
    'LANWAY': 0,
    'LANYI': 0,
    'LANYON': 0,
    'LANZ': 0,
    'LANZA': 0,
    'LANZAFAME': 0,
    'LANZANO': 0,
    'LANZARA': 0,
    'LANZARO': 0,
    'LANZARONE': 0,
    'LANZAROTTA': 0,
    'LANZAS': 0,
    'LANZEL': 0,
    'LANZENDORF': 0,
    'LANZENDORFER': 0,
    'LANZER': 0,
    'LANZETTA': 0,
    'LANZETTI': 0,
    'LANZI': 0,
    'LANZIERI': 0,
    'LANZILLO': 0,
    'LANZILLOTTA': 0,
    'LANZILLOTTI': 0,
    'LANZILOTTA': 0,
    'LANZILOTTI': 0,
    'LANZISERA': 0,
    'LANZO': 0,
    'LANZON': 0,
    'LANZONE': 0,
    'LANZONI': 0,
    'LANZOT': 0,
    'LAO': 0,
    'LAOS': 0,
    'LAP': 0,
    'LAPA': 0,
    'LAPADULA': 0,
    'LAPAGE': 0,
    'LAPAGLIA': 0,
    'LAPAIX': 0,
    'LAPALM': 0,
    'LAPALME': 0,
    'LAPAN': 0,
    'LAPANNE': 0,
    'LAPARRA': 0,
    'LAPAUGH': 0,
    'LAPAZ': 0,
    'LAPCZYNSKI': 0,
    'LAPE': 0,
    'LAPEAN': 0,
    'LAPEER': 0,
    'LAPENA': 0,
    'LAPENNA': 0,
    'LAPENSEE': 0,
    'LAPENTA': 0,
    'LAPER': 0,
    'LAPERA': 0,
    'LAPERE': 0,
    'LAPERLE': 0,
    'LAPERNA': 0,
    'LAPEROUSE': 0,
    'LAPERRIERE': 0,
    'LAPERUTA': 0,
    'LAPETINA': 0,
    'LAPEYRE': 0,
    'LAPEYROLERIE': 0,
    'LAPEYROUSE': 0,
    'LAPHAM': 0,
    'LAPI': 0,
    'LAPIANA': 0,
    'LAPIC': 0,
    'LAPID': 0,
    'LAPIDES': 0,
    'LAPIDUS': 0,
    'LAPIER': 0,
    'LAPIERRE': 0,
    'LAPIETRA': 0,
    'LAPIN': 0,
    'LAPINA': 0,
    'LAPINE': 0,
    'LAPINS': 0,
    'LAPINSKAS': 0,
    'LAPINSKI': 0,
    'LAPINSKY': 0,
    'LAPINTA': 0,
    'LAPIRA': 0,
    'LAPISH': 0,
    'LAPITAN': 0,
    'LAPKA': 0,
    'LAPKE': 0,
    'LAPKIN': 0,
    'LAPLACA': 0,
    'LAPLACE': 0,
    'LAPLANT': 0,
    'LAPLANTE': 0,
    'LAPLAUNT': 0,
    'LAPLUME': 0,
    'LAPOINT': 0,
    'LAPOINTE': 0,
    'LAPOLE': 0,
    'LAPOLICE': 0,
    'LAPOLLA': 0,
    'LAPOLLO': 0,
    'LAPOLT': 0,
    'LAPONSIE': 0,
    'LAPONTE': 0,
    'LAPORE': 0,
    'LAPORT': 0,
    'LAPORTA': 0,
    'LAPORTE': 0,
    'LAPOSKY': 0,
    'LAPOSTA': 0,
    'LAPOUR': 0,
    'LAPP': 0,
    'LAPPA': 0,
    'LAPPAS': 0,
    'LAPPE': 0,
    'LAPPEN': 0,
    'LAPPERT': 0,
    'LAPPI': 0,
    'LAPPIN': 0,
    'LAPPING': 0,
    'LAPRAD': 0,
    'LAPRADD': 0,
    'LAPRADE': 0,
    'LAPRAIRIE': 0,
    'LAPRARIE': 0,
    'LAPRATT': 0,
    'LAPRAY': 0,
    'LAPRE': 0,
    'LAPREE': 0,
    'LAPRISE': 0,
    'LAPSANSKY': 0,
    'LAPSLEY': 0,
    'LAPUMA': 0,
    'LAPUTKA': 0,
    'LAPUZ': 0,
    'LAPWORTH': 0,
    'LAQUA': 0,
    'LAQUAGLIA': 0,
    'LAQUANDA': 1,
    'LAQUATRA': 0,
    'LAQUAY': 0,
    'LAQUE': 0,
    'LAQUERRE': 0,
    'LAQUEY': 0,
    'LAQUIDARA': 0,
    'LAQUITA': 1,
    'LAR': 0,
    'LARA': 0.4195070791819612,
    'LARABEE': 0,
    'LARABEL': 0,
    'LARABELL': 0,
    'LARABY': 0,
    'LARACUENTE': 0,
    'LARACY': 0,
    'LARAE': 1,
    'LARAIA': 0,
    'LARAINE': 1,
    'LARAMEE': 0,
    'LARAMIE': 0,
    'LARAMORE': 0,
    'LARAMY': 0,
    'LARANANG': 0,
    'LARANCE': 0,
    'LARANJO': 0,
    'LARAQUE': 0,
    'LARASON': 0,
    'LARATTA': 0,
    'LARAWAY': 0,
    'LARBI': 0,
    'LARCADE': 0,
    'LARCH': 0,
    'LARCHE': 0,
    'LARCHER': 0,
    'LARCK': 0,
    'LARCO': 0,
    'LARCOM': 0,
    'LARCOMBE': 0,
    'LARD': 0,
    'LARDAS': 0,
    'LARDE': 0,
    'LARDER': 0,
    'LARDI': 0,
    'LARDIE': 0,
    'LARDIERE': 0,
    'LARDIERI': 0,
    'LARDIN': 0,
    'LARDINOIS': 0,
    'LARDIZABAL': 0,
    'LARDNER': 0,
    'LARDO': 0,
    'LARDY': 0,
    'LARE': 0,
    'LAREAU': 0,
    'LAREDO': 0,
    'LAREE': 1,
    'LAREGINA': 0,
    'LAREN': 0,
    'LARENAS': 0,
    'LARENCE': 0,
    'LARES': 0,
    'LARESE': 0,
    'LAREW': 0,
    'LAREY': 0,
    'LAREZ': 0,
    'LARGAESPADA': 0,
    'LARGAY': 0,
    'LARGE': 0,
    'LARGEN': 0,
    'LARGENT': 0,
    'LARGER': 0,
    'LARGEY': 0,
    'LARGIN': 0,
    'LARGO': 0,
    'LARHONDA': 1,
    'LARI': 0,
    'LARIA': 0,
    'LARIBEE': 0,
    'LARICCIA': 0,
    'LARICK': 0,
    'LARIE': 0,
    'LARIMER': 0,
    'LARIMORE': 0,
    'LARIN': 0,
    'LARIO': 0,
    'LARION': 0,
    'LARIOS': 0,
    'LARIOSA': 0,
    'LARIS': 0,
    'LARISA': 1,
    'LARISCY': 0,
    'LARISEY': 0,
    'LARISH': 0,
    'LARISON': 0,
    'LARISSA': 1,
    'LARITA': 1,
    'LARIVE': 0,
    'LARIVEE': 0,
    'LARIVIERE': 0,
    'LARIZ': 0,
    'LARIZZA': 0,
    'LARK': 0,
    'LARKE': 0,
    'LARKEY': 0,
    'LARKIN': 0,
    'LARKINS': 0,
    'LARKO': 0,
    'LARKOWSKI': 0,
    'LARKS': 0,
    'LARLEE': 0,
    'LARM': 0,
    'LARMAN': 0,
    'LARMAY': 0,
    'LARMEE': 0,
    'LARMER': 0,
    'LARMIE': 0,
    'LARMON': 0,
    'LARMOND': 0,
    'LARMORE': 0,
    'LARMOUR': 0,
    'LARNED': 0,
    'LARNER': 0,
    'LARNERD': 0,
    'LARNEY': 0,
    'LARO': 0,
    'LAROCCA': 0,
    'LAROCCO': 0,
    'LAROCHE': 0,
    'LAROCHELLE': 0,
    'LAROCK': 0,
    'LAROCQUE': 0,
    'LAROE': 0,
    'LARON': 0,
    'LARONDA': 1,
    'LARONDE': 0,
    'LARONGE': 0,
    'LAROQUE': 0,
    'LAROS': 0,
    'LAROSA': 0,
    'LAROSE': 0,
    'LAROSEE': 0,
    'LAROSSA': 0,
    'LAROT': 0,
    'LAROTONDA': 0,
    'LAROUCHE': 0,
    'LAROUE': 0,
    'LAROUSSE': 0,
    'LAROUX': 0,
    'LAROW': 0,
    'LAROWE': 0,
    'LAROY': 0,
    'LAROYA': 0,
    'LAROZA': 0,
    'LARR': 0,
    'LARRABEE': 0,
    'LARRACUENTE': 0,
    'LARRAGA': 0,
    'LARRAIN': 0,
    'LARRAINE': 1,
    'LARRALDE': 0,
    'LARRANAGA': 0,
    'LARRANCE': 0,
    'LARRAURI': 0,
    'LARRAZABAL': 0,
    'LARREA': 0,
    'LARREAU': 0,
    'LARREGUI': 0,
    'LARREMORE': 0,
    'LARREW': 0,
    'LARREYNAGA': 0,
    'LARRIBAS': 0,
    'LARRICK': 0,
    'LARRIER': 0,
    'LARRIEU': 0,
    'LARRIEUX': 0,
    'LARRIMER': 0,
    'LARRIMORE': 0,
    'LARRINAGA': 0,
    'LARRISON': 0,
    'LARRIVA': 0,
    'LARRIVEE': 0,
    'LARRIVIERE': 0,
    'LARRO': 0,
    'LARRONDO': 0,
    'LARROQUE': 0,
    'LARROSA': 0,
    'LARROW': 0,
    'LARRY': 0.9966224647688136,
    'LARS': 0,
    'LARSCHEID': 0,
    'LARSEN': 0,
    'LARSH': 0,
    'LARSON': 0,
    'LARSSEN': 0,
    'LARSSON': 0,
    'LARTER': 0,
    'LARTEY': 0,
    'LARTIGUE': 0,
    'LARTZ': 0,
    'LARUE': 0.41724617524339364,
    'LARUFFA': 0,
    'LARUM': 0,
    'LARUMBE': 0,
    'LARUSCH': 0,
    'LARUSSA': 0,
    'LARUSSO': 0,
    'LARVIE': 0,
    'LARWOOD': 0,
    'LARY': 0,
    'LARYEA': 0,
    'LARZELERE': 0,
    'LAS': 0,
    'LASA': 0,
    'LASAGE': 0,
    'LASAGNA': 0,
    'LASAK': 0,
    'LASALA': 0,
    'LASALANDRA': 0,
    'LASALLA': 0,
    'LASALLE': 0,
    'LASALVIA': 0,
    'LASANDRA': 1,
    'LASANE': 0,
    'LASANTA': 0,
    'LASARGE': 0,
    'LASASSO': 0,
    'LASATER': 0,
    'LASBY': 0,
    'LASCALA': 0,
    'LASCAND': 0,
    'LASCANO': 0,
    'LASCARI': 0,
    'LASCELLE': 0,
    'LASCELLES': 0,
    'LASCH': 0,
    'LASCHOBER': 0,
    'LASCO': 0,
    'LASCOLA': 0,
    'LASCURAIN': 0,
    'LASECKI': 0,
    'LASEE': 0,
    'LASEK': 0,
    'LASELL': 0,
    'LASELLE': 0,
    'LASELVA': 0,
    'LASENBY': 0,
    'LASER': 0,
    'LASERNA': 0,
    'LASETER': 0,
    'LASH': 0,
    'LASHA': 0,
    'LASHANDA': 1,
    'LASHANDRA': 1,
    'LASHAUN': 1,
    'LASHAUNDA': 1,
    'LASHAWAY': 0,
    'LASHAWN': 1,
    'LASHAWNA': 1,
    'LASHAWNDA': 1,
    'LASHAY': 1,
    'LASHBAUGH': 0,
    'LASHBROOK': 0,
    'LASHELL': 0.9523809523809523,
    'LASHELLE': 0,
    'LASHER': 0,
    'LASHIER': 0,
    'LASHINSKI': 0,
    'LASHINSKY': 0,
    'LASHLEE': 0,
    'LASHLEY': 0,
    'LASHMET': 0,
    'LASHMETT': 0,
    'LASHMIT': 0,
    'LASHOMB': 0,
    'LASHON': 1,
    'LASHONDA': 1,
    'LASHUA': 0,
    'LASHUAY': 0,
    'LASHUNDA': 1,
    'LASHURE': 0,
    'LASHWAY': 0,
    'LASICH': 0,
    'LASICK': 0,
    'LASILOO': 0,
    'LASINSKI': 0,
    'LASITA': 0,
    'LASITER': 0,
    'LASK': 0,
    'LASKA': 0,
    'LASKAR': 0,
    'LASKARIS': 0,
    'LASKAY': 0,
    'LASKE': 0,
    'LASKER': 0,
    'LASKEY': 0,
    'LASKI': 0,
    'LASKIE': 0,
    'LASKIN': 0,
    'LASKO': 0,
    'LASKOS': 0,
    'LASKOSKI': 0,
    'LASKOSKIE': 0,
    'LASKOW': 0,
    'LASKOWITZ': 0,
    'LASKOWSKI': 0,
    'LASKOWSKY': 0,
    'LASKY': 0,
    'LASLEY': 0,
    'LASLIE': 0,
    'LASLO': 0,
    'LASLOW': 0,
    'LASMAN': 0,
    'LASNER': 0,
    'LASNIER': 0,
    'LASO': 0,
    'LASON': 0,
    'LASONYA': 1,
    'LASORELLA': 0,
    'LASORSA': 0,
    'LASOTA': 0,
    'LASPADA': 0,
    'LASPINA': 0,
    'LASPISA': 0,
    'LASS': 0,
    'LASSA': 0,
    'LASSABE': 0,
    'LASSAHN': 0,
    'LASSAK': 0,
    'LASSALLE': 0,
    'LASSANDRO': 0,
    'LASSE': 0,
    'LASSEIGNE': 0,
    'LASSEK': 0,
    'LASSELL': 0,
    'LASSELLE': 0,
    'LASSEN': 0,
    'LASSER': 0,
    'LASSERE': 0,
    'LASSERRE': 0,
    'LASSETER': 0,
    'LASSETTER': 0,
    'LASSEY': 0,
    'LASSI': 0,
    'LASSIC': 0,
    'LASSIG': 0,
    'LASSILA': 0,
    'LASSITER': 0,
    'LASSITTER': 0,
    'LASSLEY': 0,
    'LASSMAN': 0,
    'LASSO': 0,
    'LASSON': 0,
    'LASSONDE': 0,
    'LASSUS': 0,
    'LASSWELL': 0,
    'LAST': 0,
    'LASTELLA': 0,
    'LASTER': 0,
    'LASTIMOSA': 0,
    'LASTINE': 0,
    'LASTINGER': 0,
    'LASTON': 0,
    'LASTORIA': 0,
    'LASTOVICA': 0,
    'LASTOWSKI': 0,
    'LASTRA': 0,
    'LASTRAPES': 0,
    'LASTRE': 0,
    'LASTRES': 0,
    'LASTRINA': 0,
    'LASURE': 0,
    'LASUSA': 0,
    'LASWELL': 0,
    'LASYONE': 0,
    'LASZEWSKI': 0,
    'LASZLO': 0,
    'LAT': 0,
    'LATA': 0,
    'LATAILLE': 0,
    'LATANYA': 1,
    'LATAPIE': 0,
    'LATARSHA': 1,
    'LATAS': 0,
    'LATASHA': 1,
    'LATASHIA': 1,
    'LATAWIEC': 0,
    'LATCH': 0,
    'LATCHAM': 0,
    'LATCHAW': 0,
    'LATCHFORD': 0,
    'LATCHISON': 0,
    'LATCHMAN': 0,
    'LATE': 0,
    'LATEEF': 0,
    'LATELLA': 0,
    'LATELY': 0,
    'LATEMPA': 0,
    'LATEN': 0,
    'LATENDRESSE': 0,
    'LATER': 0,
    'LATERRA': 0,
    'LATERZA': 0,
    'LATES': 0,
    'LATESHA': 1,
    'LATESSA': 0,
    'LATHAM': 0,
    'LATHAN': 0,
    'LATHBURY': 0,
    'LATHE': 0,
    'LATHEM': 0,
    'LATHEN': 0,
    'LATHER': 0,
    'LATHERN': 0,
    'LATHERS': 0,
    'LATHERY': 0,
    'LATHEY': 0,
    'LATHIM': 0,
    'LATHOM': 0,
    'LATHON': 0,
    'LATHRAM': 0,
    'LATHROM': 0,
    'LATHROP': 0,
    'LATHROPE': 0,
    'LATHRUM': 0,
    'LATHUM': 0,
    'LATI': 0,
    'LATIA': 1,
    'LATIC': 0,
    'LATICIA': 1,
    'LATIF': 0,
    'LATIFF': 0,
    'LATIFI': 0,
    'LATIGO': 0,
    'LATIGUE': 0,
    'LATIKER': 0,
    'LATIL': 0,
    'LATIMER': 0,
    'LATIMORE': 0,
    'LATIN': 0,
    'LATINA': 0.8849557522123894,
    'LATINI': 0,
    'LATINO': 0,
    'LATIOLAIS': 0,
    'LATISHA': 1,
    'LATKA': 0,
    'LATKO': 0,
    'LATKOVIC': 0,
    'LATKOWSKI': 0,
    'LATMAN': 0,
    'LATNER': 0,
    'LATNEY': 0,
    'LATO': 0,
    'LATOCHA': 0,
    'LATON': 0,
    'LATONA': 0,
    'LATONE': 0,
    'LATONIA': 1,
    'LATONYA': 1,
    'LATORA': 0,
    'LATORE': 0,
    'LATORELLA': 0,
    'LATORIA': 1,
    'LATORRACA': 0,
    'LATORRE': 0,
    'LATORRES': 0,
    'LATORTUE': 0,
    'LATOS': 0,
    'LATOSHA': 1,
    'LATOSKI': 0,
    'LATOUCHE': 0,
    'LATOUF': 0,
    'LATOUR': 0,
    'LATOURELLE': 0,
    'LATOURETTE': 0,
    'LATOURRETTE': 0,
    'LATOYA': 1,
    'LATOYIA': 1,
    'LATRAGNA': 0,
    'LATRAILLE': 0,
    'LATRAY': 0,
    'LATREILLE': 0,
    'LATRICE': 1,
    'LATRICIA': 1,
    'LATRINA': 1,
    'LATRISHA': 1,
    'LATRONICA': 0,
    'LATRONICO': 0,
    'LATSCH': 0,
    'LATSHA': 0,
    'LATSHAW': 0,
    'LATSKO': 0,
    'LATSON': 0,
    'LATT': 0,
    'LATTA': 0,
    'LATTANZE': 0,
    'LATTANZI': 0,
    'LATTANZIO': 0,
    'LATTARI': 0,
    'LATTARULO': 0,
    'LATTEA': 0,
    'LATTEN': 0,
    'LATTER': 0,
    'LATTERELL': 0,
    'LATTERI': 0,
    'LATTERNER': 0,
    'LATTERY': 0,
    'LATTIE': 0,
    'LATTIER': 0,
    'LATTIG': 0,
    'LATTIME': 0,
    'LATTIMER': 0,
    'LATTIMORE': 0,
    'LATTIN': 0,
    'LATTING': 0,
    'LATTMAN': 0,
    'LATTNER': 0,
    'LATTO': 0,
    'LATTRELL': 0,
    'LATTUCA': 0,
    'LATTURE': 0,
    'LATTY': 0,
    'LATTYAK': 0,
    'LATU': 0,
    'LATUCH': 0,
    'LATULIP': 0,
    'LATULIPE': 0,
    'LATULIPPE': 0,
    'LATURNER': 0,
    'LATURNO': 0,
    'LATUS': 0,
    'LATUSZEK': 0,
    'LATVA': 0,
    'LATVALA': 0,
    'LATVIS': 0,
    'LATZ': 0,
    'LATZA': 0,
    'LATZER': 0,
    'LATZIG': 0,
    'LATZKE': 0,
    'LATZKO': 0,
    'LAU': 0,
    'LAUB': 0,
    'LAUBACH': 0,
    'LAUBACHER': 0,
    'LAUBE': 0,
    'LAUBENHEIMER': 0,
    'LAUBENSTEIN': 0,
    'LAUBENTHAL': 0,
    'LAUBER': 0,
    'LAUBERT': 0,
    'LAUBHAN': 0,
    'LAUBINGER': 0,
    'LAUBNER': 0,
    'LAUBSCHER': 0,
    'LAUBY': 0,
    'LAUCELLA': 0,
    'LAUCH': 0,
    'LAUCHMAN': 0,
    'LAUCHNER': 0,
    'LAUCIRICA': 0,
    'LAUCK': 0,
    'LAUCKNER': 0,
    'LAUCKS': 0,
    'LAUD': 0,
    'LAUDA': 0,
    'LAUDADIO': 0,
    'LAUDAN': 0,
    'LAUDANI': 0,
    'LAUDANO': 0,
    'LAUDATI': 0,
    'LAUDATO': 0,
    'LAUDE': 0,
    'LAUDEMAN': 0,
    'LAUDEN': 0,
    'LAUDENBACH': 0,
    'LAUDENSLAGER': 0,
    'LAUDER': 0,
    'LAUDERBACK': 0,
    'LAUDERBAUGH': 0,
    'LAUDERDALE': 0,
    'LAUDERMAN': 0,
    'LAUDERMILCH': 0,
    'LAUDERMILK': 0,
    'LAUDERMILT': 0,
    'LAUDICINA': 0,
    'LAUDICK': 0,
    'LAUDIG': 0,
    'LAUDON': 0,
    'LAUDONE': 0,
    'LAUE': 0,
    'LAUEN': 0,
    'LAUENSTEIN': 0,
    'LAUER': 0,
    'LAUERMAN': 0,
    'LAUERMANN': 0,
    'LAUERSDORF': 0,
    'LAUF': 0,
    'LAUFENBERG': 0,
    'LAUFER': 0,
    'LAUFF': 0,
    'LAUFFENBURGER': 0,
    'LAUFFER': 0,
    'LAUFMAN': 0,
    'LAUG': 0,
    'LAUGEN': 0,
    'LAUGER': 0,
    'LAUGESEN': 0,
    'LAUGHARY': 0,
    'LAUGHBAUM': 0,
    'LAUGHEAD': 0,
    'LAUGHERTY': 0,
    'LAUGHERY': 0,
    'LAUGHHUNN': 0,
    'LAUGHING': 0,
    'LAUGHINGHOUSE': 0,
    'LAUGHLAND': 0,
    'LAUGHLIN': 0,
    'LAUGHMAN': 0,
    'LAUGHNER': 0,
    'LAUGHON': 0,
    'LAUGHREN': 0,
    'LAUGHREY': 0,
    'LAUGHRIDGE': 0,
    'LAUGHTER': 0,
    'LAUGHTON': 0,
    'LAUGHY': 0,
    'LAUHER': 0,
    'LAUHOFF': 0,
    'LAUHON': 0,
    'LAUINGER': 0,
    'LAUK': 0,
    'LAUKAITIS': 0,
    'LAUKHUF': 0,
    'LAUKHUFF': 0,
    'LAULAINEN': 0,
    'LAULE': 0,
    'LAULETTA': 0,
    'LAULU': 0,
    'LAUMAN': 0,
    'LAUMANN': 0,
    'LAUMB': 0,
    'LAUMBACH': 0,
    'LAUMER': 0,
    'LAUMEYER': 0,
    'LAUN': 0,
    'LAUNA': 1,
    'LAUNDER': 0,
    'LAUNDERVILLE': 0,
    'LAUNDRIE': 0,
    'LAUNDRY': 0,
    'LAUNER': 0,
    'LAUNEY': 0,
    'LAUNI': 0,
    'LAUNIUS': 0,
    'LAUPER': 0,
    'LAUPP': 0,
    'LAUPPE': 0,
    'LAUR': 0,
    'LAURA': 0.9989031651519901,
    'LAURAIN': 0,
    'LAURALEE': 1,
    'LAURAMORE': 0,
    'LAURAN': 1,
    'LAURANCE': 0,
    'LAURANT': 0,
    'LAURE': 0.9708737864077669,
    'LAUREANO': 0,
    'LAUREEN': 1,
    'LAUREL': 0.97323600973236,
    'LAURELES': 0,
    'LAURELL': 0,
    'LAURELLI': 0,
    'LAUREN': 0.9980181200453001,
    'LAURENA': 1,
    'LAURENCE': 0.9567546880979717,
    'LAURENCEAU': 0,
    'LAURENCELLE': 0,
    'LAURENCIO': 0,
    'LAURENDEAU': 0,
    'LAURENDINE': 0,
    'LAURENE': 1,
    'LAURENO': 0,
    'LAURENS': 0,
    'LAURENSON': 0,
    'LAURENT': 0,
    'LAURENTE': 0,
    'LAURENTI': 0,
    'LAURENTIUS': 0,
    'LAURENTS': 0,
    'LAURENZ': 0,
    'LAURENZA': 0,
    'LAURENZANA': 0,
    'LAURENZANO': 0,
    'LAURENZI': 0,
    'LAURENZO': 0,
    'LAURER': 0,
    'LAURES': 0,
    'LAURET': 0,
    'LAURETA': 0,
    'LAURETANO': 0,
    'LAURETTA': 0.9884678747940693,
    'LAURETTE': 1,
    'LAURETTI': 0,
    'LAUREY': 0,
    'LAUREYS': 0,
    'LAURI': 0.9825327510917031,
    'LAURIA': 0,
    'LAURIANO': 0,
    'LAURICE': 1,
    'LAURICELLA': 0,
    'LAURICH': 0,
    'LAURIDSEN': 0,
    'LAURIE': 0.9889823891732454,
    'LAURILA': 0,
    'LAURIN': 0,
    'LAURINAITIS': 0,
    'LAURINDA': 1,
    'LAURINE': 0.9756097560975611,
    'LAURINO': 0,
    'LAURION': 0,
    'LAURISTON': 0,
    'LAURITA': 0,
    'LAURITANO': 0,
    'LAURITO': 0,
    'LAURITSEN': 0,
    'LAURITZEN': 0,
    'LAURO': 0,
    'LAURON': 0,
    'LAURORE': 0,
    'LAURSEN': 0,
    'LAURY': 0,
    'LAURYN': 1,
    'LAUS': 0,
    'LAUSCH': 0,
    'LAUSCHER': 0,
    'LAUSE': 0,
    'LAUSELL': 0,
    'LAUSEN': 0,
    'LAUSENG': 0,
    'LAUSER': 0,
    'LAUSH': 0,
    'LAUSIER': 0,
    'LAUSON': 0,
    'LAUSTEN': 0,
    'LAUSTER': 0,
    'LAUSTERER': 0,
    'LAUSTSEN': 0,
    'LAUT': 0,
    'LAUTEN': 0,
    'LAUTENBACH': 0,
    'LAUTENSCHLAGER': 0,
    'LAUTENSCHLEGER': 0,
    'LAUTENSLAGER': 0,
    'LAUTER': 0,
    'LAUTERBACH': 0,
    'LAUTERBORN': 0,
    'LAUTERIO': 0,
    'LAUTERMILCH': 0,
    'LAUTERS': 0,
    'LAUTERWASSER': 0,
    'LAUTH': 0,
    'LAUTHER': 0,
    'LAUTMAN': 0,
    'LAUTNER': 0,
    'LAUTT': 0,
    'LAUTURE': 0,
    'LAUTZ': 0,
    'LAUTZENHEISER': 0,
    'LAUTZENHISER': 0,
    'LAUVE': 0,
    'LAUVER': 0,
    'LAUVRAY': 0,
    'LAUW': 0,
    'LAUWERS': 0,
    'LAUX': 0,
    'LAUZE': 0,
    'LAUZIER': 0,
    'LAUZIERE': 0,
    'LAUZON': 0,
    'LAVA': 0,
    'LAVACCA': 0,
    'LAVACHE': 0,
    'LAVACK': 0,
    'LAVADA': 1,
    'LAVADO': 0,
    'LAVAGNINO': 0,
    'LAVAKE': 0,
    'LAVAL': 0,
    'LAVALAIS': 0,
    'LAVALETTE': 0,
    'LAVALLA': 0,
    'LAVALLAIS': 0,
    'LAVALLE': 0,
    'LAVALLEE': 0,
    'LAVALLEY': 0,
    'LAVALLIE': 0,
    'LAVALLIERE': 0,
    'LAVAN': 0,
    'LAVANCE': 0,
    'LAVANCHA': 0,
    'LAVANCHY': 0,
    'LAVANDER': 0,
    'LAVANT': 0,
    'LAVANWAY': 0,
    'LAVARE': 0,
    'LAVARIAS': 0,
    'LAVARIEGA': 0,
    'LAVARNWAY': 0,
    'LAVASSEUR': 0,
    'LAVATAI': 0,
    'LAVATO': 0,
    'LAVAYEN': 0,
    'LAVE': 0,
    'LAVEA': 0,
    'LAVEAU': 0,
    'LAVECCHIA': 0,
    'LAVECK': 0,
    'LAVEGLIA': 0,
    'LAVELL': 0,
    'LAVELLA': 0,
    'LAVELLE': 0.3154574132492114,
    'LAVELY': 0,
    'LAVEN': 0,
    'LAVENDER': 0,
    'LAVENE': 0,
    'LAVENGOOD': 0,
    'LAVENIA': 0.9523809523809523,
    'LAVENTURE': 0,
    'LAVER': 0,
    'LAVERA': 1,
    'LAVERACK': 0,
    'LAVERDE': 0,
    'LAVERDIERE': 0,
    'LAVERDURE': 0,
    'LAVERE': 0,
    'LAVERGHETTA': 0,
    'LAVERGNE': 0,
    'LAVERICK': 0,
    'LAVERN': 0.995475113122172,
    'LAVERNA': 1,
    'LAVERNE': 0.9955462405030129,
    'LAVERRIERE': 0,
    'LAVERS': 0,
    'LAVERTU': 0,
    'LAVERTUE': 0,
    'LAVERTY': 0,
    'LAVERY': 0,
    'LAVESPERE': 0,
    'LAVETA': 1,
    'LAVETTE': 0.9259259259259258,
    'LAVEY': 0,
    'LAVEZZO': 0,
    'LAVI': 0,
    'LAVIA': 0,
    'LAVIAN': 0,
    'LAVIANO': 0,
    'LAVICKA': 0,
    'LAVICTOIRE': 0,
    'LAVIDLETTE': 0,
    'LAVIE': 0,
    'LAVIELLE': 0,
    'LAVIER': 0,
    'LAVIERI': 0,
    'LAVIGNA': 0,
    'LAVIGNE': 0,
    'LAVIGUEUR': 0,
    'LAVILLA': 0,
    'LAVILLE': 0,
    'LAVIN': 0,
    'LAVINA': 0.9852216748768473,
    'LAVINDER': 0,
    'LAVINE': 0,
    'LAVINGTON': 0,
    'LAVINIA': 1,
    'LAVINO': 0,
    'LAVIOLA': 0,
    'LAVIOLETTE': 0,
    'LAVIS': 0,
    'LAVISH': 0,
    'LAVISTA': 0,
    'LAVITA': 0,
    'LAVITT': 0,
    'LAVO': 0,
    'LAVOI': 0,
    'LAVOICE': 0,
    'LAVOIE': 0,
    'LAVOLD': 0,
    'LAVOLE': 0,
    'LAVON': 0.9876543209876544,
    'LAVONA': 1,
    'LAVONDA': 1,
    'LAVONE': 1,
    'LAVONIA': 1,
    'LAVONNA': 1,
    'LAVONNE': 1,
    'LAVORATO': 0,
    'LAVORE': 0,
    'LAVORGNA': 0,
    'LAVOY': 0,
    'LAVRICH': 0,
    'LAVULO': 0,
    'LAVY': 0,
    'LAW': 0,
    'LAWAL': 0,
    'LAWALIN': 0,
    'LAWALL': 0,
    'LAWANA': 1,
    'LAWANDA': 1,
    'LAWANNA': 1,
    'LAWARE': 0,
    'LAWAS': 0,
    'LAWDER': 0,
    'LAWE': 0,
    'LAWELL': 0,
    'LAWER': 0,
    'LAWERANCE': 0,
    'LAWERENCE': 1,
    'LAWERNCE': 0,
    'LAWERY': 0,
    'LAWES': 0,
    'LAWFER': 0,
    'LAWFORD': 0,
    'LAWHEAD': 0,
    'LAWHON': 0,
    'LAWHORN': 0,
    'LAWHORNE': 0,
    'LAWHUN': 0,
    'LAWICKI': 0,
    'LAWIN': 0,
    'LAWING': 0,
    'LAWINGER': 0,
    'LAWLER': 0,
    'LAWLESS': 0,
    'LAWLEY': 0,
    'LAWLIS': 0,
    'LAWLISS': 0,
    'LAWLOR': 0,
    'LAWMAN': 0,
    'LAWMASTER': 0,
    'LAWN': 0,
    'LAWNER': 0,
    'LAWNICKI': 0,
    'LAWNICZAK': 0,
    'LAWONN': 0,
    'LAWRANCE': 0,
    'LAWRASON': 0,
    'LAWRENCE': 0.8599471269257649,
    'LAWRENSON': 0,
    'LAWRENTZ': 0,
    'LAWRENZ': 0,
    'LAWREY': 0,
    'LAWRIE': 0,
    'LAWRIMORE': 0,
    'LAWRY': 0,
    'LAWS': 0,
    'LAWSHE': 0,
    'LAWSHEA': 0,
    'LAWSON': 0,
    'LAWSTON': 0,
    'LAWTER': 0,
    'LAWTHER': 0,
    'LAWTON': 0,
    'LAWVER': 0,
    'LAWWILL': 0,
    'LAWYER': 0,
    'LAX': 0,
    'LAXA': 0,
    'LAXAMANA': 0,
    'LAXEN': 0,
    'LAXER': 0,
    'LAXSON': 0,
    'LAXTON': 0,
    'LAY': 0,
    'LAYA': 0,
    'LAYAOU': 0,
    'LAYBOURN': 0,
    'LAYBOURNE': 0,
    'LAYBURN': 0,
    'LAYCHAK': 0,
    'LAYCOCK': 0,
    'LAYCOOK': 0,
    'LAYCOX': 0,
    'LAYDEN': 0,
    'LAYDON': 0,
    'LAYE': 0,
    'LAYELL': 0,
    'LAYER': 0,
    'LAYES': 0,
    'LAYFIELD': 0,
    'LAYGO': 0,
    'LAYHER': 0,
    'LAYHEW': 0,
    'LAYHUE': 0,
    'LAYLA': 1,
    'LAYLAND': 0,
    'LAYMAN': 0,
    'LAYMANCE': 0,
    'LAYMON': 0,
    'LAYNE': 0.17094017094017094,
    'LAYNG': 0,
    'LAYO': 0,
    'LAYON': 0,
    'LAYOS': 0,
    'LAYPORT': 0,
    'LAYSER': 0,
    'LAYSON': 0,
    'LAYTART': 0,
    'LAYTHAM': 0,
    'LAYTHE': 0,
    'LAYTON': 0,
    'LAYUG': 0,
    'LAYUGAN': 0,
    'LAYWELL': 0,
    'LAZ': 0,
    'LAZA': 0,
    'LAZAGA': 0,
    'LAZALA': 0,
    'LAZALDE': 0,
    'LAZAN': 0,
    'LAZANO': 0,
    'LAZANSKY': 0,
    'LAZAR': 0,
    'LAZARA': 0,
    'LAZARCZYK': 0,
    'LAZARD': 0,
    'LAZARE': 0,
    'LAZAREK': 0,
    'LAZAREV': 0,
    'LAZAREVIC': 0,
    'LAZARIDES': 0,
    'LAZARIDIS': 0,
    'LAZARIN': 0,
    'LAZARINE': 0,
    'LAZARIS': 0,
    'LAZARO': 0.7675438596491229,
    'LAZAROFF': 0,
    'LAZARONY': 0,
    'LAZAROS': 0,
    'LAZAROU': 0,
    'LAZAROV': 0,
    'LAZAROW': 0,
    'LAZAROWICZ': 0,
    'LAZAROWITZ': 0,
    'LAZARRE': 0,
    'LAZARSKI': 0,
    'LAZARTE': 0,
    'LAZARUS': 0,
    'LAZARZ': 0,
    'LAZATIN': 0,
    'LAZAUSKAS': 0,
    'LAZCANO': 0,
    'LAZEAR': 0,
    'LAZELL': 0,
    'LAZELLE': 0,
    'LAZENBY': 0,
    'LAZER': 0,
    'LAZERSON': 0,
    'LAZETTE': 0,
    'LAZEWSKI': 0,
    'LAZIC': 0,
    'LAZICH': 0,
    'LAZICKI': 0,
    'LAZIER': 0,
    'LAZIO': 0,
    'LAZO': 0,
    'LAZOFF': 0,
    'LAZOR': 0,
    'LAZORCHAK': 0,
    'LAZORE': 0,
    'LAZORIK': 0,
    'LAZOS': 0,
    'LAZOTT': 0,
    'LAZOWSKI': 0,
    'LAZU': 0,
    'LAZUKA': 0,
    'LAZUR': 0,
    'LAZURE': 0,
    'LAZZAR': 0,
    'LAZZARA': 0,
    'LAZZARESCHI': 0,
    'LAZZARI': 0,
    'LAZZARINI': 0,
    'LAZZARINO': 0,
    'LAZZARO': 0,
    'LAZZARONI': 0,
    'LAZZAROTTO': 0,
    'LAZZELL': 0,
    'LAZZERI': 0,
    'LAZZERINI': 0,
    'LAZZO': 0,
    'LE': 0.06512536633018562,
    'LEA': 0.8268482490272374,
    'LEAB': 0,
    'LEABO': 0,
    'LEACH': 0,
    'LEACHMAN': 0,
    'LEACOCK': 0,
    'LEAD': 0,
    'LEADBEATER': 0,
    'LEADBETTER': 0,
    'LEADER': 0,
    'LEADERS': 0,
    'LEADFORD': 0,
    'LEADINGHAM': 0,
    'LEADLEY': 0,
    'LEADMAN': 0,
    'LEADMON': 0,
    'LEADON': 0,
    'LEADY': 0,
    'LEAF': 0,
    'LEAFBLAD': 0,
    'LEAFE': 0,
    'LEAFGREEN': 0,
    'LEAFTY': 0,
    'LEAGAN': 0,
    'LEAGER': 0,
    'LEAGUE': 0,
    'LEAH': 0.9986130374479889,
    'LEAHAN': 0,
    'LEAHEY': 0,
    'LEAHY': 0,
    'LEAIR': 0,
    'LEAIRD': 0,
    'LEAK': 0,
    'LEAKE': 0,
    'LEAKES': 0,
    'LEAKEY': 0,
    'LEAKS': 0,
    'LEAL': 0,
    'LEALE': 0,
    'LEALI': 0,
    'LEAMAN': 0,
    'LEAMER': 0,
    'LEAMING': 0,
    'LEAMON': 0,
    'LEAMONS': 0,
    'LEAMY': 0,
    'LEAN': 0.7874015748031497,
    'LEANA': 0.9708737864077669,
    'LEANDER': 0,
    'LEANDRA': 1,
    'LEANDRE': 0,
    'LEANDRES': 0,
    'LEANDRI': 0,
    'LEANDRO': 0.9132420091324202,
    'LEANDRY': 0,
    'LEANG': 0,
    'LEANHART': 0,
    'LEANN': 1,
    'LEANNA': 0.9879253567508233,
    'LEANNE': 1,
    'LEANO': 0,
    'LEANORA': 1,
    'LEANOS': 0,
    'LEANY': 0,
    'LEANZA': 0,
    'LEAO': 0,
    'LEAP': 0,
    'LEAPER': 0,
    'LEAPHART': 0,
    'LEAPHEART': 0,
    'LEAPLEY': 0,
    'LEAPLINE': 0,
    'LEAR': 0,
    'LEARD': 0,
    'LEARDI': 0,
    'LEARMAN': 0,
    'LEARMONT': 0,
    'LEARMONTH': 0,
    'LEARN': 0,
    'LEARNARD': 0,
    'LEARNED': 0,
    'LEARNER': 0,
    'LEARY': 0,
    'LEAS': 0,
    'LEASE': 0,
    'LEASER': 0,
    'LEASH': 0,
    'LEASHER': 0,
    'LEASK': 0,
    'LEASMAN': 0,
    'LEASON': 0,
    'LEASOR': 0,
    'LEASURE': 0,
    'LEAT': 0,
    'LEATCH': 0,
    'LEATH': 0,
    'LEATHA': 1,
    'LEATHAM': 0,
    'LEATHEM': 0,
    'LEATHER': 0,
    'LEATHERBARROW': 0,
    'LEATHERBERRY': 0,
    'LEATHERBURY': 0,
    'LEATHERBY': 0,
    'LEATHERMAN': 0,
    'LEATHERS': 0,
    'LEATHERWOOD': 0,
    'LEATHERY': 0,
    'LEATON': 0,
    'LEATRICE': 1,
    'LEAVELL': 0,
    'LEAVELLE': 0,
    'LEAVENGOOD': 0,
    'LEAVENS': 0,
    'LEAVENWORTH': 0,
    'LEAVER': 0,
    'LEAVERTON': 0,
    'LEAVESLEY': 0,
    'LEAVEY': 0,
    'LEAVINGS': 0,
    'LEAVINS': 0,
    'LEAVITT': 0,
    'LEAVY': 0,
    'LEAYM': 0,
    'LEAZENBY': 0,
    'LEAZER': 0,
    'LEAZIER': 0,
    'LEAZOTT': 0,
    'LEB': 0,
    'LEBA': 0,
    'LEBAHN': 0,
    'LEBAK': 0,
    'LEBAKKEN': 0,
    'LEBAN': 0,
    'LEBAR': 0,
    'LEBARD': 0,
    'LEBARIO': 0,
    'LEBARON': 0,
    'LEBARRE': 0,
    'LEBARRON': 0,
    'LEBAS': 0,
    'LEBBY': 0,
    'LEBDA': 0,
    'LEBEAU': 0,
    'LEBEAUX': 0,
    'LEBECK': 0,
    'LEBED': 0,
    'LEBEDA': 0,
    'LEBEDEV': 0,
    'LEBEGUE': 0,
    'LEBEL': 0,
    'LEBELL': 0,
    'LEBEN': 0,
    'LEBENS': 0,
    'LEBEOUF': 0,
    'LEBER': 0,
    'LEBERMAN': 0,
    'LEBERT': 0,
    'LEBEUF': 0,
    'LEBHERZ': 0,
    'LEBIANC': 0,
    'LEBLANC': 0,
    'LEBLANCE': 0,
    'LEBLANE': 0,
    'LEBLANG': 0,
    'LEBLEU': 0,
    'LEBLOND': 0,
    'LEBLUE': 0,
    'LEBO': 0,
    'LEBOEUF': 0,
    'LEBOLD': 0,
    'LEBON': 0,
    'LEBORGNE': 0,
    'LEBOUEF': 0,
    'LEBOUF': 0,
    'LEBOURDAIS': 0,
    'LEBOURGEOIS': 0,
    'LEBOUTILLIER': 0,
    'LEBOVIC': 0,
    'LEBOVITS': 0,
    'LEBOVITZ': 0,
    'LEBOW': 0,
    'LEBOWITZ': 0,
    'LEBRASSEUR': 0,
    'LEBRE': 0,
    'LEBRECHT': 0,
    'LEBRECK': 0,
    'LEBRET': 0,
    'LEBRETON': 0,
    'LEBREUX': 0,
    'LEBRON': 0,
    'LEBRUN': 0,
    'LEBSACK': 0,
    'LEBSOCK': 0,
    'LEBUS': 0,
    'LECA': 0,
    'LECAIN': 0,
    'LECAPTAIN': 0,
    'LECAROS': 0,
    'LECATES': 0,
    'LECATO': 0,
    'LECAVALIER': 0,
    'LECCA': 0,
    'LECCE': 0,
    'LECCESE': 0,
    'LECEA': 0,
    'LECESNE': 0,
    'LECH': 0,
    'LECHE': 0,
    'LECHELER': 0,
    'LECHELT': 0,
    'LECHEMINANT': 0,
    'LECHENE': 0,
    'LECHER': 0,
    'LECHIEN': 0,
    'LECHLEITER': 0,
    'LECHLEITNER': 0,
    'LECHLER': 0,
    'LECHLITER': 0,
    'LECHLITNER': 0,
    'LECHMAN': 0,
    'LECHNER': 0,
    'LECHNIR': 0,
    'LECHOWICZ': 0,
    'LECHTENBERG': 0,
    'LECHUGA': 0,
    'LECIA': 1,
    'LECIEJEWSKI': 0,
    'LECK': 0,
    'LECKBAND': 0,
    'LECKBEE': 0,
    'LECKELT': 0,
    'LECKEMBY': 0,
    'LECKENBY': 0,
    'LECKER': 0,
    'LECKEY': 0,
    'LECKIE': 0,
    'LECKINGER': 0,
    'LECKINGTON': 0,
    'LECKLIDER': 0,
    'LECKLITER': 0,
    'LECKMAN': 0,
    'LECKNER': 0,
    'LECKRON': 0,
    'LECKRONE': 0,
    'LECKY': 0,
    'LECLAIR': 0,
    'LECLAIRE': 0,
    'LECLEAR': 0,
    'LECLERC': 0,
    'LECLERCQ': 0,
    'LECLERE': 0,
    'LECLOUX': 0,
    'LECO': 0,
    'LECOCQ': 0,
    'LECOMPTE': 0,
    'LECOMTE': 0,
    'LECONA': 0,
    'LECONEY': 0,
    'LECONTE': 0,
    'LECOQ': 0,
    'LECORCHICK': 0,
    'LECORNU': 0,
    'LECOUNT': 0,
    'LECOUNTE': 0,
    'LECOUR': 0,
    'LECOURS': 0,
    'LECOURT': 0,
    'LECROIX': 0,
    'LECRONE': 0,
    'LECROY': 0,
    'LECUONA': 0,
    'LECUREUX': 0,
    'LECUYER': 0,
    'LECY': 0,
    'LECZNAR': 0,
    'LEDA': 0.986842105263158,
    'LEDAN': 0,
    'LEDAY': 0,
    'LEDBETTER': 0,
    'LEDBURY': 0,
    'LEDDA': 0,
    'LEDDEN': 0,
    'LEDDER': 0,
    'LEDDICK': 0,
    'LEDDON': 0,
    'LEDDY': 0,
    'LEDE': 0,
    'LEDEBOER': 0,
    'LEDEBUHR': 0,
    'LEDEE': 0,
    'LEDEN': 0,
    'LEDER': 0,
    'LEDERER': 0,
    'LEDERGERBER': 0,
    'LEDERHAUS': 0,
    'LEDERHOS': 0,
    'LEDERHOUSE': 0,
    'LEDERLE': 0,
    'LEDERMAN': 0,
    'LEDERMANN': 0,
    'LEDESMA': 0,
    'LEDET': 0,
    'LEDEZMA': 0,
    'LEDFORD': 0,
    'LEDGARD': 0,
    'LEDGER': 0,
    'LEDGERWOOD': 0,
    'LEDGISTER': 0,
    'LEDIG': 0,
    'LEDIN': 0,
    'LEDING': 0,
    'LEDINGHAM': 0,
    'LEDINGTON': 0,
    'LEDKINS': 0,
    'LEDLEY': 0,
    'LEDLOW': 0,
    'LEDMAN': 0,
    'LEDNICKY': 0,
    'LEDNUM': 0,
    'LEDO': 0,
    'LEDOGAR': 0,
    'LEDON': 0,
    'LEDONNE': 0,
    'LEDOUX': 0,
    'LEDREW': 0,
    'LEDSINGER': 0,
    'LEDSOME': 0,
    'LEDUC': 0,
    'LEDUE': 0,
    'LEDUFF': 0,
    'LEDUKE': 0,
    'LEDVINA': 0,
    'LEDWARD': 0,
    'LEDWELL': 0,
    'LEDWIDGE': 0,
    'LEDWIG': 0,
    'LEDWITH': 0,
    'LEDWON': 0,
    'LEDY': 0,
    'LEDYARD': 0,
    'LEE': 0.486757009986517,
    'LEEANN': 1,
    'LEEANNA': 1,
    'LEEANNE': 1,
    'LEEB': 0,
    'LEEBER': 0,
    'LEEBRICK': 0,
    'LEECE': 0,
    'LEECH': 0,
    'LEEDER': 0,
    'LEEDHAM': 0,
    'LEEDLE': 0,
    'LEEDOM': 0,
    'LEEDS': 0,
    'LEEDY': 0,
    'LEEGE': 0,
    'LEEHAN': 0,
    'LEEHY': 0,
    'LEEK': 0,
    'LEEKA': 0,
    'LEEKE': 0,
    'LEEKER': 0,
    'LEEKLEY': 0,
    'LEEKS': 0,
    'LEELAND': 0,
    'LEELING': 0,
    'LEEMAN': 0,
    'LEEMASTER': 0,
    'LEEMHUIS': 0,
    'LEEMING': 0,
    'LEEMON': 0,
    'LEEN': 0,
    'LEENA': 1,
    'LEENDERS': 0,
    'LEENERTS': 0,
    'LEENEY': 0,
    'LEENHOUTS': 0,
    'LEEP': 0,
    'LEEPER': 0,
    'LEER': 0,
    'LEERHOFF': 0,
    'LEERS': 0,
    'LEERSSEN': 0,
    'LEES': 0,
    'LEESA': 1,
    'LEESE': 0,
    'LEESEBERG': 0,
    'LEESER': 0,
    'LEESMAN': 0,
    'LEESON': 0,
    'LEESTMA': 0,
    'LEET': 0,
    'LEETCH': 0,
    'LEETE': 0,
    'LEETH': 0,
    'LEETHAM': 0,
    'LEETS': 0,
    'LEETZ': 0,
    'LEEUW': 0,
    'LEEVER': 0,
    'LEEVY': 0,
    'LEEWRIGHT': 0,
    'LEEZER': 0,
    'LEFAIVE': 0,
    'LEFAIVRE': 0,
    'LEFAN': 0,
    'LEFANTE': 0,
    'LEFAVE': 0,
    'LEFAVOR': 0,
    'LEFAVOUR': 0,
    'LEFCOURT': 0,
    'LEFEBER': 0,
    'LEFEBRE': 0,
    'LEFEBURE': 0,
    'LEFEBVRE': 0,
    'LEFELD': 0,
    'LEFERE': 0,
    'LEFEVER': 0,
    'LEFEVERE': 0,
    'LEFEVERS': 0,
    'LEFEVRE': 0,
    'LEFF': 0,
    'LEFFALL': 0,
    'LEFFEL': 0,
    'LEFFELMAN': 0,
    'LEFFERS': 0,
    'LEFFERT': 0,
    'LEFFERTS': 0,
    'LEFFEW': 0,
    'LEFFINGWELL': 0,
    'LEFFLER': 0,
    'LEFFORGE': 0,
    'LEFKO': 0,
    'LEFKOVITS': 0,
    'LEFKOVITZ': 0,
    'LEFKOWITZ': 0,
    'LEFLAR': 0,
    'LEFLER': 0,
    'LEFLEUR': 0,
    'LEFLORE': 0,
    'LEFOR': 0,
    'LEFORCE': 0,
    'LEFORE': 0,
    'LEFORGE': 0,
    'LEFORS': 0,
    'LEFORT': 0,
    'LEFRANC': 0,
    'LEFRANCOIS': 0,
    'LEFROIS': 0,
    'LEFT': 0,
    'LEFTENANT': 0,
    'LEFTHAND': 0,
    'LEFTON': 0,
    'LEFTRIDGE': 0,
    'LEFTWICH': 0,
    'LEFURGE': 0,
    'LEGA': 0,
    'LEGACY': 0,
    'LEGAGNEUR': 0,
    'LEGAKIS': 0,
    'LEGAL': 0,
    'LEGALL': 0,
    'LEGAN': 0,
    'LEGANS': 0,
    'LEGARD': 0,
    'LEGARDA': 0,
    'LEGARDE': 0,
    'LEGARE': 0,
    'LEGARRETA': 0,
    'LEGAS': 0,
    'LEGASPI': 0,
    'LEGASSE': 0,
    'LEGASSEY': 0,
    'LEGASSIE': 0,
    'LEGAT': 0,
    'LEGATE': 0,
    'LEGATES': 0,
    'LEGATH': 0,
    'LEGATO': 0,
    'LEGATT': 0,
    'LEGAULT': 0,
    'LEGAUX': 0,
    'LEGAY': 0,
    'LEGE': 0,
    'LEGEAR': 0,
    'LEGEL': 0,
    'LEGENDRE': 0,
    'LEGENZA': 0,
    'LEGER': 0,
    'LEGERE': 0,
    'LEGERME': 0,
    'LEGERSKI': 0,
    'LEGESSE': 0,
    'LEGETT': 0,
    'LEGETTE': 0,
    'LEGEYT': 0,
    'LEGG': 0,
    'LEGGANS': 0,
    'LEGGAT': 0,
    'LEGGE': 0,
    'LEGGET': 0,
    'LEGGETT': 0,
    'LEGGETTE': 0,
    'LEGGIERI': 0,
    'LEGGIERO': 0,
    'LEGGIN': 0,
    'LEGGINS': 0,
    'LEGGIO': 0,
    'LEGGITT': 0,
    'LEGGOTT': 0,
    'LEGGS': 0,
    'LEGHORN': 0,
    'LEGIER': 0,
    'LEGION': 0,
    'LEGLEITER': 0,
    'LEGLER': 0,
    'LEGNER': 0,
    'LEGNON': 0,
    'LEGO': 0,
    'LEGOFF': 0,
    'LEGON': 0,
    'LEGORE': 0,
    'LEGORRETA': 0,
    'LEGOWSKI': 0,
    'LEGRA': 0,
    'LEGRAND': 0,
    'LEGRANDE': 0,
    'LEGRANGE': 0,
    'LEGRANT': 0,
    'LEGREE': 0,
    'LEGRIS': 0,
    'LEGRO': 0,
    'LEGRONE': 0,
    'LEGROS': 0,
    'LEGROW': 0,
    'LEGUE': 0,
    'LEGUIZAMO': 0,
    'LEGUIZAMON': 0,
    'LEGUM': 0,
    'LEGUTKO': 0,
    'LEH': 0,
    'LEHAN': 0,
    'LEHANE': 0,
    'LEHAR': 0,
    'LEHDE': 0,
    'LEHE': 0,
    'LEHECKA': 0,
    'LEHENBAUER': 0,
    'LEHENY': 0,
    'LEHER': 0,
    'LEHEW': 0,
    'LEHFELDT': 0,
    'LEHI': 0,
    'LEHIGH': 0,
    'LEHL': 0,
    'LEHMAN': 0,
    'LEHMANN': 0,
    'LEHMBECK': 0,
    'LEHMBERG': 0,
    'LEHMEN': 0,
    'LEHMER': 0,
    'LEHMKUHL': 0,
    'LEHMKUHLE': 0,
    'LEHMKUHLER': 0,
    'LEHN': 0,
    'LEHNE': 0,
    'LEHNEN': 0,
    'LEHNER': 0,
    'LEHNERT': 0,
    'LEHNERTZ': 0,
    'LEHNERZ': 0,
    'LEHNHARDT': 0,
    'LEHNHERR': 0,
    'LEHNHOFF': 0,
    'LEHNING': 0,
    'LEHOCKY': 0,
    'LEHOTSKY': 0,
    'LEHOUILLIER': 0,
    'LEHOUX': 0,
    'LEHR': 0,
    'LEHRER': 0,
    'LEHRFELD': 0,
    'LEHRKAMP': 0,
    'LEHRKE': 0,
    'LEHRMAN': 0,
    'LEHRMANN': 0,
    'LEHSTEN': 0,
    'LEHTI': 0,
    'LEHTINEN': 0,
    'LEHTO': 0,
    'LEHTOLA': 0,
    'LEHTONEN': 0,
    'LEI': 0,
    'LEIA': 1,
    'LEIALOHA': 0,
    'LEIATAUA': 0,
    'LEIATO': 0,
    'LEIB': 0,
    'LEIBA': 0,
    'LEIBACH': 0,
    'LEIBBRAND': 0,
    'LEIBBRANDT': 0,
    'LEIBE': 0,
    'LEIBEE': 0,
    'LEIBEL': 0,
    'LEIBENGUTH': 0,
    'LEIBENSPERGER': 0,
    'LEIBER': 0,
    'LEIBERT': 0,
    'LEIBFORTH': 0,
    'LEIBFRIED': 0,
    'LEIBHAM': 0,
    'LEIBHART': 0,
    'LEIBIG': 0,
    'LEIBL': 0,
    'LEIBLE': 0,
    'LEIBMAN': 0,
    'LEIBOLD': 0,
    'LEIBOVICH': 0,
    'LEIBOVITZ': 0,
    'LEIBOW': 0,
    'LEIBOWITZ': 0,
    'LEIBRAND': 0,
    'LEIBRANDT': 0,
    'LEIBROCK': 0,
    'LEIBSON': 0,
    'LEIBY': 0,
    'LEICESTER': 0,
    'LEICH': 0,
    'LEICHER': 0,
    'LEICHLITER': 0,
    'LEICHMAN': 0,
    'LEICHNER': 0,
    'LEICHSENRING': 0,
    'LEICHT': 0,
    'LEICHTER': 0,
    'LEICHTFUSS': 0,
    'LEICHTLE': 0,
    'LEICHTMAN': 0,
    'LEICHTNAM': 0,
    'LEICHTY': 0,
    'LEICK': 0,
    'LEID': 0,
    'LEIDA': 1,
    'LEIDAL': 0,
    'LEIDE': 0,
    'LEIDECKER': 0,
    'LEIDEL': 0,
    'LEIDEN': 0,
    'LEIDENFROST': 0,
    'LEIDENHEIMER': 0,
    'LEIDER': 0,
    'LEIDERMAN': 0,
    'LEIDHOLDT': 0,
    'LEIDHOLM': 0,
    'LEIDHOLT': 0,
    'LEIDICH': 0,
    'LEIDIG': 0,
    'LEIDIGH': 0,
    'LEIDING': 0,
    'LEIDINGER': 0,
    'LEIDNER': 0,
    'LEIDOLF': 0,
    'LEIDY': 0,
    'LEIENDECKER': 0,
    'LEIER': 0,
    'LEIF': 0.963855421686747,
    'LEIFELD': 0,
    'LEIFER': 0,
    'LEIFERMAN': 0,
    'LEIFERT': 0,
    'LEIFESTE': 0,
    'LEIFFER': 0,
    'LEIFHEIT': 0,
    'LEIFKER': 0,
    'LEIFSON': 0,
    'LEIGEBER': 0,
    'LEIGEY': 0,
    'LEIGH': 0.9086320040383644,
    'LEIGHA': 1,
    'LEIGHANN': 1,
    'LEIGHOW': 0,
    'LEIGHT': 0,
    'LEIGHTNER': 0,
    'LEIGHTON': 0,
    'LEIGHTY': 0,
    'LEIH': 0,
    'LEIJA': 0,
    'LEIK': 0,
    'LEIKAM': 0,
    'LEIKER': 0,
    'LEIKNESS': 0,
    'LEILA': 1,
    'LEILANI': 1,
    'LEILI': 0,
    'LEIMAN': 0,
    'LEIMBACH': 0,
    'LEIMER': 0,
    'LEIMGRUBER': 0,
    'LEIMKUEHLER': 0,
    'LEIMKUHLER': 0,
    'LEIN': 0,
    'LEINART': 0,
    'LEINBACH': 0,
    'LEINBAUGH': 0,
    'LEINBERGER': 0,
    'LEINDECKER': 0,
    'LEINEN': 0,
    'LEINENBACH': 0,
    'LEINER': 0,
    'LEINES': 0,
    'LEINEWEBER': 0,
    'LEINGANG': 0,
    'LEINHAUSER': 0,
    'LEINHEISER': 0,
    'LEINING': 0,
    'LEININGER': 0,
    'LEINO': 0,
    'LEINONEN': 0,
    'LEINS': 0,
    'LEINTZ': 0,
    'LEINWAND': 0,
    'LEINWEBER': 0,
    'LEIP': 0,
    'LEIPER': 0,
    'LEIPERT': 0,
    'LEIPHART': 0,
    'LEIPOLD': 0,
    'LEIPZIG': 0,
    'LEIRAN': 0,
    'LEIRD': 0,
    'LEIRER': 0,
    'LEIS': 0,
    'LEISA': 1,
    'LEISCH': 0,
    'LEISCHNER': 0,
    'LEISE': 0,
    'LEISEN': 0,
    'LEISENRING': 0,
    'LEISER': 0,
    'LEISETH': 0,
    'LEISEY': 0,
    'LEISGANG': 0,
    'LEISHA': 1,
    'LEISHEAR': 0,
    'LEISHER': 0,
    'LEISHMAN': 0,
    'LEISING': 0,
    'LEISINGER': 0,
    'LEISMAN': 0,
    'LEISNER': 0,
    'LEISS': 0,
    'LEISSNER': 0,
    'LEIST': 0,
    'LEISTEN': 0,
    'LEISTER': 0,
    'LEISTICO': 0,
    'LEISTIKO': 0,
    'LEISTIKOW': 0,
    'LEISTNER': 0,
    'LEISURE': 0,
    'LEISY': 0,
    'LEISZ': 0,
    'LEITAO': 0,
    'LEITCH': 0,
    'LEITE': 0,
    'LEITENBERGER': 0,
    'LEITER': 0,
    'LEITERMAN': 0,
    'LEITERMANN': 0,
    'LEITGEB': 0,
    'LEITH': 0,
    'LEITHAUSER': 0,
    'LEITHEAD': 0,
    'LEITHEISER': 0,
    'LEITHER': 0,
    'LEITHNER': 0,
    'LEITING': 0,
    'LEITL': 0,
    'LEITMAN': 0,
    'LEITNER': 0,
    'LEITSCH': 0,
    'LEITSCHUH': 0,
    'LEITZ': 0,
    'LEITZEL': 0,
    'LEITZELL': 0,
    'LEITZEN': 0,
    'LEITZINGER': 0,
    'LEITZKE': 0,
    'LEITZMAN': 0,
    'LEIVA': 0,
    'LEIVAN': 0,
    'LEIVAS': 0,
    'LEIX': 0,
    'LEIZEAR': 0,
    'LEJA': 0,
    'LEJANO': 0,
    'LEJEUNE': 0,
    'LEJMAN': 0,
    'LEJUNE': 0,
    'LEK': 0,
    'LEKA': 0,
    'LEKAJ': 0,
    'LEKAN': 0,
    'LEKANDER': 0,
    'LEKARCZYK': 0,
    'LEKAS': 0,
    'LEKER': 0,
    'LEKIC': 0,
    'LEKISHA': 1,
    'LEKKAS': 0,
    'LEKKI': 0,
    'LEKO': 0,
    'LELA': 0.9982174688057041,
    'LELACHEUR': 0,
    'LELAH': 1,
    'LELAND': 0.9397841977027498,
    'LELE': 0,
    'LELEA': 0,
    'LELEAUX': 0,
    'LELEK': 0,
    'LELEUX': 0,
    'LELI': 0,
    'LELIA': 1,
    'LELIEVRE': 0,
    'LELIS': 0,
    'LELITO': 0,
    'LELKO': 0,
    'LELL': 0,
    'LELLA': 0,
    'LELLE': 0,
    'LELLI': 0,
    'LELLIS': 0,
    'LELLO': 0,
    'LELM': 0,
    'LELO': 0,
    'LELONEK': 0,
    'LELONG': 0,
    'LELOUP': 0,
    'LEM': 0,
    'LEMA': 0,
    'LEMACKS': 0,
    'LEMAHIEU': 0,
    'LEMAIRE': 0,
    'LEMAITRE': 0,
    'LEMAK': 0,
    'LEMAN': 0,
    'LEMANCZYK': 0,
    'LEMANN': 0,
    'LEMANOWICZ': 0,
    'LEMANSKI': 0,
    'LEMANSKY': 0,
    'LEMAR': 0,
    'LEMARBE': 0,
    'LEMARIE': 0,
    'LEMARR': 0,
    'LEMAS': 0,
    'LEMASTER': 0,
    'LEMASTERS': 0,
    'LEMAY': 0,
    'LEMBACH': 0,
    'LEMBCKE': 0,
    'LEMBECK': 0,
    'LEMBERG': 0,
    'LEMBERGER': 0,
    'LEMBESIS': 0,
    'LEMBKE': 0,
    'LEMBO': 0,
    'LEMBRICK': 0,
    'LEMBURG': 0,
    'LEMCKE': 0,
    'LEMCOOL': 0,
    'LEMEK': 0,
    'LEMEL': 0,
    'LEMELIN': 0,
    'LEMELLE': 0,
    'LEMEN': 0,
    'LEMENAGER': 0,
    'LEMENS': 0,
    'LEMENSE': 0,
    'LEMER': 0,
    'LEMERAND': 0,
    'LEMERE': 0,
    'LEMERISE': 0,
    'LEMEROND': 0,
    'LEMERT': 0,
    'LEMERY': 0,
    'LEMES': 0,
    'LEMIER': 0,
    'LEMIESZ': 0,
    'LEMIEUR': 0,
    'LEMIEUX': 0,
    'LEMIN': 0,
    'LEMING': 0,
    'LEMINGS': 0,
    'LEMIRE': 0,
    'LEMISH': 0,
    'LEMKA': 0,
    'LEMKAU': 0,
    'LEMKE': 0,
    'LEMKEN': 0,
    'LEMKER': 0,
    'LEMKIN': 0,
    'LEMKUIL': 0,
    'LEMLE': 0,
    'LEMLER': 0,
    'LEMLEY': 0,
    'LEMLY': 0,
    'LEMM': 0,
    'LEMMA': 0,
    'LEMME': 0,
    'LEMMEL': 0,
    'LEMMEN': 0,
    'LEMMENES': 0,
    'LEMMENS': 0,
    'LEMMER': 0,
    'LEMMERMAN': 0,
    'LEMMERMANN': 0,
    'LEMMERS': 0,
    'LEMMERT': 0,
    'LEMMING': 0,
    'LEMMINGS': 0,
    'LEMMO': 0,
    'LEMMON': 0,
    'LEMMOND': 0,
    'LEMMONDS': 0,
    'LEMMONS': 0,
    'LEMNAH': 0,
    'LEMOI': 0,
    'LEMOINE': 0,
    'LEMON': 0,
    'LEMONCELLI': 0,
    'LEMOND': 0,
    'LEMONDE': 0,
    'LEMONDS': 0,
    'LEMONE': 0,
    'LEMONIER': 0,
    'LEMONNIER': 0,
    'LEMONS': 0,
    'LEMONT': 0,
    'LEMONTE': 0,
    'LEMOS': 0,
    'LEMOYNE': 0,
    'LEMP': 0,
    'LEMPA': 0,
    'LEMPERT': 0,
    'LEMPICKI': 0,
    'LEMPKA': 0,
    'LEMPKE': 0,
    'LEMS': 0,
    'LEMUEL': 0.9900990099009901,
    'LEMUNYON': 0,
    'LEMUS': 0,
    'LEMUZ': 0,
    'LEN': 0.9280742459396751,
    'LENA': 0.9954751131221719,
    'LENABURG': 0,
    'LENAGHAN': 0,
    'LENAHAN': 0,
    'LENAMOND': 0,
    'LENANDER': 0,
    'LENANE': 0,
    'LENAR': 0,
    'LENARD': 0.8156606851549756,
    'LENARDSON': 0,
    'LENARES': 0,
    'LENART': 0,
    'LENARTOWICZ': 0,
    'LENARTZ': 0,
    'LENARZ': 0,
    'LENAU': 0,
    'LENBERG': 0,
    'LENCE': 0,
    'LENCH': 0,
    'LENCHNER': 0,
    'LENCI': 0,
    'LENCIONI': 0,
    'LENCKI': 0,
    'LENCZEWSKI': 0,
    'LENDA': 0,
    'LENDE': 0,
    'LENDER': 0,
    'LENDERINK': 0,
    'LENDERMAN': 0,
    'LENDERMON': 0,
    'LENDINO': 0,
    'LENDMAN': 0,
    'LENDO': 0,
    'LENDON': 0,
    'LENDRUM': 0,
    'LENDT': 0,
    'LENDVAY': 0,
    'LENDWAY': 0,
    'LENDZION': 0,
    'LENE': 0,
    'LENEAR': 0,
    'LENEAU': 0,
    'LENEAVE': 0,
    'LENEHAN': 0,
    'LENER': 0,
    'LENERS': 0,
    'LENERT': 0,
    'LENERTZ': 0,
    'LENES': 0,
    'LENEY': 0,
    'LENFEST': 0,
    'LENFESTEY': 0,
    'LENG': 0,
    'LENGA': 0,
    'LENGACHER': 0,
    'LENGE': 0,
    'LENGEFELD': 0,
    'LENGEL': 0,
    'LENGEN': 0,
    'LENGER': 0,
    'LENGERICH': 0,
    'LENGKEEK': 0,
    'LENGLE': 0,
    'LENGUA': 0,
    'LENGUYEN': 0,
    'LENGYEL': 0,
    'LENH': 0,
    'LENHARD': 0,
    'LENHARDT': 0,
    'LENHART': 0,
    'LENHERR': 0,
    'LENHERT': 0,
    'LENHOF': 0,
    'LENHOFF': 0,
    'LENICH': 0,
    'LENICK': 0,
    'LENIG': 0,
    'LENIGAR': 0,
    'LENIGER': 0,
    'LENIHAN': 0,
    'LENIK': 0,
    'LENING': 0,
    'LENINGTON': 0,
    'LENIO': 0,
    'LENIOR': 0,
    'LENIS': 0,
    'LENITA': 1,
    'LENIUS': 0,
    'LENIX': 0,
    'LENK': 0,
    'LENKE': 0,
    'LENKER': 0,
    'LENKEY': 0,
    'LENKIEWICZ': 0,
    'LENKNER': 0,
    'LENKO': 0,
    'LENKOWSKI': 0,
    'LENLING': 0,
    'LENN': 0,
    'LENNA': 0.9803921568627452,
    'LENNAN': 0,
    'LENNARD': 0,
    'LENNARTSON': 0,
    'LENNARTZ': 0,
    'LENNEMAN': 0,
    'LENNEMANN': 0,
    'LENNEN': 0,
    'LENNER': 0,
    'LENNERT': 0,
    'LENNERTZ': 0,
    'LENNEX': 0,
    'LENNEY': 0,
    'LENNICK': 0,
    'LENNIE': 0.9615384615384616,
    'LENNING': 0,
    'LENNINGER': 0,
    'LENNINGTON': 0,
    'LENNIX': 0,
    'LENNON': 0,
    'LENNOX': 0,
    'LENNY': 0.9823182711198428,
    'LENO': 0,
    'LENOBLE': 0,
    'LENOCH': 0,
    'LENOCI': 0,
    'LENOCKER': 0,
    'LENOIR': 0,
    'LENON': 0,
    'LENOR': 0,
    'LENORA': 1,
    'LENORD': 0,
    'LENORE': 0.9943181818181819,
    'LENORMAND': 0,
    'LENOS': 0,
    'LENOUE': 0,
    'LENOVER': 0,
    'LENOX': 0,
    'LENS': 0,
    'LENSCH': 0,
    'LENSE': 0,
    'LENSER': 0,
    'LENSING': 0,
    'LENSINK': 0,
    'LENSKI': 0,
    'LENSKY': 0,
    'LENSMIRE': 0,
    'LENSON': 0,
    'LENSSEN': 0,
    'LENT': 0,
    'LENTE': 0,
    'LENTES': 0,
    'LENTH': 0,
    'LENTHE': 0,
    'LENTI': 0,
    'LENTINE': 0,
    'LENTINI': 0,
    'LENTINO': 0,
    'LENTNER': 0,
    'LENTO': 0,
    'LENTON': 0,
    'LENTS': 0,
    'LENTSCH': 0,
    'LENTZ': 0,
    'LENWAY': 0,
    'LENY': 0,
    'LENZ': 0,
    'LENZA': 0,
    'LENZE': 0,
    'LENZEN': 0,
    'LENZER': 0,
    'LENZI': 0,
    'LENZIE': 0,
    'LENZINI': 0,
    'LENZMEIER': 0,
    'LENZNER': 0,
    'LENZO': 0,
    'LENZY': 0,
    'LEO': 0.9742329053992534,
    'LEOCADIO': 0,
    'LEOGRANDE': 0,
    'LEOHR': 0,
    'LEOLA': 1,
    'LEOMA': 1,
    'LEOMBRUNO': 0,
    'LEON': 0.8308823529411765,
    'LEONA': 0.999131190269331,
    'LEONARD': 0.8490436846670014,
    'LEONARDA': 1,
    'LEONARDELLI': 0,
    'LEONARDI': 0,
    'LEONARDINI': 0,
    'LEONARDIS': 0,
    'LEONARDO': 0.9036144578313252,
    'LEONARDS': 0,
    'LEONARDSON': 0,
    'LEONBERGER': 0,
    'LEONCE': 0,
    'LEONCINI': 0,
    'LEONCIO': 0,
    'LEONE': 0.4725897920604915,
    'LEONEL': 0.9937888198757764,
    'LEONELLI': 0,
    'LEONEN': 0,
    'LEONES': 0,
    'LEONESIO': 0,
    'LEONETTI': 0,
    'LEONG': 0,
    'LEONGUERRERO': 0,
    'LEONHARD': 0,
    'LEONHARDT': 0,
    'LEONHART': 0,
    'LEONI': 0,
    'LEONIA': 1,
    'LEONIDA': 0.9615384615384616,
    'LEONIDAS': 0,
    'LEONIDES': 0,
    'LEONIE': 1,
    'LEONILA': 1,
    'LEONIS': 0,
    'LEONOR': 0.9784735812133073,
    'LEONORA': 1,
    'LEONORE': 1,
    'LEONOV': 0,
    'LEONOWICZ': 0,
    'LEONTI': 0,
    'LEONTINE': 1,
    'LEONZO': 0,
    'LEOPARD': 0,
    'LEOPARDI': 0,
    'LEOPOLD': 0,
    'LEOPOLDO': 0.9884678747940693,
    'LEORA': 1,
    'LEOS': 0,
    'LEOTA': 0.9787928221859706,
    'LEOTTA': 0,
    'LEOW': 0,
    'LEPA': 0,
    'LEPAGE': 0,
    'LEPAK': 0,
    'LEPARD': 0,
    'LEPCZYK': 0,
    'LEPE': 0,
    'LEPERA': 0,
    'LEPERE': 0,
    'LEPES': 0,
    'LEPEZ': 0,
    'LEPHART': 0,
    'LEPHEW': 0,
    'LEPIANE': 0,
    'LEPIANKA': 0,
    'LEPIEN': 0,
    'LEPIK': 0,
    'LEPINE': 0,
    'LEPINSKI': 0,
    'LEPIRE': 0,
    'LEPISTO': 0,
    'LEPKE': 0,
    'LEPKOWSKI': 0,
    'LEPLEY': 0,
    'LEPO': 0,
    'LEPOIDEVIN': 0,
    'LEPOLD': 0,
    'LEPONE': 0,
    'LEPORATI': 0,
    'LEPORE': 0,
    'LEPORI': 0,
    'LEPORT': 0,
    'LEPOSA': 0,
    'LEPOW': 0,
    'LEPP': 0,
    'LEPPALA': 0,
    'LEPPANEN': 0,
    'LEPPARD': 0,
    'LEPPEK': 0,
    'LEPPER': 0,
    'LEPPERT': 0,
    'LEPPIEN': 0,
    'LEPPIN': 0,
    'LEPPING': 0,
    'LEPPINK': 0,
    'LEPPKE': 0,
    'LEPPLA': 0,
    'LEPPO': 0,
    'LEPRE': 0,
    'LEPREE': 0,
    'LEPREVOST': 0,
    'LEPRI': 0,
    'LEPRO': 0,
    'LEPS': 0,
    'LEPSCH': 0,
    'LEPSON': 0,
    'LEPTICH': 0,
    'LEQUE': 0,
    'LEQUIA': 0,
    'LEQUIRE': 0,
    'LER': 0,
    'LERA': 0.9478672985781991,
    'LERAAS': 0,
    'LERARIO': 0,
    'LERAY': 0,
    'LERCARA': 0,
    'LERCH': 0,
    'LERCHE': 0,
    'LERCHER': 0,
    'LERDAHL': 0,
    'LERDAL': 0,
    'LERE': 0,
    'LEREBOURS': 0,
    'LERENA': 0,
    'LERER': 0,
    'LERETTE': 0,
    'LEREW': 0,
    'LERFALD': 0,
    'LERG': 0,
    'LERI': 0,
    'LERICHE': 0,
    'LERILLE': 0,
    'LERITZ': 0,
    'LERMA': 0,
    'LERMAN': 0,
    'LERMOND': 0,
    'LERNER': 0,
    'LERO': 0,
    'LEROHL': 0,
    'LEROSE': 0,
    'LEROUGE': 0,
    'LEROUX': 0,
    'LEROY': 0.9780142398873327,
    'LERRO': 0,
    'LERSCH': 0,
    'LERTORA': 0,
    'LERUD': 0,
    'LERUM': 0,
    'LERVICK': 0,
    'LERVIK': 0,
    'LERVOLD': 0,
    'LERWICK': 0,
    'LERWILL': 0,
    'LERZ': 0,
    'LES': 0.975609756097561,
    'LESA': 0.9925558312655087,
    'LESACA': 0,
    'LESAGE': 0,
    'LESAK': 0,
    'LESAN': 0,
    'LESANE': 0,
    'LESAR': 0,
    'LESCALLEET': 0,
    'LESCANO': 0,
    'LESCARBEAU': 0,
    'LESCAULT': 0,
    'LESCH': 0,
    'LESCHAK': 0,
    'LESCHBER': 0,
    'LESCHER': 0,
    'LESCHINSKI': 0,
    'LESCHINSKY': 0,
    'LESCHKE': 0,
    'LESCO': 0,
    'LESCOE': 0,
    'LESCZYNSKI': 0,
    'LESE': 0,
    'LESEBERG': 0,
    'LESEMAN': 0,
    'LESEMANN': 0,
    'LESER': 0,
    'LESESNE': 0,
    'LESH': 0,
    'LESHA': 1,
    'LESHANE': 0,
    'LESHAY': 0,
    'LESHE': 0,
    'LESHER': 0,
    'LESHIN': 0,
    'LESHINSKI': 0,
    'LESHINSKY': 0,
    'LESHKO': 0,
    'LESHNER': 0,
    'LESHO': 0,
    'LESHOCK': 0,
    'LESHORE': 0,
    'LESIA': 1,
    'LESIAK': 0,
    'LESICA': 0,
    'LESICKO': 0,
    'LESIEUR': 0,
    'LESIKAR': 0,
    'LESINSKI': 0,
    'LESJAK': 0,
    'LESKA': 0,
    'LESKANIC': 0,
    'LESKE': 0,
    'LESKI': 0,
    'LESKIN': 0,
    'LESKINEN': 0,
    'LESKO': 0,
    'LESKOVAR': 0,
    'LESKOVEC': 0,
    'LESKOW': 0,
    'LESKY': 0,
    'LESLEE': 1,
    'LESLEIN': 0,
    'LESLEY': 0.9555463232239303,
    'LESLI': 1,
    'LESLIE': 0.9631147540983608,
    'LESLY': 0,
    'LESMAN': 0,
    'LESMEISTER': 0,
    'LESMERISES': 0,
    'LESMES': 0,
    'LESNAK': 0,
    'LESNAR': 0,
    'LESNAU': 0,
    'LESNER': 0,
    'LESNESKI': 0,
    'LESNETT': 0,
    'LESNEY': 0,
    'LESNIAK': 0,
    'LESNICK': 0,
    'LESNICKI': 0,
    'LESNIEWICZ': 0,
    'LESNIEWSKI': 0,
    'LESNIK': 0,
    'LESNY': 0,
    'LESO': 0,
    'LESOINE': 0,
    'LESON': 0,
    'LESPERANCE': 0,
    'LESPIER': 0,
    'LESPINASSE': 0,
    'LESPRON': 0,
    'LESS': 0,
    'LESSA': 0,
    'LESSANE': 0,
    'LESSAR': 0,
    'LESSARD': 0,
    'LESSEL': 0,
    'LESSEN': 0,
    'LESSENBERRY': 0,
    'LESSER': 0,
    'LESSERT': 0,
    'LESSEY': 0,
    'LESSICK': 0,
    'LESSIE': 0.9950248756218906,
    'LESSIG': 0,
    'LESSIN': 0,
    'LESSING': 0,
    'LESSLER': 0,
    'LESSLEY': 0,
    'LESSLIE': 0,
    'LESSMAN': 0,
    'LESSMANN': 0,
    'LESSNAU': 0,
    'LESSNER': 0,
    'LESSO': 0,
    'LESSON': 0,
    'LESSOR': 0,
    'LESTAGE': 0,
    'LESTENKOF': 0,
    'LESTER': 0.8496490579977835,
    'LESTINA': 0,
    'LESTINGI': 0,
    'LESTON': 0,
    'LESTOURGEON': 0,
    'LESTRADE': 0,
    'LESTRANGE': 0,
    'LESUER': 0,
    'LESUEUR': 0,
    'LESURE': 0,
    'LESZCYNSKI': 0,
    'LESZCZYNSKI': 0,
    'LET': 0,
    'LETA': 0.9888751545117429,
    'LETANG': 0,
    'LETARTE': 0,
    'LETBETTER': 0,
    'LETCHER': 0,
    'LETCHFORD': 0,
    'LETCHWORTH': 0,
    'LETE': 0,
    'LETEFF': 0,
    'LETELLIER': 0,
    'LETENDRE': 0,
    'LETH': 0,
    'LETHA': 1,
    'LETHAM': 0,
    'LETHBRIDGE': 0,
    'LETHCO': 0,
    'LETHCOE': 0,
    'LETHER': 0,
    'LETHERMAN': 0,
    'LETHI': 0,
    'LETICIA': 1,
    'LETISHA': 1,
    'LETITIA': 1,
    'LETIZIA': 0,
    'LETIZIO': 0,
    'LETKE': 0,
    'LETKIEWICZ': 0,
    'LETKO': 0,
    'LETLOW': 0,
    'LETMAN': 0,
    'LETNER': 0,
    'LETNEY': 0,
    'LETO': 0,
    'LETOILE': 0,
    'LETONA': 0,
    'LETOURNEAU': 0,
    'LETRAN': 0,
    'LETSCH': 0,
    'LETSCHE': 0,
    'LETSCHER': 0,
    'LETSINGER': 0,
    'LETSON': 0,
    'LETSOS': 0,
    'LETT': 0,
    'LETTA': 0,
    'LETTAU': 0,
    'LETTE': 0,
    'LETTEER': 0,
    'LETTENBERGER': 0,
    'LETTENEY': 0,
    'LETTENMAIER': 0,
    'LETTER': 0,
    'LETTERA': 0,
    'LETTERI': 0,
    'LETTERLE': 0,
    'LETTERLY': 0,
    'LETTERMAN': 0,
    'LETTICH': 0,
    'LETTIE': 0.9917355371900827,
    'LETTIERE': 0,
    'LETTIERI': 0,
    'LETTIS': 0,
    'LETTMAN': 0,
    'LETTNER': 0,
    'LETTO': 0,
    'LETTON': 0,
    'LETTOW': 0,
    'LETTRE': 0,
    'LETTRICH': 0,
    'LETTS': 0,
    'LETTSOME': 0,
    'LETTY': 1,
    'LETULLE': 0,
    'LETURGEZ': 0,
    'LETZ': 0,
    'LETZELTER': 0,
    'LETZKUS': 0,
    'LETZRING': 0,
    'LEU': 0,
    'LEUBNER': 0,
    'LEUCI': 0,
    'LEUCK': 0,
    'LEUENBERGER': 0,
    'LEUER': 0,
    'LEUGERS': 0,
    'LEUKHARDT': 0,
    'LEUM': 0,
    'LEUNG': 0,
    'LEUPOLD': 0,
    'LEUPP': 0,
    'LEURQUIN': 0,
    'LEUS': 0,
    'LEUSCHEN': 0,
    'LEUSCHNER': 0,
    'LEUSINK': 0,
    'LEUTE': 0,
    'LEUTERIO': 0,
    'LEUTHAUSER': 0,
    'LEUTHNER': 0,
    'LEUTHOLD': 0,
    'LEUTWYLER': 0,
    'LEUTY': 0,
    'LEUTZ': 0,
    'LEUTZINGER': 0,
    'LEUZE': 0,
    'LEUZINGER': 0,
    'LEUZZI': 0,
    'LEV': 0,
    'LEVA': 0,
    'LEVAC': 0,
    'LEVACK': 0,
    'LEVAK': 0,
    'LEVAKE': 0,
    'LEVALLEY': 0,
    'LEVALLY': 0,
    'LEVAN': 0,
    'LEVANDER': 0,
    'LEVANDOSKI': 0,
    'LEVANDOWSKI': 0,
    'LEVANDUSKI': 0,
    'LEVANDUSKY': 0,
    'LEVANEN': 0,
    'LEVANG': 0,
    'LEVANGIE': 0,
    'LEVANO': 0,
    'LEVANS': 0,
    'LEVANT': 0,
    'LEVANTI': 0,
    'LEVAR': 0,
    'LEVARI': 0,
    'LEVARIO': 0,
    'LEVAS': 0,
    'LEVASH': 0,
    'LEVASSEUR': 0,
    'LEVATINO': 0,
    'LEVATO': 0,
    'LEVAULT': 0,
    'LEVAY': 0,
    'LEVCHENKO': 0,
    'LEVCHUK': 0,
    'LEVE': 0,
    'LEVEA': 0,
    'LEVECK': 0,
    'LEVEE': 0,
    'LEVEEN': 0,
    'LEVEILLE': 0,
    'LEVEILLEE': 0,
    'LEVEL': 0,
    'LEVELL': 0,
    'LEVELLE': 0,
    'LEVELS': 0,
    'LEVEN': 0,
    'LEVENBERG': 0,
    'LEVENDOSKI': 0,
    'LEVENDOSKY': 0,
    'LEVENDUSKI': 0,
    'LEVENDUSKY': 0,
    'LEVENE': 0,
    'LEVENGOOD': 0,
    'LEVENHAGEN': 0,
    'LEVENS': 0,
    'LEVENSAILOR': 0,
    'LEVENSON': 0,
    'LEVENSTEIN': 0,
    'LEVENTHAL': 0,
    'LEVENTIS': 0,
    'LEVENTON': 0,
    'LEVENTRY': 0,
    'LEVEQUE': 0,
    'LEVER': 0,
    'LEVERE': 0,
    'LEVERENCE': 0,
    'LEVERENTZ': 0,
    'LEVERENZ': 0,
    'LEVERETT': 0,
    'LEVERETTE': 0,
    'LEVERICH': 0,
    'LEVERIDGE': 0,
    'LEVERING': 0,
    'LEVERINGTON': 0,
    'LEVERITT': 0,
    'LEVERNIER': 0,
    'LEVEROCK': 0,
    'LEVERON': 0,
    'LEVERONE': 0,
    'LEVERONI': 0,
    'LEVERS': 0,
    'LEVERSEE': 0,
    'LEVERSON': 0,
    'LEVERT': 0,
    'LEVERTON': 0,
    'LEVERTY': 0,
    'LEVESQUE': 0,
    'LEVESTON': 0,
    'LEVET': 0,
    'LEVETON': 0,
    'LEVETT': 0,
    'LEVETTE': 0,
    'LEVEY': 0,
    'LEVI': 0.9110787172011662,
    'LEVIA': 0,
    'LEVIAN': 0,
    'LEVIAS': 0,
    'LEVICH': 0,
    'LEVICK': 0,
    'LEVIE': 0,
    'LEVIEGE': 0,
    'LEVIEN': 0,
    'LEVIER': 0,
    'LEVIGNE': 0,
    'LEVIN': 0,
    'LEVINA': 0,
    'LEVINE': 0,
    'LEVINER': 0,
    'LEVINESS': 0,
    'LEVINGER': 0,
    'LEVINGS': 0,
    'LEVINGSTON': 0,
    'LEVINS': 0,
    'LEVINSKI': 0,
    'LEVINSKY': 0,
    'LEVINSOHN': 0,
    'LEVINSON': 0,
    'LEVINSTEIN': 0,
    'LEVINTHAL': 0,
    'LEVIS': 0,
    'LEVISAY': 0,
    'LEVISON': 0,
    'LEVISTER': 0,
    'LEVIT': 0,
    'LEVITA': 0,
    'LEVITAN': 0,
    'LEVITAS': 0,
    'LEVITCH': 0,
    'LEVITE': 0,
    'LEVITIN': 0,
    'LEVITON': 0,
    'LEVITRE': 0,
    'LEVITSKI': 0,
    'LEVITSKY': 0,
    'LEVITT': 0,
    'LEVITZ': 0,
    'LEVO': 0,
    'LEVON': 0,
    'LEVONIAN': 0,
    'LEVOS': 0,
    'LEVOVITZ': 0,
    'LEVOY': 0,
    'LEVRA': 0,
    'LEVREAULT': 0,
    'LEVRIER': 0,
    'LEVRON': 0,
    'LEVSEN': 0,
    'LEVY': 0,
    'LEW': 0,
    'LEWALD': 0,
    'LEWALLEN': 0,
    'LEWALSKI': 0,
    'LEWAN': 0,
    'LEWAND': 0,
    'LEWANDOSKI': 0,
    'LEWANDOWSKI': 0,
    'LEWANSKI': 0,
    'LEWARK': 0,
    'LEWARNE': 0,
    'LEWARS': 0,
    'LEWCZYK': 0,
    'LEWE': 0,
    'LEWEK': 0,
    'LEWELLEN': 0,
    'LEWELLIN': 0,
    'LEWELLING': 0,
    'LEWELLYN': 0,
    'LEWEN': 0,
    'LEWER': 0,
    'LEWERENZ': 0,
    'LEWERKE': 0,
    'LEWERS': 0,
    'LEWEY': 0,
    'LEWI': 0,
    'LEWICKI': 0,
    'LEWIE': 0,
    'LEWIEN': 0,
    'LEWIN': 0,
    'LEWINE': 0,
    'LEWING': 0,
    'LEWINS': 0,
    'LEWINSKI': 0,
    'LEWINSON': 0,
    'LEWINTER': 0,
    'LEWIS': 0.34598484586375117,
    'LEWISON': 0,
    'LEWISTON': 0,
    'LEWIT': 0,
    'LEWITT': 0,
    'LEWITZKE': 0,
    'LEWKO': 0,
    'LEWKOWICZ': 0,
    'LEWKOWITZ': 0,
    'LEWKOWSKI': 0,
    'LEWMAN': 0,
    'LEWNO': 0,
    'LEWON': 0,
    'LEWSADER': 0,
    'LEWTER': 0,
    'LEWTON': 0,
    'LEWY': 0,
    'LEX': 0,
    'LEXA': 0,
    'LEXIE': 1,
    'LEXOW': 0,
    'LEXVOLD': 0,
    'LEY': 0,
    'LEYA': 0,
    'LEYBA': 0,
    'LEYBOVICH': 0,
    'LEYDA': 0,
    'LEYDE': 0,
    'LEYDECKER': 0,
    'LEYDEN': 0,
    'LEYDIG': 0,
    'LEYDON': 0,
    'LEYENDECKER': 0,
    'LEYERLE': 0,
    'LEYES': 0,
    'LEYH': 0,
    'LEYHE': 0,
    'LEYJA': 0,
    'LEYK': 0,
    'LEYKIN': 0,
    'LEYKO': 0,
    'LEYLAND': 0,
    'LEYMAN': 0,
    'LEYMEISTER': 0,
    'LEYNES': 0,
    'LEYPOLDT': 0,
    'LEYRER': 0,
    'LEYS': 0,
    'LEYSATH': 0,
    'LEYSER': 0,
    'LEYSHON': 0,
    'LEYSON': 0,
    'LEYTEM': 0,
    'LEYTHAM': 0,
    'LEYTON': 0,
    'LEYUA': 0,
    'LEYVA': 0,
    'LEYVAS': 0,
    'LEZ': 0,
    'LEZA': 0,
    'LEZAK': 0,
    'LEZAMA': 0,
    'LEZCANO': 0,
    'LEZER': 0,
    'LEZLIE': 1,
    'LEZO': 0,
    'LEZON': 0,
    'LEZOTTE': 0,
    'LHAMON': 0,
    'LHERISSON': 0,
    'LHEUREUX': 0,
    'LHOMME': 0,
    'LHOMMEDIEU': 0,
    'LHOTA': 0,
    'LHOTKA': 0,
    'LHUILLIER': 0,
    'LI': 0.12285012285012284,
    'LIA': 0.9596928982725529,
    'LIADIS': 0,
    'LIAKOS': 0,
    'LIAL': 0,
    'LIAM': 0,
    'LIAMAS': 0,
    'LIAN': 0,
    'LIANA': 0.9836065573770493,
    'LIANE': 1,
    'LIANG': 0,
    'LIANNE': 1,
    'LIANO': 0,
    'LIANOS': 0,
    'LIANTONIO': 0,
    'LIAO': 0,
    'LIAPIS': 0,
    'LIAS': 0,
    'LIAU': 0,
    'LIAUTAUD': 0,
    'LIAW': 0,
    'LIBA': 0,
    'LIBAL': 0,
    'LIBAN': 0,
    'LIBARDI': 0,
    'LIBASCI': 0,
    'LIBASSI': 0,
    'LIBBEE': 0,
    'LIBBERT': 0,
    'LIBBERTON': 0,
    'LIBBETT': 0,
    'LIBBEY': 0,
    'LIBBIE': 1,
    'LIBBRECHT': 0,
    'LIBBY': 0.6751054852320675,
    'LIBECAP': 0,
    'LIBED': 0,
    'LIBEL': 0,
    'LIBENGOOD': 0,
    'LIBER': 0,
    'LIBERA': 0,
    'LIBERACKI': 0,
    'LIBERAL': 0,
    'LIBERATI': 0,
    'LIBERATO': 0,
    'LIBERATOR': 0,
    'LIBERATORE': 0,
    'LIBERI': 0,
    'LIBERIO': 0,
    'LIBERMAN': 0,
    'LIBERO': 0,
    'LIBERT': 0,
    'LIBERTA': 0,
    'LIBERTI': 0,
    'LIBERTINI': 0,
    'LIBERTINO': 0,
    'LIBERTO': 0,
    'LIBERTORE': 0,
    'LIBERTY': 0.6134969325153374,
    'LIBEY': 0,
    'LIBHART': 0,
    'LIBIN': 0,
    'LIBKE': 0,
    'LIBMAN': 0,
    'LIBOLT': 0,
    'LIBONATI': 0,
    'LIBORIO': 0,
    'LIBRA': 0,
    'LIBRADA': 1,
    'LIBRADO': 0,
    'LIBRANDI': 0,
    'LIBRERA': 0,
    'LIBREROS': 0,
    'LIBRETTI': 0,
    'LIBRETTO': 0,
    'LIBRIZZI': 0,
    'LIBRO': 0,
    'LIBS': 0,
    'LIBSACK': 0,
    'LIBSON': 0,
    'LIBUNAO': 0,
    'LIBURD': 0,
    'LIBURDI': 0,
    'LIBUTTI': 0,
    'LIBY': 0,
    'LICA': 0,
    'LICALSI': 0,
    'LICALZI': 0,
    'LICANO': 0,
    'LICARE': 0,
    'LICARI': 0,
    'LICASTRO': 0,
    'LICATA': 0,
    'LICATO': 0,
    'LICAUSI': 0,
    'LICAVOLI': 0,
    'LICCARDI': 0,
    'LICCARDO': 0,
    'LICCIARDELLO': 0,
    'LICCIARDI': 0,
    'LICCIONE': 0,
    'LICEA': 0,
    'LICEAGA': 0,
    'LICERIO': 0,
    'LICH': 0,
    'LICHENSTEIN': 0,
    'LICHLITER': 0,
    'LICHLYTER': 0,
    'LICHMAN': 0,
    'LICHNER': 0,
    'LICHON': 0,
    'LICHOTA': 0,
    'LICHT': 0,
    'LICHTBLAU': 0,
    'LICHTE': 0,
    'LICHTEN': 0,
    'LICHTENAUER': 0,
    'LICHTENBERG': 0,
    'LICHTENBERGER': 0,
    'LICHTENFELD': 0,
    'LICHTENFELS': 0,
    'LICHTENSTEIN': 0,
    'LICHTENTHAL': 0,
    'LICHTENWALD': 0,
    'LICHTENWALNER': 0,
    'LICHTENWALTER': 0,
    'LICHTER': 0,
    'LICHTERMAN': 0,
    'LICHTFUSS': 0,
    'LICHTI': 0,
    'LICHTIG': 0,
    'LICHTLE': 0,
    'LICHTMAN': 0,
    'LICHTNER': 0,
    'LICHTSINN': 0,
    'LICHTY': 0,
    'LICHVAR': 0,
    'LICHY': 0,
    'LICIAGA': 0,
    'LICINA': 0,
    'LICITRA': 0,
    'LICK': 0,
    'LICKER': 0,
    'LICKERT': 0,
    'LICKEY': 0,
    'LICKFELT': 0,
    'LICKING': 0,
    'LICKISS': 0,
    'LICKLIDER': 0,
    'LICKLITER': 0,
    'LICKMAN': 0,
    'LICKO': 0,
    'LICKTEIG': 0,
    'LICO': 0,
    'LICON': 0,
    'LICONA': 0,
    'LICORISH': 0,
    'LICUDINE': 0,
    'LICUL': 0,
    'LICUP': 0,
    'LICURSI': 0,
    'LIDA': 0.9803921568627452,
    'LIDBERG': 0,
    'LIDDELL': 0,
    'LIDDIARD': 0,
    'LIDDIC': 0,
    'LIDDICK': 0,
    'LIDDICOAT': 0,
    'LIDDIE': 0,
    'LIDDINGTON': 0,
    'LIDDLE': 0,
    'LIDDON': 0,
    'LIDDY': 0,
    'LIDE': 0,
    'LIDELL': 0,
    'LIDEN': 0,
    'LIDER': 0,
    'LIDEY': 0,
    'LIDGARD': 0,
    'LIDGE': 0,
    'LIDGETT': 0,
    'LIDIA': 1,
    'LIDKE': 0,
    'LIDMAN': 0,
    'LIDSKY': 0,
    'LIDSTER': 0,
    'LIDSTONE': 0,
    'LIDSTROM': 0,
    'LIDTKE': 0,
    'LIDWELL': 0,
    'LIDY': 0,
    'LIE': 0,
    'LIEB': 0,
    'LIEBAL': 0,
    'LIEBAU': 0,
    'LIEBE': 0,
    'LIEBECK': 0,
    'LIEBEGOTT': 0,
    'LIEBEL': 0,
    'LIEBELT': 0,
    'LIEBENGOOD': 0,
    'LIEBENGUTH': 0,
    'LIEBENOW': 0,
    'LIEBENSTEIN': 0,
    'LIEBENTHAL': 0,
    'LIEBENTRITT': 0,
    'LIEBER': 0,
    'LIEBERG': 0,
    'LIEBERGEN': 0,
    'LIEBERMAN': 0,
    'LIEBERMANN': 0,
    'LIEBERS': 0,
    'LIEBERSON': 0,
    'LIEBERT': 0,
    'LIEBERTH': 0,
    'LIEBERUM': 0,
    'LIEBES': 0,
    'LIEBESKIND': 0,
    'LIEBETRAU': 0,
    'LIEBGOTT': 0,
    'LIEBHABER': 0,
    'LIEBHART': 0,
    'LIEBHAUSER': 0,
    'LIEBHERR': 0,
    'LIEBICH': 0,
    'LIEBIG': 0,
    'LIEBING': 0,
    'LIEBL': 0,
    'LIEBLEIN': 0,
    'LIEBLER': 0,
    'LIEBLICH': 0,
    'LIEBLING': 0,
    'LIEBMAN': 0,
    'LIEBMANN': 0,
    'LIEBNER': 0,
    'LIEBOLD': 0,
    'LIEBOWITZ': 0,
    'LIEBRECHT': 0,
    'LIEBSACK': 0,
    'LIEBSCH': 0,
    'LIEBSCHER': 0,
    'LIEBZEIT': 0,
    'LIECHTI': 0,
    'LIECHTY': 0,
    'LIECK': 0,
    'LIED': 0,
    'LIEDBERG': 0,
    'LIEDEL': 0,
    'LIEDER': 0,
    'LIEDERBACH': 0,
    'LIEDERMAN': 0,
    'LIEDKE': 0,
    'LIEDL': 0,
    'LIEDLE': 0,
    'LIEDTKA': 0,
    'LIEDTKE': 0,
    'LIEDY': 0,
    'LIEF': 0,
    'LIEFER': 0,
    'LIEFFERS': 0,
    'LIEFFRING': 0,
    'LIEGEL': 0,
    'LIEGEY': 0,
    'LIEGGI': 0,
    'LIEGL': 0,
    'LIEHR': 0,
    'LIEKHUS': 0,
    'LIEM': 0,
    'LIEN': 0.4484304932735426,
    'LIENARD': 0,
    'LIENAU': 0,
    'LIENDO': 0,
    'LIENEMANN': 0,
    'LIENERT': 0,
    'LIENG': 0,
    'LIENHARD': 0,
    'LIENHARDT': 0,
    'LIENHART': 0,
    'LIENING': 0,
    'LIENTZ': 0,
    'LIEPINS': 0,
    'LIEPOLD': 0,
    'LIER': 0,
    'LIERA': 0,
    'LIERAS': 0,
    'LIERLY': 0,
    'LIERMAN': 0,
    'LIERMANN': 0,
    'LIERZ': 0,
    'LIES': 0,
    'LIESCH': 0,
    'LIESE': 0,
    'LIESEGANG': 0,
    'LIESELOTTE': 1,
    'LIESEN': 0,
    'LIESENER': 0,
    'LIESENFELD': 0,
    'LIESER': 0,
    'LIESINGER': 0,
    'LIESKE': 0,
    'LIESMAN': 0,
    'LIESMANN': 0,
    'LIESNER': 0,
    'LIESS': 0,
    'LIESSE': 0,
    'LIESTER': 0,
    'LIESTMAN': 0,
    'LIETAERT': 0,
    'LIETHEN': 0,
    'LIETO': 0,
    'LIETTE': 0,
    'LIETZ': 0,
    'LIETZAU': 0,
    'LIETZKE': 0,
    'LIETZOW': 0,
    'LIEU': 0,
    'LIEUALLEN': 0,
    'LIEURANCE': 0,
    'LIEUX': 0,
    'LIEVANO': 0,
    'LIEVANOS': 0,
    'LIEVENS': 0,
    'LIEVENSE': 0,
    'LIEVING': 0,
    'LIEVSAY': 0,
    'LIEW': 0,
    'LIEWER': 0,
    'LIFE': 0,
    'LIFER': 0,
    'LIFF': 0,
    'LIFFICK': 0,
    'LIFFORD': 0,
    'LIFFRIG': 0,
    'LIFKA': 0,
    'LIFLAND': 0,
    'LIFORD': 0,
    'LIFRIERI': 0,
    'LIFSCHITZ': 0,
    'LIFSEY': 0,
    'LIFSHITS': 0,
    'LIFSHITZ': 0,
    'LIFSON': 0,
    'LIFTON': 0,
    'LIGA': 0,
    'LIGAMMARI': 0,
    'LIGAS': 0,
    'LIGATO': 0,
    'LIGE': 0,
    'LIGENZA': 0,
    'LIGER': 0,
    'LIGGAN': 0,
    'LIGGANS': 0,
    'LIGGENS': 0,
    'LIGGET': 0,
    'LIGGETT': 0,
    'LIGGIN': 0,
    'LIGGINS': 0,
    'LIGGIO': 0,
    'LIGGITT': 0,
    'LIGGON': 0,
    'LIGGONS': 0,
    'LIGH': 0,
    'LIGHT': 0,
    'LIGHTBODY': 0,
    'LIGHTBOURN': 0,
    'LIGHTBOURNE': 0,
    'LIGHTBOWN': 0,
    'LIGHTBURN': 0,
    'LIGHTCAP': 0,
    'LIGHTELL': 0,
    'LIGHTEN': 0,
    'LIGHTER': 0,
    'LIGHTFIELD': 0,
    'LIGHTFOOT': 0,
    'LIGHTFORD': 0,
    'LIGHTFRITZ': 0,
    'LIGHTHALL': 0,
    'LIGHTHART': 0,
    'LIGHTHILL': 0,
    'LIGHTHISER': 0,
    'LIGHTHIZER': 0,
    'LIGHTLE': 0,
    'LIGHTMAN': 0,
    'LIGHTNER': 0,
    'LIGHTNING': 0,
    'LIGHTON': 0,
    'LIGHTS': 0,
    'LIGHTSEY': 0,
    'LIGHTSTONE': 0,
    'LIGHTSY': 0,
    'LIGHTY': 0,
    'LIGI': 0,
    'LIGIA': 1,
    'LIGMAN': 0,
    'LIGNELL': 0,
    'LIGNELLI': 0,
    'LIGNOS': 0,
    'LIGO': 0,
    'LIGOCKI': 0,
    'LIGON': 0,
    'LIGONDE': 0,
    'LIGONS': 0,
    'LIGORI': 0,
    'LIGOTTI': 0,
    'LIGOURI': 0,
    'LIGSAY': 0,
    'LIGTENBERG': 0,
    'LIGUE': 0,
    'LIGUEZ': 0,
    'LIGUORI': 0,
    'LIGUS': 0,
    'LII': 0,
    'LIIMATAINEN': 0,
    'LIIMATTA': 0,
    'LIJEWSKI': 0,
    'LIJOI': 0,
    'LIKA': 0,
    'LIKAR': 0,
    'LIKE': 0,
    'LIKELY': 0,
    'LIKEN': 0,
    'LIKENS': 0,
    'LIKER': 0,
    'LIKES': 0,
    'LIKINS': 0,
    'LIKKEL': 0,
    'LIKNESS': 0,
    'LIKOS': 0,
    'LILA': 0.9972489683631361,
    'LILAC': 0,
    'LILAVOIS': 0,
    'LILBURN': 0,
    'LILE': 0,
    'LILEK': 0,
    'LILES': 0,
    'LILEY': 0,
    'LILI': 1,
    'LILIA': 1,
    'LILIAN': 1,
    'LILIANA': 1,
    'LILIE': 0,
    'LILIEN': 0,
    'LILIENFELD': 0,
    'LILIENTHAL': 0,
    'LILJA': 0,
    'LILJE': 0,
    'LILJEBERG': 0,
    'LILJEDAHL': 0,
    'LILJEGREN': 0,
    'LILJENQUIST': 0,
    'LILJEQUIST': 0,
    'LILJESTRAND': 0,
    'LILL': 0,
    'LILLA': 0.9174311926605505,
    'LILLARD': 0,
    'LILLEBERG': 0,
    'LILLEGARD': 0,
    'LILLER': 0,
    'LILLEY': 0,
    'LILLGE': 0,
    'LILLI': 0.9433962264150944,
    'LILLIA': 1,
    'LILLIAM': 1,
    'LILLIAN': 0.9996209967784726,
    'LILLIANA': 1,
    'LILLIBRIDGE': 0,
    'LILLICH': 0,
    'LILLICO': 0,
    'LILLIE': 0.9828546467183575,
    'LILLIG': 0,
    'LILLIS': 0,
    'LILLISTON': 0,
    'LILLO': 0,
    'LILLPOP': 0,
    'LILLQUIST': 0,
    'LILLY': 0.6346328195829556,
    'LILLYWHITE': 0,
    'LILOIA': 0,
    'LILY': 0.9947337624341721,
    'LILYA': 0,
    'LILYQUIST': 0,
    'LIM': 0,
    'LIMA': 0,
    'LIMAGE': 0,
    'LIMAN': 0,
    'LIMANDRI': 0,
    'LIMANI': 0,
    'LIMANNI': 0,
    'LIMARDO': 0,
    'LIMAS': 0,
    'LIMATO': 0,
    'LIMAURO': 0,
    'LIMAYE': 0,
    'LIMB': 0,
    'LIMBACH': 0,
    'LIMBACHER': 0,
    'LIMBACK': 0,
    'LIMBAUGH': 0,
    'LIMBECK': 0,
    'LIMBER': 0,
    'LIMBERG': 0,
    'LIMBERGER': 0,
    'LIMBERIS': 0,
    'LIMBERS': 0,
    'LIMBERT': 0,
    'LIMBO': 0,
    'LIMBOCKER': 0,
    'LIMBRICK': 0,
    'LIMBURG': 0,
    'LIME': 0,
    'LIMEHOUSE': 0,
    'LIMER': 0,
    'LIMERICK': 0,
    'LIMES': 0,
    'LIMESAND': 0,
    'LIMING': 0,
    'LIMJOCO': 0,
    'LIMKE': 0,
    'LIMMER': 0,
    'LIMO': 0,
    'LIMOGES': 0,
    'LIMOLI': 0,
    'LIMON': 0,
    'LIMONCELLI': 0,
    'LIMONE': 0,
    'LIMONES': 0,
    'LIMONGELLI': 0,
    'LIMONTA': 0,
    'LIMOS': 0,
    'LIMP': 0,
    'LIMPACH': 0,
    'LIMPER': 0,
    'LIMPERIS': 0,
    'LIMPERT': 0,
    'LIMPIN': 0,
    'LIMPUS': 0,
    'LIMTIACO': 0,
    'LIN': 0.14084507042253522,
    'LINA': 0.985663082437276,
    'LINABURG': 0,
    'LINAFELTER': 0,
    'LINAHAN': 0,
    'LINAM': 0,
    'LINAMAN': 0,
    'LINAMEN': 0,
    'LINAN': 0,
    'LINANE': 0,
    'LINARD': 0,
    'LINARDI': 0,
    'LINARDOS': 0,
    'LINARES': 0,
    'LINAREZ': 0,
    'LINARTE': 0,
    'LINAS': 0,
    'LINAWEAVER': 0,
    'LINBACK': 0,
    'LINBERG': 0,
    'LINCE': 0,
    'LINCECUM': 0,
    'LINCH': 0,
    'LINCICOME': 0,
    'LINCICUM': 0,
    'LINCK': 0,
    'LINCKE': 0,
    'LINCKS': 0,
    'LINCOLN': 0.5730659025787966,
    'LINCON': 0,
    'LINCOURT': 0,
    'LIND': 0,
    'LINDA': 0.9996812610472023,
    'LINDAAS': 0,
    'LINDABURY': 0,
    'LINDAHL': 0,
    'LINDAL': 0,
    'LINDALL': 0,
    'LINDAMAN': 0,
    'LINDAMOOD': 0,
    'LINDAU': 0,
    'LINDAUER': 0,
    'LINDBACK': 0,
    'LINDBECK': 0,
    'LINDBERG': 0,
    'LINDBERGH': 0,
    'LINDBLAD': 0,
    'LINDBLADE': 0,
    'LINDBLOM': 0,
    'LINDBLOOM': 0,
    'LINDBO': 0,
    'LINDBOM': 0,
    'LINDBORG': 0,
    'LINDBURG': 0,
    'LINDE': 0,
    'LINDEBERG': 0,
    'LINDEE': 0,
    'LINDEEN': 0,
    'LINDEKE': 0,
    'LINDEKUGEL': 0,
    'LINDEL': 0,
    'LINDELL': 0,
    'LINDELOF': 0,
    'LINDEMAN': 0,
    'LINDEMANN': 0,
    'LINDEMER': 0,
    'LINDEMEYER': 0,
    'LINDEMOEN': 0,
    'LINDEMULDER': 0,
    'LINDEMUTH': 0,
    'LINDEN': 0,
    'LINDENAU': 0,
    'LINDENBAUM': 0,
    'LINDENBERG': 0,
    'LINDENBERGER': 0,
    'LINDENFELD': 0,
    'LINDENFELSER': 0,
    'LINDENMAN': 0,
    'LINDENMAYER': 0,
    'LINDENMEYER': 0,
    'LINDENMUTH': 0,
    'LINDENSCHMIDT': 0,
    'LINDENTHAL': 0,
    'LINDER': 0,
    'LINDERER': 0,
    'LINDERHOLM': 0,
    'LINDERMAN': 0,
    'LINDERMUTH': 0,
    'LINDEROTH': 0,
    'LINDERS': 0,
    'LINDERT': 0,
    'LINDESMITH': 0,
    'LINDEY': 0,
    'LINDFORS': 0,
    'LINDGREN': 0,
    'LINDH': 0,
    'LINDHARDT': 0,
    'LINDHOLM': 0,
    'LINDHORST': 0,
    'LINDHOUT': 0,
    'LINDHURST': 0,
    'LINDIG': 0,
    'LINDINGER': 0,
    'LINDKE': 0,
    'LINDL': 0,
    'LINDLAND': 0,
    'LINDLE': 0,
    'LINDLER': 0,
    'LINDLEY': 0,
    'LINDLOFF': 0,
    'LINDLY': 0,
    'LINDMAN': 0,
    'LINDMARK': 0,
    'LINDMEIER': 0,
    'LINDNER': 0,
    'LINDO': 0,
    'LINDON': 0,
    'LINDOP': 0,
    'LINDOR': 0,
    'LINDORFER': 0,
    'LINDORFF': 0,
    'LINDOW': 0,
    'LINDQUIST': 0,
    'LINDROOS': 0,
    'LINDROS': 0,
    'LINDROTH': 0,
    'LINDSAY': 0.8446614755180151,
    'LINDSETH': 0,
    'LINDSEY': 0.7470175047385438,
    'LINDSKOG': 0,
    'LINDSKOOG': 0,
    'LINDSLEY': 0,
    'LINDSLY': 0,
    'LINDSTADT': 0,
    'LINDSTEDT': 0,
    'LINDSTEN': 0,
    'LINDSTRAND': 0,
    'LINDSTROM': 0,
    'LINDSY': 0.9433962264150944,
    'LINDT': 0,
    'LINDVALL': 0,
    'LINDVIG': 0,
    'LINDWALL': 0,
    'LINDY': 0.9652509652509652,
    'LINDZY': 0,
    'LINE': 0,
    'LINEAR': 0,
    'LINEAWEAVER': 0,
    'LINEBACK': 0,
    'LINEBARGER': 0,
    'LINEBAUGH': 0,
    'LINEBERGER': 0,
    'LINEBERRY': 0,
    'LINEBURG': 0,
    'LINEGAR': 0,
    'LINEHAN': 0,
    'LINEK': 0,
    'LINELL': 0,
    'LINEMAN': 0,
    'LINEN': 0,
    'LINENBERGER': 0,
    'LINENDOLL': 0,
    'LINENFELSER': 0,
    'LINER': 0,
    'LINERO': 0,
    'LINES': 0,
    'LINET': 0,
    'LINETT': 0,
    'LINETTE': 0.986842105263158,
    'LINEWEAVER': 0,
    'LINEY': 0,
    'LINFANTE': 0,
    'LINFIELD': 0,
    'LINFOOT': 0,
    'LINFORD': 0,
    'LING': 0.39603960396039606,
    'LINGAD': 0,
    'LINGAFELT': 0,
    'LINGAFELTER': 0,
    'LINGAM': 0,
    'LINGAR': 0,
    'LINGARD': 0,
    'LINGAT': 0,
    'LINGBECK': 0,
    'LINGBLOOM': 0,
    'LINGE': 0,
    'LINGEFELT': 0,
    'LINGEL': 0,
    'LINGELBACH': 0,
    'LINGEMAN': 0,
    'LINGEN': 0,
    'LINGENFELDER': 0,
    'LINGENFELSER': 0,
    'LINGENFELTER': 0,
    'LINGER': 0,
    'LINGERFELT': 0,
    'LINGG': 0,
    'LINGHAM': 0,
    'LINGINFELTER': 0,
    'LINGL': 0,
    'LINGLE': 0,
    'LINGLEY': 0,
    'LINGNAU': 0,
    'LINGNER': 0,
    'LINGO': 0,
    'LINGREN': 0,
    'LINGUA': 0,
    'LINGWALL': 0,
    'LINH': 0.9803921568627452,
    'LINHARDT': 0,
    'LINHARES': 0,
    'LINHART': 0,
    'LINHOFF': 0,
    'LINICK': 0,
    'LINIGER': 0,
    'LINIHAN': 0,
    'LININGER': 0,
    'LINK': 0,
    'LINKA': 0,
    'LINKE': 0,
    'LINKENHOKER': 0,
    'LINKER': 0,
    'LINKERT': 0,
    'LINKES': 0,
    'LINKEY': 0,
    'LINKHART': 0,
    'LINKHORN': 0,
    'LINKIEWICZ': 0,
    'LINKINS': 0,
    'LINKLATER': 0,
    'LINKLETTER': 0,
    'LINKO': 0,
    'LINKOUS': 0,
    'LINKOWSKI': 0,
    'LINKS': 0,
    'LINKUS': 0,
    'LINLEY': 0,
    'LINMAN': 0,
    'LINN': 0.1814882032667877,
    'LINNA': 0,
    'LINNABARY': 0,
    'LINNAN': 0,
    'LINNANE': 0,
    'LINNARTZ': 0,
    'LINNE': 0,
    'LINNEA': 1,
    'LINNEAR': 0,
    'LINNEBUR': 0,
    'LINNEHAN': 0,
    'LINNELL': 0,
    'LINNEMAN': 0,
    'LINNEMANN': 0,
    'LINNEMEIER': 0,
    'LINNEMEYER': 0,
    'LINNEN': 0,
    'LINNENBRINK': 0,
    'LINNENKAMP': 0,
    'LINNENKOHL': 0,
    'LINNER': 0,
    'LINNERT': 0,
    'LINNERTZ': 0,
    'LINNETT': 0,
    'LINNEY': 0,
    'LINNIE': 1,
    'LINNIK': 0,
    'LINO': 0.7858546168958742,
    'LINQUIST': 0,
    'LINS': 0,
    'LINSALATA': 0,
    'LINSANGAN': 0,
    'LINSAY': 0,
    'LINSCHEID': 0,
    'LINSCOMB': 0,
    'LINSCOTT': 0,
    'LINSDAY': 0,
    'LINSE': 0,
    'LINSENBIGLER': 0,
    'LINSENMAYER': 0,
    'LINSENMEYER': 0,
    'LINSER': 0,
    'LINSEY': 0.8771929824561404,
    'LINSINBIGLER': 0,
    'LINSKENS': 0,
    'LINSKEY': 0,
    'LINSKI': 0,
    'LINSKY': 0,
    'LINSLEY': 0,
    'LINSMEIER': 0,
    'LINSMEYER': 0,
    'LINSNER': 0,
    'LINSON': 0,
    'LINSSEN': 0,
    'LINSTAD': 0,
    'LINSTEAD': 0,
    'LINSTEDT': 0,
    'LINSTER': 0,
    'LINSTROM': 0,
    'LINT': 0,
    'LINTAG': 0,
    'LINTELMAN': 0,
    'LINTEMUTH': 0,
    'LINTHICUM': 0,
    'LINTNER': 0,
    'LINTON': 0,
    'LINTOTT': 0,
    'LINTS': 0,
    'LINTZ': 0,
    'LINTZENICH': 0,
    'LINVILL': 0,
    'LINVILLE': 0,
    'LINWOOD': 0.9750812567713976,
    'LINXWILER': 0,
    'LINYARD': 0,
    'LINZ': 0,
    'LINZA': 0,
    'LINZAY': 0,
    'LINZE': 0,
    'LINZER': 0,
    'LINZEY': 0,
    'LINZIE': 0,
    'LINZMEIER': 0,
    'LINZMEYER': 0,
    'LINZY': 0,
    'LIO': 0,
    'LIOCE': 0,
    'LIOI': 0,
    'LIOLIOS': 0,
    'LION': 0,
    'LIONBERGER': 0,
    'LIONE': 0,
    'LIONEL': 0.9979209979209979,
    'LIONETTI': 0,
    'LIONG': 0,
    'LIONS': 0,
    'LIOTINE': 0,
    'LIOTTA': 0,
    'LIOTTI': 0,
    'LIOU': 0,
    'LIOY': 0,
    'LIPA': 0,
    'LIPAN': 0,
    'LIPANI': 0,
    'LIPARI': 0,
    'LIPAROTO': 0,
    'LIPCHAK': 0,
    'LIPCHIK': 0,
    'LIPCZYNSKI': 0,
    'LIPE': 0,
    'LIPES': 0,
    'LIPETZ': 0,
    'LIPETZKY': 0,
    'LIPFORD': 0,
    'LIPHAM': 0,
    'LIPIEC': 0,
    'LIPIN': 0,
    'LIPINSKI': 0,
    'LIPINSKY': 0,
    'LIPIRA': 0,
    'LIPITZ': 0,
    'LIPKA': 0,
    'LIPKE': 0,
    'LIPKER': 0,
    'LIPKIN': 0,
    'LIPKIND': 0,
    'LIPKINS': 0,
    'LIPKO': 0,
    'LIPKOWITZ': 0,
    'LIPMAN': 0,
    'LIPNER': 0,
    'LIPNICK': 0,
    'LIPNICKI': 0,
    'LIPNICKY': 0,
    'LIPOFF': 0,
    'LIPOMI': 0,
    'LIPOSKY': 0,
    'LIPOVAC': 0,
    'LIPOVSKY': 0,
    'LIPOW': 0,
    'LIPOWSKI': 0,
    'LIPP': 0,
    'LIPPA': 0,
    'LIPPARD': 0,
    'LIPPART': 0,
    'LIPPE': 0,
    'LIPPEL': 0,
    'LIPPENCOTT': 0,
    'LIPPENS': 0,
    'LIPPER': 0,
    'LIPPERT': 0,
    'LIPPETT': 0,
    'LIPPHARDT': 0,
    'LIPPI': 0,
    'LIPPIATT': 0,
    'LIPPIELLO': 0,
    'LIPPIN': 0,
    'LIPPINCOTT': 0,
    'LIPPITT': 0,
    'LIPPKE': 0,
    'LIPPMAN': 0,
    'LIPPMANN': 0,
    'LIPPNER': 0,
    'LIPPO': 0,
    'LIPPOLD': 0,
    'LIPPOLDT': 0,
    'LIPPOLIS': 0,
    'LIPPS': 0,
    'LIPPY': 0,
    'LIPS': 0,
    'LIPSCHITZ': 0,
    'LIPSCHULTZ': 0,
    'LIPSCHUTZ': 0,
    'LIPSCOMB': 0,
    'LIPSCOMBE': 0,
    'LIPSETT': 0,
    'LIPSEY': 0,
    'LIPSHITZ': 0,
    'LIPSHUTZ': 0,
    'LIPSITZ': 0,
    'LIPSIUS': 0,
    'LIPSKA': 0,
    'LIPSKE': 0,
    'LIPSKI': 0,
    'LIPSKY': 0,
    'LIPSMAN': 0,
    'LIPSMEYER': 0,
    'LIPSON': 0,
    'LIPSTEIN': 0,
    'LIPTACK': 0,
    'LIPTAK': 0,
    'LIPTOCK': 0,
    'LIPTON': 0,
    'LIPTRAP': 0,
    'LIPTROT': 0,
    'LIPUMA': 0,
    'LIPUT': 0,
    'LIQUE': 0,
    'LIQUORI': 0,
    'LIRA': 0,
    'LIRANZO': 0,
    'LIRETTE': 0,
    'LIRIANO': 0,
    'LIRIO': 0,
    'LIROT': 0,
    'LIS': 0,
    'LISA': 0.9992335424532319,
    'LISABETH': 1,
    'LISAC': 0,
    'LISAK': 0,
    'LISANDRA': 1,
    'LISANTI': 0,
    'LISBETH': 1,
    'LISBOA': 0,
    'LISBON': 0,
    'LISBY': 0,
    'LISCANO': 0,
    'LISCH': 0,
    'LISCHER': 0,
    'LISCHKA': 0,
    'LISCHKE': 0,
    'LISCIANDRO': 0,
    'LISCINSKY': 0,
    'LISCIO': 0,
    'LISCO': 0,
    'LISCOMB': 0,
    'LISCOMBE': 0,
    'LISCUM': 0,
    'LISE': 0.9876543209876544,
    'LISEC': 0,
    'LISEE': 0,
    'LISEK': 0,
    'LISELLA': 0,
    'LISENBE': 0,
    'LISENBEE': 0,
    'LISENBY': 0,
    'LISENKO': 0,
    'LISENO': 0,
    'LISERIO': 0,
    'LISETTE': 1,
    'LISEWSKI': 0,
    'LISH': 0,
    'LISHA': 1,
    'LISHER': 0,
    'LISHMAN': 0,
    'LISI': 0,
    'LISIAK': 0,
    'LISICA': 0,
    'LISICKI': 0,
    'LISIECKI': 0,
    'LISIEWSKI': 0,
    'LISING': 0,
    'LISINSKI': 0,
    'LISIUS': 0,
    'LISK': 0,
    'LISKA': 0,
    'LISKE': 0,
    'LISKER': 0,
    'LISKEY': 0,
    'LISKIEWICZ': 0,
    'LISKO': 0,
    'LISKOW': 0,
    'LISLE': 0,
    'LISMAN': 0,
    'LISNER': 0,
    'LISO': 0,
    'LISOJO': 0,
    'LISON': 0,
    'LISONBEE': 0,
    'LISOTTA': 0,
    'LISOWE': 0,
    'LISOWSKI': 0,
    'LISS': 0,
    'LISSA': 1,
    'LISSADE': 0,
    'LISSAK': 0,
    'LISSAUER': 0,
    'LISSE': 0,
    'LISSER': 0,
    'LISSETTE': 1,
    'LISSNER': 0,
    'LISSON': 0,
    'LISSY': 0,
    'LIST': 0,
    'LISTA': 0,
    'LISTENBEE': 0,
    'LISTENBERGER': 0,
    'LISTER': 0,
    'LISTERMAN': 0,
    'LISTERMANN': 0,
    'LISTI': 0,
    'LISTMAN': 0,
    'LISTO': 0,
    'LISTON': 0,
    'LISTRO': 0,
    'LISTWAN': 0,
    'LISY': 0,
    'LISZEWSKI': 0,
    'LISZKA': 0,
    'LIT': 0,
    'LITA': 0.9740259740259739,
    'LITAKER': 0,
    'LITALIEN': 0,
    'LITCH': 0,
    'LITCHARD': 0,
    'LITCHFIELD': 0,
    'LITCHFORD': 0,
    'LITCHKO': 0,
    'LITCHMAN': 0,
    'LITCHY': 0,
    'LITE': 0,
    'LITECKY': 0,
    'LITEL': 0,
    'LITER': 0,
    'LITERSKI': 0,
    'LITES': 0,
    'LITFIN': 0,
    'LITHERLAND': 0,
    'LITHGOW': 0,
    'LITKA': 0,
    'LITKE': 0,
    'LITLE': 0,
    'LITMAN': 0,
    'LITMER': 0,
    'LITNER': 0,
    'LITONJUA': 0,
    'LITOS': 0,
    'LITOW': 0,
    'LITRAS': 0,
    'LITRENTA': 0,
    'LITSCH': 0,
    'LITSCHER': 0,
    'LITSEY': 0,
    'LITSINGER': 0,
    'LITSKY': 0,
    'LITSON': 0,
    'LITSTER': 0,
    'LITT': 0,
    'LITTAU': 0,
    'LITTEER': 0,
    'LITTEKEN': 0,
    'LITTEL': 0,
    'LITTELL': 0,
    'LITTEN': 0,
    'LITTER': 0,
    'LITTERAL': 0,
    'LITTERELL': 0,
    'LITTERER': 0,
    'LITTERINI': 0,
    'LITTERIO': 0,
    'LITTERST': 0,
    'LITTIE': 0,
    'LITTIG': 0,
    'LITTKE': 0,
    'LITTLE': 0,
    'LITTLEBEAR': 0,
    'LITTLEBIRD': 0,
    'LITTLEBOY': 0,
    'LITTLEDOG': 0,
    'LITTLEFAIR': 0,
    'LITTLEFIELD': 0,
    'LITTLEFORD': 0,
    'LITTLEHALE': 0,
    'LITTLEJOHN': 0,
    'LITTLELIGHT': 0,
    'LITTLEMAN': 0,
    'LITTLEPAGE': 0,
    'LITTLER': 0,
    'LITTLES': 0,
    'LITTLETHUNDER': 0,
    'LITTLETON': 0,
    'LITTLEWOLF': 0,
    'LITTLEWOOD': 0,
    'LITTMAN': 0,
    'LITTMANN': 0,
    'LITTNER': 0,
    'LITTO': 0,
    'LITTON': 0,
    'LITTREAL': 0,
    'LITTREL': 0,
    'LITTRELL': 0,
    'LITTS': 0,
    'LITTWIN': 0,
    'LITTY': 0,
    'LITUMA': 0,
    'LITVACK': 0,
    'LITVAK': 0,
    'LITVIN': 0,
    'LITVINENKO': 0,
    'LITVINOFF': 0,
    'LITVINOV': 0,
    'LITWA': 0,
    'LITWACK': 0,
    'LITWAK': 0,
    'LITWICKI': 0,
    'LITWILER': 0,
    'LITWILLER': 0,
    'LITWIN': 0,
    'LITWINSKI': 0,
    'LITZ': 0,
    'LITZA': 0,
    'LITZAU': 0,
    'LITZELMAN': 0,
    'LITZENBERG': 0,
    'LITZENBERGER': 0,
    'LITZINGER': 0,
    'LITZLER': 0,
    'LITZNER': 0,
    'LITZSEY': 0,
    'LITZSINGER': 0,
    'LIU': 0,
    'LIUDAHL': 0,
    'LIUFAU': 0,
    'LIUZZA': 0,
    'LIUZZI': 0,
    'LIUZZO': 0,
    'LIV': 0,
    'LIVA': 0,
    'LIVADITIS': 0,
    'LIVAK': 0,
    'LIVANOS': 0,
    'LIVAR': 0,
    'LIVAS': 0,
    'LIVAUDAIS': 0,
    'LIVE': 0,
    'LIVECCHI': 0,
    'LIVELSBERGER': 0,
    'LIVELY': 0,
    'LIVENGOOD': 0,
    'LIVEOAK': 0,
    'LIVERA': 0,
    'LIVERANCE': 0,
    'LIVERETT': 0,
    'LIVERGOOD': 0,
    'LIVERMAN': 0,
    'LIVERMONT': 0,
    'LIVERMORE': 0,
    'LIVERNOIS': 0,
    'LIVERPOOL': 0,
    'LIVERS': 0,
    'LIVERSEDGE': 0,
    'LIVESAY': 0,
    'LIVESEY': 0,
    'LIVEZEY': 0,
    'LIVI': 0,
    'LIVIA': 0.9708737864077669,
    'LIVICK': 0,
    'LIVIDINI': 0,
    'LIVIGNI': 0,
    'LIVING': 0,
    'LIVINGHOUSE': 0,
    'LIVINGOOD': 0,
    'LIVINGS': 0,
    'LIVINGSTON': 0,
    'LIVINGSTONE': 0,
    'LIVINGTON': 0,
    'LIVOLSI': 0,
    'LIVORSI': 0,
    'LIVOTI': 0,
    'LIVRERI': 0,
    'LIVSEY': 0,
    'LIVSHITS': 0,
    'LIWAG': 0,
    'LIWANAG': 0,
    'LIX': 0,
    'LIXEY': 0,
    'LIY': 0,
    'LIZ': 0.9719222462203024,
    'LIZA': 0.995850622406639,
    'LIZABETH': 1,
    'LIZADA': 0,
    'LIZAK': 0,
    'LIZAKOWSKI': 0,
    'LIZALDE': 0,
    'LIZAMA': 0,
    'LIZANA': 0,
    'LIZANO': 0,
    'LIZAOLA': 0,
    'LIZARAZO': 0,
    'LIZARDE': 0,
    'LIZARDI': 0,
    'LIZARDO': 0,
    'LIZARRAGA': 0,
    'LIZASO': 0,
    'LIZBETH': 1,
    'LIZCANO': 0,
    'LIZER': 0,
    'LIZETH': 1,
    'LIZETTE': 1,
    'LIZEWSKI': 0,
    'LIZIK': 0,
    'LIZON': 0,
    'LIZOTTE': 0,
    'LIZZA': 0,
    'LIZZETTE': 1,
    'LIZZI': 0,
    'LIZZIE': 1,
    'LIZZIO': 0,
    'LIZZO': 0,
    'LIZZUL': 0,
    'LJUCOVIC': 0,
    'LJUNGGREN': 0,
    'LL': 0,
    'LLACUNA': 0,
    'LLADO': 0,
    'LLAGUNO': 0,
    'LLAMA': 0,
    'LLAMAS': 0,
    'LLANA': 0,
    'LLANAS': 0,
    'LLANES': 0,
    'LLANEZ': 0,
    'LLANEZA': 0,
    'LLANO': 0,
    'LLANOS': 0,
    'LLANTO': 0,
    'LLAPA': 0,
    'LLARENA': 0,
    'LLAVE': 0,
    'LLERA': 0,
    'LLERANDI': 0,
    'LLERAS': 0,
    'LLERENA': 0,
    'LLERENAS': 0,
    'LLESHI': 0,
    'LLEWELLYN': 0,
    'LLEWELYN': 0,
    'LLIGUICOTA': 0,
    'LLINAS': 0,
    'LLITERAS': 0,
    'LLOPIS': 0,
    'LLOPIZ': 0,
    'LLORCA': 0,
    'LLOREN': 0,
    'LLORENS': 0,
    'LLORENTE': 0,
    'LLORET': 0,
    'LLOSA': 0,
    'LLOVET': 0,
    'LLOYD': 0.8316625826093413,
    'LLOYDJONES': 0,
    'LLUBERES': 0,
    'LLUCH': 0,
    'LLYOD': 0,
    'LO': 0,
    'LOA': 0,
    'LOACH': 0,
    'LOADER': 0,
    'LOADHOLT': 0,
    'LOADMAN': 0,
    'LOAEZA': 0,
    'LOAFMAN': 0,
    'LOAGUE': 0,
    'LOAISIGA': 0,
    'LOAIZA': 0,
    'LOAN': 0.8849557522123894,
    'LOANE': 0,
    'LOAR': 0,
    'LOARCA': 0,
    'LOATMAN': 0,
    'LOATS': 0,
    'LOAYZA': 0,
    'LOB': 0,
    'LOBACH': 0,
    'LOBACK': 0,
    'LOBACZ': 0,
    'LOBAINA': 0,
    'LOBAN': 0,
    'LOBAO': 0,
    'LOBAS': 0,
    'LOBASSO': 0,
    'LOBATO': 0,
    'LOBATON': 0,
    'LOBATOS': 0,
    'LOBAUGH': 0,
    'LOBB': 0,
    'LOBBAN': 0,
    'LOBBESTAEL': 0,
    'LOBBINS': 0,
    'LOBDELL': 0,
    'LOBE': 0,
    'LOBECK': 0,
    'LOBEL': 0,
    'LOBELL': 0,
    'LOBELLO': 0,
    'LOBENSTEIN': 0,
    'LOBER': 0,
    'LOBERG': 0,
    'LOBERGER': 0,
    'LOBERT': 0,
    'LOBES': 0,
    'LOBIANCO': 0,
    'LOBIONDO': 0,
    'LOBITZ': 0,
    'LOBL': 0,
    'LOBLEY': 0,
    'LOBMEYER': 0,
    'LOBNER': 0,
    'LOBO': 0,
    'LOBODA': 0,
    'LOBODZINSKI': 0,
    'LOBOS': 0,
    'LOBOSCO': 0,
    'LOBOZZO': 0,
    'LOBRANO': 0,
    'LOBRUTTO': 0,
    'LOBSIGER': 0,
    'LOBSINGER': 0,
    'LOBSTEIN': 0,
    'LOBUE': 0,
    'LOBUGLIO': 0,
    'LOBUONO': 0,
    'LOBUR': 0,
    'LOC': 0,
    'LOCANO': 0,
    'LOCANTORE': 0,
    'LOCASCIO': 0,
    'LOCASTO': 0,
    'LOCASTRO': 0,
    'LOCATELLI': 0,
    'LOCATI': 0,
    'LOCCISANO': 0,
    'LOCEY': 0,
    'LOCH': 0,
    'LOCHAN': 0,
    'LOCHARD': 0,
    'LOCHARY': 0,
    'LOCHBAUM': 0,
    'LOCHE': 0,
    'LOCHEN': 0,
    'LOCHER': 0,
    'LOCHHEAD': 0,
    'LOCHIATTO': 0,
    'LOCHIRCO': 0,
    'LOCHMAN': 0,
    'LOCHMANN': 0,
    'LOCHNER': 0,
    'LOCHOTZKI': 0,
    'LOCHRIDGE': 0,
    'LOCHRIE': 0,
    'LOCHTE': 0,
    'LOCHTEFELD': 0,
    'LOCICERO': 0,
    'LOCK': 0,
    'LOCKABY': 0,
    'LOCKAMY': 0,
    'LOCKARD': 0,
    'LOCKART': 0,
    'LOCKBAUM': 0,
    'LOCKE': 0,
    'LOCKEBY': 0,
    'LOCKEE': 0,
    'LOCKEN': 0,
    'LOCKER': 0,
    'LOCKERBIE': 0,
    'LOCKERBY': 0,
    'LOCKERMAN': 0,
    'LOCKERT': 0,
    'LOCKERY': 0,
    'LOCKET': 0,
    'LOCKETT': 0,
    'LOCKETTE': 0,
    'LOCKEY': 0,
    'LOCKHART': 0,
    'LOCKHEAD': 0,
    'LOCKHEART': 0,
    'LOCKIE': 0,
    'LOCKINGTON': 0,
    'LOCKLAIR': 0,
    'LOCKLAR': 0,
    'LOCKLEAR': 0,
    'LOCKLER': 0,
    'LOCKLEY': 0,
    'LOCKLIER': 0,
    'LOCKLIN': 0,
    'LOCKMAN': 0,
    'LOCKMILLER': 0,
    'LOCKNER': 0,
    'LOCKNEY': 0,
    'LOCKREM': 0,
    'LOCKREY': 0,
    'LOCKRIDGE': 0,
    'LOCKROW': 0,
    'LOCKS': 0,
    'LOCKWOOD': 0,
    'LOCKYEAR': 0,
    'LOCKYER': 0,
    'LOCOCO': 0,
    'LOCONTE': 0,
    'LOCONTI': 0,
    'LOCONTO': 0,
    'LOCQUIAO': 0,
    'LOCRICCHIO': 0,
    'LOCSIN': 0,
    'LOCURCIO': 0,
    'LOCURTO': 0,
    'LOCUS': 0,
    'LOCUST': 0,
    'LOCY': 0,
    'LODA': 0,
    'LODAHL': 0,
    'LODATO': 0,
    'LODDER': 0,
    'LODE': 0,
    'LODEN': 0,
    'LODER': 0,
    'LODERMEIER': 0,
    'LODES': 0,
    'LODESTRO': 0,
    'LODGE': 0,
    'LODHI': 0,
    'LODHOLZ': 0,
    'LODI': 0,
    'LODICO': 0,
    'LODIN': 0,
    'LODING': 0,
    'LODISE': 0,
    'LODL': 0,
    'LODOLCE': 0,
    'LODOVICO': 0,
    'LODRIGUE': 0,
    'LODS': 0,
    'LODUCA': 0,
    'LODWICK': 0,
    'LODWIG': 0,
    'LODY': 0,
    'LODZINSKI': 0,
    'LOE': 0,
    'LOEB': 0,
    'LOEBACH': 0,
    'LOEBE': 0,
    'LOEBEL': 0,
    'LOEBER': 0,
    'LOEBIG': 0,
    'LOEBL': 0,
    'LOEBLEIN': 0,
    'LOEBS': 0,
    'LOEBSACK': 0,
    'LOECHEL': 0,
    'LOECHER': 0,
    'LOECHLER': 0,
    'LOECHNER': 0,
    'LOECK': 0,
    'LOECKER': 0,
    'LOEDING': 0,
    'LOEFFEL': 0,
    'LOEFFELBEIN': 0,
    'LOEFFELHOLZ': 0,
    'LOEFFELMAN': 0,
    'LOEFFERT': 0,
    'LOEFFLER': 0,
    'LOEGERING': 0,
    'LOEHLE': 0,
    'LOEHLEIN': 0,
    'LOEHMAN': 0,
    'LOEHMANN': 0,
    'LOEHNER': 0,
    'LOEHR': 0,
    'LOEHRER': 0,
    'LOEHRKE': 0,
    'LOEKS': 0,
    'LOEN': 0,
    'LOENDORF': 0,
    'LOEPER': 0,
    'LOEPKER': 0,
    'LOEPP': 0,
    'LOER': 0,
    'LOERA': 0,
    'LOERCH': 0,
    'LOERKE': 0,
    'LOERTSCHER': 0,
    'LOERWALD': 0,
    'LOERZEL': 0,
    'LOES': 0,
    'LOESCH': 0,
    'LOESCHE': 0,
    'LOESCHEN': 0,
    'LOESCHER': 0,
    'LOESCHKE': 0,
    'LOESCHNER': 0,
    'LOESEL': 0,
    'LOESER': 0,
    'LOESING': 0,
    'LOESSIN': 0,
    'LOEST': 0,
    'LOETE': 0,
    'LOETHEN': 0,
    'LOETHER': 0,
    'LOETSCHER': 0,
    'LOETZ': 0,
    'LOEUNG': 0,
    'LOEW': 0,
    'LOEWE': 0,
    'LOEWEN': 0,
    'LOEWENBERG': 0,
    'LOEWENHAGEN': 0,
    'LOEWENSTEIN': 0,
    'LOEWENTHAL': 0,
    'LOEWER': 0,
    'LOEWY': 0,
    'LOEZA': 0,
    'LOFARO': 0,
    'LOFASO': 0,
    'LOFBERG': 0,
    'LOFDAHL': 0,
    'LOFF': 0,
    'LOFFER': 0,
    'LOFFLER': 0,
    'LOFFREDO': 0,
    'LOFFT': 0,
    'LOFGRAN': 0,
    'LOFGREEN': 0,
    'LOFGREN': 0,
    'LOFING': 0,
    'LOFINK': 0,
    'LOFLAND': 0,
    'LOFLIN': 0,
    'LOFORTE': 0,
    'LOFQUIST': 0,
    'LOFRANCO': 0,
    'LOFRANO': 0,
    'LOFSTEDT': 0,
    'LOFSTROM': 0,
    'LOFT': 0,
    'LOFTEN': 0,
    'LOFTHOUSE': 0,
    'LOFTHUS': 0,
    'LOFTICE': 0,
    'LOFTIES': 0,
    'LOFTIN': 0,
    'LOFTIS': 0,
    'LOFTON': 0,
    'LOFTS': 0,
    'LOFTSGARD': 0,
    'LOFTUS': 0,
    'LOFTY': 0,
    'LOFURNO': 0,
    'LOFY': 0,
    'LOGA': 0,
    'LOGALBO': 0,
    'LOGAN': 0.4291845493562232,
    'LOGANBILL': 0,
    'LOGAR': 0,
    'LOGAS': 0,
    'LOGATTO': 0,
    'LOGE': 0,
    'LOGEE': 0,
    'LOGEL': 0,
    'LOGELIN': 0,
    'LOGEMAN': 0,
    'LOGEMANN': 0,
    'LOGER': 0,
    'LOGERFO': 0,
    'LOGES': 0,
    'LOGG': 0,
    'LOGGAINS': 0,
    'LOGGANS': 0,
    'LOGGHE': 0,
    'LOGGIA': 0,
    'LOGGIE': 0,
    'LOGGIN': 0,
    'LOGGINS': 0,
    'LOGHRY': 0,
    'LOGIE': 0,
    'LOGIN': 0,
    'LOGING': 0,
    'LOGIUDICE': 0,
    'LOGLISCI': 0,
    'LOGNION': 0,
    'LOGO': 0,
    'LOGOTHETIS': 0,
    'LOGOZZO': 0,
    'LOGRANDE': 0,
    'LOGRASSO': 0,
    'LOGRECO': 0,
    'LOGRONO': 0,
    'LOGSDON': 0,
    'LOGSTON': 0,
    'LOGTERMAN': 0,
    'LOGUE': 0,
    'LOGUERCIO': 0,
    'LOGUIDICE': 0,
    'LOGULLO': 0,
    'LOGWOOD': 0,
    'LOH': 0,
    'LOHAN': 0,
    'LOHAUS': 0,
    'LOHBECK': 0,
    'LOHDEN': 0,
    'LOHER': 0,
    'LOHF': 0,
    'LOHFF': 0,
    'LOHKAMP': 0,
    'LOHMAN': 0,
    'LOHMANN': 0,
    'LOHMAR': 0,
    'LOHMEIER': 0,
    'LOHMEYER': 0,
    'LOHMILLER': 0,
    'LOHN': 0,
    'LOHNER': 0,
    'LOHNES': 0,
    'LOHR': 0,
    'LOHRBACH': 0,
    'LOHRE': 0,
    'LOHRENGEL': 0,
    'LOHRENTZ': 0,
    'LOHRENZ': 0,
    'LOHRER': 0,
    'LOHREY': 0,
    'LOHRKE': 0,
    'LOHRMAN': 0,
    'LOHRMANN': 0,
    'LOHRY': 0,
    'LOHSE': 0,
    'LOHSEN': 0,
    'LOHUIS': 0,
    'LOI': 0,
    'LOIA': 0,
    'LOIACANO': 0,
    'LOIACONO': 0,
    'LOIBL': 0,
    'LOIDA': 0.9803921568627452,
    'LOIDOLT': 0,
    'LOIGNON': 0,
    'LOIS': 0.998774231624824,
    'LOISE': 1,
    'LOISEAU': 0,
    'LOISEL': 0,
    'LOISELLE': 0,
    'LOITZ': 0,
    'LOIZEAUX': 0,
    'LOIZIDES': 0,
    'LOIZOS': 0,
    'LOIZOU': 0,
    'LOIZZO': 0,
    'LOJA': 0,
    'LOJACONO': 0,
    'LOJANO': 0,
    'LOJAS': 0,
    'LOJEK': 0,
    'LOJEWSKI': 0,
    'LOJKO': 0,
    'LOJO': 0,
    'LOK': 0,
    'LOKAR': 0,
    'LOKAY': 0,
    'LOKE': 0,
    'LOKEN': 0,
    'LOKENSGARD': 0,
    'LOKER': 0,
    'LOKEY': 0,
    'LOKHANDWALA': 0,
    'LOKKE': 0,
    'LOKKEN': 0,
    'LOKKER': 0,
    'LOKSHIN': 0,
    'LOKUTA': 0,
    'LOLA': 0.9979209979209979,
    'LOLAND': 0,
    'LOLAR': 0,
    'LOLE': 0,
    'LOLI': 0,
    'LOLIS': 0,
    'LOLITA': 1,
    'LOLL': 0,
    'LOLLAR': 0,
    'LOLLER': 0,
    'LOLLEY': 0,
    'LOLLI': 0,
    'LOLLIE': 0,
    'LOLLING': 0,
    'LOLLIS': 0,
    'LOLLMAN': 0,
    'LOLLO': 0,
    'LOLLY': 0,
    'LOLMAUGH': 0,
    'LOLO': 0,
    'LOLOHEA': 0,
    'LOLOS': 0,
    'LOM': 0,
    'LOMA': 0.9259259259259258,
    'LOMACK': 0,
    'LOMAGLIO': 0,
    'LOMAN': 0,
    'LOMANGINO': 0,
    'LOMANNO': 0,
    'LOMANTO': 0,
    'LOMAS': 0,
    'LOMASCOLO': 0,
    'LOMASNEY': 0,
    'LOMASTRO': 0,
    'LOMAURO': 0,
    'LOMAX': 0,
    'LOMBA': 0,
    'LOMBANA': 0,
    'LOMBARD': 0,
    'LOMBARDI': 0,
    'LOMBARDINI': 0,
    'LOMBARDINO': 0,
    'LOMBARDO': 0,
    'LOMBARDOZZI': 0,
    'LOMBARDY': 0,
    'LOMBARI': 0,
    'LOMBAS': 0,
    'LOMBERA': 0,
    'LOMBINO': 0,
    'LOMBOY': 0,
    'LOMBRANA': 0,
    'LOME': 0,
    'LOMEDICO': 0,
    'LOMELI': 0,
    'LOMELIN': 0,
    'LOMELINO': 0,
    'LOMELY': 0,
    'LOMEN': 0,
    'LOMENICK': 0,
    'LOMENZO': 0,
    'LOMEO': 0,
    'LOMERSON': 0,
    'LOMIBAO': 0,
    'LOMINAC': 0,
    'LOMINY': 0,
    'LOMIS': 0,
    'LOMISON': 0,
    'LOMMEL': 0,
    'LOMMEN': 0,
    'LOMONACO': 0,
    'LOMONT': 0,
    'LOMONTE': 0,
    'LOMPREY': 0,
    'LOMU': 0,
    'LOMUSCIO': 0,
    'LON': 0.9831460674157303,
    'LONA': 0.9283819628647215,
    'LONABAUGH': 0,
    'LONADIER': 0,
    'LONAKER': 0,
    'LONARDO': 0,
    'LONAS': 0,
    'LONBERGER': 0,
    'LONCAR': 0,
    'LONCARIC': 0,
    'LONCHAR': 0,
    'LONCZAK': 0,
    'LOND': 0,
    'LONDA': 0.9433962264150944,
    'LONDAGIN': 0,
    'LONDER': 0,
    'LONDEREE': 0,
    'LONDERGAN': 0,
    'LONDINO': 0,
    'LONDO': 0,
    'LONDON': 0,
    'LONDONO': 0,
    'LONDOS': 0,
    'LONDRE': 0,
    'LONDRIE': 0,
    'LONDRIGAN': 0,
    'LONE': 0,
    'LONEBEAR': 0,
    'LONEMAN': 0,
    'LONER': 0,
    'LONERGAN': 0,
    'LONERO': 0,
    'LONES': 0,
    'LONESOME': 0,
    'LONETREE': 0,
    'LONETTI': 0,
    'LONEWOLF': 0,
    'LONEY': 0,
    'LONG': 0.04605641911341394,
    'LONGABAUGH': 0,
    'LONGACRE': 0,
    'LONGAKER': 0,
    'LONGAN': 0,
    'LONGANBACH': 0,
    'LONGANECKER': 0,
    'LONGANO': 0,
    'LONGARDNER': 0,
    'LONGBERRY': 0,
    'LONGBINE': 0,
    'LONGBONS': 0,
    'LONGBOTHAM': 0,
    'LONGBOTTOM': 0,
    'LONGBOY': 0,
    'LONGBRAKE': 0,
    'LONGCHAMP': 0,
    'LONGCHAMPS': 0,
    'LONGCOR': 0,
    'LONGCORE': 0,
    'LONGCOY': 0,
    'LONGCRIER': 0,
    'LONGDEN': 0,
    'LONGDON': 0,
    'LONGE': 0,
    'LONGEE': 0,
    'LONGEN': 0,
    'LONGENBACH': 0,
    'LONGENBAUGH': 0,
    'LONGENBERGER': 0,
    'LONGENDYKE': 0,
    'LONGENECKER': 0,
    'LONGER': 0,
    'LONGERBEAM': 0,
    'LONGERBONE': 0,
    'LONGEST': 0,
    'LONGEWAY': 0,
    'LONGFELLOW': 0,
    'LONGFIELD': 0,
    'LONGHENRY': 0,
    'LONGHI': 0,
    'LONGHINI': 0,
    'LONGHITANO': 0,
    'LONGHOFER': 0,
    'LONGHORN': 0,
    'LONGHURST': 0,
    'LONGI': 0,
    'LONGIE': 0,
    'LONGIN': 0,
    'LONGINO': 0,
    'LONGINOTTI': 0,
    'LONGLAND': 0,
    'LONGLEY': 0,
    'LONGMAN': 0,
    'LONGMEYER': 0,
    'LONGMIRE': 0,
    'LONGMORE': 0,
    'LONGMUIR': 0,
    'LONGNECKER': 0,
    'LONGO': 0,
    'LONGOBARDI': 0,
    'LONGOBARDO': 0,
    'LONGORIA': 0,
    'LONGPRE': 0,
    'LONGRIE': 0,
    'LONGS': 0,
    'LONGSDORF': 0,
    'LONGSHAW': 0,
    'LONGSHORE': 0,
    'LONGSINE': 0,
    'LONGSON': 0,
    'LONGSTAFF': 0,
    'LONGSTREET': 0,
    'LONGSTRETH': 0,
    'LONGSWORTH': 0,
    'LONGTIN': 0,
    'LONGTINE': 0,
    'LONGTON': 0,
    'LONGUEIRA': 0,
    'LONGUS': 0,
    'LONGUSKI': 0,
    'LONGVAL': 0,
    'LONGVILLE': 0,
    'LONGWAY': 0,
    'LONGWELL': 0,
    'LONGWILL': 0,
    'LONGWITH': 0,
    'LONGWOOD': 0,
    'LONGWORTH': 0,
    'LONGYEAR': 0,
    'LONI': 1,
    'LONIDIER': 0,
    'LONIE': 0,
    'LONIEWSKI': 0,
    'LONIGRO': 0,
    'LONIS': 0,
    'LONJOSE': 0,
    'LONKER': 0,
    'LONN': 0,
    'LONNA': 1,
    'LONNEMAN': 0,
    'LONNER': 0,
    'LONNIE': 0.9994206257242179,
    'LONNING': 0,
    'LONNQUIST': 0,
    'LONNY': 1,
    'LONO': 0,
    'LONON': 0,
    'LONOWSKI': 0,
    'LONS': 0,
    'LONSBERRY': 0,
    'LONSBURY': 0,
    'LONSDALE': 0,
    'LONSFORD': 0,
    'LONSINGER': 0,
    'LONSKI': 0,
    'LONSKY': 0,
    'LONSWAY': 0,
    'LONT': 0,
    'LONTINE': 0,
    'LONTOC': 0,
    'LONTOK': 0,
    'LONTZ': 0,
    'LONZO': 0,
    'LOO': 0,
    'LOOBY': 0,
    'LOOCK': 0,
    'LOOF': 0,
    'LOOFBORO': 0,
    'LOOFBOURROW': 0,
    'LOOFT': 0,
    'LOOK': 0,
    'LOOKABAUGH': 0,
    'LOOKABILL': 0,
    'LOOKADOO': 0,
    'LOOKE': 0,
    'LOOKER': 0,
    'LOOKINGBILL': 0,
    'LOOMAN': 0,
    'LOOMANS': 0,
    'LOOMER': 0,
    'LOOMIS': 0,
    'LOON': 0,
    'LOONAM': 0,
    'LOONAN': 0,
    'LOONEY': 0,
    'LOONSFOOT': 0,
    'LOOP': 0,
    'LOOPE': 0,
    'LOOPER': 0,
    'LOOR': 0,
    'LOOS': 0,
    'LOOSBROCK': 0,
    'LOOSE': 0,
    'LOOSEMORE': 0,
    'LOOSEN': 0,
    'LOOSER': 0,
    'LOOSIER': 0,
    'LOOSLE': 0,
    'LOOSLI': 0,
    'LOOTENS': 0,
    'LOOTS': 0,
    'LOOZE': 0,
    'LOPA': 0,
    'LOPAC': 0,
    'LOPACKI': 0,
    'LOPANE': 0,
    'LOPARCO': 0,
    'LOPARDO': 0,
    'LOPARO': 0,
    'LOPAS': 0,
    'LOPATA': 0,
    'LOPATIN': 0,
    'LOPATKA': 0,
    'LOPAZ': 0,
    'LOPE': 0,
    'LOPEC': 0,
    'LOPEMAN': 0,
    'LOPER': 0,
    'LOPERA': 0,
    'LOPERENA': 0,
    'LOPERFIDO': 0,
    'LOPES': 0,
    'LOPEX': 0,
    'LOPEZ': 0,
    'LOPEZCASTILLO': 0,
    'LOPEZCASTRO': 0,
    'LOPEZCHAVEZ': 0,
    'LOPEZCRUZ': 0,
    'LOPEZDIAZ': 0,
    'LOPEZFLORES': 0,
    'LOPEZGARCIA': 0,
    'LOPEZGOMEZ': 0,
    'LOPEZGONZALEZ': 0,
    'LOPEZHERNANDEZ': 0,
    'LOPEZJIMENEZ': 0,
    'LOPEZLOPEZ': 0,
    'LOPEZMARTINEZ': 0,
    'LOPEZMENDEZ': 0,
    'LOPEZMORALES': 0,
    'LOPEZORTIZ': 0,
    'LOPEZPEREZ': 0,
    'LOPEZRAMIREZ': 0,
    'LOPEZRAMOS': 0,
    'LOPEZREYES': 0,
    'LOPEZRIVERA': 0,
    'LOPEZRODRIGUEZ': 0,
    'LOPEZROMERO': 0,
    'LOPEZRUIZ': 0,
    'LOPEZSANCHEZ': 0,
    'LOPEZTORRES': 0,
    'LOPEZVASQUEZ': 0,
    'LOPIANO': 0,
    'LOPICCOLO': 0,
    'LOPILATO': 0,
    'LOPINA': 0,
    'LOPINSKI': 0,
    'LOPINTO': 0,
    'LOPO': 0,
    'LOPOPOLO': 0,
    'LOPORTO': 0,
    'LOPP': 0,
    'LOPPNOW': 0,
    'LOPRESTI': 0,
    'LOPRESTO': 0,
    'LOPRETE': 0,
    'LOPRINZI': 0,
    'LOPRIORE': 0,
    'LOPS': 0,
    'LOPSHIRE': 0,
    'LOPUS': 0,
    'LOR': 0,
    'LORA': 0.9511228533685601,
    'LORAAS': 0,
    'LORADITCH': 0,
    'LORAH': 0,
    'LORAINE': 0.9946442234123949,
    'LORALEE': 1,
    'LORAN': 0,
    'LORANCA': 0,
    'LORANCE': 0,
    'LORANG': 0,
    'LORANGE': 0,
    'LORANGER': 0,
    'LORANT': 0,
    'LORBER': 0,
    'LORBERBAUM': 0,
    'LORBIECKI': 0,
    'LORCA': 0,
    'LORCH': 0,
    'LORD': 0,
    'LORDAN': 0,
    'LORDE': 0,
    'LORDEN': 0,
    'LORDI': 0,
    'LORDITCH': 0,
    'LORDO': 0,
    'LORDS': 0,
    'LORE': 0.628930817610063,
    'LOREA': 0,
    'LOREAN': 1,
    'LOREDO': 0,
    'LOREE': 0.8810572687224669,
    'LOREEN': 1,
    'LOREFICE': 0,
    'LOREI': 0,
    'LOREK': 0,
    'LORELEI': 1,
    'LORELLI': 0,
    'LORELLO': 0,
    'LOREMAN': 0,
    'LOREN': 0.9903640256959315,
    'LORENA': 0.9982788296041307,
    'LORENC': 0,
    'LORENCE': 0,
    'LORENCZ': 0,
    'LORENE': 1,
    'LORENO': 0,
    'LORENS': 0,
    'LORENSEN': 0,
    'LORENSON': 0,
    'LORENT': 0,
    'LORENTE': 0,
    'LORENTI': 0,
    'LORENTSEN': 0,
    'LORENTSON': 0,
    'LORENTZ': 0,
    'LORENTZEN': 0,
    'LORENZ': 0,
    'LORENZA': 1,
    'LORENZANA': 0,
    'LORENZANO': 0,
    'LORENZE': 0,
    'LORENZEN': 0,
    'LORENZETTI': 0,
    'LORENZI': 0,
    'LORENZINI': 0,
    'LORENZO': 0.8853910477127398,
    'LORENZON': 0,
    'LORENZONI': 0,
    'LORES': 0,
    'LORETA': 1,
    'LORETDEMOLA': 0,
    'LORETH': 0,
    'LORETI': 0,
    'LORETO': 0,
    'LORETT': 0,
    'LORETTA': 0.9990443923203892,
    'LORETTE': 0.8695652173913043,
    'LORETTO': 0,
    'LORETZ': 0,
    'LOREY': 0,
    'LOREZ': 0,
    'LORFING': 0,
    'LORG': 0,
    'LORGE': 0,
    'LORI': 0.999234457472098,
    'LORIA': 0.6097560975609757,
    'LORIANN': 1,
    'LORIAUX': 0,
    'LORICH': 0,
    'LORICK': 0,
    'LORICO': 0,
    'LORIE': 0.9931719428926132,
    'LORIG': 0,
    'LORIGAN': 0,
    'LORIGO': 0,
    'LORILEE': 1,
    'LORIMER': 0,
    'LORIMOR': 0,
    'LORIN': 0,
    'LORINA': 1,
    'LORINCE': 0,
    'LORINCZ': 0,
    'LORINDA': 1,
    'LORINE': 1,
    'LORING': 0,
    'LORINO': 0,
    'LORIO': 0,
    'LORION': 0,
    'LORIS': 0.9009009009009009,
    'LORISH': 0,
    'LORISTON': 0,
    'LORITA': 1,
    'LORITZ': 0,
    'LORKOWSKI': 0,
    'LORMAN': 0,
    'LORMAND': 0,
    'LORN': 0,
    'LORNA': 1,
    'LORNE': 0,
    'LORO': 0,
    'LORONA': 0,
    'LOROW': 0,
    'LORQUET': 0,
    'LORR': 0,
    'LORRAIN': 0,
    'LORRAINE': 0.9974878084823408,
    'LORREN': 0,
    'LORRETTA': 1,
    'LORRI': 1,
    'LORRIANE': 1,
    'LORRIE': 1,
    'LORRINE': 1,
    'LORSBACH': 0,
    'LORSCHEIDER': 0,
    'LORSON': 0,
    'LORSUNG': 0,
    'LORT': 0,
    'LORTA': 0,
    'LORTIE': 0,
    'LORTON': 0,
    'LORTS': 0,
    'LORTSCHER': 0,
    'LORTZ': 0,
    'LORUSSO': 0,
    'LORY': 0.9090909090909091,
    'LORZ': 0,
    'LOS': 0,
    'LOSA': 0,
    'LOSACCO': 0,
    'LOSACK': 0,
    'LOSADA': 0,
    'LOSAK': 0,
    'LOSANO': 0,
    'LOSAPIO': 0,
    'LOSARDO': 0,
    'LOSASSO': 0,
    'LOSAVIO': 0,
    'LOSAW': 0,
    'LOSBY': 0,
    'LOSCALZO': 0,
    'LOSCAR': 0,
    'LOSCH': 0,
    'LOSCHEIDER': 0,
    'LOSCHEN': 0,
    'LOSCHER': 0,
    'LOSCHIAVO': 0,
    'LOSCO': 0,
    'LOSE': 0,
    'LOSEE': 0,
    'LOSEKAMP': 0,
    'LOSEKE': 0,
    'LOSEN': 0,
    'LOSER': 0,
    'LOSEY': 0,
    'LOSH': 0,
    'LOSHBAUGH': 0,
    'LOSHBOUGH': 0,
    'LOSHE': 0,
    'LOSHER': 0,
    'LOSI': 0,
    'LOSIE': 0,
    'LOSIER': 0,
    'LOSIEWICZ': 0,
    'LOSIK': 0,
    'LOSING': 0,
    'LOSINGER': 0,
    'LOSINIECKI': 0,
    'LOSINSKI': 0,
    'LOSITO': 0,
    'LOSKOT': 0,
    'LOSLI': 0,
    'LOSO': 0,
    'LOSORDO': 0,
    'LOSOYA': 0,
    'LOSQUADRO': 0,
    'LOSS': 0,
    'LOSSE': 0,
    'LOSSER': 0,
    'LOSSETT': 0,
    'LOSSIAH': 0,
    'LOSSING': 0,
    'LOSSMAN': 0,
    'LOSSON': 0,
    'LOSTAUNAU': 0,
    'LOSTER': 0,
    'LOSTETTER': 0,
    'LOSTON': 0,
    'LOSTRACCO': 0,
    'LOSTRITTO': 0,
    'LOSTUMBO': 0,
    'LOSTUTTER': 0,
    'LOSURDO': 0,
    'LOSURE': 0,
    'LOT': 0,
    'LOTA': 0,
    'LOTAN': 0,
    'LOTARSKI': 0,
    'LOTEMPIO': 0,
    'LOTER': 0,
    'LOTERO': 0,
    'LOTFI': 0,
    'LOTH': 0,
    'LOTHAMER': 0,
    'LOTHARP': 0,
    'LOTHE': 0,
    'LOTHER': 0,
    'LOTHERT': 0,
    'LOTHERY': 0,
    'LOTHES': 0,
    'LOTHIAN': 0,
    'LOTHRIDGE': 0,
    'LOTHRINGER': 0,
    'LOTHROP': 0,
    'LOTHSPEICH': 0,
    'LOTIERZO': 0,
    'LOTITO': 0,
    'LOTMAN': 0,
    'LOTRIDGE': 0,
    'LOTSHAW': 0,
    'LOTSPEICH': 0,
    'LOTT': 0,
    'LOTTA': 0,
    'LOTTE': 0,
    'LOTTEN': 0,
    'LOTTER': 0,
    'LOTTERER': 0,
    'LOTTES': 0,
    'LOTTI': 0,
    'LOTTIE': 0.9942004971002485,
    'LOTTIG': 0,
    'LOTTINVILLE': 0,
    'LOTTMAN': 0,
    'LOTTMANN': 0,
    'LOTTO': 0,
    'LOTTON': 0,
    'LOTTRIDGE': 0,
    'LOTTS': 0,
    'LOTURCO': 0,
    'LOTZ': 0,
    'LOTZE': 0,
    'LOTZER': 0,
    'LOU': 0.9652509652509652,
    'LOUALLEN': 0,
    'LOUANGRATH': 0,
    'LOUANN': 1,
    'LOUANNE': 1,
    'LOUBERT': 0,
    'LOUBIER': 0,
    'LOUBRIEL': 0,
    'LOUCAS': 0,
    'LOUCEL': 0,
    'LOUCH': 0,
    'LOUCHART': 0,
    'LOUCK': 0,
    'LOUCKS': 0,
    'LOUD': 0,
    'LOUDD': 0,
    'LOUDEN': 0,
    'LOUDENBACK': 0,
    'LOUDENSLAGER': 0,
    'LOUDER': 0,
    'LOUDERBACK': 0,
    'LOUDERMAN': 0,
    'LOUDERMILK': 0,
    'LOUDERMILL': 0,
    'LOUDIN': 0,
    'LOUDIS': 0,
    'LOUDNER': 0,
    'LOUDON': 0,
    'LOUDY': 0,
    'LOUE': 0,
    'LOUELLA': 1,
    'LOUER': 0,
    'LOUETTA': 1,
    'LOUEY': 0,
    'LOUGE': 0,
    'LOUGEE': 0,
    'LOUGH': 0,
    'LOUGHAN': 0,
    'LOUGHARY': 0,
    'LOUGHBOROUGH': 0,
    'LOUGHEAD': 0,
    'LOUGHEED': 0,
    'LOUGHERY': 0,
    'LOUGHIN': 0,
    'LOUGHLIN': 0,
    'LOUGHMAN': 0,
    'LOUGHMILLER': 0,
    'LOUGHNANE': 0,
    'LOUGHNER': 0,
    'LOUGHNEY': 0,
    'LOUGHRAN': 0,
    'LOUGHREN': 0,
    'LOUGHREY': 0,
    'LOUGHRIDGE': 0,
    'LOUGHRIGE': 0,
    'LOUGHRIN': 0,
    'LOUGHRY': 0,
    'LOUI': 0,
    'LOUIDOR': 0,
    'LOUIE': 0.8699434536755111,
    'LOUIMA': 0,
    'LOUIS': 0.9730069052102951,
    'LOUISA': 0.995850622406639,
    'LOUISCHARLES': 0,
    'LOUISE': 0.9989966409283254,
    'LOUISELLE': 0,
    'LOUISJACQUES': 0,
    'LOUISJEAN': 0,
    'LOUISJEUNE': 0,
    'LOUISON': 0,
    'LOUISSAINT': 0,
    'LOUISVILLE': 0,
    'LOUK': 0,
    'LOUKAS': 0,
    'LOUKOTA': 0,
    'LOUKS': 0,
    'LOULA': 0,
    'LOUN': 0,
    'LOUNDER': 0,
    'LOUNDS': 0,
    'LOUNG': 0,
    'LOUNSBERRY': 0,
    'LOUNSBERY': 0,
    'LOUNSBURY': 0,
    'LOUP': 0,
    'LOUPE': 0,
    'LOUPEE': 0,
    'LOUQUE': 0,
    'LOUR': 0,
    'LOURA': 0.9009009009009009,
    'LOURCEY': 0,
    'LOURDES': 0.9979209979209979,
    'LOUREIRD': 0,
    'LOUREIRO': 0,
    'LOURENCO': 0,
    'LOURENS': 0,
    'LOURIA': 0,
    'LOURIDO': 0,
    'LOURIE': 0.8547008547008547,
    'LOURIS': 0,
    'LOURO': 0,
    'LOURY': 0,
    'LOUSBERG': 0,
    'LOUSHIN': 0,
    'LOUSTALOT': 0,
    'LOUSTAUNAU': 0,
    'LOUSTEAU': 0,
    'LOUT': 0,
    'LOUTH': 0,
    'LOUTHAIN': 0,
    'LOUTHAN': 0,
    'LOUTHEN': 0,
    'LOUTHER': 0,
    'LOUTHIAN': 0,
    'LOUTON': 0,
    'LOUTSCH': 0,
    'LOUTTIT': 0,
    'LOUTZENHEISER': 0,
    'LOUTZENHISER': 0,
    'LOUVAR': 0,
    'LOUVENIA': 1,
    'LOUVIER': 0,
    'LOUVIERE': 0,
    'LOUW': 0,
    'LOUWAGIE': 0,
    'LOUWERS': 0,
    'LOUX': 0,
    'LOUY': 0,
    'LOUZON': 0,
    'LOV': 0,
    'LOVAAS': 0,
    'LOVAGLIO': 0,
    'LOVALL': 0,
    'LOVALLO': 0,
    'LOVAN': 0,
    'LOVAS': 0,
    'LOVASCO': 0,
    'LOVASZ': 0,
    'LOVATO': 0,
    'LOVATT': 0,
    'LOVDAHL': 0,
    'LOVE': 0.0333000333000333,
    'LOVEALL': 0,
    'LOVEBERRY': 0,
    'LOVECCHIO': 0,
    'LOVEDAY': 0,
    'LOVEGREEN': 0,
    'LOVEGREN': 0,
    'LOVEGROVE': 0,
    'LOVEJOY': 0,
    'LOVEKAMP': 0,
    'LOVEL': 0,
    'LOVELACE': 0,
    'LOVELADY': 0,
    'LOVELAND': 0,
    'LOVELESS': 0,
    'LOVELETT': 0,
    'LOVELETTE': 0,
    'LOVELL': 0,
    'LOVELLA': 1,
    'LOVELLE': 0,
    'LOVELLETTE': 0,
    'LOVELOCK': 0,
    'LOVELY': 0,
    'LOVEMAN': 0,
    'LOVEN': 0,
    'LOVENBERG': 0,
    'LOVENBURG': 0,
    'LOVENDAHL': 0,
    'LOVENDUSKI': 0,
    'LOVENGUTH': 0,
    'LOVER': 0,
    'LOVERA': 0,
    'LOVERDE': 0,
    'LOVERDI': 0,
    'LOVERICH': 0,
    'LOVERIDGE': 0,
    'LOVERIN': 0,
    'LOVERING': 0,
    'LOVERME': 0,
    'LOVERN': 0,
    'LOVERO': 0,
    'LOVERRO': 0,
    'LOVERSO': 0,
    'LOVESEE': 0,
    'LOVESTRAND': 0,
    'LOVETERE': 0,
    'LOVETRO': 0,
    'LOVETT': 0,
    'LOVETTA': 1,
    'LOVETTE': 0,
    'LOVEWELL': 0,
    'LOVEY': 0,
    'LOVGREN': 0,
    'LOVI': 0,
    'LOVICH': 0,
    'LOVICK': 0,
    'LOVIE': 0.99009900990099,
    'LOVIG': 0,
    'LOVIK': 0,
    'LOVILL': 0,
    'LOVIN': 0,
    'LOVINE': 0,
    'LOVING': 0,
    'LOVINGER': 0,
    'LOVINGGOOD': 0,
    'LOVINGOOD': 0,
    'LOVINGS': 0,
    'LOVINS': 0,
    'LOVINSKY': 0,
    'LOVIO': 0,
    'LOVIS': 0,
    'LOVISA': 0,
    'LOVISKA': 0,
    'LOVITT': 0,
    'LOVITZ': 0,
    'LOVLEY': 0,
    'LOVO': 0,
    'LOVOI': 0,
    'LOVOLD': 0,
    'LOVORN': 0,
    'LOVOS': 0,
    'LOVOY': 0,
    'LOVRIC': 0,
    'LOVRICH': 0,
    'LOVRIEN': 0,
    'LOVSEY': 0,
    'LOVSTAD': 0,
    'LOVULLO': 0,
    'LOVVORN': 0,
    'LOVY': 0,
    'LOW': 0,
    'LOWANS': 0,
    'LOWARY': 0,
    'LOWBER': 0,
    'LOWD': 0,
    'LOWDEN': 0,
    'LOWDER': 0,
    'LOWDERMILK': 0,
    'LOWE': 0,
    'LOWELL': 0.9215125516364792,
    'LOWEN': 0,
    'LOWENBERG': 0,
    'LOWENSTEIN': 0,
    'LOWENTHAL': 0,
    'LOWER': 0,
    'LOWERRE': 0,
    'LOWERS': 0,
    'LOWERY': 0,
    'LOWES': 0,
    'LOWETH': 0,
    'LOWEY': 0,
    'LOWHORN': 0,
    'LOWIE': 0,
    'LOWIN': 0,
    'LOWING': 0,
    'LOWINGER': 0,
    'LOWIS': 0,
    'LOWITZ': 0,
    'LOWMAN': 0,
    'LOWMASTER': 0,
    'LOWMILLER': 0,
    'LOWN': 0,
    'LOWNDES': 0,
    'LOWNDS': 0,
    'LOWNES': 0,
    'LOWNEY': 0,
    'LOWNSBERY': 0,
    'LOWRANCE': 0,
    'LOWREY': 0,
    'LOWRIE': 0,
    'LOWRIMORE': 0,
    'LOWRY': 0,
    'LOWS': 0,
    'LOWSON': 0,
    'LOWTHER': 0,
    'LOWTHIAN': 0,
    'LOWTHORP': 0,
    'LOWY': 0,
    'LOX': 0,
    'LOXLEY': 0,
    'LOXTERMAN': 0,
    'LOXTON': 0,
    'LOY': 0,
    'LOYA': 0,
    'LOYACANO': 0,
    'LOYAL': 0,
    'LOYALL': 0,
    'LOYCE': 1,
    'LOYD': 0.688360450563204,
    'LOYDE': 0,
    'LOYE': 0,
    'LOYED': 0,
    'LOYER': 0,
    'LOYET': 0,
    'LOYLE': 0,
    'LOYLESS': 0,
    'LOYNACHAN': 0,
    'LOYNAZ': 0,
    'LOYND': 0,
    'LOYNES': 0,
    'LOYO': 0,
    'LOYOLA': 0,
    'LOZA': 0,
    'LOZADA': 0,
    'LOZADO': 0,
    'LOZANO': 0,
    'LOZAR': 0,
    'LOZE': 0,
    'LOZEAU': 0,
    'LOZEN': 0,
    'LOZENSKY': 0,
    'LOZIER': 0,
    'LOZINAK': 0,
    'LOZINSKI': 0,
    'LOZITO': 0,
    'LOZO': 0,
    'LOZON': 0,
    'LOZOWSKI': 0,
    'LOZOYA': 0,
    'LOZZI': 0,
    'LU': 0.2604166666666667,
    'LUA': 0,
    'LUACES': 0,
    'LUALHATI': 0,
    'LUALLEN': 0,
    'LUALLIN': 0,
    'LUAN': 0,
    'LUANA': 1,
    'LUANGKHOT': 0,
    'LUANGRAJ': 0,
    'LUANGRATH': 0,
    'LUANN': 1,
    'LUANNA': 1,
    'LUANNE': 1,
    'LUARCA': 0,
    'LUARK': 0,
    'LUAT': 0,
    'LUBA': 0.8403361344537815,
    'LUBACH': 0,
    'LUBAG': 0,
    'LUBAHN': 0,
    'LUBAN': 0,
    'LUBANSKI': 0,
    'LUBAR': 0,
    'LUBARSKI': 0,
    'LUBARSKY': 0,
    'LUBAS': 0,
    'LUBASH': 0,
    'LUBBE': 0,
    'LUBBEHUSEN': 0,
    'LUBBEN': 0,
    'LUBBERS': 0,
    'LUBBERT': 0,
    'LUBBOCK': 0,
    'LUBE': 0,
    'LUBECK': 0,
    'LUBECKE': 0,
    'LUBECKI': 0,
    'LUBELL': 0,
    'LUBELSKI': 0,
    'LUBEN': 0,
    'LUBENOW': 0,
    'LUBER': 0,
    'LUBERA': 0,
    'LUBERDA': 0,
    'LUBERT': 0,
    'LUBERTO': 0,
    'LUBESKI': 0,
    'LUBETKIN': 0,
    'LUBEY': 0,
    'LUBIANO': 0,
    'LUBIC': 0,
    'LUBICH': 0,
    'LUBICK': 0,
    'LUBIN': 0,
    'LUBINSKI': 0,
    'LUBINSKY': 0,
    'LUBIS': 0,
    'LUBITZ': 0,
    'LUBKE': 0,
    'LUBKEMAN': 0,
    'LUBKER': 0,
    'LUBLIN': 0,
    'LUBLINER': 0,
    'LUBMAN': 0,
    'LUBNER': 0,
    'LUBNIEWSKI': 0,
    'LUBOLD': 0,
    'LUBONSKI': 0,
    'LUBOVICH': 0,
    'LUBOW': 0,
    'LUBRAND': 0,
    'LUBRANO': 0,
    'LUBRANT': 0,
    'LUBS': 0,
    'LUBY': 0,
    'LUC': 0,
    'LUCA': 0,
    'LUCABAUGH': 0,
    'LUCADAMO': 0,
    'LUCADO': 0,
    'LUCAJ': 0,
    'LUCANIA': 0,
    'LUCANO': 0,
    'LUCARELLI': 0,
    'LUCARIELLO': 0,
    'LUCARINI': 0,
    'LUCARIO': 0,
    'LUCAS': 0.45441219583699793,
    'LUCASH': 0,
    'LUCATERO': 0,
    'LUCATORTO': 0,
    'LUCCA': 0,
    'LUCCHESE': 0,
    'LUCCHESI': 0,
    'LUCCHETTI': 0,
    'LUCCHI': 0,
    'LUCCHINI': 0,
    'LUCCHINO': 0,
    'LUCCI': 0,
    'LUCCIOLA': 0,
    'LUCCIONI': 0,
    'LUCCO': 0,
    'LUCE': 0,
    'LUCEK': 0,
    'LUCENA': 0,
    'LUCENTE': 0,
    'LUCENTI': 0,
    'LUCERA': 0,
    'LUCERO': 0,
    'LUCES': 0,
    'LUCEY': 0,
    'LUCH': 0,
    'LUCHA': 0,
    'LUCHAK': 0,
    'LUCHANSKY': 0,
    'LUCHAU': 0,
    'LUCHENBILL': 0,
    'LUCHENE': 0,
    'LUCHETTA': 0,
    'LUCHETTI': 0,
    'LUCHI': 0,
    'LUCHIES': 0,
    'LUCHINI': 0,
    'LUCHS': 0,
    'LUCHSINGER': 0,
    'LUCHT': 0,
    'LUCHTEFELD': 0,
    'LUCHTEL': 0,
    'LUCHTENBURG': 0,
    'LUCHTERHAND': 0,
    'LUCHTMAN': 0,
    'LUCI': 0.9259259259259258,
    'LUCIA': 0.9507640067911713,
    'LUCIAN': 0,
    'LUCIANA': 0.9836065573770493,
    'LUCIANI': 0,
    'LUCIANO': 0.6903353057199211,
    'LUCIBELLO': 0,
    'LUCIC': 0,
    'LUCICH': 0,
    'LUCID': 0,
    'LUCIDI': 0,
    'LUCIDO': 0,
    'LUCIE': 0.9803921568627452,
    'LUCIEN': 0.9421265141318977,
    'LUCIENNE': 1,
    'LUCIER': 0,
    'LUCIK': 0,
    'LUCILA': 1,
    'LUCILE': 1,
    'LUCILLA': 1,
    'LUCILLE': 1,
    'LUCIN': 0,
    'LUCINA': 1,
    'LUCINDA': 1,
    'LUCINI': 0,
    'LUCIO': 0.6795016987542468,
    'LUCIOUS': 0,
    'LUCISANO': 0,
    'LUCITO': 0,
    'LUCIUS': 0.8492569002123141,
    'LUCIW': 0,
    'LUCK': 0,
    'LUCKA': 0,
    'LUCKADO': 0,
    'LUCKADOO': 0,
    'LUCKAS': 0,
    'LUCKE': 0,
    'LUCKEL': 0,
    'LUCKEN': 0,
    'LUCKENBACH': 0,
    'LUCKENBAUGH': 0,
    'LUCKENBILL': 0,
    'LUCKER': 0,
    'LUCKEROTH': 0,
    'LUCKERT': 0,
    'LUCKETT': 0,
    'LUCKETTE': 0,
    'LUCKEY': 0,
    'LUCKHARDT': 0,
    'LUCKHURST': 0,
    'LUCKI': 0,
    'LUCKIE': 0,
    'LUCKINBILL': 0,
    'LUCKING': 0,
    'LUCKMAN': 0,
    'LUCKNER': 0,
    'LUCKO': 0,
    'LUCKOW': 0,
    'LUCKRITZ': 0,
    'LUCKS': 0,
    'LUCKSINGER': 0,
    'LUCKY': 0,
    'LUCO': 0,
    'LUCORE': 0,
    'LUCOT': 0,
    'LUCRECIA': 1,
    'LUCRETIA': 1,
    'LUCUS': 0,
    'LUCY': 0.9893381999807895,
    'LUCYK': 0,
    'LUCZAK': 0,
    'LUCZKOWSKI': 0,
    'LUCZYNSKI': 0,
    'LUDD': 0,
    'LUDDEKE': 0,
    'LUDDEN': 0,
    'LUDDINGTON': 0,
    'LUDDY': 0,
    'LUDE': 0,
    'LUDECKE': 0,
    'LUDEKE': 0,
    'LUDEKING': 0,
    'LUDEMA': 0,
    'LUDEMAN': 0,
    'LUDEMANN': 0,
    'LUDEN': 0,
    'LUDENA': 0,
    'LUDENS': 0,
    'LUDER': 0,
    'LUDERMAN': 0,
    'LUDERS': 0,
    'LUDES': 0,
    'LUDESCHER': 0,
    'LUDEWIG': 0,
    'LUDFORD': 0,
    'LUDGATE': 0,
    'LUDGOOD': 0,
    'LUDI': 0,
    'LUDICK': 0,
    'LUDIE': 1,
    'LUDIKER': 0,
    'LUDIN': 0,
    'LUDINGTON': 0,
    'LUDIVINA': 1,
    'LUDKA': 0,
    'LUDKE': 0,
    'LUDLAM': 0,
    'LUDLOW': 0,
    'LUDLUM': 0,
    'LUDMAN': 0,
    'LUDOLPH': 0,
    'LUDOVICI': 0,
    'LUDOVICO': 0,
    'LUDOVISSY': 0,
    'LUDOWESE': 0,
    'LUDT': 0,
    'LUDTKE': 0,
    'LUDVIGSEN': 0,
    'LUDVIGSON': 0,
    'LUDVIK': 0,
    'LUDWICK': 0,
    'LUDWICZAK': 0,
    'LUDWIG': 0,
    'LUDWIGS': 0,
    'LUDWIGSEN': 0,
    'LUDWIGSON': 0,
    'LUDWIKOWSKI': 0,
    'LUDWIN': 0,
    'LUDWINSKI': 0,
    'LUDY': 0,
    'LUE': 0.8955223880597015,
    'LUEB': 0,
    'LUEBANO': 0,
    'LUEBBE': 0,
    'LUEBBEHUSEN': 0,
    'LUEBBEN': 0,
    'LUEBBERING': 0,
    'LUEBBERS': 0,
    'LUEBBERT': 0,
    'LUEBCKE': 0,
    'LUEBE': 0,
    'LUEBECK': 0,
    'LUEBKE': 0,
    'LUEBKER': 0,
    'LUEBRECHT': 0,
    'LUEBS': 0,
    'LUECHT': 0,
    'LUECHTEFELD': 0,
    'LUECK': 0,
    'LUECKE': 0,
    'LUECKEMEYER': 0,
    'LUECKENHOFF': 0,
    'LUECKENOTTE': 0,
    'LUECKER': 0,
    'LUECKING': 0,
    'LUEDDE': 0,
    'LUEDDERS': 0,
    'LUEDECKE': 0,
    'LUEDEKE': 0,
    'LUEDEMAN': 0,
    'LUEDEMANN': 0,
    'LUEDER': 0,
    'LUEDERS': 0,
    'LUEDKE': 0,
    'LUEDLOFF': 0,
    'LUEDTKE': 0,
    'LUEHMANN': 0,
    'LUEHR': 0,
    'LUEHRING': 0,
    'LUEHRS': 0,
    'LUEKE': 0,
    'LUEKEN': 0,
    'LUEKER': 0,
    'LUEKING': 0,
    'LUELLA': 1,
    'LUELLEN': 0,
    'LUENEBURG': 0,
    'LUENGAS': 0,
    'LUENGO': 0,
    'LUENSMANN': 0,
    'LUEPKE': 0,
    'LUER': 0,
    'LUERA': 0,
    'LUERAS': 0,
    'LUERS': 0,
    'LUERSEN': 0,
    'LUERSSEN': 0,
    'LUESCHER': 0,
    'LUETH': 0,
    'LUETHJE': 0,
    'LUETHKE': 0,
    'LUETHY': 0,
    'LUETJE': 0,
    'LUETJEN': 0,
    'LUETKE': 0,
    'LUETKEMEYER': 0,
    'LUETKENHAUS': 0,
    'LUETTA': 1,
    'LUETZOW': 0,
    'LUEVANO': 0,
    'LUEVANOS': 0,
    'LUEY': 0,
    'LUFF': 0,
    'LUFFEY': 0,
    'LUFFMAN': 0,
    'LUFFY': 0,
    'LUFKIN': 0,
    'LUFRANO': 0,
    'LUFT': 0,
    'LUFTIG': 0,
    'LUFTMAN': 0,
    'LUGAN': 0,
    'LUGAR': 0,
    'LUGARDO': 0,
    'LUGAY': 0,
    'LUGENBEEL': 0,
    'LUGER': 0,
    'LUGERT': 0,
    'LUGG': 0,
    'LUGGE': 0,
    'LUGIBIHL': 0,
    'LUGINBILL': 0,
    'LUGINBUHL': 0,
    'LUGLI': 0,
    'LUGO': 0,
    'LUGONES': 0,
    'LUGOWSKI': 0,
    'LUGTU': 0,
    'LUGUE': 0,
    'LUH': 0,
    'LUHM': 0,
    'LUHMAN': 0,
    'LUHMANN': 0,
    'LUHN': 0,
    'LUHR': 0,
    'LUHRING': 0,
    'LUHRS': 0,
    'LUHRSEN': 0,
    'LUI': 0,
    'LUICH': 0,
    'LUICK': 0,
    'LUIGI': 1,
    'LUIGS': 0,
    'LUIKART': 0,
    'LUIKEN': 0,
    'LUIKENS': 0,
    'LUING': 0,
    'LUINSTRA': 0,
    'LUIPPOLD': 0,
    'LUIS': 0.986876097964245,
    'LUISA': 0.9962640099626402,
    'LUISE': 0.966183574879227,
    'LUISI': 0,
    'LUISO': 0,
    'LUISTRO': 0,
    'LUITEN': 0,
    'LUITHLE': 0,
    'LUITJENS': 0,
    'LUIZ': 0,
    'LUIZZI': 0,
    'LUJAN': 0,
    'LUJANO': 0,
    'LUK': 0,
    'LUKA': 0,
    'LUKAC': 0,
    'LUKACH': 0,
    'LUKACS': 0,
    'LUKAN': 0,
    'LUKAS': 0,
    'LUKASAVAGE': 0,
    'LUKASEK': 0,
    'LUKASH': 0,
    'LUKASIAK': 0,
    'LUKASIEWICZ': 0,
    'LUKASIK': 0,
    'LUKASZCZYK': 0,
    'LUKASZEK': 0,
    'LUKASZEWICZ': 0,
    'LUKASZEWSKI': 0,
    'LUKAT': 0,
    'LUKAVSKY': 0,
    'LUKAWSKI': 0,
    'LUKE': 0.8637443316778234,
    'LUKEFAHR': 0,
    'LUKEHART': 0,
    'LUKEMAN': 0,
    'LUKEMIRE': 0,
    'LUKEN': 0,
    'LUKENBILL': 0,
    'LUKENS': 0,
    'LUKER': 0,
    'LUKERT': 0,
    'LUKES': 0,
    'LUKESH': 0,
    'LUKETIC': 0,
    'LUKETICH': 0,
    'LUKEY': 0,
    'LUKIC': 0,
    'LUKICH': 0,
    'LUKIE': 0,
    'LUKIN': 0,
    'LUKING': 0,
    'LUKINS': 0,
    'LUKIS': 0,
    'LUKITSCH': 0,
    'LUKKEN': 0,
    'LUKKES': 0,
    'LUKMAN': 0,
    'LUKO': 0,
    'LUKOFF': 0,
    'LUKOMSKI': 0,
    'LUKOSE': 0,
    'LUKOW': 0,
    'LUKOWIAK': 0,
    'LUKOWICZ': 0,
    'LUKOWSKI': 0,
    'LUKS': 0,
    'LUKSA': 0,
    'LUKSCH': 0,
    'LUKSIC': 0,
    'LUKSICH': 0,
    'LUKSIK': 0,
    'LUKUS': 0,
    'LULA': 0.9977135730617335,
    'LULAY': 0,
    'LULE': 0,
    'LULEK': 0,
    'LULEWICZ': 0,
    'LULEY': 0,
    'LULGJURAJ': 0,
    'LULI': 0,
    'LULICH': 0,
    'LULL': 0,
    'LULLA': 0,
    'LULLO': 0,
    'LULLOFF': 0,
    'LULO': 0,
    'LULOFF': 0,
    'LULOFS': 0,
    'LULOW': 0,
    'LULU': 0.9852216748768473,
    'LUM': 0,
    'LUMA': 0,
    'LUMADUE': 0,
    'LUMAGUI': 0,
    'LUMAN': 0,
    'LUMANLAN': 0,
    'LUMAR': 0,
    'LUMAS': 0,
    'LUMAYE': 0,
    'LUMB': 0,
    'LUMBA': 0,
    'LUMBARD': 0,
    'LUMBATIS': 0,
    'LUMBERG': 0,
    'LUMBERT': 0,
    'LUMBI': 0,
    'LUMBLEY': 0,
    'LUMBRA': 0,
    'LUMBRERAS': 0,
    'LUMBREZER': 0,
    'LUMBY': 0,
    'LUMER': 0,
    'LUMETTA': 0,
    'LUMFORD': 0,
    'LUMIA': 0,
    'LUMLEY': 0,
    'LUMM': 0,
    'LUMMER': 0,
    'LUMMIS': 0,
    'LUMMUS': 0,
    'LUMP': 0,
    'LUMPKIN': 0,
    'LUMPKINS': 0,
    'LUMPP': 0,
    'LUMSDEN': 0,
    'LUMSDON': 0,
    'LUMZY': 0,
    'LUN': 0,
    'LUNA': 0.06618133686300465,
    'LUNAK': 0,
    'LUNAN': 0,
    'LUNAR': 0,
    'LUNARDI': 0,
    'LUNAS': 0,
    'LUNBECK': 0,
    'LUNCEFORD': 0,
    'LUNCH': 0,
    'LUND': 0,
    'LUNDA': 0,
    'LUNDAHL': 0,
    'LUNDAK': 0,
    'LUNDAY': 0,
    'LUNDBERG': 0,
    'LUNDBLAD': 0,
    'LUNDBLADE': 0,
    'LUNDBOM': 0,
    'LUNDBORG': 0,
    'LUNDBY': 0,
    'LUNDE': 0,
    'LUNDEBERG': 0,
    'LUNDEEN': 0,
    'LUNDELL': 0,
    'LUNDEN': 0,
    'LUNDER': 0,
    'LUNDERGAN': 0,
    'LUNDERMAN': 0,
    'LUNDERS': 0,
    'LUNDERVILLE': 0,
    'LUNDGREEN': 0,
    'LUNDGREN': 0,
    'LUNDH': 0,
    'LUNDHOLM': 0,
    'LUNDI': 0,
    'LUNDIE': 0,
    'LUNDIEN': 0,
    'LUNDIN': 0,
    'LUNDINE': 0,
    'LUNDMARK': 0,
    'LUNDON': 0,
    'LUNDQUIST': 0,
    'LUNDRIGAN': 0,
    'LUNDRY': 0,
    'LUNDSFORD': 0,
    'LUNDSTEDT': 0,
    'LUNDSTEN': 0,
    'LUNDSTROM': 0,
    'LUNDT': 0,
    'LUNDVALL': 0,
    'LUNDWALL': 0,
    'LUNDY': 0,
    'LUNEAU': 0,
    'LUNEKE': 0,
    'LUNEMANN': 0,
    'LUNETTA': 0,
    'LUNEY': 0,
    'LUNFORD': 0,
    'LUNG': 0,
    'LUNGARO': 0,
    'LUNGER': 0,
    'LUNGHI': 0,
    'LUNGO': 0,
    'LUNGREN': 0,
    'LUNGU': 0,
    'LUNGWITZ': 0,
    'LUNIEWSKI': 0,
    'LUNING': 0,
    'LUNK': 0,
    'LUNKENHEIMER': 0,
    'LUNN': 0,
    'LUNNEBORG': 0,
    'LUNNEN': 0,
    'LUNNEY': 0,
    'LUNNIE': 0,
    'LUNNING': 0,
    'LUNNON': 0,
    'LUNNY': 0,
    'LUNOW': 0,
    'LUNSFORD': 0,
    'LUNSKI': 0,
    'LUNSTRUM': 0,
    'LUNT': 0,
    'LUNTSFORD': 0,
    'LUNTZ': 0,
    'LUNZ': 0,
    'LUNZER': 0,
    'LUO': 0,
    'LUOMA': 0,
    'LUONG': 0,
    'LUONGO': 0,
    'LUOTO': 0,
    'LUP': 0,
    'LUPA': 0,
    'LUPACCHINO': 0,
    'LUPARDO': 0,
    'LUPARDUS': 0,
    'LUPARELLO': 0,
    'LUPAS': 0,
    'LUPE': 0.9897070467141725,
    'LUPER': 0,
    'LUPERCIO': 0,
    'LUPEZ': 0,
    'LUPFER': 0,
    'LUPHER': 0,
    'LUPI': 0,
    'LUPIA': 0,
    'LUPIAN': 0,
    'LUPICA': 0,
    'LUPIEN': 0,
    'LUPIN': 0,
    'LUPINACCI': 0,
    'LUPINEK': 0,
    'LUPINETTI': 0,
    'LUPINI': 0,
    'LUPINO': 0,
    'LUPINSKI': 0,
    'LUPIS': 0,
    'LUPITA': 1,
    'LUPKES': 0,
    'LUPLOW': 0,
    'LUPO': 0,
    'LUPOLD': 0,
    'LUPOLE': 0,
    'LUPOLI': 0,
    'LUPONE': 0,
    'LUPORI': 0,
    'LUPP': 0,
    'LUPPENS': 0,
    'LUPPI': 0,
    'LUPPINO': 0,
    'LUPTAK': 0,
    'LUPTON': 0,
    'LUPTOWSKI': 0,
    'LUPU': 0,
    'LUQUE': 0,
    'LUQUETTE': 0,
    'LUQUIN': 0,
    'LUQUIRE': 0,
    'LUQUIS': 0,
    'LURA': 0.9787928221859706,
    'LURCH': 0,
    'LURIA': 0,
    'LURIE': 0,
    'LURK': 0,
    'LURKER': 0,
    'LURKINS': 0,
    'LURKS': 0,
    'LURLENE': 1,
    'LURLINE': 1,
    'LURRY': 0,
    'LURSEN': 0,
    'LURTZ': 0,
    'LURVEY': 0,
    'LURYE': 0,
    'LURZ': 0,
    'LUS': 0,
    'LUSA': 0,
    'LUSANE': 0,
    'LUSARDI': 0,
    'LUSBY': 0,
    'LUSCH': 0,
    'LUSCHEN': 0,
    'LUSCHER': 0,
    'LUSCO': 0,
    'LUSCOMB': 0,
    'LUSCOMBE': 0,
    'LUSE': 0,
    'LUSEBRINK': 0,
    'LUSH': 0,
    'LUSHBAUGH': 0,
    'LUSHER': 0,
    'LUSIAK': 0,
    'LUSIGNAN': 0,
    'LUSIS': 0,
    'LUSK': 0,
    'LUSKEY': 0,
    'LUSKIN': 0,
    'LUSKO': 0,
    'LUSKY': 0,
    'LUSS': 0,
    'LUSSI': 0,
    'LUSSIER': 0,
    'LUSSO': 0,
    'LUSSON': 0,
    'LUSSOW': 0,
    'LUST': 0,
    'LUSTBADER': 0,
    'LUSTBERG': 0,
    'LUSTENBERGER': 0,
    'LUSTER': 0,
    'LUSTGARTEN': 0,
    'LUSTGRAAF': 0,
    'LUSTIG': 0,
    'LUSTIK': 0,
    'LUSTMAN': 0,
    'LUSTRE': 0,
    'LUSTY': 0,
    'LUSZCZ': 0,
    'LUTA': 0,
    'LUTCH': 0,
    'LUTCHER': 0,
    'LUTCHMAN': 0,
    'LUTE': 0,
    'LUTEN': 0,
    'LUTER': 0,
    'LUTERAN': 0,
    'LUTERBACH': 0,
    'LUTERMAN': 0,
    'LUTES': 0,
    'LUTEY': 0,
    'LUTFI': 0,
    'LUTFY': 0,
    'LUTGEN': 0,
    'LUTGENS': 0,
    'LUTGRING': 0,
    'LUTH': 0,
    'LUTHE': 0,
    'LUTHER': 0.8950874271440467,
    'LUTHERAN': 0,
    'LUTHI': 0,
    'LUTHMAN': 0,
    'LUTHRA': 0,
    'LUTHRINGER': 0,
    'LUTHY': 0,
    'LUTIN': 0,
    'LUTJE': 0,
    'LUTJEN': 0,
    'LUTJENS': 0,
    'LUTKE': 0,
    'LUTKUS': 0,
    'LUTMAN': 0,
    'LUTMER': 0,
    'LUTOMSKI': 0,
    'LUTON': 0,
    'LUTOSTANSKI': 0,
    'LUTOVSKY': 0,
    'LUTRARIO': 0,
    'LUTRELL': 0,
    'LUTRICK': 0,
    'LUTRINGER': 0,
    'LUTSCH': 0,
    'LUTSKO': 0,
    'LUTSKY': 0,
    'LUTT': 0,
    'LUTTE': 0,
    'LUTTENBERGER': 0,
    'LUTTER': 0,
    'LUTTERLOH': 0,
    'LUTTERMAN': 0,
    'LUTTERMOSER': 0,
    'LUTTIG': 0,
    'LUTTINEN': 0,
    'LUTTINGER': 0,
    'LUTTMAN': 0,
    'LUTTMANN': 0,
    'LUTTMER': 0,
    'LUTTNER': 0,
    'LUTTON': 0,
    'LUTTRELL': 0,
    'LUTTRULL': 0,
    'LUTTS': 0,
    'LUTU': 0,
    'LUTY': 0,
    'LUTZ': 0,
    'LUTZE': 0,
    'LUTZEN': 0,
    'LUTZI': 0,
    'LUTZKE': 0,
    'LUTZKER': 0,
    'LUTZKY': 0,
    'LUTZOW': 0,
    'LUU': 0,
    'LUUKKONEN': 0,
    'LUURTSEMA': 0,
    'LUVAAS': 0,
    'LUVENE': 0,
    'LUVENIA': 1,
    'LUVERA': 0,
    'LUVIANO': 0,
    'LUVIANOS': 0,
    'LUVISI': 0,
    'LUX': 0,
    'LUXEM': 0,
    'LUXENBERG': 0,
    'LUXFORD': 0,
    'LUXMORE': 0,
    'LUXON': 0,
    'LUXTON': 0,
    'LUY': 0,
    'LUYANDO': 0,
    'LUYET': 0,
    'LUYK': 0,
    'LUYSTER': 0,
    'LUZ': 0.9873060648801129,
    'LUZA': 0,
    'LUZADDER': 0,
    'LUZADER': 0,
    'LUZAK': 0,
    'LUZANIA': 0,
    'LUZANILLA': 0,
    'LUZANO': 0,
    'LUZAR': 0,
    'LUZARDO': 0,
    'LUZE': 0,
    'LUZI': 0,
    'LUZIER': 0,
    'LUZIETTI': 0,
    'LUZINSKI': 0,
    'LUZIO': 0,
    'LUZIUS': 0,
    'LUZON': 0,
    'LUZUM': 0,
    'LUZUNARIS': 0,
    'LUZURIAGA': 0,
    'LUZZI': 0,
    'LUZZO': 0,
    'LWIN': 0,
    'LY': 0,
    'LYALL': 0,
    'LYAS': 0,
    'LYBARGER': 0,
    'LYBBERT': 0,
    'LYBECK': 0,
    'LYBERG': 0,
    'LYBERGER': 0,
    'LYBERT': 0,
    'LYBOLT': 0,
    'LYBRAND': 0,
    'LYBROOK': 0,
    'LYCAN': 0,
    'LYCANS': 0,
    'LYCETT': 0,
    'LYCKE': 0,
    'LYCZAK': 0,
    'LYCZKOWSKI': 0,
    'LYDA': 0.7978723404255319,
    'LYDAY': 0,
    'LYDDANE': 0,
    'LYDDON': 0,
    'LYDE': 0,
    'LYDECKER': 0,
    'LYDELL': 0,
    'LYDEN': 0,
    'LYDER': 0,
    'LYDIA': 0.9986065954482117,
    'LYDIC': 0,
    'LYDICK': 0,
    'LYDON': 0,
    'LYDY': 0,
    'LYE': 0,
    'LYELL': 0,
    'LYERLA': 0,
    'LYERLY': 0,
    'LYES': 0,
    'LYEW': 0,
    'LYFORD': 0,
    'LYGA': 0,
    'LYGHT': 0,
    'LYKE': 0,
    'LYKENS': 0,
    'LYKES': 0,
    'LYKINS': 0,
    'LYKKE': 0,
    'LYKKEN': 0,
    'LYKO': 0,
    'LYKOWSKI': 0,
    'LYLA': 1,
    'LYLE': 0.8878504672897196,
    'LYLES': 0,
    'LYM': 0,
    'LYMAN': 0.5853658536585367,
    'LYMAS': 0,
    'LYMBURNER': 0,
    'LYMER': 0,
    'LYMON': 0,
    'LYN': 0.947867298578199,
    'LYNA': 0,
    'LYNADY': 0,
    'LYNAGH': 0,
    'LYNAH': 0,
    'LYNAM': 0,
    'LYNARD': 0,
    'LYNAS': 0,
    'LYNAUGH': 0,
    'LYNCH': 0,
    'LYNCHARD': 0,
    'LYND': 0,
    'LYNDA': 1,
    'LYNDAKER': 0,
    'LYNDE': 0,
    'LYNDES': 0,
    'LYNDIA': 1,
    'LYNDON': 0.9784735812133073,
    'LYNDS': 0,
    'LYNDSAY': 1,
    'LYNDSEY': 1,
    'LYNE': 0,
    'LYNELL': 1,
    'LYNELLE': 1,
    'LYNEM': 0,
    'LYNEMA': 0,
    'LYNES': 0,
    'LYNESS': 0,
    'LYNETT': 0,
    'LYNETTA': 1,
    'LYNETTE': 0.9987893462469734,
    'LYNG': 0,
    'LYNGAAS': 0,
    'LYNGE': 0,
    'LYNGEN': 0,
    'LYNGHOLM': 0,
    'LYNGSTAD': 0,
    'LYNK': 0,
    'LYNN': 0.9263225530092096,
    'LYNNA': 1,
    'LYNNE': 0.9939898289412852,
    'LYNNER': 0,
    'LYNNES': 0,
    'LYNNETTE': 1,
    'LYNOTT': 0,
    'LYNSEY': 1,
    'LYNSKEY': 0,
    'LYNTON': 0,
    'LYNUM': 0,
    'LYNWOOD': 1,
    'LYNXWILER': 0,
    'LYON': 0,
    'LYONNAIS': 0,
    'LYONS': 0,
    'LYRA': 0,
    'LYRAS': 0,
    'LYREK': 0,
    'LYS': 0,
    'LYSAGHT': 0,
    'LYSAK': 0,
    'LYSAKER': 0,
    'LYSAKOWSKI': 0,
    'LYSAUGHT': 0,
    'LYSDAHL': 0,
    'LYSEK': 0,
    'LYSEN': 0,
    'LYSENKO': 0,
    'LYSHER': 0,
    'LYSIAK': 0,
    'LYSIK': 0,
    'LYSINGER': 0,
    'LYSKAWA': 0,
    'LYSNE': 0,
    'LYSOGORSKI': 0,
    'LYSON': 0,
    'LYSSY': 0,
    'LYSTAD': 0,
    'LYSTER': 0,
    'LYSY': 0,
    'LYTAL': 0,
    'LYTCH': 0,
    'LYTE': 0,
    'LYTELL': 0,
    'LYTER': 0,
    'LYTES': 0,
    'LYTH': 0,
    'LYTHGOE': 0,
    'LYTLE': 0,
    'LYTTLE': 0,
    'LYTTON': 0,
    'LYTWYN': 0,
    'LYU': 0,
    'LYVER': 0,
    'LYVERS': 0,
    'LYZENGA': 0,
    'LZ': 0,
    'MA': 0.53156146179402,
    'MAA': 0,
    'MAACK': 0,
    'MAAE': 0,
    'MAAG': 0,
    'MAAHS': 0,
    'MAAK': 0,
    'MAAKESTAD': 0,
    'MAALI': 0,
    'MAALOUF': 0,
    'MAAN': 0,
    'MAANUM': 0,
    'MAAR': 0,
    'MAAS': 0,
    'MAASCH': 0,
    'MAASEN': 0,
    'MAASKE': 0,
    'MAASS': 0,
    'MAASSEN': 0,
    'MAAT': 0,
    'MAATMAN': 0,
    'MAATTA': 0,
    'MABALOT': 0,
    'MABARY': 0,
    'MABASA': 0,
    'MABB': 0,
    'MABBETT': 0,
    'MABBITT': 0,
    'MABBOTT': 0,
    'MABBUTT': 0,
    'MABE': 0,
    'MABEE': 0,
    'MABEL': 0.9991033687716153,
    'MABELLE': 1,
    'MABEN': 0,
    'MABERRY': 0,
    'MABERY': 0,
    'MABES': 0,
    'MABEUS': 0,
    'MABEY': 0,
    'MABIE': 0,
    'MABILE': 0,
    'MABIN': 0,
    'MABINE': 0,
    'MABINI': 0,
    'MABINS': 0,
    'MABIS': 0,
    'MABLE': 0.9950248756218906,
    'MABLES': 0,
    'MABLEY': 0,
    'MABON': 0,
    'MABONE': 0,
    'MABRA': 0,
    'MABRAY': 0,
    'MABREY': 0,
    'MABROUK': 0,
    'MABRY': 0,
    'MABSON': 0,
    'MABUS': 0,
    'MABUTAS': 0,
    'MAC': 0.8787346221441125,
    'MACA': 0,
    'MACABEO': 0,
    'MACADAM': 0,
    'MACADAMS': 0,
    'MACADANGDANG': 0,
    'MACAFEE': 0,
    'MACAGNONE': 0,
    'MACAIONE': 0,
    'MACAK': 0,
    'MACAL': 0,
    'MACALA': 0,
    'MACALALAD': 0,
    'MACALI': 0,
    'MACALIK': 0,
    'MACALINO': 0,
    'MACALINTAL': 0,
    'MACALISTER': 0,
    'MACALLISTER': 0,
    'MACALMA': 0,
    'MACALPINE': 0,
    'MACALUSO': 0,
    'MACAN': 0,
    'MACANAS': 0,
    'MACANCELA': 0,
    'MACAPAGAL': 0,
    'MACAPINLAC': 0,
    'MACARAEG': 0,
    'MACARAIG': 0,
    'MACARANAS': 0,
    'MACARENO': 0,
    'MACARI': 0,
    'MACARIO': 0,
    'MACARO': 0,
    'MACARTHUR': 0,
    'MACARTHY': 0,
    'MACARTNEY': 0,
    'MACARY': 0,
    'MACAS': 0,
    'MACASAET': 0,
    'MACASIEB': 0,
    'MACASKILL': 0,
    'MACASPAC': 0,
    'MACATANGAY': 0,
    'MACATEE': 0,
    'MACAULAY': 0,
    'MACAULEY': 0,
    'MACAVOY': 0,
    'MACAY': 0,
    'MACAYA': 0,
    'MACBAIN': 0,
    'MACBEAN': 0,
    'MACBETH': 0,
    'MACBLANE': 0,
    'MACBRIDE': 0,
    'MACCA': 0,
    'MACCABE': 0,
    'MACCABEE': 0,
    'MACCALL': 0,
    'MACCALLA': 0,
    'MACCALLUM': 0,
    'MACCANI': 0,
    'MACCARI': 0,
    'MACCARIO': 0,
    'MACCARO': 0,
    'MACCARONE': 0,
    'MACCARRONE': 0,
    'MACCARTER': 0,
    'MACCARTHY': 0,
    'MACCARTNEY': 0,
    'MACCHI': 0,
    'MACCHIA': 0,
    'MACCHIARELLA': 0,
    'MACCHIAROLI': 0,
    'MACCHIO': 0,
    'MACCHIONE': 0,
    'MACCIA': 0,
    'MACCINI': 0,
    'MACCIO': 0,
    'MACCIOLI': 0,
    'MACCLELLAN': 0,
    'MACCO': 0,
    'MACCOLL': 0,
    'MACCOLLUM': 0,
    'MACCONNELL': 0,
    'MACCORD': 0,
    'MACCORMACK': 0,
    'MACCORMICK': 0,
    'MACCOY': 0,
    'MACCRACKEN': 0,
    'MACCREADY': 0,
    'MACCUBBIN': 0,
    'MACCULLOCH': 0,
    'MACCURDY': 0,
    'MACDANIEL': 0,
    'MACDERMID': 0,
    'MACDERMOTT': 0,
    'MACDIARMID': 0,
    'MACDONALD': 0,
    'MACDONELL': 0,
    'MACDONNELL': 0,
    'MACDONOUGH': 0,
    'MACDOUGAL': 0,
    'MACDOUGALL': 0,
    'MACDOWALL': 0,
    'MACDOWELL': 0,
    'MACDUFF': 0,
    'MACDUFFIE': 0,
    'MACE': 0,
    'MACEACHEN': 0,
    'MACEACHERN': 0,
    'MACEDA': 0,
    'MACEDO': 0,
    'MACEDONIA': 0,
    'MACEDONIO': 0,
    'MACEIRA': 0,
    'MACEJAK': 0,
    'MACEJKA': 0,
    'MACEK': 0,
    'MACELROY': 0,
    'MACEMORE': 0,
    'MACENTEE': 0,
    'MACEO': 0,
    'MACER': 0,
    'MACERA': 0,
    'MACERI': 0,
    'MACERO': 0,
    'MACEWAN': 0,
    'MACEWEN': 0,
    'MACEY': 0,
    'MACEYKO': 0,
    'MACFADDEN': 0,
    'MACFADYEN': 0,
    'MACFALL': 0,
    'MACFARLAN': 0,
    'MACFARLAND': 0,
    'MACFARLANE': 0,
    'MACFEE': 0,
    'MACFIE': 0,
    'MACGEORGE': 0,
    'MACGIBBON': 0,
    'MACGILL': 0,
    'MACGILLIS': 0,
    'MACGILLIVARY': 0,
    'MACGILLIVRAY': 0,
    'MACGILVRAY': 0,
    'MACGOWAN': 0,
    'MACGOWN': 0,
    'MACGREGOR': 0,
    'MACGUIRE': 0,
    'MACH': 0,
    'MACHA': 0,
    'MACHAC': 0,
    'MACHACEK': 0,
    'MACHADO': 0,
    'MACHAIN': 0,
    'MACHAJ': 0,
    'MACHAJEWSKI': 0,
    'MACHAK': 0,
    'MACHAL': 0,
    'MACHALA': 0,
    'MACHALEK': 0,
    'MACHAMER': 0,
    'MACHAN': 0,
    'MACHARIA': 0,
    'MACHART': 0,
    'MACHCINSKI': 0,
    'MACHEEL': 0,
    'MACHEK': 0,
    'MACHEL': 0,
    'MACHELL': 0,
    'MACHELLE': 1,
    'MACHEMER': 0,
    'MACHEN': 0,
    'MACHER': 0,
    'MACHESKY': 0,
    'MACHESNEY': 0,
    'MACHI': 0,
    'MACHIA': 0,
    'MACHICEK': 0,
    'MACHICOTE': 0,
    'MACHIDA': 0,
    'MACHIELA': 0,
    'MACHIN': 0,
    'MACHINSKI': 0,
    'MACHLAN': 0,
    'MACHLEIT': 0,
    'MACHLER': 0,
    'MACHLIN': 0,
    'MACHMER': 0,
    'MACHNIAK': 0,
    'MACHNICKI': 0,
    'MACHNIK': 0,
    'MACHO': 0,
    'MACHOL': 0,
    'MACHOLD': 0,
    'MACHOLL': 0,
    'MACHOLZ': 0,
    'MACHON': 0,
    'MACHORRO': 0,
    'MACHOS': 0,
    'MACHOTKA': 0,
    'MACHOVEC': 0,
    'MACHOVINA': 0,
    'MACHOVSKY': 0,
    'MACHOWICZ': 0,
    'MACHOWSKI': 0,
    'MACHT': 0,
    'MACHTEMES': 0,
    'MACHUCA': 0,
    'MACHUGA': 0,
    'MACHUT': 0,
    'MACHUTA': 0,
    'MACIA': 0,
    'MACIAG': 0,
    'MACIAK': 0,
    'MACIAS': 0,
    'MACIASZEK': 0,
    'MACIE': 0.9302325581395349,
    'MACIEJ': 0,
    'MACIEJEWSKI': 0,
    'MACIEJKO': 0,
    'MACIEL': 0,
    'MACIER': 0,
    'MACIK': 0,
    'MACINA': 0,
    'MACINDOE': 0,
    'MACINNES': 0,
    'MACINNIS': 0,
    'MACINO': 0,
    'MACINTIRE': 0,
    'MACINTOSH': 0,
    'MACINTYRE': 0,
    'MACIOCE': 0,
    'MACIOCH': 0,
    'MACIOCI': 0,
    'MACIOLEK': 0,
    'MACIOROWSKI': 0,
    'MACIS': 0,
    'MACISAAC': 0,
    'MACIVER': 0,
    'MACIVOR': 0,
    'MACK': 0.5011024253357386,
    'MACKALL': 0,
    'MACKAMAN': 0,
    'MACKAY': 0,
    'MACKE': 0,
    'MACKECHNIE': 0,
    'MACKEDANZ': 0,
    'MACKEEN': 0,
    'MACKEL': 0,
    'MACKELL': 0,
    'MACKELLAR': 0,
    'MACKELPRANG': 0,
    'MACKEN': 0,
    'MACKENDRICK': 0,
    'MACKENNA': 0,
    'MACKENROTH': 0,
    'MACKENS': 0,
    'MACKENSEN': 0,
    'MACKENTHUN': 0,
    'MACKENZIE': 0.45045045045045046,
    'MACKER': 0,
    'MACKERETH': 0,
    'MACKERT': 0,
    'MACKES': 0,
    'MACKESEY': 0,
    'MACKESSY': 0,
    'MACKESY': 0,
    'MACKEY': 0,
    'MACKI': 0,
    'MACKIE': 0,
    'MACKIEWICZ': 0,
    'MACKILLOP': 0,
    'MACKIN': 0,
    'MACKINDER': 0,
    'MACKINLAY': 0,
    'MACKINNEY': 0,
    'MACKINNON': 0,
    'MACKINS': 0,
    'MACKINSON': 0,
    'MACKINTOSH': 0,
    'MACKISON': 0,
    'MACKLE': 0,
    'MACKLEM': 0,
    'MACKLEN': 0,
    'MACKLER': 0,
    'MACKLES': 0,
    'MACKLEY': 0,
    'MACKLIN': 0,
    'MACKLING': 0,
    'MACKNER': 0,
    'MACKNEY': 0,
    'MACKNIGHT': 0,
    'MACKO': 0,
    'MACKOOL': 0,
    'MACKOUL': 0,
    'MACKOWIAK': 0,
    'MACKOWSKI': 0,
    'MACKRELL': 0,
    'MACKRILL': 0,
    'MACKS': 0,
    'MACKSEY': 0,
    'MACKSON': 0,
    'MACKSOUD': 0,
    'MACKUS': 0,
    'MACKY': 0,
    'MACLACHLAN': 0,
    'MACLAIN': 0,
    'MACLAINE': 0,
    'MACLANE': 0,
    'MACLAREN': 0,
    'MACLAUCHLAN': 0,
    'MACLAUGHLIN': 0,
    'MACLAURIN': 0,
    'MACLAURY': 0,
    'MACLAY': 0,
    'MACLEAN': 0,
    'MACLEAY': 0,
    'MACLEISH': 0,
    'MACLELLAN': 0,
    'MACLENNAN': 0,
    'MACLEOD': 0,
    'MACLIN': 0,
    'MACLURE': 0,
    'MACMAHON': 0,
    'MACMANUS': 0,
    'MACMARTIN': 0,
    'MACMASTER': 0,
    'MACMATH': 0,
    'MACMICHAEL': 0,
    'MACMILLAN': 0,
    'MACMILLEN': 0,
    'MACMILLIAN': 0,
    'MACMINN': 0,
    'MACMULLAN': 0,
    'MACMULLEN': 0,
    'MACMULLIN': 0,
    'MACMURDO': 0,
    'MACMURRAY': 0,
    'MACNAB': 0,
    'MACNABB': 0,
    'MACNAIR': 0,
    'MACNALLY': 0,
    'MACNAMARA': 0,
    'MACNAMEE': 0,
    'MACNAUGHT': 0,
    'MACNAUGHTON': 0,
    'MACNEAL': 0,
    'MACNEIL': 0,
    'MACNEILL': 0,
    'MACNEVIN': 0,
    'MACNICHOL': 0,
    'MACNICOL': 0,
    'MACNIVEN': 0,
    'MACNUTT': 0,
    'MACO': 0,
    'MACOLINO': 0,
    'MACOM': 0,
    'MACOMB': 0,
    'MACOMBER': 0,
    'MACOMSON': 0,
    'MACON': 0,
    'MACONE': 0,
    'MACOUBRIE': 0,
    'MACOY': 0,
    'MACPEEK': 0,
    'MACPHAIL': 0,
    'MACPHEE': 0,
    'MACPHERSON': 0,
    'MACQUARRIE': 0,
    'MACQUEEN': 0,
    'MACRAE': 0,
    'MACRANDER': 0,
    'MACREADY': 0,
    'MACRI': 0,
    'MACRINA': 0,
    'MACRIS': 0,
    'MACRITCHIE': 0,
    'MACRO': 0,
    'MACROBERTS': 0,
    'MACSHANE': 0,
    'MACSWAIN': 0,
    'MACTAGGART': 0,
    'MACTAVISH': 0,
    'MACUCH': 0,
    'MACUGA': 0,
    'MACUMBER': 0,
    'MACURA': 0,
    'MACURAK': 0,
    'MACURDY': 0,
    'MACVANE': 0,
    'MACVEAN': 0,
    'MACVEIGH': 0,
    'MACVICAR': 0,
    'MACVITTIE': 0,
    'MACWAN': 0,
    'MACWHINNIE': 0,
    'MACWHORTER': 0,
    'MACWILLIAM': 0,
    'MACWILLIAMS': 0,
    'MACY': 0.5089058524173028,
    'MACZIEWSKI': 0,
    'MACZKA': 0,
    'MACZKO': 0,
    'MACZUGA': 0,
    'MADA': 0,
    'MADAFFARI': 0,
    'MADAIO': 0,
    'MADAJ': 0,
    'MADAK': 0,
    'MADALA': 0,
    'MADALENA': 0,
    'MADALENE': 1,
    'MADALINE': 1,
    'MADALINSKI': 0,
    'MADALYN': 1,
    'MADAMA': 0,
    'MADAMBA': 0,
    'MADAN': 0,
    'MADANAT': 0,
    'MADANI': 0,
    'MADAR': 0,
    'MADARA': 0,
    'MADARANG': 0,
    'MADARAS': 0,
    'MADARASZ': 0,
    'MADARIAGA': 0,
    'MADARIS': 0,
    'MADARY': 0,
    'MADAUS': 0,
    'MADAY': 0,
    'MADAYAG': 0,
    'MADDALENA': 0,
    'MADDALONE': 0,
    'MADDALONI': 0,
    'MADDAMMA': 0,
    'MADDELA': 0,
    'MADDEN': 0,
    'MADDERN': 0,
    'MADDEROM': 0,
    'MADDERRA': 0,
    'MADDEX': 0,
    'MADDI': 0,
    'MADDIE': 0.9259259259259258,
    'MADDIGAN': 0,
    'MADDIN': 0,
    'MADDING': 0,
    'MADDISON': 0,
    'MADDIX': 0,
    'MADDLE': 0,
    'MADDOCK': 0,
    'MADDOCKS': 0,
    'MADDON': 0,
    'MADDOUX': 0,
    'MADDOX': 0,
    'MADDOY': 0,
    'MADDREY': 0,
    'MADDRON': 0,
    'MADDRY': 0,
    'MADDUX': 0,
    'MADDY': 0,
    'MADE': 0,
    'MADEIRA': 0,
    'MADEIROS': 0,
    'MADEJ': 0,
    'MADEJA': 0,
    'MADEL': 0,
    'MADELAINE': 1,
    'MADELEINE': 1,
    'MADELENE': 1,
    'MADELEY': 0,
    'MADELINE': 0.9984639016897081,
    'MADELL': 0,
    'MADELYN': 1,
    'MADEN': 0,
    'MADENFORD': 0,
    'MADEO': 0,
    'MADER': 0,
    'MADERA': 0,
    'MADERAZO': 0,
    'MADERE': 0,
    'MADERIA': 0,
    'MADERO': 0,
    'MADEROS': 0,
    'MADES': 0,
    'MADEWELL': 0,
    'MADEY': 0,
    'MADGE': 0.990990990990991,
    'MADGETT': 0,
    'MADGWICK': 0,
    'MADHANI': 0,
    'MADHAVAN': 0,
    'MADI': 0,
    'MADIA': 0,
    'MADIAS': 0,
    'MADICK': 0,
    'MADIE': 1,
    'MADIGAN': 0,
    'MADILL': 0,
    'MADINE': 0,
    'MADINGER': 0,
    'MADIS': 0,
    'MADISON': 0.2336448598130841,
    'MADIX': 0,
    'MADKINS': 0,
    'MADL': 0,
    'MADLAND': 0,
    'MADLANGBAYAN': 0,
    'MADLEM': 0,
    'MADLENER': 0,
    'MADLER': 0,
    'MADLEY': 0,
    'MADLIN': 0,
    'MADLINGER': 0,
    'MADLOCK': 0,
    'MADLYN': 1,
    'MADNICK': 0,
    'MADOFF': 0,
    'MADOLE': 0,
    'MADON': 0,
    'MADONADO': 0,
    'MADONIA': 0,
    'MADONNA': 0.907715582450832,
    'MADOR': 0,
    'MADORE': 0,
    'MADORIN': 0,
    'MADORMA': 0,
    'MADORSKY': 0,
    'MADOW': 0,
    'MADPLUME': 0,
    'MADRAK': 0,
    'MADRANO': 0,
    'MADRAY': 0,
    'MADRAZO': 0,
    'MADRE': 0,
    'MADREN': 0,
    'MADREY': 0,
    'MADRIAGA': 0,
    'MADRID': 0,
    'MADRIGAL': 0,
    'MADRIGALES': 0,
    'MADRIL': 0,
    'MADRILES': 0,
    'MADRILL': 0,
    'MADRIS': 0,
    'MADRIZ': 0,
    'MADRO': 0,
    'MADRON': 0,
    'MADRONA': 0,
    'MADRU': 0,
    'MADRUENO': 0,
    'MADRUGA': 0,
    'MADRY': 0,
    'MADSEN': 0,
    'MADSON': 0,
    'MADU': 0,
    'MADUENA': 0,
    'MADUENO': 0,
    'MADUKA': 0,
    'MADURA': 0,
    'MADURI': 0,
    'MADURO': 0,
    'MADURSKI': 0,
    'MADUZIA': 0,
    'MADVIG': 0,
    'MADY': 0,
    'MADYUN': 0,
    'MAE': 0.9973088491372487,
    'MAEDA': 0,
    'MAEDEL': 0,
    'MAEDER': 0,
    'MAEDGEN': 0,
    'MAEDKE': 0,
    'MAEGAN': 1,
    'MAEHARA': 0,
    'MAEHL': 0,
    'MAEHR': 0,
    'MAEKAWA': 0,
    'MAEKER': 0,
    'MAEL': 0,
    'MAENDEL': 0,
    'MAENG': 0,
    'MAENLE': 0,
    'MAENNER': 0,
    'MAENPAA': 0,
    'MAENZA': 0,
    'MAER': 0,
    'MAERTEN': 0,
    'MAERTENS': 0,
    'MAERTZ': 0,
    'MAERZ': 0,
    'MAES': 0,
    'MAESE': 0,
    'MAESER': 0,
    'MAESHIRO': 0,
    'MAESTAS': 0,
    'MAESTRE': 0,
    'MAESTRETTI': 0,
    'MAESTRI': 0,
    'MAESTRO': 0,
    'MAETZOLD': 0,
    'MAEWEATHER': 0,
    'MAEZ': 0,
    'MAFALDA': 1,
    'MAFERA': 0,
    'MAFFE': 0,
    'MAFFEI': 0,
    'MAFFEO': 0,
    'MAFFETONE': 0,
    'MAFFETT': 0,
    'MAFFETTONE': 0,
    'MAFFEY': 0,
    'MAFFIA': 0,
    'MAFFIE': 0,
    'MAFFIN': 0,
    'MAFFIOLI': 0,
    'MAFFIT': 0,
    'MAFFITT': 0,
    'MAFFUCCI': 0,
    'MAFI': 0,
    'MAFNAS': 0,
    'MAG': 0,
    'MAGA': 0,
    'MAGADAN': 0,
    'MAGADIA': 0,
    'MAGAGNA': 0,
    'MAGAHA': 0,
    'MAGALDI': 0,
    'MAGALEI': 0,
    'MAGALETTA': 0,
    'MAGALHAES': 0,
    'MAGALI': 1,
    'MAGALIS': 0,
    'MAGALLAN': 0,
    'MAGALLANES': 0,
    'MAGALLANEZ': 0,
    'MAGALLON': 0,
    'MAGALONG': 0,
    'MAGALSKI': 0,
    'MAGALY': 1,
    'MAGAN': 0.8733624454148472,
    'MAGANA': 0,
    'MAGANDA': 0,
    'MAGANN': 0,
    'MAGANO': 0,
    'MAGANTE': 0,
    'MAGAOAY': 0,
    'MAGAR': 0,
    'MAGARACI': 0,
    'MAGARELLI': 0,
    'MAGARET': 1,
    'MAGARGAL': 0,
    'MAGARGEE': 0,
    'MAGARGLE': 0,
    'MAGARIAN': 0,
    'MAGARIN': 0,
    'MAGARINO': 0,
    'MAGARITY': 0,
    'MAGARO': 0,
    'MAGARY': 0,
    'MAGAS': 0,
    'MAGAT': 0,
    'MAGATHAN': 0,
    'MAGAW': 0,
    'MAGAZINE': 0,
    'MAGAZINER': 0,
    'MAGAZU': 0,
    'MAGAZZU': 0,
    'MAGBANUA': 0,
    'MAGBEE': 0,
    'MAGBITANG': 0,
    'MAGBUAL': 0,
    'MAGBY': 0,
    'MAGCALAS': 0,
    'MAGDA': 0.9363295880149812,
    'MAGDALEN': 1,
    'MAGDALENA': 0.9940357852882704,
    'MAGDALENE': 1,
    'MAGDALENO': 0,
    'MAGDANZ': 0,
    'MAGDEN': 0,
    'MAGDIC': 0,
    'MAGDICH': 0,
    'MAGDZIAK': 0,
    'MAGDZIARZ': 0,
    'MAGE': 0,
    'MAGEAU': 0,
    'MAGED': 0,
    'MAGEDANZ': 0,
    'MAGEE': 0,
    'MAGEL': 0,
    'MAGELKY': 0,
    'MAGELSSEN': 0,
    'MAGEN': 0.9708737864077669,
    'MAGENHEIM': 0,
    'MAGENHEIMER': 0,
    'MAGENNIS': 0,
    'MAGENTA': 0,
    'MAGEO': 0,
    'MAGER': 0,
    'MAGERA': 0,
    'MAGERKURTH': 0,
    'MAGERL': 0,
    'MAGERS': 0,
    'MAGES': 0,
    'MAGESTRO': 0,
    'MAGETT': 0,
    'MAGETTE': 0,
    'MAGGARD': 0,
    'MAGGART': 0,
    'MAGGERT': 0,
    'MAGGETT': 0,
    'MAGGETTE': 0,
    'MAGGETTI': 0,
    'MAGGI': 0,
    'MAGGIACOMO': 0,
    'MAGGIANO': 0,
    'MAGGIE': 0.9988249118683901,
    'MAGGIO': 0,
    'MAGGIORA': 0,
    'MAGGIORE': 0,
    'MAGGITT': 0,
    'MAGGITTI': 0,
    'MAGGS': 0,
    'MAGHAKIAN': 0,
    'MAGHAN': 0,
    'MAGHIRANG': 0,
    'MAGI': 0,
    'MAGIC': 0,
    'MAGID': 0,
    'MAGIDSON': 0,
    'MAGIE': 0,
    'MAGIER': 0,
    'MAGIERA': 0,
    'MAGILL': 0,
    'MAGILTON': 0,
    'MAGIN': 0,
    'MAGINITY': 0,
    'MAGINN': 0,
    'MAGINNESS': 0,
    'MAGINNIS': 0,
    'MAGINOT': 0,
    'MAGISTRO': 0,
    'MAGLALANG': 0,
    'MAGLARAS': 0,
    'MAGLASANG': 0,
    'MAGLAYA': 0,
    'MAGLE': 0,
    'MAGLEBY': 0,
    'MAGLEY': 0,
    'MAGLIA': 0,
    'MAGLIANO': 0,
    'MAGLIARO': 0,
    'MAGLIATO': 0,
    'MAGLICH': 0,
    'MAGLIERI': 0,
    'MAGLINGER': 0,
    'MAGLIO': 0,
    'MAGLIOCCA': 0,
    'MAGLIOCCO': 0,
    'MAGLIOCHETTI': 0,
    'MAGLIOLA': 0,
    'MAGLIOLO': 0,
    'MAGLIONE': 0,
    'MAGLIOZZI': 0,
    'MAGLIULO': 0,
    'MAGLOIRE': 0,
    'MAGLOTHIN': 0,
    'MAGLOTT': 0,
    'MAGNA': 0,
    'MAGNAN': 0,
    'MAGNANI': 0,
    'MAGNANO': 0,
    'MAGNANT': 0,
    'MAGNANTI': 0,
    'MAGNARELLI': 0,
    'MAGNASCO': 0,
    'MAGNATTA': 0,
    'MAGNAYE': 0,
    'MAGNE': 0,
    'MAGNELL': 0,
    'MAGNELLI': 0,
    'MAGNER': 0,
    'MAGNES': 0,
    'MAGNESON': 0,
    'MAGNESS': 0,
    'MAGNETT': 0,
    'MAGNETTI': 0,
    'MAGNEY': 0,
    'MAGNI': 0,
    'MAGNIFICO': 0,
    'MAGNIN': 0,
    'MAGNO': 0,
    'MAGNOLI': 0,
    'MAGNOLIA': 0.9852216748768473,
    'MAGNON': 0,
    'MAGNONE': 0,
    'MAGNOTTA': 0,
    'MAGNOTTI': 0,
    'MAGNUM': 0,
    'MAGNUS': 0,
    'MAGNUSEN': 0,
    'MAGNUSON': 0,
    'MAGNUSSEN': 0,
    'MAGNUSSON': 0,
    'MAGNY': 0,
    'MAGO': 0,
    'MAGOFFIN': 0,
    'MAGOLAN': 0,
    'MAGON': 0,
    'MAGONE': 0,
    'MAGOON': 0,
    'MAGOR': 0,
    'MAGORIAN': 0,
    'MAGOS': 0,
    'MAGOTO': 0,
    'MAGOUIRK': 0,
    'MAGOULAS': 0,
    'MAGOUN': 0,
    'MAGOVERN': 0,
    'MAGOWAN': 0,
    'MAGPANTAY': 0,
    'MAGPAYO': 0,
    'MAGRAM': 0,
    'MAGRANE': 0,
    'MAGRANN': 0,
    'MAGRAS': 0,
    'MAGRATH': 0,
    'MAGRAW': 0,
    'MAGRI': 0,
    'MAGRINI': 0,
    'MAGRINO': 0,
    'MAGRO': 0,
    'MAGROGAN': 0,
    'MAGRONE': 0,
    'MAGRUDER': 0,
    'MAGRUM': 0,
    'MAGSAM': 0,
    'MAGSAMEN': 0,
    'MAGSAYO': 0,
    'MAGSAYSAY': 0,
    'MAGSBY': 0,
    'MAGSIG': 0,
    'MAGSINO': 0,
    'MAGSTADT': 0,
    'MAGTIBAY': 0,
    'MAGTOTO': 0,
    'MAGUE': 0,
    'MAGUFFEE': 0,
    'MAGUIRE': 0,
    'MAGULA': 0,
    'MAGURA': 0,
    'MAGWIRE': 0,
    'MAGWOOD': 0,
    'MAGYAR': 0,
    'MAGYARI': 0,
    'MAH': 0,
    'MAHA': 0,
    'MAHABEER': 0,
    'MAHABIR': 0,
    'MAHADEO': 0,
    'MAHADEVAN': 0,
    'MAHADY': 0,
    'MAHAFFEE': 0,
    'MAHAFFEY': 0,
    'MAHAFFIE': 0,
    'MAHAFFY': 0,
    'MAHAJAN': 0,
    'MAHAL': 0,
    'MAHALA': 0,
    'MAHALAK': 0,
    'MAHALEY': 0,
    'MAHALIA': 1,
    'MAHALICK': 0,
    'MAHALIK': 0,
    'MAHALINGAM': 0,
    'MAHAM': 0,
    'MAHAMED': 0,
    'MAHAMUD': 0,
    'MAHAN': 0,
    'MAHANA': 0,
    'MAHANAY': 0,
    'MAHANES': 0,
    'MAHANEY': 0,
    'MAHANNA': 0,
    'MAHANNAH': 0,
    'MAHANY': 0,
    'MAHAPATRA': 0,
    'MAHAR': 0,
    'MAHARAJ': 0,
    'MAHARG': 0,
    'MAHARREY': 0,
    'MAHARRY': 0,
    'MAHASE': 0,
    'MAHATHA': 0,
    'MAHAY': 0,
    'MAHBOOB': 0,
    'MAHDAVI': 0,
    'MAHDI': 0,
    'MAHE': 0,
    'MAHECHA': 0,
    'MAHEDY': 0,
    'MAHELONA': 0,
    'MAHENDRA': 0,
    'MAHER': 0,
    'MAHERAS': 0,
    'MAHESH': 0,
    'MAHESHWARI': 0,
    'MAHEU': 0,
    'MAHEUX': 0,
    'MAHFOOD': 0,
    'MAHFOUZ': 0,
    'MAHGEREFTEH': 0,
    'MAHGOUB': 0,
    'MAHI': 0,
    'MAHIAI': 0,
    'MAHIDA': 0,
    'MAHIEU': 0,
    'MAHIN': 0,
    'MAHL': 0,
    'MAHLA': 0,
    'MAHLANDT': 0,
    'MAHLBERG': 0,
    'MAHLE': 0,
    'MAHLEN': 0,
    'MAHLER': 0,
    'MAHLEY': 0,
    'MAHLIK': 0,
    'MAHLKE': 0,
    'MAHLMAN': 0,
    'MAHLMANN': 0,
    'MAHLMEISTER': 0,
    'MAHLOCH': 0,
    'MAHLON': 0,
    'MAHLOW': 0,
    'MAHLSTEDT': 0,
    'MAHLUM': 0,
    'MAHMOOD': 0,
    'MAHMOODI': 0,
    'MAHMOUD': 0,
    'MAHMOUDI': 0,
    'MAHMUD': 0,
    'MAHMUTOVIC': 0,
    'MAHN': 0,
    'MAHNE': 0,
    'MAHNESMITH': 0,
    'MAHNKE': 0,
    'MAHNKEN': 0,
    'MAHNS': 0,
    'MAHOE': 0,
    'MAHOLICK': 0,
    'MAHOLLAND': 0,
    'MAHOLMES': 0,
    'MAHOLTZ': 0,
    'MAHOMES': 0,
    'MAHON': 0,
    'MAHONE': 0,
    'MAHONEY': 0,
    'MAHONY': 0,
    'MAHOOD': 0,
    'MAHORNEY': 0,
    'MAHOSKY': 0,
    'MAHOWALD': 0,
    'MAHOY': 0,
    'MAHR': 0,
    'MAHRE': 0,
    'MAHRENHOLZ': 0,
    'MAHRER': 0,
    'MAHRLE': 0,
    'MAHRT': 0,
    'MAHTANI': 0,
    'MAHUGH': 0,
    'MAHURIN': 0,
    'MAHURON': 0,
    'MAHY': 0,
    'MAI': 0.6686478454680534,
    'MAIA': 0.888888888888889,
    'MAIALE': 0,
    'MAIAVA': 0,
    'MAIB': 0,
    'MAIBACH': 0,
    'MAIBERGER': 0,
    'MAICHEL': 0,
    'MAICHLE': 0,
    'MAID': 0,
    'MAIDA': 0.7434944237918216,
    'MAIDEN': 0,
    'MAIDENS': 0,
    'MAIDL': 0,
    'MAIDLOW': 0,
    'MAIDMENT': 0,
    'MAIDONADO': 0,
    'MAIELLA': 0,
    'MAIELLO': 0,
    'MAIER': 0,
    'MAIERHOFER': 0,
    'MAIERLE': 0,
    'MAIERS': 0,
    'MAIESE': 0,
    'MAIETTA': 0,
    'MAIFELD': 0,
    'MAIGNAN': 0,
    'MAIJALA': 0,
    'MAIKE': 0,
    'MAIKOWSKI': 0,
    'MAIKRANZ': 0,
    'MAIL': 0,
    'MAILAND': 0,
    'MAILANDER': 0,
    'MAILE': 0.7407407407407407,
    'MAILER': 0,
    'MAILES': 0,
    'MAILEY': 0,
    'MAILHIOT': 0,
    'MAILHOT': 0,
    'MAILLARD': 0,
    'MAILLE': 0,
    'MAILLET': 0,
    'MAILLETTE': 0,
    'MAILLIARD': 0,
    'MAILLIE': 0,
    'MAILLIS': 0,
    'MAILLOUX': 0,
    'MAILLY': 0,
    'MAILMAN': 0,
    'MAILO': 0,
    'MAIMAN': 0,
    'MAIMON': 0,
    'MAIMONE': 0,
    'MAIN': 0,
    'MAINA': 0,
    'MAINARD': 0,
    'MAINARDI': 0,
    'MAINE': 0,
    'MAINELLA': 0,
    'MAINELLI': 0,
    'MAINELLO': 0,
    'MAINER': 0,
    'MAINES': 0,
    'MAINEY': 0,
    'MAINEZ': 0,
    'MAINGOT': 0,
    'MAINHART': 0,
    'MAINI': 0,
    'MAINIERI': 0,
    'MAINIERO': 0,
    'MAININI': 0,
    'MAINKA': 0,
    'MAINLAND': 0,
    'MAINO': 0,
    'MAINOLFI': 0,
    'MAINOR': 0,
    'MAINORD': 0,
    'MAINOUS': 0,
    'MAINS': 0,
    'MAINUS': 0,
    'MAINVILLE': 0,
    'MAINWARING': 0,
    'MAINZ': 0,
    'MAINZER': 0,
    'MAIO': 0,
    'MAIOCCO': 0,
    'MAIOLA': 0,
    'MAIOLO': 0,
    'MAIONE': 0,
    'MAIORANA': 0,
    'MAIORANO': 0,
    'MAIORCA': 0,
    'MAIORIELLO': 0,
    'MAIORINO': 0,
    'MAIR': 0,
    'MAIRA': 0.970873786407767,
    'MAIRE': 0.8196721311475409,
    'MAIRENA': 0,
    'MAIROSE': 0,
    'MAIRS': 0,
    'MAIS': 0,
    'MAISAND': 0,
    'MAISANO': 0,
    'MAISCH': 0,
    'MAISE': 0,
    'MAISEL': 0,
    'MAISEY': 0,
    'MAISH': 0,
    'MAISHA': 1,
    'MAISIE': 1,
    'MAISNER': 0,
    'MAISON': 0,
    'MAISONAVE': 0,
    'MAISONET': 0,
    'MAISONNEUVE': 0,
    'MAISTO': 0,
    'MAISTROS': 0,
    'MAITA': 0,
    'MAITH': 0,
    'MAITIN': 0,
    'MAITLAND': 0,
    'MAITLEN': 0,
    'MAITNER': 0,
    'MAITRA': 0,
    'MAITRE': 0,
    'MAITZ': 0,
    'MAIURI': 0,
    'MAIWALD': 0,
    'MAIXNER': 0,
    'MAIZ': 0,
    'MAIZE': 0,
    'MAIZEL': 0,
    'MAJ': 0,
    'MAJALCA': 0,
    'MAJANO': 0,
    'MAJARIAN': 0,
    'MAJCHER': 0,
    'MAJCHROWICZ': 0,
    'MAJCHROWSKI': 0,
    'MAJCHRZAK': 0,
    'MAJD': 0,
    'MAJED': 0,
    'MAJEED': 0,
    'MAJEK': 0,
    'MAJER': 0,
    'MAJERCIK': 0,
    'MAJERCZAK': 0,
    'MAJERCZYK': 0,
    'MAJERES': 0,
    'MAJERLE': 0,
    'MAJERNIK': 0,
    'MAJEROWICZ': 0,
    'MAJERSKY': 0,
    'MAJERUS': 0,
    'MAJESKE': 0,
    'MAJESKI': 0,
    'MAJESKY': 0,
    'MAJESTIC': 0,
    'MAJETIC': 0,
    'MAJETICH': 0,
    'MAJETTE': 0,
    'MAJEWICZ': 0,
    'MAJEWSKI': 0,
    'MAJIA': 0,
    'MAJID': 0,
    'MAJIDI': 0,
    'MAJIED': 0,
    'MAJKA': 0,
    'MAJKOWSKI': 0,
    'MAJKRZAK': 0,
    'MAJKUT': 0,
    'MAJMUDAR': 0,
    'MAJMUNDAR': 0,
    'MAJOCHA': 0,
    'MAJOR': 0.4881450488145049,
    'MAJORIE': 1,
    'MAJOROS': 0,
    'MAJORS': 0,
    'MAJOY': 0,
    'MAJSZAK': 0,
    'MAJUMDAR': 0,
    'MAJUMDER': 0,
    'MAJURE': 0,
    'MAK': 0,
    'MAKA': 0,
    'MAKAL': 0,
    'MAKAMSON': 0,
    'MAKAR': 0,
    'MAKARA': 0,
    'MAKARENKO': 0,
    'MAKAREVICH': 0,
    'MAKAREWICZ': 0,
    'MAKAROV': 0,
    'MAKARSKI': 0,
    'MAKARY': 0,
    'MAKAS': 0,
    'MAKATURA': 0,
    'MAKAY': 0,
    'MAKEDA': 1,
    'MAKEKAU': 0,
    'MAKEL': 0,
    'MAKELA': 0,
    'MAKELL': 0,
    'MAKELY': 0,
    'MAKEMSON': 0,
    'MAKEPEACE': 0,
    'MAKER': 0,
    'MAKEY': 0,
    'MAKHANI': 0,
    'MAKHIJA': 0,
    'MAKHIJANI': 0,
    'MAKHLOUF': 0,
    'MAKHOUL': 0,
    'MAKI': 0,
    'MAKIE': 0,
    'MAKIELSKI': 0,
    'MAKIL': 0,
    'MAKIN': 0,
    'MAKINEN': 0,
    'MAKINGS': 0,
    'MAKINO': 0,
    'MAKINS': 0,
    'MAKINSON': 0,
    'MAKINSTER': 0,
    'MAKIS': 0,
    'MAKISHIMA': 0,
    'MAKKAR': 0,
    'MAKKI': 0,
    'MAKLARY': 0,
    'MAKLE': 0,
    'MAKLED': 0,
    'MAKLER': 0,
    'MAKLEY': 0,
    'MAKNOJIA': 0,
    'MAKO': 0,
    'MAKOFSKE': 0,
    'MAKONNEN': 0,
    'MAKOS': 0,
    'MAKOSKI': 0,
    'MAKOSKY': 0,
    'MAKOVEC': 0,
    'MAKOVICKA': 0,
    'MAKOVSKY': 0,
    'MAKOWIEC': 0,
    'MAKOWIECKI': 0,
    'MAKOWKA': 0,
    'MAKOWSKI': 0,
    'MAKOWSKY': 0,
    'MAKRIDES': 0,
    'MAKRIDIS': 0,
    'MAKRIS': 0,
    'MAKS': 0,
    'MAKSIM': 0,
    'MAKSIMOV': 0,
    'MAKSIMOVIC': 0,
    'MAKSIMOWICZ': 0,
    'MAKSIN': 0,
    'MAKSYM': 0,
    'MAKSYMOWICZ': 0,
    'MAKUA': 0,
    'MAKUCH': 0,
    'MAKULA': 0,
    'MAKUPSON': 0,
    'MAKUS': 0,
    'MAKUTA': 0,
    'MAKWANA': 0,
    'MAL': 0,
    'MALA': 0,
    'MALABANAN': 0,
    'MALABY': 0,
    'MALACARA': 0,
    'MALACARNE': 0,
    'MALACH': 0,
    'MALACHI': 0,
    'MALACHOWSKI': 0,
    'MALACK': 0,
    'MALADY': 0,
    'MALAER': 0,
    'MALAFRONTE': 0,
    'MALAGA': 0,
    'MALAGARIE': 0,
    'MALAGISI': 0,
    'MALAGON': 0,
    'MALAGUTI': 0,
    'MALAISE': 0,
    'MALAK': 0,
    'MALAKI': 0,
    'MALAKOFF': 0,
    'MALAKOWSKY': 0,
    'MALAM': 0,
    'MALAMA': 0,
    'MALAMPHY': 0,
    'MALAMUD': 0,
    'MALAMUT': 0,
    'MALAN': 0,
    'MALANA': 0,
    'MALANAPHY': 0,
    'MALANCHE': 0,
    'MALAND': 0,
    'MALANDRA': 0,
    'MALANDRINO': 0,
    'MALANDRO': 0,
    'MALANE': 0,
    'MALANEY': 0,
    'MALANGA': 0,
    'MALANGONE': 0,
    'MALANI': 0,
    'MALANOSKI': 0,
    'MALANOWSKI': 0,
    'MALAPIT': 0,
    'MALAQUIAS': 0,
    'MALARA': 0,
    'MALARET': 0,
    'MALARIK': 0,
    'MALARK': 0,
    'MALARKEY': 0,
    'MALARNEY': 0,
    'MALARY': 0,
    'MALAS': 0,
    'MALASIG': 0,
    'MALASKA': 0,
    'MALASKI': 0,
    'MALASKY': 0,
    'MALASPINA': 0,
    'MALAT': 0,
    'MALATEK': 0,
    'MALATERRE': 0,
    'MALATESTA': 0,
    'MALATINO': 0,
    'MALATT': 0,
    'MALATY': 0,
    'MALAVE': 0,
    'MALAVENDA': 0,
    'MALAVET': 0,
    'MALAY': 0,
    'MALBERG': 0,
    'MALBOEUF': 0,
    'MALBON': 0,
    'MALBONE': 0,
    'MALBROUGH': 0,
    'MALBURG': 0,
    'MALBY': 0,
    'MALCHIODI': 0,
    'MALCHOW': 0,
    'MALCOLM': 0.9049773755656109,
    'MALCOLMSON': 0,
    'MALCOM': 0.7518796992481203,
    'MALCOMB': 0,
    'MALCOME': 0,
    'MALCOMSON': 0,
    'MALCORE': 0,
    'MALCUIT': 0,
    'MALCZEWSKI': 0,
    'MALCZYK': 0,
    'MALCZYNSKI': 0,
    'MALDA': 0,
    'MALDARI': 0,
    'MALDE': 0,
    'MALDEN': 0,
    'MALDON': 0,
    'MALDONA': 0,
    'MALDONADO': 0,
    'MALDONALDO': 0,
    'MALDONDO': 0,
    'MALE': 0,
    'MALEAR': 0,
    'MALEBRANCHE': 0,
    'MALEC': 0,
    'MALECEK': 0,
    'MALECHA': 0,
    'MALECK': 0,
    'MALECKI': 0,
    'MALEE': 0,
    'MALEH': 0,
    'MALEHORN': 0,
    'MALEK': 0,
    'MALEKI': 0,
    'MALEKZADEH': 0,
    'MALEN': 0,
    'MALENA': 0.8547008547008547,
    'MALENDA': 0,
    'MALENFANT': 0,
    'MALENICH': 0,
    'MALENKE': 0,
    'MALENO': 0,
    'MALENSEK': 0,
    'MALEPORT': 0,
    'MALER': 0,
    'MALERBA': 0,
    'MALERICH': 0,
    'MALES': 0,
    'MALESKI': 0,
    'MALESKY': 0,
    'MALESPIN': 0,
    'MALET': 0,
    'MALETA': 0,
    'MALETIC': 0,
    'MALETICH': 0,
    'MALETT': 0,
    'MALETTA': 0,
    'MALETTE': 0,
    'MALETTO': 0,
    'MALETZ': 0,
    'MALEWICKI': 0,
    'MALEWICZ': 0,
    'MALEWSKI': 0,
    'MALEY': 0,
    'MALFA': 0,
    'MALFARA': 0,
    'MALFATTI': 0,
    'MALFAVON': 0,
    'MALFITANO': 0,
    'MALGERI': 0,
    'MALGIERI': 0,
    'MALHAM': 0,
    'MALHERBE': 0,
    'MALHI': 0,
    'MALHIOT': 0,
    'MALHOTRA': 0,
    'MALI': 0,
    'MALIA': 0.8982035928143713,
    'MALIC': 0,
    'MALICDEM': 0,
    'MALICH': 0,
    'MALICK': 0,
    'MALICKI': 0,
    'MALICOAT': 0,
    'MALICOTE': 0,
    'MALIE': 0,
    'MALIG': 0,
    'MALIGA': 0,
    'MALIK': 0.5095541401273885,
    'MALIKA': 1,
    'MALIKOWSKI': 0,
    'MALILAY': 0,
    'MALIMBAN': 0,
    'MALIN': 0,
    'MALINA': 0,
    'MALINAK': 0,
    'MALINAO': 0,
    'MALINAUSKAS': 0,
    'MALINCHAK': 0,
    'MALINCONICO': 0,
    'MALINDA': 1,
    'MALINE': 0,
    'MALING': 0,
    'MALINIAK': 0,
    'MALINICH': 0,
    'MALINIS': 0,
    'MALINOSKI': 0,
    'MALINOSKY': 0,
    'MALINOVSKY': 0,
    'MALINOWSKI': 0,
    'MALINOWSKY': 0,
    'MALINS': 0,
    'MALINSKI': 0,
    'MALINSKY': 0,
    'MALIS': 0,
    'MALISA': 1,
    'MALISH': 0,
    'MALISKA': 0,
    'MALISON': 0,
    'MALISSA': 1,
    'MALISZEWSKI': 0,
    'MALIT': 0,
    'MALITO': 0,
    'MALITZ': 0,
    'MALIVERT': 0,
    'MALIZIA': 0,
    'MALIZIO': 0,
    'MALK': 0,
    'MALKA': 0.8474576271186441,
    'MALKANI': 0,
    'MALKASIAN': 0,
    'MALKE': 0,
    'MALKEMES': 0,
    'MALKEMUS': 0,
    'MALKI': 0,
    'MALKIEWICZ': 0,
    'MALKIN': 0,
    'MALKMUS': 0,
    'MALKO': 0,
    'MALKOFF': 0,
    'MALKOVICH': 0,
    'MALKOWSKI': 0,
    'MALKUS': 0,
    'MALL': 0,
    'MALLA': 0,
    'MALLABER': 0,
    'MALLACH': 0,
    'MALLADI': 0,
    'MALLADY': 0,
    'MALLAH': 0,
    'MALLAHAN': 0,
    'MALLAK': 0,
    'MALLALIEU': 0,
    'MALLAM': 0,
    'MALLAMO': 0,
    'MALLAMS': 0,
    'MALLAN': 0,
    'MALLANEY': 0,
    'MALLAR': 0,
    'MALLARD': 0,
    'MALLARDI': 0,
    'MALLARE': 0,
    'MALLARI': 0,
    'MALLARY': 0,
    'MALLAS': 0,
    'MALLATT': 0,
    'MALLAY': 0,
    'MALLE': 0,
    'MALLEA': 0,
    'MALLECK': 0,
    'MALLEK': 0,
    'MALLEN': 0,
    'MALLEO': 0,
    'MALLER': 0,
    'MALLERNEE': 0,
    'MALLERY': 0,
    'MALLES': 0,
    'MALLET': 0,
    'MALLETT': 0,
    'MALLETTE': 0,
    'MALLEY': 0,
    'MALLI': 0,
    'MALLIA': 0,
    'MALLICK': 0,
    'MALLICOAT': 0,
    'MALLICOTE': 0,
    'MALLIE': 0.9433962264150944,
    'MALLIET': 0,
    'MALLIK': 0,
    'MALLIN': 0,
    'MALLING': 0,
    'MALLINGER': 0,
    'MALLINSON': 0,
    'MALLIOS': 0,
    'MALLIS': 0,
    'MALLISON': 0,
    'MALLMANN': 0,
    'MALLO': 0,
    'MALLOCH': 0,
    'MALLOCK': 0,
    'MALLON': 0,
    'MALLONE': 0,
    'MALLONEE': 0,
    'MALLORY': 0.6557377049180327,
    'MALLOS': 0,
    'MALLOT': 0,
    'MALLOTT': 0,
    'MALLOW': 0,
    'MALLOY': 0,
    'MALLOZZI': 0,
    'MALLUM': 0,
    'MALLY': 0,
    'MALLYA': 0,
    'MALM': 0,
    'MALMAN': 0,
    'MALMANGER': 0,
    'MALMAY': 0,
    'MALMBERG': 0,
    'MALMBORG': 0,
    'MALMER': 0,
    'MALMGREN': 0,
    'MALMIN': 0,
    'MALMO': 0,
    'MALMOTRA': 0,
    'MALMQUIST': 0,
    'MALMROSE': 0,
    'MALMSTEN': 0,
    'MALMSTROM': 0,
    'MALNAR': 0,
    'MALNATI': 0,
    'MALNICK': 0,
    'MALNORY': 0,
    'MALO': 0,
    'MALOCH': 0,
    'MALOFF': 0,
    'MALOLEPSZY': 0,
    'MALOLEY': 0,
    'MALON': 0,
    'MALONE': 0,
    'MALONEY': 0,
    'MALONG': 0,
    'MALONI': 0,
    'MALONSON': 0,
    'MALONY': 0,
    'MALONZO': 0,
    'MALOOF': 0,
    'MALOOLY': 0,
    'MALOON': 0,
    'MALORANA': 0,
    'MALORIE': 1,
    'MALORY': 0,
    'MALOS': 0,
    'MALOSH': 0,
    'MALOTA': 0,
    'MALOTT': 0,
    'MALOTTE': 0,
    'MALOUF': 0,
    'MALOUFF': 0,
    'MALOUIN': 0,
    'MALOVICH': 0,
    'MALOY': 0,
    'MALOYED': 0,
    'MALPARTIDA': 0,
    'MALPASS': 0,
    'MALPEDE': 0,
    'MALPHRUS': 0,
    'MALPHURS': 0,
    'MALPHUS': 0,
    'MALPICA': 0,
    'MALS': 0,
    'MALSACK': 0,
    'MALSAM': 0,
    'MALSBURY': 0,
    'MALSCH': 0,
    'MALSEED': 0,
    'MALSKY': 0,
    'MALSOM': 0,
    'MALSON': 0,
    'MALSTROM': 0,
    'MALT': 0,
    'MALTA': 0,
    'MALTAGLIATI': 0,
    'MALTAIS': 0,
    'MALTAS': 0,
    'MALTBA': 0,
    'MALTBIA': 0,
    'MALTBIE': 0,
    'MALTBY': 0,
    'MALTER': 0,
    'MALTERER': 0,
    'MALTES': 0,
    'MALTESE': 0,
    'MALTEZ': 0,
    'MALTHANER': 0,
    'MALTIN': 0,
    'MALTMAN': 0,
    'MALTON': 0,
    'MALTOS': 0,
    'MALTRY': 0,
    'MALTSBERGER': 0,
    'MALTZ': 0,
    'MALTZMAN': 0,
    'MALUCHNIK': 0,
    'MALUEG': 0,
    'MALUGEN': 0,
    'MALUGIN': 0,
    'MALUSKY': 0,
    'MALVAEZ': 0,
    'MALVAR': 0,
    'MALVASIO': 0,
    'MALVEAUX': 0,
    'MALVESTUTO': 0,
    'MALVEY': 0,
    'MALVIN': 0,
    'MALVINA': 1,
    'MALVITZ': 0,
    'MALVO': 0,
    'MALWITZ': 0,
    'MALY': 0,
    'MALYS': 0,
    'MALYSA': 0,
    'MALYSZKO': 0,
    'MALZ': 0,
    'MALZAHN': 0,
    'MALZONE': 0,
    'MAM': 0,
    'MAMA': 0,
    'MAMADOU': 0,
    'MAMAKOS': 0,
    'MAMAN': 0,
    'MAMANI': 0,
    'MAMARADLO': 0,
    'MAMARIL': 0,
    'MAMARY': 0,
    'MAMDANI': 0,
    'MAMEA': 0,
    'MAMEDOV': 0,
    'MAMER': 0,
    'MAMEROW': 0,
    'MAMI': 0,
    'MAMIE': 1,
    'MAMIYA': 0,
    'MAMIYE': 0,
    'MAMMANA': 0,
    'MAMMANO': 0,
    'MAMMARELLA': 0,
    'MAMMEL': 0,
    'MAMMEN': 0,
    'MAMMENGA': 0,
    'MAMMIE': 1,
    'MAMMINA': 0,
    'MAMMO': 0,
    'MAMMOLA': 0,
    'MAMMON': 0,
    'MAMMONE': 0,
    'MAMMOSER': 0,
    'MAMO': 0,
    'MAMOLA': 0,
    'MAMON': 0,
    'MAMONE': 0,
    'MAMOU': 0,
    'MAMRAK': 0,
    'MAMUAD': 0,
    'MAMULA': 0,
    'MAMUN': 0,
    'MAN': 0.7530120481927711,
    'MANA': 0.9433962264150944,
    'MANABAT': 0,
    'MANABE': 0,
    'MANACK': 0,
    'MANAGAN': 0,
    'MANAGHAN': 0,
    'MANAGO': 0,
    'MANAHAN': 0,
    'MANAK': 0,
    'MANALAC': 0,
    'MANALANG': 0,
    'MANALANSAN': 0,
    'MANALASTAS': 0,
    'MANALAYSAY': 0,
    'MANALE': 0,
    'MANALILI': 0,
    'MANALO': 0,
    'MANALOTO': 0,
    'MANAN': 0,
    'MANANGAN': 0,
    'MANANSALA': 0,
    'MANAOIS': 0,
    'MANAPAT': 0,
    'MANAR': 0,
    'MANARD': 0,
    'MANARY': 0,
    'MANAS': 0,
    'MANASCO': 0,
    'MANASSA': 0,
    'MANASSE': 0,
    'MANATT': 0,
    'MANAUGH': 0,
    'MANBECK': 0,
    'MANBY': 0,
    'MANCA': 0,
    'MANCAO': 0,
    'MANCARELLA': 0,
    'MANCARI': 0,
    'MANCE': 0,
    'MANCEAUX': 0,
    'MANCEBO': 0,
    'MANCELL': 0,
    'MANCERA': 0,
    'MANCERO': 0,
    'MANCHA': 0,
    'MANCHACA': 0,
    'MANCHANDA': 0,
    'MANCHE': 0,
    'MANCHEGO': 0,
    'MANCHEN': 0,
    'MANCHENO': 0,
    'MANCHESKI': 0,
    'MANCHESTER': 0,
    'MANCHIK': 0,
    'MANCI': 0,
    'MANCIA': 0,
    'MANCIAS': 0,
    'MANCIL': 0,
    'MANCILL': 0,
    'MANCILLA': 0,
    'MANCILLAS': 0,
    'MANCINA': 0,
    'MANCINAS': 0,
    'MANCINE': 0,
    'MANCINELLI': 0,
    'MANCINI': 0,
    'MANCINO': 0,
    'MANCIO': 0,
    'MANCL': 0,
    'MANCO': 0,
    'MANCUSI': 0,
    'MANCUSO': 0,
    'MAND': 0,
    'MANDA': 0.9090909090909091,
    'MANDAC': 0,
    'MANDAL': 0,
    'MANDALA': 0,
    'MANDAP': 0,
    'MANDAPAT': 0,
    'MANDARA': 0,
    'MANDARANO': 0,
    'MANDARINO': 0,
    'MANDARO': 0,
    'MANDAS': 0,
    'MANDAT': 0,
    'MANDATO': 0,
    'MANDAVA': 0,
    'MANDE': 0,
    'MANDEL': 0,
    'MANDELA': 0,
    'MANDELBAUM': 0,
    'MANDELKOW': 0,
    'MANDELL': 0,
    'MANDELLA': 0,
    'MANDER': 0,
    'MANDERA': 0,
    'MANDERFELD': 0,
    'MANDERFIELD': 0,
    'MANDERINO': 0,
    'MANDERNACH': 0,
    'MANDERS': 0,
    'MANDERSCHEID': 0,
    'MANDERSON': 0,
    'MANDERVILLE': 0,
    'MANDERY': 0,
    'MANDES': 0,
    'MANDEVILLE': 0,
    'MANDEZ': 0,
    'MANDI': 0.9900990099009901,
    'MANDIA': 0,
    'MANDIC': 0,
    'MANDICH': 0,
    'MANDIE': 1,
    'MANDIGO': 0,
    'MANDILE': 0,
    'MANDINA': 0,
    'MANDIS': 0,
    'MANDISH': 0,
    'MANDL': 0,
    'MANDLE': 0,
    'MANDLER': 0,
    'MANDLEY': 0,
    'MANDLI': 0,
    'MANDO': 0,
    'MANDOLA': 0,
    'MANDOLFO': 0,
    'MANDOLINI': 0,
    'MANDONADO': 0,
    'MANDOZA': 0,
    'MANDRA': 0,
    'MANDRACCHIA': 0,
    'MANDRELL': 0,
    'MANDRICK': 0,
    'MANDROS': 0,
    'MANDRY': 0,
    'MANDT': 0,
    'MANDUCA': 0,
    'MANDUJANO': 0,
    'MANDY': 0.9917920656634747,
    'MANE': 0,
    'MANEA': 0,
    'MANECKE': 0,
    'MANEE': 0,
    'MANEELY': 0,
    'MANEEN': 0,
    'MANEES': 0,
    'MANEGOLD': 0,
    'MANEIRO': 0,
    'MANEJA': 0,
    'MANEK': 0,
    'MANEKE': 0,
    'MANEL': 0,
    'MANELA': 0,
    'MANELIS': 0,
    'MANELL': 0,
    'MANELLA': 0,
    'MANELSKI': 0,
    'MANELY': 0,
    'MANEMANN': 0,
    'MANENTE': 0,
    'MANER': 0,
    'MANERA': 0,
    'MANERI': 0,
    'MANERO': 0,
    'MANERS': 0,
    'MANERY': 0,
    'MANES': 0,
    'MANESE': 0,
    'MANESH': 0,
    'MANESIS': 0,
    'MANESS': 0,
    'MANESSIS': 0,
    'MANETH': 0,
    'MANETTA': 0,
    'MANETTI': 0,
    'MANEVAL': 0,
    'MANEY': 0,
    'MANEZ': 0,
    'MANFIELD': 0,
    'MANFORD': 0,
    'MANFRA': 0,
    'MANFRE': 0,
    'MANFRED': 0,
    'MANFREDA': 0,
    'MANFREDI': 0,
    'MANFREDINI': 0,
    'MANFREDO': 0,
    'MANFREDONIA': 0,
    'MANFULL': 0,
    'MANG': 0,
    'MANGA': 0,
    'MANGABAT': 0,
    'MANGAHAS': 0,
    'MANGAL': 0,
    'MANGALINDAN': 0,
    'MANGAM': 0,
    'MANGAN': 0,
    'MANGANARD': 0,
    'MANGANARO': 0,
    'MANGANELLA': 0,
    'MANGANELLI': 0,
    'MANGANELLO': 0,
    'MANGANIELLO': 0,
    'MANGANO': 0,
    'MANGAOANG': 0,
    'MANGAR': 0,
    'MANGAROO': 0,
    'MANGAS': 0,
    'MANGAT': 0,
    'MANGE': 0,
    'MANGEL': 0,
    'MANGELLI': 0,
    'MANGELS': 0,
    'MANGELSDORF': 0,
    'MANGELSEN': 0,
    'MANGELSON': 0,
    'MANGEN': 0,
    'MANGENE': 0,
    'MANGER': 0,
    'MANGERI': 0,
    'MANGERS': 0,
    'MANGES': 0,
    'MANGHAM': 0,
    'MANGI': 0,
    'MANGIA': 0,
    'MANGIAFICO': 0,
    'MANGIALARDI': 0,
    'MANGIAMELE': 0,
    'MANGIAMELI': 0,
    'MANGIAPANE': 0,
    'MANGIARACINA': 0,
    'MANGIARDI': 0,
    'MANGIARELLI': 0,
    'MANGIERI': 0,
    'MANGIN': 0,
    'MANGINA': 0,
    'MANGINE': 0,
    'MANGINELLI': 0,
    'MANGINI': 0,
    'MANGINO': 0,
    'MANGIO': 0,
    'MANGIONE': 0,
    'MANGIS': 0,
    'MANGLE': 0,
    'MANGLER': 0,
    'MANGLES': 0,
    'MANGLICMOT': 0,
    'MANGLONA': 0,
    'MANGLOS': 0,
    'MANGNALL': 0,
    'MANGO': 0,
    'MANGOGNA': 0,
    'MANGOL': 0,
    'MANGOLD': 0,
    'MANGONA': 0,
    'MANGONE': 0,
    'MANGONON': 0,
    'MANGOS': 0,
    'MANGOSING': 0,
    'MANGRA': 0,
    'MANGRAM': 0,
    'MANGRICH': 0,
    'MANGROBANG': 0,
    'MANGROO': 0,
    'MANGRU': 0,
    'MANGRUM': 0,
    'MANGUAL': 0,
    'MANGUBAT': 0,
    'MANGUM': 0,
    'MANGUN': 0,
    'MANGUNE': 0,
    'MANGUS': 0,
    'MANGUSO': 0,
    'MANHARD': 0,
    'MANHARDT': 0,
    'MANHART': 0,
    'MANHEIM': 0,
    'MANHEIMER': 0,
    'MANI': 0,
    'MANIA': 0,
    'MANIACE': 0,
    'MANIACI': 0,
    'MANIAGO': 0,
    'MANIAK': 0,
    'MANIAN': 0,
    'MANIAR': 0,
    'MANIAS': 0,
    'MANIATES': 0,
    'MANIATIS': 0,
    'MANIBOG': 0,
    'MANIBUSAN': 0,
    'MANICA': 0,
    'MANICCIA': 0,
    'MANICK': 0,
    'MANICKAM': 0,
    'MANICKE': 0,
    'MANICONE': 0,
    'MANIE': 1,
    'MANIECE': 0,
    'MANIEGO': 0,
    'MANIER': 0,
    'MANIERI': 0,
    'MANIES': 0,
    'MANIFOLD': 0,
    'MANIGAN': 0,
    'MANIGAT': 0,
    'MANIGAULT': 0,
    'MANIGLIA': 0,
    'MANIGO': 0,
    'MANIGOLD': 0,
    'MANIK': 0,
    'MANIKAS': 0,
    'MANIKOWSKI': 0,
    'MANILA': 0,
    'MANILLA': 0,
    'MANIN': 0,
    'MANING': 0,
    'MANINGAS': 0,
    'MANINGER': 0,
    'MANINI': 0,
    'MANINO': 0,
    'MANIO': 0,
    'MANION': 0,
    'MANIPON': 0,
    'MANIQUIS': 0,
    'MANIRE': 0,
    'MANIS': 0,
    'MANISCALCO': 0,
    'MANISTA': 0,
    'MANITTA': 0,
    'MANIVANH': 0,
    'MANIVONG': 0,
    'MANIX': 0,
    'MANJARRES': 0,
    'MANJARREZ': 0,
    'MANJI': 0,
    'MANJUNATH': 0,
    'MANK': 0,
    'MANKA': 0,
    'MANKE': 0,
    'MANKEL': 0,
    'MANKER': 0,
    'MANKEY': 0,
    'MANKIEWICZ': 0,
    'MANKIN': 0,
    'MANKINS': 0,
    'MANKO': 0,
    'MANKOFF': 0,
    'MANKOSKI': 0,
    'MANKOWSKI': 0,
    'MANKUS': 0,
    'MANLANGIT': 0,
    'MANLAPAZ': 0,
    'MANLEY': 0,
    'MANLICK': 0,
    'MANLOVE': 0,
    'MANLY': 0,
    'MANN': 0,
    'MANNA': 0,
    'MANNAN': 0,
    'MANNARA': 0,
    'MANNARELLI': 0,
    'MANNARINO': 0,
    'MANNAS': 0,
    'MANNE': 0,
    'MANNEBACH': 0,
    'MANNEH': 0,
    'MANNEL': 0,
    'MANNELL': 0,
    'MANNELLA': 0,
    'MANNELLO': 0,
    'MANNEN': 0,
    'MANNER': 0,
    'MANNERING': 0,
    'MANNERS': 0,
    'MANNERY': 0,
    'MANNES': 0,
    'MANNESS': 0,
    'MANNETTA': 0,
    'MANNETTE': 0,
    'MANNEY': 0,
    'MANNHEIMER': 0,
    'MANNI': 0,
    'MANNICK': 0,
    'MANNIE': 0,
    'MANNIELLO': 0,
    'MANNIKKO': 0,
    'MANNILA': 0,
    'MANNIN': 0,
    'MANNINA': 0,
    'MANNINEN': 0,
    'MANNING': 0,
    'MANNINGS': 0,
    'MANNINO': 0,
    'MANNION': 0,
    'MANNIS': 0,
    'MANNISTO': 0,
    'MANNIX': 0,
    'MANNLEIN': 0,
    'MANNO': 0,
    'MANNON': 0,
    'MANNONE': 0,
    'MANNOR': 0,
    'MANNOS': 0,
    'MANNS': 0,
    'MANNSCHRECK': 0,
    'MANNUZZA': 0,
    'MANNY': 0,
    'MANO': 0,
    'MANOCCHIO': 0,
    'MANOCHA': 0,
    'MANOCK': 0,
    'MANOFF': 0,
    'MANOGUE': 0,
    'MANOHAR': 0,
    'MANOHARAN': 0,
    'MANOJLOVIC': 0,
    'MANOLA': 0,
    'MANOLAKIS': 0,
    'MANOLAS': 0,
    'MANOLI': 0,
    'MANOLIS': 0,
    'MANON': 0,
    'MANONI': 0,
    'MANOOGIAN': 0,
    'MANOOKIAN': 0,
    'MANOR': 0,
    'MANORE': 0,
    'MANOS': 0,
    'MANOSH': 0,
    'MANOUGIAN': 0,
    'MANOUKIAN': 0,
    'MANOUS': 0,
    'MANOUSOS': 0,
    'MANOWN': 0,
    'MANOWSKI': 0,
    'MANOZ': 0,
    'MANQUERO': 0,
    'MANQUEROS': 0,
    'MANRESA': 0,
    'MANRIGUEZ': 0,
    'MANRING': 0,
    'MANRIQUE': 0,
    'MANRIQUEZ': 0,
    'MANROE': 0,
    'MANROSS': 0,
    'MANRRIQUEZ': 0,
    'MANRY': 0,
    'MANS': 0,
    'MANSAGER': 0,
    'MANSANAREZ': 0,
    'MANSARAY': 0,
    'MANSAVAGE': 0,
    'MANSBACH': 0,
    'MANSBERGER': 0,
    'MANSBERRY': 0,
    'MANSBRIDGE': 0,
    'MANSCH': 0,
    'MANSE': 0,
    'MANSEAU': 0,
    'MANSEL': 0,
    'MANSELL': 0,
    'MANSELLE': 0,
    'MANSEN': 0,
    'MANSER': 0,
    'MANSFIELD': 0,
    'MANSHACK': 0,
    'MANSHEIM': 0,
    'MANSHIP': 0,
    'MANSHOLT': 0,
    'MANSI': 0,
    'MANSILLA': 0,
    'MANSINGH': 0,
    'MANSION': 0,
    'MANSIR': 0,
    'MANSKE': 0,
    'MANSKER': 0,
    'MANSKI': 0,
    'MANSKY': 0,
    'MANSMANN': 0,
    'MANSMITH': 0,
    'MANSO': 0,
    'MANSOLILLO': 0,
    'MANSON': 0,
    'MANSOOR': 0,
    'MANSOORI': 0,
    'MANSOR': 0,
    'MANSOUR': 0,
    'MANSOURI': 0,
    'MANSOURIAN': 0,
    'MANSPEAKER': 0,
    'MANSPERGER': 0,
    'MANSPILE': 0,
    'MANSUETO': 0,
    'MANSUKHANI': 0,
    'MANSUR': 0,
    'MANSURI': 0,
    'MANSY': 0,
    'MANTA': 0,
    'MANTANONA': 0,
    'MANTAS': 0,
    'MANTAY': 0,
    'MANTE': 0,
    'MANTECON': 0,
    'MANTEGNA': 0,
    'MANTEI': 0,
    'MANTEIGA': 0,
    'MANTEL': 0,
    'MANTELL': 0,
    'MANTELLI': 0,
    'MANTELLO': 0,
    'MANTER': 0,
    'MANTERNACH': 0,
    'MANTEUFEL': 0,
    'MANTEUFFEL': 0,
    'MANTEY': 0,
    'MANTHA': 0,
    'MANTHE': 0,
    'MANTHEI': 0,
    'MANTHEY': 0,
    'MANTHIE': 0,
    'MANTHOS': 0,
    'MANTI': 0,
    'MANTIA': 0,
    'MANTICA': 0,
    'MANTILLA': 0,
    'MANTINI': 0,
    'MANTIONE': 0,
    'MANTIS': 0,
    'MANTLE': 0,
    'MANTLO': 0,
    'MANTO': 0,
    'MANTON': 0,
    'MANTONE': 0,
    'MANTONYA': 0,
    'MANTOOTH': 0,
    'MANTOR': 0,
    'MANTOS': 0,
    'MANTOVANI': 0,
    'MANTSCH': 0,
    'MANTUANO': 0,
    'MANTY': 0,
    'MANTYCH': 0,
    'MANTYLA': 0,
    'MANTZ': 0,
    'MANTZKE': 0,
    'MANTZOURANIS': 0,
    'MANU': 0,
    'MANUAL': 0.9708737864077669,
    'MANUCY': 0,
    'MANUEL': 0.9527318665122645,
    'MANUELA': 1,
    'MANUELE': 0,
    'MANUELIAN': 0,
    'MANUELITO': 0,
    'MANUELL': 0,
    'MANUES': 0,
    'MANUKIAN': 0,
    'MANUKYAN': 0,
    'MANULI': 0,
    'MANUS': 0,
    'MANUSZAK': 0,
    'MANVILLE': 0,
    'MANWARING': 0,
    'MANWARREN': 0,
    'MANWEILER': 0,
    'MANWELL': 0,
    'MANWILL': 0,
    'MANWILLER': 0,
    'MANY': 0.8130081300813008,
    'MANYAK': 0,
    'MANYEN': 0,
    'MANYGOATS': 0,
    'MANYPENNY': 0,
    'MANZ': 0,
    'MANZA': 0,
    'MANZANARES': 0,
    'MANZANAREZ': 0,
    'MANZANEDO': 0,
    'MANZANERA': 0,
    'MANZANERO': 0,
    'MANZANET': 0,
    'MANZANILLA': 0,
    'MANZANILLO': 0,
    'MANZANO': 0,
    'MANZARI': 0,
    'MANZELLA': 0,
    'MANZELLI': 0,
    'MANZER': 0,
    'MANZI': 0,
    'MANZIE': 0,
    'MANZINI': 0,
    'MANZIONE': 0,
    'MANZKE': 0,
    'MANZO': 0,
    'MANZOLILLO': 0,
    'MANZON': 0,
    'MANZONE': 0,
    'MANZONI': 0,
    'MANZOOR': 0,
    'MANZUETA': 0,
    'MANZUR': 0,
    'MAO': 0.4,
    'MAOKHAMPHIOU': 0,
    'MAPA': 0,
    'MAPANAO': 0,
    'MAPEL': 0,
    'MAPES': 0,
    'MAPHET': 0,
    'MAPHIS': 0,
    'MAPLE': 0.5571030640668523,
    'MAPLES': 0,
    'MAPLETHORPE': 0,
    'MAPP': 0,
    'MAPPES': 0,
    'MAPPIN': 0,
    'MAPPS': 0,
    'MAPSON': 0,
    'MAPSTONE': 0,
    'MAPU': 0,
    'MAPULA': 0,
    'MAQBOOL': 0,
    'MAQSOOD': 0,
    'MAQUEDA': 0,
    'MAQUEIRA': 0,
    'MAQUET': 0,
    'MAR': 0,
    'MARA': 0.8928571428571428,
    'MARABELLA': 0,
    'MARABELLO': 0,
    'MARABLE': 0,
    'MARACCINI': 0,
    'MARACH': 0,
    'MARACLE': 0,
    'MARADIAGA': 0,
    'MARAFINO': 0,
    'MARAFIOTI': 0,
    'MARAGARET': 1,
    'MARAGH': 0,
    'MARAGNI': 0,
    'MARAGOS': 0,
    'MARAGRET': 1,
    'MARAH': 0,
    'MARAIA': 0,
    'MARAIS': 0,
    'MARAIST': 0,
    'MARAJ': 0,
    'MARAK': 0,
    'MARAKOVITS': 0,
    'MARALDO': 0,
    'MARALES': 0,
    'MARALIT': 0,
    'MARALLO': 0,
    'MARAMAN': 0,
    'MARAMBA': 0,
    'MARAN': 0,
    'MARANA': 0,
    'MARANAN': 0,
    'MARANDA': 0.9501187648456058,
    'MARANDINO': 0,
    'MARANDO': 0,
    'MARANDOLA': 0,
    'MARANG': 0,
    'MARANGE': 0,
    'MARANGI': 0,
    'MARANGONI': 0,
    'MARANGOS': 0,
    'MARANI': 0,
    'MARANO': 0,
    'MARANON': 0,
    'MARANS': 0,
    'MARANT': 0,
    'MARANTE': 0,
    'MARANTO': 0,
    'MARANTZ': 0,
    'MARANVILLE': 0,
    'MARANZANO': 0,
    'MARAS': 0,
    'MARASA': 0,
    'MARASCHIELLO': 0,
    'MARASCIO': 0,
    'MARASCO': 0,
    'MARASHI': 0,
    'MARASIGAN': 0,
    'MARATEA': 0,
    'MARATHE': 0,
    'MARATTA': 0,
    'MARAVELIAS': 0,
    'MARAVI': 0,
    'MARAVICH': 0,
    'MARAVIGLIA': 0,
    'MARAVILLA': 0,
    'MARAVILLAS': 0,
    'MARAZITA': 0,
    'MARAZZI': 0,
    'MARAZZO': 0,
    'MARBACH': 0,
    'MARBAKER': 0,
    'MARBAN': 0,
    'MARBAUGH': 0,
    'MARBELLA': 0,
    'MARBERRY': 0,
    'MARBLE': 0,
    'MARBLEY': 0,
    'MARBREY': 0,
    'MARBRY': 0,
    'MARBURGER': 0,
    'MARBURY': 0,
    'MARBUT': 0,
    'MARBY': 0,
    'MARC': 0.9954233409610984,
    'MARCA': 0,
    'MARCACCI': 0,
    'MARCACCIO': 0,
    'MARCADO': 0,
    'MARCAL': 0,
    'MARCANO': 0,
    'MARCANTEL': 0,
    'MARCANTONIO': 0,
    'MARCARELLI': 0,
    'MARCARIO': 0,
    'MARCAURELE': 0,
    'MARCAVAGE': 0,
    'MARCEAU': 0,
    'MARCEAUX': 0,
    'MARCEE': 0,
    'MARCEL': 0.9463722397476342,
    'MARCELA': 1,
    'MARCELENE': 1,
    'MARCELENO': 0,
    'MARCELIN': 0,
    'MARCELINA': 1,
    'MARCELINE': 0.9803921568627452,
    'MARCELINO': 0.944386149003148,
    'MARCELIS': 0,
    'MARCELL': 0.7092198581560284,
    'MARCELLA': 0.9893048128342247,
    'MARCELLE': 0.9505703422053231,
    'MARCELLETTI': 0,
    'MARCELLI': 0,
    'MARCELLIN': 0,
    'MARCELLINO': 0,
    'MARCELLO': 0,
    'MARCELLUS': 0.8602150537634409,
    'MARCELO': 0.8944543828264758,
    'MARCELUS': 0,
    'MARCENE': 1,
    'MARCENGILL': 0,
    'MARCERO': 0,
    'MARCERON': 0,
    'MARCET': 0,
    'MARCEY': 0,
    'MARCH': 0,
    'MARCHA': 0,
    'MARCHAK': 0,
    'MARCHAL': 0,
    'MARCHAN': 0,
    'MARCHAND': 0,
    'MARCHANT': 0,
    'MARCHANTE': 0,
    'MARCHANY': 0,
    'MARCHBANK': 0,
    'MARCHBANKS': 0,
    'MARCHE': 0,
    'MARCHEGIANI': 0,
    'MARCHEK': 0,
    'MARCHEL': 0,
    'MARCHELL': 0,
    'MARCHELLE': 1,
    'MARCHELLETTA': 0,
    'MARCHELLO': 0,
    'MARCHENA': 0,
    'MARCHENKO': 0,
    'MARCHER': 0,
    'MARCHESANI': 0,
    'MARCHESANO': 0,
    'MARCHESCHI': 0,
    'MARCHESE': 0,
    'MARCHESI': 0,
    'MARCHESINI': 0,
    'MARCHESKI': 0,
    'MARCHESSAULT': 0,
    'MARCHESSEAULT': 0,
    'MARCHETERRE': 0,
    'MARCHETTA': 0,
    'MARCHETTE': 0,
    'MARCHETTI': 0,
    'MARCHETTO': 0,
    'MARCHEWKA': 0,
    'MARCHI': 0,
    'MARCHIAFAVA': 0,
    'MARCHIANDO': 0,
    'MARCHIANO': 0,
    'MARCHICA': 0,
    'MARCHILDON': 0,
    'MARCHINI': 0,
    'MARCHINO': 0,
    'MARCHIO': 0,
    'MARCHIOLI': 0,
    'MARCHION': 0,
    'MARCHIONDA': 0,
    'MARCHIONE': 0,
    'MARCHIONI': 0,
    'MARCHIONNA': 0,
    'MARCHIONNE': 0,
    'MARCHIONNI': 0,
    'MARCHIORI': 0,
    'MARCHISELLO': 0,
    'MARCHISIO': 0,
    'MARCHISOTTO': 0,
    'MARCHITELLI': 0,
    'MARCHITELLO': 0,
    'MARCHITTO': 0,
    'MARCHLEWSKI': 0,
    'MARCHMAN': 0,
    'MARCHUK': 0,
    'MARCHUS': 0,
    'MARCHWINSKI': 0,
    'MARCI': 0.9930486593843098,
    'MARCIA': 0.9963467286615741,
    'MARCIAL': 0,
    'MARCIANO': 0,
    'MARCIANTE': 0,
    'MARCIAS': 0,
    'MARCIE': 1,
    'MARCIEL': 0,
    'MARCIL': 0,
    'MARCILLE': 0,
    'MARCIN': 0,
    'MARCINAK': 0,
    'MARCINCZYK': 0,
    'MARCINEK': 0,
    'MARCINIAK': 0,
    'MARCINIEC': 0,
    'MARCINIK': 0,
    'MARCINKIEWICZ': 0,
    'MARCINKO': 0,
    'MARCINKOWSKI': 0,
    'MARCINKUS': 0,
    'MARCINO': 0,
    'MARCINOWSKI': 0,
    'MARCIS': 0,
    'MARCISZ': 0,
    'MARCISZEWSKI': 0,
    'MARCK': 0,
    'MARCKEL': 0,
    'MARCKINI': 0,
    'MARCKS': 0,
    'MARCO': 0.9694477085781434,
    'MARCOCCIA': 0,
    'MARCOCCIO': 0,
    'MARCOE': 0,
    'MARCOLINA': 0,
    'MARCOLINI': 0,
    'MARCOLONGO': 0,
    'MARCOM': 0,
    'MARCON': 0,
    'MARCONE': 0,
    'MARCONI': 0,
    'MARCONTELL': 0,
    'MARCOS': 0.9538344143456695,
    'MARCOTRIGIANO': 0,
    'MARCOTT': 0,
    'MARCOTTE': 0,
    'MARCOU': 0,
    'MARCOUILLER': 0,
    'MARCOUILLIER': 0,
    'MARCOUX': 0,
    'MARCOVECCHIO': 0,
    'MARCOZZI': 0,
    'MARCROFT': 0,
    'MARCRUM': 0,
    'MARCU': 0,
    'MARCUCCI': 0,
    'MARCUCCILLI': 0,
    'MARCUCCIO': 0,
    'MARCUM': 0,
    'MARCURE': 0,
    'MARCUS': 0.9506286415210058,
    'MARCUSE': 0,
    'MARCUSEN': 0,
    'MARCUSON': 0,
    'MARCUSSEN': 0,
    'MARCY': 0.9417304296645086,
    'MARCYES': 0,
    'MARCZAK': 0,
    'MARCZEWSKI': 0,
    'MARCZYK': 0,
    'MARCZYNSKI': 0,
    'MARD': 0,
    'MARDELL': 1,
    'MARDEN': 0,
    'MARDER': 0,
    'MARDEROSIAN': 0,
    'MARDESICH': 0,
    'MARDEUSZ': 0,
    'MARDIAN': 0,
    'MARDIGIAN': 0,
    'MARDIKIAN': 0,
    'MARDIN': 0,
    'MARDINI': 0,
    'MARDIROSIAN': 0,
    'MARDIROSSIAN': 0,
    'MARDIS': 0,
    'MARDO': 0,
    'MARDOCK': 0,
    'MARDON': 0,
    'MARDONES': 0,
    'MARDY': 0,
    'MARE': 0,
    'MAREADY': 0,
    'MAREAN': 0,
    'MARECEK': 0,
    'MARECHAL': 0,
    'MARECK': 0,
    'MARECKI': 0,
    'MAREDIA': 0,
    'MAREE': 0,
    'MAREK': 0,
    'MARELICH': 0,
    'MARELL': 0,
    'MARELLA': 0,
    'MARELLI': 0,
    'MARELLO': 0,
    'MAREN': 0.9569377990430621,
    'MARENCO': 0,
    'MARENDA': 0,
    'MARENGER': 0,
    'MARENGHI': 0,
    'MARENGO': 0,
    'MARENO': 0,
    'MARENTES': 0,
    'MARENTETTE': 0,
    'MARERO': 0,
    'MARES': 0,
    'MARESCA': 0,
    'MARESCH': 0,
    'MARESCHAL': 0,
    'MARESCO': 0,
    'MARESH': 0,
    'MARET': 0,
    'MARETH': 0,
    'MARETT': 0,
    'MARETTE': 0,
    'MARETTI': 0,
    'MAREZ': 0,
    'MARFELL': 0,
    'MARFIA': 0,
    'MARFIL': 0,
    'MARFISI': 0,
    'MARFLAK': 0,
    'MARFO': 0,
    'MARFORI': 0,
    'MARG': 0.9090909090909091,
    'MARGADONNA': 0,
    'MARGALIT': 0,
    'MARGAN': 0,
    'MARGARET': 0.9998437744102484,
    'MARGARETA': 1,
    'MARGARETE': 1,
    'MARGARETT': 1,
    'MARGARETTA': 1,
    'MARGARETTE': 1,
    'MARGARIT': 0,
    'MARGARITA': 0.9989840839823908,
    'MARGARITE': 1,
    'MARGARITIS': 0,
    'MARGARITO': 0.9819967266775776,
    'MARGART': 1,
    'MARGARYAN': 0,
    'MARGASON': 0,
    'MARGE': 0.9917355371900827,
    'MARGEL': 0,
    'MARGELOFSKY': 0,
    'MARGENAU': 0,
    'MARGENE': 1,
    'MARGERET': 1,
    'MARGERT': 1,
    'MARGERUM': 0,
    'MARGERY': 1,
    'MARGESON': 0,
    'MARGET': 0.9803921568627452,
    'MARGETIS': 0,
    'MARGETTA': 0,
    'MARGETTS': 0,
    'MARGHEIM': 0,
    'MARGHERIO': 0,
    'MARGHERITA': 0.9615384615384616,
    'MARGIE': 0.9993060374739765,
    'MARGINEAN': 0,
    'MARGIOTTA': 0,
    'MARGIS': 0,
    'MARGISON': 0,
    'MARGIT': 1,
    'MARGO': 0.9864364981504316,
    'MARGOL': 0,
    'MARGOLIES': 0,
    'MARGOLIN': 0,
    'MARGOLIS': 0,
    'MARGOLIUS': 0,
    'MARGORIE': 1,
    'MARGOSIAN': 0,
    'MARGOSSIAN': 0,
    'MARGOT': 0.9937888198757764,
    'MARGOTTA': 0,
    'MARGRAF': 0,
    'MARGRAFF': 0,
    'MARGRAVE': 0,
    'MARGRAVES': 0,
    'MARGRET': 1,
    'MARGRETT': 1,
    'MARGRITZ': 0,
    'MARGUARDT': 0,
    'MARGUERITA': 1,
    'MARGUERITE': 1,
    'MARGUES': 0,
    'MARGUGLIO': 0,
    'MARGULES': 0,
    'MARGULIES': 0,
    'MARGULIS': 0,
    'MARGURITE': 1,
    'MARGY': 1,
    'MARHEFKA': 0,
    'MARHEINE': 0,
    'MARHOFER': 0,
    'MARHTA': 1,
    'MARI': 0.9540329575021683,
    'MARIA': 0.9982742917405686,
    'MARIACA': 0,
    'MARIACHER': 0,
    'MARIAGE': 0,
    'MARIAGUADALUPE': 0,
    'MARIAH': 1,
    'MARIAM': 0.984251968503937,
    'MARIAN': 0.9961774585891346,
    'MARIANA': 0.989010989010989,
    'MARIANELA': 1,
    'MARIANETTI': 0,
    'MARIANI': 0,
    'MARIANN': 1,
    'MARIANNA': 1,
    'MARIANNE': 1,
    'MARIANO': 0.7518796992481203,
    'MARIAS': 0,
    'MARIBEL': 1,
    'MARIBETH': 1,
    'MARIC': 0,
    'MARICA': 1,
    'MARICAL': 0,
    'MARICELA': 1,
    'MARICH': 0,
    'MARICHAL': 0,
    'MARICHALAR': 0,
    'MARICHE': 0,
    'MARICIC': 0,
    'MARICICH': 0,
    'MARICK': 0,
    'MARICLE': 0,
    'MARICONDA': 0,
    'MARICRUZ': 1,
    'MARIE': 0.9976572165626891,
    'MARIEL': 1,
    'MARIELA': 1,
    'MARIELLA': 1,
    'MARIELLE': 1,
    'MARIEN': 0,
    'MARIENAU': 0,
    'MARIENTHAL': 0,
    'MARIER': 0,
    'MARIETTA': 0.9643201542912248,
    'MARIETTE': 0.9523809523809523,
    'MARIETTI': 0,
    'MARIGLIANO': 0,
    'MARIGNY': 0,
    'MARIHUGH': 0,
    'MARIK': 0,
    'MARIKO': 1,
    'MARILEE': 1,
    'MARILES': 0,
    'MARILLA': 0,
    'MARILLO': 0,
    'MARILOU': 1,
    'MARILU': 1,
    'MARILYN': 1,
    'MARILYNN': 1,
    'MARIMAN': 0,
    'MARIMON': 0,
    'MARIN': 0.07824726134585291,
    'MARINA': 0.9897360703812316,
    'MARINACCI': 0,
    'MARINACCIO': 0,
    'MARINAK': 0,
    'MARINAKIS': 0,
    'MARINAN': 0,
    'MARINARD': 0,
    'MARINARI': 0,
    'MARINARO': 0,
    'MARINAS': 0,
    'MARINCHAK': 0,
    'MARINCIC': 0,
    'MARINDA': 1,
    'MARINE': 0.45045045045045046,
    'MARINEAU': 0,
    'MARINELARENA': 0,
    'MARINELLA': 0,
    'MARINELLI': 0,
    'MARINELLO': 0,
    'MARINER': 0,
    'MARINERO': 0,
    'MARINES': 0,
    'MARINESCU': 0,
    'MARINEZ': 0,
    'MARING': 0,
    'MARINGER': 0,
    'MARINGO': 0,
    'MARINHO': 0,
    'MARINI': 0,
    'MARINICH': 0,
    'MARINIER': 0,
    'MARINIS': 0,
    'MARINKO': 0,
    'MARINKOVIC': 0,
    'MARINKOVICH': 0,
    'MARINO': 0,
    'MARINOFF': 0,
    'MARINONI': 0,
    'MARINOS': 0,
    'MARINOV': 0,
    'MARINOVICH': 0,
    'MARINUCCI': 0,
    'MARIO': 0.9978785259684136,
    'MARION': 0.9696554871092858,
    'MARIONA': 0,
    'MARIONI': 0,
    'MARIONNEAUX': 0,
    'MARIOTT': 0,
    'MARIOTTI': 0,
    'MARIS': 0.591715976331361,
    'MARISA': 1,
    'MARISCAL': 0,
    'MARISELA': 1,
    'MARISH': 0,
    'MARISHA': 1,
    'MARISOL': 1,
    'MARISSA': 1,
    'MARISTANY': 0,
    'MARISTELA': 0,
    'MARIT': 0,
    'MARITA': 1,
    'MARITATO': 0,
    'MARITN': 0,
    'MARITNEZ': 0,
    'MARITT': 0,
    'MARITZ': 0,
    'MARITZA': 1,
    'MARIUCCI': 0,
    'MARIUS': 0,
    'MARIVEL': 1,
    'MARIZ': 0,
    'MARIZAN': 0,
    'MARJAMAA': 0,
    'MARJANOVIC': 0,
    'MARJI': 0,
    'MARJORIE': 1,
    'MARJORY': 1,
    'MARK': 0.9937757147378415,
    'MARKA': 0,
    'MARKAKIS': 0,
    'MARKARIAN': 0,
    'MARKARYAN': 0,
    'MARKATOS': 0,
    'MARKCUM': 0,
    'MARKE': 0,
    'MARKEE': 0,
    'MARKEGARD': 0,
    'MARKEL': 0,
    'MARKELL': 0,
    'MARKEN': 0,
    'MARKER': 0,
    'MARKERT': 0,
    'MARKES': 0,
    'MARKESE': 0,
    'MARKESON': 0,
    'MARKET': 0,
    'MARKETTA': 1,
    'MARKETTE': 0,
    'MARKEVICH': 0,
    'MARKEY': 0,
    'MARKFORT': 0,
    'MARKGRAF': 0,
    'MARKHAM': 0,
    'MARKI': 0,
    'MARKIE': 0,
    'MARKIEWICZ': 0,
    'MARKILLIE': 0,
    'MARKIN': 0,
    'MARKING': 0,
    'MARKINS': 0,
    'MARKIS': 0,
    'MARKITA': 1,
    'MARKL': 0,
    'MARKLAND': 0,
    'MARKLE': 0,
    'MARKLEIN': 0,
    'MARKLEY': 0,
    'MARKLIN': 0,
    'MARKMAN': 0,
    'MARKMANN': 0,
    'MARKO': 0,
    'MARKOE': 0,
    'MARKOFF': 0,
    'MARKOPOULOS': 0,
    'MARKOS': 0,
    'MARKOSIAN': 0,
    'MARKOSKI': 0,
    'MARKOSKY': 0,
    'MARKOSYAN': 0,
    'MARKOU': 0,
    'MARKOV': 0,
    'MARKOVIC': 0,
    'MARKOVICH': 0,
    'MARKOVICS': 0,
    'MARKOVITCH': 0,
    'MARKOVITS': 0,
    'MARKOVITZ': 0,
    'MARKOVSKI': 0,
    'MARKOW': 0,
    'MARKOWICH': 0,
    'MARKOWICZ': 0,
    'MARKOWITZ': 0,
    'MARKOWSKI': 0,
    'MARKOWSKY': 0,
    'MARKRAY': 0,
    'MARKS': 0,
    'MARKSBERRY': 0,
    'MARKSBURY': 0,
    'MARKSON': 0,
    'MARKSTEIN': 0,
    'MARKSTROM': 0,
    'MARKT': 0,
    'MARKU': 0,
    'MARKULIN': 0,
    'MARKULIS': 0,
    'MARKUM': 0,
    'MARKUNAS': 0,
    'MARKUS': 0.7911392405063291,
    'MARKUSEN': 0,
    'MARKUSIC': 0,
    'MARKUSON': 0,
    'MARKUSSEN': 0,
    'MARKUT': 0,
    'MARKWALTER': 0,
    'MARKWARD': 0,
    'MARKWARDT': 0,
    'MARKWART': 0,
    'MARKWAY': 0,
    'MARKWELL': 0,
    'MARKWICK': 0,
    'MARKWITH': 0,
    'MARKWOOD': 0,
    'MARKWORTH': 0,
    'MARKY': 0,
    'MARL': 0,
    'MARLA': 1,
    'MARLAN': 0,
    'MARLANA': 1,
    'MARLAND': 0,
    'MARLAR': 0,
    'MARLATT': 0,
    'MARLAY': 0,
    'MARLBOROUGH': 0,
    'MARLEAU': 0,
    'MARLEEN': 1,
    'MARLEN': 0.9708737864077669,
    'MARLENA': 1,
    'MARLENE': 1,
    'MARLER': 0,
    'MARLES': 0,
    'MARLETT': 0,
    'MARLETTA': 0,
    'MARLETTE': 0,
    'MARLEY': 0,
    'MARLIER': 0,
    'MARLIN': 0.866089273817455,
    'MARLINE': 1,
    'MARLING': 0,
    'MARLO': 0.9554140127388534,
    'MARLON': 0.9973753280839894,
    'MARLOR': 0,
    'MARLOW': 0,
    'MARLOWE': 0,
    'MARLYN': 1,
    'MARLYS': 1,
    'MARMADUKE': 0,
    'MARMAN': 0,
    'MARMER': 0,
    'MARMET': 0,
    'MARMIE': 0,
    'MARMINO': 0,
    'MARMION': 0,
    'MARMO': 0,
    'MARMOL': 0,
    'MARMOLEJO': 0,
    'MARMOLEJOS': 0,
    'MARMON': 0,
    'MARMOR': 0,
    'MARMORA': 0,
    'MARMORSTEIN': 0,
    'MARN': 0,
    'MARNA': 1,
    'MARNACH': 0,
    'MARNELL': 0,
    'MARNER': 0,
    'MARNEY': 0,
    'MARNI': 1,
    'MARNIE': 1,
    'MARNIK': 0,
    'MARNIN': 0,
    'MARNOCHA': 0,
    'MARNON': 0,
    'MARO': 0,
    'MAROCCO': 0,
    'MAROGI': 0,
    'MAROHL': 0,
    'MAROHN': 0,
    'MAROHNIC': 0,
    'MAROIS': 0,
    'MAROK': 0,
    'MAROLA': 0,
    'MAROLD': 0,
    'MAROLDA': 0,
    'MAROLF': 0,
    'MAROLLA': 0,
    'MAROLT': 0,
    'MAROM': 0,
    'MARON': 0,
    'MARONA': 0,
    'MARONDE': 0,
    'MARONE': 0,
    'MARONEY': 0,
    'MARONGE': 0,
    'MARONI': 0,
    'MARONSKI': 0,
    'MAROON': 0,
    'MAROQUIN': 0,
    'MAROS': 0,
    'MAROSE': 0,
    'MAROSI': 0,
    'MAROSTICA': 0,
    'MAROSY': 0,
    'MAROSZEK': 0,
    'MAROT': 0,
    'MAROTO': 0,
    'MAROTTA': 0,
    'MAROTTE': 0,
    'MAROTTI': 0,
    'MAROTTO': 0,
    'MAROTZ': 0,
    'MAROUDAS': 0,
    'MAROUF': 0,
    'MAROULIS': 0,
    'MAROUN': 0,
    'MAROUS': 0,
    'MAROUSEK': 0,
    'MAROVICH': 0,
    'MAROWITZ': 0,
    'MAROWSKI': 0,
    'MAROZAS': 0,
    'MAROZZI': 0,
    'MARPLE': 0,
    'MARPLES': 0,
    'MARQUA': 0,
    'MARQUAND': 0,
    'MARQUARD': 0,
    'MARQUARDT': 0,
    'MARQUART': 0,
    'MARQUE': 0,
    'MARQUERITE': 1,
    'MARQUES': 0,
    'MARQUESS': 0,
    'MARQUET': 0,
    'MARQUETTA': 1,
    'MARQUETTE': 0,
    'MARQUEZ': 0,
    'MARQUINA': 0,
    'MARQUIS': 0.6571741511500548,
    'MARQUISS': 0,
    'MARQUITA': 1,
    'MARQUITTA': 1,
    'MARR': 0,
    'MARRA': 0,
    'MARRACCINI': 0,
    'MARRACINO': 0,
    'MARRAFFA': 0,
    'MARRAH': 0,
    'MARRALE': 0,
    'MARRAMA': 0,
    'MARRAN': 0,
    'MARRANCA': 0,
    'MARRANO': 0,
    'MARRAPESE': 0,
    'MARRAPODI': 0,
    'MARRARA': 0,
    'MARRAS': 0,
    'MARRAZZO': 0,
    'MARRE': 0,
    'MARRELL': 0,
    'MARRELLA': 0,
    'MARRELLI': 0,
    'MARRELLO': 0,
    'MARREN': 0,
    'MARRERO': 0,
    'MARRESE': 0,
    'MARRET': 0,
    'MARRETT': 0,
    'MARRETTA': 0,
    'MARRI': 0,
    'MARRIA': 0,
    'MARRIAGE': 0,
    'MARRIE': 0,
    'MARRIER': 0,
    'MARRIETTA': 0,
    'MARRIN': 0,
    'MARRINAN': 0,
    'MARRINER': 0,
    'MARRION': 0,
    'MARRIOT': 0,
    'MARRIOTT': 0,
    'MARRIS': 0,
    'MARRISON': 0,
    'MARRITT': 0,
    'MARRO': 0,
    'MARROCCO': 0,
    'MARROGUIN': 0,
    'MARRON': 0,
    'MARRONE': 0,
    'MARRONI': 0,
    'MARROQUIN': 0,
    'MARROTT': 0,
    'MARROTTE': 0,
    'MARROW': 0,
    'MARRS': 0,
    'MARRUFFO': 0,
    'MARRUFO': 0,
    'MARRUGO': 0,
    'MARRUJO': 0,
    'MARRY': 0.9493670886075949,
    'MARS': 0,
    'MARSA': 0,
    'MARSAC': 0,
    'MARSACK': 0,
    'MARSAGLIA': 0,
    'MARSALA': 0,
    'MARSALEK': 0,
    'MARSALIS': 0,
    'MARSAN': 0,
    'MARSANO': 0,
    'MARSAW': 0,
    'MARSCH': 0,
    'MARSCHALL': 0,
    'MARSCHEL': 0,
    'MARSCHKE': 0,
    'MARSCHNER': 0,
    'MARSDEN': 0,
    'MARSE': 0,
    'MARSEE': 0,
    'MARSEGLIA': 0,
    'MARSEILLE': 0,
    'MARSEILLES': 0,
    'MARSELL': 0,
    'MARSELLA': 0,
    'MARSELLE': 0,
    'MARSENGILL': 0,
    'MARSEY': 0,
    'MARSH': 0,
    'MARSHA': 0.9984639016897081,
    'MARSHAK': 0,
    'MARSHALEK': 0,
    'MARSHALL': 0.4321894718644654,
    'MARSHBANKS': 0,
    'MARSHBURN': 0,
    'MARSHEL': 0,
    'MARSHELL': 0,
    'MARSHIK': 0,
    'MARSHMAN': 0,
    'MARSI': 0,
    'MARSICANO': 0,
    'MARSICEK': 0,
    'MARSICH': 0,
    'MARSICO': 0,
    'MARSIGLIA': 0,
    'MARSIGLIO': 0,
    'MARSIK': 0,
    'MARSILI': 0,
    'MARSILIO': 0,
    'MARSILLETT': 0,
    'MARSILLO': 0,
    'MARSING': 0,
    'MARSINGILL': 0,
    'MARSKE': 0,
    'MARSKI': 0,
    'MARSLAND': 0,
    'MARSMAN': 0,
    'MARSO': 0,
    'MARSOCCI': 0,
    'MARSOLAIS': 0,
    'MARSOLEK': 0,
    'MARSON': 0,
    'MARSTALL': 0,
    'MARSTALLER': 0,
    'MARSTELLAR': 0,
    'MARSTELLER': 0,
    'MARSTEN': 0,
    'MARSTERS': 0,
    'MARSTILLER': 0,
    'MARSTON': 0,
    'MARSYLA': 0,
    'MARSZAL': 0,
    'MARSZALEK': 0,
    'MARSZALKOWSKI': 0,
    'MARTA': 0.9859154929577465,
    'MARTAN': 0,
    'MARTARANO': 0,
    'MARTE': 0,
    'MARTEENY': 0,
    'MARTEK': 0,
    'MARTEL': 0,
    'MARTELL': 0,
    'MARTELLA': 0,
    'MARTELLARO': 0,
    'MARTELLE': 0,
    'MARTELLI': 0,
    'MARTELLO': 0,
    'MARTELLUCCI': 0,
    'MARTELLY': 0,
    'MARTELO': 0,
    'MARTEN': 0,
    'MARTENEY': 0,
    'MARTENIZ': 0,
    'MARTENS': 0,
    'MARTENSEN': 0,
    'MARTENSON': 0,
    'MARTENY': 0,
    'MARTER': 0,
    'MARTES': 0,
    'MARTEZ': 0,
    'MARTH': 0.6451612903225806,
    'MARTHA': 0.999442059044708,
    'MARTHALER': 0,
    'MARTHALLER': 0,
    'MARTHE': 0,
    'MARTHERS': 0,
    'MARTHEY': 0,
    'MARTI': 0.7285974499089253,
    'MARTIA': 0,
    'MARTIAL': 0,
    'MARTIAN': 0,
    'MARTICH': 0,
    'MARTICORENA': 0,
    'MARTIE': 0,
    'MARTIEN': 0,
    'MARTIEZ': 0,
    'MARTIG': 0,
    'MARTIGNETTI': 0,
    'MARTIGNONI': 0,
    'MARTIJA': 0,
    'MARTILLA': 0,
    'MARTILLO': 0,
    'MARTIN': 0.4664398656310846,
    'MARTINA': 0.9650180940892642,
    'MARTINAC': 0,
    'MARTINAGE': 0,
    'MARTINAK': 0,
    'MARTINAS': 0,
    'MARTINAT': 0,
    'MARTINAZ': 0,
    'MARTINCIC': 0,
    'MARTINDALE': 0,
    'MARTINDELCAMPO': 0,
    'MARTINDELL': 0,
    'MARTINDILL': 0,
    'MARTINE': 0.7712082262210798,
    'MARTINEAU': 0,
    'MARTINEC': 0,
    'MARTINECK': 0,
    'MARTINEK': 0,
    'MARTINEL': 0,
    'MARTINELL': 0,
    'MARTINELLI': 0,
    'MARTINELLO': 0,
    'MARTINER': 0,
    'MARTINES': 0,
    'MARTINET': 0,
    'MARTINETTI': 0,
    'MARTINEX': 0,
    'MARTINEZ': 0,
    'MARTINEZCRUZ': 0,
    'MARTINEZDIAZ': 0,
    'MARTINEZGARCIA': 0,
    'MARTINEZGOMEZ': 0,
    'MARTINEZGONZAL': 0,
    'MARTINEZHERNAN': 0,
    'MARTINEZLOPEZ': 0,
    'MARTINEZMARTIN': 0,
    'MARTINEZORTIZ': 0,
    'MARTINEZPEREZ': 0,
    'MARTINEZREYES': 0,
    'MARTINEZSANCHE': 0,
    'MARTINEZTORRES': 0,
    'MARTINHO': 0,
    'MARTINI': 0,
    'MARTINICH': 0,
    'MARTINICO': 0,
    'MARTINIE': 0,
    'MARTINIELLO': 0,
    'MARTINIS': 0,
    'MARTINIZ': 0,
    'MARTINKA': 0,
    'MARTINKO': 0,
    'MARTINKOVIC': 0,
    'MARTINKUS': 0,
    'MARTINMAAS': 0,
    'MARTINO': 0,
    'MARTINOLICH': 0,
    'MARTINON': 0,
    'MARTINOS': 0,
    'MARTINOV': 0,
    'MARTINOVIC': 0,
    'MARTINOVICH': 0,
    'MARTINS': 0,
    'MARTINSEN': 0,
    'MARTINSON': 0,
    'MARTINUCCI': 0,
    'MARTINUS': 0,
    'MARTINZ': 0,
    'MARTIR': 0,
    'MARTIRANO': 0,
    'MARTIRE': 0,
    'MARTIROSIAN': 0,
    'MARTIROSYAN': 0,
    'MARTIS': 0,
    'MARTIZ': 0,
    'MARTLEY': 0,
    'MARTLING': 0,
    'MARTNEZ': 0,
    'MARTO': 0,
    'MARTOCCHIO': 0,
    'MARTOCCI': 0,
    'MARTOCCIA': 0,
    'MARTOCCIO': 0,
    'MARTON': 0,
    'MARTONE': 0,
    'MARTONIK': 0,
    'MARTORANA': 0,
    'MARTORAND': 0,
    'MARTORANO': 0,
    'MARTORELL': 0,
    'MARTORELLA': 0,
    'MARTORELLI': 0,
    'MARTORELLO': 0,
    'MARTORI': 0,
    'MARTOS': 0,
    'MARTS': 0,
    'MARTSOLF': 0,
    'MARTSON': 0,
    'MARTTILA': 0,
    'MARTUCCI': 0,
    'MARTUCCIO': 0,
    'MARTURANO': 0,
    'MARTUS': 0,
    'MARTUSCELLI': 0,
    'MARTUSCELLO': 0,
    'MARTUSHEV': 0,
    'MARTWICK': 0,
    'MARTY': 0.941492938802959,
    'MARTYAK': 0,
    'MARTYKA': 0,
    'MARTYN': 0,
    'MARTYNENKO': 0,
    'MARTYNIAK': 0,
    'MARTYNIUK': 0,
    'MARTYNOWICZ': 0,
    'MARTYNYUK': 0,
    'MARTZ': 0,
    'MARTZAHL': 0,
    'MARTZALL': 0,
    'MARTZKE': 0,
    'MARU': 0,
    'MARUCA': 0,
    'MARUCCI': 0,
    'MARUCUT': 0,
    'MARUGG': 0,
    'MARULANDA': 0,
    'MARULLI': 0,
    'MARULLO': 0,
    'MARUM': 0,
    'MARUMOTO': 0,
    'MARUNA': 0,
    'MARUNGO': 0,
    'MARURE': 0,
    'MARURI': 0,
    'MARUS': 0,
    'MARUSA': 0,
    'MARUSAK': 0,
    'MARUSARZ': 0,
    'MARUSCHAK': 0,
    'MARUSIAK': 0,
    'MARUSIC': 0,
    'MARUSICH': 0,
    'MARUSKA': 0,
    'MARUSZAK': 0,
    'MARUSZEWSKI': 0,
    'MARUT': 0,
    'MARUYAMA': 0,
    'MARVA': 0.9960159362549801,
    'MARVAN': 0,
    'MARVEL': 0.7352941176470589,
    'MARVELL': 0,
    'MARVELLA': 1,
    'MARVELLI': 0,
    'MARVER': 0,
    'MARVICH': 0,
    'MARVIL': 0,
    'MARVILLE': 0,
    'MARVIN': 0.9779811266800115,
    'MARVIS': 1,
    'MARWAH': 0,
    'MARWAHA': 0,
    'MARWICK': 0,
    'MARWITZ': 0,
    'MARX': 0.22271714922049,
    'MARXEN': 0,
    'MARXER': 0,
    'MARY': 0.9164969450101833,
    'MARYA': 1,
    'MARYALICE': 1,
    'MARYAM': 1,
    'MARYAN': 0,
    'MARYANN': 1,
    'MARYANNA': 1,
    'MARYANNE': 1,
    'MARYANSKI': 0,
    'MARYBELLE': 1,
    'MARYBETH': 1,
    'MARYE': 0,
    'MARYELLEN': 1,
    'MARYETTA': 1,
    'MARYJANE': 1,
    'MARYJO': 1,
    'MARYLAND': 0.8474576271186441,
    'MARYLEE': 1,
    'MARYLIN': 1,
    'MARYLN': 1,
    'MARYLOU': 1,
    'MARYLOUISE': 1,
    'MARYLYN': 1,
    'MARYLYNN': 1,
    'MARYMEE': 0,
    'MARYNIAK': 0,
    'MARYNOWSKI': 0,
    'MARYON': 0,
    'MARYOTT': 0,
    'MARYROSE': 1,
    'MARZ': 0,
    'MARZAHL': 0,
    'MARZAN': 0,
    'MARZANO': 0,
    'MARZE': 0,
    'MARZEAN': 0,
    'MARZEC': 0,
    'MARZELLA': 0,
    'MARZEN': 0,
    'MARZETT': 0,
    'MARZETTA': 0,
    'MARZETTE': 0,
    'MARZETTI': 0,
    'MARZI': 0,
    'MARZIALE': 0,
    'MARZIANI': 0,
    'MARZIANO': 0,
    'MARZIGLIANO': 0,
    'MARZILIANO': 0,
    'MARZILLI': 0,
    'MARZKA': 0,
    'MARZO': 0,
    'MARZOCCA': 0,
    'MARZOCCHI': 0,
    'MARZOLA': 0,
    'MARZOLF': 0,
    'MARZORATI': 0,
    'MARZOUK': 0,
    'MARZULLI': 0,
    'MARZULLO': 0,
    'MAS': 0,
    'MASA': 0,
    'MASAD': 0,
    'MASADA': 0,
    'MASAITIS': 0,
    'MASAK': 0,
    'MASAKI': 0,
    'MASAKO': 1,
    'MASANGCAY': 0,
    'MASANGKAY': 0,
    'MASANIAI': 0,
    'MASANZ': 0,
    'MASAR': 0,
    'MASARIEGOS': 0,
    'MASARIK': 0,
    'MASBRUCH': 0,
    'MASCALI': 0,
    'MASCALL': 0,
    'MASCARA': 0,
    'MASCARDO': 0,
    'MASCARELLA': 0,
    'MASCARELLI': 0,
    'MASCARELLO': 0,
    'MASCARENA': 0,
    'MASCARENAS': 0,
    'MASCARENHAS': 0,
    'MASCARENO': 0,
    'MASCARI': 0,
    'MASCARINAS': 0,
    'MASCARO': 0,
    'MASCELLINO': 0,
    'MASCETTI': 0,
    'MASCH': 0,
    'MASCHAK': 0,
    'MASCHAL': 0,
    'MASCHE': 0,
    'MASCHEK': 0,
    'MASCHER': 0,
    'MASCHERI': 0,
    'MASCHHOFF': 0,
    'MASCHI': 0,
    'MASCHING': 0,
    'MASCHINO': 0,
    'MASCHINOT': 0,
    'MASCHIO': 0,
    'MASCHKA': 0,
    'MASCHKE': 0,
    'MASCHLER': 0,
    'MASCHMANN': 0,
    'MASCHMEIER': 0,
    'MASCHMEYER': 0,
    'MASCHO': 0,
    'MASCI': 0,
    'MASCIA': 0,
    'MASCIALE': 0,
    'MASCIANGELO': 0,
    'MASCIANTONIO': 0,
    'MASCIARELLI': 0,
    'MASCIO': 0,
    'MASCIOCCHI': 0,
    'MASCIOLA': 0,
    'MASCIOLI': 0,
    'MASCIOPINTO': 0,
    'MASCIS': 0,
    'MASCITELLI': 0,
    'MASCITTI': 0,
    'MASCIULLI': 0,
    'MASCO': 0,
    'MASCOE': 0,
    'MASCOLA': 0,
    'MASCOLD': 0,
    'MASCOLINO': 0,
    'MASCOLL': 0,
    'MASCOLO': 0,
    'MASCORRO': 0,
    'MASCOTE': 0,
    'MASDEN': 0,
    'MASDON': 0,
    'MASE': 0,
    'MASEDA': 0,
    'MASEK': 0,
    'MASEL': 0,
    'MASELLA': 0,
    'MASELLI': 0,
    'MASELLO': 0,
    'MASEN': 0,
    'MASENGALE': 0,
    'MASENGILL': 0,
    'MASENHEIMER': 0,
    'MASER': 0,
    'MASERANG': 0,
    'MASESSA': 0,
    'MASEY': 0,
    'MASFERRER': 0,
    'MASH': 0,
    'MASHA': 0,
    'MASHACK': 0,
    'MASHAK': 0,
    'MASHAL': 0,
    'MASHALL': 0,
    'MASHAW': 0,
    'MASHAYEKHI': 0,
    'MASHBURN': 0,
    'MASHEK': 0,
    'MASHER': 0,
    'MASHIA': 0,
    'MASHNI': 0,
    'MASHORE': 0,
    'MASHTARE': 0,
    'MASI': 0,
    'MASIA': 0,
    'MASIAK': 0,
    'MASIAS': 0,
    'MASIC': 0,
    'MASICA': 0,
    'MASICH': 0,
    'MASICK': 0,
    'MASIEL': 0,
    'MASIELLO': 0,
    'MASIERO': 0,
    'MASIH': 0,
    'MASIMORE': 0,
    'MASIN': 0,
    'MASINA': 0,
    'MASINELLI': 0,
    'MASINGALE': 0,
    'MASINGILL': 0,
    'MASINGO': 0,
    'MASINI': 0,
    'MASINO': 0,
    'MASINTER': 0,
    'MASIS': 0,
    'MASK': 0,
    'MASKA': 0,
    'MASKAL': 0,
    'MASKE': 0,
    'MASKEL': 0,
    'MASKELL': 0,
    'MASKER': 0,
    'MASKEW': 0,
    'MASKEY': 0,
    'MASKILL': 0,
    'MASKIN': 0,
    'MASKO': 0,
    'MASKREY': 0,
    'MASLACH': 0,
    'MASLAK': 0,
    'MASLAN': 0,
    'MASLAND': 0,
    'MASLANIK': 0,
    'MASLANKA': 0,
    'MASLAR': 0,
    'MASLEN': 0,
    'MASLER': 0,
    'MASLEY': 0,
    'MASLIN': 0,
    'MASLINE': 0,
    'MASLINSKI': 0,
    'MASLO': 0,
    'MASLONKA': 0,
    'MASLOSKI': 0,
    'MASLOV': 0,
    'MASLOW': 0,
    'MASLOWSKI': 0,
    'MASLOWSKY': 0,
    'MASLYK': 0,
    'MASLYN': 0,
    'MASNER': 0,
    'MASNICA': 0,
    'MASNY': 0,
    'MASO': 0,
    'MASON': 0.1723147616312464,
    'MASONE': 0,
    'MASONER': 0,
    'MASONHEIMER': 0,
    'MASONI': 0,
    'MASOOD': 0,
    'MASOPUST': 0,
    'MASOTTA': 0,
    'MASOTTI': 0,
    'MASOTTO': 0,
    'MASOUD': 0,
    'MASQUELIER': 0,
    'MASRI': 0,
    'MASS': 0,
    'MASSA': 0,
    'MASSACHI': 0,
    'MASSAD': 0,
    'MASSAGLI': 0,
    'MASSAGLIA': 0,
    'MASSALINE': 0,
    'MASSANELLI': 0,
    'MASSANET': 0,
    'MASSANOVA': 0,
    'MASSAQUOI': 0,
    'MASSAR': 0,
    'MASSARA': 0,
    'MASSARD': 0,
    'MASSARELLA': 0,
    'MASSARELLI': 0,
    'MASSARI': 0,
    'MASSARO': 0,
    'MASSARONI': 0,
    'MASSAROTTI': 0,
    'MASSART': 0,
    'MASSAS': 0,
    'MASSAY': 0,
    'MASSE': 0,
    'MASSEE': 0,
    'MASSEI': 0,
    'MASSEL': 0,
    'MASSELINK': 0,
    'MASSELL': 0,
    'MASSELLA': 0,
    'MASSELLI': 0,
    'MASSELLO': 0,
    'MASSEN': 0,
    'MASSENA': 0,
    'MASSENBERG': 0,
    'MASSENBURG': 0,
    'MASSENGALE': 0,
    'MASSENGILL': 0,
    'MASSER': 0,
    'MASSERANT': 0,
    'MASSERIA': 0,
    'MASSERY': 0,
    'MASSET': 0,
    'MASSETH': 0,
    'MASSETT': 0,
    'MASSETTI': 0,
    'MASSEY': 0,
    'MASSI': 0,
    'MASSIAH': 0,
    'MASSICK': 0,
    'MASSICOT': 0,
    'MASSICOTTE': 0,
    'MASSIE': 0,
    'MASSIER': 0,
    'MASSIH': 0,
    'MASSILLON': 0,
    'MASSIMI': 0,
    'MASSIMILLA': 0,
    'MASSIMINI': 0,
    'MASSIMINO': 0,
    'MASSIMO': 0,
    'MASSIN': 0,
    'MASSING': 0,
    'MASSINGALE': 0,
    'MASSINGHAM': 0,
    'MASSINGILL': 0,
    'MASSINI': 0,
    'MASSINO': 0,
    'MASSIS': 0,
    'MASSMAN': 0,
    'MASSMANN': 0,
    'MASSNER': 0,
    'MASSO': 0,
    'MASSOGLIA': 0,
    'MASSON': 0,
    'MASSONE': 0,
    'MASSONG': 0,
    'MASSONI': 0,
    'MASSOP': 0,
    'MASSOTH': 0,
    'MASSOUD': 0,
    'MASSOUDI': 0,
    'MASSRY': 0,
    'MASSUCCI': 0,
    'MASSUCCO': 0,
    'MASSUNG': 0,
    'MASSY': 0,
    'MAST': 0,
    'MASTA': 0,
    'MASTACHE': 0,
    'MASTALERZ': 0,
    'MASTALIR': 0,
    'MASTALSKI': 0,
    'MASTANDREA': 0,
    'MASTANTUONO': 0,
    'MASTBERGEN': 0,
    'MASTEJ': 0,
    'MASTEL': 0,
    'MASTELLER': 0,
    'MASTELLONE': 0,
    'MASTEN': 0,
    'MASTENBROOK': 0,
    'MASTER': 0,
    'MASTERJOHN': 0,
    'MASTERMAN': 0,
    'MASTERNAK': 0,
    'MASTERS': 0,
    'MASTERSON': 0,
    'MASTERTON': 0,
    'MASTEY': 0,
    'MASTICK': 0,
    'MASTIN': 0,
    'MASTNY': 0,
    'MASTO': 0,
    'MASTON': 0,
    'MASTORIS': 0,
    'MASTOWSKI': 0,
    'MASTRACCHIO': 0,
    'MASTRACCI': 0,
    'MASTRANDREA': 0,
    'MASTRANGELO': 0,
    'MASTRANTONIO': 0,
    'MASTRAPA': 0,
    'MASTRE': 0,
    'MASTRELLA': 0,
    'MASTRI': 0,
    'MASTRIA': 0,
    'MASTRIAN': 0,
    'MASTRIANI': 0,
    'MASTRIANNI': 0,
    'MASTRIANO': 0,
    'MASTRO': 0,
    'MASTROBATTISTA': 0,
    'MASTROBERTI': 0,
    'MASTROBUONO': 0,
    'MASTROCINQUE': 0,
    'MASTROCOLA': 0,
    'MASTRODDI': 0,
    'MASTRODOMENICO': 0,
    'MASTRODONATO': 0,
    'MASTROENI': 0,
    'MASTROGIACOMO': 0,
    'MASTROGIOVANNI': 0,
    'MASTROIANNI': 0,
    'MASTROLIA': 0,
    'MASTROMARINO': 0,
    'MASTROMATTEO': 0,
    'MASTROMONACO': 0,
    'MASTRONARDI': 0,
    'MASTRONI': 0,
    'MASTROPAOLO': 0,
    'MASTROPASQUA': 0,
    'MASTROPIERI': 0,
    'MASTROPIETRO': 0,
    'MASTROPOLO': 0,
    'MASTRORILLI': 0,
    'MASTROROCCO': 0,
    'MASTROS': 0,
    'MASTROSIMONE': 0,
    'MASTROSTEFANO': 0,
    'MASTROVITO': 0,
    'MASTRUD': 0,
    'MASTURZO': 0,
    'MASUCCI': 0,
    'MASUD': 0,
    'MASUDA': 0,
    'MASUGA': 0,
    'MASUI': 0,
    'MASUKAWA': 0,
    'MASULLO': 0,
    'MASUMOTO': 0,
    'MASUNAGA': 0,
    'MASUOKA': 0,
    'MASUR': 0,
    'MASURA': 0,
    'MASURE': 0,
    'MASZK': 0,
    'MAT': 0,
    'MATA': 0,
    'MATACZYNSKI': 0,
    'MATADAMAS': 0,
    'MATAELE': 0,
    'MATAGI': 0,
    'MATAL': 0,
    'MATALA': 0,
    'MATALAVAGE': 0,
    'MATALLANA': 0,
    'MATALON': 0,
    'MATALONE': 0,
    'MATAMOROS': 0,
    'MATAN': 0,
    'MATANANE': 0,
    'MATANO': 0,
    'MATAR': 0,
    'MATARAZZO': 0,
    'MATARESE': 0,
    'MATARRESE': 0,
    'MATAS': 0,
    'MATASSA': 0,
    'MATATALL': 0,
    'MATATOV': 0,
    'MATAU': 0,
    'MATAUTIA': 0,
    'MATAVA': 0,
    'MATAYA': 0,
    'MATAYOSHI': 0,
    'MATCEK': 0,
    'MATCH': 0,
    'MATCHAM': 0,
    'MATCHELL': 0,
    'MATCHEM': 0,
    'MATCHEN': 0,
    'MATCHETT': 0,
    'MATCHETTE': 0,
    'MATCHEY': 0,
    'MATCZAK': 0,
    'MATE': 0,
    'MATEAS': 0,
    'MATECKI': 0,
    'MATEEN': 0,
    'MATEER': 0,
    'MATEHUALA': 0,
    'MATEI': 0,
    'MATEJ': 0,
    'MATEJA': 0,
    'MATEJCEK': 0,
    'MATEJEK': 0,
    'MATEJKA': 0,
    'MATEL': 0,
    'MATELA': 0,
    'MATELSKI': 0,
    'MATEN': 0,
    'MATENAER': 0,
    'MATEO': 0,
    'MATEOS': 0,
    'MATER': 0,
    'MATERA': 0,
    'MATERAZZI': 0,
    'MATERI': 0,
    'MATERIA': 0,
    'MATERN': 0,
    'MATERNA': 0,
    'MATERNE': 0,
    'MATERNOWSKI': 0,
    'MATERO': 0,
    'MATES': 0,
    'MATESIC': 0,
    'MATESICH': 0,
    'MATESKI': 0,
    'MATEU': 0,
    'MATEUS': 0,
    'MATEVOSYAN': 0,
    'MATEY': 0,
    'MATEYKA': 0,
    'MATH': 0,
    'MATHA': 0.9259259259259258,
    'MATHAI': 0,
    'MATHARU': 0,
    'MATHAS': 0,
    'MATHE': 0,
    'MATHEIS': 0,
    'MATHELIER': 0,
    'MATHEN': 0,
    'MATHENA': 0,
    'MATHENEY': 0,
    'MATHENIA': 0,
    'MATHENY': 0,
    'MATHEOS': 0,
    'MATHER': 0,
    'MATHERLY': 0,
    'MATHERN': 0,
    'MATHERNE': 0,
    'MATHERS': 0,
    'MATHERSON': 0,
    'MATHES': 0,
    'MATHESIUS': 0,
    'MATHESON': 0,
    'MATHESS': 0,
    'MATHEU': 0,
    'MATHEUS': 0,
    'MATHEW': 0.9488510007412898,
    'MATHEWES': 0,
    'MATHEWS': 0,
    'MATHEWSON': 0,
    'MATHEY': 0,
    'MATHIA': 0,
    'MATHIAK': 0,
    'MATHIAS': 0,
    'MATHIASEN': 0,
    'MATHIASON': 0,
    'MATHIE': 0,
    'MATHIES': 0,
    'MATHIESEN': 0,
    'MATHIESON': 0,
    'MATHIEU': 0,
    'MATHIEW': 0,
    'MATHIEWS': 0,
    'MATHILDA': 1,
    'MATHILDE': 1,
    'MATHIOT': 0,
    'MATHIOWETZ': 0,
    'MATHIS': 0,
    'MATHISEN': 0,
    'MATHISON': 0,
    'MATHNA': 0,
    'MATHON': 0,
    'MATHOS': 0,
    'MATHRE': 0,
    'MATHSON': 0,
    'MATHUES': 0,
    'MATHUR': 0,
    'MATHURA': 0,
    'MATHURIN': 0,
    'MATHUS': 0,
    'MATHWIG': 0,
    'MATHY': 0,
    'MATHYS': 0,
    'MATI': 0,
    'MATIA': 0,
    'MATIAS': 0,
    'MATIC': 0,
    'MATICE': 0,
    'MATICH': 0,
    'MATICHAK': 0,
    'MATICS': 0,
    'MATIE': 0,
    'MATIENZO': 0,
    'MATIER': 0,
    'MATIJEVIC': 0,
    'MATIJEVICH': 0,
    'MATIKA': 0,
    'MATILDA': 1,
    'MATILDE': 1,
    'MATILE': 0,
    'MATILLA': 0,
    'MATIN': 0,
    'MATINA': 0,
    'MATIONG': 0,
    'MATIS': 0,
    'MATISE': 0,
    'MATISKO': 0,
    'MATISON': 0,
    'MATIZ': 0,
    'MATKIN': 0,
    'MATKINS': 0,
    'MATKO': 0,
    'MATKOVIC': 0,
    'MATKOVICH': 0,
    'MATKOWSKI': 0,
    'MATL': 0,
    'MATLA': 0,
    'MATLACK': 0,
    'MATLAGA': 0,
    'MATLAK': 0,
    'MATLEY': 0,
    'MATLI': 0,
    'MATLICK': 0,
    'MATLIN': 0,
    'MATLOCK': 0,
    'MATLOFF': 0,
    'MATLOSZ': 0,
    'MATLOW': 0,
    'MATNEY': 0,
    'MATO': 0,
    'MATOBA': 0,
    'MATOCHA': 0,
    'MATOLA': 0,
    'MATON': 0,
    'MATONE': 0,
    'MATONIS': 0,
    'MATONTI': 0,
    'MATOS': 0,
    'MATOSIAN': 0,
    'MATOSICH': 0,
    'MATOSKA': 0,
    'MATOSKY': 0,
    'MATOSSIAN': 0,
    'MATOTT': 0,
    'MATOUS': 0,
    'MATOUSEK': 0,
    'MATOVICH': 0,
    'MATOVINA': 0,
    'MATOY': 0,
    'MATOZZO': 0,
    'MATRANGA': 0,
    'MATRAS': 0,
    'MATRE': 0,
    'MATRICARDI': 0,
    'MATRIOUS': 0,
    'MATRISCIANO': 0,
    'MATRO': 0,
    'MATRONE': 0,
    'MATRONI': 0,
    'MATROS': 0,
    'MATSCH': 0,
    'MATSCHE': 0,
    'MATSCHKE': 0,
    'MATSEN': 0,
    'MATSEY': 0,
    'MATSIL': 0,
    'MATSINGER': 0,
    'MATSKO': 0,
    'MATSLER': 0,
    'MATSON': 0,
    'MATSU': 0,
    'MATSUBARA': 0,
    'MATSUDA': 0,
    'MATSUI': 0,
    'MATSUKAWA': 0,
    'MATSUKI': 0,
    'MATSUMOTO': 0,
    'MATSUMURA': 0,
    'MATSUNAGA': 0,
    'MATSUNAMI': 0,
    'MATSUNO': 0,
    'MATSUO': 0,
    'MATSUOKA': 0,
    'MATSUSHIMA': 0,
    'MATSUSHITA': 0,
    'MATSUURA': 0,
    'MATSUYAMA': 0,
    'MATSUZAKI': 0,
    'MATSUZAWA': 0,
    'MATT': 0.960323477381855,
    'MATTA': 0,
    'MATTAIR': 0,
    'MATTALIANO': 0,
    'MATTAN': 0,
    'MATTAR': 0,
    'MATTAS': 0,
    'MATTAUSCH': 0,
    'MATTAX': 0,
    'MATTE': 0,
    'MATTEA': 0,
    'MATTEAU': 0,
    'MATTEI': 0,
    'MATTEIS': 0,
    'MATTEK': 0,
    'MATTEL': 0,
    'MATTEN': 0,
    'MATTEO': 0,
    'MATTEOLI': 0,
    'MATTEONI': 0,
    'MATTER': 0,
    'MATTERA': 0,
    'MATTERI': 0,
    'MATTERN': 0,
    'MATTERO': 0,
    'MATTERS': 0,
    'MATTERSON': 0,
    'MATTES': 0,
    'MATTESON': 0,
    'MATTESSICH': 0,
    'MATTEUCCI': 0,
    'MATTEY': 0,
    'MATTFELD': 0,
    'MATTFIELD': 0,
    'MATTHAEI': 0,
    'MATTHAI': 0,
    'MATTHEES': 0,
    'MATTHEI': 0,
    'MATTHEIS': 0,
    'MATTHEISEN': 0,
    'MATTHES': 0,
    'MATTHESON': 0,
    'MATTHESS': 0,
    'MATTHEUS': 0,
    'MATTHEW': 0.9963713335349259,
    'MATTHEWS': 0,
    'MATTHEWSON': 0,
    'MATTHEY': 0,
    'MATTHIAS': 0,
    'MATTHIE': 0,
    'MATTHIES': 0,
    'MATTHIESEN': 0,
    'MATTHIESSEN': 0,
    'MATTHIEU': 0,
    'MATTHIS': 0,
    'MATTHYS': 0,
    'MATTI': 0,
    'MATTIA': 0,
    'MATTIACE': 0,
    'MATTIAS': 0,
    'MATTICE': 0,
    'MATTICK': 0,
    'MATTICKS': 0,
    'MATTIE': 0.9942310052780166,
    'MATTIELLO': 0,
    'MATTIES': 0,
    'MATTILA': 0,
    'MATTIMOE': 0,
    'MATTIMORE': 0,
    'MATTIN': 0,
    'MATTINA': 0,
    'MATTINGLEY': 0,
    'MATTINGLY': 0,
    'MATTINSON': 0,
    'MATTIO': 0,
    'MATTIODA': 0,
    'MATTIOLI': 0,
    'MATTIONI': 0,
    'MATTIS': 0,
    'MATTISON': 0,
    'MATTIVI': 0,
    'MATTIX': 0,
    'MATTKE': 0,
    'MATTLE': 0,
    'MATTLER': 0,
    'MATTLEY': 0,
    'MATTLIN': 0,
    'MATTLY': 0,
    'MATTMILLER': 0,
    'MATTNER': 0,
    'MATTO': 0,
    'MATTOCK': 0,
    'MATTOCKS': 0,
    'MATTON': 0,
    'MATTONE': 0,
    'MATTONI': 0,
    'MATTOON': 0,
    'MATTOS': 0,
    'MATTOX': 0,
    'MATTOZZI': 0,
    'MATTRESS': 0,
    'MATTS': 0,
    'MATTSEN': 0,
    'MATTSON': 0,
    'MATTSSON': 0,
    'MATTU': 0,
    'MATTUCCI': 0,
    'MATTURRO': 0,
    'MATTUS': 0,
    'MATTY': 0,
    'MATUCH': 0,
    'MATUK': 0,
    'MATUL': 0,
    'MATULA': 0,
    'MATULAITIS': 0,
    'MATULEVICH': 0,
    'MATULEWICZ': 0,
    'MATULICH': 0,
    'MATULIS': 0,
    'MATULKA': 0,
    'MATULLO': 0,
    'MATULONIS': 0,
    'MATURA': 0,
    'MATURANA': 0,
    'MATURE': 0,
    'MATUREN': 0,
    'MATURI': 0,
    'MATURIN': 0,
    'MATURINO': 0,
    'MATURO': 0,
    'MATUS': 0,
    'MATUSAK': 0,
    'MATUSEK': 0,
    'MATUSEVICH': 0,
    'MATUSIAK': 0,
    'MATUSIEWICZ': 0,
    'MATUSIK': 0,
    'MATUSKA': 0,
    'MATUSKO': 0,
    'MATUSKY': 0,
    'MATUSOW': 0,
    'MATUSZ': 0,
    'MATUSZAK': 0,
    'MATUSZCZAK': 0,
    'MATUSZEK': 0,
    'MATUSZEWSKI': 0,
    'MATUTE': 0,
    'MATUZ': 0,
    'MATUZA': 0,
    'MATUZAK': 0,
    'MATVEY': 0,
    'MATVEYEV': 0,
    'MATY': 0,
    'MATYAS': 0,
    'MATYE': 0,
    'MATYI': 0,
    'MATYJA': 0,
    'MATYJASIK': 0,
    'MATYKA': 0,
    'MATYKIEWICZ': 0,
    'MATYS': 0,
    'MATYSEK': 0,
    'MATYSIAK': 0,
    'MATYSIK': 0,
    'MATZ': 0,
    'MATZA': 0,
    'MATZAT': 0,
    'MATZDORF': 0,
    'MATZDORFF': 0,
    'MATZEK': 0,
    'MATZELLE': 0,
    'MATZEN': 0,
    'MATZENBACHER': 0,
    'MATZER': 0,
    'MATZINGER': 0,
    'MATZKE': 0,
    'MATZKIN': 0,
    'MATZKO': 0,
    'MATZNER': 0,
    'MATZNICK': 0,
    'MAU': 0,
    'MAUBACH': 0,
    'MAUCERI': 0,
    'MAUCH': 0,
    'MAUCHER': 0,
    'MAUCHLEY': 0,
    'MAUCIERI': 0,
    'MAUCK': 0,
    'MAUD': 0.992063492063492,
    'MAUDE': 0.9939498703543647,
    'MAUDER': 0,
    'MAUDIE': 1,
    'MAUDLIN': 0,
    'MAUDSLEY': 0,
    'MAUE': 0,
    'MAUEL': 0,
    'MAUER': 0,
    'MAUERMAN': 0,
    'MAUERMANN': 0,
    'MAUFFRAY': 0,
    'MAUGA': 0,
    'MAUGANS': 0,
    'MAUGE': 0,
    'MAUGER': 0,
    'MAUGERI': 0,
    'MAUGHAN': 0,
    'MAUGHMER': 0,
    'MAUGHN': 0,
    'MAUGHON': 0,
    'MAUK': 0,
    'MAUL': 0,
    'MAULDEN': 0,
    'MAULDIN': 0,
    'MAULDING': 0,
    'MAULE': 0,
    'MAULEON': 0,
    'MAULER': 0,
    'MAULFAIR': 0,
    'MAULHARDT': 0,
    'MAULIN': 0,
    'MAULL': 0,
    'MAULLER': 0,
    'MAULSBY': 0,
    'MAULT': 0,
    'MAULTSBY': 0,
    'MAULUCCI': 0,
    'MAUN': 0,
    'MAUND': 0,
    'MAUNDER': 0,
    'MAUNE': 0,
    'MAUNEY': 0,
    'MAUNG': 0,
    'MAUNSELL': 0,
    'MAUNTEL': 0,
    'MAUNU': 0,
    'MAUNZ': 0,
    'MAUPIN': 0,
    'MAUPINS': 0,
    'MAUR': 0,
    'MAURA': 0.9793253536452665,
    'MAURAIS': 0,
    'MAURAS': 0,
    'MAURATH': 0,
    'MAURE': 0,
    'MAUREEN': 1,
    'MAURELLO': 0,
    'MAUREN': 0,
    'MAURER': 0,
    'MAUREY': 0,
    'MAURI': 0,
    'MAURICE': 0.9868421052631577,
    'MAURICI': 0,
    'MAURICIO': 0.8865248226950355,
    'MAURIELLO': 0,
    'MAURIN': 0,
    'MAURINE': 1,
    'MAURINO': 0,
    'MAURITA': 1,
    'MAURITZ': 0,
    'MAURIZI': 0,
    'MAURIZIO': 0,
    'MAURO': 0.6435006435006435,
    'MAURSTAD': 0,
    'MAURUS': 0,
    'MAURY': 0,
    'MAUS': 0,
    'MAUSBACH': 0,
    'MAUSER': 0,
    'MAUSETH': 0,
    'MAUSNER': 0,
    'MAUSOLF': 0,
    'MAUSS': 0,
    'MAUSSER': 0,
    'MAUST': 0,
    'MAUSTELLER': 0,
    'MAUTE': 0,
    'MAUTER': 0,
    'MAUTERER': 0,
    'MAUTHE': 0,
    'MAUTINO': 0,
    'MAUTNER': 0,
    'MAUTONE': 0,
    'MAUTZ': 0,
    'MAUVAIS': 0,
    'MAUZEY': 0,
    'MAUZY': 0,
    'MAVAR': 0,
    'MAVASHEV': 0,
    'MAVEN': 0,
    'MAVENCAMP': 0,
    'MAVER': 0,
    'MAVERICK': 0,
    'MAVES': 0,
    'MAVILIA': 0,
    'MAVIN': 0,
    'MAVIS': 0.97442143727162,
    'MAVITY': 0,
    'MAVOR': 0,
    'MAVRAKIS': 0,
    'MAVRIDIS': 0,
    'MAVROMATIS': 0,
    'MAVROS': 0,
    'MAVROUDIS': 0,
    'MAW': 0,
    'MAWBY': 0,
    'MAWDSLEY': 0,
    'MAWER': 0,
    'MAWHINEY': 0,
    'MAWHINNEY': 0,
    'MAWHIRTER': 0,
    'MAWHORR': 0,
    'MAWHORTER': 0,
    'MAWN': 0,
    'MAWSON': 0,
    'MAWYER': 0,
    'MAX': 0.9816971713810315,
    'MAXA': 0,
    'MAXAM': 0,
    'MAXBERRY': 0,
    'MAXCEY': 0,
    'MAXCY': 0,
    'MAXEDON': 0,
    'MAXEINER': 0,
    'MAXELL': 0,
    'MAXEY': 0,
    'MAXFIELD': 0,
    'MAXHAM': 0,
    'MAXHEIMER': 0,
    'MAXHIMER': 0,
    'MAXI': 0,
    'MAXIAN': 0,
    'MAXIE': 0.7984031936127745,
    'MAXIM': 0,
    'MAXIMA': 1,
    'MAXIME': 0,
    'MAXIMINA': 1,
    'MAXIMO': 0.9541984732824428,
    'MAXIMOV': 0,
    'MAXIMOVICH': 0,
    'MAXIN': 0,
    'MAXINE': 1,
    'MAXION': 0,
    'MAXNER': 0,
    'MAXON': 0,
    'MAXSON': 0,
    'MAXTED': 0,
    'MAXTON': 0,
    'MAXWELL': 0.29086678301337987,
    'MAY': 0.4347174336681157,
    'MAYA': 0.6912442396313364,
    'MAYABB': 0,
    'MAYALL': 0,
    'MAYAN': 0,
    'MAYANS': 0,
    'MAYAR': 0,
    'MAYARD': 0,
    'MAYAS': 0,
    'MAYBACH': 0,
    'MAYBANK': 0,
    'MAYBAUM': 0,
    'MAYBE': 0,
    'MAYBEE': 0,
    'MAYBELL': 0.9708737864077669,
    'MAYBELLE': 1,
    'MAYBEN': 0,
    'MAYBERRY': 0,
    'MAYBIN': 0,
    'MAYBON': 0,
    'MAYBRIER': 0,
    'MAYBURY': 0,
    'MAYBUSH': 0,
    'MAYCOCK': 0,
    'MAYCROFT': 0,
    'MAYCUMBER': 0,
    'MAYDAK': 0,
    'MAYDEN': 0,
    'MAYDEW': 0,
    'MAYDOLE': 0,
    'MAYDON': 0,
    'MAYDRAL': 0,
    'MAYDWELL': 0,
    'MAYE': 0.5730659025787966,
    'MAYEA': 0,
    'MAYEAUX': 0,
    'MAYEDA': 0,
    'MAYEN': 0,
    'MAYENSCHEIN': 0,
    'MAYER': 0,
    'MAYERCHAK': 0,
    'MAYERHOFER': 0,
    'MAYERLE': 0,
    'MAYERNICK': 0,
    'MAYERNIK': 0,
    'MAYERS': 0,
    'MAYERSKY': 0,
    'MAYERSON': 0,
    'MAYES': 0,
    'MAYESKI': 0,
    'MAYET': 0,
    'MAYETTE': 0,
    'MAYEUR': 0,
    'MAYEUX': 0,
    'MAYEWSKI': 0,
    'MAYFEILD': 0,
    'MAYFIELD': 0,
    'MAYFORTH': 0,
    'MAYHALL': 0,
    'MAYHAN': 0,
    'MAYHAND': 0,
    'MAYHER': 0,
    'MAYHEW': 0,
    'MAYHILL': 0,
    'MAYHLE': 0,
    'MAYHOOD': 0,
    'MAYHORN': 0,
    'MAYHUE': 0,
    'MAYHUGH': 0,
    'MAYI': 0,
    'MAYKUT': 0,
    'MAYLAND': 0,
    'MAYLATH': 0,
    'MAYLE': 0,
    'MAYLEE': 0,
    'MAYLEN': 0,
    'MAYLES': 0,
    'MAYLIN': 0,
    'MAYLONE': 0,
    'MAYLOR': 0,
    'MAYME': 1,
    'MAYMI': 0,
    'MAYMON': 0,
    'MAYNARD': 0.4308487720809996,
    'MAYNE': 0,
    'MAYNER': 0,
    'MAYNES': 0,
    'MAYNEZ': 0,
    'MAYNOR': 0,
    'MAYNORD': 0,
    'MAYO': 0,
    'MAYOCK': 0,
    'MAYOL': 0,
    'MAYOLA': 1,
    'MAYON': 0,
    'MAYONE': 0,
    'MAYOR': 0,
    'MAYORA': 0,
    'MAYORAL': 0,
    'MAYORGA': 0,
    'MAYOROS': 0,
    'MAYORQUIN': 0,
    'MAYOTT': 0,
    'MAYOTTE': 0,
    'MAYOU': 0,
    'MAYR': 0,
    'MAYRA': 1,
    'MAYRAND': 0,
    'MAYRANT': 0,
    'MAYRONNE': 0,
    'MAYROSE': 0,
    'MAYS': 0,
    'MAYSE': 0,
    'MAYSHACK': 0,
    'MAYSON': 0,
    'MAYSONET': 0,
    'MAYTA': 0,
    'MAYTON': 0,
    'MAYTORENA': 0,
    'MAYTUBBY': 0,
    'MAYTUM': 0,
    'MAYUGA': 0,
    'MAYVILLE': 0,
    'MAYWALD': 0,
    'MAYWEATHER': 0,
    'MAYWELL': 0,
    'MAYWOOD': 0,
    'MAYWORM': 0,
    'MAYZE': 0,
    'MAYZEL': 0,
    'MAZ': 0,
    'MAZA': 0,
    'MAZAC': 0,
    'MAZAHERI': 0,
    'MAZAIKA': 0,
    'MAZAK': 0,
    'MAZAL': 0,
    'MAZALEWSKI': 0,
    'MAZAN': 0,
    'MAZANEC': 0,
    'MAZANEK': 0,
    'MAZANY': 0,
    'MAZAR': 0,
    'MAZARA': 0,
    'MAZARI': 0,
    'MAZARIEGO': 0,
    'MAZARIEGOS': 0,
    'MAZAS': 0,
    'MAZE': 0,
    'MAZEIKA': 0,
    'MAZEL': 0,
    'MAZELIN': 0,
    'MAZELLA': 0,
    'MAZEN': 0,
    'MAZENKO': 0,
    'MAZEPA': 0,
    'MAZER': 0,
    'MAZEROLLE': 0,
    'MAZEY': 0,
    'MAZGAJ': 0,
    'MAZHAR': 0,
    'MAZIAR': 0,
    'MAZIARKA': 0,
    'MAZIARZ': 0,
    'MAZICH': 0,
    'MAZIE': 0.970873786407767,
    'MAZIK': 0,
    'MAZIN': 0,
    'MAZINGO': 0,
    'MAZION': 0,
    'MAZIQUE': 0,
    'MAZLOOM': 0,
    'MAZMANIAN': 0,
    'MAZO': 0,
    'MAZOCH': 0,
    'MAZOLA': 0,
    'MAZON': 0,
    'MAZONE': 0,
    'MAZOR': 0,
    'MAZORRA': 0,
    'MAZOUR': 0,
    'MAZUCA': 0,
    'MAZUERA': 0,
    'MAZUMDAR': 0,
    'MAZUMDER': 0,
    'MAZUR': 0,
    'MAZURA': 0,
    'MAZURAK': 0,
    'MAZURE': 0,
    'MAZUREK': 0,
    'MAZURIK': 0,
    'MAZURKIEWICZ': 0,
    'MAZUROWSKI': 0,
    'MAZY': 0,
    'MAZYCK': 0,
    'MAZZA': 0,
    'MAZZACANE': 0,
    'MAZZACANO': 0,
    'MAZZAFERRO': 0,
    'MAZZAGATTI': 0,
    'MAZZAGLIA': 0,
    'MAZZAMUTO': 0,
    'MAZZANTI': 0,
    'MAZZARA': 0,
    'MAZZARELLA': 0,
    'MAZZARELLI': 0,
    'MAZZARESE': 0,
    'MAZZARIELLO': 0,
    'MAZZARINI': 0,
    'MAZZARINO': 0,
    'MAZZARISI': 0,
    'MAZZARO': 0,
    'MAZZEI': 0,
    'MAZZELLA': 0,
    'MAZZENGA': 0,
    'MAZZEO': 0,
    'MAZZETTA': 0,
    'MAZZETTI': 0,
    'MAZZI': 0,
    'MAZZIE': 0,
    'MAZZILLI': 0,
    'MAZZINI': 0,
    'MAZZIO': 0,
    'MAZZIOTTA': 0,
    'MAZZIOTTI': 0,
    'MAZZITELLI': 0,
    'MAZZO': 0,
    'MAZZOCCA': 0,
    'MAZZOCCHI': 0,
    'MAZZOCCO': 0,
    'MAZZOCCOLI': 0,
    'MAZZOCHI': 0,
    'MAZZOLA': 0,
    'MAZZOLENI': 0,
    'MAZZOLI': 0,
    'MAZZOLINI': 0,
    'MAZZONE': 0,
    'MAZZONI': 0,
    'MAZZOTTA': 0,
    'MAZZOTTI': 0,
    'MAZZU': 0,
    'MAZZUCA': 0,
    'MAZZUCCA': 0,
    'MAZZUCCO': 0,
    'MAZZUCHELLI': 0,
    'MAZZULLA': 0,
    'MAZZULLO': 0,
    'MAZZURCO': 0,
    'MBA': 0,
    'MBAH': 0,
    'MBAYE': 0,
    'MBUGUA': 0,
    'MBURU': 0,
    'MCABE': 0,
    'MCABEE': 0,
    'MCABOY': 0,
    'MCADA': 0,
    'MCADAM': 0,
    'MCADAMS': 0,
    'MCADEN': 0,
    'MCADOO': 0,
    'MCADORY': 0,
    'MCADOW': 0,
    'MCAFEE': 0,
    'MCAFERTY': 0,
    'MCAFFEE': 0,
    'MCAFFREY': 0,
    'MCAFOOS': 0,
    'MCAFOOSE': 0,
    'MCAHREN': 0,
    'MCALARNEY': 0,
    'MCALARY': 0,
    'MCALEAR': 0,
    'MCALEAVEY': 0,
    'MCALEE': 0,
    'MCALEENAN': 0,
    'MCALEER': 0,
    'MCALEESE': 0,
    'MCALESTER': 0,
    'MCALEVEY': 0,
    'MCALEVY': 0,
    'MCALEXANDER': 0,
    'MCALHANEY': 0,
    'MCALHANY': 0,
    'MCALILEY': 0,
    'MCALINDEN': 0,
    'MCALISTER': 0,
    'MCALL': 0,
    'MCALLAN': 0,
    'MCALLASTER': 0,
    'MCALLEN': 0,
    'MCALLESTER': 0,
    'MCALLISTER': 0,
    'MCALONAN': 0,
    'MCALONEY': 0,
    'MCALOON': 0,
    'MCALPIN': 0,
    'MCALPINE': 0,
    'MCALVAIN': 0,
    'MCALVEY': 0,
    'MCAMIS': 0,
    'MCANALLEN': 0,
    'MCANALLEY': 0,
    'MCANALLY': 0,
    'MCANANEY': 0,
    'MCANANY': 0,
    'MCANARNEY': 0,
    'MCANDREW': 0,
    'MCANDREWS': 0,
    'MCANEAR': 0,
    'MCANELLY': 0,
    'MCANENEY': 0,
    'MCANENY': 0,
    'MCANGUS': 0,
    'MCANINCH': 0,
    'MCANLIS': 0,
    'MCANLY': 0,
    'MCANN': 0,
    'MCANNALLY': 0,
    'MCANUFF': 0,
    'MCANULTY': 0,
    'MCARDELL': 0,
    'MCARDLE': 0,
    'MCAREE': 0,
    'MCARN': 0,
    'MCAROY': 0,
    'MCARTER': 0,
    'MCARTHUR': 0,
    'MCARTHY': 0,
    'MCARTOR': 0,
    'MCARTY': 0,
    'MCARVER': 0,
    'MCASKILL': 0,
    'MCATAMNEY': 0,
    'MCATEE': 0,
    'MCATEER': 0,
    'MCAULAY': 0,
    'MCAULEY': 0,
    'MCAULIFF': 0,
    'MCAULIFFE': 0,
    'MCAULY': 0,
    'MCAUSLAND': 0,
    'MCAVEY': 0,
    'MCAVOY': 0,
    'MCBAIN': 0,
    'MCBANE': 0,
    'MCBARRON': 0,
    'MCBATH': 0,
    'MCBAY': 0,
    'MCBEAN': 0,
    'MCBEATH': 0,
    'MCBEE': 0,
    'MCBETH': 0,
    'MCBIRNEY': 0,
    'MCBRADY': 0,
    'MCBRATNEY': 0,
    'MCBRAYER': 0,
    'MCBREAIRTY': 0,
    'MCBREARTY': 0,
    'MCBREEN': 0,
    'MCBRIAN': 0,
    'MCBRIDE': 0,
    'MCBRIEN': 0,
    'MCBRINE': 0,
    'MCBROOM': 0,
    'MCBROOME': 0,
    'MCBRYAN': 0,
    'MCBRYANT': 0,
    'MCBRYAR': 0,
    'MCBRYDE': 0,
    'MCBURNETT': 0,
    'MCBURNEY': 0,
    'MCBURNIE': 0,
    'MCBURROWS': 0,
    'MCCAA': 0,
    'MCCABE': 0,
    'MCCACHREN': 0,
    'MCCADDEN': 0,
    'MCCADDON': 0,
    'MCCADE': 0,
    'MCCADEN': 0,
    'MCCADNEY': 0,
    'MCCAFFERTY': 0,
    'MCCAFFERY': 0,
    'MCCAFFETY': 0,
    'MCCAFFITY': 0,
    'MCCAFFREE': 0,
    'MCCAFFREY': 0,
    'MCCAGE': 0,
    'MCCAGG': 0,
    'MCCAGHREN': 0,
    'MCCAGUE': 0,
    'MCCAHAN': 0,
    'MCCAHEY': 0,
    'MCCAHILL': 0,
    'MCCAHON': 0,
    'MCCAIG': 0,
    'MCCAII': 0,
    'MCCAIN': 0,
    'MCCAINE': 0,
    'MCCALE': 0,
    'MCCALEB': 0,
    'MCCALEBB': 0,
    'MCCALIB': 0,
    'MCCALIP': 0,
    'MCCALISTER': 0,
    'MCCALL': 0,
    'MCCALLA': 0,
    'MCCALLAN': 0,
    'MCCALLEN': 0,
    'MCCALLEY': 0,
    'MCCALLIE': 0,
    'MCCALLIN': 0,
    'MCCALLION': 0,
    'MCCALLISTER': 0,
    'MCCALLON': 0,
    'MCCALLOP': 0,
    'MCCALLOUGH': 0,
    'MCCALLSON': 0,
    'MCCALLUM': 0,
    'MCCALLY': 0,
    'MCCALMAN': 0,
    'MCCALMANT': 0,
    'MCCALMON': 0,
    'MCCALMONT': 0,
    'MCCALOP': 0,
    'MCCALPIN': 0,
    'MCCALPINE': 0,
    'MCCALVIN': 0,
    'MCCAMAN': 0,
    'MCCAMANT': 0,
    'MCCAMBRIDGE': 0,
    'MCCAMENT': 0,
    'MCCAMERON': 0,
    'MCCAMEY': 0,
    'MCCAMISH': 0,
    'MCCAMLEY': 0,
    'MCCAMMACK': 0,
    'MCCAMMAN': 0,
    'MCCAMMANT': 0,
    'MCCAMMON': 0,
    'MCCAMMOND': 0,
    'MCCAMON': 0,
    'MCCAMPBELL': 0,
    'MCCAMY': 0,
    'MCCAN': 0,
    'MCCANCE': 0,
    'MCCANDIES': 0,
    'MCCANDLESS': 0,
    'MCCANDLISH': 0,
    'MCCANE': 0,
    'MCCANLESS': 0,
    'MCCANN': 0,
    'MCCANNA': 0,
    'MCCANNE': 0,
    'MCCANNEY': 0,
    'MCCANNON': 0,
    'MCCANS': 0,
    'MCCANT': 0,
    'MCCANTS': 0,
    'MCCARD': 0,
    'MCCARDEL': 0,
    'MCCARDELL': 0,
    'MCCARDLE': 0,
    'MCCAREY': 0,
    'MCCARGAR': 0,
    'MCCARGO': 0,
    'MCCARL': 0,
    'MCCARLEY': 0,
    'MCCARN': 0,
    'MCCARNEY': 0,
    'MCCARR': 0,
    'MCCARRA': 0,
    'MCCARRAGHER': 0,
    'MCCARRAHER': 0,
    'MCCARREL': 0,
    'MCCARRELL': 0,
    'MCCARREN': 0,
    'MCCARREY': 0,
    'MCCARRICK': 0,
    'MCCARRIER': 0,
    'MCCARROLL': 0,
    'MCCARRON': 0,
    'MCCARRY': 0,
    'MCCARSON': 0,
    'MCCART': 0,
    'MCCARTAN': 0,
    'MCCARTEN': 0,
    'MCCARTER': 0,
    'MCCARTEY': 0,
    'MCCARTHA': 0,
    'MCCARTHER': 0,
    'MCCARTHEY': 0,
    'MCCARTHUR': 0,
    'MCCARTHY': 0,
    'MCCARTIN': 0,
    'MCCARTNEY': 0,
    'MCCARTT': 0,
    'MCCARTY': 0,
    'MCCARVER': 0,
    'MCCARVILL': 0,
    'MCCARVILLE': 0,
    'MCCARY': 0,
    'MCCASH': 0,
    'MCCASHLAND': 0,
    'MCCASKELL': 0,
    'MCCASKEY': 0,
    'MCCASKIE': 0,
    'MCCASKILL': 0,
    'MCCASLAND': 0,
    'MCCASLIN': 0,
    'MCCASTER': 0,
    'MCCASTLE': 0,
    'MCCATHERN': 0,
    'MCCATHRAN': 0,
    'MCCATTY': 0,
    'MCCAUGHAN': 0,
    'MCCAUGHEY': 0,
    'MCCAUGHIN': 0,
    'MCCAUGHTRY': 0,
    'MCCAUL': 0,
    'MCCAULEY': 0,
    'MCCAULIFF': 0,
    'MCCAULLA': 0,
    'MCCAULLEY': 0,
    'MCCAULLY': 0,
    'MCCAUSLAND': 0,
    'MCCAUSLIN': 0,
    'MCCAVE': 0,
    'MCCAVITT': 0,
    'MCCAW': 0,
    'MCCAWLEY': 0,
    'MCCAY': 0,
    'MCCELLAN': 0,
    'MCCELLAND': 0,
    'MCCHAREN': 0,
    'MCCHARGUE': 0,
    'MCCHESNEY': 0,
    'MCCHRISTIAN': 0,
    'MCCHRISTON': 0,
    'MCCHRISTY': 0,
    'MCCHRYSTAL': 0,
    'MCCIAIN': 0,
    'MCCIURE': 0,
    'MCCLADDIE': 0,
    'MCCLAFFERTY': 0,
    'MCCLAFLIN': 0,
    'MCCLAIN': 0,
    'MCCLAINE': 0,
    'MCCLAIR': 0,
    'MCCLAM': 0,
    'MCCLAMB': 0,
    'MCCLAMMA': 0,
    'MCCLAMMY': 0,
    'MCCLAMROCH': 0,
    'MCCLAMROCK': 0,
    'MCCLANAHAN': 0,
    'MCCLANATHAN': 0,
    'MCCLANE': 0,
    'MCCLANEY': 0,
    'MCCLANHAN': 0,
    'MCCLANNAHAN': 0,
    'MCCLARAN': 0,
    'MCCLARD': 0,
    'MCCLARE': 0,
    'MCCLAREN': 0,
    'MCCLAREY': 0,
    'MCCLARIN': 0,
    'MCCLARITY': 0,
    'MCCLARNEY': 0,
    'MCCLARNON': 0,
    'MCCLARREN': 0,
    'MCCLARTY': 0,
    'MCCLARY': 0,
    'MCCLASKEY': 0,
    'MCCLASKIE': 0,
    'MCCLATCHEY': 0,
    'MCCLATCHIE': 0,
    'MCCLATCHY': 0,
    'MCCLAUGHERTY': 0,
    'MCCLAUGHRY': 0,
    'MCCLAURIN': 0,
    'MCCLAVE': 0,
    'MCCLAY': 0,
    'MCCLEAD': 0,
    'MCCLEAF': 0,
    'MCCLEAN': 0,
    'MCCLEAR': 0,
    'MCCLEAREN': 0,
    'MCCLEARN': 0,
    'MCCLEARY': 0,
    'MCCLEASE': 0,
    'MCCLEAVE': 0,
    'MCCLEEREY': 0,
    'MCCLEERY': 0,
    'MCCLEES': 0,
    'MCCLEESE': 0,
    'MCCLELAND': 0,
    'MCCLELLAN': 0,
    'MCCLELLAND': 0,
    'MCCLELLEN': 0,
    'MCCLELLON': 0,
    'MCCLEMENS': 0,
    'MCCLEMENT': 0,
    'MCCLEMENTS': 0,
    'MCCLENAGHAN': 0,
    'MCCLENAHAN': 0,
    'MCCLENAN': 0,
    'MCCLENATHAN': 0,
    'MCCLENDON': 0,
    'MCCLENEY': 0,
    'MCCLENITHAN': 0,
    'MCCLENNAN': 0,
    'MCCLENNEN': 0,
    'MCCLENNEY': 0,
    'MCCLENNING': 0,
    'MCCLENNON': 0,
    'MCCLENNY': 0,
    'MCCLENON': 0,
    'MCCLENTON': 0,
    'MCCLEOD': 0,
    'MCCLERKIN': 0,
    'MCCLERNAN': 0,
    'MCCLERNON': 0,
    'MCCLERREN': 0,
    'MCCLESKEY': 0,
    'MCCLESTER': 0,
    'MCCLEVE': 0,
    'MCCLIMANS': 0,
    'MCCLIMENT': 0,
    'MCCLIMON': 0,
    'MCCLINCY': 0,
    'MCCLINE': 0,
    'MCCLINSEY': 0,
    'MCCLINTIC': 0,
    'MCCLINTICK': 0,
    'MCCLINTOCK': 0,
    'MCCLINTON': 0,
    'MCCLISH': 0,
    'MCCLISTER': 0,
    'MCCLOE': 0,
    'MCCLONE': 0,
    'MCCLOREY': 0,
    'MCCLORY': 0,
    'MCCLOSKEY': 0,
    'MCCLOSKY': 0,
    'MCCLOUD': 0,
    'MCCLOUGH': 0,
    'MCCLOUGHAN': 0,
    'MCCLOW': 0,
    'MCCLOY': 0,
    'MCCLUE': 0,
    'MCCLUER': 0,
    'MCCLUGGAGE': 0,
    'MCCLUNE': 0,
    'MCCLUNEY': 0,
    'MCCLUNG': 0,
    'MCCLURE': 0,
    'MCCLURG': 0,
    'MCCLURKAN': 0,
    'MCCLURKEN': 0,
    'MCCLURKIN': 0,
    'MCCLUSKEY': 0,
    'MCCLUSKIE': 0,
    'MCCLUSKY': 0,
    'MCCLUSTER': 0,
    'MCCLYMONDS': 0,
    'MCCLYMONT': 0,
    'MCCOACH': 0,
    'MCCOARD': 0,
    'MCCOART': 0,
    'MCCOBB': 0,
    'MCCOGGLE': 0,
    'MCCOID': 0,
    'MCCOIG': 0,
    'MCCOIN': 0,
    'MCCOLE': 0,
    'MCCOLGAN': 0,
    'MCCOLGIN': 0,
    'MCCOLL': 0,
    'MCCOLLAM': 0,
    'MCCOLLAUM': 0,
    'MCCOLLEM': 0,
    'MCCOLLEY': 0,
    'MCCOLLIGAN': 0,
    'MCCOLLIM': 0,
    'MCCOLLIN': 0,
    'MCCOLLINS': 0,
    'MCCOLLISTER': 0,
    'MCCOLLOCH': 0,
    'MCCOLLOM': 0,
    'MCCOLLOR': 0,
    'MCCOLLOUGH': 0,
    'MCCOLLUM': 0,
    'MCCOLLY': 0,
    'MCCOLM': 0,
    'MCCOLPIN': 0,
    'MCCOMACK': 0,
    'MCCOMAS': 0,
    'MCCOMB': 0,
    'MCCOMBE': 0,
    'MCCOMBER': 0,
    'MCCOMBIE': 0,
    'MCCOMBS': 0,
    'MCCOMIC': 0,
    'MCCOMIS': 0,
    'MCCOMISH': 0,
    'MCCOMISKEY': 0,
    'MCCOMMAS': 0,
    'MCCOMMON': 0,
    'MCCOMMONS': 0,
    'MCCOMSEY': 0,
    'MCCON': 0,
    'MCCONACHIE': 0,
    'MCCONAGHIE': 0,
    'MCCONAGHY': 0,
    'MCCONAHA': 0,
    'MCCONAHAY': 0,
    'MCCONAHY': 0,
    'MCCONATHY': 0,
    'MCCONAUGHEY': 0,
    'MCCONAUGHY': 0,
    'MCCONCHIE': 0,
    'MCCONE': 0,
    'MCCONEGHY': 0,
    'MCCONELL': 0,
    'MCCONICO': 0,
    'MCCONKEY': 0,
    'MCCONKIE': 0,
    'MCCONLEY': 0,
    'MCCONLOGUE': 0,
    'MCCONN': 0,
    'MCCONNACHIE': 0,
    'MCCONNAHA': 0,
    'MCCONNAUGHAY': 0,
    'MCCONNAUGHEY': 0,
    'MCCONNAUGHHAY': 0,
    'MCCONNAUGHY': 0,
    'MCCONNEL': 0,
    'MCCONNELL': 0,
    'MCCONNER': 0,
    'MCCONNEY': 0,
    'MCCONNICO': 0,
    'MCCONNON': 0,
    'MCCONOMY': 0,
    'MCCONOUGHEY': 0,
    'MCCONVILLE': 0,
    'MCCOO': 0,
    'MCCOOEY': 0,
    'MCCOOK': 0,
    'MCCOOL': 0,
    'MCCOOLE': 0,
    'MCCOON': 0,
    'MCCOPPIN': 0,
    'MCCORD': 0,
    'MCCOREY': 0,
    'MCCORISON': 0,
    'MCCORKEL': 0,
    'MCCORKELL': 0,
    'MCCORKENDALE': 0,
    'MCCORKHILL': 0,
    'MCCORKIE': 0,
    'MCCORKINDALE': 0,
    'MCCORKLE': 0,
    'MCCORMAC': 0,
    'MCCORMACK': 0,
    'MCCORMIC': 0,
    'MCCORMICK': 0,
    'MCCORNACK': 0,
    'MCCORNELL': 0,
    'MCCORQUODALE': 0,
    'MCCORRISTON': 0,
    'MCCORRY': 0,
    'MCCORT': 0,
    'MCCORVEY': 0,
    'MCCORY': 0,
    'MCCOSH': 0,
    'MCCOSKER': 0,
    'MCCOSKEY': 0,
    'MCCOSTLIN': 0,
    'MCCOTTER': 0,
    'MCCOTTRELL': 0,
    'MCCOTTRY': 0,
    'MCCOUBREY': 0,
    'MCCOULLOUGH': 0,
    'MCCOUN': 0,
    'MCCOURRY': 0,
    'MCCOURT': 0,
    'MCCOURTNEY': 0,
    'MCCOURY': 0,
    'MCCOVERY': 0,
    'MCCOVEY': 0,
    'MCCOWAN': 0,
    'MCCOWEN': 0,
    'MCCOWIN': 0,
    'MCCOWN': 0,
    'MCCOX': 0,
    'MCCOY': 0,
    'MCCRABB': 0,
    'MCCRACKEN': 0,
    'MCCRACKIN': 0,
    'MCCRADY': 0,
    'MCCRAE': 0,
    'MCCRAIN': 0,
    'MCCRAINE': 0,
    'MCCRAITH': 0,
    'MCCRAKEN': 0,
    'MCCRANE': 0,
    'MCCRANEY': 0,
    'MCCRANIE': 0,
    'MCCRANN': 0,
    'MCCRARY': 0,
    'MCCRATE': 0,
    'MCCRAVEN': 0,
    'MCCRAVEY': 0,
    'MCCRAVY': 0,
    'MCCRAW': 0,
    'MCCRAY': 0,
    'MCCREA': 0,
    'MCCREADIE': 0,
    'MCCREADY': 0,
    'MCCREARY': 0,
    'MCCREATH': 0,
    'MCCREDIE': 0,
    'MCCREE': 0,
    'MCCREEDY': 0,
    'MCCREERY': 0,
    'MCCREESH': 0,
    'MCCREIGHT': 0,
    'MCCRELESS': 0,
    'MCCRERY': 0,
    'MCCREY': 0,
    'MCCRICKARD': 0,
    'MCCRIGHT': 0,
    'MCCRILLIS': 0,
    'MCCRIMMON': 0,
    'MCCRIMON': 0,
    'MCCRINDLE': 0,
    'MCCRINK': 0,
    'MCCRITE': 0,
    'MCCROAN': 0,
    'MCCROBIE': 0,
    'MCCROCKLIN': 0,
    'MCCROHAN': 0,
    'MCCRONE': 0,
    'MCCROREY': 0,
    'MCCRORIE': 0,
    'MCCRORY': 0,
    'MCCROSKEY': 0,
    'MCCROSKY': 0,
    'MCCROSSAN': 0,
    'MCCROSSEN': 0,
    'MCCROSSIN': 0,
    'MCCROSSON': 0,
    'MCCROY': 0,
    'MCCRUDDEN': 0,
    'MCCRUM': 0,
    'MCCRUMB': 0,
    'MCCRUMMEN': 0,
    'MCCRYSTAL': 0,
    'MCCUAIG': 0,
    'MCCUAN': 0,
    'MCCUBBIN': 0,
    'MCCUBBINS': 0,
    'MCCUDDEN': 0,
    'MCCUDDY': 0,
    'MCCUE': 0,
    'MCCUEN': 0,
    'MCCUIEN': 0,
    'MCCUIN': 0,
    'MCCUISTION': 0,
    'MCCUISTON': 0,
    'MCCULLA': 0,
    'MCCULLAGH': 0,
    'MCCULLAH': 0,
    'MCCULLAN': 0,
    'MCCULLAR': 0,
    'MCCULLARS': 0,
    'MCCULLEN': 0,
    'MCCULLER': 0,
    'MCCULLERS': 0,
    'MCCULLEY': 0,
    'MCCULLICK': 0,
    'MCCULLIN': 0,
    'MCCULLION': 0,
    'MCCULLOCH': 0,
    'MCCULLOCK': 0,
    'MCCULLOGH': 0,
    'MCCULLOH': 0,
    'MCCULLOM': 0,
    'MCCULLOR': 0,
    'MCCULLOUCH': 0,
    'MCCULLOUGH': 0,
    'MCCULLUM': 0,
    'MCCULLY': 0,
    'MCCULOUGH': 0,
    'MCCUMBEE': 0,
    'MCCUMBER': 0,
    'MCCUMBERS': 0,
    'MCCUMISKEY': 0,
    'MCCUMMINGS': 0,
    'MCCUMSEY': 0,
    'MCCUNE': 0,
    'MCCUNN': 0,
    'MCCUNNEY': 0,
    'MCCURDY': 0,
    'MCCURE': 0,
    'MCCURLEY': 0,
    'MCCURNIN': 0,
    'MCCURRIE': 0,
    'MCCURRY': 0,
    'MCCURTAIN': 0,
    'MCCURTIS': 0,
    'MCCURTY': 0,
    'MCCUSKER': 0,
    'MCCUSKEY': 0,
    'MCCUTCHAN': 0,
    'MCCUTCHEN': 0,
    'MCCUTCHEON': 0,
    'MCCUTCHIN': 0,
    'MCCUTHEON': 0,
    'MCDADE': 0,
    'MCDAID': 0,
    'MCDANAL': 0,
    'MCDANEL': 0,
    'MCDANELD': 0,
    'MCDANIAL': 0,
    'MCDANIEL': 0,
    'MCDANIELS': 0,
    'MCDANNALD': 0,
    'MCDANNEL': 0,
    'MCDANNELL': 0,
    'MCDANNOLD': 0,
    'MCDARBY': 0,
    'MCDARIS': 0,
    'MCDARMENT': 0,
    'MCDAVID': 0,
    'MCDAVIS': 0,
    'MCDAVITT': 0,
    'MCDAY': 0,
    'MCDEARMAN': 0,
    'MCDEARMON': 0,
    'MCDEAVITT': 0,
    'MCDERMAID': 0,
    'MCDERMAND': 0,
    'MCDERMED': 0,
    'MCDERMEIT': 0,
    'MCDERMENT': 0,
    'MCDERMID': 0,
    'MCDERMIT': 0,
    'MCDERMITT': 0,
    'MCDERMOND': 0,
    'MCDERMOT': 0,
    'MCDERMOTT': 0,
    'MCDEVITT': 0,
    'MCDEW': 0,
    'MCDIARMID': 0,
    'MCDIFFETT': 0,
    'MCDIFFITT': 0,
    'MCDILDA': 0,
    'MCDILL': 0,
    'MCDIVITT': 0,
    'MCDOLE': 0,
    'MCDONAGH': 0,
    'MCDONAL': 0,
    'MCDONALD': 0,
    'MCDONALDS': 0,
    'MCDONALDSON': 0,
    'MCDONAUGH': 0,
    'MCDONEL': 0,
    'MCDONELL': 0,
    'MCDONIE': 0,
    'MCDONIEL': 0,
    'MCDONNEL': 0,
    'MCDONNELL': 0,
    'MCDONNOLD': 0,
    'MCDONNOUGH': 0,
    'MCDONOUGH': 0,
    'MCDORMAN': 0,
    'MCDOUGAL': 0,
    'MCDOUGALD': 0,
    'MCDOUGALE': 0,
    'MCDOUGALL': 0,
    'MCDOUGLE': 0,
    'MCDOW': 0,
    'MCDOWALL': 0,
    'MCDOWEII': 0,
    'MCDOWEL': 0,
    'MCDOWELL': 0,
    'MCDOWN': 0,
    'MCDOWNEY': 0,
    'MCDUFF': 0,
    'MCDUFFEE': 0,
    'MCDUFFEY': 0,
    'MCDUFFIE': 0,
    'MCDUFFY': 0,
    'MCDUGALD': 0,
    'MCDUGLE': 0,
    'MCDUNN': 0,
    'MCDURMON': 0,
    'MCDYER': 0,
    'MCEACHEN': 0,
    'MCEACHERN': 0,
    'MCEACHIN': 0,
    'MCEACHRAN': 0,
    'MCEACHRON': 0,
    'MCEADY': 0,
    'MCEATHRON': 0,
    'MCELANEY': 0,
    'MCELDERRY': 0,
    'MCELDOWNEY': 0,
    'MCELDUFF': 0,
    'MCELENEY': 0,
    'MCELFISH': 0,
    'MCELFRESH': 0,
    'MCELHANEY': 0,
    'MCELHANNON': 0,
    'MCELHANON': 0,
    'MCELHANY': 0,
    'MCELHATTAN': 0,
    'MCELHATTEN': 0,
    'MCELHATTON': 0,
    'MCELHENEY': 0,
    'MCELHENIE': 0,
    'MCELHENNEY': 0,
    'MCELHENNY': 0,
    'MCELHENY': 0,
    'MCELHINEY': 0,
    'MCELHINNEY': 0,
    'MCELHINNY': 0,
    'MCELHOE': 0,
    'MCELHONE': 0,
    'MCELHOSE': 0,
    'MCELLEN': 0,
    'MCELLIGOTT': 0,
    'MCELLIOTT': 0,
    'MCELMAN': 0,
    'MCELMEEL': 0,
    'MCELMURRAY': 0,
    'MCELMURRY': 0,
    'MCELMURY': 0,
    'MCELORY': 0,
    'MCELRATH': 0,
    'MCELRAVY': 0,
    'MCELREA': 0,
    'MCELREATH': 0,
    'MCELREE': 0,
    'MCELRONE': 0,
    'MCELROY': 0,
    'MCELVAIN': 0,
    'MCELVAINE': 0,
    'MCELVANEY': 0,
    'MCELVANY': 0,
    'MCELVEEN': 0,
    'MCELVOGUE': 0,
    'MCELVY': 0,
    'MCELWAIN': 0,
    'MCELWAINE': 0,
    'MCELWANEY': 0,
    'MCELWEE': 0,
    'MCELWRATH': 0,
    'MCELYA': 0,
    'MCELYEA': 0,
    'MCENANEY': 0,
    'MCENANY': 0,
    'MCENDARFER': 0,
    'MCENDREE': 0,
    'MCENEANEY': 0,
    'MCENEANY': 0,
    'MCENENY': 0,
    'MCENERNEY': 0,
    'MCENERY': 0,
    'MCENIRY': 0,
    'MCENROE': 0,
    'MCENTEE': 0,
    'MCENTIRE': 0,
    'MCENTYRE': 0,
    'MCEOWEN': 0,
    'MCERLAIN': 0,
    'MCERLANE': 0,
    'MCERLEAN': 0,
    'MCEUEN': 0,
    'MCEVEN': 0,
    'MCEVER': 0,
    'MCEVERS': 0,
    'MCEVILLY': 0,
    'MCEVILY': 0,
    'MCEVOY': 0,
    'MCEWAN': 0,
    'MCEWEN': 0,
    'MCEWIN': 0,
    'MCEWING': 0,
    'MCFADDEN': 0,
    'MCFADDIN': 0,
    'MCFADEN': 0,
    'MCFADGEN': 0,
    'MCFADIN': 0,
    'MCFADYEN': 0,
    'MCFADZEAN': 0,
    'MCFADZEN': 0,
    'MCFAIL': 0,
    'MCFALL': 0,
    'MCFALLS': 0,
    'MCFANN': 0,
    'MCFARLAIN': 0,
    'MCFARLAN': 0,
    'MCFARLAND': 0,
    'MCFARLANE': 0,
    'MCFARLEN': 0,
    'MCFARLEY': 0,
    'MCFARLIN': 0,
    'MCFARLING': 0,
    'MCFARREN': 0,
    'MCFATE': 0,
    'MCFATRIDGE': 0,
    'MCFATTER': 0,
    'MCFAUL': 0,
    'MCFAYDEN': 0,
    'MCFEATERS': 0,
    'MCFEE': 0,
    'MCFEELEY': 0,
    'MCFEELY': 0,
    'MCFEETERS': 0,
    'MCFERON': 0,
    'MCFERRAN': 0,
    'MCFERREN': 0,
    'MCFERRIN': 0,
    'MCFERRON': 0,
    'MCFERSON': 0,
    'MCFETERS': 0,
    'MCFETRIDGE': 0,
    'MCFIELD': 0,
    'MCFILLIN': 0,
    'MCFOLLEY': 0,
    'MCFREDERICK': 0,
    'MCFRY': 0,
    'MCGAFFEY': 0,
    'MCGAFFIC': 0,
    'MCGAFFICK': 0,
    'MCGAFFIGAN': 0,
    'MCGAFFIN': 0,
    'MCGAHA': 0,
    'MCGAHAN': 0,
    'MCGAHEE': 0,
    'MCGAHEN': 0,
    'MCGAHEY': 0,
    'MCGAHUEY': 0,
    'MCGALL': 0,
    'MCGALLIARD': 0,
    'MCGALLION': 0,
    'MCGAN': 0,
    'MCGANN': 0,
    'MCGANNON': 0,
    'MCGAR': 0,
    'MCGAREY': 0,
    'MCGARGILL': 0,
    'MCGARITY': 0,
    'MCGARR': 0,
    'MCGARRAH': 0,
    'MCGARRAHAN': 0,
    'MCGARRAUGH': 0,
    'MCGARRELL': 0,
    'MCGARRH': 0,
    'MCGARRIGLE': 0,
    'MCGARRITY': 0,
    'MCGARRY': 0,
    'MCGARTH': 0,
    'MCGARTLAND': 0,
    'MCGARTY': 0,
    'MCGARVA': 0,
    'MCGARVEY': 0,
    'MCGARVIE': 0,
    'MCGARVIN': 0,
    'MCGARY': 0,
    'MCGASKEY': 0,
    'MCGATH': 0,
    'MCGATHA': 0,
    'MCGATHEY': 0,
    'MCGATHY': 0,
    'MCGAUGH': 0,
    'MCGAUGHEY': 0,
    'MCGAUGHRAN': 0,
    'MCGAUGHY': 0,
    'MCGAULEY': 0,
    'MCGAUVRAN': 0,
    'MCGAVERN': 0,
    'MCGAVIC': 0,
    'MCGAVIN': 0,
    'MCGAVOCK': 0,
    'MCGAVRAN': 0,
    'MCGAW': 0,
    'MCGAY': 0,
    'MCGEACHY': 0,
    'MCGEADY': 0,
    'MCGEARY': 0,
    'MCGEATH': 0,
    'MCGEE': 0,
    'MCGEEHAN': 0,
    'MCGEEHON': 0,
    'MCGEENEY': 0,
    'MCGEEVER': 0,
    'MCGEHEE': 0,
    'MCGEOCH': 0,
    'MCGEORGE': 0,
    'MCGEOUGH': 0,
    'MCGEOWN': 0,
    'MCGERVEY': 0,
    'MCGESHICK': 0,
    'MCGETRICK': 0,
    'MCGETTIGAN': 0,
    'MCGETTRICK': 0,
    'MCGHAN': 0,
    'MCGHEE': 0,
    'MCGHEHEY': 0,
    'MCGHGHY': 0,
    'MCGHIE': 0,
    'MCGHIN': 0,
    'MCGIBBON': 0,
    'MCGIBBONEY': 0,
    'MCGIBNEY': 0,
    'MCGIBONEY': 0,
    'MCGIFFERT': 0,
    'MCGIFFIN': 0,
    'MCGILBERRY': 0,
    'MCGILBRA': 0,
    'MCGILL': 0,
    'MCGILLEM': 0,
    'MCGILLEN': 0,
    'MCGILLICK': 0,
    'MCGILLICUDDY': 0,
    'MCGILLIGAN': 0,
    'MCGILLIN': 0,
    'MCGILLIS': 0,
    'MCGILLIVARY': 0,
    'MCGILLIVRAY': 0,
    'MCGILLOWAY': 0,
    'MCGILLVRAY': 0,
    'MCGILTON': 0,
    'MCGILVARY': 0,
    'MCGILVERY': 0,
    'MCGILVRA': 0,
    'MCGILVRAY': 0,
    'MCGILVREY': 0,
    'MCGIMPSEY': 0,
    'MCGIMSEY': 0,
    'MCGING': 0,
    'MCGINITY': 0,
    'MCGINLEY': 0,
    'MCGINN': 0,
    'MCGINNES': 0,
    'MCGINNESS': 0,
    'MCGINNIS': 0,
    'MCGINNISS': 0,
    'MCGINNITY': 0,
    'MCGINTY': 0,
    'MCGIRK': 0,
    'MCGIRL': 0,
    'MCGIRR': 0,
    'MCGIRT': 0,
    'MCGIVERN': 0,
    'MCGIVERON': 0,
    'MCGIVNEY': 0,
    'MCGLADE': 0,
    'MCGLAMERY': 0,
    'MCGLAMORY': 0,
    'MCGLAMRY': 0,
    'MCGLASHAN': 0,
    'MCGLASHEN': 0,
    'MCGLASHING': 0,
    'MCGLASSON': 0,
    'MCGLATHERY': 0,
    'MCGLAUFLIN': 0,
    'MCGLAUGHLIN': 0,
    'MCGLAUGHN': 0,
    'MCGLAUN': 0,
    'MCGLAWN': 0,
    'MCGLENN': 0,
    'MCGLENNON': 0,
    'MCGLEW': 0,
    'MCGLIN': 0,
    'MCGLINCH': 0,
    'MCGLINCHEY': 0,
    'MCGLINCHY': 0,
    'MCGLINN': 0,
    'MCGLOCKLIN': 0,
    'MCGLOHON': 0,
    'MCGLOIN': 0,
    'MCGLON': 0,
    'MCGLONE': 0,
    'MCGLORY': 0,
    'MCGLOTHAN': 0,
    'MCGLOTHEN': 0,
    'MCGLOTHERN': 0,
    'MCGLOTHIN': 0,
    'MCGLOTHLEN': 0,
    'MCGLOTHLIN': 0,
    'MCGLOTTEN': 0,
    'MCGLOUGHLIN': 0,
    'MCGLOWN': 0,
    'MCGLUMPHY': 0,
    'MCGLYNN': 0,
    'MCGOEY': 0,
    'MCGOFF': 0,
    'MCGOFFIN': 0,
    'MCGOHAN': 0,
    'MCGOLDRICK': 0,
    'MCGOMERY': 0,
    'MCGONAGILL': 0,
    'MCGONAGLE': 0,
    'MCGONEGAL': 0,
    'MCGONEGLE': 0,
    'MCGONIGAL': 0,
    'MCGONIGLE': 0,
    'MCGONNELL': 0,
    'MCGOOGAN': 0,
    'MCGOON': 0,
    'MCGORMAN': 0,
    'MCGORRY': 0,
    'MCGORTY': 0,
    'MCGORY': 0,
    'MCGOUGAN': 0,
    'MCGOUGH': 0,
    'MCGOUIRK': 0,
    'MCGOULDRICK': 0,
    'MCGOURTY': 0,
    'MCGOVERN': 0,
    'MCGOVNEY': 0,
    'MCGOWAN': 0,
    'MCGOWEN': 0,
    'MCGOWENS': 0,
    'MCGOWIN': 0,
    'MCGOWN': 0,
    'MCGRADE': 0,
    'MCGRADY': 0,
    'MCGRAIL': 0,
    'MCGRAIN': 0,
    'MCGRAN': 0,
    'MCGRANAGHAN': 0,
    'MCGRANAHAN': 0,
    'MCGRANE': 0,
    'MCGRANER': 0,
    'MCGRANN': 0,
    'MCGRANOR': 0,
    'MCGRATH': 0,
    'MCGRATTAN': 0,
    'MCGRAW': 0,
    'MCGRAY': 0,
    'MCGREADY': 0,
    'MCGREAL': 0,
    'MCGREE': 0,
    'MCGREEN': 0,
    'MCGREER': 0,
    'MCGREEVEY': 0,
    'MCGREEVY': 0,
    'MCGREGER': 0,
    'MCGREGGOR': 0,
    'MCGREGOR': 0,
    'MCGREGORY': 0,
    'MCGREW': 0,
    'MCGRIER': 0,
    'MCGRIFF': 0,
    'MCGRIGGS': 0,
    'MCGROARTY': 0,
    'MCGROARY': 0,
    'MCGROGAN': 0,
    'MCGRONE': 0,
    'MCGRORTY': 0,
    'MCGRORY': 0,
    'MCGRUDER': 0,
    'MCGRUE': 0,
    'MCGRUTHER': 0,
    'MCGUAN': 0,
    'MCGUANE': 0,
    'MCGUCKEN': 0,
    'MCGUCKIN': 0,
    'MCGUE': 0,
    'MCGUFF': 0,
    'MCGUFFEE': 0,
    'MCGUFFEY': 0,
    'MCGUFFIE': 0,
    'MCGUFFIN': 0,
    'MCGUGAN': 0,
    'MCGUGIN': 0,
    'MCGUIGAN': 0,
    'MCGUIGGAN': 0,
    'MCGUILL': 0,
    'MCGUIN': 0,
    'MCGUINESS': 0,
    'MCGUINN': 0,
    'MCGUINNESS': 0,
    'MCGUIRE': 0,
    'MCGUIRK': 0,
    'MCGUIRL': 0,
    'MCGUIRT': 0,
    'MCGUNNIGLE': 0,
    'MCGURGAN': 0,
    'MCGURK': 0,
    'MCGURL': 0,
    'MCGURN': 0,
    'MCGURRAN': 0,
    'MCGURREN': 0,
    'MCGURRIN': 0,
    'MCGURTY': 0,
    'MCGUYER': 0,
    'MCGWIRE': 0,
    'MCHAFFIE': 0,
    'MCHALE': 0,
    'MCHALEY': 0,
    'MCHALFFEY': 0,
    'MCHAM': 0,
    'MCHAN': 0,
    'MCHANEY': 0,
    'MCHANN': 0,
    'MCHARDY': 0,
    'MCHARG': 0,
    'MCHARGUE': 0,
    'MCHARRIS': 0,
    'MCHATTEN': 0,
    'MCHATTIE': 0,
    'MCHATTON': 0,
    'MCHAYLE': 0,
    'MCHENRY': 0,
    'MCHERRON': 0,
    'MCHOLLAND': 0,
    'MCHONE': 0,
    'MCHORNEY': 0,
    'MCHORSE': 0,
    'MCHOSE': 0,
    'MCHUGH': 0,
    'MCHUGHES': 0,
    'MCIE': 0,
    'MCILHANEY': 0,
    'MCILHARGEY': 0,
    'MCILHENNEY': 0,
    'MCILHENNY': 0,
    'MCILLWAIN': 0,
    'MCILNAY': 0,
    'MCILQUHAM': 0,
    'MCILRAITH': 0,
    'MCILRATH': 0,
    'MCILRAVY': 0,
    'MCILROY': 0,
    'MCILVAIN': 0,
    'MCILVAINE': 0,
    'MCILVEEN': 0,
    'MCILVENNA': 0,
    'MCILVOY': 0,
    'MCILWAIN': 0,
    'MCILWAINE': 0,
    'MCILWEE': 0,
    'MCINALLY': 0,
    'MCINDOE': 0,
    'MCINDOO': 0,
    'MCINELLY': 0,
    'MCINERNEY': 0,
    'MCINERNY': 0,
    'MCININCH': 0,
    'MCINNES': 0,
    'MCINNIS': 0,
    'MCINNISH': 0,
    'MCINROE': 0,
    'MCINROY': 0,
    'MCINTEE': 0,
    'MCINTEER': 0,
    'MCINTIER': 0,
    'MCINTIRE': 0,
    'MCINTOSH': 0,
    'MCINTRYE': 0,
    'MCINTURF': 0,
    'MCINTURFF': 0,
    'MCINTYRE': 0,
    'MCINVALE': 0,
    'MCINVILLE': 0,
    'MCIRVIN': 0,
    'MCISAAC': 0,
    'MCIVER': 0,
    'MCIVOR': 0,
    'MCJILTON': 0,
    'MCJIMSEY': 0,
    'MCJUNKIN': 0,
    'MCJUNKINS': 0,
    'MCKAGUE': 0,
    'MCKAHAN': 0,
    'MCKAIG': 0,
    'MCKAIN': 0,
    'MCKALE': 0,
    'MCKALIP': 0,
    'MCKAMEY': 0,
    'MCKAMIE': 0,
    'MCKAMY': 0,
    'MCKANE': 0,
    'MCKANNA': 0,
    'MCKASKLE': 0,
    'MCKASSON': 0,
    'MCKAUGHAN': 0,
    'MCKAY': 0,
    'MCKEAG': 0,
    'MCKEAGE': 0,
    'MCKEAGUE': 0,
    'MCKEAN': 0,
    'MCKEAND': 0,
    'MCKEARN': 0,
    'MCKEARNEY': 0,
    'MCKECHNIE': 0,
    'MCKEE': 0,
    'MCKEEBY': 0,
    'MCKEEFRY': 0,
    'MCKEEGAN': 0,
    'MCKEEHAN': 0,
    'MCKEEHEN': 0,
    'MCKEEL': 0,
    'MCKEEMAN': 0,
    'MCKEEN': 0,
    'MCKEETH': 0,
    'MCKEEVER': 0,
    'MCKEIGHAN': 0,
    'MCKEIGHEN': 0,
    'MCKEIRNAN': 0,
    'MCKEITH': 0,
    'MCKEITHAN': 0,
    'MCKEITHEN': 0,
    'MCKEIVER': 0,
    'MCKELDIN': 0,
    'MCKELL': 0,
    'MCKELLAR': 0,
    'MCKELLER': 0,
    'MCKELLEY': 0,
    'MCKELLIP': 0,
    'MCKELLIPS': 0,
    'MCKELLOP': 0,
    'MCKELLY': 0,
    'MCKELPHIN': 0,
    'MCKELROY': 0,
    'MCKELTON': 0,
    'MCKELVAIN': 0,
    'MCKELVEY': 0,
    'MCKELVIE': 0,
    'MCKELVIN': 0,
    'MCKELVY': 0,
    'MCKEMIE': 0,
    'MCKEMY': 0,
    'MCKEN': 0,
    'MCKENDALL': 0,
    'MCKENDREE': 0,
    'MCKENDRICK': 0,
    'MCKENDRY': 0,
    'MCKENITH': 0,
    'MCKENIZE': 0,
    'MCKENLEY': 0,
    'MCKENNA': 0,
    'MCKENNAN': 0,
    'MCKENNEY': 0,
    'MCKENNIE': 0,
    'MCKENNON': 0,
    'MCKENNY': 0,
    'MCKENRICK': 0,
    'MCKENRY': 0,
    'MCKENSIE': 0,
    'MCKENTY': 0,
    'MCKENY': 0,
    'MCKENZIE': 0.08920606601248884,
    'MCKEOGH': 0,
    'MCKEON': 0,
    'MCKEONE': 0,
    'MCKEOUGH': 0,
    'MCKEOWN': 0,
    'MCKERCHER': 0,
    'MCKERCHIE': 0,
    'MCKERLEY': 0,
    'MCKERLIE': 0,
    'MCKERN': 0,
    'MCKERNAN': 0,
    'MCKERNON': 0,
    'MCKERRACHER': 0,
    'MCKERROW': 0,
    'MCKERVEY': 0,
    'MCKESSON': 0,
    'MCKESSY': 0,
    'MCKETHAN': 0,
    'MCKEVER': 0,
    'MCKEVITT': 0,
    'MCKEW': 0,
    'MCKEWEN': 0,
    'MCKEY': 0,
    'MCKIBBEN': 0,
    'MCKIBBIN': 0,
    'MCKIBBINS': 0,
    'MCKIBBON': 0,
    'MCKIDDIE': 0,
    'MCKIDDY': 0,
    'MCKIE': 0,
    'MCKIEL': 0,
    'MCKIERNAN': 0,
    'MCKIEVER': 0,
    'MCKILLEN': 0,
    'MCKILLIP': 0,
    'MCKILLIPS': 0,
    'MCKILLOP': 0,
    'MCKIM': 0,
    'MCKIMM': 0,
    'MCKIMMEY': 0,
    'MCKIMMIE': 0,
    'MCKIMMY': 0,
    'MCKIN': 0,
    'MCKINDLEY': 0,
    'MCKINE': 0,
    'MCKINES': 0,
    'MCKINESS': 0,
    'MCKINEY': 0,
    'MCKINION': 0,
    'MCKINLAY': 0,
    'MCKINLEY': 0.3684598378776713,
    'MCKINNA': 0,
    'MCKINNELL': 0,
    'MCKINNERNEY': 0,
    'MCKINNES': 0,
    'MCKINNEY': 0,
    'MCKINNIE': 0,
    'MCKINNIES': 0,
    'MCKINNIS': 0,
    'MCKINNISH': 0,
    'MCKINNISS': 0,
    'MCKINNLEY': 0,
    'MCKINNON': 0,
    'MCKINNY': 0,
    'MCKINSEY': 0,
    'MCKINSTER': 0,
    'MCKINSTRY': 0,
    'MCKINZEY': 0,
    'MCKINZIE': 0,
    'MCKINZY': 0,
    'MCKIRAHAN': 0,
    'MCKIRDY': 0,
    'MCKIRGAN': 0,
    'MCKISIC': 0,
    'MCKISSACK': 0,
    'MCKISSEN': 0,
    'MCKISSIC': 0,
    'MCKISSICK': 0,
    'MCKISSOCK': 0,
    'MCKISSON': 0,
    'MCKITHEN': 0,
    'MCKITRICK': 0,
    'MCKITTERICK': 0,
    'MCKITTRICK': 0,
    'MCKIVER': 0,
    'MCKLEMURRY': 0,
    'MCKLEROY': 0,
    'MCKLVEEN': 0,
    'MCKNABB': 0,
    'MCKNATT': 0,
    'MCKNEELY': 0,
    'MCKNELLY': 0,
    'MCKNEW': 0,
    'MCKNIGHT': 0,
    'MCKOIN': 0,
    'MCKONE': 0,
    'MCKOON': 0,
    'MCKOWEN': 0,
    'MCKOWN': 0,
    'MCKOY': 0,
    'MCKRELL': 0,
    'MCKUHEN': 0,
    'MCKUIN': 0,
    'MCKUNE': 0,
    'MCKUSICK': 0,
    'MCLACHLAN': 0,
    'MCLAFFERTY': 0,
    'MCLAGAN': 0,
    'MCLAIN': 0,
    'MCLAINE': 0,
    'MCLALLEN': 0,
    'MCLAM': 0,
    'MCLAMB': 0,
    'MCLAMORE': 0,
    'MCLANAHAN': 0,
    'MCLANE': 0,
    'MCLANEY': 0,
    'MCLAREN': 0,
    'MCLARIN': 0,
    'MCLARNAN': 0,
    'MCLARNEY': 0,
    'MCLARNON': 0,
    'MCLARRY': 0,
    'MCLARTY': 0,
    'MCLARY': 0,
    'MCLATCHY': 0,
    'MCLAUCHLAN': 0,
    'MCLAUCHLIN': 0,
    'MCLAUD': 0,
    'MCLAUGHIN': 0,
    'MCLAUGHLAN': 0,
    'MCLAUGHLIN': 0,
    'MCLAUGLIN': 0,
    'MCLAUREN': 0,
    'MCLAURIN': 0,
    'MCLAURINE': 0,
    'MCLAURY': 0,
    'MCLAWHORN': 0,
    'MCLAWRENCE': 0,
    'MCLAWS': 0,
    'MCLAY': 0,
    'MCLEAD': 0,
    'MCLEAN': 0,
    'MCLEAR': 0,
    'MCLEAREN': 0,
    'MCLEARY': 0,
    'MCLEE': 0,
    'MCLEER': 0,
    'MCLEES': 0,
    'MCLEESE': 0,
    'MCLEISH': 0,
    'MCLELAND': 0,
    'MCLELLAN': 0,
    'MCLELLAND': 0,
    'MCLEMORE': 0,
    'MCLENDON': 0,
    'MCLENITHAN': 0,
    'MCLENNAN': 0,
    'MCLENNON': 0,
    'MCLENON': 0,
    'MCLEOD': 0,
    'MCLEON': 0,
    'MCLERAN': 0,
    'MCLERNON': 0,
    'MCLEROY': 0,
    'MCLERRAN': 0,
    'MCLESKEY': 0,
    'MCLESTER': 0,
    'MCLEVAIN': 0,
    'MCLEY': 0,
    'MCLIMANS': 0,
    'MCLIN': 0,
    'MCLINDEN': 0,
    'MCLINN': 0,
    'MCLINTOCK': 0,
    'MCLOCHLIN': 0,
    'MCLOED': 0,
    'MCLOON': 0,
    'MCLOONE': 0,
    'MCLOUD': 0,
    'MCLOUGHLIN': 0,
    'MCLOUTH': 0,
    'MCLOYD': 0,
    'MCLUCAS': 0,
    'MCLUCKIE': 0,
    'MCLUEN': 0,
    'MCLURE': 0,
    'MCLURKIN': 0,
    'MCLYMONT': 0,
    'MCMACKEN': 0,
    'MCMACKIN': 0,
    'MCMAHAN': 0,
    'MCMAHEL': 0,
    'MCMAHEN': 0,
    'MCMAHILL': 0,
    'MCMAHON': 0,
    'MCMAIN': 0,
    'MCMAINS': 0,
    'MCMAKEN': 0,
    'MCMAKIN': 0,
    'MCMAN': 0,
    'MCMANAMA': 0,
    'MCMANAMAN': 0,
    'MCMANAMON': 0,
    'MCMANAMY': 0,
    'MCMANAWAY': 0,
    'MCMANEMY': 0,
    'MCMANES': 0,
    'MCMANIGAL': 0,
    'MCMANIGLE': 0,
    'MCMANIMON': 0,
    'MCMANIS': 0,
    'MCMANMON': 0,
    'MCMANN': 0,
    'MCMANNES': 0,
    'MCMANNIS': 0,
    'MCMANNUS': 0,
    'MCMANUS': 0,
    'MCMARTIN': 0,
    'MCMASTER': 0,
    'MCMASTERS': 0,
    'MCMATH': 0,
    'MCMEANS': 0,
    'MCMECHAN': 0,
    'MCMEEKAN': 0,
    'MCMEEKIN': 0,
    'MCMEEL': 0,
    'MCMEEN': 0,
    'MCMELLEN': 0,
    'MCMELLON': 0,
    'MCMENAMIN': 0,
    'MCMENAMY': 0,
    'MCMENEMY': 0,
    'MCMENIMEN': 0,
    'MCMENOMY': 0,
    'MCMICHAEL': 0,
    'MCMICHEAL': 0,
    'MCMICHEN': 0,
    'MCMICKEN': 0,
    'MCMICKENS': 0,
    'MCMICKLE': 0,
    'MCMILLAN': 0,
    'MCMILLEN': 0,
    'MCMILLER': 0,
    'MCMILLIAM': 0,
    'MCMILLIAN': 0,
    'MCMILLIN': 0,
    'MCMILLION': 0,
    'MCMILLON': 0,
    'MCMINDES': 0,
    'MCMINN': 0,
    'MCMONAGLE': 0,
    'MCMONIGAL': 0,
    'MCMONIGLE': 0,
    'MCMOORE': 0,
    'MCMORAN': 0,
    'MCMORDIE': 0,
    'MCMORRAN': 0,
    'MCMORRIES': 0,
    'MCMORRIS': 0,
    'MCMORROW': 0,
    'MCMULLAN': 0,
    'MCMULLEN': 0,
    'MCMULLIN': 0,
    'MCMULLINS': 0,
    'MCMUNN': 0,
    'MCMURCHIE': 0,
    'MCMURDIE': 0,
    'MCMURDO': 0,
    'MCMURDY': 0,
    'MCMURPHY': 0,
    'MCMURRAN': 0,
    'MCMURRAY': 0,
    'MCMURREN': 0,
    'MCMURRER': 0,
    'MCMURREY': 0,
    'MCMURRIAN': 0,
    'MCMURRIN': 0,
    'MCMURROUGH': 0,
    'MCMURRY': 0,
    'MCMURTRAY': 0,
    'MCMURTREY': 0,
    'MCMURTRIE': 0,
    'MCMURTRY': 0,
    'MCNAB': 0,
    'MCNABB': 0,
    'MCNABNEY': 0,
    'MCNABOE': 0,
    'MCNAC': 0,
    'MCNACK': 0,
    'MCNAIL': 0,
    'MCNAIR': 0,
    'MCNAIRY': 0,
    'MCNALL': 0,
    'MCNALLAN': 0,
    'MCNALLEY': 0,
    'MCNALLY': 0,
    'MCNAMAR': 0,
    'MCNAMARA': 0,
    'MCNAMEE': 0,
    'MCNAMER': 0,
    'MCNAMES': 0,
    'MCNANEY': 0,
    'MCNANY': 0,
    'MCNARY': 0,
    'MCNATT': 0,
    'MCNAUGHT': 0,
    'MCNAUGHTON': 0,
    'MCNAUL': 0,
    'MCNAULTY': 0,
    'MCNAY': 0,
    'MCNEA': 0,
    'MCNEACE': 0,
    'MCNEAL': 0,
    'MCNEALEY': 0,
    'MCNEALLY': 0,
    'MCNEALY': 0,
    'MCNEAR': 0,
    'MCNEARNEY': 0,
    'MCNEARY': 0,
    'MCNEASE': 0,
    'MCNECE': 0,
    'MCNEE': 0,
    'MCNEECE': 0,
    'MCNEEL': 0,
    'MCNEELA': 0,
    'MCNEELEY': 0,
    'MCNEELY': 0,
    'MCNEER': 0,
    'MCNEES': 0,
    'MCNEESE': 0,
    'MCNEFF': 0,
    'MCNEICE': 0,
    'MCNEIGHT': 0,
    'MCNEIL': 0,
    'MCNEILL': 0,
    'MCNEILLY': 0,
    'MCNEILY': 0,
    'MCNEIR': 0,
    'MCNEISH': 0,
    'MCNEIVE': 0,
    'MCNELEY': 0,
    'MCNELIS': 0,
    'MCNELL': 0,
    'MCNELLEY': 0,
    'MCNELLIS': 0,
    'MCNELLY': 0,
    'MCNEMAR': 0,
    'MCNERLIN': 0,
    'MCNERNEY': 0,
    'MCNERNY': 0,
    'MCNERTNEY': 0,
    'MCNESBY': 0,
    'MCNETT': 0,
    'MCNEVIN': 0,
    'MCNEW': 0,
    'MCNEY': 0,
    'MCNICHOL': 0,
    'MCNICHOLAS': 0,
    'MCNICHOLL': 0,
    'MCNICHOLS': 0,
    'MCNICKLE': 0,
    'MCNICKLES': 0,
    'MCNICOL': 0,
    'MCNICOLL': 0,
    'MCNIECE': 0,
    'MCNIEL': 0,
    'MCNIELL': 0,
    'MCNIER': 0,
    'MCNIERNEY': 0,
    'MCNIFF': 0,
    'MCNIGHT': 0,
    'MCNINCH': 0,
    'MCNISH': 0,
    'MCNITT': 0,
    'MCNIVEN': 0,
    'MCNORTON': 0,
    'MCNOWN': 0,
    'MCNULTY': 0,
    'MCNURLEN': 0,
    'MCNURLIN': 0,
    'MCNUTT': 0,
    'MCOMBER': 0,
    'MCOMIE': 0,
    'MCOSKER': 0,
    'MCOWEN': 0,
    'MCOY': 0,
    'MCPADDEN': 0,
    'MCPARLAND': 0,
    'MCPARTLAN': 0,
    'MCPARTLAND': 0,
    'MCPARTLIN': 0,
    'MCPAUL': 0,
    'MCPEAK': 0,
    'MCPEAKE': 0,
    'MCPECK': 0,
    'MCPEEK': 0,
    'MCPETERS': 0,
    'MCPHAIL': 0,
    'MCPHALL': 0,
    'MCPHARLIN': 0,
    'MCPHATE': 0,
    'MCPHATTER': 0,
    'MCPHAUL': 0,
    'MCPHEARSON': 0,
    'MCPHEE': 0,
    'MCPHEETERS': 0,
    'MCPHERON': 0,
    'MCPHERRAN': 0,
    'MCPHERREN': 0,
    'MCPHERRIN': 0,
    'MCPHERRON': 0,
    'MCPHERSON': 0,
    'MCPHETERS': 0,
    'MCPHETRIDGE': 0,
    'MCPHIE': 0,
    'MCPHILLIPS': 0,
    'MCPIKE': 0,
    'MCPIPE': 0,
    'MCPOLAND': 0,
    'MCPOLIN': 0,
    'MCQUADE': 0,
    'MCQUAGE': 0,
    'MCQUAGGE': 0,
    'MCQUAID': 0,
    'MCQUAIDE': 0,
    'MCQUAIG': 0,
    'MCQUAIN': 0,
    'MCQUALITY': 0,
    'MCQUARRIE': 0,
    'MCQUARRY': 0,
    'MCQUARTER': 0,
    'MCQUARTERS': 0,
    'MCQUARY': 0,
    'MCQUATE': 0,
    'MCQUATTERS': 0,
    'MCQUAY': 0,
    'MCQUEARY': 0,
    'MCQUEEN': 0,
    'MCQUEENEY': 0,
    'MCQUEENY': 0,
    'MCQUERREY': 0,
    'MCQUERRY': 0,
    'MCQUERY': 0,
    'MCQUESTEN': 0,
    'MCQUESTION': 0,
    'MCQUIDDY': 0,
    'MCQUIEN': 0,
    'MCQUIGG': 0,
    'MCQUIGGAN': 0,
    'MCQUILKEN': 0,
    'MCQUILKIN': 0,
    'MCQUILLAN': 0,
    'MCQUILLAR': 0,
    'MCQUILLEN': 0,
    'MCQUILLER': 0,
    'MCQUILLIAMS': 0,
    'MCQUILLIN': 0,
    'MCQUILLING': 0,
    'MCQUIN': 0,
    'MCQUINN': 0,
    'MCQUIRE': 0,
    'MCQUIRK': 0,
    'MCQUIRTER': 0,
    'MCQUISTEN': 0,
    'MCQUISTION': 0,
    'MCQUISTON': 0,
    'MCQUITTY': 0,
    'MCQUIVEY': 0,
    'MCQUOID': 0,
    'MCQUOWN': 0,
    'MCRAE': 0,
    'MCRANEY': 0,
    'MCRARY': 0,
    'MCRATH': 0,
    'MCRAVEN': 0,
    'MCRAY': 0,
    'MCREA': 0,
    'MCREADY': 0,
    'MCREAVY': 0,
    'MCREDMOND': 0,
    'MCREE': 0,
    'MCRELL': 0,
    'MCREYNOLDS': 0,
    'MCRIGHT': 0,
    'MCRILL': 0,
    'MCRITCHIE': 0,
    'MCROBBIE': 0,
    'MCROBERT': 0,
    'MCROBERTS': 0,
    'MCROBIE': 0,
    'MCROREY': 0,
    'MCRORIE': 0,
    'MCRORY': 0,
    'MCROY': 0,
    'MCSHAN': 0,
    'MCSHANE': 0,
    'MCSHARRY': 0,
    'MCSHAY': 0,
    'MCSHEA': 0,
    'MCSHEEHY': 0,
    'MCSHEFFREY': 0,
    'MCSHERRY': 0,
    'MCSKIMMING': 0,
    'MCSMITH': 0,
    'MCSOLEY': 0,
    'MCSORLEY': 0,
    'MCSPADDEN': 0,
    'MCSPARIN': 0,
    'MCSPARRAN': 0,
    'MCSPARREN': 0,
    'MCSPARRON': 0,
    'MCSPEDON': 0,
    'MCSPERITT': 0,
    'MCSPIRIT': 0,
    'MCSTAY': 0,
    'MCSTOOTS': 0,
    'MCSTRAVICK': 0,
    'MCSURDY': 0,
    'MCSWAIN': 0,
    'MCSWEEN': 0,
    'MCSWEENEY': 0,
    'MCSWEENY': 0,
    'MCSWINE': 0,
    'MCSWINEY': 0,
    'MCTAGGART': 0,
    'MCTAGUE': 0,
    'MCTAMNEY': 0,
    'MCTARSNEY': 0,
    'MCTAVISH': 0,
    'MCTEAGUE': 0,
    'MCTEAR': 0,
    'MCTEE': 0,
    'MCTEER': 0,
    'MCTERNAN': 0,
    'MCTIER': 0,
    'MCTIERNAN': 0,
    'MCTIGHE': 0,
    'MCTIGUE': 0,
    'MCTIZIC': 0,
    'MCTYRE': 0,
    'MCUMBER': 0,
    'MCVAN': 0,
    'MCVANE': 0,
    'MCVANEY': 0,
    'MCVAUGH': 0,
    'MCVAY': 0,
    'MCVEA': 0,
    'MCVEAN': 0,
    'MCVEETY': 0,
    'MCVEIGH': 0,
    'MCVERRY': 0,
    'MCVETY': 0,
    'MCVEY': 0,
    'MCVICAR': 0,
    'MCVICKAR': 0,
    'MCVICKER': 0,
    'MCVICKERS': 0,
    'MCVITTIE': 0,
    'MCVOY': 0,
    'MCWADE': 0,
    'MCWAIN': 0,
    'MCWALTER': 0,
    'MCWALTERS': 0,
    'MCWANE': 0,
    'MCWARD': 0,
    'MCWASHINGTON': 0,
    'MCWATERS': 0,
    'MCWATTERS': 0,
    'MCWAY': 0,
    'MCWAYNE': 0,
    'MCWEENEY': 0,
    'MCWEENY': 0,
    'MCWETHY': 0,
    'MCWHA': 0,
    'MCWHERTER': 0,
    'MCWHINNEY': 0,
    'MCWHINNIE': 0,
    'MCWHIRT': 0,
    'MCWHIRTER': 0,
    'MCWHITE': 0,
    'MCWHORTER': 0,
    'MCWILLIAM': 0,
    'MCWILLIAMS': 0,
    'MCWILSON': 0,
    'MCWITHEY': 0,
    'MCWRIGHT': 0,
    'MCZEAL': 0,
    'MEA': 0,
    'MEABON': 0,
    'MEACH': 0,
    'MEACHAM': 0,
    'MEACHEM': 0,
    'MEACHEN': 0,
    'MEACHER': 0,
    'MEACHUM': 0,
    'MEAD': 0,
    'MEADE': 0,
    'MEADEN': 0,
    'MEADER': 0,
    'MEADERS': 0,
    'MEADES': 0,
    'MEADOR': 0,
    'MEADORS': 0,
    'MEADOW': 0,
    'MEADOWCROFT': 0,
    'MEADOWS': 0,
    'MEADS': 0,
    'MEAGAN': 1,
    'MEAGER': 0,
    'MEAGHAN': 1,
    'MEAGHER': 0,
    'MEAGLEY': 0,
    'MEAH': 0,
    'MEAHAN': 0,
    'MEAHL': 0,
    'MEAK': 0,
    'MEAKER': 0,
    'MEAKIN': 0,
    'MEAKINS': 0,
    'MEAL': 0,
    'MEALE': 0,
    'MEALER': 0,
    'MEALEY': 0,
    'MEALING': 0,
    'MEALMAN': 0,
    'MEALOR': 0,
    'MEALS': 0,
    'MEALY': 0,
    'MEAN': 0,
    'MEANA': 0,
    'MEANEY': 0,
    'MEANOR': 0,
    'MEANS': 0,
    'MEANY': 0,
    'MEAR': 0,
    'MEARA': 0,
    'MEARES': 0,
    'MEARKLE': 0,
    'MEARNS': 0,
    'MEARS': 0,
    'MEARSE': 0,
    'MEAS': 0,
    'MEASE': 0,
    'MEASEL': 0,
    'MEASLES': 0,
    'MEASLEY': 0,
    'MEASMER': 0,
    'MEASOM': 0,
    'MEASON': 0,
    'MEATH': 0,
    'MEATS': 0,
    'MEATTE': 0,
    'MEATTEY': 0,
    'MEAUX': 0,
    'MEAVE': 0,
    'MEAZELL': 0,
    'MEBANE': 0,
    'MEBERG': 0,
    'MEBRAHTU': 0,
    'MEBRUER': 0,
    'MEBUST': 0,
    'MECA': 0,
    'MECCA': 0,
    'MECCARIELLO': 0,
    'MECCHI': 0,
    'MECCIA': 0,
    'MECH': 0,
    'MECHA': 0,
    'MECHAM': 0,
    'MECHAN': 0,
    'MECHANIC': 0,
    'MECHE': 0,
    'MECHELKE': 0,
    'MECHELL': 0,
    'MECHELLE': 1,
    'MECHEM': 0,
    'MECHER': 0,
    'MECHLER': 0,
    'MECHLIN': 0,
    'MECHLING': 0,
    'MECHTEL': 0,
    'MECHURA': 0,
    'MECIAS': 0,
    'MECIMORE': 0,
    'MECK': 0,
    'MECKE': 0,
    'MECKEL': 0,
    'MECKER': 0,
    'MECKES': 0,
    'MECKFESSEL': 0,
    'MECKLE': 0,
    'MECKLENBURG': 0,
    'MECKLER': 0,
    'MECKLEY': 0,
    'MECKLING': 0,
    'MECKSTROTH': 0,
    'MECOM': 0,
    'MECOZZI': 0,
    'MECUM': 0,
    'MED': 0,
    'MEDA': 0.8,
    'MEDAGLIA': 0,
    'MEDAK': 0,
    'MEDAL': 0,
    'MEDALEN': 0,
    'MEDALLA': 0,
    'MEDARD': 0,
    'MEDARIS': 0,
    'MEDART': 0,
    'MEDAS': 0,
    'MEDAUGH': 0,
    'MEDAWAR': 0,
    'MEDBERRY': 0,
    'MEDBERY': 0,
    'MEDBURY': 0,
    'MEDCALF': 0,
    'MEDD': 0,
    'MEDDAUGH': 0,
    'MEDDERS': 0,
    'MEDDINGS': 0,
    'MEDDLES': 0,
    'MEDDOCK': 0,
    'MEDE': 0,
    'MEDEARIS': 0,
    'MEDECK': 0,
    'MEDEIROS': 0,
    'MEDEK': 0,
    'MEDEL': 0,
    'MEDELES': 0,
    'MEDELEZ': 0,
    'MEDELL': 0,
    'MEDELLIN': 0,
    'MEDEMA': 0,
    'MEDEN': 0,
    'MEDENA': 0,
    'MEDENDORP': 0,
    'MEDENWALD': 0,
    'MEDENWALDT': 0,
    'MEDER': 0,
    'MEDERIOS': 0,
    'MEDERNACH': 0,
    'MEDERO': 0,
    'MEDEROS': 0,
    'MEDES': 0,
    'MEDFORD': 0,
    'MEDHURST': 0,
    'MEDIA': 0,
    'MEDIAN': 0,
    'MEDIANO': 0,
    'MEDIATE': 0,
    'MEDIAVILLA': 0,
    'MEDIC': 0,
    'MEDICA': 0,
    'MEDICH': 0,
    'MEDICI': 0,
    'MEDICK': 0,
    'MEDICO': 0,
    'MEDICUS': 0,
    'MEDILL': 0,
    'MEDIN': 0,
    'MEDINA': 0,
    'MEDINE': 0,
    'MEDING': 0,
    'MEDINGER': 0,
    'MEDINILLA': 0,
    'MEDINO': 0,
    'MEDITZ': 0,
    'MEDLAND': 0,
    'MEDLAR': 0,
    'MEDLEN': 0,
    'MEDLER': 0,
    'MEDLEY': 0,
    'MEDLICOTT': 0,
    'MEDLIN': 0,
    'MEDLING': 0,
    'MEDLOCK': 0,
    'MEDLYN': 0,
    'MEDNICK': 0,
    'MEDO': 0,
    'MEDOFF': 0,
    'MEDOR': 0,
    'MEDORA': 0,
    'MEDORO': 0,
    'MEDOVICH': 0,
    'MEDOW': 0,
    'MEDOWS': 0,
    'MEDOZA': 0,
    'MEDRAN': 0,
    'MEDRANO': 0,
    'MEDRICK': 0,
    'MEDROW': 0,
    'MEDSGER': 0,
    'MEDSKER': 0,
    'MEDUGNO': 0,
    'MEDUNA': 0,
    'MEDURE': 0,
    'MEDURI': 0,
    'MEDVE': 0,
    'MEDVEC': 0,
    'MEDVED': 0,
    'MEDVEDEV': 0,
    'MEDVETZ': 0,
    'MEDVID': 0,
    'MEDVIN': 0,
    'MEDVITZ': 0,
    'MEDWAY': 0,
    'MEDWICK': 0,
    'MEDWID': 0,
    'MEDWIN': 0,
    'MEE': 0.7894736842105263,
    'MEECE': 0,
    'MEECH': 0,
    'MEECHAN': 0,
    'MEED': 0,
    'MEEDER': 0,
    'MEEDS': 0,
    'MEEGAN': 0,
    'MEEH': 0,
    'MEEHAN': 0,
    'MEEHL': 0,
    'MEEK': 0,
    'MEEKER': 0,
    'MEEKHOF': 0,
    'MEEKIN': 0,
    'MEEKINS': 0,
    'MEEKMA': 0,
    'MEEKS': 0,
    'MEELER': 0,
    'MEELY': 0,
    'MEEMKEN': 0,
    'MEENA': 0,
    'MEENACH': 0,
    'MEENAN': 0,
    'MEENDERING': 0,
    'MEENEN': 0,
    'MEENGS': 0,
    'MEENTS': 0,
    'MEER': 0,
    'MEERDINK': 0,
    'MEERE': 0,
    'MEERMAN': 0,
    'MEERS': 0,
    'MEERSCHAERT': 0,
    'MEERSMAN': 0,
    'MEERT': 0,
    'MEES': 0,
    'MEESE': 0,
    'MEESKE': 0,
    'MEESTER': 0,
    'MEETER': 0,
    'MEETH': 0,
    'MEETZ': 0,
    'MEETZE': 0,
    'MEEUSEN': 0,
    'MEEUWSEN': 0,
    'MEEVES': 0,
    'MEFFERD': 0,
    'MEFFERT': 0,
    'MEFFORD': 0,
    'MEG': 1,
    'MEGA': 0,
    'MEGAHAN': 0,
    'MEGALE': 0,
    'MEGAN': 0.9985734664764622,
    'MEGARGEE': 0,
    'MEGARGEL': 0,
    'MEGARO': 0,
    'MEGAS': 0,
    'MEGASON': 0,
    'MEGEE': 0,
    'MEGEHEE': 0,
    'MEGEL': 0,
    'MEGENITY': 0,
    'MEGER': 0,
    'MEGERDICHIAN': 0,
    'MEGERLE': 0,
    'MEGGAN': 1,
    'MEGGERS': 0,
    'MEGGETT': 0,
    'MEGGINSON': 0,
    'MEGGISON': 0,
    'MEGGITT': 0,
    'MEGGS': 0,
    'MEGHAN': 1,
    'MEGHANI': 0,
    'MEGHANN': 1,
    'MEGIA': 0,
    'MEGILL': 0,
    'MEGINLEY': 0,
    'MEGINNIS': 0,
    'MEGIVERN': 0,
    'MEGLI': 0,
    'MEGLIO': 0,
    'MEGNA': 0,
    'MEGO': 0,
    'MEGOW': 0,
    'MEGOWAN': 0,
    'MEGOWN': 0,
    'MEGRATH': 0,
    'MEGUIAR': 0,
    'MEGUIRE': 0,
    'MEGYESI': 0,
    'MEHAFFEY': 0,
    'MEHAFFIE': 0,
    'MEHAFFY': 0,
    'MEHAL': 0,
    'MEHALIC': 0,
    'MEHALICK': 0,
    'MEHALIK': 0,
    'MEHALKO': 0,
    'MEHALL': 0,
    'MEHAN': 0,
    'MEHARG': 0,
    'MEHARI': 0,
    'MEHARRY': 0,
    'MEHAS': 0,
    'MEHDI': 0,
    'MEHDIZADEH': 0,
    'MEHEGAN': 0,
    'MEHER': 0,
    'MEHERG': 0,
    'MEHIC': 0,
    'MEHIGAN': 0,
    'MEHL': 0,
    'MEHLBERG': 0,
    'MEHLBRECH': 0,
    'MEHLE': 0,
    'MEHLENBACHER': 0,
    'MEHLER': 0,
    'MEHLHAFF': 0,
    'MEHLHOFF': 0,
    'MEHLHOP': 0,
    'MEHLHORN': 0,
    'MEHLIG': 0,
    'MEHLIN': 0,
    'MEHLING': 0,
    'MEHLMAN': 0,
    'MEHLTRETTER': 0,
    'MEHM': 0,
    'MEHMEDI': 0,
    'MEHMEDOVIC': 0,
    'MEHMEN': 0,
    'MEHMET': 0,
    'MEHMETI': 0,
    'MEHMOOD': 0,
    'MEHN': 0,
    'MEHNE': 0,
    'MEHNER': 0,
    'MEHNERT': 0,
    'MEHOK': 0,
    'MEHOLIC': 0,
    'MEHOLICK': 0,
    'MEHR': 0,
    'MEHRA': 0,
    'MEHRABI': 0,
    'MEHRABIAN': 0,
    'MEHRAN': 0,
    'MEHREN': 0,
    'MEHRENS': 0,
    'MEHRER': 0,
    'MEHRHOFF': 0,
    'MEHRING': 0,
    'MEHRINGER': 0,
    'MEHRKENS': 0,
    'MEHRMAN': 0,
    'MEHRMANN': 0,
    'MEHROTRA': 0,
    'MEHRTENS': 0,
    'MEHTA': 0,
    'MEHU': 0,
    'MEHUS': 0,
    'MEI': 0.7374631268436579,
    'MEICHER': 0,
    'MEICHTRY': 0,
    'MEIDAM': 0,
    'MEIDE': 0,
    'MEIDELL': 0,
    'MEIDENBAUER': 0,
    'MEIDINGER': 0,
    'MEIDL': 0,
    'MEIDLINGER': 0,
    'MEIER': 0,
    'MEIERHOFER': 0,
    'MEIERHOFF': 0,
    'MEIEROTTO': 0,
    'MEIERS': 0,
    'MEIGEL': 0,
    'MEIGGS': 0,
    'MEIGHAN': 0,
    'MEIGHEN': 0,
    'MEIGS': 0,
    'MEIHLS': 0,
    'MEIJER': 0,
    'MEIKLE': 0,
    'MEIKLEJOHN': 0,
    'MEIL': 0,
    'MEILAHN': 0,
    'MEILE': 0,
    'MEILER': 0,
    'MEILI': 0,
    'MEILINGER': 0,
    'MEILLER': 0,
    'MEILLEUR': 0,
    'MEILS': 0,
    'MEILY': 0,
    'MEIMAN': 0,
    'MEIN': 0,
    'MEINBERG': 0,
    'MEINCKE': 0,
    'MEINDERS': 0,
    'MEINDL': 0,
    'MEINE': 0,
    'MEINECKE': 0,
    'MEINEKE': 0,
    'MEINEL': 0,
    'MEINEMA': 0,
    'MEINEN': 0,
    'MEINER': 0,
    'MEINERDING': 0,
    'MEINERS': 0,
    'MEINERSHAGEN': 0,
    'MEINERT': 0,
    'MEINHARD': 0,
    'MEINHARDT': 0,
    'MEINHART': 0,
    'MEINHOLD': 0,
    'MEINHOLZ': 0,
    'MEINIG': 0,
    'MEININGER': 0,
    'MEINKE': 0,
    'MEINKEN': 0,
    'MEINKING': 0,
    'MEINS': 0,
    'MEINSEN': 0,
    'MEINTEL': 0,
    'MEINTS': 0,
    'MEINTZ': 0,
    'MEINTZER': 0,
    'MEINZ': 0,
    'MEINZER': 0,
    'MEIR': 0,
    'MEIRA': 0,
    'MEIRELES': 0,
    'MEIRICK': 0,
    'MEIRING': 0,
    'MEIROSE': 0,
    'MEIS': 0,
    'MEISBERGER': 0,
    'MEISCH': 0,
    'MEISE': 0,
    'MEISEL': 0,
    'MEISELMAN': 0,
    'MEISELS': 0,
    'MEISENBACH': 0,
    'MEISENBURG': 0,
    'MEISENHEIMER': 0,
    'MEISENHELDER': 0,
    'MEISENHOLDER': 0,
    'MEISENZAHL': 0,
    'MEISER': 0,
    'MEISINGER': 0,
    'MEISLER': 0,
    'MEISMER': 0,
    'MEISNER': 0,
    'MEISS': 0,
    'MEISSEN': 0,
    'MEISSNER': 0,
    'MEISTE': 0,
    'MEISTER': 0,
    'MEISTRELL': 0,
    'MEITL': 0,
    'MEITLER': 0,
    'MEITNER': 0,
    'MEITZ': 0,
    'MEITZEN': 0,
    'MEITZLER': 0,
    'MEITZNER': 0,
    'MEIVES': 0,
    'MEIWES': 0,
    'MEIXEL': 0,
    'MEIXELL': 0,
    'MEIXNER': 0,
    'MEIXSELL': 0,
    'MEJEAN': 0,
    'MEJEUR': 0,
    'MEJIA': 0,
    'MEJIAS': 0,
    'MEJICANOS': 0,
    'MEJILLA': 0,
    'MEJORADA': 0,
    'MEJORADO': 0,
    'MEKA': 0,
    'MEKEEL': 0,
    'MEKELBURG': 0,
    'MEKHAIL': 0,
    'MEKIC': 0,
    'MEKLER': 0,
    'MEKO': 0,
    'MEKONEN': 0,
    'MEKONNEN': 0,
    'MEKURIA': 0,
    'MEKUS': 0,
    'MEL': 0.984251968503937,
    'MELA': 0,
    'MELAAS': 0,
    'MELADY': 0,
    'MELAHN': 0,
    'MELAINE': 1,
    'MELAKU': 0,
    'MELAMED': 0,
    'MELAMPY': 0,
    'MELAMUD': 0,
    'MELAN': 0,
    'MELANCON': 0,
    'MELAND': 0,
    'MELANDER': 0,
    'MELANI': 0.9345794392523364,
    'MELANIA': 1,
    'MELANIE': 1,
    'MELANO': 0,
    'MELANSON': 0,
    'MELANY': 1,
    'MELARA': 0,
    'MELARAGNI': 0,
    'MELARAGNO': 0,
    'MELAS': 0,
    'MELBA': 1,
    'MELBER': 0,
    'MELBERG': 0,
    'MELBERT': 0,
    'MELBOURNE': 0,
    'MELBY': 0,
    'MELBYE': 0,
    'MELCER': 0,
    'MELCHER': 0,
    'MELCHERT': 0,
    'MELCHI': 0,
    'MELCHIN': 0,
    'MELCHING': 0,
    'MELCHIONDA': 0,
    'MELCHIONE': 0,
    'MELCHIONNA': 0,
    'MELCHIONNE': 0,
    'MELCHIONNO': 0,
    'MELCHIOR': 0,
    'MELCHIORE': 0,
    'MELCHIORI': 0,
    'MELCHIORRE': 0,
    'MELCHOR': 0,
    'MELDA': 1,
    'MELDAHL': 0,
    'MELDE': 0,
    'MELDER': 0,
    'MELDON': 0,
    'MELDRUM': 0,
    'MELE': 0,
    'MELEAN': 0,
    'MELEAR': 0,
    'MELECIO': 0,
    'MELEEN': 0,
    'MELEGA': 0,
    'MELEK': 0,
    'MELEN': 0,
    'MELENA': 0,
    'MELENCIANO': 0,
    'MELENDES': 0,
    'MELENDEZ': 0,
    'MELENDRES': 0,
    'MELENDREZ': 0,
    'MELENDY': 0,
    'MELENEY': 0,
    'MELEO': 0,
    'MELER': 0,
    'MELERINE': 0,
    'MELERO': 0,
    'MELES': 0,
    'MELESIO': 0,
    'MELESKI': 0,
    'MELESKY': 0,
    'MELEWSKI': 0,
    'MELEY': 0,
    'MELFA': 0,
    'MELFI': 0,
    'MELFORD': 0,
    'MELGAARD': 0,
    'MELGAR': 0,
    'MELGARD': 0,
    'MELGAREJO': 0,
    'MELGARES': 0,
    'MELGOSA': 0,
    'MELGOZA': 0,
    'MELGREN': 0,
    'MELHADO': 0,
    'MELHEM': 0,
    'MELHORN': 0,
    'MELHOUSE': 0,
    'MELHUISH': 0,
    'MELHUS': 0,
    'MELI': 0,
    'MELIA': 0.5882352941176471,
    'MELIAN': 0,
    'MELICAN': 0,
    'MELICH': 0,
    'MELICHAR': 0,
    'MELICK': 0,
    'MELIDA': 1,
    'MELIGAN': 0,
    'MELIK': 0,
    'MELIKIAN': 0,
    'MELIKYAN': 0,
    'MELILLI': 0,
    'MELILLO': 0,
    'MELIM': 0,
    'MELIN': 0,
    'MELINA': 0.9756097560975611,
    'MELINDA': 1,
    'MELINDEZ': 0,
    'MELINE': 0,
    'MELING': 0,
    'MELINO': 0,
    'MELIO': 0,
    'MELIS': 0,
    'MELISA': 1,
    'MELISH': 0,
    'MELISI': 0,
    'MELISSA': 0.9998701467341904,
    'MELISSIA': 1,
    'MELITA': 0.8928571428571428,
    'MELITO': 0,
    'MELIUS': 0,
    'MELKA': 0,
    'MELKE': 0,
    'MELKER': 0,
    'MELKI': 0,
    'MELKO': 0,
    'MELKONIAN': 0,
    'MELKONYAN': 0,
    'MELKUS': 0,
    'MELL': 0,
    'MELLA': 0,
    'MELLACE': 0,
    'MELLADO': 0,
    'MELLADY': 0,
    'MELLAN': 0,
    'MELLAND': 0,
    'MELLARD': 0,
    'MELLAS': 0,
    'MELLBERG': 0,
    'MELLE': 0,
    'MELLECKER': 0,
    'MELLEM': 0,
    'MELLEMA': 0,
    'MELLEN': 0,
    'MELLENBRUCH': 0,
    'MELLENCAMP': 0,
    'MELLENDORF': 0,
    'MELLENTHIN': 0,
    'MELLENTINE': 0,
    'MELLER': 0,
    'MELLERSON': 0,
    'MELLERT': 0,
    'MELLETT': 0,
    'MELLETTE': 0,
    'MELLEY': 0,
    'MELLGREN': 0,
    'MELLI': 0,
    'MELLICK': 0,
    'MELLIE': 1,
    'MELLIES': 0,
    'MELLIGAN': 0,
    'MELLIN': 0,
    'MELLINA': 0,
    'MELLING': 0,
    'MELLINGER': 0,
    'MELLINO': 0,
    'MELLION': 0,
    'MELLIS': 0,
    'MELLISA': 1,
    'MELLISH': 0,
    'MELLISSA': 1,
    'MELLMAN': 0,
    'MELLO': 0,
    'MELLODY': 0,
    'MELLOH': 0,
    'MELLON': 0,
    'MELLONE': 0,
    'MELLONI': 0,
    'MELLONS': 0,
    'MELLOR': 0,
    'MELLORS': 0,
    'MELLOS': 0,
    'MELLOTT': 0,
    'MELLOW': 0,
    'MELLOY': 0,
    'MELLS': 0,
    'MELLUM': 0,
    'MELLUSI': 0,
    'MELLUZZO': 0,
    'MELLY': 0,
    'MELMAN': 0,
    'MELMED': 0,
    'MELMER': 0,
    'MELMS': 0,
    'MELNAR': 0,
    'MELNICHENKO': 0,
    'MELNICHUK': 0,
    'MELNICK': 0,
    'MELNIK': 0,
    'MELNIKOFF': 0,
    'MELNIKOV': 0,
    'MELNYCHUK': 0,
    'MELNYK': 0,
    'MELO': 0,
    'MELOCHE': 0,
    'MELODEE': 1,
    'MELODI': 1,
    'MELODIA': 0,
    'MELODIE': 1,
    'MELODY': 0.9938382031405287,
    'MELOHN': 0,
    'MELON': 0,
    'MELONAS': 0,
    'MELONE': 0,
    'MELONEY': 0,
    'MELONI': 0,
    'MELONIE': 1,
    'MELONSON': 0,
    'MELONY': 1,
    'MELOON': 0,
    'MELORO': 0,
    'MELOT': 0,
    'MELOTT': 0,
    'MELOTTE': 0,
    'MELOW': 0,
    'MELOY': 0,
    'MELQUIST': 0,
    'MELRATH': 0,
    'MELROSE': 0,
    'MELROY': 0,
    'MELSER': 0,
    'MELSHA': 0,
    'MELSHEIMER': 0,
    'MELSNESS': 0,
    'MELSON': 0,
    'MELSTROM': 0,
    'MELTABARGER': 0,
    'MELTER': 0,
    'MELTESEN': 0,
    'MELTON': 0,
    'MELTSER': 0,
    'MELTZ': 0,
    'MELTZER': 0,
    'MELUCCI': 0,
    'MELUCH': 0,
    'MELUGIN': 0,
    'MELUM': 0,
    'MELUSKEY': 0,
    'MELUSKY': 0,
    'MELUSO': 0,
    'MELVA': 1,
    'MELVILLE': 0,
    'MELVIN': 0.9574718045112782,
    'MELVINA': 1,
    'MELWANI': 0,
    'MELYNDA': 1,
    'MELZ': 0,
    'MELZER': 0,
    'MEMA': 0,
    'MEMBERS': 0,
    'MEMBRENO': 0,
    'MEMBRERE': 0,
    'MEMBRILA': 0,
    'MEMBRINO': 0,
    'MEME': 0,
    'MEMERING': 0,
    'MEMIC': 0,
    'MEMIJE': 0,
    'MEMINGER': 0,
    'MEMMEL': 0,
    'MEMMELAAR': 0,
    'MEMMER': 0,
    'MEMMINGER': 0,
    'MEMMO': 0,
    'MEMMOLO': 0,
    'MEMMOTT': 0,
    'MEMOLI': 0,
    'MEMOLO': 0,
    'MEMON': 0,
    'MEMORY': 0,
    'MEMS': 0,
    'MEN': 0,
    'MENA': 0,
    'MENACHER': 0,
    'MENACHO': 0,
    'MENADUE': 0,
    'MENAGH': 0,
    'MENAKER': 0,
    'MENAPACE': 0,
    'MENARD': 0,
    'MENARY': 0,
    'MENAS': 0,
    'MENASCO': 0,
    'MENASHE': 0,
    'MENBRENO': 0,
    'MENCARELLI': 0,
    'MENCARINI': 0,
    'MENCEL': 0,
    'MENCER': 0,
    'MENCH': 0,
    'MENCHACA': 0,
    'MENCHEL': 0,
    'MENCHEN': 0,
    'MENCHER': 0,
    'MENCHEY': 0,
    'MENCHHOFER': 0,
    'MENCHU': 0,
    'MENCIA': 0,
    'MENCIAS': 0,
    'MENCK': 0,
    'MENCKE': 0,
    'MENCL': 0,
    'MENCONI': 0,
    'MENCOS': 0,
    'MENCY': 0,
    'MENDA': 0,
    'MENDALL': 0,
    'MENDE': 0,
    'MENDEL': 0,
    'MENDELL': 0,
    'MENDELOWITZ': 0,
    'MENDELSOHN': 0,
    'MENDELSON': 0,
    'MENDEN': 0,
    'MENDENALL': 0,
    'MENDENHALL': 0,
    'MENDER': 0,
    'MENDES': 0,
    'MENDEZ': 0,
    'MENDEZLOPEZ': 0,
    'MENDHAM': 0,
    'MENDHEIM': 0,
    'MENDIA': 0,
    'MENDIAS': 0,
    'MENDIAZ': 0,
    'MENDIBLES': 0,
    'MENDICINO': 0,
    'MENDICK': 0,
    'MENDIETA': 0,
    'MENDIETTA': 0,
    'MENDILLO': 0,
    'MENDIOLA': 0,
    'MENDIS': 0,
    'MENDITTO': 0,
    'MENDIVE': 0,
    'MENDIVIL': 0,
    'MENDIZABAL': 0,
    'MENDLER': 0,
    'MENDLIK': 0,
    'MENDLOVIC': 0,
    'MENDLOWITZ': 0,
    'MENDO': 0,
    'MENDOCA': 0,
    'MENDOLA': 0,
    'MENDOLERA': 0,
    'MENDOLIA': 0,
    'MENDONCA': 0,
    'MENDONSA': 0,
    'MENDONZA': 0,
    'MENDOSA': 0,
    'MENDOZ': 0,
    'MENDOZA': 0,
    'MENDOZAGARCIA': 0,
    'MENDOZAMENDOZA': 0,
    'MENDRALA': 0,
    'MENDRICK': 0,
    'MENDRIN': 0,
    'MENDS': 0,
    'MENDY': 0.9433962264150944,
    'MENDYK': 0,
    'MENDYKA': 0,
    'MENE': 0,
    'MENEAR': 0,
    'MENECES': 0,
    'MENEDEZ': 0,
    'MENEELY': 0,
    'MENEES': 0,
    'MENEESE': 0,
    'MENEFEE': 0,
    'MENEFIELD': 0,
    'MENEGAY': 0,
    'MENEGHETTI': 0,
    'MENEGHIN': 0,
    'MENEGHINI': 0,
    'MENEGUS': 0,
    'MENELAS': 0,
    'MENELEY': 0,
    'MENENDEZ': 0,
    'MENERA': 0,
    'MENEREY': 0,
    'MENES': 0,
    'MENESES': 0,
    'MENESSES': 0,
    'MENEZ': 0,
    'MENEZES': 0,
    'MENG': 0,
    'MENGARELLI': 0,
    'MENGE': 0,
    'MENGEL': 0,
    'MENGELKOCH': 0,
    'MENGER': 0,
    'MENGERINK': 0,
    'MENGERS': 0,
    'MENGERT': 0,
    'MENGES': 0,
    'MENGESHA': 0,
    'MENGHINI': 0,
    'MENGIS': 0,
    'MENGISTU': 0,
    'MENGLE': 0,
    'MENGLER': 0,
    'MENGWASSER': 0,
    'MENHART': 0,
    'MENHENNETT': 0,
    'MENICHETTI': 0,
    'MENICHINI': 0,
    'MENICK': 0,
    'MENICUCCI': 0,
    'MENIER': 0,
    'MENIFEE': 0,
    'MENIFIELD': 0,
    'MENIG': 0,
    'MENIN': 0,
    'MENINGER': 0,
    'MENINNO': 0,
    'MENIS': 0,
    'MENIUS': 0,
    'MENIX': 0,
    'MENJARES': 0,
    'MENJIBAR': 0,
    'MENJIVAR': 0,
    'MENK': 0,
    'MENKE': 0,
    'MENKEL': 0,
    'MENKEN': 0,
    'MENKER': 0,
    'MENKES': 0,
    'MENKHAUS': 0,
    'MENKIN': 0,
    'MENKING': 0,
    'MENKO': 0,
    'MENLEY': 0,
    'MENLOVE': 0,
    'MENN': 0,
    'MENNA': 0,
    'MENNE': 0,
    'MENNECKE': 0,
    'MENNEL': 0,
    'MENNELL': 0,
    'MENNELLA': 0,
    'MENNEMEYER': 0,
    'MENNEN': 0,
    'MENNENGA': 0,
    'MENNER': 0,
    'MENNES': 0,
    'MENNIE': 0,
    'MENNIG': 0,
    'MENNILLO': 0,
    'MENNING': 0,
    'MENNINGA': 0,
    'MENNINGER': 0,
    'MENNIS': 0,
    'MENNITI': 0,
    'MENNO': 0,
    'MENNONA': 0,
    'MENNUTI': 0,
    'MENO': 0,
    'MENOCAL': 0,
    'MENOLD': 0,
    'MENON': 0,
    'MENOR': 0,
    'MENOS': 0,
    'MENOSKY': 0,
    'MENOTTI': 0,
    'MENOUGH': 0,
    'MENOZZI': 0,
    'MENS': 0,
    'MENSAH': 0,
    'MENSCH': 0,
    'MENSCHING': 0,
    'MENSE': 0,
    'MENSEN': 0,
    'MENSER': 0,
    'MENSH': 0,
    'MENSHOUSE': 0,
    'MENSI': 0,
    'MENSIK': 0,
    'MENSING': 0,
    'MENSINGER': 0,
    'MENSINK': 0,
    'MENSON': 0,
    'MENSSEN': 0,
    'MENSTER': 0,
    'MENTA': 0,
    'MENTADO': 0,
    'MENTCH': 0,
    'MENTE': 0,
    'MENTEER': 0,
    'MENTEL': 0,
    'MENTELE': 0,
    'MENTEN': 0,
    'MENTER': 0,
    'MENTESANA': 0,
    'MENTGEN': 0,
    'MENTH': 0,
    'MENTING': 0,
    'MENTINK': 0,
    'MENTION': 0,
    'MENTIS': 0,
    'MENTO': 0,
    'MENTON': 0,
    'MENTOR': 0,
    'MENTORE': 0,
    'MENTUS': 0,
    'MENTZ': 0,
    'MENTZEL': 0,
    'MENTZER': 0,
    'MENUEY': 0,
    'MENY': 0,
    'MENYWEATHER': 0,
    'MENZ': 0,
    'MENZA': 0,
    'MENZE': 0,
    'MENZEL': 0,
    'MENZER': 0,
    'MENZIA': 0,
    'MENZIE': 0,
    'MENZIES': 0,
    'MENZO': 0,
    'MEO': 0,
    'MEOLA': 0,
    'MEOLI': 0,
    'MEONI': 0,
    'MEONO': 0,
    'MEPHAM': 0,
    'MEPPELINK': 0,
    'MEPPEN': 0,
    'MER': 0,
    'MERA': 0,
    'MERACLE': 0,
    'MERAM': 0,
    'MERAN': 0,
    'MERANDA': 0,
    'MERANDI': 0,
    'MERANDO': 0,
    'MERANTE': 0,
    'MERAS': 0,
    'MERAZ': 0,
    'MERBACH': 0,
    'MERCADAL': 0,
    'MERCADANTE': 0,
    'MERCADEL': 0,
    'MERCADER': 0,
    'MERCADO': 0,
    'MERCALDI': 0,
    'MERCALDO': 0,
    'MERCANDETTI': 0,
    'MERCANTE': 0,
    'MERCARDO': 0,
    'MERCATANTE': 0,
    'MERCED': 0,
    'MERCEDE': 0,
    'MERCEDES': 0.9697325888921541,
    'MERCEDEZ': 0.9615384615384616,
    'MERCER': 0,
    'MERCERON': 0,
    'MERCHAIN': 0,
    'MERCHAN': 0,
    'MERCHANT': 0,
    'MERCHEN': 0,
    'MERCHLEWITZ': 0,
    'MERCIECA': 0,
    'MERCIER': 0,
    'MERCIK': 0,
    'MERCIL': 0,
    'MERCK': 0,
    'MERCKER': 0,
    'MERCKLE': 0,
    'MERCKLING': 0,
    'MERCOGLIANO': 0,
    'MERCULIEF': 0,
    'MERCURE': 0,
    'MERCURI': 0,
    'MERCURIO': 0,
    'MERCURIUS': 0,
    'MERCURO': 0,
    'MERCURY': 0,
    'MERCY': 0.9404388714733541,
    'MERDIAN': 0,
    'MERDINGER': 0,
    'MERDITH': 0,
    'MERE': 0,
    'MEREDITH': 0.7881538094100788,
    'MEREGILDO': 0,
    'MEREJO': 0,
    'MEREK': 0,
    'MEREL': 0,
    'MERENA': 0,
    'MERENDA': 0,
    'MERENDINO': 0,
    'MERENESS': 0,
    'MERES': 0,
    'MEREZ': 0,
    'MERFELD': 0,
    'MERGEL': 0,
    'MERGELE': 0,
    'MERGEN': 0,
    'MERGENER': 0,
    'MERGENS': 0,
    'MERGENTHAL': 0,
    'MERGENTHALER': 0,
    'MERGERSON': 0,
    'MERGES': 0,
    'MERGET': 0,
    'MERGIST': 0,
    'MERGL': 0,
    'MERGLER': 0,
    'MERGNER': 0,
    'MERHAR': 0,
    'MERHAUT': 0,
    'MERHI': 0,
    'MERHIGE': 0,
    'MERI': 0.9756097560975611,
    'MERIAM': 0,
    'MERIAN': 0,
    'MERICA': 0,
    'MERICAL': 0,
    'MERICK': 0,
    'MERICKEL': 0,
    'MERICLE': 0,
    'MERIDA': 0,
    'MERIDETH': 0.5882352941176471,
    'MERIDIETH': 0,
    'MERIDITH': 0.888888888888889,
    'MERIDY': 0,
    'MERIGOLD': 0,
    'MERILA': 0,
    'MERILLAT': 0,
    'MERILUS': 0,
    'MERILYN': 1,
    'MERIN': 0,
    'MERINAR': 0,
    'MERING': 0,
    'MERINGOLO': 0,
    'MERINO': 0,
    'MERIS': 0,
    'MERISIER': 0,
    'MERISSA': 1,
    'MERIT': 0,
    'MERITHEW': 0,
    'MERITT': 0,
    'MERIWEATHER': 0,
    'MERIWETHER': 0,
    'MERIZALDE': 0,
    'MERJIL': 0,
    'MERK': 0,
    'MERKA': 0,
    'MERKEL': 0,
    'MERKER': 0,
    'MERKERSON': 0,
    'MERKERT': 0,
    'MERKES': 0,
    'MERKEY': 0,
    'MERKIN': 0,
    'MERKINS': 0,
    'MERKISON': 0,
    'MERKL': 0,
    'MERKLE': 0,
    'MERKLEIN': 0,
    'MERKLER': 0,
    'MERKLEY': 0,
    'MERKLIN': 0,
    'MERKLING': 0,
    'MERKLINGER': 0,
    'MERKSON': 0,
    'MERKT': 0,
    'MERKWAN': 0,
    'MERL': 0,
    'MERLA': 0,
    'MERLAN': 0,
    'MERLAU': 0,
    'MERLE': 0.987045033929673,
    'MERLENE': 1,
    'MERLET': 0,
    'MERLEY': 0,
    'MERLI': 0,
    'MERLIN': 0.9544008483563097,
    'MERLINA': 0,
    'MERLINE': 0,
    'MERLING': 0,
    'MERLINI': 0,
    'MERLINO': 0,
    'MERLIS': 0,
    'MERLO': 0,
    'MERLOCK': 0,
    'MERLOS': 0,
    'MERLOTTI': 0,
    'MERLUZZI': 0,
    'MERLY': 0,
    'MERLYN': 1,
    'MERMAN': 0,
    'MERMELSTEIN': 0,
    'MERMER': 0,
    'MERMIS': 0,
    'MERNA': 0.9615384615384616,
    'MERNER': 0,
    'MERNICK': 0,
    'MERO': 0,
    'MEROLA': 0,
    'MEROLD': 0,
    'MEROLLA': 0,
    'MEROLLE': 0,
    'MEROLLI': 0,
    'MERON': 0,
    'MERONE': 0,
    'MERONEK': 0,
    'MERONEY': 0,
    'MERONK': 0,
    'MEROW': 0,
    'MERREL': 0,
    'MERRELL': 0,
    'MERREN': 0,
    'MERRETT': 0,
    'MERRI': 1,
    'MERRIAM': 0,
    'MERRICK': 0,
    'MERRICKS': 0,
    'MERRIE': 1,
    'MERRIEL': 0,
    'MERRIETT': 0,
    'MERRIFIELD': 0,
    'MERRIGAN': 0,
    'MERRIHEW': 0,
    'MERRIKEN': 0,
    'MERRILEE': 1,
    'MERRILL': 0.4593477262287552,
    'MERRILLS': 0,
    'MERRIMAN': 0,
    'MERRIN': 0,
    'MERRINER': 0,
    'MERRING': 0,
    'MERRION': 0,
    'MERRIOTT': 0,
    'MERRIS': 0,
    'MERRISS': 0,
    'MERRIT': 0,
    'MERRITHEW': 0,
    'MERRITT': 0,
    'MERRITTE': 0,
    'MERRITTS': 0,
    'MERRIWEATHER': 0,
    'MERRIWETHER': 0,
    'MERRON': 0,
    'MERROW': 0,
    'MERRY': 0.8363201911589009,
    'MERRYFIELD': 0,
    'MERRYMAN': 0,
    'MERRYWEATHER': 0,
    'MERS': 0,
    'MERSCH': 0,
    'MERSCHMAN': 0,
    'MERSEAL': 0,
    'MERSEREAU': 0,
    'MERSHIMER': 0,
    'MERSHON': 0,
    'MERSING': 0,
    'MERSINGER': 0,
    'MERSINO': 0,
    'MERSKI': 0,
    'MERSKY': 0,
    'MERSMAN': 0,
    'MERSMANN': 0,
    'MERSON': 0,
    'MERTA': 0,
    'MERTEL': 0,
    'MERTEN': 0,
    'MERTENS': 0,
    'MERTES': 0,
    'MERTH': 0,
    'MERTIE': 1,
    'MERTIN': 0,
    'MERTINS': 0,
    'MERTON': 0,
    'MERTUS': 0,
    'MERTZ': 0,
    'MERTZLUFFT': 0,
    'MERULLA': 0,
    'MERULLO': 0,
    'MERVA': 0,
    'MERVAR': 0,
    'MERVILLE': 0,
    'MERVIN': 0.9735744089012517,
    'MERVINE': 0,
    'MERVIS': 0,
    'MERVYN': 0,
    'MERWARTH': 0,
    'MERWIN': 0,
    'MERWINE': 0,
    'MERWORTH': 0,
    'MERY': 0,
    'MERYHEW': 0,
    'MERYL': 1,
    'MERZ': 0,
    'MERZA': 0,
    'MERZLAK': 0,
    'MESA': 0,
    'MESADIEU': 0,
    'MESAROS': 0,
    'MESBAH': 0,
    'MESCAL': 0,
    'MESCALL': 0,
    'MESCE': 0,
    'MESCH': 0,
    'MESCHEDE': 0,
    'MESCHER': 0,
    'MESCHI': 0,
    'MESCHINO': 0,
    'MESCHKE': 0,
    'MESE': 0,
    'MESEBERG': 0,
    'MESEC': 0,
    'MESECHER': 0,
    'MESECK': 0,
    'MESEKE': 0,
    'MESENBRINK': 0,
    'MESENBURG': 0,
    'MESEROLE': 0,
    'MESEROLL': 0,
    'MESERVE': 0,
    'MESERVEY': 0,
    'MESERVY': 0,
    'MESEY': 0,
    'MESFIN': 0,
    'MESH': 0,
    'MESHACK': 0,
    'MESHAW': 0,
    'MESHELL': 0,
    'MESHER': 0,
    'MESHESHA': 0,
    'MESHEW': 0,
    'MESHKE': 0,
    'MESHULAM': 0,
    'MESI': 0,
    'MESIA': 0,
    'MESIAS': 0,
    'MESIC': 0,
    'MESICH': 0,
    'MESICK': 0,
    'MESIDOR': 0,
    'MESIMER': 0,
    'MESINA': 0,
    'MESINAS': 0,
    'MESING': 0,
    'MESIROW': 0,
    'MESITI': 0,
    'MESKE': 0,
    'MESKEL': 0,
    'MESKELL': 0,
    'MESKER': 0,
    'MESKILL': 0,
    'MESKIMEN': 0,
    'MESKIN': 0,
    'MESKO': 0,
    'MESLER': 0,
    'MESLOH': 0,
    'MESMAN': 0,
    'MESMER': 0,
    'MESNARD': 0,
    'MESNER': 0,
    'MESNICK': 0,
    'MESONES': 0,
    'MESPLAY': 0,
    'MESQUITA': 0,
    'MESROBIAN': 0,
    'MESROPIAN': 0,
    'MESS': 0,
    'MESSA': 0,
    'MESSAM': 0,
    'MESSAMORE': 0,
    'MESSANA': 0,
    'MESSANO': 0,
    'MESSAROS': 0,
    'MESSBARGER': 0,
    'MESSEL': 0,
    'MESSELT': 0,
    'MESSEMER': 0,
    'MESSENGER': 0,
    'MESSER': 0,
    'MESSERE': 0,
    'MESSERICH': 0,
    'MESSERLE': 0,
    'MESSERLI': 0,
    'MESSERLY': 0,
    'MESSERSCHMIDT': 0,
    'MESSERSCHMITT': 0,
    'MESSERSMITH': 0,
    'MESSERVY': 0,
    'MESSETT': 0,
    'MESSEX': 0,
    'MESSIAH': 0,
    'MESSICK': 0,
    'MESSIER': 0,
    'MESSIHA': 0,
    'MESSIMER': 0,
    'MESSINA': 0,
    'MESSINEO': 0,
    'MESSING': 0,
    'MESSINGER': 0,
    'MESSINK': 0,
    'MESSINO': 0,
    'MESSLER': 0,
    'MESSMAN': 0,
    'MESSMANN': 0,
    'MESSMER': 0,
    'MESSMORE': 0,
    'MESSNER': 0,
    'MESSORE': 0,
    'MESSURI': 0,
    'MEST': 0,
    'MESTA': 0,
    'MESTAD': 0,
    'MESTANZA': 0,
    'MESTAS': 0,
    'MESTAYER': 0,
    'MESTAZ': 0,
    'MESTDAGH': 0,
    'MESTEL': 0,
    'MESTEMAKER': 0,
    'MESTER': 0,
    'MESTETH': 0,
    'MESTIZO': 0,
    'MESTON': 0,
    'MESTRE': 0,
    'MESTRES': 0,
    'MESTROVICH': 0,
    'MESZAROS': 0,
    'META': 0.9756097560975611,
    'METALLO': 0,
    'METAXAS': 0,
    'METAYER': 0,
    'METCALF': 0,
    'METCALFE': 0,
    'METE': 0,
    'METEER': 0,
    'METELLUS': 0,
    'METELSKI': 0,
    'METELUS': 0,
    'METER': 0,
    'METEVIA': 0,
    'METEVIER': 0,
    'METEYER': 0,
    'METH': 0,
    'METHE': 0,
    'METHENEY': 0,
    'METHENY': 0,
    'METHER': 0,
    'METHNER': 0,
    'METHOD': 0,
    'METHOT': 0,
    'METHVEN': 0,
    'METHVIN': 0,
    'METIVA': 0,
    'METIVIER': 0,
    'METKE': 0,
    'METKO': 0,
    'METLER': 0,
    'METOTT': 0,
    'METOXEN': 0,
    'METOYER': 0,
    'METRAS': 0,
    'METREJEAN': 0,
    'METRICK': 0,
    'METRO': 0,
    'METROKA': 0,
    'METROPOULOS': 0,
    'METROPULOS': 0,
    'METROS': 0,
    'METRY': 0,
    'METS': 0,
    'METSCH': 0,
    'METSCHER': 0,
    'METSCHKE': 0,
    'METSKER': 0,
    'METT': 0,
    'METTA': 0,
    'METTAM': 0,
    'METTE': 0,
    'METTEE': 0,
    'METTEER': 0,
    'METTEN': 0,
    'METTENBRINK': 0,
    'METTER': 0,
    'METTERNICH': 0,
    'METTERS': 0,
    'METTERT': 0,
    'METTES': 0,
    'METTETAL': 0,
    'METTILLE': 0,
    'METTING': 0,
    'METTLACH': 0,
    'METTLE': 0,
    'METTLEN': 0,
    'METTLER': 0,
    'METTLING': 0,
    'METTS': 0,
    'METTY': 0,
    'METZ': 0,
    'METZDORF': 0,
    'METZE': 0,
    'METZEL': 0,
    'METZEN': 0,
    'METZER': 0,
    'METZGAR': 0,
    'METZGER': 0,
    'METZIG': 0,
    'METZINGER': 0,
    'METZKE': 0,
    'METZKER': 0,
    'METZLER': 0,
    'METZMEIER': 0,
    'METZNER': 0,
    'MEUCCI': 0,
    'MEUCHEL': 0,
    'MEUDT': 0,
    'MEUER': 0,
    'MEULEMAN': 0,
    'MEULEMANS': 0,
    'MEULENBERG': 0,
    'MEULENERS': 0,
    'MEULER': 0,
    'MEULI': 0,
    'MEUNIER': 0,
    'MEURER': 0,
    'MEURET': 0,
    'MEURS': 0,
    'MEURY': 0,
    'MEUS': 0,
    'MEUSCHKE': 0,
    'MEUSE': 0,
    'MEUSEL': 0,
    'MEUSER': 0,
    'MEUSHAW': 0,
    'MEUTH': 0,
    'MEUWISSEN': 0,
    'MEUX': 0,
    'MEVERDEN': 0,
    'MEVES': 0,
    'MEVIS': 0,
    'MEVISSEN': 0,
    'MEVORAH': 0,
    'MEW': 0,
    'MEWBORN': 0,
    'MEWBOURN': 0,
    'MEWBOURNE': 0,
    'MEWES': 0,
    'MEWHINNEY': 0,
    'MEWHIRTER': 0,
    'MEWHORTER': 0,
    'MEWIS': 0,
    'MEWS': 0,
    'MEWSHAW': 0,
    'MEX': 0,
    'MEXIA': 0,
    'MEXICAN': 0,
    'MEXICANO': 0,
    'MEXICO': 0,
    'MEY': 0,
    'MEYE': 0,
    'MEYEN': 0,
    'MEYER': 0,
    'MEYERAAN': 0,
    'MEYERDIRK': 0,
    'MEYERHOEFFER': 0,
    'MEYERHOFER': 0,
    'MEYERHOFF': 0,
    'MEYERHOFFER': 0,
    'MEYERHOLTZ': 0,
    'MEYERHOLZ': 0,
    'MEYERING': 0,
    'MEYERINK': 0,
    'MEYEROWITZ': 0,
    'MEYERPETER': 0,
    'MEYERS': 0,
    'MEYERSON': 0,
    'MEYETTE': 0,
    'MEYLAN': 0,
    'MEYLE': 0,
    'MEYLER': 0,
    'MEYLOR': 0,
    'MEYN': 0,
    'MEYNARD': 0,
    'MEYO': 0,
    'MEYR': 0,
    'MEYRICK': 0,
    'MEYROWITZ': 0,
    'MEYSENBURG': 0,
    'MEYTHALER': 0,
    'MEZ': 0,
    'MEZA': 0,
    'MEZEI': 0,
    'MEZERA': 0,
    'MEZEY': 0,
    'MEZGER': 0,
    'MEZICK': 0,
    'MEZIERE': 0,
    'MEZO': 0,
    'MEZQUITA': 0,
    'MEZYK': 0,
    'MEZYNSKI': 0,
    'MEZZA': 0,
    'MEZZACAPO': 0,
    'MEZZACAPPA': 0,
    'MEZZANO': 0,
    'MEZZANOTTE': 0,
    'MEZZATESTA': 0,
    'MEZZELL': 0,
    'MEZZETTI': 0,
    'MEZZINA': 0,
    'MEZZO': 0,
    'MGUYEN': 0,
    'MHOON': 0,
    'MI': 0.9633911368015414,
    'MIA': 0.989399293286219,
    'MIAH': 0,
    'MIAL': 0,
    'MIALE': 0,
    'MIAN': 0,
    'MIANECKI': 0,
    'MIANI': 0,
    'MIANO': 0,
    'MIAO': 0,
    'MIARA': 0,
    'MIARECKI': 0,
    'MIARS': 0,
    'MIATA': 0,
    'MIAZGA': 0,
    'MICA': 0.9009009009009009,
    'MICAELA': 1,
    'MICAH': 1,
    'MICAL': 0,
    'MICALE': 0,
    'MICALETTI': 0,
    'MICALI': 0,
    'MICALIZZI': 0,
    'MICALLEF': 0,
    'MICAN': 0,
    'MICARI': 0,
    'MICCA': 0,
    'MICCHELLI': 0,
    'MICCI': 0,
    'MICCICHE': 0,
    'MICCIO': 0,
    'MICCIULLA': 0,
    'MICCO': 0,
    'MICCOLI': 0,
    'MICCOLIS': 0,
    'MICEK': 0,
    'MICELE': 0,
    'MICELI': 0,
    'MICELLI': 0,
    'MICETICH': 0,
    'MICH': 0,
    'MICHA': 0.9345794392523364,
    'MICHACA': 0,
    'MICHAEL': 0.9945059290025945,
    'MICHAELA': 0.99009900990099,
    'MICHAELE': 1,
    'MICHAELI': 0,
    'MICHAELIAN': 0,
    'MICHAELIDES': 0,
    'MICHAELIS': 0,
    'MICHAELS': 0,
    'MICHAELSEN': 0,
    'MICHAELSON': 0,
    'MICHAIL': 0,
    'MICHAL': 0.9478672985781991,
    'MICHALAK': 0,
    'MICHALCZYK': 0,
    'MICHALE': 1,
    'MICHALEC': 0,
    'MICHALEK': 0,
    'MICHALENKO': 0,
    'MICHALES': 0,
    'MICHALETZ': 0,
    'MICHALEWICZ': 0,
    'MICHALICEK': 0,
    'MICHALIK': 0,
    'MICHALISZYN': 0,
    'MICHALK': 0,
    'MICHALKA': 0,
    'MICHALKE': 0,
    'MICHALKIEWICZ': 0,
    'MICHALKO': 0,
    'MICHALOPOULOS': 0,
    'MICHALOS': 0,
    'MICHALOSKI': 0,
    'MICHALOWICZ': 0,
    'MICHALOWSKI': 0,
    'MICHALS': 0,
    'MICHALSEN': 0,
    'MICHALSKI': 0,
    'MICHALSKY': 0,
    'MICHALSON': 0,
    'MICHALUK': 0,
    'MICHAM': 0,
    'MICHAS': 0,
    'MICHAU': 0,
    'MICHAUD': 0,
    'MICHAUX': 0,
    'MICHE': 0,
    'MICHEAL': 1,
    'MICHEALS': 0,
    'MICHEAU': 0,
    'MICHEAUX': 0,
    'MICHEEL': 0,
    'MICHEELS': 0,
    'MICHEL': 0.6372325898953117,
    'MICHELA': 0,
    'MICHELE': 0.9986225895316804,
    'MICHELENA': 0,
    'MICHELET': 0,
    'MICHELETTI': 0,
    'MICHELETTO': 0,
    'MICHELFELDER': 0,
    'MICHELI': 0,
    'MICHELICH': 0,
    'MICHELIN': 0,
    'MICHELINA': 1,
    'MICHELINE': 1,
    'MICHELINI': 0,
    'MICHELIS': 0,
    'MICHELL': 0.8998875140607424,
    'MICHELLE': 0.9994415451866971,
    'MICHELLI': 0,
    'MICHELMAN': 0,
    'MICHELON': 0,
    'MICHELOTTI': 0,
    'MICHELS': 0,
    'MICHELSEN': 0,
    'MICHELSON': 0,
    'MICHENER': 0,
    'MICHETTI': 0,
    'MICHI': 0,
    'MICHIE': 0,
    'MICHIELLI': 0,
    'MICHIELS': 0,
    'MICHIELSEN': 0,
    'MICHIENZI': 0,
    'MICHIKO': 1,
    'MICHITSCH': 0,
    'MICHL': 0,
    'MICHLER': 0,
    'MICHLIG': 0,
    'MICHLIK': 0,
    'MICHLIN': 0,
    'MICHLITSCH': 0,
    'MICHNA': 0,
    'MICHNER': 0,
    'MICHNIAK': 0,
    'MICHNIEWICZ': 0,
    'MICHNO': 0,
    'MICHO': 0,
    'MICHOLS': 0,
    'MICHON': 0,
    'MICHONSKI': 0,
    'MICHOS': 0,
    'MICHOT': 0,
    'MICHUDA': 0,
    'MICIC': 0,
    'MICIK': 0,
    'MICINSKI': 0,
    'MICIOTTO': 0,
    'MICK': 0,
    'MICKA': 0,
    'MICKAN': 0,
    'MICKE': 0,
    'MICKEL': 0,
    'MICKELBERRY': 0,
    'MICKELL': 0,
    'MICKELS': 0,
    'MICKELSEN': 0,
    'MICKELSON': 0,
    'MICKEN': 0,
    'MICKENS': 0,
    'MICKEY': 0.9263547938860583,
    'MICKI': 1,
    'MICKIE': 0.9740259740259739,
    'MICKIEWICZ': 0,
    'MICKINS': 0,
    'MICKLAS': 0,
    'MICKLE': 0,
    'MICKLER': 0,
    'MICKLES': 0,
    'MICKLEWRIGHT': 0,
    'MICKLEY': 0,
    'MICKLICH': 0,
    'MICKLIN': 0,
    'MICKLO': 0,
    'MICKLOS': 0,
    'MICKLOW': 0,
    'MICKLUS': 0,
    'MICKO': 0,
    'MICKOW': 0,
    'MICKS': 0,
    'MICKSCHL': 0,
    'MICKUNAS': 0,
    'MICKUS': 0,
    'MICLAT': 0,
    'MICLETTE': 0,
    'MICO': 0,
    'MICOL': 0,
    'MICOLICHEK': 0,
    'MICONI': 0,
    'MICOU': 0,
    'MICOZZI': 0,
    'MICTHELL': 0,
    'MICU': 0,
    'MICUCCI': 0,
    'MICULKA': 0,
    'MIDA': 0,
    'MIDAS': 0,
    'MIDAY': 0,
    'MIDBOE': 0,
    'MIDCAP': 0,
    'MIDDAGH': 0,
    'MIDDAUGH': 0,
    'MIDDELTON': 0,
    'MIDDEN': 0,
    'MIDDENDORF': 0,
    'MIDDLE': 0,
    'MIDDLEBROOK': 0,
    'MIDDLEBROOKS': 0,
    'MIDDLECAMP': 0,
    'MIDDLEKAUFF': 0,
    'MIDDLEMAN': 0,
    'MIDDLEMAS': 0,
    'MIDDLEMISS': 0,
    'MIDDLESTADT': 0,
    'MIDDLESTEAD': 0,
    'MIDDLESWART': 0,
    'MIDDLESWORTH': 0,
    'MIDDLETON': 0,
    'MIDDOUR': 0,
    'MIDENCE': 0,
    'MIDGET': 0,
    'MIDGETT': 0,
    'MIDGETTE': 0,
    'MIDGLEY': 0,
    'MIDILI': 0,
    'MIDIRI': 0,
    'MIDKIFF': 0,
    'MIDLAM': 0,
    'MIDLAND': 0,
    'MIDLER': 0,
    'MIDOLO': 0,
    'MIDTHUN': 0,
    'MIDURA': 0,
    'MIDWOOD': 0,
    'MIDY': 0,
    'MIDYETT': 0,
    'MIDYETTE': 0,
    'MIEARS': 0,
    'MIECH': 0,
    'MIECZKOWSKI': 0,
    'MIECZNIKOWSKI': 0,
    'MIEDEL': 0,
    'MIEDEMA': 0,
    'MIEDZINSKI': 0,
    'MIEHE': 0,
    'MIEHL': 0,
    'MIEHLE': 0,
    'MIEHLKE': 0,
    'MIEL': 0,
    'MIELCAREK': 0,
    'MIELCZAREK': 0,
    'MIELE': 0,
    'MIELENZ': 0,
    'MIELES': 0,
    'MIELKE': 0,
    'MIELL': 0,
    'MIELNICKI': 0,
    'MIELNIK': 0,
    'MIER': 0,
    'MIERA': 0,
    'MIERAS': 0,
    'MIERAU': 0,
    'MIERENDORF': 0,
    'MIERISCH': 0,
    'MIERKE': 0,
    'MIERNICKI': 0,
    'MIEROP': 0,
    'MIEROW': 0,
    'MIERS': 0,
    'MIERSMA': 0,
    'MIERTSCHIN': 0,
    'MIERZEJEWSKI': 0,
    'MIERZWA': 0,
    'MIERZWINSKI': 0,
    'MIES': 0,
    'MIESBAUER': 0,
    'MIESCH': 0,
    'MIESEL': 0,
    'MIESEN': 0,
    'MIESES': 0,
    'MIESHA': 1,
    'MIESKE': 0,
    'MIESNER': 0,
    'MIESS': 0,
    'MIESSE': 0,
    'MIESSNER': 0,
    'MIESZALA': 0,
    'MIETH': 0,
    'MIETHE': 0,
    'MIETTINEN': 0,
    'MIETUS': 0,
    'MIETZ': 0,
    'MIETZNER': 0,
    'MIEURE': 0,
    'MIFFLIN': 0,
    'MIFSUD': 0,
    'MIFTARI': 0,
    'MIGA': 0,
    'MIGACZ': 0,
    'MIGALA': 0,
    'MIGAS': 0,
    'MIGDAL': 0,
    'MIGDALIA': 1,
    'MIGDOL': 0,
    'MIGEL': 0,
    'MIGET': 0,
    'MIGGINS': 0,
    'MIGHELL': 0,
    'MIGHT': 0,
    'MIGHTY': 0,
    'MIGITA': 0,
    'MIGL': 0,
    'MIGLIACCI': 0,
    'MIGLIACCIO': 0,
    'MIGLIANO': 0,
    'MIGLIARA': 0,
    'MIGLIARESE': 0,
    'MIGLIARO': 0,
    'MIGLIAZZO': 0,
    'MIGLIETTA': 0,
    'MIGLIN': 0,
    'MIGLINO': 0,
    'MIGLIO': 0,
    'MIGLIONICO': 0,
    'MIGLIORATO': 0,
    'MIGLIORE': 0,
    'MIGLIORI': 0,
    'MIGLIORINI': 0,
    'MIGLIORINO': 0,
    'MIGLIORISI': 0,
    'MIGLIOZZI': 0,
    'MIGNACCA': 0,
    'MIGNANELLI': 0,
    'MIGNANO': 0,
    'MIGNAULT': 0,
    'MIGNEAULT': 0,
    'MIGNECO': 0,
    'MIGNELLA': 0,
    'MIGNEREY': 0,
    'MIGNERY': 0,
    'MIGNOGNA': 0,
    'MIGNON': 0.9345794392523364,
    'MIGNONE': 0,
    'MIGNOSA': 0,
    'MIGNOT': 0,
    'MIGNOTT': 0,
    'MIGUEL': 0.9783480352846833,
    'MIGUELEZ': 0,
    'MIGUELINA': 1,
    'MIGUES': 0,
    'MIGUEZ': 0,
    'MIGURA': 0,
    'MIGUT': 0,
    'MIHAI': 0,
    'MIHAILOFF': 0,
    'MIHAILOVIC': 0,
    'MIHAILOVICH': 0,
    'MIHAJLOVIC': 0,
    'MIHAL': 0,
    'MIHALAK': 0,
    'MIHALAKIS': 0,
    'MIHALCIK': 0,
    'MIHALCIN': 0,
    'MIHALEK': 0,
    'MIHALIC': 0,
    'MIHALICH': 0,
    'MIHALICK': 0,
    'MIHALIK': 0,
    'MIHALJEVIC': 0,
    'MIHALKO': 0,
    'MIHALOPOULOS': 0,
    'MIHALOV': 0,
    'MIHALOVIC': 0,
    'MIHALOVICH': 0,
    'MIHALSKI': 0,
    'MIHALY': 0,
    'MIHALYI': 0,
    'MIHARA': 0,
    'MIHELCIC': 0,
    'MIHELIC': 0,
    'MIHELICH': 0,
    'MIHILL': 0,
    'MIHLBAUER': 0,
    'MIHM': 0,
    'MIHOK': 0,
    'MIHOS': 0,
    'MIHULKA': 0,
    'MIILLER': 0,
    'MIJAL': 0,
    'MIJANGO': 0,
    'MIJANGOS': 0,
    'MIJARES': 0,
    'MIJAREZ': 0,
    'MIJATOVIC': 0,
    'MIK': 0,
    'MIKA': 0.6920415224913495,
    'MIKAELA': 1,
    'MIKAELE': 0,
    'MIKAELIAN': 0,
    'MIKALAUSKAS': 0,
    'MIKALONIS': 0,
    'MIKAMI': 0,
    'MIKAN': 0,
    'MIKASA': 0,
    'MIKAYELYAN': 0,
    'MIKE': 0.9933082392304474,
    'MIKEAL': 0,
    'MIKEL': 0.8460236886632826,
    'MIKELL': 0,
    'MIKELONIS': 0,
    'MIKELS': 0,
    'MIKELSON': 0,
    'MIKES': 0,
    'MIKESELL': 0,
    'MIKESH': 0,
    'MIKESIC': 0,
    'MIKESKA': 0,
    'MIKETA': 0,
    'MIKEWORTH': 0,
    'MIKHA': 0,
    'MIKHAEL': 0,
    'MIKHAIL': 0,
    'MIKHAILOV': 0,
    'MIKHAYLOV': 0,
    'MIKI': 0.9009009009009009,
    'MIKITA': 0,
    'MIKKELSEN': 0,
    'MIKKELSON': 0,
    'MIKKI': 1,
    'MIKKOLA': 0,
    'MIKKONEN': 0,
    'MIKLAS': 0,
    'MIKLAVCIC': 0,
    'MIKLE': 0,
    'MIKLER': 0,
    'MIKLES': 0,
    'MIKLICH': 0,
    'MIKLOS': 0,
    'MIKLOVIC': 0,
    'MIKLUS': 0,
    'MIKO': 0,
    'MIKOL': 0,
    'MIKOLA': 0,
    'MIKOLAITIS': 0,
    'MIKOLAJCZAK': 0,
    'MIKOLAJCZYK': 0,
    'MIKOLAJEWSKI': 0,
    'MIKOLAS': 0,
    'MIKOLAY': 0,
    'MIKOLIC': 0,
    'MIKOLICH': 0,
    'MIKOLON': 0,
    'MIKOLOWSKI': 0,
    'MIKOLS': 0,
    'MIKOS': 0,
    'MIKOSZ': 0,
    'MIKOTA': 0,
    'MIKOVICH': 0,
    'MIKOWSKI': 0,
    'MIKRUT': 0,
    'MIKS': 0,
    'MIKSA': 0,
    'MIKSCH': 0,
    'MIKSELL': 0,
    'MIKSIS': 0,
    'MIKUCKI': 0,
    'MIKULA': 0,
    'MIKULAK': 0,
    'MIKULAN': 0,
    'MIKULAS': 0,
    'MIKULEC': 0,
    'MIKULECKY': 0,
    'MIKULENCAK': 0,
    'MIKULENKA': 0,
    'MIKULEWICZ': 0,
    'MIKULICH': 0,
    'MIKULIK': 0,
    'MIKULIN': 0,
    'MIKULKA': 0,
    'MIKULSKI': 0,
    'MIKULSKY': 0,
    'MIKUS': 0,
    'MIKUSH': 0,
    'MIKUTA': 0,
    'MIL': 0,
    'MILA': 0.9345794392523364,
    'MILACEK': 0,
    'MILAD': 0,
    'MILAGRO': 1,
    'MILAGROS': 1,
    'MILAK': 0,
    'MILAKOVIC': 0,
    'MILAKOVICH': 0,
    'MILAM': 0,
    'MILAN': 0.6700167504187605,
    'MILANA': 0,
    'MILAND': 0,
    'MILANDER': 0,
    'MILANES': 0,
    'MILANESE': 0,
    'MILANESI': 0,
    'MILANEZ': 0,
    'MILANI': 0,
    'MILANO': 0,
    'MILANOVIC': 0,
    'MILANOVICH': 0,
    'MILANOWSKI': 0,
    'MILAR': 0,
    'MILARCH': 0,
    'MILARDO': 0,
    'MILAS': 0,
    'MILATZ': 0,
    'MILAUSKAS': 0,
    'MILAVEC': 0,
    'MILAZZO': 0,
    'MILBACH': 0,
    'MILBANK': 0,
    'MILBAUER': 0,
    'MILBEE': 0,
    'MILBERG': 0,
    'MILBERGER': 0,
    'MILBERT': 0,
    'MILBOURN': 0,
    'MILBOURNE': 0,
    'MILBRADT': 0,
    'MILBRAND': 0,
    'MILBRANDT': 0,
    'MILBRATH': 0,
    'MILBRETT': 0,
    'MILBRODT': 0,
    'MILBRY': 0,
    'MILBURN': 0,
    'MILBURY': 0,
    'MILBY': 0,
    'MILCAREK': 0,
    'MILCH': 0,
    'MILCHAK': 0,
    'MILCIC': 0,
    'MILCZAREK': 0,
    'MILCZARSKI': 0,
    'MILCZEWSKI': 0,
    'MILD': 0,
    'MILDA': 1,
    'MILDE': 0,
    'MILDEN': 0,
    'MILDENBERGER': 0,
    'MILDENSTEIN': 0,
    'MILDER': 0,
    'MILDNER': 0,
    'MILDON': 0,
    'MILDRED': 0.9998722208024534,
    'MILDREN': 0,
    'MILE': 0,
    'MILEA': 0,
    'MILEHAM': 0,
    'MILEK': 0,
    'MILEM': 0,
    'MILEN': 0,
    'MILENDER': 0,
    'MILENKOVIC': 0,
    'MILEO': 0,
    'MILER': 0,
    'MILES': 0.3588769263246781,
    'MILESKI': 0,
    'MILESKY': 0,
    'MILESTONE': 0,
    'MILETELLO': 0,
    'MILETI': 0,
    'MILETIC': 0,
    'MILETICH': 0,
    'MILETO': 0,
    'MILETTA': 0,
    'MILETTE': 0,
    'MILETTI': 0,
    'MILEUR': 0,
    'MILEWSKI': 0,
    'MILEWSKY': 0,
    'MILEY': 0,
    'MILFORD': 0.8368200836820083,
    'MILFORT': 0,
    'MILGATE': 0,
    'MILGRAM': 0,
    'MILGRIM': 0,
    'MILGROM': 0,
    'MILHAM': 0,
    'MILHEIM': 0,
    'MILHEISER': 0,
    'MILHOAN': 0,
    'MILHOLEN': 0,
    'MILHOLLAND': 0,
    'MILHOLLIN': 0,
    'MILHOMME': 0,
    'MILHON': 0,
    'MILHORN': 0,
    'MILHOUS': 0,
    'MILHOUSE': 0,
    'MILIA': 0,
    'MILIAN': 0,
    'MILIANO': 0,
    'MILIC': 0,
    'MILICEVIC': 0,
    'MILICH': 0,
    'MILICI': 0,
    'MILICIA': 0,
    'MILIEN': 0,
    'MILIK': 0,
    'MILILLO': 0,
    'MILIN': 0,
    'MILINAZZO': 0,
    'MILINER': 0,
    'MILINKOVICH': 0,
    'MILINOVICH': 0,
    'MILINSKI': 0,
    'MILIO': 0,
    'MILIOTO': 0,
    'MILIS': 0,
    'MILISITS': 0,
    'MILISPAUGH': 0,
    'MILISSA': 1,
    'MILITANO': 0,
    'MILITANTE': 0,
    'MILITAR': 0,
    'MILITE': 0,
    'MILITELLO': 0,
    'MILITO': 0,
    'MILITZER': 0,
    'MILIUS': 0,
    'MILJKOVIC': 0,
    'MILK': 0,
    'MILKA': 0,
    'MILKE': 0,
    'MILKEY': 0,
    'MILKIE': 0,
    'MILKIEWICZ': 0,
    'MILKINS': 0,
    'MILKO': 0,
    'MILKOVICH': 0,
    'MILKOWSKI': 0,
    'MILKS': 0,
    'MILL': 0,
    'MILLA': 0,
    'MILLAGE': 0,
    'MILLAM': 0,
    'MILLAN': 0,
    'MILLANE': 0,
    'MILLANES': 0,
    'MILLANG': 0,
    'MILLAR': 0,
    'MILLARD': 0.701530612244898,
    'MILLARE': 0,
    'MILLARES': 0,
    'MILLAS': 0,
    'MILLAWAY': 0,
    'MILLAY': 0,
    'MILLBROOK': 0,
    'MILLBROOKS': 0,
    'MILLBURG': 0,
    'MILLBURN': 0,
    'MILLE': 0,
    'MILLEA': 0,
    'MILLEDGE': 0,
    'MILLEGAN': 0,
    'MILLEMAN': 0,
    'MILLEN': 0,
    'MILLENDER': 0,
    'MILLER': 0,
    'MILLERBERND': 0,
    'MILLERICK': 0,
    'MILLERING': 0,
    'MILLERMON': 0,
    'MILLES': 0,
    'MILLESON': 0,
    'MILLESS': 0,
    'MILLET': 0,
    'MILLETT': 0,
    'MILLETTE': 0,
    'MILLEVILLE': 0,
    'MILLEVOI': 0,
    'MILLEY': 0,
    'MILLHAM': 0,
    'MILLHEIM': 0,
    'MILLHOFF': 0,
    'MILLHOLLAND': 0,
    'MILLHOLLIN': 0,
    'MILLHOLLON': 0,
    'MILLHORN': 0,
    'MILLHOUSE': 0,
    'MILLIAN': 0,
    'MILLIANS': 0,
    'MILLIARD': 0,
    'MILLICAN': 0,
    'MILLICENT': 1,
    'MILLICH': 0,
    'MILLICK': 0,
    'MILLIE': 0.9947337624341721,
    'MILLIEN': 0,
    'MILLIER': 0,
    'MILLIGAN': 0,
    'MILLIKAN': 0,
    'MILLIKEN': 0,
    'MILLIKIN': 0,
    'MILLIMAN': 0,
    'MILLIN': 0,
    'MILLINDER': 0,
    'MILLINE': 0,
    'MILLINER': 0,
    'MILLINES': 0,
    'MILLING': 0,
    'MILLINGER': 0,
    'MILLINGS': 0,
    'MILLINGTON': 0,
    'MILLION': 0,
    'MILLIORN': 0,
    'MILLIREN': 0,
    'MILLIRON': 0,
    'MILLIRONS': 0,
    'MILLIS': 0,
    'MILLISER': 0,
    'MILLISOCK': 0,
    'MILLISON': 0,
    'MILLISOR': 0,
    'MILLMAN': 0,
    'MILLNER': 0,
    'MILLO': 0,
    'MILLON': 0,
    'MILLONZI': 0,
    'MILLOWAY': 0,
    'MILLOY': 0,
    'MILLS': 0,
    'MILLSAP': 0,
    'MILLSAPS': 0,
    'MILLSLAGLE': 0,
    'MILLSON': 0,
    'MILLSPAUGH': 0,
    'MILLSTEAD': 0,
    'MILLSTEIN': 0,
    'MILLSTONE': 0,
    'MILLUS': 0,
    'MILLWARD': 0,
    'MILLWATER': 0,
    'MILLWEE': 0,
    'MILLWOOD': 0,
    'MILLY': 0.9615384615384616,
    'MILMAN': 0,
    'MILMINE': 0,
    'MILMOE': 0,
    'MILMORE': 0,
    'MILNAMOW': 0,
    'MILNE': 0,
    'MILNER': 0,
    'MILNES': 0,
    'MILNOR': 0,
    'MILO': 0.8503401360544217,
    'MILON': 0,
    'MILONAS': 0,
    'MILONE': 0,
    'MILORD': 0,
    'MILORO': 0,
    'MILOS': 0,
    'MILOSAVLJEVIC': 0,
    'MILOSCH': 0,
    'MILOSCIA': 0,
    'MILOSER': 0,
    'MILOSEVIC': 0,
    'MILOSEVICH': 0,
    'MILOSH': 0,
    'MILOSTAN': 0,
    'MILOT': 0,
    'MILOTA': 0,
    'MILOTTE': 0,
    'MILOVANOVIC': 0,
    'MILOVICH': 0,
    'MILOW': 0,
    'MILROY': 0,
    'MILSAP': 0,
    'MILSAPS': 0,
    'MILSHTEYN': 0,
    'MILSOM': 0,
    'MILSON': 0,
    'MILSTEAD': 0,
    'MILSTED': 0,
    'MILSTEIN': 0,
    'MILSTEN': 0,
    'MILSTER': 0,
    'MILTEER': 0,
    'MILTENBERGER': 0,
    'MILTER': 0,
    'MILTIER': 0,
    'MILTIMORE': 0,
    'MILTNER': 0,
    'MILTON': 0.9155413138017853,
    'MILTZ': 0,
    'MILUM': 0,
    'MILUS': 0,
    'MILUTINOVIC': 0,
    'MILWARD': 0,
    'MILWEE': 0,
    'MILWOOD': 0,
    'MILZ': 0,
    'MIMBS': 0,
    'MIMES': 0,
    'MIMI': 1,
    'MIMM': 0,
    'MIMMS': 0,
    'MIMNAUGH': 0,
    'MIMS': 0,
    'MIMURA': 0,
    'MIN': 0.5181347150259067,
    'MINA': 0.898876404494382,
    'MINADEO': 0,
    'MINAHAN': 0,
    'MINAKER': 0,
    'MINALGA': 0,
    'MINAMI': 0,
    'MINAMYER': 0,
    'MINANO': 0,
    'MINAR': 0,
    'MINARCIK': 0,
    'MINARCIN': 0,
    'MINARD': 0,
    'MINARDI': 0,
    'MINARDO': 0,
    'MINARICH': 0,
    'MINARICK': 0,
    'MINARIK': 0,
    'MINAS': 0,
    'MINASI': 0,
    'MINASIAN': 0,
    'MINASSIAN': 0,
    'MINASYAN': 0,
    'MINATEE': 0,
    'MINATO': 0,
    'MINATRA': 0,
    'MINAUDO': 0,
    'MINAYA': 0,
    'MINCE': 0,
    'MINCEMOYER': 0,
    'MINCER': 0,
    'MINCEY': 0,
    'MINCH': 0,
    'MINCHALA': 0,
    'MINCHELLA': 0,
    'MINCHER': 0,
    'MINCHEW': 0,
    'MINCHEY': 0,
    'MINCHIN': 0,
    'MINCHOW': 0,
    'MINCHUK': 0,
    'MINCIELI': 0,
    'MINCIN': 0,
    'MINCK': 0,
    'MINCKLER': 0,
    'MINCKS': 0,
    'MINCY': 0,
    'MINDA': 0.9090909090909091,
    'MINDAK': 0,
    'MINDE': 0,
    'MINDEL': 0,
    'MINDELL': 0,
    'MINDEN': 0,
    'MINDER': 0,
    'MINDERMAN': 0,
    'MINDERMANN': 0,
    'MINDHAM': 0,
    'MINDI': 1,
    'MINDICH': 0,
    'MINDICK': 0,
    'MINDIETA': 0,
    'MINDIOLA': 0,
    'MINDLER': 0,
    'MINDLIN': 0,
    'MINDOCK': 0,
    'MINDRUM': 0,
    'MINDRUP': 0,
    'MINDT': 0,
    'MINDY': 1,
    'MINE': 0,
    'MINEA': 0,
    'MINEAR': 0,
    'MINEARD': 0,
    'MINEART': 0,
    'MINEAU': 0,
    'MINEER': 0,
    'MINEFEE': 0,
    'MINEGAR': 0,
    'MINEHAN': 0,
    'MINEHART': 0,
    'MINELLA': 0,
    'MINELLI': 0,
    'MINEO': 0,
    'MINER': 0,
    'MINERA': 0,
    'MINERD': 0,
    'MINERICH': 0,
    'MINERO': 0,
    'MINEROS': 0,
    'MINERS': 0,
    'MINERT': 0,
    'MINERVA': 0.9845288326300985,
    'MINERVINI': 0,
    'MINERVINO': 0,
    'MINES': 0,
    'MINET': 0,
    'MINETREE': 0,
    'MINETT': 0,
    'MINETTE': 0,
    'MINETTI': 0,
    'MINEVICH': 0,
    'MINEWEASER': 0,
    'MINFORD': 0,
    'MING': 0.37878787878787884,
    'MINGA': 0,
    'MINGE': 0,
    'MINGEE': 0,
    'MINGER': 0,
    'MINGES': 0,
    'MINGGIA': 0,
    'MINGIN': 0,
    'MINGIONE': 0,
    'MINGLE': 0,
    'MINGLEDORFF': 0,
    'MINGO': 0,
    'MINGOIA': 0,
    'MINGRONE': 0,
    'MINGS': 0,
    'MINGUELA': 0,
    'MINGUEZ': 0,
    'MINGURA': 0,
    'MINGUS': 0,
    'MINH': 0.9929078014184397,
    'MINHAS': 0,
    'MINI': 0,
    'MINIACI': 0,
    'MINIARD': 0,
    'MINIC': 0,
    'MINICA': 0,
    'MINICH': 0,
    'MINICHELLO': 0,
    'MINICHIELLO': 0,
    'MINICHINI': 0,
    'MINICHINO': 0,
    'MINICK': 0,
    'MINICOZZI': 0,
    'MINICUCCI': 0,
    'MINIEL': 0,
    'MINIER': 0,
    'MINIERI': 0,
    'MINIFIELD': 0,
    'MINIHAN': 0,
    'MINIKEL': 0,
    'MINIKUS': 0,
    'MININGER': 0,
    'MININNI': 0,
    'MININO': 0,
    'MINIO': 0,
    'MINION': 0,
    'MINIS': 0,
    'MINISH': 0,
    'MINISSALE': 0,
    'MINISTER': 0,
    'MINITER': 0,
    'MINIUM': 0,
    'MINIUTTI': 0,
    'MINIX': 0,
    'MINJARES': 0,
    'MINJAREZ': 0,
    'MINK': 0,
    'MINKA': 0,
    'MINKE': 0,
    'MINKEL': 0,
    'MINKER': 0,
    'MINKIEWICZ': 0,
    'MINKIN': 0,
    'MINKINS': 0,
    'MINKLE': 0,
    'MINKLER': 0,
    'MINKLEY': 0,
    'MINKO': 0,
    'MINKOFF': 0,
    'MINKOWSKI': 0,
    'MINKS': 0,
    'MINKUS': 0,
    'MINN': 0,
    'MINNA': 1,
    'MINNAERT': 0,
    'MINNARD': 0,
    'MINNE': 0,
    'MINNEAR': 0,
    'MINNECI': 0,
    'MINNEHAN': 0,
    'MINNELLA': 0,
    'MINNEMA': 0,
    'MINNEMAN': 0,
    'MINNER': 0,
    'MINNERLY': 0,
    'MINNES': 0,
    'MINNEY': 0,
    'MINNI': 0,
    'MINNICH': 0,
    'MINNICK': 0,
    'MINNICKS': 0,
    'MINNIE': 0.9976460038112319,
    'MINNIEAR': 0,
    'MINNIEFIELD': 0,
    'MINNIER': 0,
    'MINNIEWEATHER': 0,
    'MINNIFIELD': 0,
    'MINNIG': 0,
    'MINNIHAN': 0,
    'MINNING': 0,
    'MINNINGER': 0,
    'MINNIS': 0,
    'MINNITI': 0,
    'MINNIX': 0,
    'MINNOCK': 0,
    'MINNS': 0,
    'MINNUCCI': 0,
    'MINO': 0,
    'MINOCK': 0,
    'MINOFF': 0,
    'MINOGUE': 0,
    'MINOR': 0,
    'MINORE': 0,
    'MINORS': 0,
    'MINOT': 0,
    'MINOTT': 0,
    'MINOTTI': 0,
    'MINS': 0,
    'MINSER': 0,
    'MINSHALL': 0,
    'MINSHEW': 0,
    'MINSHULL': 0,
    'MINSK': 0,
    'MINSKE': 0,
    'MINSKER': 0,
    'MINSKI': 0,
    'MINSKY': 0,
    'MINSON': 0,
    'MINSTER': 0,
    'MINTA': 0.9433962264150944,
    'MINTEER': 0,
    'MINTEN': 0,
    'MINTER': 0,
    'MINTHORN': 0,
    'MINTLE': 0,
    'MINTNER': 0,
    'MINTO': 0,
    'MINTON': 0,
    'MINTS': 0,
    'MINTUN': 0,
    'MINTURN': 0,
    'MINTUS': 0,
    'MINTY': 0,
    'MINTZ': 0,
    'MINTZER': 0,
    'MINUCCI': 0,
    'MINUGH': 0,
    'MINUS': 0,
    'MINUTELLA': 0,
    'MINUTILLO': 0,
    'MINUTO': 0,
    'MINUTOLI': 0,
    'MINUTOLO': 0,
    'MINVIELLE': 0,
    'MINX': 0,
    'MINYARD': 0,
    'MINYON': 0,
    'MINZE': 0,
    'MINZENMAYER': 0,
    'MINZER': 0,
    'MINZEY': 0,
    'MIO': 0,
    'MIODUSZEWSKI': 0,
    'MION': 0,
    'MIONE': 0,
    'MIONI': 0,
    'MIOSI': 0,
    'MIOTKE': 0,
    'MIOTTO': 0,
    'MIOZZA': 0,
    'MIOZZI': 0,
    'MIQUEL': 0.9876543209876544,
    'MIR': 0,
    'MIRA': 0.8522727272727273,
    'MIRABAL': 0,
    'MIRABEL': 0,
    'MIRABELLA': 0,
    'MIRABELLI': 0,
    'MIRABELLO': 0,
    'MIRABILE': 0,
    'MIRABITO': 0,
    'MIRACLE': 0,
    'MIRACOLA': 0,
    'MIRADOR': 0,
    'MIRAFLOR': 0,
    'MIRAFUENTES': 0,
    'MIRAGLIA': 0,
    'MIRAGLIOTTA': 0,
    'MIRAKIAN': 0,
    'MIRALDA': 0,
    'MIRALDI': 0,
    'MIRALES': 0,
    'MIRALLES': 0,
    'MIRALRIO': 0,
    'MIRAMON': 0,
    'MIRAMONTES': 0,
    'MIRAMONTEZ': 0,
    'MIRAMONTI': 0,
    'MIRAN': 0,
    'MIRAND': 0,
    'MIRANDA': 0.5275056518462699,
    'MIRANDE': 0,
    'MIRANDI': 0,
    'MIRANDO': 0,
    'MIRANI': 0,
    'MIRANO': 0,
    'MIRANOWSKI': 0,
    'MIRANTE': 0,
    'MIRANTI': 0,
    'MIRARCHI': 0,
    'MIRAS': 0,
    'MIRASOL': 0,
    'MIRASOLA': 0,
    'MIRCH': 0,
    'MIRCHANDANI': 0,
    'MIRCOVICH': 0,
    'MIRE': 0,
    'MIREAU': 0,
    'MIREAULT': 0,
    'MIRECKI': 0,
    'MIREE': 0,
    'MIREILLE': 1,
    'MIREK': 0,
    'MIRELES': 0,
    'MIRELEZ': 0,
    'MIRELLA': 1,
    'MIRENDA': 0,
    'MIRES': 0,
    'MIRET': 0,
    'MIREYA': 1,
    'MIRI': 0,
    'MIRIAM': 1,
    'MIRIAN': 1,
    'MIRIANI': 0,
    'MIRICH': 0,
    'MIRICK': 0,
    'MIRIELLO': 0,
    'MIRISOLA': 0,
    'MIRIZIO': 0,
    'MIRKA': 0,
    'MIRKES': 0,
    'MIRKIN': 0,
    'MIRKOVIC': 0,
    'MIRKOVICH': 0,
    'MIRMAN': 0,
    'MIRNA': 1,
    'MIRO': 0,
    'MIROBALLI': 0,
    'MIROCHA': 0,
    'MIROCHNIK': 0,
    'MIRON': 0,
    'MIRONOV': 0,
    'MIROS': 0,
    'MIROSHNICHENKO': 0,
    'MIROSLAW': 0,
    'MIROWSKI': 0,
    'MIRPURI': 0,
    'MIRR': 0,
    'MIRRA': 0,
    'MIRRER': 0,
    'MIRRIONE': 0,
    'MIRRO': 0,
    'MIRSKY': 0,
    'MIRT': 0,
    'MIRTA': 1,
    'MIRTH': 0,
    'MIRTHA': 1,
    'MIRTO': 0,
    'MIRUS': 0,
    'MIRVILLE': 0,
    'MIRVIS': 0,
    'MIRZA': 0,
    'MIRZAIAN': 0,
    'MIRZAKHANIAN': 0,
    'MIRZOYAN': 0,
    'MIS': 0,
    'MISA': 0,
    'MISAK': 0,
    'MISAMORE': 0,
    'MISAS': 0,
    'MISASI': 0,
    'MISAWA': 0,
    'MISBACH': 0,
    'MISCAVAGE': 0,
    'MISCH': 0,
    'MISCHE': 0,
    'MISCHEL': 0,
    'MISCHENKO': 0,
    'MISCHKA': 0,
    'MISCHKE': 0,
    'MISCHLER': 0,
    'MISCHLEY': 0,
    'MISCHNICK': 0,
    'MISCHO': 0,
    'MISCIA': 0,
    'MISCIAGNA': 0,
    'MISCIONE': 0,
    'MISCIOSCIA': 0,
    'MISCO': 0,
    'MISCOVICH': 0,
    'MISE': 0,
    'MISEK': 0,
    'MISEL': 0,
    'MISEMER': 0,
    'MISENAR': 0,
    'MISENCIK': 0,
    'MISENER': 0,
    'MISENHEIMER': 0,
    'MISENHELTER': 0,
    'MISENHIMER': 0,
    'MISENKO': 0,
    'MISENTI': 0,
    'MISER': 0,
    'MISERENDINO': 0,
    'MISFELDT': 0,
    'MISH': 0,
    'MISHA': 1,
    'MISHAK': 0,
    'MISHAN': 0,
    'MISHER': 0,
    'MISHIMA': 0,
    'MISHINA': 0,
    'MISHKIN': 0,
    'MISHKO': 0,
    'MISHLER': 0,
    'MISHOE': 0,
    'MISHRA': 0,
    'MISHUE': 0,
    'MISIAK': 0,
    'MISIALEK': 0,
    'MISIANO': 0,
    'MISIASZEK': 0,
    'MISIC': 0,
    'MISICKA': 0,
    'MISIEWICZ': 0,
    'MISIK': 0,
    'MISIOLEK': 0,
    'MISIR': 0,
    'MISITA': 0,
    'MISITI': 0,
    'MISIUK': 0,
    'MISIURA': 0,
    'MISKA': 0,
    'MISKE': 0,
    'MISKEL': 0,
    'MISKELL': 0,
    'MISKELLEY': 0,
    'MISKELLY': 0,
    'MISKEY': 0,
    'MISKIEWICZ': 0,
    'MISKIMEN': 0,
    'MISKIMINS': 0,
    'MISKIMON': 0,
    'MISKIN': 0,
    'MISKINIS': 0,
    'MISKO': 0,
    'MISKOV': 0,
    'MISKOVIC': 0,
    'MISKOVICH': 0,
    'MISKOVSKY': 0,
    'MISKOWIC': 0,
    'MISKOWICZ': 0,
    'MISKOWIEC': 0,
    'MISKOWSKI': 0,
    'MISKULIN': 0,
    'MISLAN': 0,
    'MISLANG': 0,
    'MISLEH': 0,
    'MISLEY': 0,
    'MISMAS': 0,
    'MISNER': 0,
    'MISNIK': 0,
    'MISPAGEL': 0,
    'MISQUEZ': 0,
    'MISRA': 0,
    'MISS': 0.9433962264150944,
    'MISSAL': 0,
    'MISSALL': 0,
    'MISSEL': 0,
    'MISSELHORN': 0,
    'MISSERI': 0,
    'MISSETT': 0,
    'MISSEY': 0,
    'MISSI': 0,
    'MISSICK': 0,
    'MISSIG': 0,
    'MISSILDINE': 0,
    'MISSIMER': 0,
    'MISSION': 0,
    'MISSLER': 0,
    'MISSMAN': 0,
    'MISSO': 0,
    'MISSON': 0,
    'MISSOURI': 0,
    'MISSY': 1,
    'MISTAK': 0,
    'MISTAL': 0,
    'MISTELE': 0,
    'MISTER': 0,
    'MISTEREK': 0,
    'MISTERKA': 0,
    'MISTI': 1,
    'MISTIC': 0,
    'MISTICH': 0,
    'MISTIE': 1,
    'MISTLER': 0,
    'MISTOVICH': 0,
    'MISTRETTA': 0,
    'MISTRIC': 0,
    'MISTROT': 0,
    'MISTRY': 0,
    'MISTY': 1,
    'MISUNAS': 0,
    'MISURA': 0,
    'MISURACA': 0,
    'MISZEWSKI': 0,
    'MISZTAL': 0,
    'MITA': 0,
    'MITACEK': 0,
    'MITAL': 0,
    'MITAN': 0,
    'MITANI': 0,
    'MITAS': 0,
    'MITCH': 0.9448818897637796,
    'MITCHAM': 0,
    'MITCHEL': 0.7543103448275862,
    'MITCHELL': 0.34893169542564884,
    'MITCHELLE': 0,
    'MITCHELSON': 0,
    'MITCHELTREE': 0,
    'MITCHEM': 0,
    'MITCHEN': 0,
    'MITCHENER': 0,
    'MITCHESON': 0,
    'MITCHINER': 0,
    'MITCHKO': 0,
    'MITCHLER': 0,
    'MITCHNER': 0,
    'MITCHUM': 0,
    'MITCHUSSON': 0,
    'MITE': 0,
    'MITERA': 0,
    'MITERKO': 0,
    'MITH': 0,
    'MITHA': 0,
    'MITHANI': 0,
    'MITHCELL': 0,
    'MITHELL': 0,
    'MITHUN': 0,
    'MITIC': 0,
    'MITICH': 0,
    'MITKO': 0,
    'MITKOWSKI': 0,
    'MITLO': 0,
    'MITLYNG': 0,
    'MITMAN': 0,
    'MITNICK': 0,
    'MITNIK': 0,
    'MITO': 0,
    'MITOLA': 0,
    'MITORAJ': 0,
    'MITRA': 0,
    'MITRANI': 0,
    'MITRANO': 0,
    'MITRE': 0,
    'MITRI': 0,
    'MITRIONE': 0,
    'MITRISIN': 0,
    'MITRO': 0,
    'MITROFF': 0,
    'MITROPOULOS': 0,
    'MITROS': 0,
    'MITROVIC': 0,
    'MITROVICH': 0,
    'MITRY': 0,
    'MITSCH': 0,
    'MITSCHELE': 0,
    'MITSCHELEN': 0,
    'MITSCHKE': 0,
    'MITSDARFFER': 0,
    'MITSON': 0,
    'MITSOS': 0,
    'MITSTIFER': 0,
    'MITSUDA': 0,
    'MITSUE': 1,
    'MITSUI': 0,
    'MITSUKO': 1,
    'MITSUNAGA': 0,
    'MITTAG': 0,
    'MITTAL': 0,
    'MITTAN': 0,
    'MITTEER': 0,
    'MITTEL': 0,
    'MITTELMAN': 0,
    'MITTELSTADT': 0,
    'MITTELSTAEDT': 0,
    'MITTELSTEADT': 0,
    'MITTELSTEDT': 0,
    'MITTEN': 0,
    'MITTENDORF': 0,
    'MITTENTHAL': 0,
    'MITTER': 0,
    'MITTERER': 0,
    'MITTERLING': 0,
    'MITTERMEIER': 0,
    'MITTICA': 0,
    'MITTIE': 1,
    'MITTIGA': 0,
    'MITTL': 0,
    'MITTLEIDER': 0,
    'MITTLEMAN': 0,
    'MITTLER': 0,
    'MITTLESTADT': 0,
    'MITTLESTEADT': 0,
    'MITTMAN': 0,
    'MITTNACHT': 0,
    'MITTON': 0,
    'MITTS': 0,
    'MITZ': 0,
    'MITZEL': 0,
    'MITZELFELT': 0,
    'MITZEN': 0,
    'MITZI': 1,
    'MITZIE': 1,
    'MITZNER': 0,
    'MIU': 0,
    'MIUCCIO': 0,
    'MIURA': 0,
    'MIVILLE': 0,
    'MIWA': 0,
    'MIX': 0,
    'MIXA': 0,
    'MIXAN': 0,
    'MIXCO': 0,
    'MIXDORF': 0,
    'MIXELL': 0,
    'MIXEN': 0,
    'MIXER': 0,
    'MIXON': 0,
    'MIXSON': 0,
    'MIXTER': 0,
    'MIYA': 0,
    'MIYAGAWA': 0,
    'MIYAGI': 0,
    'MIYAGISHIMA': 0,
    'MIYAHARA': 0,
    'MIYAHIRA': 0,
    'MIYAJI': 0,
    'MIYAJIMA': 0,
    'MIYAKAWA': 0,
    'MIYAKE': 0,
    'MIYAKI': 0,
    'MIYAMOTO': 0,
    'MIYAMURA': 0,
    'MIYAO': 0,
    'MIYARES': 0,
    'MIYASAKI': 0,
    'MIYASATO': 0,
    'MIYASHIRO': 0,
    'MIYASHITA': 0,
    'MIYATA': 0,
    'MIYATAKE': 0,
    'MIYAUCHI': 0,
    'MIYAZAKI': 0,
    'MIYAZAWA': 0,
    'MIYAZONO': 0,
    'MIYOKO': 1,
    'MIYOSHI': 0,
    'MIZAK': 0,
    'MIZE': 0,
    'MIZEL': 0,
    'MIZELL': 0,
    'MIZELLE': 0,
    'MIZEN': 0,
    'MIZENER': 0,
    'MIZENKO': 0,
    'MIZER': 0,
    'MIZERA': 0,
    'MIZERAK': 0,
    'MIZEREK': 0,
    'MIZEUR': 0,
    'MIZHQUIRI': 0,
    'MIZIA': 0,
    'MIZIKAR': 0,
    'MIZNER': 0,
    'MIZOGUCHI': 0,
    'MIZOKAMI': 0,
    'MIZRACHI': 0,
    'MIZRAHI': 0,
    'MIZUKAMI': 0,
    'MIZUKI': 0,
    'MIZUMOTO': 0,
    'MIZUNO': 0,
    'MIZUSAWA': 0,
    'MIZUSHIMA': 0,
    'MIZUTA': 0,
    'MIZUTANI': 0,
    'MIZYED': 0,
    'MIZZELL': 0,
    'MIZZI': 0,
    'MIZZONI': 0,
    'MJELDE': 0,
    'MJOEN': 0,
    'MJOLSNESS': 0,
    'MKHITARYAN': 0,
    'MKRTCHIAN': 0,
    'MKRTCHYAN': 0,
    'MLADENKA': 0,
    'MLADENOVIC': 0,
    'MLADY': 0,
    'MLAKAR': 0,
    'MLECZKO': 0,
    'MLEJNEK': 0,
    'MLEKUSH': 0,
    'MLEZIVA': 0,
    'MLINAR': 0,
    'MLINARCIK': 0,
    'MLNARIK': 0,
    'MLODZIK': 0,
    'MLOT': 0,
    'MLSNA': 0,
    'MLYNAR': 0,
    'MLYNARCZYK': 0,
    'MLYNAREK': 0,
    'MLYNARSKI': 0,
    'MLYNEK': 0,
    'MNATSAKANYAN': 0,
    'MNICH': 0,
    'MO': 0,
    'MOA': 0,
    'MOAD': 0,
    'MOAG': 0,
    'MOAK': 0,
    'MOAKE': 0,
    'MOAKLER': 0,
    'MOAKLEY': 0,
    'MOALA': 0,
    'MOALES': 0,
    'MOAN': 0,
    'MOANEY': 0,
    'MOAR': 0,
    'MOAT': 0,
    'MOATE': 0,
    'MOATES': 0,
    'MOATS': 0,
    'MOATZ': 0,
    'MOAWAD': 0,
    'MOBARAK': 0,
    'MOBBS': 0,
    'MOBERG': 0,
    'MOBERLEY': 0,
    'MOBERLY': 0,
    'MOBILE': 0,
    'MOBILIA': 0,
    'MOBILIO': 0,
    'MOBLEY': 0,
    'MOBLO': 0,
    'MOBLY': 0,
    'MOBUS': 0,
    'MOC': 0,
    'MOCABEE': 0,
    'MOCABY': 0,
    'MOCADLO': 0,
    'MOCANU': 0,
    'MOCARSKI': 0,
    'MOCCIA': 0,
    'MOCCIO': 0,
    'MOCCO': 0,
    'MOCEK': 0,
    'MOCERI': 0,
    'MOCERINO': 0,
    'MOCH': 0,
    'MOCHA': 0,
    'MOCHAN': 0,
    'MOCHEL': 0,
    'MOCHERMAN': 0,
    'MOCHIZUKI': 0,
    'MOCHON': 0,
    'MOCHRIE': 0,
    'MOCK': 0,
    'MOCKABEE': 0,
    'MOCKAITIS': 0,
    'MOCKBEE': 0,
    'MOCKEL': 0,
    'MOCKENHAUPT': 0,
    'MOCKENSTURM': 0,
    'MOCKER': 0,
    'MOCKERMAN': 0,
    'MOCKLER': 0,
    'MOCKO': 0,
    'MOCKRIDGE': 0,
    'MOCKUS': 0,
    'MOCNIAK': 0,
    'MOCNY': 0,
    'MOCTEZUMA': 0,
    'MOCZULSKI': 0,
    'MOCZYDLOWSKI': 0,
    'MOCZYGEMBA': 0,
    'MOCZYNSKI': 0,
    'MODAFF': 0,
    'MODAFFERI': 0,
    'MODAHL': 0,
    'MODAK': 0,
    'MODAR': 0,
    'MODARELLI': 0,
    'MODDE': 0,
    'MODDELMOG': 0,
    'MODDERMAN': 0,
    'MODDY': 0,
    'MODE': 0,
    'MODEEN': 0,
    'MODEL': 0,
    'MODELL': 0,
    'MODELSKI': 0,
    'MODEN': 0,
    'MODENA': 0,
    'MODER': 0,
    'MODEROW': 0,
    'MODERSKI': 0,
    'MODERSON': 0,
    'MODERT': 0,
    'MODES': 0,
    'MODESITT': 0,
    'MODEST': 0,
    'MODESTA': 1,
    'MODESTE': 0,
    'MODESTI': 0,
    'MODESTO': 0.8928571428571428,
    'MODGLIN': 0,
    'MODGLING': 0,
    'MODHA': 0,
    'MODI': 0,
    'MODIC': 0,
    'MODICA': 0,
    'MODIE': 0,
    'MODIN': 0,
    'MODINE': 0,
    'MODISETT': 0,
    'MODISETTE': 0,
    'MODJESKA': 0,
    'MODJESKI': 0,
    'MODLIN': 0,
    'MODLINSKI': 0,
    'MODOCK': 0,
    'MODRADIAN': 0,
    'MODRAK': 0,
    'MODRALL': 0,
    'MODRELL': 0,
    'MODRICH': 0,
    'MODROW': 0,
    'MODRZEJEWSKI': 0,
    'MODRZYNSKI': 0,
    'MODUGNO': 0,
    'MODY': 0,
    'MODZEL': 0,
    'MODZELEWSKI': 0,
    'MOE': 0,
    'MOEBES': 0,
    'MOEBIUS': 0,
    'MOEBS': 0,
    'MOEBUS': 0,
    'MOECK': 0,
    'MOECKEL': 0,
    'MOED': 0,
    'MOEDANO': 0,
    'MOEDE': 0,
    'MOEDER': 0,
    'MOEGGENBERG': 0,
    'MOEHL': 0,
    'MOEHLE': 0,
    'MOEHLING': 0,
    'MOEHLMAN': 0,
    'MOEHLMANN': 0,
    'MOEHN': 0,
    'MOEHNKE': 0,
    'MOEHR': 0,
    'MOEHRING': 0,
    'MOEHRKE': 0,
    'MOEHRLE': 0,
    'MOELKER': 0,
    'MOELL': 0,
    'MOELLENDORF': 0,
    'MOELLENKAMP': 0,
    'MOELLER': 0,
    'MOELLERING': 0,
    'MOELLERS': 0,
    'MOELLMAN': 0,
    'MOELTER': 0,
    'MOEN': 0,
    'MOENCH': 0,
    'MOENCK': 0,
    'MOENICH': 0,
    'MOENING': 0,
    'MOENNING': 0,
    'MOENS': 0,
    'MOENTER': 0,
    'MOENTMANN': 0,
    'MOERBE': 0,
    'MOERER': 0,
    'MOERICKE': 0,
    'MOERING': 0,
    'MOERKE': 0,
    'MOERMAN': 0,
    'MOERMOND': 0,
    'MOERS': 0,
    'MOERSCH': 0,
    'MOERSCHEL': 0,
    'MOERY': 0,
    'MOES': 0,
    'MOESCH': 0,
    'MOESER': 0,
    'MOESLEIN': 0,
    'MOESSNER': 0,
    'MOESTA': 0,
    'MOEUN': 0,
    'MOEUNG': 0,
    'MOEWS': 0,
    'MOFF': 0,
    'MOFFA': 0,
    'MOFFAT': 0,
    'MOFFATT': 0,
    'MOFFET': 0,
    'MOFFETT': 0,
    'MOFFIT': 0,
    'MOFFITT': 0,
    'MOFFO': 0,
    'MOFFORD': 0,
    'MOFIELD': 0,
    'MOG': 0,
    'MOGA': 0,
    'MOGAN': 0,
    'MOGANNAM': 0,
    'MOGARD': 0,
    'MOGAVERO': 0,
    'MOGCK': 0,
    'MOGE': 0,
    'MOGEL': 0,
    'MOGEN': 0,
    'MOGENSEN': 0,
    'MOGER': 0,
    'MOGES': 0,
    'MOGFORD': 0,
    'MOGG': 0,
    'MOGHADAM': 0,
    'MOGHADDAM': 0,
    'MOGIL': 0,
    'MOGILEVSKY': 0,
    'MOGK': 0,
    'MOGLE': 0,
    'MOGLER': 0,
    'MOGLIA': 0,
    'MOGOLLON': 0,
    'MOGREN': 0,
    'MOGROVEJO': 0,
    'MOGUEL': 0,
    'MOGUL': 0,
    'MOGUS': 0,
    'MOH': 0,
    'MOHABEER': 0,
    'MOHABIR': 0,
    'MOHAGEN': 0,
    'MOHAJER': 0,
    'MOHAMAD': 0,
    'MOHAMADI': 0,
    'MOHAMED': 0.5192107995846313,
    'MOHAMEDALI': 0,
    'MOHAMMAD': 0.8565310492505354,
    'MOHAMMADI': 0,
    'MOHAMMED': 0.6635071090047394,
    'MOHAMOUD': 0,
    'MOHAMUD': 0,
    'MOHAN': 0,
    'MOHANTY': 0,
    'MOHAPATRA': 0,
    'MOHAR': 0,
    'MOHATT': 0,
    'MOHAWK': 0,
    'MOHD': 0,
    'MOHEAD': 0,
    'MOHEBBI': 0,
    'MOHEDANO': 0,
    'MOHER': 0,
    'MOHESKY': 0,
    'MOHIUDDIN': 0,
    'MOHL': 0,
    'MOHLE': 0,
    'MOHLENHOFF': 0,
    'MOHLER': 0,
    'MOHLING': 0,
    'MOHLIS': 0,
    'MOHLKE': 0,
    'MOHLMAN': 0,
    'MOHLMANN': 0,
    'MOHMAND': 0,
    'MOHME': 0,
    'MOHMED': 0,
    'MOHN': 0,
    'MOHNEY': 0,
    'MOHNING': 0,
    'MOHNKERN': 0,
    'MOHNS': 0,
    'MOHON': 0,
    'MOHONEY': 0,
    'MOHORN': 0,
    'MOHR': 0,
    'MOHRBACHER': 0,
    'MOHRE': 0,
    'MOHRFELD': 0,
    'MOHRING': 0,
    'MOHRLAND': 0,
    'MOHRMAN': 0,
    'MOHRMANN': 0,
    'MOHROR': 0,
    'MOHS': 0,
    'MOHSEN': 0,
    'MOHSENI': 0,
    'MOHSIN': 0,
    'MOHUN': 0,
    'MOHUNDRO': 0,
    'MOI': 0,
    'MOILANEN': 0,
    'MOILES': 0,
    'MOIMOI': 0,
    'MOIN': 0,
    'MOINE': 0,
    'MOINI': 0,
    'MOINUDDIN': 0,
    'MOIR': 0,
    'MOIRA': 1,
    'MOISA': 0,
    'MOISAN': 0,
    'MOISANT': 0,
    'MOISE': 0,
    'MOISER': 0,
    'MOISES': 0.9863429438543249,
    'MOISEYEV': 0,
    'MOISIO': 0,
    'MOISON': 0,
    'MOIST': 0,
    'MOISTNER': 0,
    'MOITOSO': 0,
    'MOITOZA': 0,
    'MOIX': 0,
    'MOIZE': 0,
    'MOJARRO': 0,
    'MOJE': 0,
    'MOJENA': 0,
    'MOJICA': 0,
    'MOK': 0,
    'MOKE': 0,
    'MOKER': 0,
    'MOKHTAR': 0,
    'MOKHTARI': 0,
    'MOKIAO': 0,
    'MOKLER': 0,
    'MOKMA': 0,
    'MOKROS': 0,
    'MOKRY': 0,
    'MOKRZYCKI': 0,
    'MOL': 0,
    'MOLA': 0,
    'MOLACEK': 0,
    'MOLAISON': 0,
    'MOLAN': 0,
    'MOLAND': 0,
    'MOLANDER': 0,
    'MOLANDES': 0,
    'MOLANO': 0,
    'MOLARO': 0,
    'MOLASH': 0,
    'MOLASKI': 0,
    'MOLAVI': 0,
    'MOLAY': 0,
    'MOLBERT': 0,
    'MOLBY': 0,
    'MOLCHAN': 0,
    'MOLCHANY': 0,
    'MOLCK': 0,
    'MOLCZYK': 0,
    'MOLD': 0,
    'MOLDAN': 0,
    'MOLDE': 0,
    'MOLDEN': 0,
    'MOLDENHAUER': 0,
    'MOLDER': 0,
    'MOLDOVAN': 0,
    'MOLDREM': 0,
    'MOLE': 0,
    'MOLEA': 0,
    'MOLEK': 0,
    'MOLEN': 0,
    'MOLENA': 0,
    'MOLENAAR': 0,
    'MOLENDA': 0,
    'MOLENKAMP': 0,
    'MOLER': 0,
    'MOLERA': 0,
    'MOLERO': 0,
    'MOLES': 0,
    'MOLESKI': 0,
    'MOLESKY': 0,
    'MOLESWORTH': 0,
    'MOLET': 0,
    'MOLETA': 0,
    'MOLETT': 0,
    'MOLETTE': 0,
    'MOLEY': 0,
    'MOLFESE': 0,
    'MOLFETTA': 0,
    'MOLGAARD': 0,
    'MOLICA': 0,
    'MOLICK': 0,
    'MOLIDOR': 0,
    'MOLIERE': 0,
    'MOLIERI': 0,
    'MOLIK': 0,
    'MOLIN': 0,
    'MOLINA': 0,
    'MOLINAR': 0,
    'MOLINARE': 0,
    'MOLINARES': 0,
    'MOLINARI': 0,
    'MOLINARO': 0,
    'MOLINARY': 0,
    'MOLINAS': 0,
    'MOLINE': 0,
    'MOLINEAUX': 0,
    'MOLINELLI': 0,
    'MOLINERO': 0,
    'MOLINET': 0,
    'MOLINEUX': 0,
    'MOLING': 0,
    'MOLINI': 0,
    'MOLINO': 0,
    'MOLINSKI': 0,
    'MOLINSKY': 0,
    'MOLIS': 0,
    'MOLISANI': 0,
    'MOLISEE': 0,
    'MOLITERNO': 0,
    'MOLITOR': 0,
    'MOLITORIS': 0,
    'MOLK': 0,
    'MOLKENTIN': 0,
    'MOLL': 0,
    'MOLLA': 0,
    'MOLLAH': 0,
    'MOLLAHAN': 0,
    'MOLLAN': 0,
    'MOLLAND': 0,
    'MOLLARD': 0,
    'MOLLBERG': 0,
    'MOLLE': 0,
    'MOLLEDA': 0,
    'MOLLEMA': 0,
    'MOLLEN': 0,
    'MOLLENHAUER': 0,
    'MOLLENHOUR': 0,
    'MOLLENKAMP': 0,
    'MOLLENKOPF': 0,
    'MOLLER': 0,
    'MOLLERE': 0,
    'MOLLES': 0,
    'MOLLET': 0,
    'MOLLETT': 0,
    'MOLLETTE': 0,
    'MOLLEUR': 0,
    'MOLLEY': 0,
    'MOLLI': 0,
    'MOLLICA': 0,
    'MOLLICK': 0,
    'MOLLICONE': 0,
    'MOLLIE': 1,
    'MOLLIN': 0,
    'MOLLINEAUX': 0,
    'MOLLINEDO': 0,
    'MOLLING': 0,
    'MOLLINS': 0,
    'MOLLIS': 0,
    'MOLLISON': 0,
    'MOLLITOR': 0,
    'MOLLMAN': 0,
    'MOLLNER': 0,
    'MOLLO': 0,
    'MOLLOHAN': 0,
    'MOLLON': 0,
    'MOLLOY': 0,
    'MOLLY': 0.9987288905029963,
    'MOLNAR': 0,
    'MOLNER': 0,
    'MOLO': 0,
    'MOLOCK': 0,
    'MOLOHON': 0,
    'MOLON': 0,
    'MOLONE': 0,
    'MOLONEY': 0,
    'MOLONY': 0,
    'MOLOSKY': 0,
    'MOLOUGHNEY': 0,
    'MOLPUS': 0,
    'MOLSBEE': 0,
    'MOLSBERRY': 0,
    'MOLSKI': 0,
    'MOLSON': 0,
    'MOLSTAD': 0,
    'MOLT': 0,
    'MOLTA': 0,
    'MOLTEN': 0,
    'MOLTENI': 0,
    'MOLTER': 0,
    'MOLTHEN': 0,
    'MOLTON': 0,
    'MOLTZ': 0,
    'MOLTZAN': 0,
    'MOLTZEN': 0,
    'MOLUMBY': 0,
    'MOLYNEAUX': 0,
    'MOLYNEUX': 0,
    'MOLZ': 0,
    'MOLZAHN': 0,
    'MOLZAN': 0,
    'MOLZEN': 0,
    'MOLZON': 0,
    'MOM': 0,
    'MOMA': 0,
    'MOMAN': 0,
    'MOMANY': 0,
    'MOMBER': 0,
    'MOMBERG': 0,
    'MOMBERGER': 0,
    'MOMEN': 0,
    'MOMENEE': 0,
    'MOMENI': 0,
    'MOMENT': 0,
    'MOMEYER': 0,
    'MOMIN': 0,
    'MOMINEE': 0,
    'MOMJIAN': 0,
    'MOMMAERTS': 0,
    'MOMMER': 0,
    'MOMMSEN': 0,
    'MOMOH': 0,
    'MOMOHARA': 0,
    'MOMON': 0,
    'MOMOT': 0,
    'MOMPER': 0,
    'MOMPLAISIR': 0,
    'MOMPOINT': 0,
    'MOMPREMIER': 0,
    'MOMSEN': 0,
    'MOMYER': 0,
    'MON': 0,
    'MONA': 0.9915014164305949,
    'MONACELLI': 0,
    'MONACHELLI': 0,
    'MONACHELLO': 0,
    'MONACHINO': 0,
    'MONACK': 0,
    'MONACO': 0,
    'MONAGAN': 0,
    'MONAGAS': 0,
    'MONAGHAN': 0,
    'MONAGLE': 0,
    'MONAHAN': 0,
    'MONAN': 0,
    'MONAR': 0,
    'MONARCA': 0,
    'MONARCH': 0,
    'MONARD': 0,
    'MONARES': 0,
    'MONAREZ': 0,
    'MONARI': 0,
    'MONARQUE': 0,
    'MONARREZ': 0,
    'MONAS': 0,
    'MONASMITH': 0,
    'MONAST': 0,
    'MONASTERIO': 0,
    'MONASTERO': 0,
    'MONASTRA': 0,
    'MONAT': 0,
    'MONATH': 0,
    'MONAY': 0,
    'MONCADA': 0,
    'MONCADO': 0,
    'MONCAYO': 0,
    'MONCE': 0,
    'MONCEAUX': 0,
    'MONCHAK': 0,
    'MONCHAMP': 0,
    'MONCHER': 0,
    'MONCIBAIS': 0,
    'MONCIBAIZ': 0,
    'MONCIER': 0,
    'MONCION': 0,
    'MONCIVAIS': 0,
    'MONCIVAIZ': 0,
    'MONCK': 0,
    'MONCKTON': 0,
    'MONCLA': 0,
    'MONCLOVA': 0,
    'MONCREASE': 0,
    'MONCRIEF': 0,
    'MONCRIEFF': 0,
    'MONCRIEFFE': 0,
    'MONCUR': 0,
    'MONCURE': 0,
    'MONCUS': 0,
    'MOND': 0,
    'MONDA': 0,
    'MONDACA': 0,
    'MONDAINE': 0,
    'MONDAK': 0,
    'MONDAL': 0,
    'MONDAY': 0,
    'MONDE': 0,
    'MONDEAU': 0,
    'MONDEJAR': 0,
    'MONDELL': 0,
    'MONDELLA': 0,
    'MONDELLI': 0,
    'MONDELLO': 0,
    'MONDELUS': 0,
    'MONDEN': 0,
    'MONDESIR': 0,
    'MONDESTIN': 0,
    'MONDI': 0,
    'MONDIE': 0,
    'MONDIN': 0,
    'MONDINE': 0,
    'MONDINO': 0,
    'MONDLOCH': 0,
    'MONDO': 0,
    'MONDOCK': 0,
    'MONDOK': 0,
    'MONDON': 0,
    'MONDOR': 0,
    'MONDORE': 0,
    'MONDOUX': 0,
    'MONDRAGON': 0,
    'MONDRO': 0,
    'MONDRY': 0,
    'MONDS': 0,
    'MONDSCHEIN': 0,
    'MONDT': 0,
    'MONDY': 0,
    'MONE': 0,
    'MONEGAN': 0,
    'MONEGRO': 0,
    'MONEK': 0,
    'MONELL': 0,
    'MONELLO': 0,
    'MONEN': 0,
    'MONER': 0,
    'MONES': 0,
    'MONESMITH': 0,
    'MONESTIME': 0,
    'MONET': 0.8695652173913043,
    'MONETA': 0,
    'MONETT': 0,
    'MONETTA': 0,
    'MONETTE': 0,
    'MONETTI': 0,
    'MONEY': 0,
    'MONEYHAM': 0,
    'MONEYHAN': 0,
    'MONEYHUN': 0,
    'MONEYMAKER': 0,
    'MONEYPENNY': 0,
    'MONEZ': 0,
    'MONFEE': 0,
    'MONFETTE': 0,
    'MONFILS': 0,
    'MONFISTON': 0,
    'MONFORD': 0,
    'MONFORE': 0,
    'MONFORT': 0,
    'MONFORTE': 0,
    'MONFORTON': 0,
    'MONFRE': 0,
    'MONFREDA': 0,
    'MONG': 0,
    'MONGA': 0,
    'MONGALO': 0,
    'MONGAN': 0,
    'MONGAR': 0,
    'MONGE': 0,
    'MONGEAU': 0,
    'MONGELL': 0,
    'MONGELLI': 0,
    'MONGELLO': 0,
    'MONGELLUZZO': 0,
    'MONGEON': 0,
    'MONGER': 0,
    'MONGES': 0,
    'MONGIA': 0,
    'MONGIARDO': 0,
    'MONGIELLO': 0,
    'MONGILLO': 0,
    'MONGIN': 0,
    'MONGIOVI': 0,
    'MONGO': 0,
    'MONGOLD': 0,
    'MONGOMERY': 0,
    'MONGOVEN': 0,
    'MONGRAIN': 0,
    'MONHEIM': 0,
    'MONHEIT': 0,
    'MONHOLLAND': 0,
    'MONHOLLEN': 0,
    'MONHOLLON': 0,
    'MONI': 0,
    'MONIA': 0,
    'MONIAK': 0,
    'MONICA': 0.99693712089364,
    'MONICAL': 0,
    'MONICK': 0,
    'MONICO': 0,
    'MONIE': 0,
    'MONIER': 0,
    'MONIGAN': 0,
    'MONIGOLD': 0,
    'MONIHAN': 0,
    'MONIKA': 1,
    'MONIN': 0,
    'MONINGER': 0,
    'MONIOT': 0,
    'MONIQUE': 0.9992163009404389,
    'MONIS': 0,
    'MONISMITH': 0,
    'MONISTERE': 0,
    'MONITA': 0,
    'MONIZ': 0,
    'MONIZE': 0,
    'MONJARAS': 0,
    'MONJARAZ': 0,
    'MONJE': 0,
    'MONJES': 0,
    'MONK': 0,
    'MONKA': 0,
    'MONKE': 0,
    'MONKEN': 0,
    'MONKHOUSE': 0,
    'MONKIEWICZ': 0,
    'MONKMAN': 0,
    'MONKO': 0,
    'MONKRES': 0,
    'MONKS': 0,
    'MONKUS': 0,
    'MONLEY': 0,
    'MONLUX': 0,
    'MONN': 0,
    'MONNAHAN': 0,
    'MONNAT': 0,
    'MONNENS': 0,
    'MONNET': 0,
    'MONNETT': 0,
    'MONNETTE': 0,
    'MONNEY': 0,
    'MONNICH': 0,
    'MONNIE': 0.9345794392523364,
    'MONNIER': 0,
    'MONNIG': 0,
    'MONNIN': 0,
    'MONNINGER': 0,
    'MONNOT': 0,
    'MONO': 0,
    'MONOHAN': 0,
    'MONOHON': 0,
    'MONOPOLI': 0,
    'MONOS': 0,
    'MONOZ': 0,
    'MONPLAISIR': 0,
    'MONRAD': 0,
    'MONREAL': 0,
    'MONRIAL': 0,
    'MONRO': 0,
    'MONROE': 0.28756290438533433,
    'MONROIG': 0,
    'MONROSE': 0,
    'MONROY': 0,
    'MONRREAL': 0,
    'MONRROY': 0,
    'MONS': 0,
    'MONSALUD': 0,
    'MONSALVE': 0,
    'MONSALVO': 0,
    'MONSANTO': 0,
    'MONSCHEIN': 0,
    'MONSE': 0,
    'MONSEES': 0,
    'MONSEGUR': 0,
    'MONSELL': 0,
    'MONSEN': 0,
    'MONSER': 0,
    'MONSERRAT': 0,
    'MONSERRATE': 0.8968609865470852,
    'MONSEVAIS': 0,
    'MONSEY': 0,
    'MONSIBAIS': 0,
    'MONSIVAIS': 0,
    'MONSIVAIZ': 0,
    'MONSKY': 0,
    'MONSMA': 0,
    'MONSON': 0,
    'MONSOUR': 0,
    'MONSRUD': 0,
    'MONT': 0,
    'MONTA': 0,
    'MONTAG': 0,
    'MONTAGANO': 0,
    'MONTAGNA': 0,
    'MONTAGNE': 0,
    'MONTAGNINO': 0,
    'MONTAGNO': 0,
    'MONTAGUE': 0,
    'MONTAIGNE': 0,
    'MONTAIVO': 0,
    'MONTALBAN': 0,
    'MONTALBANO': 0,
    'MONTALBO': 0,
    'MONTALDO': 0,
    'MONTALTO': 0,
    'MONTALUO': 0,
    'MONTALVAN': 0,
    'MONTALVO': 0,
    'MONTAMBO': 0,
    'MONTAN': 0,
    'MONTANA': 0,
    'MONTANARD': 0,
    'MONTANARI': 0,
    'MONTANARO': 0,
    'MONTANDON': 0,
    'MONTANE': 0,
    'MONTANER': 0,
    'MONTANES': 0,
    'MONTANEZ': 0,
    'MONTANI': 0,
    'MONTANILE': 0,
    'MONTANINO': 0,
    'MONTANIO': 0,
    'MONTANO': 0,
    'MONTANTE': 0,
    'MONTANTES': 0,
    'MONTANTI': 0,
    'MONTANUS': 0,
    'MONTANYA': 0,
    'MONTANYE': 0,
    'MONTAPERTO': 0,
    'MONTAQUE': 0,
    'MONTAQUILA': 0,
    'MONTAS': 0,
    'MONTAVO': 0,
    'MONTAVON': 0,
    'MONTAYA': 0,
    'MONTBRIAND': 0,
    'MONTCALM': 0,
    'MONTCLAIR': 0,
    'MONTE': 0.9047044632086851,
    'MONTEAGUDO': 0,
    'MONTEALEGRE': 0,
    'MONTEALVO': 0,
    'MONTEAU': 0,
    'MONTEBELLO': 0,
    'MONTECALVO': 0,
    'MONTECILLO': 0,
    'MONTECINO': 0,
    'MONTECINOS': 0,
    'MONTEE': 0,
    'MONTEER': 0,
    'MONTEFORTE': 0,
    'MONTEFUSCO': 0,
    'MONTEGNA': 0,
    'MONTEGUT': 0,
    'MONTEI': 0,
    'MONTEIL': 0,
    'MONTEILH': 0,
    'MONTEIRO': 0,
    'MONTEITH': 0,
    'MONTEJANO': 0,
    'MONTEJO': 0,
    'MONTEL': 0,
    'MONTELBANO': 0,
    'MONTELEON': 0,
    'MONTELEONE': 0,
    'MONTELIONE': 0,
    'MONTELIUS': 0,
    'MONTELL': 0,
    'MONTELLA': 0,
    'MONTELLANO': 0,
    'MONTELLI': 0,
    'MONTELLO': 0,
    'MONTELONGO': 0,
    'MONTEMAGNO': 0,
    'MONTEMARANO': 0,
    'MONTEMAYOR': 0,
    'MONTEMURRO': 0,
    'MONTENARO': 0,
    'MONTENEGRO': 0,
    'MONTENERO': 0,
    'MONTEON': 0,
    'MONTEPEQUE': 0,
    'MONTER': 0,
    'MONTERA': 0,
    'MONTERASTELLI': 0,
    'MONTERIO': 0,
    'MONTERO': 0,
    'MONTEROS': 0,
    'MONTEROSA': 0,
    'MONTEROSO': 0,
    'MONTEROSSO': 0,
    'MONTERREY': 0,
    'MONTERROSA': 0,
    'MONTERROSO': 0,
    'MONTERROZA': 0,
    'MONTERRUBIO': 0,
    'MONTES': 0,
    'MONTESA': 0,
    'MONTESANO': 0,
    'MONTESANTI': 0,
    'MONTESANTO': 0,
    'MONTESDEOCA': 0,
    'MONTESI': 0,
    'MONTESINO': 0,
    'MONTESINOS': 0,
    'MONTET': 0,
    'MONTEVERDE': 0,
    'MONTEVERDI': 0,
    'MONTEY': 0,
    'MONTEZ': 0,
    'MONTEZUMA': 0,
    'MONTFORD': 0,
    'MONTFORT': 0,
    'MONTGOMERY': 0,
    'MONTHEI': 0,
    'MONTHIE': 0,
    'MONTI': 0,
    'MONTICELLI': 0,
    'MONTICELLO': 0,
    'MONTICUE': 0,
    'MONTIE': 0,
    'MONTIEL': 0,
    'MONTIERO': 0,
    'MONTIERTH': 0,
    'MONTIETH': 0,
    'MONTIGNY': 0,
    'MONTIJO': 0,
    'MONTILLA': 0,
    'MONTINI': 0,
    'MONTION': 0,
    'MONTIQUE': 0,
    'MONTIS': 0,
    'MONTJOY': 0,
    'MONTLE': 0,
    'MONTMINY': 0,
    'MONTNEY': 0,
    'MONTO': 0,
    'MONTOGOMERY': 0,
    'MONTOLIO': 0,
    'MONTOLLA': 0,
    'MONTON': 0,
    'MONTONDO': 0,
    'MONTONE': 0,
    'MONTONEY': 0,
    'MONTONI': 0,
    'MONTOOTH': 0,
    'MONTORO': 0,
    'MONTOTO': 0,
    'MONTOUR': 0,
    'MONTOURE': 0,
    'MONTOUTE': 0,
    'MONTOY': 0,
    'MONTOYA': 0,
    'MONTPAS': 0,
    'MONTPELIER': 0,
    'MONTPETIT': 0,
    'MONTPLAISIR': 0,
    'MONTREAL': 0,
    'MONTREUIL': 0,
    'MONTREVIL': 0,
    'MONTREY': 0,
    'MONTRI': 0,
    'MONTROND': 0,
    'MONTRONE': 0,
    'MONTROSE': 0,
    'MONTROSS': 0,
    'MONTROY': 0,
    'MONTRY': 0,
    'MONTS': 0,
    'MONTUFAR': 0,
    'MONTUORI': 0,
    'MONTUORO': 0,
    'MONTVILLE': 0,
    'MONTY': 0.9546539379474941,
    'MONTZ': 0,
    'MONUS': 0,
    'MONVILLE': 0,
    'MONY': 0,
    'MONYAK': 0,
    'MONZ': 0,
    'MONZEL': 0,
    'MONZINGO': 0,
    'MONZO': 0,
    'MONZON': 0,
    'MOO': 0,
    'MOOBERRY': 0,
    'MOOCK': 0,
    'MOOD': 0,
    'MOODEY': 0,
    'MOODIE': 0,
    'MOODY': 0,
    'MOOERS': 0,
    'MOOG': 0,
    'MOOI': 0,
    'MOOK': 0,
    'MOOKE': 0,
    'MOOLE': 0,
    'MOOMAU': 0,
    'MOOMAW': 0,
    'MOOMEY': 0,
    'MOON': 0.060277275467148894,
    'MOONAN': 0,
    'MOONE': 0,
    'MOONEN': 0,
    'MOONEY': 0,
    'MOONEYHAM': 0,
    'MOONEYHAN': 0,
    'MOONIER': 0,
    'MOONINGHAM': 0,
    'MOONS': 0,
    'MOONSAMMY': 0,
    'MOOR': 0,
    'MOORADIAN': 0,
    'MOORBY': 0,
    'MOORCROFT': 0,
    'MOORE': 0,
    'MOOREFIELD': 0,
    'MOOREHEAD': 0,
    'MOOREHOUSE': 0,
    'MOORELAND': 0,
    'MOORER': 0,
    'MOORES': 0,
    'MOORHEAD': 0,
    'MOORHOUS': 0,
    'MOORHOUSE': 0,
    'MOORING': 0,
    'MOORIS': 0,
    'MOORJANI': 0,
    'MOORMAN': 0,
    'MOORMANN': 0,
    'MOORS': 0,
    'MOORSE': 0,
    'MOORTHY': 0,
    'MOOS': 0,
    'MOOSA': 0,
    'MOOSAVI': 0,
    'MOOSBRUGGER': 0,
    'MOOSE': 0,
    'MOOSER': 0,
    'MOOSMAN': 0,
    'MOOSMANN': 0,
    'MOOSO': 0,
    'MOOT': 0,
    'MOOTE': 0,
    'MOOTHART': 0,
    'MOOTOO': 0,
    'MOOTRY': 0,
    'MOOTS': 0,
    'MOOTY': 0,
    'MOOTZ': 0,
    'MOOY': 0,
    'MOOYOUNG': 0,
    'MOPPERT': 0,
    'MOPPIN': 0,
    'MOPPINS': 0,
    'MOQUETE': 0,
    'MOQUIN': 0,
    'MOQUINO': 0,
    'MOR': 0,
    'MORA': 0.0612369871402327,
    'MORABITO': 0,
    'MORACA': 0,
    'MORACCO': 0,
    'MORACE': 0,
    'MORACHE': 0,
    'MORACK': 0,
    'MORACO': 0,
    'MORACZEWSKI': 0,
    'MORAD': 0,
    'MORADA': 0,
    'MORADEL': 0,
    'MORADI': 0,
    'MORADIAN': 0,
    'MORADO': 0,
    'MORAES': 0,
    'MORAGA': 0,
    'MORAGNE': 0,
    'MORAGO': 0,
    'MORAHAN': 0,
    'MORAIDA': 0,
    'MORAILA': 0,
    'MORAIN': 0,
    'MORAINE': 0,
    'MORAIS': 0,
    'MORAITES': 0,
    'MORAITIS': 0,
    'MORAL': 0,
    'MORALAS': 0,
    'MORALE': 0,
    'MORALES': 0,
    'MORALESGARCIA': 0,
    'MORALESLOPEZ': 0,
    'MORALEZ': 0,
    'MORALIS': 0,
    'MORAMARCO': 0,
    'MORAN': 0,
    'MORANA': 0,
    'MORANCHEL': 0,
    'MORANCY': 0,
    'MORAND': 0,
    'MORANDA': 0,
    'MORANDI': 0,
    'MORANDO': 0,
    'MORANG': 0,
    'MORANI': 0,
    'MORANO': 0,
    'MORANSKI': 0,
    'MORANT': 0,
    'MORANTE': 0,
    'MORANTES': 0,
    'MORANVILLE': 0,
    'MORANZ': 0,
    'MORAR': 0,
    'MORARU': 0,
    'MORAS': 0,
    'MORASCH': 0,
    'MORASCO': 0,
    'MORASH': 0,
    'MORASKI': 0,
    'MORASSE': 0,
    'MORAST': 0,
    'MORAT': 0,
    'MORATA': 0,
    'MORATAYA': 0,
    'MORATH': 0,
    'MORATO': 0,
    'MORATTO': 0,
    'MORAVA': 0,
    'MORAVCIK': 0,
    'MORAVEC': 0,
    'MORAVEK': 0,
    'MORAVETZ': 0,
    'MORAVITS': 0,
    'MORAVITZ': 0,
    'MORAWA': 0,
    'MORAWIEC': 0,
    'MORAWSKI': 0,
    'MORAY': 0,
    'MORAZA': 0,
    'MORAZAN': 0,
    'MORBER': 0,
    'MORBITZER': 0,
    'MORBY': 0,
    'MORCH': 0,
    'MORCIGLIO': 0,
    'MORCILLO': 0,
    'MORCK': 0,
    'MORCKEL': 0,
    'MORCOM': 0,
    'MORCOS': 0,
    'MORD': 0,
    'MORDA': 0,
    'MORDAN': 0,
    'MORDARSKI': 0,
    'MORDAS': 0,
    'MORDAUNT': 0,
    'MORDECAI': 0,
    'MORDEN': 0,
    'MORDENTE': 0,
    'MORDER': 0,
    'MORDHORST': 0,
    'MORDI': 0,
    'MORDICA': 0,
    'MORDICK': 0,
    'MORDINI': 0,
    'MORDUE': 0,
    'MORE': 0,
    'MOREA': 0,
    'MOREAN': 0,
    'MOREANO': 0,
    'MOREAU': 0,
    'MOREAUX': 0,
    'MORECI': 0,
    'MORECRAFT': 0,
    'MOREDA': 0,
    'MOREDOCK': 0,
    'MOREE': 0,
    'MOREEN': 0,
    'MOREFIELD': 0,
    'MOREHART': 0,
    'MOREHEAD': 0,
    'MOREHOUSE': 0,
    'MOREIDA': 0,
    'MOREIN': 0,
    'MOREIRA': 0,
    'MOREJON': 0,
    'MOREL': 0,
    'MORELAN': 0,
    'MORELAND': 0,
    'MORELES': 0,
    'MORELL': 0,
    'MORELLA': 0,
    'MORELLE': 0,
    'MORELLI': 0,
    'MORELLO': 0,
    'MORELOCK': 0,
    'MORELOS': 0,
    'MOREMAN': 0,
    'MOREN': 0,
    'MORENA': 0,
    'MORENCY': 0,
    'MORENE': 0,
    'MORENO': 0,
    'MORENOGARCIA': 0,
    'MORENTE': 0,
    'MORENTIN': 0,
    'MORENUS': 0,
    'MORENZ': 0,
    'MOREO': 0,
    'MORERA': 0,
    'MORES': 0,
    'MORESCHI': 0,
    'MORESCO': 0,
    'MORESHEAD': 0,
    'MORESI': 0,
    'MORET': 0,
    'MORETA': 0,
    'MORETH': 0,
    'MORETON': 0,
    'MORETT': 0,
    'MORETTA': 0,
    'MORETTI': 0,
    'MORETTINI': 0,
    'MORETTO': 0,
    'MORETZ': 0,
    'MOREY': 0,
    'MOREYRA': 0,
    'MORF': 0,
    'MORFA': 0,
    'MORFE': 0,
    'MORFELD': 0,
    'MORFFI': 0,
    'MORFIN': 0,
    'MORFITT': 0,
    'MORFORD': 0,
    'MORGA': 0,
    'MORGADO': 0,
    'MORGAL': 0,
    'MORGAN': 0.2807805699845571,
    'MORGANELLI': 0,
    'MORGANFIELD': 0,
    'MORGANO': 0,
    'MORGANROTH': 0,
    'MORGANS': 0,
    'MORGANSON': 0,
    'MORGANSTEIN': 0,
    'MORGANSTERN': 0,
    'MORGANTE': 0,
    'MORGANTI': 0,
    'MORGANTINI': 0,
    'MORGART': 0,
    'MORGASON': 0,
    'MORGE': 0,
    'MORGEN': 0,
    'MORGENROTH': 0,
    'MORGENSEN': 0,
    'MORGENSON': 0,
    'MORGENSTEIN': 0,
    'MORGENSTERN': 0,
    'MORGENTHAL': 0,
    'MORGENTHALER': 0,
    'MORGENWECK': 0,
    'MORGER': 0,
    'MORGERA': 0,
    'MORGESE': 0,
    'MORGESON': 0,
    'MORGIA': 0,
    'MORGILLO': 0,
    'MORGNER': 0,
    'MORGON': 0,
    'MORGRET': 0,
    'MORGRIDGE': 0,
    'MORHARDT': 0,
    'MORI': 0,
    'MORIA': 0,
    'MORIAH': 1,
    'MORIAN': 0,
    'MORIARITY': 0,
    'MORIARTY': 0,
    'MORIC': 0,
    'MORICAL': 0,
    'MORICE': 0,
    'MORICH': 0,
    'MORICI': 0,
    'MORICK': 0,
    'MORICLE': 0,
    'MORICO': 0,
    'MORICONI': 0,
    'MORICZ': 0,
    'MORIE': 0,
    'MORIEL': 0,
    'MORIELLO': 0,
    'MORIEN': 0,
    'MORIGEAU': 0,
    'MORIGUCHI': 0,
    'MORIHARA': 0,
    'MORIKAWA': 0,
    'MORILLA': 0,
    'MORILLO': 0,
    'MORILLON': 0,
    'MORIMOTO': 0,
    'MORIN': 0,
    'MORINA': 0,
    'MORINAGA': 0,
    'MORINAKA': 0,
    'MORINE': 0,
    'MORINELLI': 0,
    'MORING': 0,
    'MORINI': 0,
    'MORINO': 0,
    'MORINVILLE': 0,
    'MORIO': 0,
    'MORIOKA': 0,
    'MORIS': 0,
    'MORISAKI': 0,
    'MORISCO': 0,
    'MORISETTE': 0,
    'MORISHIGE': 0,
    'MORISHIMA': 0,
    'MORISHITA': 0,
    'MORISI': 0,
    'MORISON': 0,
    'MORISSE': 0,
    'MORISSEAU': 0,
    'MORISSET': 0,
    'MORISSETTE': 0,
    'MORITA': 0,
    'MORITZ': 0,
    'MORIWAKI': 0,
    'MORIYA': 0,
    'MORIYAMA': 0,
    'MORIZIO': 0,
    'MORK': 0,
    'MORKEN': 0,
    'MORKERT': 0,
    'MORKIN': 0,
    'MORLA': 0,
    'MORLAN': 0,
    'MORLAND': 0,
    'MORLANDO': 0,
    'MORLANG': 0,
    'MORLAS': 0,
    'MORLEN': 0,
    'MORLES': 0,
    'MORLET': 0,
    'MORLETT': 0,
    'MORLEY': 0,
    'MORLINO': 0,
    'MORLOCK': 0,
    'MORLOK': 0,
    'MORMAN': 0,
    'MORMANDO': 0,
    'MORMANN': 0,
    'MORMILE': 0,
    'MORMINO': 0,
    'MORMON': 0,
    'MORN': 0,
    'MORNEAU': 0,
    'MORNEAULT': 0,
    'MORNER': 0,
    'MORNES': 0,
    'MORNING': 0,
    'MORNINGSTAR': 0,
    'MORO': 0,
    'MOROCCO': 0,
    'MOROCH': 0,
    'MOROCHO': 0,
    'MOROCK': 0,
    'MOROLES': 0,
    'MORON': 0,
    'MORONE': 0,
    'MORONES': 0,
    'MORONEY': 0,
    'MORONEZ': 0,
    'MORONG': 0,
    'MORONI': 0,
    'MORONTA': 0,
    'MOROS': 0,
    'MOROSCO': 0,
    'MOROSE': 0,
    'MOROSINI': 0,
    'MOROSKI': 0,
    'MOROSKO': 0,
    'MOROSKY': 0,
    'MOROSO': 0,
    'MOROSS': 0,
    'MOROYOQUI': 0,
    'MOROZ': 0,
    'MOROZOV': 0,
    'MOROZOVA': 0,
    'MORPHET': 0,
    'MORPHEW': 0,
    'MORPHIS': 0,
    'MORPHY': 0,
    'MORQUECHO': 0,
    'MORR': 0,
    'MORRA': 0,
    'MORRAL': 0,
    'MORRALES': 0,
    'MORRALL': 0,
    'MORRAN': 0,
    'MORRAY': 0,
    'MORRE': 0,
    'MORREALE': 0,
    'MORREIRA': 0,
    'MORREL': 0,
    'MORRELL': 0,
    'MORRELLI': 0,
    'MORRELLO': 0,
    'MORREN': 0,
    'MORRES': 0,
    'MORRETT': 0,
    'MORREY': 0,
    'MORRI': 0,
    'MORRICAL': 0,
    'MORRICE': 0,
    'MORRIE': 0,
    'MORRIES': 0,
    'MORRILL': 0,
    'MORRIN': 0,
    'MORRING': 0,
    'MORRIS': 0.30617758299813885,
    'MORRISETT': 0,
    'MORRISETTE': 0,
    'MORRISEY': 0,
    'MORRISH': 0,
    'MORRISON': 0,
    'MORRISROE': 0,
    'MORRISS': 0,
    'MORRISSEAU': 0,
    'MORRISSETT': 0,
    'MORRISSETTE': 0,
    'MORRISSEY': 0,
    'MORRISSON': 0,
    'MORRISSY': 0,
    'MORRISTON': 0,
    'MORRO': 0,
    'MORROBEL': 0,
    'MORROCCO': 0,
    'MORRON': 0,
    'MORRONE': 0,
    'MORRONGIELLO': 0,
    'MORRONI': 0,
    'MORROS': 0,
    'MORROW': 0,
    'MORRY': 0,
    'MORS': 0,
    'MORSBACH': 0,
    'MORSBERGER': 0,
    'MORSCH': 0,
    'MORSCHAUSER': 0,
    'MORSCHING': 0,
    'MORSE': 0,
    'MORSELL': 0,
    'MORSEMAN': 0,
    'MORSER': 0,
    'MORSETH': 0,
    'MORSETTE': 0,
    'MORSEY': 0,
    'MORSHED': 0,
    'MORSI': 0,
    'MORSMAN': 0,
    'MORSON': 0,
    'MORSS': 0,
    'MORSTAD': 0,
    'MORSY': 0,
    'MORT': 0,
    'MORTAN': 0,
    'MORTARA': 0,
    'MORTAZAVI': 0,
    'MORTE': 0,
    'MORTEL': 0,
    'MORTELL': 0,
    'MORTELLARO': 0,
    'MORTEN': 0,
    'MORTENSEN': 0,
    'MORTENSON': 0,
    'MORTER': 0,
    'MORTERA': 0,
    'MORTH': 0,
    'MORTHLAND': 0,
    'MORTIER': 0,
    'MORTILLARO': 0,
    'MORTIMER': 0,
    'MORTIMORE': 0,
    'MORTIN': 0,
    'MORTIS': 0,
    'MORTL': 0,
    'MORTLAND': 0,
    'MORTLEY': 0,
    'MORTLOCK': 0,
    'MORTOLA': 0,
    'MORTON': 0.2431399791594304,
    'MORTORFF': 0,
    'MORTVEDT': 0,
    'MORTZ': 0,
    'MORUA': 0,
    'MORUZZI': 0,
    'MORVA': 0,
    'MORVAN': 0,
    'MORVANT': 0,
    'MORVAY': 0,
    'MORVILLO': 0,
    'MORWAY': 0,
    'MORWOOD': 0,
    'MORY': 0,
    'MORYL': 0,
    'MOS': 0,
    'MOSA': 0,
    'MOSACK': 0,
    'MOSAKOWSKI': 0,
    'MOSBACH': 0,
    'MOSBACHER': 0,
    'MOSBARGER': 0,
    'MOSBAUGH': 0,
    'MOSBERG': 0,
    'MOSBEY': 0,
    'MOSBRUCKER': 0,
    'MOSBURG': 0,
    'MOSBY': 0,
    'MOSCA': 0,
    'MOSCARDELLI': 0,
    'MOSCARDINI': 0,
    'MOSCARELLI': 0,
    'MOSCARELLO': 0,
    'MOSCARIELLO': 0,
    'MOSCARITOLO': 0,
    'MOSCATELLI': 0,
    'MOSCATELLO': 0,
    'MOSCATI': 0,
    'MOSCATIELLO': 0,
    'MOSCATO': 0,
    'MOSCH': 0,
    'MOSCHEL': 0,
    'MOSCHELL': 0,
    'MOSCHELLA': 0,
    'MOSCHETTA': 0,
    'MOSCHETTI': 0,
    'MOSCHETTO': 0,
    'MOSCHINI': 0,
    'MOSCHITTA': 0,
    'MOSCHNER': 0,
    'MOSCICKI': 0,
    'MOSCINSKI': 0,
    'MOSCO': 0,
    'MOSCOE': 0,
    'MOSCONE': 0,
    'MOSCONI': 0,
    'MOSCOSA': 0,
    'MOSCOSO': 0,
    'MOSCOW': 0,
    'MOSCOWITZ': 0,
    'MOSCRIP': 0,
    'MOSE': 0.851063829787234,
    'MOSEBACH': 0,
    'MOSEBAR': 0,
    'MOSEBROOK': 0,
    'MOSEBY': 0,
    'MOSEL': 0,
    'MOSELE': 0,
    'MOSELER': 0,
    'MOSELEY': 0,
    'MOSELLE': 0,
    'MOSELY': 0,
    'MOSEMAN': 0,
    'MOSEMANN': 0,
    'MOSENG': 0,
    'MOSER': 0,
    'MOSES': 0.5943536404160475,
    'MOSESON': 0,
    'MOSESSO': 0,
    'MOSEY': 0,
    'MOSGROVE': 0,
    'MOSHE': 0.9803921568627452,
    'MOSHER': 0,
    'MOSHIER': 0,
    'MOSHIRI': 0,
    'MOSHKOVICH': 0,
    'MOSHOLDER': 0,
    'MOSHOS': 0,
    'MOSICH': 0,
    'MOSIELLO': 0,
    'MOSIER': 0,
    'MOSIMAN': 0,
    'MOSIMANN': 0,
    'MOSINIAK': 0,
    'MOSINSKI': 0,
    'MOSIO': 0,
    'MOSK': 0,
    'MOSKAL': 0,
    'MOSKALENKO': 0,
    'MOSKALIK': 0,
    'MOSKALSKI': 0,
    'MOSKALUK': 0,
    'MOSKE': 0,
    'MOSKEY': 0,
    'MOSKO': 0,
    'MOSKOS': 0,
    'MOSKOVICH': 0,
    'MOSKOVITS': 0,
    'MOSKOVITZ': 0,
    'MOSKOW': 0,
    'MOSKOWITZ': 0,
    'MOSKUS': 0,
    'MOSKWA': 0,
    'MOSLANDER': 0,
    'MOSLEH': 0,
    'MOSLER': 0,
    'MOSLEY': 0,
    'MOSLOW': 0,
    'MOSMAN': 0,
    'MOSNER': 0,
    'MOSO': 0,
    'MOSON': 0,
    'MOSQUEA': 0,
    'MOSQUEDA': 0,
    'MOSQUEIRA': 0,
    'MOSQUERA': 0,
    'MOSS': 0,
    'MOSSA': 0,
    'MOSSBARGER': 0,
    'MOSSBERG': 0,
    'MOSSBERGER': 0,
    'MOSSBURG': 0,
    'MOSSE': 0,
    'MOSSER': 0,
    'MOSSERI': 0,
    'MOSSES': 0,
    'MOSSET': 0,
    'MOSSETT': 0,
    'MOSSEY': 0,
    'MOSSHOLDER': 0,
    'MOSSI': 0,
    'MOSSING': 0,
    'MOSSLER': 0,
    'MOSSMAN': 0,
    'MOSSNER': 0,
    'MOSSO': 0,
    'MOSSON': 0,
    'MOSSOP': 0,
    'MOSSOR': 0,
    'MOSSOW': 0,
    'MOST': 0,
    'MOSTAD': 0,
    'MOSTAFA': 0,
    'MOSTAFAVI': 0,
    'MOSTAJO': 0,
    'MOSTEK': 0,
    'MOSTELLA': 0,
    'MOSTELLER': 0,
    'MOSTER': 0,
    'MOSTERT': 0,
    'MOSTILLER': 0,
    'MOSTOFI': 0,
    'MOSTOLLER': 0,
    'MOSTOVOY': 0,
    'MOSTOW': 0,
    'MOSTOWY': 0,
    'MOSTROM': 0,
    'MOSTYN': 0,
    'MOSURE': 0,
    'MOSZER': 0,
    'MOSZKOWICZ': 0,
    'MOTA': 0,
    'MOTAL': 0,
    'MOTAMED': 0,
    'MOTAMEDI': 0,
    'MOTAS': 0,
    'MOTE': 0,
    'MOTEL': 0,
    'MOTEN': 0,
    'MOTER': 0,
    'MOTES': 0,
    'MOTH': 0,
    'MOTHERAL': 0,
    'MOTHERSBAUGH': 0,
    'MOTHERSELL': 0,
    'MOTHERSHEAD': 0,
    'MOTHERSHED': 0,
    'MOTHERSILL': 0,
    'MOTHERWAY': 0,
    'MOTHERWELL': 0,
    'MOTHES': 0,
    'MOTHS': 0,
    'MOTI': 0,
    'MOTICHEK': 0,
    'MOTICHKA': 0,
    'MOTIKA': 0,
    'MOTIL': 0,
    'MOTIN': 0,
    'MOTIS': 0,
    'MOTISI': 0,
    'MOTIWALA': 0,
    'MOTKO': 0,
    'MOTL': 0,
    'MOTLAGH': 0,
    'MOTLEY': 0,
    'MOTLOW': 0,
    'MOTO': 0,
    'MOTOLA': 0,
    'MOTON': 0,
    'MOTONAGA': 0,
    'MOTOS': 0,
    'MOTOYAMA': 0,
    'MOTRONI': 0,
    'MOTSCH': 0,
    'MOTSCHENBACHER': 0,
    'MOTSENBOCKER': 0,
    'MOTSINGER': 0,
    'MOTSKO': 0,
    'MOTT': 0,
    'MOTTA': 0,
    'MOTTAZ': 0,
    'MOTTE': 0,
    'MOTTELER': 0,
    'MOTTER': 0,
    'MOTTERN': 0,
    'MOTTERSHEAD': 0,
    'MOTTES': 0,
    'MOTTESHEARD': 0,
    'MOTTET': 0,
    'MOTTI': 0,
    'MOTTICE': 0,
    'MOTTIN': 0,
    'MOTTINGER': 0,
    'MOTTL': 0,
    'MOTTLE': 0,
    'MOTTLEY': 0,
    'MOTTO': 0,
    'MOTTOLA': 0,
    'MOTTON': 0,
    'MOTTRAM': 0,
    'MOTTS': 0,
    'MOTTU': 0,
    'MOTWANI': 0,
    'MOTYCKA': 0,
    'MOTYKA': 0,
    'MOTYL': 0,
    'MOTZ': 0,
    'MOTZER': 0,
    'MOTZKO': 0,
    'MOTZKUS': 0,
    'MOU': 0,
    'MOUA': 0,
    'MOUAT': 0,
    'MOUAWAD': 0,
    'MOUBRAY': 0,
    'MOUCH': 0,
    'MOUCHA': 0,
    'MOUCK': 0,
    'MOUDRY': 0,
    'MOUDY': 0,
    'MOUER': 0,
    'MOUG': 0,
    'MOUGEY': 0,
    'MOUGH': 0,
    'MOUGHAN': 0,
    'MOUGHLER': 0,
    'MOUGHON': 0,
    'MOUGIN': 0,
    'MOUHOT': 0,
    'MOUILLE': 0,
    'MOUL': 0,
    'MOULAISON': 0,
    'MOULD': 0,
    'MOULDEN': 0,
    'MOULDER': 0,
    'MOULDING': 0,
    'MOULDS': 0,
    'MOULE': 0,
    'MOULES': 0,
    'MOULIN': 0,
    'MOULIS': 0,
    'MOULTHROP': 0,
    'MOULTON': 0,
    'MOULTRIE': 0,
    'MOULTRUP': 0,
    'MOULTRY': 0,
    'MOULZOLF': 0,
    'MOUM': 0,
    'MOUN': 0,
    'MOUNCE': 0,
    'MOUND': 0,
    'MOUNGA': 0,
    'MOUNGER': 0,
    'MOUNIER': 0,
    'MOUNIVONG': 0,
    'MOUNKES': 0,
    'MOUNSEY': 0,
    'MOUNT': 0,
    'MOUNTAIN': 0,
    'MOUNTCASTLE': 0,
    'MOUNTEER': 0,
    'MOUNTFORD': 0,
    'MOUNTJOY': 0,
    'MOUNTS': 0,
    'MOUNTZ': 0,
    'MOURA': 0,
    'MOURAD': 0,
    'MOURADIAN': 0,
    'MOURAO': 0,
    'MOURE': 0,
    'MOUREAU': 0,
    'MOURER': 0,
    'MOURET': 0,
    'MOUREY': 0,
    'MOURING': 0,
    'MOURINO': 0,
    'MOURITSEN': 0,
    'MOURNING': 0,
    'MOURO': 0,
    'MOURTON': 0,
    'MOURY': 0,
    'MOUSA': 0,
    'MOUSAVI': 0,
    'MOUSAW': 0,
    'MOUSE': 0,
    'MOUSEL': 0,
    'MOUSER': 0,
    'MOUSHEY': 0,
    'MOUSHON': 0,
    'MOUSLEY': 0,
    'MOUSSA': 0,
    'MOUSSAVI': 0,
    'MOUSSEAU': 0,
    'MOUSSETTE': 0,
    'MOUSTAFA': 0,
    'MOUSTAKAS': 0,
    'MOUSTAKIS': 0,
    'MOUTINHO': 0,
    'MOUTON': 0,
    'MOUTOUX': 0,
    'MOUTRAY': 0,
    'MOUTREY': 0,
    'MOUTRY': 0,
    'MOUW': 0,
    'MOUZAKIS': 0,
    'MOUZON': 0,
    'MOUZONE': 0,
    'MOVA': 0,
    'MOVER': 0,
    'MOVIUS': 0,
    'MOVSESIAN': 0,
    'MOVSESSIAN': 0,
    'MOVSESYAN': 0,
    'MOW': 0,
    'MOWAD': 0,
    'MOWAN': 0,
    'MOWAT': 0,
    'MOWATT': 0,
    'MOWBRAY': 0,
    'MOWDAY': 0,
    'MOWDER': 0,
    'MOWDY': 0,
    'MOWE': 0,
    'MOWELL': 0,
    'MOWEN': 0,
    'MOWER': 0,
    'MOWERS': 0,
    'MOWERY': 0,
    'MOWINSKI': 0,
    'MOWL': 0,
    'MOWLA': 0,
    'MOWLES': 0,
    'MOWRER': 0,
    'MOWREY': 0,
    'MOWRIS': 0,
    'MOWRY': 0,
    'MOX': 0,
    'MOXAM': 0,
    'MOXEY': 0,
    'MOXHAM': 0,
    'MOXIE': 0,
    'MOXLEY': 0,
    'MOXNESS': 0,
    'MOXON': 0,
    'MOY': 0,
    'MOYA': 0,
    'MOYAL': 0,
    'MOYANO': 0,
    'MOYAO': 0,
    'MOYAR': 0,
    'MOYD': 0,
    'MOYE': 0,
    'MOYEDA': 0,
    'MOYEN': 0,
    'MOYER': 0,
    'MOYERS': 0,
    'MOYES': 0,
    'MOYET': 0,
    'MOYHER': 0,
    'MOYLAN': 0,
    'MOYLE': 0,
    'MOYLER': 0,
    'MOYLES': 0,
    'MOYNA': 0,
    'MOYNAGH': 0,
    'MOYNAHAN': 0,
    'MOYNIER': 0,
    'MOYNIHAN': 0,
    'MOYO': 0,
    'MOYOTL': 0,
    'MOYSE': 0,
    'MOZ': 0,
    'MOZA': 0,
    'MOZAFFARI': 0,
    'MOZAL': 0,
    'MOZDEN': 0,
    'MOZDZEN': 0,
    'MOZDZIERZ': 0,
    'MOZE': 0,
    'MOZEB': 0,
    'MOZEE': 0,
    'MOZELESKI': 0,
    'MOZELL': 0.9740259740259739,
    'MOZELLA': 1,
    'MOZELLE': 0.992063492063492,
    'MOZENA': 0,
    'MOZER': 0,
    'MOZES': 0,
    'MOZIE': 0,
    'MOZIER': 0,
    'MOZINA': 0,
    'MOZINGO': 0,
    'MOZISEK': 0,
    'MOZLEY': 0,
    'MOZO': 0,
    'MOZQUEDA': 0,
    'MOZZETTI': 0,
    'MOZZICATO': 0,
    'MOZZONE': 0,
    'MRACEK': 0,
    'MRACHEK': 0,
    'MRAK': 0,
    'MRAMOR': 0,
    'MRAS': 0,
    'MRAZ': 0,
    'MRAZEK': 0,
    'MRAZIK': 0,
    'MRKVICKA': 0,
    'MROCH': 0,
    'MROCK': 0,
    'MROCZEK': 0,
    'MROCZENSKI': 0,
    'MROCZKA': 0,
    'MROCZKO': 0,
    'MROCZKOWSKI': 0,
    'MROS': 0,
    'MROSKO': 0,
    'MROSLA': 0,
    'MROSS': 0,
    'MROTEK': 0,
    'MROWCA': 0,
    'MROWCZYNSKI': 0,
    'MROWIEC': 0,
    'MROWKA': 0,
    'MROZ': 0,
    'MROZEK': 0,
    'MROZIK': 0,
    'MROZINSKI': 0,
    'MROZOWSKI': 0,
    'MRSNY': 0,
    'MRUGALA': 0,
    'MRUK': 0,
    'MRUZ': 0,
    'MRVA': 0,
    'MU': 0,
    'MUA': 0,
    'MUASAU': 0,
    'MUBARAK': 0,
    'MUCARIA': 0,
    'MUCCI': 0,
    'MUCCIA': 0,
    'MUCCIACCIARO': 0,
    'MUCCIARONE': 0,
    'MUCCIGROSSO': 0,
    'MUCCINO': 0,
    'MUCCIO': 0,
    'MUCCIOLI': 0,
    'MUCCIOLO': 0,
    'MUCERINO': 0,
    'MUCH': 0,
    'MUCHA': 0,
    'MUCHE': 0,
    'MUCHER': 0,
    'MUCHERINO': 0,
    'MUCHLER': 0,
    'MUCHMORE': 0,
    'MUCHNICK': 0,
    'MUCHNIK': 0,
    'MUCHOW': 0,
    'MUCIA': 0,
    'MUCINO': 0,
    'MUCK': 0,
    'MUCKEL': 0,
    'MUCKELROY': 0,
    'MUCKENFUSS': 0,
    'MUCKENHIRN': 0,
    'MUCKENSTURM': 0,
    'MUCKENTHALER': 0,
    'MUCKER': 0,
    'MUCKERHEIDE': 0,
    'MUCKERMAN': 0,
    'MUCKEY': 0,
    'MUCKLE': 0,
    'MUCKLER': 0,
    'MUCKLEROY': 0,
    'MUCKLEY': 0,
    'MUCKLOW': 0,
    'MUCZYNSKI': 0,
    'MUDALIAR': 0,
    'MUDD': 0,
    'MUDDER': 0,
    'MUDDIMAN': 0,
    'MUDEK': 0,
    'MUDER': 0,
    'MUDGE': 0,
    'MUDGET': 0,
    'MUDGETT': 0,
    'MUDIE': 0,
    'MUDLOFF': 0,
    'MUDRA': 0,
    'MUDRACK': 0,
    'MUDRAK': 0,
    'MUDRICK': 0,
    'MUDROCK': 0,
    'MUDROW': 0,
    'MUDRY': 0,
    'MUDRYK': 0,
    'MUECK': 0,
    'MUECKE': 0,
    'MUEGGE': 0,
    'MUEGGENBERG': 0,
    'MUEGGENBORG': 0,
    'MUEHE': 0,
    'MUEHL': 0,
    'MUEHLBACH': 0,
    'MUEHLBAUER': 0,
    'MUEHLBERG': 0,
    'MUEHLBERGER': 0,
    'MUEHLEISEN': 0,
    'MUEHLENBECK': 0,
    'MUEHLENKAMP': 0,
    'MUEHLER': 0,
    'MUEHLFELD': 0,
    'MUEHLHAUSEN': 0,
    'MUEHLHAUSER': 0,
    'MUEHLING': 0,
    'MUEHLSTEIN': 0,
    'MUEHR': 0,
    'MUEHRING': 0,
    'MUELA': 0,
    'MUELKEN': 0,
    'MUELL': 0,
    'MUELLENBACH': 0,
    'MUELLENBERG': 0,
    'MUELLER': 0,
    'MUELLERLEILE': 0,
    'MUELLNER': 0,
    'MUENCH': 0,
    'MUENCHOW': 0,
    'MUENICH': 0,
    'MUENKEL': 0,
    'MUENKS': 0,
    'MUENNICH': 0,
    'MUENNINK': 0,
    'MUENSTER': 0,
    'MUENSTERMAN': 0,
    'MUENTES': 0,
    'MUENZ': 0,
    'MUENZENBERGER': 0,
    'MUENZER': 0,
    'MUERY': 0,
    'MUES': 0,
    'MUESING': 0,
    'MUESKE': 0,
    'MUESSIG': 0,
    'MUETH': 0,
    'MUETING': 0,
    'MUETZEL': 0,
    'MUEX': 0,
    'MUFARREH': 0,
    'MUFF': 0,
    'MUFFETT': 0,
    'MUFFLER': 0,
    'MUFFLEY': 0,
    'MUFFLY': 0,
    'MUFFOLETTO': 0,
    'MUFICH': 0,
    'MUFSON': 0,
    'MUFTI': 0,
    'MUGA': 0,
    'MUGAN': 0,
    'MUGAVERO': 0,
    'MUGFORD': 0,
    'MUGG': 0,
    'MUGGE': 0,
    'MUGGEO': 0,
    'MUGGLI': 0,
    'MUGHAL': 0,
    'MUGICA': 0,
    'MUGLER': 0,
    'MUGLESTON': 0,
    'MUGLIA': 0,
    'MUGNAINI': 0,
    'MUGNO': 0,
    'MUGNOLO': 0,
    'MUGRAGE': 0,
    'MUGRIDGE': 0,
    'MUGUERZA': 0,
    'MUH': 0,
    'MUHA': 0,
    'MUHAMAD': 0,
    'MUHAMED': 0,
    'MUHAMMAD': 0,
    'MUHAMMED': 0,
    'MUHAR': 0,
    'MUHIC': 0,
    'MUHICH': 0,
    'MUHL': 0,
    'MUHLBACH': 0,
    'MUHLBAIER': 0,
    'MUHLBAUER': 0,
    'MUHLE': 0,
    'MUHLEISEN': 0,
    'MUHLEMAN': 0,
    'MUHLENBECK': 0,
    'MUHLENBRUCH': 0,
    'MUHLENKAMP': 0,
    'MUHLER': 0,
    'MUHLESTEIN': 0,
    'MUHLHAUSER': 0,
    'MUHLY': 0,
    'MUHM': 0,
    'MUHN': 0,
    'MUHONEN': 0,
    'MUHR': 0,
    'MUHS': 0,
    'MUHSIN': 0,
    'MUI': 0.6153846153846153,
    'MUIA': 0,
    'MUICH': 0,
    'MUILENBURG': 0,
    'MUINO': 0,
    'MUIR': 0,
    'MUIRHEAD': 0,
    'MUIRHEID': 0,
    'MUISE': 0,
    'MUJAGIC': 0,
    'MUJAHID': 0,
    'MUJANOVIC': 0,
    'MUJIC': 0,
    'MUJICA': 0,
    'MUJKANOVIC': 0,
    'MUJKIC': 0,
    'MUJTABA': 0,
    'MUKA': 0,
    'MUKAI': 0,
    'MUKASA': 0,
    'MUKERJEE': 0,
    'MUKERJI': 0,
    'MUKES': 0,
    'MUKHERJEE': 0,
    'MUKHERJI': 0,
    'MUKHIN': 0,
    'MUKHOPADHYAY': 0,
    'MUKHTAR': 0,
    'MULA': 0,
    'MULAC': 0,
    'MULALIC': 0,
    'MULALLY': 0,
    'MULANAX': 0,
    'MULARSKI': 0,
    'MULARZ': 0,
    'MULATO': 0,
    'MULAY': 0,
    'MULBAH': 0,
    'MULBERRY': 0,
    'MULCAHEY': 0,
    'MULCAHY': 0,
    'MULCARE': 0,
    'MULCH': 0,
    'MULCOCK': 0,
    'MULCRONE': 0,
    'MULDER': 0,
    'MULDERIG': 0,
    'MULDERINK': 0,
    'MULDERRIG': 0,
    'MULDOON': 0,
    'MULDOWNEY': 0,
    'MULDREW': 0,
    'MULDROW': 0,
    'MULE': 0,
    'MULEA': 0,
    'MULERO': 0,
    'MULES': 0,
    'MULET': 0,
    'MULEY': 0,
    'MULFINGER': 0,
    'MULFORD': 0,
    'MULGADO': 0,
    'MULGREW': 0,
    'MULHAIR': 0,
    'MULHALL': 0,
    'MULHARE': 0,
    'MULHEARN': 0,
    'MULHERIN': 0,
    'MULHERN': 0,
    'MULHERON': 0,
    'MULHOLAND': 0,
    'MULHOLLAN': 0,
    'MULHOLLAND': 0,
    'MULHOLLEN': 0,
    'MULIA': 0,
    'MULICA': 0,
    'MULICH': 0,
    'MULICK': 0,
    'MULIERI': 0,
    'MULIK': 0,
    'MULINA': 0,
    'MULINIX': 0,
    'MULKA': 0,
    'MULKEEN': 0,
    'MULKERIN': 0,
    'MULKERN': 0,
    'MULKERRIN': 0,
    'MULKEY': 0,
    'MULKIN': 0,
    'MULKINS': 0,
    'MULL': 0,
    'MULLA': 0,
    'MULLADY': 0,
    'MULLAHEY': 0,
    'MULLAHY': 0,
    'MULLALEY': 0,
    'MULLALLY': 0,
    'MULLALY': 0,
    'MULLAN': 0,
    'MULLANE': 0,
    'MULLANEY': 0,
    'MULLANIX': 0,
    'MULLANY': 0,
    'MULLARD': 0,
    'MULLARKEY': 0,
    'MULLARKY': 0,
    'MULLAY': 0,
    'MULLE': 0,
    'MULLEE': 0,
    'MULLEN': 0,
    'MULLENAUX': 0,
    'MULLENAX': 0,
    'MULLENBACH': 0,
    'MULLENBERG': 0,
    'MULLENDORE': 0,
    'MULLENEAUX': 0,
    'MULLENHOUR': 0,
    'MULLENIX': 0,
    'MULLENNEX': 0,
    'MULLENNIX': 0,
    'MULLENS': 0,
    'MULLER': 0,
    'MULLERY': 0,
    'MULLET': 0,
    'MULLETT': 0,
    'MULLEY': 0,
    'MULLHOLAND': 0,
    'MULLICA': 0,
    'MULLICAN': 0,
    'MULLICK': 0,
    'MULLIGAN': 0,
    'MULLIKEN': 0,
    'MULLIKIN': 0,
    'MULLIN': 0,
    'MULLINAX': 0,
    'MULLINEAUX': 0,
    'MULLINER': 0,
    'MULLINEX': 0,
    'MULLING': 0,
    'MULLINGS': 0,
    'MULLINIKS': 0,
    'MULLINIX': 0,
    'MULLINNIX': 0,
    'MULLINO': 0,
    'MULLINS': 0,
    'MULLIS': 0,
    'MULLISON': 0,
    'MULLNER': 0,
    'MULLOCK': 0,
    'MULLOKANDOV': 0,
    'MULLOOLY': 0,
    'MULLOWNEY': 0,
    'MULLOY': 0,
    'MULLVAIN': 0,
    'MULNIX': 0,
    'MULOCK': 0,
    'MULQUEEN': 0,
    'MULRAIN': 0,
    'MULRANEY': 0,
    'MULREADY': 0,
    'MULRENAN': 0,
    'MULRENIN': 0,
    'MULREY': 0,
    'MULRINE': 0,
    'MULROE': 0,
    'MULRONEY': 0,
    'MULROONEY': 0,
    'MULROY': 0,
    'MULRY': 0,
    'MULRYAN': 0,
    'MULSON': 0,
    'MULTANI': 0,
    'MULTARI': 0,
    'MULTER': 0,
    'MULTERER': 0,
    'MULTHAUF': 0,
    'MULTON': 0,
    'MULUGETA': 0,
    'MULVANEY': 0,
    'MULVANIA': 0,
    'MULVANY': 0,
    'MULVEHILL': 0,
    'MULVENA': 0,
    'MULVENNA': 0,
    'MULVERHILL': 0,
    'MULVEY': 0,
    'MULVIHILL': 0,
    'MULVILLE': 0,
    'MULVIN': 0,
    'MULWEE': 0,
    'MULZAC': 0,
    'MULZER': 0,
    'MUMA': 0,
    'MUMAU': 0,
    'MUMAUGH': 0,
    'MUMAW': 0,
    'MUMBAUER': 0,
    'MUMBOWER': 0,
    'MUMBY': 0,
    'MUMEY': 0,
    'MUMFORD': 0,
    'MUMIN': 0,
    'MUMINOVIC': 0,
    'MUMLEY': 0,
    'MUMM': 0,
    'MUMMA': 0,
    'MUMMAU': 0,
    'MUMMAW': 0,
    'MUMME': 0,
    'MUMMERT': 0,
    'MUMMERY': 0,
    'MUMMEY': 0,
    'MUMPER': 0,
    'MUMPHERY': 0,
    'MUMPHORD': 0,
    'MUMPHREY': 0,
    'MUMPOWER': 0,
    'MUMTAZ': 0,
    'MUMY': 0,
    'MUN': 0,
    'MUNA': 0,
    'MUNACO': 0,
    'MUNAFO': 0,
    'MUNAR': 0,
    'MUNAWAR': 0,
    'MUNCASTER': 0,
    'MUNCE': 0,
    'MUNCEY': 0,
    'MUNCH': 0,
    'MUNCHEL': 0,
    'MUNCHER': 0,
    'MUNCIE': 0,
    'MUNCK': 0,
    'MUNCRIEF': 0,
    'MUNCY': 0,
    'MUND': 0,
    'MUNDA': 0,
    'MUNDAHL': 0,
    'MUNDAY': 0,
    'MUNDELL': 0,
    'MUNDEN': 0,
    'MUNDER': 0,
    'MUNDERLOH': 0,
    'MUNDEY': 0,
    'MUNDHENK': 0,
    'MUNDHENKE': 0,
    'MUNDI': 0,
    'MUNDIE': 0,
    'MUNDINE': 0,
    'MUNDING': 0,
    'MUNDINGER': 0,
    'MUNDIS': 0,
    'MUNDLE': 0,
    'MUNDO': 0,
    'MUNDON': 0,
    'MUNDORF': 0,
    'MUNDORFF': 0,
    'MUNDRICK': 0,
    'MUNDS': 0,
    'MUNDSCHENK': 0,
    'MUNDSTOCK': 0,
    'MUNDT': 0,
    'MUNDWILER': 0,
    'MUNDWILLER': 0,
    'MUNDY': 0,
    'MUNDZ': 0,
    'MUNERA': 0,
    'MUNERLYN': 0,
    'MUNET': 0,
    'MUNETON': 0,
    'MUNEVAR': 0,
    'MUNFORD': 0,
    'MUNG': 0,
    'MUNGAI': 0,
    'MUNGAL': 0,
    'MUNGALL': 0,
    'MUNGARAY': 0,
    'MUNGARRO': 0,
    'MUNGCAL': 0,
    'MUNGER': 0,
    'MUNGIA': 0,
    'MUNGIN': 0,
    'MUNGLE': 0,
    'MUNGO': 0,
    'MUNGOVAN': 0,
    'MUNGRO': 0,
    'MUNGUIA': 0,
    'MUNHALL': 0,
    'MUNHOLLAND': 0,
    'MUNI': 0,
    'MUNIAK': 0,
    'MUNICH': 0,
    'MUNIE': 0,
    'MUNIER': 0,
    'MUNION': 0,
    'MUNIR': 0,
    'MUNIS': 0,
    'MUNITZ': 0,
    'MUNIVE': 0,
    'MUNIZ': 0,
    'MUNIZZA': 0,
    'MUNJAL': 0,
    'MUNK': 0,
    'MUNKEL': 0,
    'MUNKELWITZ': 0,
    'MUNKERS': 0,
    'MUNKRES': 0,
    'MUNKS': 0,
    'MUNKVOLD': 0,
    'MUNLEY': 0,
    'MUNLIN': 0,
    'MUNN': 0,
    'MUNNA': 0,
    'MUNNEKE': 0,
    'MUNNELL': 0,
    'MUNNELLY': 0,
    'MUNNERLYN': 0,
    'MUNNINGS': 0,
    'MUNNO': 0,
    'MUNNS': 0,
    'MUNO': 0,
    'MUNOS': 0,
    'MUNOZ': 0,
    'MUNRO': 0,
    'MUNROE': 0,
    'MUNS': 0,
    'MUNSAYAC': 0,
    'MUNSCH': 0,
    'MUNSEE': 0,
    'MUNSELL': 0,
    'MUNSELLE': 0,
    'MUNSEN': 0,
    'MUNSEY': 0,
    'MUNSHI': 0,
    'MUNSHOWER': 0,
    'MUNSIE': 0,
    'MUNSINGER': 0,
    'MUNSON': 0,
    'MUNSTER': 0,
    'MUNSTERMAN': 0,
    'MUNSTERTEIGER': 0,
    'MUNT': 0,
    'MUNTEAN': 0,
    'MUNTEANU': 0,
    'MUNTER': 0,
    'MUNTNER': 0,
    'MUNTON': 0,
    'MUNTS': 0,
    'MUNTZ': 0,
    'MUNUZ': 0,
    'MUNYAN': 0,
    'MUNYE': 0,
    'MUNYER': 0,
    'MUNYON': 0,
    'MUNZ': 0,
    'MUNZER': 0,
    'MUNZERT': 0,
    'MUNZING': 0,
    'MUNZO': 0,
    'MUOI': 1,
    'MUOIO': 0,
    'MUOLO': 0,
    'MUONIO': 0,
    'MUR': 0,
    'MURA': 0,
    'MURABITO': 0,
    'MURACA': 0,
    'MURACH': 0,
    'MURACO': 0,
    'MURAD': 0,
    'MURADIAN': 0,
    'MURADYAN': 0,
    'MURAI': 0,
    'MURAIRA': 0,
    'MURAKAMI': 0,
    'MURAKAWA': 0,
    'MURAKI': 0,
    'MURAL': 0,
    'MURALI': 0,
    'MURALIDHARAN': 0,
    'MURALLES': 0,
    'MURAMATSU': 0,
    'MURAMOTO': 0,
    'MURAN': 0,
    'MURANAKA': 0,
    'MURANO': 0,
    'MURANTE': 0,
    'MURAO': 0,
    'MURAOKA': 0,
    'MURAR': 0,
    'MURAS': 0,
    'MURASE': 0,
    'MURASHIGE': 0,
    'MURASKI': 0,
    'MURAT': 0,
    'MURATA': 0,
    'MURATALLA': 0,
    'MURATI': 0,
    'MURATORE': 0,
    'MURATORI': 0,
    'MURATOV': 0,
    'MURATOVIC': 0,
    'MURAWSKI': 0,
    'MURAY': 0,
    'MURAYAMA': 0,
    'MURBACH': 0,
    'MURCEK': 0,
    'MURCH': 0,
    'MURCHIE': 0,
    'MURCHINSON': 0,
    'MURCHISON': 0,
    'MURCHLAND': 0,
    'MURCIA': 0,
    'MURCKO': 0,
    'MURDAUGH': 0,
    'MURDAY': 0,
    'MURDEN': 0,
    'MURDERS': 0,
    'MURDICK': 0,
    'MURDIE': 0,
    'MURDOCH': 0,
    'MURDOCK': 0,
    'MURDOUGH': 0,
    'MURDY': 0,
    'MURDZA': 0,
    'MURE': 0,
    'MURELL': 0,
    'MURELLO': 0,
    'MUREN': 0,
    'MURER': 0,
    'MURESAN': 0,
    'MURFEE': 0,
    'MURFF': 0,
    'MURFIELD': 0,
    'MURFIN': 0,
    'MURFITT': 0,
    'MURGA': 0,
    'MURGAS': 0,
    'MURGATROYD': 0,
    'MURGIA': 0,
    'MURGO': 0,
    'MURGOLO': 0,
    'MURGUIA': 0,
    'MURI': 0,
    'MURIE': 0,
    'MURIEL': 0.9875259875259875,
    'MURILLO': 0,
    'MURIN': 0,
    'MURINO': 0,
    'MURISON': 0,
    'MURK': 0,
    'MURKEN': 0,
    'MURKERSON': 0,
    'MURKOWSKI': 0,
    'MURKS': 0,
    'MURLEY': 0,
    'MURLIN': 0,
    'MURMAN': 0,
    'MURN': 0,
    'MURNAHAN': 0,
    'MURNAN': 0,
    'MURNANE': 0,
    'MURNEN': 0,
    'MURNER': 0,
    'MURNEY': 0,
    'MURNIGHAN': 0,
    'MURNIN': 0,
    'MURNION': 0,
    'MURO': 0,
    'MUROFF': 0,
    'MUROLO': 0,
    'MUROS': 0,
    'MUROSKI': 0,
    'MURPH': 0,
    'MURPHEY': 0,
    'MURPHREE': 0,
    'MURPHREY': 0,
    'MURPHY': 0,
    'MURR': 0,
    'MURRA': 0,
    'MURRAH': 0,
    'MURRAIN': 0,
    'MURRAY': 0.18486566428395365,
    'MURREL': 0,
    'MURRELL': 0,
    'MURREN': 0,
    'MURRER': 0,
    'MURREY': 0,
    'MURRI': 0,
    'MURRIA': 0,
    'MURRIE': 0,
    'MURRIEL': 0,
    'MURRIETA': 0,
    'MURRIETTA': 0,
    'MURRILL': 0,
    'MURRILLO': 0,
    'MURRIN': 0,
    'MURRISH': 0,
    'MURRISON': 0,
    'MURRO': 0,
    'MURROW': 0,
    'MURRY': 0,
    'MURSCH': 0,
    'MURSCHEL': 0,
    'MURSHED': 0,
    'MURSKI': 0,
    'MURSULI': 0,
    'MURT': 0,
    'MURTA': 0,
    'MURTAGH': 0,
    'MURTAUGH': 0,
    'MURTAZA': 0,
    'MURTHA': 0,
    'MURTHY': 0,
    'MURTI': 0,
    'MURTISHAW': 0,
    'MURTLAND': 0,
    'MURTO': 0,
    'MURTON': 0,
    'MURTY': 0,
    'MURUA': 0,
    'MURUATO': 0,
    'MURUGESAN': 0,
    'MURVIN': 0,
    'MURVINE': 0,
    'MURWIN': 0,
    'MURY': 0,
    'MURZIN': 0,
    'MURZYN': 0,
    'MURZYNSKI': 0,
    'MUS': 0,
    'MUSA': 0,
    'MUSACCHIA': 0,
    'MUSACCHIO': 0,
    'MUSAL': 0,
    'MUSALL': 0,
    'MUSALLAM': 0,
    'MUSANTE': 0,
    'MUSARRA': 0,
    'MUSBACH': 0,
    'MUSCA': 0,
    'MUSCARA': 0,
    'MUSCARELLA': 0,
    'MUSCARELLO': 0,
    'MUSCARI': 0,
    'MUSCARO': 0,
    'MUSCAT': 0,
    'MUSCATELL': 0,
    'MUSCATELLO': 0,
    'MUSCATO': 0,
    'MUSCELLA': 0,
    'MUSCENTE': 0,
    'MUSCH': 0,
    'MUSCHA': 0,
    'MUSCHAMP': 0,
    'MUSCHETT': 0,
    'MUSCHETTE': 0,
    'MUSCHLITZ': 0,
    'MUSCHONG': 0,
    'MUSCI': 0,
    'MUSCIO': 0,
    'MUSCO': 0,
    'MUSCOLINO': 0,
    'MUSCOTT': 0,
    'MUSE': 0,
    'MUSEL': 0,
    'MUSELLA': 0,
    'MUSER': 0,
    'MUSETTI': 0,
    'MUSFELDT': 0,
    'MUSGRAVE': 0,
    'MUSGRAVES': 0,
    'MUSGROVE': 0,
    'MUSHARBASH': 0,
    'MUSHATT': 0,
    'MUSHENO': 0,
    'MUSHEYEV': 0,
    'MUSHINSKI': 0,
    'MUSHINSKY': 0,
    'MUSHRUSH': 0,
    'MUSHTAQ': 0,
    'MUSI': 0,
    'MUSIAL': 0,
    'MUSIC': 0,
    'MUSICANT': 0,
    'MUSICH': 0,
    'MUSICK': 0,
    'MUSICO': 0,
    'MUSIELAK': 0,
    'MUSIL': 0,
    'MUSILEK': 0,
    'MUSILLI': 0,
    'MUSILLO': 0,
    'MUSINSKI': 0,
    'MUSK': 0,
    'MUSKA': 0,
    'MUSKAT': 0,
    'MUSKE': 0,
    'MUSKELLY': 0,
    'MUSKET': 0,
    'MUSKETT': 0,
    'MUSKIN': 0,
    'MUSKO': 0,
    'MUSKOPF': 0,
    'MUSKRAT': 0,
    'MUSKUS': 0,
    'MUSLEH': 0,
    'MUSLER': 0,
    'MUSLIM': 0,
    'MUSLIN': 0,
    'MUSNGI': 0,
    'MUSNI': 0,
    'MUSOLF': 0,
    'MUSOLFF': 0,
    'MUSOLINO': 0,
    'MUSQUEZ': 0,
    'MUSQUIZ': 0,
    'MUSS': 0,
    'MUSSA': 0,
    'MUSSACK': 0,
    'MUSSARI': 0,
    'MUSSATTI': 0,
    'MUSSATTO': 0,
    'MUSSAW': 0,
    'MUSSE': 0,
    'MUSSEHL': 0,
    'MUSSELL': 0,
    'MUSSELMAN': 0,
    'MUSSELWHITE': 0,
    'MUSSEN': 0,
    'MUSSENDEN': 0,
    'MUSSER': 0,
    'MUSSETT': 0,
    'MUSSETTER': 0,
    'MUSSEY': 0,
    'MUSSI': 0,
    'MUSSIO': 0,
    'MUSSLER': 0,
    'MUSSLEWHITE': 0,
    'MUSSMAN': 0,
    'MUSSMANN': 0,
    'MUSSO': 0,
    'MUSSON': 0,
    'MUST': 0,
    'MUSTA': 0,
    'MUSTAC': 0,
    'MUSTACCHIO': 0,
    'MUSTACHE': 0,
    'MUSTACHIO': 0,
    'MUSTAFA': 0,
    'MUSTAFAA': 0,
    'MUSTAFIC': 0,
    'MUSTAIN': 0,
    'MUSTAINE': 0,
    'MUSTAPHA': 0,
    'MUSTARD': 0,
    'MUSTARI': 0,
    'MUSTEDANAGIC': 0,
    'MUSTELIER': 0,
    'MUSTER': 0,
    'MUSTIAN': 0,
    'MUSTICO': 0,
    'MUSTILLO': 0,
    'MUSTIN': 0,
    'MUSTION': 0,
    'MUSTO': 0,
    'MUSTOE': 0,
    'MUSTON': 0,
    'MUSTONE': 0,
    'MUSTONEN': 0,
    'MUSTY': 0,
    'MUSULIN': 0,
    'MUSUMECI': 0,
    'MUSZYNSKI': 0,
    'MUT': 0,
    'MUTA': 0,
    'MUTASCIO': 0,
    'MUTCH': 0,
    'MUTCHIE': 0,
    'MUTCHLER': 0,
    'MUTER': 0,
    'MUTERSPAUGH': 0,
    'MUTERSPAW': 0,
    'MUTERT': 0,
    'MUTH': 0,
    'MUTHANA': 0,
    'MUTHARD': 0,
    'MUTHART': 0,
    'MUTHER': 0,
    'MUTHERSBAUGH': 0,
    'MUTHIG': 0,
    'MUTHLER': 0,
    'MUTHUSAMY': 0,
    'MUTI': 0,
    'MUTIA': 0,
    'MUTKA': 0,
    'MUTLU': 0,
    'MUTNANSKY': 0,
    'MUTNICK': 0,
    'MUTO': 0,
    'MUTONE': 0,
    'MUTSCHELKNAUS': 0,
    'MUTSCHLER': 0,
    'MUTT': 0,
    'MUTTART': 0,
    'MUTTER': 0,
    'MUTTERS': 0,
    'MUTTI': 0,
    'MUTTILLO': 0,
    'MUTTON': 0,
    'MUTTY': 0,
    'MUTUC': 0,
    'MUTZ': 0,
    'MUTZABAUGH': 0,
    'MUUS': 0,
    'MUWWAKKIL': 0,
    'MUXLOW': 0,
    'MUY': 0,
    'MUYRES': 0,
    'MUYSKENS': 0,
    'MUZA': 0,
    'MUZAFFAR': 0,
    'MUZI': 0,
    'MUZIC': 0,
    'MUZIK': 0,
    'MUZIO': 0,
    'MUZNY': 0,
    'MUZQUIZ': 0,
    'MUZYK': 0,
    'MUZYKA': 0,
    'MUZZALL': 0,
    'MUZZARELLI': 0,
    'MUZZEY': 0,
    'MUZZI': 0,
    'MUZZILLO': 0,
    'MUZZIN': 0,
    'MUZZIO': 0,
    'MUZZY': 0,
    'MWANGI': 0,
    'MWAURA': 0,
    'MY': 0.967741935483871,
    'MYALL': 0,
    'MYATT': 0,
    'MYCEK': 0,
    'MYCROFT': 0,
    'MYDLAND': 0,
    'MYE': 0,
    'MYER': 0,
    'MYERHOLTZ': 0,
    'MYERLY': 0,
    'MYERS': 0,
    'MYERSCOUGH': 0,
    'MYERSON': 0,
    'MYESHA': 1,
    'MYETTE': 0,
    'MYGATT': 0,
    'MYGRANT': 0,
    'MYHAN': 0,
    'MYHAND': 0,
    'MYHILL': 0,
    'MYHR': 0,
    'MYHRA': 0,
    'MYHRE': 0,
    'MYHREN': 0,
    'MYINT': 0,
    'MYJAK': 0,
    'MYKEL': 0,
    'MYKINS': 0,
    'MYKLEBUST': 0,
    'MYKYTIUK': 0,
    'MYKYTYN': 0,
    'MYLAN': 0,
    'MYLAND': 0,
    'MYLANDER': 0,
    'MYLAR': 0,
    'MYLER': 0,
    'MYLES': 0.6044905008635578,
    'MYLET': 0,
    'MYLETT': 0,
    'MYLIN': 0,
    'MYLIUS': 0,
    'MYLOD': 0,
    'MYLONAS': 0,
    'MYLOTT': 0,
    'MYNAHAN': 0,
    'MYNAR': 0,
    'MYNARD': 0,
    'MYNATT': 0,
    'MYNEAR': 0,
    'MYNES': 0,
    'MYNHIER': 0,
    'MYONG': 1,
    'MYOTT': 0,
    'MYOTTE': 0,
    'MYRA': 0.9982530571499875,
    'MYRACLE': 0,
    'MYRAN': 0,
    'MYRAND': 0,
    'MYRDA': 0,
    'MYRE': 0,
    'MYREE': 0,
    'MYREN': 0,
    'MYRES': 0,
    'MYRIAM': 1,
    'MYRICE': 0,
    'MYRICK': 0,
    'MYRICKS': 0,
    'MYRIE': 0,
    'MYRL': 1,
    'MYRLE': 1,
    'MYRNA': 1,
    'MYROLD': 0,
    'MYRON': 0.9884678747940693,
    'MYRTA': 1,
    'MYRTHIL': 0,
    'MYRTICE': 1,
    'MYRTIE': 1,
    'MYRTIL': 0,
    'MYRTIS': 1,
    'MYRTLE': 0.9982083439979523,
    'MYRUM': 0,
    'MYRUP': 0,
    'MYRVIK': 0,
    'MYRVOLD': 0,
    'MYSAK': 0,
    'MYSHRALL': 0,
    'MYSINGER': 0,
    'MYSKA': 0,
    'MYSLINSKI': 0,
    'MYSLIWIEC': 0,
    'MYSORE': 0,
    'MYSZAK': 0,
    'MYSZEWSKI': 0,
    'MYSZKA': 0,
    'MYSZKOWSKI': 0,
    'MYTON': 0,
    'MYTYCH': 0,
    'MYUNG': 0.9049773755656109,
    'MYVETT': 0,
    'NA': 1,
    'NAAB': 0,
    'NAAKTGEBOREN': 0,
    'NAAMAN': 0,
    'NAAR': 0,
    'NAAS': 0,
    'NAASZ': 0,
    'NAATZ': 0,
    'NAB': 0,
    'NABA': 0,
    'NABARRETE': 0,
    'NABARRO': 0,
    'NABAVI': 0,
    'NABB': 0,
    'NABBEFELD': 0,
    'NABEL': 0,
    'NABER': 0,
    'NABERHAUS': 0,
    'NABERS': 0,
    'NABHAN': 0,
    'NABHOLZ': 0,
    'NABI': 0,
    'NABINGER': 0,
    'NABITY': 0,
    'NABLE': 0,
    'NABLO': 0,
    'NABONG': 0,
    'NABOR': 0,
    'NABORS': 0,
    'NABOURS': 0,
    'NABOZNY': 0,
    'NABULSI': 0,
    'NACAR': 0,
    'NACARATO': 0,
    'NACARIO': 0,
    'NACCA': 0,
    'NACCARATO': 0,
    'NACCARI': 0,
    'NACCI': 0,
    'NACE': 0,
    'NACEY': 0,
    'NACHAZEL': 0,
    'NACHBAR': 0,
    'NACHMAN': 0,
    'NACHREINER': 0,
    'NACHT': 0,
    'NACHTIGAL': 0,
    'NACHTIGALL': 0,
    'NACHTMAN': 0,
    'NACHTRAB': 0,
    'NACHTRIEB': 0,
    'NACHTSHEIM': 0,
    'NACHTWEY': 0,
    'NACIANCENO': 0,
    'NACINO': 0,
    'NACINOVICH': 0,
    'NACION': 0,
    'NACIONALES': 0,
    'NACK': 0,
    'NACKE': 0,
    'NACKERS': 0,
    'NACKLEY': 0,
    'NACLERIO': 0,
    'NACOL': 0,
    'NACUA': 0,
    'NACY': 0,
    'NADA': 0.9740259740259739,
    'NADAL': 0,
    'NADALIN': 0,
    'NADAR': 0,
    'NADARAJAH': 0,
    'NADDAF': 0,
    'NADDEO': 0,
    'NADDY': 0,
    'NADE': 0,
    'NADEAU': 0,
    'NADEEM': 0,
    'NADEL': 0,
    'NADELL': 0,
    'NADELLA': 0,
    'NADELMAN': 0,
    'NADEN': 0,
    'NADENE': 1,
    'NADER': 0,
    'NADERI': 0,
    'NADERMANN': 0,
    'NADIA': 1,
    'NADIG': 0,
    'NADIN': 0,
    'NADINE': 1,
    'NADING': 0,
    'NADIR': 0,
    'NADKARNI': 0,
    'NADLER': 0,
    'NADOLNY': 0,
    'NADOLSKI': 0,
    'NADOLSKY': 0,
    'NADON': 0,
    'NADRATOWSKI': 0,
    'NADREAU': 0,
    'NADROWSKI': 0,
    'NADY': 0,
    'NADZAM': 0,
    'NADZAN': 0,
    'NAEA': 0,
    'NAEEM': 0,
    'NAEF': 0,
    'NAEGEL': 0,
    'NAEGELE': 0,
    'NAEGELI': 0,
    'NAEGELIN': 0,
    'NAEGER': 0,
    'NAEGLE': 0,
    'NAEOLE': 0,
    'NAERT': 0,
    'NAES': 0,
    'NAESS': 0,
    'NAESSENS': 0,
    'NAEVE': 0,
    'NAEYAERT': 0,
    'NAFE': 0,
    'NAFF': 0,
    'NAFFZIGER': 0,
    'NAFTALI': 0,
    'NAFTEL': 0,
    'NAFTZGER': 0,
    'NAFUS': 0,
    'NAFZGER': 0,
    'NAFZIGER': 0,
    'NAG': 0,
    'NAGA': 0,
    'NAGAI': 0,
    'NAGAL': 0,
    'NAGAMATSU': 0,
    'NAGAMINE': 0,
    'NAGAN': 0,
    'NAGANO': 0,
    'NAGANUMA': 0,
    'NAGAO': 0,
    'NAGAOKA': 0,
    'NAGAR': 0,
    'NAGARAJ': 0,
    'NAGARAJA': 0,
    'NAGARAJAN': 0,
    'NAGASAKO': 0,
    'NAGASAWA': 0,
    'NAGASE': 0,
    'NAGASHIMA': 0,
    'NAGATA': 0,
    'NAGATANI': 0,
    'NAGAYAMA': 0,
    'NAGBE': 0,
    'NAGEL': 0,
    'NAGELBERG': 0,
    'NAGELE': 0,
    'NAGELHOUT': 0,
    'NAGELKIRK': 0,
    'NAGELL': 0,
    'NAGENGAST': 0,
    'NAGEOTTE': 0,
    'NAGER': 0,
    'NAGERA': 0,
    'NAGEY': 0,
    'NAGG': 0,
    'NAGGAR': 0,
    'NAGI': 0,
    'NAGIB': 0,
    'NAGIN': 0,
    'NAGL': 0,
    'NAGLE': 0,
    'NAGLER': 0,
    'NAGLEY': 0,
    'NAGLICH': 0,
    'NAGLIERI': 0,
    'NAGO': 0,
    'NAGODE': 0,
    'NAGORNY': 0,
    'NAGORSKI': 0,
    'NAGOWSKI': 0,
    'NAGPAL': 0,
    'NAGRA': 0,
    'NAGTALON': 0,
    'NAGUIB': 0,
    'NAGUIT': 0,
    'NAGURNEY': 0,
    'NAGY': 0,
    'NAH': 0,
    'NAHA': 0,
    'NAHABEDIAN': 0,
    'NAHAL': 0,
    'NAHAR': 0,
    'NAHAS': 0,
    'NAHASS': 0,
    'NAHAY': 0,
    'NAHHAS': 0,
    'NAHIGIAN': 0,
    'NAHILL': 0,
    'NAHINU': 0,
    'NAHLEN': 0,
    'NAHLIK': 0,
    'NAHM': 0,
    'NAHMIAS': 0,
    'NAHODIL': 0,
    'NAHON': 0,
    'NAHORNIAK': 0,
    'NAHRA': 0,
    'NAHRGANG': 0,
    'NAHRSTEDT': 0,
    'NAHRWOLD': 0,
    'NAHUM': 0,
    'NAI': 0,
    'NAICKER': 0,
    'NAIDA': 0.9345794392523364,
    'NAIDITCH': 0,
    'NAIDOO': 0,
    'NAIDU': 0,
    'NAIFEH': 0,
    'NAIG': 0,
    'NAIHE': 0,
    'NAII': 0,
    'NAIK': 0,
    'NAIL': 0,
    'NAILE': 0,
    'NAILER': 0,
    'NAILL': 0,
    'NAILLING': 0,
    'NAILLON': 0,
    'NAILON': 0,
    'NAILOR': 0,
    'NAILS': 0,
    'NAIM': 0,
    'NAIMAN': 0,
    'NAIMI': 0,
    'NAIMO': 0,
    'NAIMOLI': 0,
    'NAIN': 0,
    'NAING': 0,
    'NAIPO': 0,
    'NAIR': 0,
    'NAIRN': 0,
    'NAIRNE': 0,
    'NAISBITT': 0,
    'NAISER': 0,
    'NAISH': 0,
    'NAISMITH': 0,
    'NAITO': 0,
    'NAJA': 0,
    'NAJAFI': 0,
    'NAJAM': 0,
    'NAJAR': 0,
    'NAJARIAN': 0,
    'NAJARRO': 0,
    'NAJDA': 0,
    'NAJDEK': 0,
    'NAJDOWSKI': 0,
    'NAJEM': 0,
    'NAJERA': 0,
    'NAJI': 0,
    'NAJIB': 0,
    'NAJIM': 0,
    'NAJJAR': 0,
    'NAJM': 0,
    'NAJMAN': 0,
    'NAJMI': 0,
    'NAJOR': 0,
    'NAK': 0,
    'NAKA': 0,
    'NAKABAYASHI': 0,
    'NAKACHI': 0,
    'NAKADA': 0,
    'NAKAGAKI': 0,
    'NAKAGAWA': 0,
    'NAKAHARA': 0,
    'NAKAI': 0,
    'NAKAJI': 0,
    'NAKAJIMA': 0,
    'NAKAMA': 0,
    'NAKAMATSU': 0,
    'NAKAMICHI': 0,
    'NAKAMOTO': 0,
    'NAKAMURA': 0,
    'NAKANISHI': 0,
    'NAKANO': 0,
    'NAKAO': 0,
    'NAKAOKA': 0,
    'NAKASATO': 0,
    'NAKASH': 0,
    'NAKASHIAN': 0,
    'NAKASHIMA': 0,
    'NAKASONE': 0,
    'NAKATA': 0,
    'NAKATANI': 0,
    'NAKATSU': 0,
    'NAKATSUKA': 0,
    'NAKAWATASE': 0,
    'NAKAYA': 0,
    'NAKAYAMA': 0,
    'NAKAZATO': 0,
    'NAKAZAWA': 0,
    'NAKESHA': 1,
    'NAKHLA': 0,
    'NAKHLEH': 0,
    'NAKI': 0,
    'NAKIA': 1,
    'NAKIS': 0,
    'NAKISHA': 1,
    'NAKITA': 1,
    'NAKKEN': 0,
    'NAKO': 0,
    'NAKOA': 0,
    'NAKONECHNY': 0,
    'NAKONECZNY': 0,
    'NAKOS': 0,
    'NALBACH': 0,
    'NALBANDIAN': 0,
    'NALBANDYAN': 0,
    'NALBONE': 0,
    'NALDER': 0,
    'NALE': 0,
    'NALEPA': 0,
    'NALEPKA': 0,
    'NALER': 0,
    'NALES': 0,
    'NALESNIK': 0,
    'NALETTE': 0,
    'NALEVANKO': 0,
    'NALEWAY': 0,
    'NALEZNY': 0,
    'NALK': 0,
    'NALL': 0,
    'NALLE': 0,
    'NALLEN': 0,
    'NALLEY': 0,
    'NALLI': 0,
    'NALLS': 0,
    'NALLY': 0,
    'NALTY': 0,
    'NALVEN': 0,
    'NAM': 0.37878787878787884,
    'NAMA': 0,
    'NAMAHOE': 0,
    'NAMAN': 0,
    'NAMANNY': 0,
    'NAMAZI': 0,
    'NAMBA': 0,
    'NAMBIAR': 0,
    'NAMBO': 0,
    'NAMDAR': 0,
    'NAME': 0,
    'NAMER': 0,
    'NAMES': 0,
    'NAMETH': 0,
    'NAMEY': 0,
    'NAMI': 0,
    'NAMIAS': 0,
    'NAMIE': 0,
    'NAMKEN': 0,
    'NAMKOONG': 0,
    'NAMKUNG': 0,
    'NAMM': 0,
    'NAMMOUR': 0,
    'NAMOKI': 0,
    'NAMOWICZ': 0,
    'NAMVAR': 0,
    'NAN': 0.9791921664626683,
    'NANA': 0.9523809523809523,
    'NANAN': 0,
    'NANAVATI': 0,
    'NANAYAKKARA': 0,
    'NANCARROW': 0,
    'NANCE': 0,
    'NANCEE': 1,
    'NANCEY': 1,
    'NANCI': 1,
    'NANCIE': 1,
    'NANCY': 0.9998206599713056,
    'NAND': 0,
    'NANDA': 0,
    'NANDI': 0,
    'NANDIN': 0,
    'NANDLAL': 0,
    'NANDWANI': 0,
    'NANDY': 0,
    'NANES': 0,
    'NANETTE': 1,
    'NANEY': 0,
    'NANEZ': 0,
    'NANFITO': 0,
    'NANG': 0,
    'NANGIA': 0,
    'NANGLE': 0,
    'NANI': 0,
    'NANIA': 0,
    'NANK': 0,
    'NANKE': 0,
    'NANKERVIS': 0,
    'NANKIN': 0,
    'NANKIVELL': 0,
    'NANN': 0,
    'NANNA': 0,
    'NANNEMAN': 0,
    'NANNEN': 0,
    'NANNENGA': 0,
    'NANNERY': 0,
    'NANNETTE': 1,
    'NANNEY': 0,
    'NANNI': 0,
    'NANNIE': 0.9923664122137404,
    'NANNINGA': 0,
    'NANNINI': 0,
    'NANNY': 0,
    'NANO': 0,
    'NANOS': 0,
    'NANSEL': 0,
    'NANSEN': 0,
    'NANSON': 0,
    'NANTAIS': 0,
    'NANTHAVONG': 0,
    'NANTON': 0,
    'NANTZ': 0,
    'NANZ': 0,
    'NAO': 0,
    'NAOMA': 1,
    'NAOMI': 1,
    'NAONE': 0,
    'NAOR': 0,
    'NAOUM': 0,
    'NAP': 0,
    'NAPARSTEK': 0,
    'NAPE': 0,
    'NAPER': 0,
    'NAPERT': 0,
    'NAPIER': 0,
    'NAPIERALA': 0,
    'NAPIERALSKI': 0,
    'NAPIERKOWSKI': 0,
    'NAPIERSKI': 0,
    'NAPIORKOWSKI': 0,
    'NAPIWOCKI': 0,
    'NAPLE': 0,
    'NAPLES': 0,
    'NAPODANO': 0,
    'NAPOLEON': 0.8823529411764706,
    'NAPOLEONE': 0,
    'NAPOLEONI': 0,
    'NAPOLES': 0,
    'NAPOLETANO': 0,
    'NAPOLI': 0,
    'NAPOLIELLO': 0,
    'NAPOLILLO': 0,
    'NAPOLITAN': 0,
    'NAPOLITANO': 0,
    'NAPORA': 0,
    'NAPP': 0,
    'NAPPA': 0,
    'NAPPE': 0,
    'NAPPER': 0,
    'NAPPI': 0,
    'NAPPIER': 0,
    'NAPPO': 0,
    'NAPUE': 0,
    'NAPUTI': 0,
    'NAQUI': 0,
    'NAQUIN': 0,
    'NAQVI': 0,
    'NARA': 0,
    'NARAG': 0,
    'NARAGHI': 0,
    'NARAGON': 0,
    'NARAIN': 0,
    'NARAINE': 0,
    'NARAMORE': 0,
    'NARAN': 0,
    'NARANG': 0,
    'NARANGO': 0,
    'NARANJO': 0,
    'NARASIMHAN': 0,
    'NARAYAN': 0,
    'NARAYANA': 0,
    'NARAYANAN': 0,
    'NARAYANASWAMY': 0,
    'NARBUT': 0,
    'NARBY': 0,
    'NARCHO': 0,
    'NARCISA': 1,
    'NARCISCO': 0,
    'NARCISE': 0,
    'NARCISI': 0,
    'NARCISO': 0,
    'NARCISSE': 0,
    'NARD': 0,
    'NARDACCI': 0,
    'NARDECCHIA': 0,
    'NARDELLA': 0,
    'NARDELLI': 0,
    'NARDELLO': 0,
    'NARDI': 0,
    'NARDIELLO': 0,
    'NARDIN': 0,
    'NARDINE': 0,
    'NARDINI': 0,
    'NARDO': 0,
    'NARDOLILLO': 0,
    'NARDONE': 0,
    'NARDONI': 0,
    'NARDOZZA': 0,
    'NARDOZZI': 0,
    'NARDUCCI': 0,
    'NARDULLI': 0,
    'NARDUZZI': 0,
    'NARDY': 0,
    'NARE': 0,
    'NARED': 0,
    'NAREDO': 0,
    'NAREHOOD': 0,
    'NAREL': 0,
    'NARENS': 0,
    'NARES': 0,
    'NAREWSKI': 0,
    'NAREY': 0,
    'NAREZ': 0,
    'NARGI': 0,
    'NARIMATSU': 0,
    'NARIN': 0,
    'NARINE': 0,
    'NARIO': 0,
    'NARITA': 0,
    'NARKIEWICZ': 0,
    'NARLOCH': 0,
    'NARLOCK': 0,
    'NARMORE': 0,
    'NARO': 0,
    'NAROG': 0,
    'NARON': 0,
    'NAROWSKI': 0,
    'NARR': 0,
    'NARRA': 0,
    'NARRAGON': 0,
    'NARRAMORE': 0,
    'NARRELL': 0,
    'NARRIS': 0,
    'NARRO': 0,
    'NARRON': 0,
    'NARROW': 0,
    'NARTATEZ': 0,
    'NARTEY': 0,
    'NARTINEZ': 0,
    'NARTKER': 0,
    'NARTOWICZ': 0,
    'NARULA': 0,
    'NARUM': 0,
    'NARUP': 0,
    'NARUS': 0,
    'NARVA': 0,
    'NARVAES': 0,
    'NARVAEZ': 0,
    'NARVAIS': 0,
    'NARVAIZ': 0,
    'NARVESON': 0,
    'NARWOLD': 0,
    'NARY': 0,
    'NAS': 0,
    'NASA': 0,
    'NASALROAD': 0,
    'NASAR': 0,
    'NASARIO': 0,
    'NASATKA': 0,
    'NASBY': 0,
    'NASCA': 0,
    'NASCIMENTO': 0,
    'NASCO': 0,
    'NASE': 0,
    'NASEEF': 0,
    'NASEEM': 0,
    'NASEER': 0,
    'NASELLI': 0,
    'NASELLO': 0,
    'NASEMAN': 0,
    'NASER': 0,
    'NASH': 0,
    'NASHAWATY': 0,
    'NASHED': 0,
    'NASI': 0,
    'NASIATKA': 0,
    'NASIF': 0,
    'NASIM': 0,
    'NASIR': 0,
    'NASIRI': 0,
    'NASLUND': 0,
    'NASMAN': 0,
    'NASO': 0,
    'NASON': 0,
    'NASRALLA': 0,
    'NASRALLAH': 0,
    'NASRI': 0,
    'NASS': 0,
    'NASSAR': 0,
    'NASSAU': 0,
    'NASSE': 0,
    'NASSEF': 0,
    'NASSEN': 0,
    'NASSER': 0,
    'NASSERI': 0,
    'NASSET': 0,
    'NASSI': 0,
    'NASSIF': 0,
    'NASSIFF': 0,
    'NASSIR': 0,
    'NASSIRI': 0,
    'NASSO': 0,
    'NASSOUR': 0,
    'NAST': 0,
    'NASTA': 0,
    'NASTACIO': 0,
    'NASTALLY': 0,
    'NASTARI': 0,
    'NASTASE': 0,
    'NASTASI': 0,
    'NASTASIA': 0,
    'NASTI': 0,
    'NASTO': 0,
    'NASTRI': 0,
    'NASTRO': 0,
    'NASUTA': 0,
    'NASUTI': 0,
    'NASWORTHY': 0,
    'NAT': 0,
    'NATA': 0,
    'NATACHA': 1,
    'NATAL': 0,
    'NATALE': 0,
    'NATALI': 0,
    'NATALIA': 1,
    'NATALIE': 0.9974554707379136,
    'NATALINI': 0,
    'NATALINO': 0,
    'NATALIZIO': 0,
    'NATALYA': 1,
    'NATAN': 0,
    'NATARAJAN': 0,
    'NATARELLI': 0,
    'NATAREN': 0,
    'NATARENO': 0,
    'NATASHA': 1,
    'NATASHIA': 1,
    'NATCHER': 0,
    'NATE': 0,
    'NATELLI': 0,
    'NATELSON': 0,
    'NATER': 0,
    'NATERA': 0,
    'NATERAS': 0,
    'NATES': 0,
    'NATH': 0,
    'NATHALIE': 1,
    'NATHAN': 0.9854578383849145,
    'NATHANAEL': 1,
    'NATHANI': 0,
    'NATHANIAL': 1,
    'NATHANIEL': 0.992525425805661,
    'NATHANS': 0,
    'NATHANSON': 0,
    'NATHE': 0,
    'NATHER': 0,
    'NATHO': 0,
    'NATHOO': 0,
    'NATI': 0,
    'NATIELLO': 0,
    'NATION': 0,
    'NATIONS': 0,
    'NATISHA': 1,
    'NATIVI': 0,
    'NATIVIDAD': 0.7692307692307693,
    'NATKIN': 0,
    'NATO': 0,
    'NATOLA': 0,
    'NATOLE': 0,
    'NATOLI': 0,
    'NATONABAH': 0,
    'NATOSHA': 1,
    'NATOUR': 0,
    'NATSCHKE': 0,
    'NATSIS': 0,
    'NATSON': 0,
    'NATT': 0,
    'NATTA': 0,
    'NATTER': 0,
    'NATTINGER': 0,
    'NATTRASS': 0,
    'NATTRESS': 0,
    'NATUSCH': 0,
    'NATVIG': 0,
    'NATWICK': 0,
    'NATZEL': 0,
    'NATZKE': 0,
    'NAU': 0,
    'NAUCK': 0,
    'NAUD': 0,
    'NAUDE': 0,
    'NAUDEN': 0,
    'NAUER': 0,
    'NAUERT': 0,
    'NAUERTZ': 0,
    'NAUGHER': 0,
    'NAUGHT': 0,
    'NAUGHTIN': 0,
    'NAUGHTON': 0,
    'NAUGLE': 0,
    'NAUGLER': 0,
    'NAUGLES': 0,
    'NAUJOKAS': 0,
    'NAUJOKS': 0,
    'NAUL': 0,
    'NAULA': 0,
    'NAULLS': 0,
    'NAULS': 0,
    'NAULT': 0,
    'NAULTY': 0,
    'NAUM': 0,
    'NAUMAN': 0,
    'NAUMANN': 0,
    'NAUMENKO': 0,
    'NAUMES': 0,
    'NAUMOFF': 0,
    'NAUMOV': 0,
    'NAUMOVSKI': 0,
    'NAUMOWICZ': 0,
    'NAUROTH': 0,
    'NAUS': 0,
    'NAUSE': 0,
    'NAUSS': 0,
    'NAUTA': 0,
    'NAUTH': 0,
    'NAUYEN': 0,
    'NAVA': 0,
    'NAVAIRA': 0,
    'NAVAJO': 0,
    'NAVAL': 0,
    'NAVALES': 0,
    'NAVALTA': 0,
    'NAVAR': 0,
    'NAVARA': 0,
    'NAVARES': 0,
    'NAVARETE': 0,
    'NAVARETTE': 0,
    'NAVAREZ': 0,
    'NAVARIJO': 0,
    'NAVAROLI': 0,
    'NAVARRA': 0,
    'NAVARRE': 0,
    'NAVARRETE': 0,
    'NAVARRETTE': 0,
    'NAVARRO': 0,
    'NAVAS': 0,
    'NAVASCA': 0,
    'NAVE': 0,
    'NAVEDO': 0,
    'NAVEED': 0,
    'NAVEIRA': 0,
    'NAVEJA': 0,
    'NAVEJAR': 0,
    'NAVEJAS': 0,
    'NAVEL': 0,
    'NAVES': 0,
    'NAVETTA': 0,
    'NAVEY': 0,
    'NAVI': 0,
    'NAVIA': 0,
    'NAVICKAS': 0,
    'NAVID': 0,
    'NAVIDAD': 0,
    'NAVIGATO': 0,
    'NAVILLE': 0,
    'NAVIN': 0,
    'NAVIS': 0,
    'NAVITSKY': 0,
    'NAVO': 0,
    'NAVON': 0,
    'NAVONE': 0,
    'NAVOR': 0,
    'NAVRATIL': 0,
    'NAVRKAL': 0,
    'NAVY': 0,
    'NAWA': 0,
    'NAWAB': 0,
    'NAWABI': 0,
    'NAWARA': 0,
    'NAWAZ': 0,
    'NAWMAN': 0,
    'NAWN': 0,
    'NAWROCKI': 0,
    'NAWROT': 0,
    'NAY': 0,
    'NAYA': 0,
    'NAYAK': 0,
    'NAYAR': 0,
    'NAYDEN': 0,
    'NAYEE': 0,
    'NAYEEM': 0,
    'NAYER': 0,
    'NAYES': 0,
    'NAYLON': 0,
    'NAYLOR': 0,
    'NAYMAN': 0,
    'NAYMIK': 0,
    'NAYSMITH': 0,
    'NAYYAR': 0,
    'NAZ': 0,
    'NAZAIRE': 0,
    'NAZAR': 0,
    'NAZARENKO': 0,
    'NAZARENO': 0,
    'NAZARENUS': 0,
    'NAZARETH': 0,
    'NAZARI': 0,
    'NAZARIAN': 0,
    'NAZARIO': 0,
    'NAZAROFF': 0,
    'NAZAROV': 0,
    'NAZARUK': 0,
    'NAZARY': 0,
    'NAZARYAN': 0,
    'NAZE': 0,
    'NAZEER': 0,
    'NAZELROD': 0,
    'NAZEMI': 0,
    'NAZER': 0,
    'NAZIMEK': 0,
    'NAZIR': 0,
    'NAZIRI': 0,
    'NAZON': 0,
    'NAZWORTH': 0,
    'NAZZAL': 0,
    'NAZZARO': 0,
    'NDIAYE': 0,
    'NDOYE': 0,
    'NDUKWE': 0,
    'NDUNGU': 0,
    'NE': 0,
    'NEA': 0,
    'NEACE': 0,
    'NEAD': 0,
    'NEADEAU': 0,
    'NEADER': 0,
    'NEAFSEY': 0,
    'NEAFUS': 0,
    'NEAGLE': 0,
    'NEAGLEY': 0,
    'NEAGU': 0,
    'NEAHRING': 0,
    'NEAK': 0,
    'NEAL': 0.5434782608695652,
    'NEALE': 0,
    'NEALEIGH': 0,
    'NEALEN': 0,
    'NEALER': 0,
    'NEALEY': 0,
    'NEALIS': 0,
    'NEALL': 0,
    'NEALLEY': 0,
    'NEALLY': 0,
    'NEALON': 0,
    'NEALS': 0,
    'NEALY': 0,
    'NEAMAN': 0,
    'NEAMON': 0,
    'NEANDER': 0,
    'NEANG': 0,
    'NEANOVER': 0,
    'NEAPOLITAN': 0,
    'NEAR': 0,
    'NEARGARDER': 0,
    'NEARHOOD': 0,
    'NEARHOOF': 0,
    'NEARING': 0,
    'NEARMAN': 0,
    'NEARN': 0,
    'NEARPASS': 0,
    'NEARY': 0,
    'NEAS': 0,
    'NEASBITT': 0,
    'NEASE': 0,
    'NEASHAM': 0,
    'NEASON': 0,
    'NEAT': 0,
    'NEATE': 0,
    'NEATH': 0,
    'NEATHERLIN': 0,
    'NEATHERY': 0,
    'NEATON': 0,
    'NEATROUR': 0,
    'NEAU': 0,
    'NEAULT': 0,
    'NEAVE': 0,
    'NEAVEILL': 0,
    'NEAVES': 0,
    'NEAVILLE': 0,
    'NEAVIN': 0,
    'NEBBIA': 0,
    'NEBE': 0,
    'NEBEKER': 0,
    'NEBEL': 0,
    'NEBELSICK': 0,
    'NEBELUNG': 0,
    'NEBEN': 0,
    'NEBENZAHL': 0,
    'NEBER': 0,
    'NEBERGALL': 0,
    'NEBGEN': 0,
    'NEBLETT': 0,
    'NEBLINA': 0,
    'NEBLOCK': 0,
    'NEBUS': 0,
    'NECAISE': 0,
    'NECAS': 0,
    'NECCI': 0,
    'NECE': 0,
    'NECESSARY': 0,
    'NECHANICKY': 0,
    'NECHVATAL': 0,
    'NECK': 0,
    'NECKAR': 0,
    'NECKEL': 0,
    'NECKER': 0,
    'NECKERS': 0,
    'NECKLES': 0,
    'NECOCHEA': 0,
    'NECOECHEA': 0,
    'NECOLE': 1,
    'NED': 0.9630818619582665,
    'NEDA': 1,
    'NEDAB': 0,
    'NEDBAL': 0,
    'NEDBALEK': 0,
    'NEDD': 0,
    'NEDDERMAN': 0,
    'NEDDERMEYER': 0,
    'NEDDO': 0,
    'NEDEAU': 0,
    'NEDELCU': 0,
    'NEDELJKOVIC': 0,
    'NEDELL': 0,
    'NEDELMAN': 0,
    'NEDER': 0,
    'NEDERHOFF': 0,
    'NEDEROSTEK': 0,
    'NEDERVELD': 0,
    'NEDIC': 0,
    'NEDIMYER': 0,
    'NEDINA': 0,
    'NEDLAND': 0,
    'NEDLEY': 0,
    'NEDRA': 1,
    'NEDRICK': 0,
    'NEDROW': 0,
    'NEDRY': 0,
    'NEDVED': 0,
    'NEDWICK': 0,
    'NEDZA': 0,
    'NEE': 0,
    'NEEB': 0,
    'NEECE': 0,
    'NEED': 0,
    'NEEDAM': 0,
    'NEEDELL': 0,
    'NEEDELMAN': 0,
    'NEEDELS': 0,
    'NEEDHAM': 0,
    'NEEDLE': 0,
    'NEEDLEMAN': 0,
    'NEEDLER': 0,
    'NEEDLES': 0,
    'NEEDS': 0,
    'NEEDY': 0,
    'NEEF': 0,
    'NEEFE': 0,
    'NEEL': 0,
    'NEELAND': 0,
    'NEELANDS': 0,
    'NEELD': 0,
    'NEELEY': 0,
    'NEELIS': 0,
    'NEELLEY': 0,
    'NEELON': 0,
    'NEELS': 0,
    'NEELY': 0.1037344398340249,
    'NEEMAN': 0,
    'NEEMANN': 0,
    'NEENAN': 0,
    'NEEPER': 0,
    'NEER': 0,
    'NEERGAARD': 0,
    'NEERING': 0,
    'NEES': 0,
    'NEESE': 0,
    'NEESEN': 0,
    'NEESER': 0,
    'NEESMITH': 0,
    'NEESON': 0,
    'NEET': 0,
    'NEETZ': 0,
    'NEEVEL': 0,
    'NEEVES': 0,
    'NEF': 0,
    'NEFF': 0,
    'NEFFENDORF': 0,
    'NEFT': 0,
    'NEFZGER': 0,
    'NEGA': 0,
    'NEGAARD': 0,
    'NEGASH': 0,
    'NEGELE': 0,
    'NEGEN': 0,
    'NEGER': 0,
    'NEGI': 0,
    'NEGIN': 0,
    'NEGLEY': 0,
    'NEGLIA': 0,
    'NEGRE': 0,
    'NEGRELLI': 0,
    'NEGREROS': 0,
    'NEGRETE': 0,
    'NEGRETTE': 0,
    'NEGREY': 0,
    'NEGRI': 0,
    'NEGRILLO': 0,
    'NEGRIN': 0,
    'NEGRINI': 0,
    'NEGRO': 0,
    'NEGRON': 0,
    'NEGRONI': 0,
    'NEGROTTO': 0,
    'NEGRU': 0,
    'NEGUS': 0,
    'NEGUSSIE': 0,
    'NEHER': 0,
    'NEHEZ': 0,
    'NEHF': 0,
    'NEHILA': 0,
    'NEHL': 0,
    'NEHLIG': 0,
    'NEHLS': 0,
    'NEHLSEN': 0,
    'NEHMAN': 0,
    'NEHME': 0,
    'NEHMER': 0,
    'NEHR': 0,
    'NEHRA': 0,
    'NEHRBASS': 0,
    'NEHRENZ': 0,
    'NEHRIG': 0,
    'NEHRING': 0,
    'NEHRKORN': 0,
    'NEHRT': 0,
    'NEHUS': 0,
    'NEI': 0,
    'NEIBARGER': 0,
    'NEIBAUER': 0,
    'NEIBAUR': 0,
    'NEIBEL': 0,
    'NEIBER': 0,
    'NEIBERGER': 0,
    'NEIBERT': 0,
    'NEICE': 0,
    'NEID': 0,
    'NEIDA': 1,
    'NEIDECKER': 0,
    'NEIDEFFER': 0,
    'NEIDEL': 0,
    'NEIDENBACH': 0,
    'NEIDER': 0,
    'NEIDERER': 0,
    'NEIDERHISER': 0,
    'NEIDERMAN': 0,
    'NEIDERMEYER': 0,
    'NEIDERMYER': 0,
    'NEIDERT': 0,
    'NEIDHARDT': 0,
    'NEIDHART': 0,
    'NEIDICH': 0,
    'NEIDIG': 0,
    'NEIDIGH': 0,
    'NEIDINGER': 0,
    'NEIDLINGER': 0,
    'NEIE': 0,
    'NEIER': 0,
    'NEIFELD': 0,
    'NEIFER': 0,
    'NEIFERT': 0,
    'NEIFFER': 0,
    'NEIGEL': 0,
    'NEIGER': 0,
    'NEIGH': 0,
    'NEIGHBARGER': 0,
    'NEIGHBOR': 0,
    'NEIGHBORS': 0,
    'NEIGHBOUR': 0,
    'NEIGHBOURS': 0,
    'NEIGHOFF': 0,
    'NEIGUM': 0,
    'NEIHARDT': 0,
    'NEIHART': 0,
    'NEIHEISEL': 0,
    'NEIHOFF': 0,
    'NEIKIRK': 0,
    'NEIL': 0.9508716323296355,
    'NEILAN': 0,
    'NEILD': 0,
    'NEILEY': 0,
    'NEILING': 0,
    'NEILL': 0,
    'NEILLY': 0,
    'NEILON': 0,
    'NEILS': 0,
    'NEILSEN': 0,
    'NEILSON': 0,
    'NEILY': 0,
    'NEIMAN': 0,
    'NEIMARK': 0,
    'NEIMEYER': 0,
    'NEIN': 0,
    'NEINAST': 0,
    'NEINER': 0,
    'NEIPERT': 0,
    'NEIR': 0,
    'NEIRA': 0,
    'NEIS': 0,
    'NEISE': 0,
    'NEISEN': 0,
    'NEISER': 0,
    'NEISES': 0,
    'NEISH': 0,
    'NEISINGER': 0,
    'NEISIUS': 0,
    'NEISLER': 0,
    'NEISS': 0,
    'NEISSER': 0,
    'NEISWANDER': 0,
    'NEISWANGER': 0,
    'NEISWENDER': 0,
    'NEISWONGER': 0,
    'NEISZ': 0,
    'NEITA': 0,
    'NEITCH': 0,
    'NEITH': 0,
    'NEITZ': 0,
    'NEITZEL': 0,
    'NEITZELT': 0,
    'NEITZEY': 0,
    'NEITZKE': 0,
    'NEIVES': 0,
    'NEJAD': 0,
    'NEJAT': 0,
    'NEJEDLO': 0,
    'NEJEDLY': 0,
    'NEJIA': 0,
    'NEJMAN': 0,
    'NEKOLA': 0,
    'NEKTALOV': 0,
    'NEKUDA': 0,
    'NEL': 0,
    'NELA': 0,
    'NELAMS': 0,
    'NELAN': 0,
    'NELDA': 1,
    'NELDER': 0,
    'NELDNER': 0,
    'NELDON': 0,
    'NELEN': 0,
    'NELIA': 1,
    'NELIDA': 1,
    'NELIGAN': 0,
    'NELIS': 0,
    'NELKE': 0,
    'NELKIN': 0,
    'NELL': 0.9567198177676538,
    'NELLA': 1,
    'NELLANS': 0,
    'NELLE': 0.967741935483871,
    'NELLEN': 0,
    'NELLENBACH': 0,
    'NELLENBACK': 0,
    'NELLER': 0,
    'NELLERMOE': 0,
    'NELLES': 0,
    'NELLESEN': 0,
    'NELLESSEN': 0,
    'NELLETT': 0,
    'NELLI': 0,
    'NELLIE': 1,
    'NELLIGAN': 0,
    'NELLIS': 0,
    'NELLIST': 0,
    'NELLOMS': 0,
    'NELLON': 0,
    'NELLOR': 0,
    'NELLS': 0,
    'NELLUM': 0,
    'NELLUMS': 0,
    'NELLY': 0.9876543209876544,
    'NELMARK': 0,
    'NELMES': 0,
    'NELMS': 0,
    'NELOMS': 0,
    'NELON': 0,
    'NELS': 0,
    'NELSEN': 0,
    'NELSON': 0.285300032739348,
    'NELTNER': 0,
    'NELTON': 0,
    'NELUMS': 0,
    'NEM': 0,
    'NEMAN': 0,
    'NEMANI': 0,
    'NEMANIC': 0,
    'NEMANICH': 0,
    'NEMATI': 0,
    'NEMBHARD': 0,
    'NEMCEK': 0,
    'NEMCHEK': 0,
    'NEMCHICK': 0,
    'NEMCHIK': 0,
    'NEMCIK': 0,
    'NEMEC': 0,
    'NEMECEK': 0,
    'NEMECHEK': 0,
    'NEMEH': 0,
    'NEMELKA': 0,
    'NEMER': 0,
    'NEMERGUT': 0,
    'NEMEROFF': 0,
    'NEMES': 0,
    'NEMET': 0,
    'NEMETH': 0,
    'NEMETHY': 0,
    'NEMETZ': 0,
    'NEMEYER': 0,
    'NEMIER': 0,
    'NEMIRE': 0,
    'NEMIROFF': 0,
    'NEMIROVSKY': 0,
    'NEMITH': 0,
    'NEMITZ': 0,
    'NEMMER': 0,
    'NEMMERS': 0,
    'NEMNICH': 0,
    'NEMO': 0,
    'NEMORIN': 0,
    'NEMOTO': 0,
    'NEN': 0,
    'NENA': 0.9876543209876544,
    'NENDZA': 0,
    'NENE': 0,
    'NENITA': 1,
    'NENNEMAN': 0,
    'NENNI': 0,
    'NENNIG': 0,
    'NENNINGER': 0,
    'NENNO': 0,
    'NENO': 0,
    'NENOW': 0,
    'NENSTIEL': 0,
    'NENTWIG': 0,
    'NEO': 0,
    'NEOFOTISTOS': 0,
    'NEOMA': 1,
    'NEOMI': 1,
    'NEOU': 0,
    'NEPA': 0,
    'NEPH': 0,
    'NEPHEW': 0,
    'NEPOMUCENO': 0,
    'NEPOTE': 0,
    'NEPPEL': 0,
    'NEPPER': 0,
    'NEPPL': 0,
    'NEPPLE': 0,
    'NEPSTAD': 0,
    'NEPTUNE': 0,
    'NER': 0,
    'NERA': 0,
    'NERAD': 0,
    'NERAT': 0,
    'NERBONNE': 0,
    'NERBY': 0,
    'NERCESSIAN': 0,
    'NERDAHL': 0,
    'NERDIN': 0,
    'NERE': 0,
    'NEREIDA': 1,
    'NEREM': 0,
    'NERENBERG': 0,
    'NERETTE': 0,
    'NEREY': 0,
    'NERGER': 0,
    'NERHEIM': 0,
    'NERI': 0,
    'NERIA': 0,
    'NERING': 0,
    'NERIO': 0,
    'NERIOS': 0,
    'NERIS': 0,
    'NERISON': 0,
    'NERISSA': 1,
    'NERKOWSKI': 0,
    'NERLAND': 0,
    'NERN': 0,
    'NERNEY': 0,
    'NERO': 0,
    'NERON': 0,
    'NERONA': 0,
    'NERONE': 0,
    'NERONI': 0,
    'NERREN': 0,
    'NERSESIAN': 0,
    'NERSESYAN': 0,
    'NERUD': 0,
    'NERVIG': 0,
    'NERVIS': 0,
    'NERVO': 0,
    'NERY': 0.78125,
    'NERYS': 0,
    'NESBETH': 0,
    'NESBETT': 0,
    'NESBIT': 0,
    'NESBITT': 0,
    'NESBY': 0,
    'NESCI': 0,
    'NESE': 0,
    'NESEMEIER': 0,
    'NESFIELD': 0,
    'NESGODA': 0,
    'NESHEIM': 0,
    'NESHEIWAT': 0,
    'NESHEM': 0,
    'NESI': 0,
    'NESIUS': 0,
    'NESKE': 0,
    'NESKY': 0,
    'NESLAND': 0,
    'NESLER': 0,
    'NESLONEY': 0,
    'NESLUND': 0,
    'NESMITH': 0,
    'NESOM': 0,
    'NESPECA': 0,
    'NESPER': 0,
    'NESPOLI': 0,
    'NESPOR': 0,
    'NESS': 0,
    'NESSA': 0,
    'NESSE': 0,
    'NESSEL': 0,
    'NESSELHAUF': 0,
    'NESSELROAD': 0,
    'NESSELRODE': 0,
    'NESSELRODT': 0,
    'NESSELROTTE': 0,
    'NESSEN': 0,
    'NESSER': 0,
    'NESSET': 0,
    'NESSETH': 0,
    'NESSIM': 0,
    'NESSINGER': 0,
    'NESSLAGE': 0,
    'NESSLER': 0,
    'NESSMAN': 0,
    'NESSMITH': 0,
    'NESSON': 0,
    'NEST': 0,
    'NESTA': 0,
    'NESTE': 0,
    'NESTEBY': 0,
    'NESTEGARD': 0,
    'NESTEL': 0,
    'NESTELL': 0,
    'NESTER': 0,
    'NESTERENKO': 0,
    'NESTERUK': 0,
    'NESTI': 0,
    'NESTICO': 0,
    'NESTINGEN': 0,
    'NESTLE': 0,
    'NESTLER': 0,
    'NESTLEROAD': 0,
    'NESTLERODE': 0,
    'NESTO': 0,
    'NESTON': 0,
    'NESTOR': 0.8226691042047533,
    'NESVIG': 0,
    'NESVOLD': 0,
    'NETA': 1,
    'NETCHER': 0,
    'NETEMEYER': 0,
    'NETH': 0,
    'NETHAWAY': 0,
    'NETHERCOTT': 0,
    'NETHERCUTT': 0,
    'NETHERLAND': 0,
    'NETHERLY': 0,
    'NETHERS': 0,
    'NETHERTON': 0,
    'NETHERY': 0,
    'NETHING': 0,
    'NETHKEN': 0,
    'NETLAND': 0,
    'NETO': 0,
    'NETOLICKY': 0,
    'NETRO': 0,
    'NETSCH': 0,
    'NETT': 0,
    'NETTA': 0,
    'NETTE': 0,
    'NETTEKOVEN': 0,
    'NETTELL': 0,
    'NETTER': 0,
    'NETTERS': 0,
    'NETTERVILLE': 0,
    'NETTESHEIM': 0,
    'NETTI': 0,
    'NETTIE': 1,
    'NETTING': 0,
    'NETTLE': 0,
    'NETTLES': 0,
    'NETTLESHIP': 0,
    'NETTLETON': 0,
    'NETTNIN': 0,
    'NETTO': 0,
    'NETTROUER': 0,
    'NETZ': 0,
    'NETZBAND': 0,
    'NETZEL': 0,
    'NETZER': 0,
    'NETZLER': 0,
    'NETZLEY': 0,
    'NEU': 0,
    'NEUBACHER': 0,
    'NEUBARTH': 0,
    'NEUBAUER': 0,
    'NEUBAUM': 0,
    'NEUBECK': 0,
    'NEUBECKER': 0,
    'NEUBER': 0,
    'NEUBERG': 0,
    'NEUBERGER': 0,
    'NEUBERT': 0,
    'NEUBIG': 0,
    'NEUBURG': 0,
    'NEUBURGER': 0,
    'NEUDECK': 0,
    'NEUDECKER': 0,
    'NEUDER': 0,
    'NEUDORF': 0,
    'NEUDORFER': 0,
    'NEUENDORF': 0,
    'NEUENDORFF': 0,
    'NEUENFELDT': 0,
    'NEUENS': 0,
    'NEUENSCHWANDER': 0,
    'NEUENSWANDER': 0,
    'NEUER': 0,
    'NEUERBURG': 0,
    'NEUFELD': 0,
    'NEUFELDT': 0,
    'NEUFER': 0,
    'NEUFFER': 0,
    'NEUFVILLE': 0,
    'NEUGEBAUER': 0,
    'NEUGENT': 0,
    'NEUGIN': 0,
    'NEUHALFEN': 0,
    'NEUHARD': 0,
    'NEUHARDT': 0,
    'NEUHART': 0,
    'NEUHARTH': 0,
    'NEUHAUS': 0,
    'NEUHAUSER': 0,
    'NEUHOFF': 0,
    'NEUJAHR': 0,
    'NEUKAM': 0,
    'NEUKIRCH': 0,
    'NEUKOM': 0,
    'NEUKOMM': 0,
    'NEULAND': 0,
    'NEULEIB': 0,
    'NEULS': 0,
    'NEUMAIER': 0,
    'NEUMAN': 0,
    'NEUMANN': 0,
    'NEUMARK': 0,
    'NEUMAYER': 0,
    'NEUMEIER': 0,
    'NEUMEISTER': 0,
    'NEUMER': 0,
    'NEUMEYER': 0,
    'NEUMILLER': 0,
    'NEUMUELLER': 0,
    'NEUMYER': 0,
    'NEUN': 0,
    'NEUNABER': 0,
    'NEUNER': 0,
    'NEUPAUER': 0,
    'NEUPERT': 0,
    'NEURATH': 0,
    'NEURAUTER': 0,
    'NEUREUTHER': 0,
    'NEUROHR': 0,
    'NEUROTH': 0,
    'NEUS': 0,
    'NEUSCH': 0,
    'NEUSCHAEFER': 0,
    'NEUSCHAFER': 0,
    'NEUSCHWANDER': 0,
    'NEUSCHWANGER': 0,
    'NEUSE': 0,
    'NEUSER': 0,
    'NEUSS': 0,
    'NEUSTADT': 0,
    'NEUSTADTER': 0,
    'NEUSTEIN': 0,
    'NEUSTEL': 0,
    'NEUSTROM': 0,
    'NEUTZ': 0,
    'NEUTZE': 0,
    'NEUTZLING': 0,
    'NEUVILLE': 0,
    'NEUVIRTH': 0,
    'NEUWIRTH': 0,
    'NEUYEN': 0,
    'NEUZIL': 0,
    'NEVA': 0.9908536585365854,
    'NEVADA': 0.9523809523809523,
    'NEVALA': 0,
    'NEVANS': 0,
    'NEVARES': 0,
    'NEVAREZ': 0,
    'NEVE': 0,
    'NEVEAU': 0,
    'NEVEAUX': 0,
    'NEVEL': 0,
    'NEVELL': 0,
    'NEVELLS': 0,
    'NEVELS': 0,
    'NEVEN': 0,
    'NEVENHOVEN': 0,
    'NEVENS': 0,
    'NEVENSCHWANDER': 0,
    'NEVER': 0,
    'NEVERMAN': 0,
    'NEVERS': 0,
    'NEVERSON': 0,
    'NEVES': 0,
    'NEVEU': 0,
    'NEVEUX': 0,
    'NEVIL': 0,
    'NEVILL': 0,
    'NEVILLE': 0.48959608323133413,
    'NEVILLES': 0,
    'NEVILLS': 0,
    'NEVILS': 0,
    'NEVIN': 0,
    'NEVINGER': 0,
    'NEVINS': 0,
    'NEVIS': 0,
    'NEVISON': 0,
    'NEVITT': 0,
    'NEVIUS': 0,
    'NEVLING': 0,
    'NEVOLA': 0,
    'NEW': 0,
    'NEWAGO': 0,
    'NEWALL': 0,
    'NEWARK': 0,
    'NEWBAKER': 0,
    'NEWBALL': 0,
    'NEWBANKS': 0,
    'NEWBAUER': 0,
    'NEWBEGIN': 0,
    'NEWBERG': 0,
    'NEWBERGER': 0,
    'NEWBERN': 0,
    'NEWBERRY': 0,
    'NEWBERT': 0,
    'NEWBERY': 0,
    'NEWBILL': 0,
    'NEWBLE': 0,
    'NEWBOLD': 0,
    'NEWBOLES': 0,
    'NEWBOLT': 0,
    'NEWBORG': 0,
    'NEWBORN': 0,
    'NEWBOULD': 0,
    'NEWBRAUGH': 0,
    'NEWBREY': 0,
    'NEWBROUGH': 0,
    'NEWBRY': 0,
    'NEWBURG': 0,
    'NEWBURGER': 0,
    'NEWBURGH': 0,
    'NEWBURN': 0,
    'NEWBURRY': 0,
    'NEWBURY': 0,
    'NEWBY': 0,
    'NEWCAMP': 0,
    'NEWCHURCH': 0,
    'NEWCITY': 0,
    'NEWCOM': 0,
    'NEWCOMB': 0,
    'NEWCOMBE': 0,
    'NEWCOME': 0,
    'NEWCOMER': 0,
    'NEWEII': 0,
    'NEWEL': 0,
    'NEWELL': 0,
    'NEWENHOUSE': 0,
    'NEWER': 0,
    'NEWETT': 0,
    'NEWEY': 0,
    'NEWFIELD': 0,
    'NEWGARD': 0,
    'NEWGENT': 0,
    'NEWGREN': 0,
    'NEWHALL': 0,
    'NEWHAM': 0,
    'NEWHARD': 0,
    'NEWHART': 0,
    'NEWHAUSER': 0,
    'NEWHOFF': 0,
    'NEWHOOK': 0,
    'NEWHOUSE': 0,
    'NEWHOUSER': 0,
    'NEWILL': 0,
    'NEWINGHAM': 0,
    'NEWITT': 0,
    'NEWKIRK': 0,
    'NEWLAN': 0,
    'NEWLAND': 0,
    'NEWLANDER': 0,
    'NEWLANDS': 0,
    'NEWLEN': 0,
    'NEWLIN': 0,
    'NEWLING': 0,
    'NEWLON': 0,
    'NEWLOVE': 0,
    'NEWLUN': 0,
    'NEWMAN': 0,
    'NEWMANN': 0,
    'NEWMANS': 0,
    'NEWMARK': 0,
    'NEWMASTER': 0,
    'NEWMEYER': 0,
    'NEWMILLER': 0,
    'NEWMON': 0,
    'NEWMYER': 0,
    'NEWNAM': 0,
    'NEWNHAM': 0,
    'NEWNUM': 0,
    'NEWPHER': 0,
    'NEWPORT': 0,
    'NEWQUIST': 0,
    'NEWREN': 0,
    'NEWS': 0,
    'NEWSAM': 0,
    'NEWSHAM': 0,
    'NEWSOM': 0,
    'NEWSOME': 0,
    'NEWSON': 0,
    'NEWSONE': 0,
    'NEWSTEAD': 0,
    'NEWSTED': 0,
    'NEWSTROM': 0,
    'NEWSUM': 0,
    'NEWSWANGER': 0,
    'NEWTH': 0,
    'NEWTON': 0.15718327569946558,
    'NEWTOWN': 0,
    'NEWTSON': 0,
    'NEWVILLE': 0,
    'NEWVINE': 0,
    'NEY': 0,
    'NEYENS': 0,
    'NEYER': 0,
    'NEYHARD': 0,
    'NEYHART': 0,
    'NEYLAN': 0,
    'NEYLAND': 0,
    'NEYLON': 0,
    'NEYMAN': 0,
    'NEYMEYER': 0,
    'NEYRA': 0,
    'NEYS': 0,
    'NEZ': 0,
    'NEZAJ': 0,
    'NEZAT': 0,
    'NEZBETH': 0,
    'NEZIRI': 0,
    'NEZTSOSIE': 0,
    'NG': 0,
    'NGA': 1,
    'NGAI': 0,
    'NGAN': 0.7874015748031497,
    'NGANGA': 0,
    'NGET': 0,
    'NGETH': 0,
    'NGHE': 0,
    'NGHIEM': 0,
    'NGIN': 0,
    'NGO': 0,
    'NGOC': 1,
    'NGOV': 0,
    'NGOY': 0,
    'NGU': 0,
    'NGUEN': 0,
    'NGUGI': 0,
    'NGUIEN': 0,
    'NGUON': 0,
    'NGUY': 0,
    'NGUYAN': 0,
    'NGUYEN': 0,
    'NGUYENLE': 0,
    'NGUYENT': 0,
    'NGUYENTHANH': 0,
    'NGUYENTHI': 0,
    'NGUYENTRAN': 0,
    'NGUYENVAN': 0,
    'NGUYET': 1,
    'NHAM': 0,
    'NHAN': 0,
    'NHEAN': 0,
    'NHEK': 0,
    'NHEM': 0,
    'NHEP': 0,
    'NHIEU': 0,
    'NHIM': 0,
    'NHO': 0,
    'NI': 0,
    'NIA': 1,
    'NIANG': 0,
    'NIAZ': 0,
    'NIAZI': 0,
    'NIBARGER': 0,
    'NIBBE': 0,
    'NIBBELINK': 0,
    'NIBBLETT': 0,
    'NIBBS': 0,
    'NIBERT': 0,
    'NIBLACK': 0,
    'NIBLE': 0,
    'NIBLER': 0,
    'NIBLETT': 0,
    'NIBLEY': 0,
    'NIBLICK': 0,
    'NIBLO': 0,
    'NIBLOCK': 0,
    'NICACIO': 0,
    'NICAISE': 0,
    'NICAJ': 0,
    'NICANOR': 0,
    'NICAR': 0,
    'NICARAGUA': 0,
    'NICAS': 0,
    'NICASIO': 0,
    'NICASSIO': 0,
    'NICASTRI': 0,
    'NICASTRO': 0,
    'NICCOLAI': 0,
    'NICCOLI': 0,
    'NICCOLLS': 0,
    'NICCUM': 0,
    'NICDAO': 0,
    'NICE': 0,
    'NICELEY': 0,
    'NICELY': 0,
    'NICESWANGER': 0,
    'NICEWANDER': 0,
    'NICEWARNER': 0,
    'NICEWICZ': 0,
    'NICEWONGER': 0,
    'NICGORSKI': 0,
    'NICHELLE': 1,
    'NICHELSON': 0,
    'NICHLOS': 0,
    'NICHOIS': 0,
    'NICHOL': 0.702576112412178,
    'NICHOLAI': 0,
    'NICHOLAS': 0.9653526169831853,
    'NICHOLE': 1,
    'NICHOLES': 0,
    'NICHOLIS': 0,
    'NICHOLL': 0,
    'NICHOLLE': 1,
    'NICHOLLS': 0,
    'NICHOLOFF': 0,
    'NICHOLOS': 0,
    'NICHOLS': 0,
    'NICHOLSEN': 0,
    'NICHOLSON': 0,
    'NICHTER': 0,
    'NICHTING': 0,
    'NICI': 0,
    'NICITA': 0,
    'NICK': 0.973731884057971,
    'NICKAS': 0,
    'NICKEL': 0,
    'NICKELBERRY': 0,
    'NICKELL': 0,
    'NICKELLS': 0,
    'NICKELS': 0,
    'NICKELSEN': 0,
    'NICKELSON': 0,
    'NICKENS': 0,
    'NICKERSON': 0,
    'NICKESON': 0,
    'NICKEY': 0,
    'NICKI': 1,
    'NICKIE': 1,
    'NICKISCH': 0,
    'NICKL': 0,
    'NICKLAS': 0,
    'NICKLAUS': 0,
    'NICKLAW': 0,
    'NICKLAY': 0,
    'NICKLE': 0,
    'NICKLEBERRY': 0,
    'NICKLER': 0,
    'NICKLES': 0,
    'NICKLESON': 0,
    'NICKLESS': 0,
    'NICKLEY': 0,
    'NICKLIN': 0,
    'NICKLOS': 0,
    'NICKLOW': 0,
    'NICKMAN': 0,
    'NICKOL': 0,
    'NICKOLA': 0,
    'NICKOLAI': 0,
    'NICKOLAS': 0.9813542688910696,
    'NICKOLAUS': 0,
    'NICKOLAUSON': 0,
    'NICKOLE': 1,
    'NICKOLES': 0,
    'NICKOLI': 0,
    'NICKOLICH': 0,
    'NICKOLITE': 0,
    'NICKOLOFF': 0,
    'NICKOLS': 0,
    'NICKOLSON': 0,
    'NICKOSON': 0,
    'NICKS': 0,
    'NICKSIC': 0,
    'NICKSON': 0,
    'NICKUM': 0,
    'NICKY': 1,
    'NICLEY': 0,
    'NICO': 0,
    'NICOARA': 0,
    'NICODEMO': 0,
    'NICODEMUS': 0,
    'NICOL': 0.5263157894736842,
    'NICOLA': 0.8547008547008547,
    'NICOLAE': 0,
    'NICOLAI': 0,
    'NICOLAIDES': 0,
    'NICOLAIDIS': 0,
    'NICOLAIS': 0,
    'NICOLAISEN': 0,
    'NICOLAOU': 0,
    'NICOLAS': 0.918133129303749,
    'NICOLASA': 1,
    'NICOLAU': 0,
    'NICOLAUS': 0,
    'NICOLAY': 0,
    'NICOLAYSEN': 0,
    'NICOLAZZI': 0,
    'NICOLAZZO': 0,
    'NICOLE': 0.9992532271256356,
    'NICOLEAU': 0,
    'NICOLELLA': 0,
    'NICOLES': 0,
    'NICOLESCU': 0,
    'NICOLET': 0,
    'NICOLETTA': 0,
    'NICOLETTE': 0.9584664536741214,
    'NICOLETTI': 0,
    'NICOLETTO': 0,
    'NICOLI': 0,
    'NICOLIA': 0,
    'NICOLICH': 0,
    'NICOLINI': 0,
    'NICOLINO': 0,
    'NICOLL': 0,
    'NICOLLE': 0.9708737864077669,
    'NICOLLS': 0,
    'NICOLO': 0,
    'NICOLOFF': 0,
    'NICOLOPOULOS': 0,
    'NICOLOSI': 0,
    'NICOLS': 0,
    'NICOLSON': 0,
    'NICOLUCCI': 0,
    'NICORA': 0,
    'NICOSIA': 0,
    'NICOSON': 0,
    'NICOT': 0,
    'NICOTERA': 0,
    'NICOTRA': 0,
    'NICOULIN': 0,
    'NICPON': 0,
    'NICULESCU': 0,
    'NIDA': 0.6711409395973155,
    'NIDAY': 0,
    'NIDER': 0,
    'NIDEVER': 0,
    'NIDEY': 0,
    'NIDIA': 1,
    'NIDIFFER': 0,
    'NIDO': 0,
    'NIE': 0,
    'NIEB': 0,
    'NIEBAUER': 0,
    'NIEBAUM': 0,
    'NIEBEL': 0,
    'NIEBER': 0,
    'NIEBERDING': 0,
    'NIEBERGALL': 0,
    'NIEBERLEIN': 0,
    'NIEBLA': 0,
    'NIEBLAS': 0,
    'NIEBLER': 0,
    'NIEBLES': 0,
    'NIEBLING': 0,
    'NIEBOER': 0,
    'NIEBRUEGGE': 0,
    'NIEBRUGGE': 0,
    'NIEBRZYDOWSKI': 0,
    'NIEBUHR': 0,
    'NIEBUR': 0,
    'NIEC': 0,
    'NIECE': 0,
    'NIECKARZ': 0,
    'NIED': 0,
    'NIEDBALA': 0,
    'NIEDBALSKI': 0,
    'NIEDENS': 0,
    'NIEDENTHAL': 0,
    'NIEDER': 0,
    'NIEDERBERGER': 0,
    'NIEDERBRACH': 0,
    'NIEDERER': 0,
    'NIEDERHAUS': 0,
    'NIEDERHAUSER': 0,
    'NIEDERHOFER': 0,
    'NIEDERKOHR': 0,
    'NIEDERKORN': 0,
    'NIEDERMAIER': 0,
    'NIEDERMAN': 0,
    'NIEDERMANN': 0,
    'NIEDERMAYER': 0,
    'NIEDERMEIER': 0,
    'NIEDERMEYER': 0,
    'NIEDERMIER': 0,
    'NIEDERRITER': 0,
    'NIEDERSTADT': 0,
    'NIEDERT': 0,
    'NIEDFELDT': 0,
    'NIEDRICH': 0,
    'NIEDRINGHAUS': 0,
    'NIEDZIALEK': 0,
    'NIEDZIELA': 0,
    'NIEDZIELSKI': 0,
    'NIEDZWIECKI': 0,
    'NIEDZWIEDZ': 0,
    'NIEFT': 0,
    'NIEH': 0,
    'NIEHAUS': 0,
    'NIEHENKE': 0,
    'NIEHOFF': 0,
    'NIEHUES': 0,
    'NIEHUS': 0,
    'NIEJADLIK': 0,
    'NIEKAMP': 0,
    'NIEL': 0,
    'NIELAND': 0,
    'NIELANDER': 0,
    'NIELD': 0,
    'NIELDS': 0,
    'NIELL': 0,
    'NIELSEN': 0,
    'NIELSON': 0,
    'NIEMAN': 0,
    'NIEMAND': 0,
    'NIEMANN': 0,
    'NIEMCZURA': 0,
    'NIEMCZYK': 0,
    'NIEMEIER': 0,
    'NIEMELA': 0,
    'NIEMER': 0,
    'NIEMERG': 0,
    'NIEMEYER': 0,
    'NIEMI': 0,
    'NIEMIEC': 0,
    'NIEMIER': 0,
    'NIEMIETZ': 0,
    'NIEMINEN': 0,
    'NIEMINSKI': 0,
    'NIEMIRA': 0,
    'NIEMOTH': 0,
    'NIEMUTH': 0,
    'NIENABER': 0,
    'NIENBERG': 0,
    'NIENDORF': 0,
    'NIENHAUS': 0,
    'NIENHOUSE': 0,
    'NIENHUESER': 0,
    'NIENHUIS': 0,
    'NIENKE': 0,
    'NIENOW': 0,
    'NIENSTEDT': 0,
    'NIEPORTE': 0,
    'NIER': 0,
    'NIERADKA': 0,
    'NIERE': 0,
    'NIERENBERG': 0,
    'NIERENGARTEN': 0,
    'NIERENHAUSEN': 0,
    'NIERGARTH': 0,
    'NIERI': 0,
    'NIERMAN': 0,
    'NIERMANN': 0,
    'NIERMEYER': 0,
    'NIERODA': 0,
    'NIES': 0,
    'NIESE': 0,
    'NIESEN': 0,
    'NIESER': 0,
    'NIESET': 0,
    'NIESHA': 1,
    'NIESMAN': 0,
    'NIESS': 0,
    'NIESSEN': 0,
    'NIESSNER': 0,
    'NIESZ': 0,
    'NIETERS': 0,
    'NIETERT': 0,
    'NIETFELD': 0,
    'NIETHAMMER': 0,
    'NIETLING': 0,
    'NIETO': 0,
    'NIETTE': 0,
    'NIETUPSKI': 0,
    'NIETZ': 0,
    'NIETZEL': 0,
    'NIEUWENHUIS': 0,
    'NIEUWSMA': 0,
    'NIEVA': 0,
    'NIEVE': 0,
    'NIEVERA': 0,
    'NIEVES': 0.16155088852988692,
    'NIEVEZ': 0,
    'NIEWALD': 0,
    'NIEWIADOMSKI': 0,
    'NIEWIAROWSKI': 0,
    'NIEWINSKI': 0,
    'NIEWOEHNER': 0,
    'NIEWOHNER': 0,
    'NIEWOLD': 0,
    'NIEZGODA': 0,
    'NIFFEN': 0,
    'NIFFENEGGER': 0,
    'NIFONG': 0,
    'NIFOROS': 0,
    'NIGAM': 0,
    'NIGBOR': 0,
    'NIGBUR': 0,
    'NIGEL': 1,
    'NIGG': 0,
    'NIGGEL': 0,
    'NIGGEMANN': 0,
    'NIGGEMEYER': 0,
    'NIGGLI': 0,
    'NIGH': 0,
    'NIGHBERT': 0,
    'NIGHBOR': 0,
    'NIGHSWANDER': 0,
    'NIGHSWONGER': 0,
    'NIGHT': 0,
    'NIGHTENGALE': 0,
    'NIGHTINGALE': 0,
    'NIGHTLINGER': 0,
    'NIGL': 0,
    'NIGLIO': 0,
    'NIGO': 0,
    'NIGON': 0,
    'NIGRA': 0,
    'NIGRELLI': 0,
    'NIGRO': 0,
    'NIHAN': 0,
    'NIHART': 0,
    'NIHEI': 0,
    'NIHILL': 0,
    'NIHIPALI': 0,
    'NIHISER': 0,
    'NII': 0,
    'NIICHEL': 0,
    'NIIMI': 0,
    'NIJJAR': 0,
    'NIJMEH': 0,
    'NIKA': 0,
    'NIKAC': 0,
    'NIKAIDO': 0,
    'NIKAS': 0,
    'NIKEL': 0,
    'NIKI': 1,
    'NIKIA': 1,
    'NIKIC': 0,
    'NIKIEL': 0,
    'NIKIFOROV': 0,
    'NIKIRK': 0,
    'NIKITA': 1,
    'NIKITAS': 0,
    'NIKITENKO': 0,
    'NIKITIN': 0,
    'NIKKEL': 0,
    'NIKKI': 1,
    'NIKKILA': 0,
    'NIKLAS': 0,
    'NIKLAUS': 0,
    'NIKLES': 0,
    'NIKNAM': 0,
    'NIKO': 0,
    'NIKOCEVIC': 0,
    'NIKODEM': 0,
    'NIKODYM': 0,
    'NIKOLA': 0,
    'NIKOLAI': 0,
    'NIKOLAIDIS': 0,
    'NIKOLAISEN': 0,
    'NIKOLAOU': 0,
    'NIKOLAS': 0,
    'NIKOLAUS': 0,
    'NIKOLAYEV': 0,
    'NIKOLE': 1,
    'NIKOLIC': 0,
    'NIKOLICH': 0,
    'NIKOLOPOULOS': 0,
    'NIKOLOV': 0,
    'NIKOLOVSKI': 0,
    'NIKSA': 0,
    'NIKSCH': 0,
    'NIKSICH': 0,
    'NIKULA': 0,
    'NIKZAD': 0,
    'NIL': 0,
    'NILA': 0.9501187648456058,
    'NILAN': 0,
    'NILAND': 0,
    'NILDA': 1,
    'NILE': 0,
    'NILES': 0,
    'NILGES': 0,
    'NILL': 0,
    'NILLER': 0,
    'NILLES': 0,
    'NILLIAMS': 0,
    'NILLO': 0,
    'NILO': 0,
    'NILON': 0,
    'NILSA': 1,
    'NILSEN': 0,
    'NILSON': 0,
    'NILSSEN': 0,
    'NILSSON': 0,
    'NIM': 0,
    'NIMAN': 0,
    'NIMBLETT': 0,
    'NIMEH': 0,
    'NIMER': 0,
    'NIMETH': 0,
    'NIMETZ': 0,
    'NIMICK': 0,
    'NIMITZ': 0,
    'NIMKE': 0,
    'NIMMAGADDA': 0,
    'NIMMER': 0,
    'NIMMO': 0,
    'NIMMONS': 0,
    'NIMO': 0,
    'NIMOCKS': 0,
    'NIMON': 0,
    'NIMPHIUS': 0,
    'NIMRI': 0,
    'NIMRICK': 0,
    'NIMROD': 0,
    'NIMS': 0,
    'NIMTZ': 0,
    'NIMZ': 0,
    'NIN': 0,
    'NINA': 0.9968157275370345,
    'NINAN': 0,
    'NINE': 0,
    'NINEMIRE': 0,
    'NINER': 0,
    'NINES': 0,
    'NINFA': 1,
    'NING': 0,
    'NINH': 0,
    'NINHAM': 0,
    'NINI': 0,
    'NININGER': 0,
    'NINIVAGGI': 0,
    'NINK': 0,
    'NINKE': 0,
    'NINMANN': 0,
    'NINNEMAN': 0,
    'NINNEMANN': 0,
    'NINNESS': 0,
    'NINO': 0,
    'NINOMIYA': 0,
    'NINOS': 0,
    'NINOW': 0,
    'NIOLA': 0,
    'NIOSI': 0,
    'NIOUS': 0,
    'NIP': 0,
    'NIPE': 0,
    'NIPER': 0,
    'NIPP': 0,
    'NIPPER': 0,
    'NIPPERT': 0,
    'NIPPLE': 0,
    'NIPPS': 0,
    'NIQUETTE': 0,
    'NIR': 0,
    'NIRA': 0,
    'NIRANJAN': 0,
    'NIRENBERG': 0,
    'NIRO': 0,
    'NIRSCHL': 0,
    'NISA': 0,
    'NISANOV': 0,
    'NISAR': 0,
    'NISBET': 0,
    'NISBETH': 0,
    'NISBETT': 0,
    'NISBY': 0,
    'NISCHAN': 0,
    'NISCHWITZ': 0,
    'NISCO': 0,
    'NISE': 0,
    'NISEN': 0,
    'NISENBAUM': 0,
    'NISENSON': 0,
    'NISH': 0,
    'NISHA': 0.9615384615384616,
    'NISHANIAN': 0,
    'NISHI': 0,
    'NISHIDA': 0,
    'NISHIGUCHI': 0,
    'NISHIHARA': 0,
    'NISHIHIRA': 0,
    'NISHIJIMA': 0,
    'NISHIKAWA': 0,
    'NISHIKI': 0,
    'NISHIMORI': 0,
    'NISHIMOTO': 0,
    'NISHIMURA': 0,
    'NISHINO': 0,
    'NISHIO': 0,
    'NISHIOKA': 0,
    'NISHITA': 0,
    'NISHIYAMA': 0,
    'NISHIZAKI': 0,
    'NISHIZAWA': 0,
    'NISI': 0,
    'NISIEWICZ': 0,
    'NISIUS': 0,
    'NISIVOCCIA': 0,
    'NISKA': 0,
    'NISKALA': 0,
    'NISKANEN': 0,
    'NISKI': 0,
    'NISLEY': 0,
    'NISLY': 0,
    'NISONGER': 0,
    'NISPEL': 0,
    'NISPEROS': 0,
    'NISS': 0,
    'NISSAN': 0,
    'NISSEL': 0,
    'NISSEN': 0,
    'NISSENBAUM': 0,
    'NISSIM': 0,
    'NISSLEY': 0,
    'NISSLY': 0,
    'NISSON': 0,
    'NIST': 0,
    'NISTA': 0,
    'NISTAL': 0,
    'NISTICO': 0,
    'NISTLER': 0,
    'NISTOR': 0,
    'NISULA': 0,
    'NISWANDER': 0,
    'NISWANGER': 0,
    'NISWENDER': 0,
    'NISWONGER': 0,
    'NITA': 0.9917355371900827,
    'NITCH': 0,
    'NITCHALS': 0,
    'NITCHER': 0,
    'NITCHIE': 0,
    'NITCHMAN': 0,
    'NITE': 0,
    'NITECKI': 0,
    'NITKA': 0,
    'NITKIEWICZ': 0,
    'NITKIN': 0,
    'NITKOWSKI': 0,
    'NITO': 0,
    'NITOWSKI': 0,
    'NITSCH': 0,
    'NITSCHE': 0,
    'NITSCHKE': 0,
    'NITTA': 0,
    'NITTI': 0,
    'NITTINGER': 0,
    'NITTLER': 0,
    'NITTO': 0,
    'NITTOLI': 0,
    'NITTOLO': 0,
    'NITZ': 0,
    'NITZBERG': 0,
    'NITZEL': 0,
    'NITZKE': 0,
    'NITZSCHE': 0,
    'NITZSCHKE': 0,
    'NIU': 0,
    'NIV': 0,
    'NIVA': 0,
    'NIVALA': 0,
    'NIVAR': 0,
    'NIVELO': 0,
    'NIVEN': 0,
    'NIVENS': 0,
    'NIVER': 0,
    'NIVES': 0,
    'NIVISON': 0,
    'NIWA': 0,
    'NIX': 0,
    'NIXA': 0,
    'NIXDORF': 0,
    'NIXON': 0,
    'NIXSON': 0,
    'NIXT': 0,
    'NIYAZOV': 0,
    'NIZ': 0,
    'NIZAM': 0,
    'NIZAMI': 0,
    'NIZER': 0,
    'NIZINSKI': 0,
    'NIZIOL': 0,
    'NIZIOLEK': 0,
    'NIZNIK': 0,
    'NIZOLEK': 0,
    'NIZZA': 0,
    'NIZZI': 0,
    'NJENGA': 0,
    'NJIE': 0,
    'NJOKU': 0,
    'NJOROGE': 0,
    'NJOS': 0,
    'NJUGUNA': 0,
    'NJUS': 0,
    'NKANSAH': 0,
    'NKRUMAH': 0,
    'NKWOCHA': 0,
    'NNADI': 0,
    'NNAJI': 0,
    'NO': 0,
    'NOA': 0,
    'NOACK': 0,
    'NOAD': 0,
    'NOAH': 0.9235936188077246,
    'NOAK': 0,
    'NOAKER': 0,
    'NOAKES': 0,
    'NOAL': 0,
    'NOALL': 0,
    'NOAR': 0,
    'NOBACH': 0,
    'NOBBE': 0,
    'NOBBS': 0,
    'NOBE': 0,
    'NOBEL': 0,
    'NOBERT': 0,
    'NOBES': 0,
    'NOBILE': 0,
    'NOBILI': 0,
    'NOBIS': 0,
    'NOBLE': 0.25113008538422904,
    'NOBLES': 0,
    'NOBLET': 0,
    'NOBLETT': 0,
    'NOBLEY': 0,
    'NOBLEZA': 0,
    'NOBLIN': 0,
    'NOBLIT': 0,
    'NOBLITT': 0,
    'NOBOA': 0,
    'NOBRE': 0,
    'NOBREGA': 0,
    'NOBRIGA': 0,
    'NOBS': 0,
    'NOBUKO': 1,
    'NOCAR': 0,
    'NOCCHI': 0,
    'NOCCO': 0,
    'NOCE': 0,
    'NOCEDA': 0,
    'NOCEK': 0,
    'NOCELLA': 0,
    'NOCERA': 0,
    'NOCERINO': 0,
    'NOCERO': 0,
    'NOCH': 0,
    'NOCHE': 0,
    'NOCHEZ': 0,
    'NOCITA': 0,
    'NOCITO': 0,
    'NOCK': 0,
    'NOCKELS': 0,
    'NOCKS': 0,
    'NOCON': 0,
    'NODA': 0,
    'NODAL': 0,
    'NODAR': 0,
    'NODARSE': 0,
    'NODD': 0,
    'NODDIN': 0,
    'NODELL': 0,
    'NODELMAN': 0,
    'NODEN': 0,
    'NODES': 0,
    'NODINE': 0,
    'NODLAND': 0,
    'NODLER': 0,
    'NODOLF': 0,
    'NODURFT': 0,
    'NOE': 0.7333333333333333,
    'NOECKER': 0,
    'NOEGEL': 0,
    'NOEL': 0.7736943907156673,
    'NOELDNER': 0,
    'NOELIA': 1,
    'NOELKE': 0,
    'NOELKER': 0,
    'NOELL': 0,
    'NOELLA': 1,
    'NOELLE': 0.9888751545117429,
    'NOELLER': 0,
    'NOEMI': 1,
    'NOER': 0,
    'NOERENBERG': 0,
    'NOERR': 0,
    'NOES': 0,
    'NOESEN': 0,
    'NOESI': 0,
    'NOESKE': 0,
    'NOETH': 0,
    'NOETHE': 0,
    'NOETHEN': 0,
    'NOETZEL': 0,
    'NOEY': 0,
    'NOFAL': 0,
    'NOFER': 0,
    'NOFFKE': 0,
    'NOFFSINGER': 0,
    'NOFFZ': 0,
    'NOFI': 0,
    'NOFIRE': 0,
    'NOFS': 0,
    'NOFSINGER': 0,
    'NOFTLE': 0,
    'NOFTSGER': 0,
    'NOFTSIER': 0,
    'NOFTZ': 0,
    'NOFZIGER': 0,
    'NOFZINGER': 0,
    'NOGA': 0,
    'NOGAJ': 0,
    'NOGAL': 0,
    'NOGALES': 0,
    'NOGALSKI': 0,
    'NOGAMI': 0,
    'NOGAR': 0,
    'NOGAY': 0,
    'NOGGLE': 0,
    'NOGLE': 0,
    'NOGLER': 0,
    'NOGOSEK': 0,
    'NOGOWSKI': 0,
    'NOGRADY': 0,
    'NOGUCHI': 0,
    'NOGUEDA': 0,
    'NOGUEIRA': 0,
    'NOGUERA': 0,
    'NOGUERAS': 0,
    'NOGUES': 0,
    'NOGUEZ': 0,
    'NOH': 0,
    'NOHA': 0,
    'NOHARA': 0,
    'NOHAVA': 0,
    'NOHE': 0,
    'NOHELTY': 0,
    'NOHEMI': 1,
    'NOHL': 0,
    'NOHNER': 0,
    'NOHR': 0,
    'NOHRA': 0,
    'NOHREN': 0,
    'NOHRENBERG': 0,
    'NOIA': 0,
    'NOICE': 0,
    'NOID': 0,
    'NOIL': 0,
    'NOILES': 0,
    'NOIROT': 0,
    'NOISETTE': 0,
    'NOISEUX': 0,
    'NOJI': 0,
    'NOJIMA': 0,
    'NOJIRI': 0,
    'NOKE': 0,
    'NOKES': 0,
    'NOKLEBY': 0,
    'NOL': 0,
    'NOLA': 0.9817671809256662,
    'NOLAN': 0.4411265693926027,
    'NOLAND': 0,
    'NOLASCO': 0,
    'NOLAZCO': 0,
    'NOLD': 0,
    'NOLDE': 0,
    'NOLDEN': 0,
    'NOLDER': 0,
    'NOLDY': 0,
    'NOLE': 0,
    'NOLEN': 0,
    'NOLES': 0,
    'NOLET': 0,
    'NOLETTE': 0,
    'NOLF': 0,
    'NOLFF': 0,
    'NOLFI': 0,
    'NOLFO': 0,
    'NOLI': 0,
    'NOLIN': 0,
    'NOLING': 0,
    'NOLKER': 0,
    'NOLL': 0,
    'NOLLA': 0,
    'NOLLAN': 0,
    'NOLLE': 0,
    'NOLLEN': 0,
    'NOLLER': 0,
    'NOLLET': 0,
    'NOLLETTE': 0,
    'NOLLEY': 0,
    'NOLLIE': 0,
    'NOLLMAN': 0,
    'NOLLNER': 0,
    'NOLT': 0,
    'NOLTA': 0,
    'NOLTE': 0,
    'NOLTEMEYER': 0,
    'NOLTER': 0,
    'NOLTING': 0,
    'NOLTNER': 0,
    'NOLTON': 0,
    'NOLZ': 0,
    'NOMA': 0.9756097560975611,
    'NOMAN': 0,
    'NOMEE': 0,
    'NOMIKOS': 0,
    'NOMMENSEN': 0,
    'NOMOTO': 0,
    'NOMURA': 0,
    'NON': 0,
    'NONA': 0.990990990990991,
    'NONAKA': 0,
    'NONAMAKER': 0,
    'NONAME': 0,
    'NONATO': 0,
    'NONDORF': 0,
    'NONEMAKER': 0,
    'NONEMAN': 0,
    'NONEOFYOURBU': 0,
    'NONES': 0,
    'NONEZ': 0,
    'NONG': 0,
    'NONN': 0,
    'NONNEMACHER': 0,
    'NONNEMAKER': 0,
    'NONNENMACHER': 0,
    'NONO': 0,
    'NOOD': 0,
    'NOOE': 0,
    'NOOJIN': 0,
    'NOOK': 0,
    'NOOKS': 0,
    'NOON': 0,
    'NOONAN': 0,
    'NOONCHESTER': 0,
    'NOONE': 0,
    'NOONEN': 0,
    'NOONER': 0,
    'NOONEY': 0,
    'NOONKESTER': 0,
    'NOOR': 0,
    'NOORALI': 0,
    'NOORANI': 0,
    'NOORDA': 0,
    'NOORDHOEK': 0,
    'NOORE': 0,
    'NOORI': 0,
    'NOORLANDER': 0,
    'NOORMAN': 0,
    'NOORY': 0,
    'NOOTBAAR': 0,
    'NOOYEN': 0,
    'NOP': 0,
    'NOPERI': 0,
    'NOPPE': 0,
    'NOPPENBERGER': 0,
    'NOPPER': 0,
    'NOR': 0,
    'NORA': 0.9938733832539143,
    'NORAH': 0.966183574879227,
    'NORALES': 0,
    'NORALS': 0,
    'NORAN': 0,
    'NORAT': 0,
    'NORATO': 0,
    'NORBECK': 0,
    'NORBERG': 0,
    'NORBERT': 0.9931245225362872,
    'NORBERTO': 0.975609756097561,
    'NORBURY': 0,
    'NORBUT': 0,
    'NORBY': 0,
    'NORCIA': 0,
    'NORCINI': 0,
    'NORCOTT': 0,
    'NORCROSS': 0,
    'NORCUTT': 0,
    'NORD': 0,
    'NORDAHL': 0,
    'NORDAN': 0,
    'NORDBECK': 0,
    'NORDBERG': 0,
    'NORDBROCK': 0,
    'NORDBY': 0,
    'NORDBYE': 0,
    'NORDE': 0,
    'NORDEEN': 0,
    'NORDELL': 0,
    'NORDEMAN': 0,
    'NORDEN': 0,
    'NORDENG': 0,
    'NORDENSTROM': 0,
    'NORDER': 0,
    'NORDGAARD': 0,
    'NORDGREN': 0,
    'NORDHAGEN': 0,
    'NORDHAUS': 0,
    'NORDHAUSEN': 0,
    'NORDHEIM': 0,
    'NORDHOFF': 0,
    'NORDHOLM': 0,
    'NORDHUES': 0,
    'NORDHUS': 0,
    'NORDICK': 0,
    'NORDIKE': 0,
    'NORDIN': 0,
    'NORDINE': 0,
    'NORDLAND': 0,
    'NORDLIE': 0,
    'NORDLING': 0,
    'NORDLOF': 0,
    'NORDLOH': 0,
    'NORDLUND': 0,
    'NORDMAN': 0,
    'NORDMANN': 0,
    'NORDMARK': 0,
    'NORDMEYER': 0,
    'NORDNESS': 0,
    'NORDONE': 0,
    'NORDQUIST': 0,
    'NORDRUM': 0,
    'NORDSKOG': 0,
    'NORDSTRAND': 0,
    'NORDSTROM': 0,
    'NORDT': 0,
    'NORDTVEDT': 0,
    'NORDWALL': 0,
    'NORDYKE': 0,
    'NORE': 0,
    'NORED': 0,
    'NOREEN': 0.9774436090225564,
    'NOREIGA': 0,
    'NOREIKA': 0,
    'NOREK': 0,
    'NORELIUS': 0,
    'NORELL': 0,
    'NORELLI': 0,
    'NOREM': 0,
    'NOREN': 0,
    'NORENA': 0,
    'NORENBERG': 0,
    'NORENE': 0.9836065573770493,
    'NORES': 0,
    'NORFLEET': 0,
    'NORFOLK': 0,
    'NORFORD': 0,
    'NORFUL': 0,
    'NORGAARD': 0,
    'NORGAN': 0,
    'NORGARD': 0,
    'NORGART': 0,
    'NORGREN': 0,
    'NORGROVE': 0,
    'NORHEIM': 0,
    'NORI': 0,
    'NORIA': 0,
    'NORIAN': 0,
    'NORICK': 0,
    'NORIEGA': 0,
    'NORIKO': 1,
    'NORIN': 0,
    'NORINE': 0.9803921568627452,
    'NORING': 0,
    'NORIS': 0,
    'NORK': 0,
    'NORKETT': 0,
    'NORKIEWICZ': 0,
    'NORKIN': 0,
    'NORKO': 0,
    'NORKUS': 0,
    'NORLAND': 0,
    'NORLANDER': 0,
    'NORLEN': 0,
    'NORLEY': 0,
    'NORLIN': 0,
    'NORLING': 0,
    'NORLUND': 0,
    'NORMA': 1,
    'NORMAN': 0.8809055118110236,
    'NORMAND': 0.8403361344537815,
    'NORMANDEAU': 0,
    'NORMANDIA': 0,
    'NORMANDIN': 0,
    'NORMANDY': 0,
    'NORMANN': 0,
    'NORMENT': 0,
    'NORMIL': 0,
    'NORMILE': 0,
    'NORMINGTON': 0,
    'NORMOYLE': 0,
    'NORNES': 0,
    'NORNG': 0,
    'NORNHOLD': 0,
    'NORONA': 0,
    'NORONHA': 0,
    'NORORI': 0,
    'NORQUEST': 0,
    'NORQUIST': 0,
    'NORR': 0,
    'NORRBOM': 0,
    'NORRED': 0,
    'NORRELL': 0,
    'NORRGARD': 0,
    'NORRICK': 0,
    'NORRID': 0,
    'NORRIE': 0,
    'NORRIED': 0,
    'NORRINGTON': 0,
    'NORRIS': 0.2582765907490021,
    'NORRISH': 0,
    'NORRISS': 0,
    'NORROD': 0,
    'NORS': 0,
    'NORSE': 0,
    'NORSEN': 0,
    'NORSKOG': 0,
    'NORSTAD': 0,
    'NORSTROM': 0,
    'NORSWORTHY': 0,
    'NORTE': 0,
    'NORTEN': 0,
    'NORTEY': 0,
    'NORTH': 0,
    'NORTHAM': 0,
    'NORTHAN': 0,
    'NORTHCOTE': 0,
    'NORTHCOTT': 0,
    'NORTHCRAFT': 0,
    'NORTHCROSS': 0,
    'NORTHCUT': 0,
    'NORTHCUTT': 0,
    'NORTHEN': 0,
    'NORTHERN': 0,
    'NORTHEY': 0,
    'NORTHFIELD': 0,
    'NORTHINGTON': 0,
    'NORTHOUSE': 0,
    'NORTHOVER': 0,
    'NORTHRIDGE': 0,
    'NORTHRIP': 0,
    'NORTHROP': 0,
    'NORTHRUP': 0,
    'NORTHUP': 0,
    'NORTHWAY': 0,
    'NORTHWOOD': 0,
    'NORTMAN': 0,
    'NORTON': 0,
    'NORTRUP': 0,
    'NORTZ': 0,
    'NORUM': 0,
    'NORVAL': 0,
    'NORVEL': 0,
    'NORVELL': 0,
    'NORVELLE': 0,
    'NORVIEL': 0,
    'NORVIL': 0,
    'NORVILLE': 0,
    'NORWALK': 0,
    'NORWAY': 0,
    'NORWELL': 0,
    'NORWICH': 0,
    'NORWICK': 0,
    'NORWINE': 0,
    'NORWOOD': 0,
    'NORZAGARAY': 0,
    'NOSACK': 0,
    'NOSAL': 0,
    'NOSAN': 0,
    'NOSBISCH': 0,
    'NOSBUSCH': 0,
    'NOSBUSH': 0,
    'NOSCHESE': 0,
    'NOSE': 0,
    'NOSEK': 0,
    'NOSEL': 0,
    'NOSER': 0,
    'NOSEWORTHY': 0,
    'NOSIE': 0,
    'NOSKA': 0,
    'NOSKE': 0,
    'NOSKER': 0,
    'NOSKO': 0,
    'NOSKOWIAK': 0,
    'NOSKY': 0,
    'NOSLER': 0,
    'NOSRATI': 0,
    'NOSS': 0,
    'NOSSAMAN': 0,
    'NOSSE': 0,
    'NOSSER': 0,
    'NOSSETT': 0,
    'NOST': 0,
    'NOSTER': 0,
    'NOSTRAND': 0,
    'NOSTRANT': 0,
    'NOSTRO': 0,
    'NOSWORTHY': 0,
    'NOT': 0,
    'NOTA': 0,
    'NOTAFRAID': 0,
    'NOTAH': 0,
    'NOTAR': 0,
    'NOTARANGELO': 0,
    'NOTARFRANCESCO': 0,
    'NOTARGIACOMO': 0,
    'NOTARI': 0,
    'NOTARIANNI': 0,
    'NOTARIO': 0,
    'NOTARNICOLA': 0,
    'NOTARO': 0,
    'NOTCH': 0,
    'NOTE': 0,
    'NOTEBOOM': 0,
    'NOTERMANN': 0,
    'NOTESTINE': 0,
    'NOTEWARE': 0,
    'NOTGRASS': 0,
    'NOTH': 0,
    'NOTHAFT': 0,
    'NOTHDURFT': 0,
    'NOTHEIS': 0,
    'NOTHEM': 0,
    'NOTHNAGEL': 0,
    'NOTHNAGLE': 0,
    'NOTHSTEIN': 0,
    'NOTHSTINE': 0,
    'NOTI': 0,
    'NOTICE': 0,
    'NOTIS': 0,
    'NOTKIN': 0,
    'NOTLEY': 0,
    'NOTMAN': 0,
    'NOTO': 0,
    'NOTSCH': 0,
    'NOTT': 0,
    'NOTTAGE': 0,
    'NOTTE': 0,
    'NOTTER': 0,
    'NOTTESTAD': 0,
    'NOTTI': 0,
    'NOTTINGHAM': 0,
    'NOTTKE': 0,
    'NOTTO': 0,
    'NOTTOLI': 0,
    'NOTZ': 0,
    'NOU': 0,
    'NOUD': 0,
    'NOUHAN': 0,
    'NOUJAIM': 0,
    'NOULLET': 0,
    'NOUN': 0,
    'NOUR': 0,
    'NOUREDDINE': 0,
    'NOURI': 0,
    'NOURIAN': 0,
    'NOURIE': 0,
    'NOURSE': 0,
    'NOURY': 0,
    'NOV': 0,
    'NOVA': 0.8350730688935282,
    'NOVAC': 0,
    'NOVACEK': 0,
    'NOVACK': 0,
    'NOVAK': 0,
    'NOVAKOSKI': 0,
    'NOVAKOVIC': 0,
    'NOVAKOVICH': 0,
    'NOVAKOWSKI': 0,
    'NOVAL': 0,
    'NOVALES': 0,
    'NOVAR': 0,
    'NOVARA': 0,
    'NOVARIA': 0,
    'NOVARRO': 0,
    'NOVAS': 0,
    'NOVE': 0,
    'NOVECK': 0,
    'NOVEL': 0,
    'NOVELA': 0,
    'NOVELL': 0,
    'NOVELLA': 0.9569377990430621,
    'NOVELLI': 0,
    'NOVELLINO': 0,
    'NOVELLO': 0,
    'NOVELLY': 0,
    'NOVELO': 0,
    'NOVEMBER': 0,
    'NOVEMBRE': 0,
    'NOVER': 0,
    'NOVERO': 0,
    'NOVEY': 0,
    'NOVI': 0,
    'NOVIA': 0,
    'NOVIAN': 0,
    'NOVICH': 0,
    'NOVICK': 0,
    'NOVICKI': 0,
    'NOVICKY': 0,
    'NOVIELLI': 0,
    'NOVIELLO': 0,
    'NOVIK': 0,
    'NOVIKOFF': 0,
    'NOVIKOV': 0,
    'NOVIKOVA': 0,
    'NOVILLO': 0,
    'NOVIN': 0,
    'NOVINGER': 0,
    'NOVINSKI': 0,
    'NOVIS': 0,
    'NOVISKI': 0,
    'NOVITSKE': 0,
    'NOVITSKI': 0,
    'NOVITSKY': 0,
    'NOVO': 0,
    'NOVOA': 0,
    'NOVOBILSKI': 0,
    'NOVOSAD': 0,
    'NOVOSEL': 0,
    'NOVOTNAK': 0,
    'NOVOTNEY': 0,
    'NOVOTNY': 0,
    'NOVY': 0,
    'NOW': 0,
    'NOWACK': 0,
    'NOWACKI': 0,
    'NOWACZEWSKI': 0,
    'NOWACZYK': 0,
    'NOWAK': 0,
    'NOWAKOWSKI': 0,
    'NOWALK': 0,
    'NOWARK': 0,
    'NOWASKI': 0,
    'NOWATZKE': 0,
    'NOWATZKI': 0,
    'NOWDEN': 0,
    'NOWE': 0,
    'NOWELL': 0,
    'NOWELS': 0,
    'NOWERS': 0,
    'NOWICK': 0,
    'NOWICKI': 0,
    'NOWIK': 0,
    'NOWINSKI': 0,
    'NOWISKI': 0,
    'NOWITZKE': 0,
    'NOWKA': 0,
    'NOWLAN': 0,
    'NOWLAND': 0,
    'NOWLEN': 0,
    'NOWLIN': 0,
    'NOWLING': 0,
    'NOWMAN': 0,
    'NOWOBILSKI': 0,
    'NOWOCIN': 0,
    'NOWORYTA': 0,
    'NOWOSAD': 0,
    'NOWOSIELSKI': 0,
    'NOWOTARSKI': 0,
    'NOWOTNY': 0,
    'NOXON': 0,
    'NOY': 0,
    'NOYA': 0,
    'NOYCE': 0,
    'NOYD': 0,
    'NOYE': 0,
    'NOYER': 0,
    'NOYES': 0,
    'NOYOLA': 0,
    'NOZAKI': 0,
    'NOZAWA': 0,
    'NU': 1,
    'NUA': 0,
    'NUANES': 0,
    'NUANEZ': 0,
    'NUARA': 0,
    'NUBER': 0,
    'NUBIA': 1,
    'NUBLA': 0,
    'NUBY': 0,
    'NUCCI': 0,
    'NUCCIO': 0,
    'NUCCITELLI': 0,
    'NUCE': 0,
    'NUCERA': 0,
    'NUCHOLS': 0,
    'NUCIFORA': 0,
    'NUCKELS': 0,
    'NUCKLES': 0,
    'NUCKOLES': 0,
    'NUCKOLLS': 0,
    'NUCKOLS': 0,
    'NUCUM': 0,
    'NUDD': 0,
    'NUDEL': 0,
    'NUDELL': 0,
    'NUDELMAN': 0,
    'NUDI': 0,
    'NUDING': 0,
    'NUDO': 0,
    'NUEBEL': 0,
    'NUECHTERLEIN': 0,
    'NUEHRING': 0,
    'NUELLE': 0,
    'NUERNBERG': 0,
    'NUERNBERGER': 0,
    'NUESCA': 0,
    'NUESE': 0,
    'NUESI': 0,
    'NUESSE': 0,
    'NUESSEN': 0,
    'NUESSLE': 0,
    'NUEST': 0,
    'NUETZEL': 0,
    'NUETZMAN': 0,
    'NUEVA': 0,
    'NUEVO': 0,
    'NUEZ': 0,
    'NUFER': 0,
    'NUFFER': 0,
    'NUFIO': 0,
    'NUGEN': 0,
    'NUGENT': 0,
    'NUGUID': 0,
    'NUGYEN': 0,
    'NUHANOVIC': 0,
    'NUHFER': 0,
    'NUHN': 0,
    'NUILA': 0,
    'NUKALA': 0,
    'NULF': 0,
    'NULL': 0,
    'NULLE': 0,
    'NULMAN': 0,
    'NULPH': 0,
    'NULSEN': 0,
    'NULTON': 0,
    'NULTY': 0,
    'NUMA': 0,
    'NUMAN': 0,
    'NUMATA': 0,
    'NUMBERS': 0.9874326750448834,
    'NUMEZ': 0,
    'NUMKENA': 0,
    'NUMMER': 0,
    'NUMMERDOR': 0,
    'NUMMY': 0,
    'NUMRICH': 0,
    'NUN': 0,
    'NUNAG': 0,
    'NUNALLY': 0,
    'NUNAMAKER': 0,
    'NUNAN': 0,
    'NUNBERG': 0,
    'NUNCIO': 0,
    'NUNDAHL': 0,
    'NUNE': 0,
    'NUNEMACHER': 0,
    'NUNEMAKER': 0,
    'NUNERY': 0,
    'NUNES': 0,
    'NUNEZ': 0,
    'NUNGARAY': 0,
    'NUNGESSER': 0,
    'NUNGESTER': 0,
    'NUNIS': 0,
    'NUNLEY': 0,
    'NUNLIST': 0,
    'NUNN': 0,
    'NUNNALLY': 0,
    'NUNNARI': 0,
    'NUNNELEE': 0,
    'NUNNELEY': 0,
    'NUNNELLEY': 0,
    'NUNNELLY': 0,
    'NUNNEMAKER': 0,
    'NUNNENKAMP': 0,
    'NUNNERY': 0,
    'NUNNIKHOVEN': 0,
    'NUNNINK': 0,
    'NUNNO': 0,
    'NUNNS': 0,
    'NUNO': 0,
    'NUNOZ': 0,
    'NUNZIATA': 0,
    'NUNZIATO': 0,
    'NUON': 0,
    'NUOVO': 0,
    'NUPP': 0,
    'NUQUI': 0,
    'NUR': 0,
    'NURCZYK': 0,
    'NURENBERG': 0,
    'NURGE': 0,
    'NURI': 0,
    'NURIDDIN': 0,
    'NURMI': 0,
    'NURNBERG': 0,
    'NURNBERGER': 0,
    'NURRE': 0,
    'NURRENBERN': 0,
    'NURSE': 0,
    'NUSBAUM': 0,
    'NUSE': 0,
    'NUSH': 0,
    'NUSKE': 0,
    'NUSOM': 0,
    'NUSS': 0,
    'NUSSBAUM': 0,
    'NUSSBAUMER': 0,
    'NUSSEAR': 0,
    'NUSSER': 0,
    'NUSSLE': 0,
    'NUSSMAN': 0,
    'NUSTAD': 0,
    'NUSZ': 0,
    'NUTALL': 0,
    'NUTBROWN': 0,
    'NUTE': 0,
    'NUTGRASS': 0,
    'NUTH': 0,
    'NUTHALS': 0,
    'NUTI': 0,
    'NUTILE': 0,
    'NUTINI': 0,
    'NUTLEY': 0,
    'NUTSCH': 0,
    'NUTT': 0,
    'NUTTALL': 0,
    'NUTTELMAN': 0,
    'NUTTER': 0,
    'NUTTING': 0,
    'NUTTLE': 0,
    'NUTTY': 0,
    'NUTWELL': 0,
    'NUTZ': 0,
    'NUTZMAN': 0,
    'NUVAL': 0,
    'NUWER': 0,
    'NUXOLL': 0,
    'NUYEN': 0,
    'NUZMAN': 0,
    'NUZUM': 0,
    'NUZZI': 0,
    'NUZZO': 0,
    'NUZZOLO': 0,
    'NWACHUKU': 0,
    'NWACHUKWU': 0,
    'NWADIKE': 0,
    'NWAFOR': 0,
    'NWAGWU': 0,
    'NWANERI': 0,
    'NWANKWO': 0,
    'NWEKE': 0,
    'NWOGU': 0,
    'NWOKE': 0,
    'NWOKO': 0,
    'NWOSU': 0,
    'NY': 0,
    'NYACK': 0,
    'NYAMEKYE': 0,
    'NYARI': 0,
    'NYARKO': 0,
    'NYBAKKEN': 0,
    'NYBECK': 0,
    'NYBERG': 0,
    'NYBLOM': 0,
    'NYBO': 0,
    'NYBOER': 0,
    'NYBORG': 0,
    'NYCE': 0,
    'NYCUM': 0,
    'NYCZ': 0,
    'NYDAM': 0,
    'NYDEGGER': 0,
    'NYDIA': 1,
    'NYE': 0,
    'NYEGAARD': 0,
    'NYEHOLT': 0,
    'NYEN': 0,
    'NYENHUIS': 0,
    'NYER': 0,
    'NYERGES': 0,
    'NYERS': 0,
    'NYESTE': 0,
    'NYFFELER': 0,
    'NYGAARD': 0,
    'NYGARD': 0,
    'NYGREN': 0,
    'NYHAN': 0,
    'NYHART': 0,
    'NYHOF': 0,
    'NYHOFF': 0,
    'NYHOLM': 0,
    'NYHUIS': 0,
    'NYHUS': 0,
    'NYIKOS': 0,
    'NYIRI': 0,
    'NYITRAI': 0,
    'NYITRAY': 0,
    'NYKAMP': 0,
    'NYKANEN': 0,
    'NYKAZA': 0,
    'NYKIEL': 0,
    'NYLA': 1,
    'NYLAND': 0,
    'NYLANDER': 0,
    'NYLEN': 0,
    'NYLIN': 0,
    'NYLUND': 0,
    'NYMAN': 0,
    'NYMEYER': 0,
    'NYPAVER': 0,
    'NYQUIST': 0,
    'NYRE': 0,
    'NYREN': 0,
    'NYS': 0,
    'NYSETH': 0,
    'NYSSEN': 0,
    'NYSTEDT': 0,
    'NYSTRAND': 0,
    'NYSTROM': 0,
    'NYSTUEN': 0,
    'NYTES': 0,
    'NYTKO': 0,
    'NYUGEN': 0,
    'NYZIO': 0,
    'NZUYEN': 0,
    'OACHS': 0,
    'OAK': 0,
    'OAKDEN': 0,
    'OAKE': 0,
    'OAKERSON': 0,
    'OAKES': 0,
    'OAKESON': 0,
    'OAKEY': 0,
    'OAKFORD': 0,
    'OAKLAND': 0,
    'OAKLEAF': 0,
    'OAKLEY': 0,
    'OAKMAN': 0,
    'OAKS': 0,
    'OALMANN': 0,
    'OAR': 0,
    'OARD': 0,
    'OARE': 0,
    'OAS': 0,
    'OASAY': 0,
    'OASE': 0,
    'OASTER': 0,
    'OATES': 0,
    'OATHOUT': 0,
    'OATIS': 0,
    'OATLEY': 0,
    'OATMAN': 0,
    'OATNEY': 0,
    'OATS': 0,
    'OATSVALL': 0,
    'OATTS': 0,
    'OAXACA': 0,
    'OBA': 0,
    'OBAD': 0,
    'OBAID': 0,
    'OBAKER': 0,
    'OBAL': 0,
    'OBALLE': 0,
    'OBAN': 0,
    'OBANA': 0,
    'OBANDO': 0,
    'OBANION': 0,
    'OBANNER': 0,
    'OBANNION': 0,
    'OBANNON': 0,
    'OBAR': 0,
    'OBARA': 0,
    'OBARR': 0,
    'OBARSKI': 0,
    'OBAS': 0,
    'OBASI': 0,
    'OBATA': 0,
    'OBAUGH': 0,
    'OBAYA': 0,
    'OBAYASHI': 0,
    'OBBINK': 0,
    'OBDULIA': 1,
    'OBE': 0,
    'OBEAR': 0,
    'OBED': 0,
    'OBEDOZA': 0,
    'OBEE': 0,
    'OBEID': 0,
    'OBEIRNE': 0,
    'OBEL': 0,
    'OBEN': 0,
    'OBENAUER': 0,
    'OBENAUF': 0,
    'OBENCHAIN': 0,
    'OBENDORF': 0,
    'OBENDORFER': 0,
    'OBENG': 0,
    'OBENHAUS': 0,
    'OBENLAND': 0,
    'OBENOUR': 0,
    'OBENSHAIN': 0,
    'OBER': 0,
    'OBERACKER': 0,
    'OBERBECK': 0,
    'OBERBROECKLING': 0,
    'OBERC': 0,
    'OBERDICK': 0,
    'OBERDIER': 0,
    'OBERDING': 0,
    'OBERDORF': 0,
    'OBERDORFER': 0,
    'OBEREMBT': 0,
    'OBERENDER': 0,
    'OBERER': 0,
    'OBERFELD': 0,
    'OBERFOELL': 0,
    'OBERG': 0,
    'OBERGFELL': 0,
    'OBERHAUS': 0,
    'OBERHAUSEN': 0,
    'OBERHAUSER': 0,
    'OBERHEIM': 0,
    'OBERHELMAN': 0,
    'OBERHEU': 0,
    'OBERHOFER': 0,
    'OBERHOLTZER': 0,
    'OBERHOLZER': 0,
    'OBERKROM': 0,
    'OBERLANDER': 0,
    'OBERLE': 0,
    'OBERLEY': 0,
    'OBERLIES': 0,
    'OBERLIN': 0,
    'OBERLOH': 0,
    'OBERLY': 0,
    'OBERMAIER': 0,
    'OBERMAN': 0,
    'OBERMANN': 0,
    'OBERMARK': 0,
    'OBERMAYER': 0,
    'OBERMEIER': 0,
    'OBERMEYER': 0,
    'OBERMIER': 0,
    'OBERMILLER': 0,
    'OBERMIRE': 0,
    'OBERMUELLER': 0,
    'OBERNDORFER': 0,
    'OBERNESSER': 0,
    'OBERNUEFEMANN': 0,
    'OBEROI': 0,
    'OBERPRILLER': 0,
    'OBERRY': 0,
    'OBERSCHLAKE': 0,
    'OBERSCHMIDT': 0,
    'OBERSHAW': 0,
    'OBERSKI': 0,
    'OBERSON': 0,
    'OBERST': 0,
    'OBERSTAR': 0,
    'OBERSTE': 0,
    'OBERSTEIN': 0,
    'OBERT': 0,
    'OBERTI': 0,
    'OBERTING': 0,
    'OBERTO': 0,
    'OBERTON': 0,
    'OBERTS': 0,
    'OBERY': 0,
    'OBESO': 0,
    'OBETZ': 0,
    'OBEY': 0,
    'OBEZO': 0,
    'OBI': 0,
    'OBIE': 0,
    'OBIEDO': 0,
    'OBIEN': 0,
    'OBIER': 0,
    'OBIN': 0,
    'OBIOHA': 0,
    'OBISPO': 0,
    'OBITZ': 0,
    'OBJIO': 0,
    'OBLACK': 0,
    'OBLAD': 0,
    'OBLAK': 0,
    'OBLANDER': 0,
    'OBLEA': 0,
    'OBLENES': 0,
    'OBLENESS': 0,
    'OBLENIS': 0,
    'OBLER': 0,
    'OBLEY': 0,
    'OBLIGACION': 0,
    'OBLINGER': 0,
    'OBLISK': 0,
    'OBLOCK': 0,
    'OBLOY': 0,
    'OBNEY': 0,
    'OBORN': 0,
    'OBORNE': 0,
    'OBORNY': 0,
    'OBORSKI': 0,
    'OBOT': 0,
    'OBOYLE': 0,
    'OBRA': 0,
    'OBRADOVIC': 0,
    'OBRADOVICH': 0,
    'OBRANOVICH': 0,
    'OBRAY': 0,
    'OBRECHT': 0,
    'OBREGON': 0,
    'OBREIN': 0,
    'OBREMSKI': 0,
    'OBRERO': 0,
    'OBREY': 0,
    'OBRIAN': 0,
    'OBRIANT': 0,
    'OBRIEN': 0,
    'OBRIGEWITCH': 0,
    'OBRIGHT': 0,
    'OBRINGER': 0,
    'OBRION': 0,
    'OBRIST': 0,
    'OBROCHTA': 0,
    'OBROCK': 0,
    'OBRY': 0,
    'OBRYAN': 0,
    'OBRYANT': 0,
    'OBRYCKI': 0,
    'OBRYON': 0,
    'OBRZUT': 0,
    'OBST': 0,
    'OBUCH': 0,
    'OBUCHOWSKI': 0,
    'OBUSEK': 0,
    'OBY': 0,
    'OBYRNE': 0,
    'OCA': 0,
    'OCACIO': 0,
    'OCADIZ': 0,
    'OCAIN': 0,
    'OCALLAGHAN': 0,
    'OCALLAHAN': 0,
    'OCAMB': 0,
    'OCAMPO': 0,
    'OCAMPOS': 0,
    'OCANA': 0,
    'OCANAS': 0,
    'OCANO': 0,
    'OCARANZA': 0,
    'OCARROLL': 0,
    'OCASIO': 0,
    'OCCEAN': 0,
    'OCCHI': 0,
    'OCCHINO': 0,
    'OCCHIOGROSSO': 0,
    'OCCHIONERO': 0,
    'OCCHIPINTI': 0,
    'OCCHIUTO': 0,
    'OCCUPANT': 0,
    'OCEAN': 0,
    'OCEGUEDA': 0,
    'OCEGUERA': 0,
    'OCEJO': 0,
    'OCEL': 0,
    'OCELLO': 0,
    'OCEPEK': 0,
    'OCH': 0,
    'OCHA': 0,
    'OCHAB': 0,
    'OCHAL': 0,
    'OCHALEK': 0,
    'OCHAMPAUGH': 0,
    'OCHART': 0,
    'OCHELTREE': 0,
    'OCHI': 0,
    'OCHIAI': 0,
    'OCHIENG': 0,
    'OCHILTREE': 0,
    'OCHINERO': 0,
    'OCHMAN': 0,
    'OCHOA': 0,
    'OCHOCKI': 0,
    'OCHODNICKY': 0,
    'OCHOTORENA': 0,
    'OCHS': 0,
    'OCHSE': 0,
    'OCHSENBEIN': 0,
    'OCHSENDORF': 0,
    'OCHSENHIRT': 0,
    'OCHSNER': 0,
    'OCHWAT': 0,
    'OCIE': 1,
    'OCK': 0,
    'OCKEN': 0,
    'OCKENFELS': 0,
    'OCKER': 0,
    'OCKERMAN': 0,
    'OCKERT': 0,
    'OCKEY': 0,
    'OCKMAN': 0,
    'OCKULY': 0,
    'OCLAIR': 0,
    'OCLAIRE': 0,
    'OCOIN': 0,
    'OCON': 0,
    'OCONELL': 0,
    'OCONNELL': 0,
    'OCONNER': 0,
    'OCONNOR': 0,
    'OCONNORS': 0,
    'OCONOR': 0,
    'OCTAVE': 0,
    'OCTAVIA': 1,
    'OCTAVIANO': 0,
    'OCTAVIO': 0.9937888198757764,
    'OCTAVO': 0,
    'OCTOBER': 0,
    'OCULL': 0,
    'OCZKOWSKI': 0,
    'ODA': 0.6060606060606061,
    'ODABASHIAN': 0,
    'ODACHOWSKI': 0,
    'ODAFFER': 0,
    'ODAM': 0,
    'ODANIEL': 0,
    'ODANIELL': 0,
    'ODANIELS': 0,
    'ODAR': 0,
    'ODAY': 0,
    'ODD': 0,
    'ODDEN': 0,
    'ODDI': 0,
    'ODDIE': 0,
    'ODDO': 0,
    'ODDY': 0,
    'ODE': 0,
    'ODEA': 0,
    'ODEAN': 0,
    'ODEAR': 0,
    'ODEE': 0,
    'ODEEN': 0,
    'ODEGAARD': 0,
    'ODEGARD': 0,
    'ODEH': 0,
    'ODEHNAL': 0,
    'ODEKIRK': 0,
    'ODEL': 0,
    'ODELIA': 1,
    'ODELL': 0.5312627707396812,
    'ODEM': 0,
    'ODEMS': 0,
    'ODEN': 0,
    'ODENBACH': 0,
    'ODENBAUGH': 0,
    'ODENBRETT': 0,
    'ODENDAHL': 0,
    'ODENEAL': 0,
    'ODENHEIMER': 0,
    'ODENS': 0,
    'ODENTHAL': 0,
    'ODENWALD': 0,
    'ODENWELDER': 0,
    'ODENWELLER': 0,
    'ODER': 0,
    'ODERKIRK': 0,
    'ODERMANN': 0,
    'ODERMATT': 0,
    'ODESSA': 1,
    'ODETT': 0,
    'ODETTE': 0.9009009009009008,
    'ODEY': 0,
    'ODGEN': 0,
    'ODGERS': 0,
    'ODHAM': 0,
    'ODHNER': 0,
    'ODIE': 0,
    'ODIERNA': 0,
    'ODIERNO': 0,
    'ODILIA': 1,
    'ODIN': 0,
    'ODIO': 0,
    'ODIORNE': 0,
    'ODIS': 1,
    'ODISH': 0,
    'ODISHO': 0,
    'ODISHOO': 0,
    'ODLAND': 0,
    'ODLE': 0,
    'ODLUM': 0,
    'ODMAN': 0,
    'ODMARK': 0,
    'ODNEAL': 0,
    'ODO': 0,
    'ODOHERTY': 0,
    'ODOM': 0,
    'ODOMS': 0,
    'ODON': 0,
    'ODONAHUE': 0,
    'ODONAL': 0,
    'ODONALD': 0,
    'ODONELL': 0,
    'ODONLEY': 0,
    'ODONNAL': 0,
    'ODONNEL': 0,
    'ODONNELL': 0,
    'ODONOGHUE': 0,
    'ODONOHOE': 0,
    'ODONOHUE': 0,
    'ODONOVAN': 0,
    'ODOR': 0,
    'ODORISIO': 0,
    'ODORIZZI': 0,
    'ODOUGHERTY': 0,
    'ODOWD': 0,
    'ODRISCOLL': 0,
    'ODULIO': 0,
    'ODUM': 0,
    'ODUMS': 0,
    'ODURO': 0,
    'ODWYER': 0,
    'ODY': 0,
    'OE': 0,
    'OECHSLE': 0,
    'OECHSNER': 0,
    'OEDER': 0,
    'OEDING': 0,
    'OEFELEIN': 0,
    'OEFINGER': 0,
    'OEHL': 0,
    'OEHLER': 0,
    'OEHLERKING': 0,
    'OEHLERS': 0,
    'OEHLERT': 0,
    'OEHLING': 0,
    'OEHLKE': 0,
    'OEHM': 0,
    'OEHME': 0,
    'OEHMEN': 0,
    'OEHMKE': 0,
    'OEHRING': 0,
    'OEHRLE': 0,
    'OEHRLEIN': 0,
    'OEI': 0,
    'OELBAUM': 0,
    'OELERICH': 0,
    'OELFKE': 0,
    'OELHAFEN': 0,
    'OELKE': 0,
    'OELKERS': 0,
    'OELLERICH': 0,
    'OELMANN': 0,
    'OELRICH': 0,
    'OELSCHLAEGER': 0,
    'OELSCHLAGER': 0,
    'OELTJEN': 0,
    'OELTJENBRUNS': 0,
    'OELZE': 0,
    'OEMIG': 0,
    'OEN': 0,
    'OERMAN': 0,
    'OERTEL': 0,
    'OERTER': 0,
    'OERTHER': 0,
    'OERTLE': 0,
    'OERTLI': 0,
    'OERTWIG': 0,
    'OESCH': 0,
    'OESCHGER': 0,
    'OESER': 0,
    'OEST': 0,
    'OESTER': 0,
    'OESTERLE': 0,
    'OESTERLING': 0,
    'OESTERREICH': 0,
    'OESTERREICHER': 0,
    'OESTMANN': 0,
    'OESTREICH': 0,
    'OESTREICHER': 0,
    'OETH': 0,
    'OETINGER': 0,
    'OETJEN': 0,
    'OETKEN': 0,
    'OETKER': 0,
    'OETMAN': 0,
    'OETTEL': 0,
    'OETTER': 0,
    'OETTING': 0,
    'OETTINGER': 0,
    'OETTLE': 0,
    'OETZEL': 0,
    'OEUN': 0,
    'OEUR': 0,
    'OEY': 0,
    'OFALLON': 0,
    'OFARRELL': 0,
    'OFARRILL': 0,
    'OFELIA': 1,
    'OFENLOCH': 0,
    'OFERRALL': 0,
    'OFERRELL': 0,
    'OFF': 0,
    'OFFEN': 0,
    'OFFENBACH': 0,
    'OFFENBACHER': 0,
    'OFFENBACKER': 0,
    'OFFENBECHER': 0,
    'OFFENBERG': 0,
    'OFFENBERGER': 0,
    'OFFENBURGER': 0,
    'OFFER': 0,
    'OFFERDAHL': 0,
    'OFFERLE': 0,
    'OFFERMAN': 0,
    'OFFERMANN': 0,
    'OFFHAUS': 0,
    'OFFICE': 0,
    'OFFICER': 0,
    'OFFIELD': 0,
    'OFFILL': 0,
    'OFFLEY': 0,
    'OFFMAN': 0,
    'OFFNER': 0,
    'OFFOR': 0,
    'OFFORD': 0,
    'OFFRET': 0,
    'OFFRINGA': 0,
    'OFFUTT': 0,
    'OFIARA': 0,
    'OFIELD': 0,
    'OFLAHERTY': 0,
    'OFLANAGAN': 0,
    'OFLYNN': 0,
    'OFMAN': 0,
    'OFNER': 0,
    'OFORI': 0,
    'OFOSU': 0,
    'OFRAY': 0,
    'OFRIA': 0,
    'OFRIEL': 0,
    'OFSTAD': 0,
    'OFSTHUN': 0,
    'OFTEDAHL': 0,
    'OFTEDAL': 0,
    'OGA': 0,
    'OGAARD': 0,
    'OGALDEZ': 0,
    'OGAN': 0,
    'OGANDO': 0,
    'OGANESIAN': 0,
    'OGANESYAN': 0,
    'OGANS': 0,
    'OGANYAN': 0,
    'OGAR': 0,
    'OGARA': 0,
    'OGARD': 0,
    'OGARRO': 0,
    'OGAS': 0,
    'OGASAWARA': 0,
    'OGATA': 0,
    'OGAWA': 0,
    'OGAZ': 0,
    'OGBEBOR': 0,
    'OGBEIDE': 0,
    'OGBONNA': 0,
    'OGBONNAYA': 0,
    'OGBORN': 0,
    'OGBURN': 0,
    'OGDAHL': 0,
    'OGDEN': 0,
    'OGDON': 0,
    'OGE': 0,
    'OGEA': 0,
    'OGEDA': 0,
    'OGEEN': 0,
    'OGELSBY': 0,
    'OGER': 0,
    'OGG': 0,
    'OGGS': 0,
    'OGI': 0,
    'OGIBA': 0,
    'OGIE': 0,
    'OGIER': 0,
    'OGILBEE': 0,
    'OGILBY': 0,
    'OGILVIE': 0,
    'OGILVY': 0,
    'OGIN': 0,
    'OGINO': 0,
    'OGINSKI': 0,
    'OGINSKY': 0,
    'OGLE': 0,
    'OGLES': 0,
    'OGLESBEE': 0,
    'OGLESBY': 0,
    'OGLETREE': 0,
    'OGLEVIE': 0,
    'OGLINE': 0,
    'OGNIBENE': 0,
    'OGO': 0,
    'OGONOWSKI': 0,
    'OGOREK': 0,
    'OGORMAN': 0,
    'OGORZALEK': 0,
    'OGOZALY': 0,
    'OGRADY': 0,
    'OGRAM': 0,
    'OGREEN': 0,
    'OGREN': 0,
    'OGRIN': 0,
    'OGRINC': 0,
    'OGRODNICK': 0,
    'OGRODNIK': 0,
    'OGRODNY': 0,
    'OGRODOWSKI': 0,
    'OGSTON': 0,
    'OGU': 0,
    'OGUENDO': 0,
    'OGUIN': 0,
    'OGUINN': 0,
    'OGUN': 0,
    'OGUNDIPE': 0,
    'OGUNLEYE': 0,
    'OGUNSANYA': 0,
    'OGUNYEMI': 0,
    'OGURA': 0,
    'OGUREK': 0,
    'OGUZ': 0,
    'OGWIN': 0,
    'OGWYNN': 0,
    'OH': 0,
    'OHAGAN': 0,
    'OHAIR': 0,
    'OHAIRE': 0,
    'OHALLORAN': 0,
    'OHAMA': 0,
    'OHAN': 0,
    'OHANA': 0,
    'OHANDLEY': 0,
    'OHANESIAN': 0,
    'OHANESSIAN': 0,
    'OHANIAN': 0,
    'OHANLEY': 0,
    'OHANLON': 0,
    'OHANNESIAN': 0,
    'OHANNESSIAN': 0,
    'OHAR': 0,
    'OHARA': 0,
    'OHARE': 0,
    'OHARRA': 0,
    'OHARROW': 0,
    'OHASHI': 0,
    'OHATA': 0,
    'OHAVER': 0,
    'OHAYON': 0,
    'OHAYRE': 0,
    'OHDE': 0,
    'OHE': 0,
    'OHEA': 0,
    'OHEARN': 0,
    'OHEARNE': 0,
    'OHEHIR': 0,
    'OHEIR': 0,
    'OHERN': 0,
    'OHERON': 0,
    'OHERRON': 0,
    'OHIGGINS': 0,
    'OHIRA': 0,
    'OHL': 0,
    'OHLAND': 0,
    'OHLANDT': 0,
    'OHLDE': 0,
    'OHLE': 0,
    'OHLEMACHER': 0,
    'OHLEN': 0,
    'OHLENDORF': 0,
    'OHLER': 0,
    'OHLERT': 0,
    'OHLHAUSEN': 0,
    'OHLHAUSER': 0,
    'OHLIGER': 0,
    'OHLIN': 0,
    'OHLINGER': 0,
    'OHLMAN': 0,
    'OHLMANN': 0,
    'OHLMS': 0,
    'OHLRICH': 0,
    'OHLROGGE': 0,
    'OHLS': 0,
    'OHLSEN': 0,
    'OHLSON': 0,
    'OHLSSON': 0,
    'OHLUND': 0,
    'OHLY': 0,
    'OHM': 0,
    'OHMAN': 0,
    'OHMANN': 0,
    'OHMART': 0,
    'OHME': 0,
    'OHMER': 0,
    'OHMES': 0,
    'OHMS': 0,
    'OHMSTEDE': 0,
    'OHNECK': 0,
    'OHNEMUS': 0,
    'OHNESORGE': 0,
    'OHNMACHT': 0,
    'OHNMEISS': 0,
    'OHNO': 0,
    'OHNSTAD': 0,
    'OHORA': 0,
    'OHORO': 0,
    'OHOTTO': 0,
    'OHR': 0,
    'OHREN': 0,
    'OHRENBERGER': 0,
    'OHRI': 0,
    'OHRMAN': 0,
    'OHRN': 0,
    'OHRT': 0,
    'OHRTMAN': 0,
    'OHS': 0,
    'OHSE': 0,
    'OHTA': 0,
    'OI': 0,
    'OIE': 0,
    'OIEN': 0,
    'OILAR': 0,
    'OILER': 0,
    'OINEAL': 0,
    'OINEIL': 0,
    'OISHI': 0,
    'OISTEN': 0,
    'OJA': 0,
    'OJALA': 0,
    'OJANEN': 0,
    'OJEA': 0,
    'OJEDA': 0,
    'OJHA': 0,
    'OJI': 0,
    'OJIBWAY': 0,
    'OJINAGA': 0,
    'OJO': 0,
    'OJUKWU': 0,
    'OK': 0.9259259259259258,
    'OKA': 0,
    'OKABAYASHI': 0,
    'OKABE': 0,
    'OKADA': 0,
    'OKAFOR': 0,
    'OKAI': 0,
    'OKAIN': 0,
    'OKAJIMA': 0,
    'OKAL': 0,
    'OKAMOTO': 0,
    'OKAMURA': 0,
    'OKANE': 0,
    'OKANO': 0,
    'OKANOVIC': 0,
    'OKARMA': 0,
    'OKAWA': 0,
    'OKAY': 0,
    'OKAYAMA': 0,
    'OKAZAKI': 0,
    'OKE': 0,
    'OKECHUKWU': 0,
    'OKEEFE': 0,
    'OKEEFFE': 0,
    'OKEKE': 0,
    'OKEL': 0,
    'OKELBERRY': 0,
    'OKELLEY': 0,
    'OKELLY': 0,
    'OKEN': 0,
    'OKER': 0,
    'OKERE': 0,
    'OKEREKE': 0,
    'OKERLUND': 0,
    'OKERMAN': 0,
    'OKERSON': 0,
    'OKERSTROM': 0,
    'OKERT': 0,
    'OKES': 0,
    'OKESON': 0,
    'OKEY': 0,
    'OKEZIE': 0,
    'OKI': 0,
    'OKIE': 0,
    'OKIMOTO': 0,
    'OKIMURA': 0,
    'OKIN': 0,
    'OKINAKA': 0,
    'OKINE': 0,
    'OKINO': 0,
    'OKINS': 0,
    'OKITA': 0,
    'OKKEN': 0,
    'OKLAND': 0,
    'OKO': 0,
    'OKOCHA': 0,
    'OKOH': 0,
    'OKOJIE': 0,
    'OKOLI': 0,
    'OKOLIE': 0,
    'OKOLO': 0,
    'OKON': 0,
    'OKONEK': 0,
    'OKONIEWSKI': 0,
    'OKONKWO': 0,
    'OKONSKI': 0,
    'OKORIE': 0,
    'OKORN': 0,
    'OKORO': 0,
    'OKORONKWO': 0,
    'OKOYE': 0,
    'OKPALA': 0,
    'OKPARA': 0,
    'OKRASINSKI': 0,
    'OKRAY': 0,
    'OKRENT': 0,
    'OKRZESIK': 0,
    'OKS': 0,
    'OKSANEN': 0,
    'OKTAVEC': 0,
    'OKTAY': 0,
    'OKU': 0,
    'OKUBO': 0,
    'OKUDA': 0,
    'OKUHARA': 0,
    'OKULA': 0,
    'OKULEY': 0,
    'OKULY': 0,
    'OKUM': 0,
    'OKUMA': 0,
    'OKUMOTO': 0,
    'OKUMURA': 0,
    'OKUN': 0,
    'OKUNO': 0,
    'OKURA': 0,
    'OKUYAMA': 0,
    'OKYERE': 0,
    'OL': 0,
    'OLA': 0.9925558312655086,
    'OLACHEA': 0,
    'OLACK': 0,
    'OLADAPO': 0,
    'OLADIPO': 0,
    'OLAECHEA': 0,
    'OLAES': 0,
    'OLAFSEN': 0,
    'OLAFSON': 0,
    'OLAFSSON': 0,
    'OLAGUE': 0,
    'OLAGUEZ': 0,
    'OLAH': 0,
    'OLAIS': 0,
    'OLAIZ': 0,
    'OLALDE': 0,
    'OLALEYE': 0,
    'OLAN': 0,
    'OLAND': 0,
    'OLANDER': 0,
    'OLANDESE': 0,
    'OLANIYAN': 0,
    'OLANNA': 0,
    'OLANO': 0,
    'OLAR': 0,
    'OLARI': 0,
    'OLARTE': 0,
    'OLAS': 0,
    'OLASCOAGA': 0,
    'OLASO': 0,
    'OLASON': 0,
    'OLATUNJI': 0,
    'OLAUGHLIN': 0,
    'OLAVARRIA': 0,
    'OLAVARRIETA': 0,
    'OLAVE': 0,
    'OLAVESON': 0,
    'OLAY': 0,
    'OLAYA': 0,
    'OLAYINKA': 0,
    'OLAYO': 0,
    'OLAZABA': 0,
    'OLAZABAL': 0,
    'OLBERA': 0,
    'OLBERDING': 0,
    'OLBERG': 0,
    'OLBERT': 0,
    'OLBRANTZ': 0,
    'OLBRICH': 0,
    'OLBRYCH': 0,
    'OLBRYS': 0,
    'OLCESE': 0,
    'OLCOTT': 0,
    'OLCZAK': 0,
    'OLD': 0,
    'OLDACH': 0,
    'OLDACRE': 0,
    'OLDAG': 0,
    'OLDAK': 0,
    'OLDAKER': 0,
    'OLDAKOWSKI': 0,
    'OLDANI': 0,
    'OLDAY': 0,
    'OLDEN': 0,
    'OLDENBERG': 0,
    'OLDENBURG': 0,
    'OLDENBURGER': 0,
    'OLDENDORF': 0,
    'OLDENKAMP': 0,
    'OLDER': 0,
    'OLDERMAN': 0,
    'OLDERSHAW': 0,
    'OLDFATHER': 0,
    'OLDFIELD': 0,
    'OLDFORD': 0,
    'OLDHAM': 0,
    'OLDIGES': 0,
    'OLDING': 0,
    'OLDLAND': 0,
    'OLDMAN': 0,
    'OLDMIXON': 0,
    'OLDNER': 0,
    'OLDRIDGE': 0,
    'OLDROYD': 0,
    'OLDS': 0,
    'OLDSON': 0,
    'OLDT': 0,
    'OLE': 0,
    'OLEA': 0,
    'OLEAGA': 0,
    'OLEAN': 0,
    'OLEAR': 0,
    'OLEARY': 0,
    'OLECH': 0,
    'OLECHNOWICZ': 0,
    'OLECHOWSKI': 0,
    'OLECK': 0,
    'OLECKI': 0,
    'OLEEN': 0,
    'OLEGARIO': 0,
    'OLEINIK': 0,
    'OLEJAR': 0,
    'OLEJARCZYK': 0,
    'OLEJARZ': 0,
    'OLEJNICZAK': 0,
    'OLEJNIK': 0,
    'OLEK': 0,
    'OLEKSA': 0,
    'OLEKSAK': 0,
    'OLEKSIAK': 0,
    'OLEKSIK': 0,
    'OLEKSY': 0,
    'OLEMAN': 0,
    'OLEN': 0.9363295880149812,
    'OLENA': 0,
    'OLENDER': 0,
    'OLENE': 1,
    'OLENIACZ': 0,
    'OLENICK': 0,
    'OLENICZAK': 0,
    'OLENIK': 0,
    'OLENSKI': 0,
    'OLER': 0,
    'OLERICH': 0,
    'OLERUD': 0,
    'OLES': 0,
    'OLESEN': 0,
    'OLESH': 0,
    'OLESIAK': 0,
    'OLESINSKI': 0,
    'OLESKA': 0,
    'OLESKE': 0,
    'OLESKI': 0,
    'OLESKO': 0,
    'OLESKY': 0,
    'OLESON': 0,
    'OLESZCZUK': 0,
    'OLESZKOWICZ': 0,
    'OLETA': 1,
    'OLEVIA': 1,
    'OLEWILER': 0,
    'OLEWINE': 0,
    'OLEWINSKI': 0,
    'OLEWNIK': 0,
    'OLEXA': 0,
    'OLEXY': 0,
    'OLEY': 0,
    'OLEYAR': 0,
    'OLEYNIK': 0,
    'OLFERS': 0,
    'OLFERT': 0,
    'OLGA': 0.9992862241256246,
    'OLGER': 0,
    'OLGIN': 0,
    'OLGREN': 0,
    'OLGUIN': 0,
    'OLHAUSEN': 0,
    'OLHEISER': 0,
    'OLI': 0,
    'OLIAN': 0,
    'OLIBRICE': 0,
    'OLICK': 0,
    'OLIDE': 0,
    'OLIDEN': 0,
    'OLIEN': 0,
    'OLIER': 0,
    'OLIFF': 0,
    'OLIG': 0,
    'OLIGER': 0,
    'OLIGMUELLER': 0,
    'OLIGNEY': 0,
    'OLIGSCHLAEGER': 0,
    'OLIJNYK': 0,
    'OLIMPIA': 1,
    'OLIMPIO': 0,
    'OLIMPO': 0,
    'OLIN': 0.79155672823219,
    'OLINDA': 1,
    'OLINDE': 0,
    'OLINE': 0,
    'OLINER': 0,
    'OLINGER': 0,
    'OLINGHOUSE': 0,
    'OLINICK': 0,
    'OLINSKI': 0,
    'OLINSKY': 0,
    'OLIPHANT': 0,
    'OLIPHINT': 0,
    'OLIS': 0,
    'OLISON': 0,
    'OLITA': 0,
    'OLITSKY': 0,
    'OLIVA': 0.35211267605633806,
    'OLIVAN': 0,
    'OLIVAR': 0,
    'OLIVARES': 0,
    'OLIVAREZ': 0,
    'OLIVARI': 0,
    'OLIVARRI': 0,
    'OLIVARRIA': 0,
    'OLIVAS': 0,
    'OLIVE': 0.9351620947630922,
    'OLIVEAUX': 0,
    'OLIVEIRA': 0,
    'OLIVELLA': 0,
    'OLIVENCIA': 0,
    'OLIVER': 0.4915212582944212,
    'OLIVERA': 0,
    'OLIVERAS': 0,
    'OLIVERE': 0,
    'OLIVEREZ': 0,
    'OLIVERI': 0,
    'OLIVERIA': 0,
    'OLIVERIO': 0,
    'OLIVERIUS': 0,
    'OLIVERO': 0,
    'OLIVEROS': 0,
    'OLIVERSON': 0,
    'OLIVES': 0,
    'OLIVET': 0,
    'OLIVETO': 0,
    'OLIVETTI': 0,
    'OLIVI': 0,
    'OLIVIA': 0.9963399755998372,
    'OLIVIER': 0,
    'OLIVIERA': 0,
    'OLIVIERI': 0,
    'OLIVIERO': 0,
    'OLIVIO': 0,
    'OLIVITO': 0,
    'OLIVO': 0,
    'OLIVOS': 0,
    'OLK': 0,
    'OLKEN': 0,
    'OLKER': 0,
    'OLKO': 0,
    'OLKOWSKI': 0,
    'OLLA': 0,
    'OLLAR': 0,
    'OLLE': 0,
    'OLLENBURG': 0,
    'OLLENDICK': 0,
    'OLLER': 0,
    'OLLERTON': 0,
    'OLLERVIDES': 0,
    'OLLES': 0,
    'OLLEY': 0,
    'OLLHOFF': 0,
    'OLLI': 0,
    'OLLIE': 0.9882478632478633,
    'OLLIER': 0,
    'OLLIFF': 0,
    'OLLIGES': 0,
    'OLLILA': 0,
    'OLLINGER': 0,
    'OLLIS': 0,
    'OLLISON': 0,
    'OLLIVER': 0,
    'OLLIVIER': 0,
    'OLLIVIERRE': 0,
    'OLLMAN': 0,
    'OLLMANN': 0,
    'OLLOM': 0,
    'OLLOQUI': 0,
    'OLM': 0,
    'OLMAN': 0,
    'OLMEDA': 0,
    'OLMEDO': 0,
    'OLMER': 0,
    'OLMO': 0,
    'OLMOS': 0,
    'OLMS': 0,
    'OLMSCHEID': 0,
    'OLMSTEAD': 0,
    'OLMSTED': 0,
    'OLNESS': 0,
    'OLNEY': 0,
    'OLNICK': 0,
    'OLOFF': 0,
    'OLOFSON': 0,
    'OLOFSSON': 0,
    'OLOMON': 0,
    'OLONA': 0,
    'OLONE': 0,
    'OLORTEGUI': 0,
    'OLOUGHLIN': 0,
    'OLOYEDE': 0,
    'OLP': 0,
    'OLPIN': 0,
    'OLQUIN': 0,
    'OLREE': 0,
    'OLRICH': 0,
    'OLS': 0,
    'OLSAN': 0,
    'OLSAVSKY': 0,
    'OLSCHEWSKI': 0,
    'OLSEM': 0,
    'OLSEN': 0,
    'OLSHAN': 0,
    'OLSHANSKY': 0,
    'OLSHEFSKI': 0,
    'OLSHEFSKY': 0,
    'OLSHOVE': 0,
    'OLSON': 0,
    'OLSOVSKY': 0,
    'OLSSON': 0,
    'OLSTAD': 0,
    'OLSTEIN': 0,
    'OLSTEN': 0,
    'OLSTER': 0,
    'OLSTON': 0,
    'OLSZAK': 0,
    'OLSZANSKI': 0,
    'OLSZEWSKI': 0,
    'OLSZOWKA': 0,
    'OLSZOWY': 0,
    'OLSZYK': 0,
    'OLT': 0,
    'OLTEAN': 0,
    'OLTHOF': 0,
    'OLTHOFF': 0,
    'OLTJENBRUNS': 0,
    'OLTMAN': 0,
    'OLTMANN': 0,
    'OLTMANNS': 0,
    'OLTMANS': 0,
    'OLTON': 0,
    'OLTROGGE': 0,
    'OLTZ': 0,
    'OLUFSON': 0,
    'OLUND': 0,
    'OLUWOLE': 0,
    'OLVEDA': 0,
    'OLVER': 0,
    'OLVERA': 0,
    'OLVERSON': 0,
    'OLVEY': 0,
    'OLWELL': 0,
    'OLWIN': 0,
    'OLYMPIA': 0.9803921568627452,
    'OLYNICK': 0,
    'OLYNYK': 0,
    'OLZAK': 0,
    'OM': 0,
    'OMA': 1,
    'OMAHEN': 0,
    'OMAHONEY': 0,
    'OMAHONY': 0,
    'OMALEY': 0,
    'OMALIA': 0,
    'OMALLEY': 0,
    'OMALLY': 0,
    'OMAN': 0,
    'OMANA': 0,
    'OMANN': 0,
    'OMANOVIC': 0,
    'OMANS': 0,
    'OMAR': 0.9587217043941412,
    'OMARA': 0,
    'OMARI': 0,
    'OMARRA': 0,
    'OMARY': 0,
    'OMASTA': 0,
    'OMBERG': 0,
    'OMDAHL': 0,
    'OMEALLY': 0,
    'OMEARA': 0,
    'OMEGA': 0.9615384615384616,
    'OMELIA': 0,
    'OMEN': 0,
    'OMER': 0.9057971014492754,
    'OMERA': 0,
    'OMERAGIC': 0,
    'OMERNIK': 0,
    'OMEROVIC': 0,
    'OMERZA': 0,
    'OMEY': 0,
    'OMI': 0,
    'OMIECINSKI': 0,
    'OMIYA': 0,
    'OMLAND': 0,
    'OMLID': 0,
    'OMLIN': 0,
    'OMLOR': 0,
    'OMMEN': 0,
    'OMMERT': 0,
    'OMO': 0,
    'OMODT': 0,
    'OMOHUNDRO': 0,
    'OMOREGIE': 0,
    'OMORI': 0,
    'OMORUYI': 0,
    'OMOTO': 0,
    'OMPS': 0,
    'OMRAN': 0,
    'OMS': 0,
    'OMSBERG': 0,
    'OMSTEAD': 0,
    'OMTVEDT': 0,
    'OMUNDSON': 0,
    'OMURA': 0,
    'OMVIG': 0,
    'ON': 0,
    'ONA': 0.9727626459143969,
    'ONAGA': 0,
    'ONAK': 0,
    'ONAKA': 0,
    'ONAL': 0,
    'ONAN': 0,
    'ONASCH': 0,
    'ONATE': 0,
    'ONCALE': 0,
    'ONCKEN': 0,
    'ONDA': 0,
    'ONDARZA': 0,
    'ONDECK': 0,
    'ONDEK': 0,
    'ONDER': 0,
    'ONDERDONK': 0,
    'ONDERKO': 0,
    'ONDERSMA': 0,
    'ONDICH': 0,
    'ONDIK': 0,
    'ONDISH': 0,
    'ONDO': 0,
    'ONDRA': 0,
    'ONDRACEK': 0,
    'ONDRAKO': 0,
    'ONDRAS': 0,
    'ONDRASEK': 0,
    'ONDREJKA': 0,
    'ONDREJKO': 0,
    'ONDREY': 0,
    'ONDRICK': 0,
    'ONDRIEZEK': 0,
    'ONDRUS': 0,
    'ONDRUSEK': 0,
    'ONEAIL': 0,
    'ONEAL': 0,
    'ONEALE': 0,
    'ONEALL': 0,
    'ONEEL': 0,
    'ONEIDA': 0.9803921568627452,
    'ONEIL': 0,
    'ONEILL': 0,
    'ONELL': 0,
    'ONER': 0,
    'ONES': 0,
    'ONESKO': 0,
    'ONESTI': 0,
    'ONESTO': 0,
    'ONETO': 0,
    'ONEY': 0,
    'ONG': 0,
    'ONGARO': 0,
    'ONGLEY': 0,
    'ONI': 0,
    'ONIE': 1,
    'ONIEL': 0,
    'ONIELL': 0,
    'ONIFER': 0,
    'ONIK': 0,
    'ONION': 0,
    'ONIONS': 0,
    'ONISHCHENKO': 0,
    'ONISHI': 0,
    'ONISKO': 0,
    'ONITA': 1,
    'ONIZUKA': 0,
    'ONKEN': 0,
    'ONKKA': 0,
    'ONKS': 0,
    'ONKST': 0,
    'ONLEY': 0,
    'ONLY': 0,
    'ONN': 0,
    'ONNEN': 0,
    'ONO': 0,
    'ONODA': 0,
    'ONODERA': 0,
    'ONOFRE': 0,
    'ONOFREY': 0,
    'ONOFRIO': 0,
    'ONOPA': 0,
    'ONORATI': 0,
    'ONORATO': 0,
    'ONORI': 0,
    'ONSAGER': 0,
    'ONSGARD': 0,
    'ONSRUD': 0,
    'ONSTAD': 0,
    'ONSTEAD': 0,
    'ONSTOT': 0,
    'ONSTOTT': 0,
    'ONSUREZ': 0,
    'ONTAI': 0,
    'ONTANEDA': 0,
    'ONTHANK': 0,
    'ONTIBEROS': 0,
    'ONTIS': 0,
    'ONTIVERO': 0,
    'ONTIVEROS': 0,
    'ONTIVEROZ': 0,
    'ONTJES': 0,
    'ONTKO': 0,
    'ONUFER': 0,
    'ONUFRAK': 0,
    'ONUMA': 0,
    'ONUOHA': 0,
    'ONUSCHAK': 0,
    'ONUSKA': 0,
    'ONUSKO': 0,
    'ONWELLER': 0,
    'ONWUKA': 0,
    'ONYANGO': 0,
    'ONYEKWERE': 0,
    'ONYETT': 0,
    'ONYIA': 0,
    'OO': 0,
    'OOI': 0,
    'OOKA': 0,
    'OOLEY': 0,
    'OOM': 0,
    'OOMMEN': 0,
    'OOMS': 0,
    'OONK': 0,
    'OOST': 0,
    'OOSTDYK': 0,
    'OOSTENDORP': 0,
    'OOSTERBAAN': 0,
    'OOSTERHOUSE': 0,
    'OOSTERMAN': 0,
    'OOSTING': 0,
    'OOSTRA': 0,
    'OOT': 0,
    'OOTEN': 0,
    'OOTHOUDT': 0,
    'OOTON': 0,
    'OPACIC': 0,
    'OPAL': 0.9972078181092939,
    'OPALA': 0,
    'OPALACH': 0,
    'OPALENIK': 0,
    'OPALEWSKI': 0,
    'OPALINSKI': 0,
    'OPALKA': 0,
    'OPALKO': 0,
    'OPARA': 0,
    'OPARKA': 0,
    'OPAROWSKI': 0,
    'OPAT': 0,
    'OPATRNY': 0,
    'OPATZ': 0,
    'OPBROEK': 0,
    'OPDAHL': 0,
    'OPDYCKE': 0,
    'OPDYKE': 0,
    'OPEKA': 0,
    'OPEL': 0,
    'OPELA': 0,
    'OPELL': 0,
    'OPELLA': 0,
    'OPELT': 0,
    'OPENA': 0,
    'OPENSHAW': 0,
    'OPFAR': 0,
    'OPFER': 0,
    'OPFERMAN': 0,
    'OPFERMANN': 0,
    'OPGENORTH': 0,
    'OPHEIKENS': 0,
    'OPHEIM': 0,
    'OPHELIA': 1,
    'OPHER': 0,
    'OPHUS': 0,
    'OPICHKA': 0,
    'OPIE': 0,
    'OPIELA': 0,
    'OPILA': 0,
    'OPIO': 0,
    'OPIOLA': 0,
    'OPITZ': 0,
    'OPLAND': 0,
    'OPLIGER': 0,
    'OPLINGER': 0,
    'OPOKA': 0,
    'OPOKU': 0,
    'OPOLKA': 0,
    'OPOLSKI': 0,
    'OPORTA': 0,
    'OPORTO': 0,
    'OPP': 0,
    'OPPEDAHL': 0,
    'OPPEDAL': 0,
    'OPPEDISANO': 0,
    'OPPEGAARD': 0,
    'OPPEGARD': 0,
    'OPPEL': 0,
    'OPPELT': 0,
    'OPPEN': 0,
    'OPPENHEIM': 0,
    'OPPENHEIMER': 0,
    'OPPENHUIZEN': 0,
    'OPPENLANDER': 0,
    'OPPER': 0,
    'OPPERMAN': 0,
    'OPPERMANN': 0,
    'OPPERUD': 0,
    'OPPIE': 0,
    'OPPLIGER': 0,
    'OPPMAN': 0,
    'OPPOLD': 0,
    'OPPONG': 0,
    'OPPY': 0,
    'OPRE': 0,
    'OPREA': 0,
    'OPREAN': 0,
    'OPRIS': 0,
    'OPRY': 0,
    'OPSAHL': 0,
    'OPSAL': 0,
    'OPSTAD': 0,
    'OQUAIN': 0,
    'OQUENDO': 0,
    'OQUIN': 0,
    'OQUINN': 0,
    'OQUIST': 0,
    'OR': 0,
    'ORA': 0.9974141115626154,
    'ORABONA': 0,
    'ORABUENA': 0,
    'ORACION': 0,
    'ORAHA': 0,
    'ORAHOOD': 0,
    'ORALEE': 1,
    'ORALIA': 1,
    'ORALLO': 0,
    'ORAM': 0,
    'ORAMA': 0,
    'ORAMAS': 0,
    'ORAN': 0,
    'ORAND': 0,
    'ORANDAY': 0,
    'ORANGE': 0,
    'ORANSKY': 0,
    'ORANTE': 0,
    'ORANTES': 0,
    'ORANTEZ': 0,
    'ORASCO': 0,
    'ORAVEC': 0,
    'ORAVECZ': 0,
    'ORAVETZ': 0,
    'ORAVITZ': 0,
    'ORAVSKY': 0,
    'ORAWIEC': 0,
    'ORAZEM': 0,
    'ORAZI': 0,
    'ORAZIO': 0,
    'ORBACH': 0,
    'ORBAKER': 0,
    'ORBAN': 0,
    'ORBE': 0,
    'ORBECK': 0,
    'ORBEGOSO': 0,
    'ORBEN': 0,
    'ORBERSON': 0,
    'ORBIN': 0,
    'ORBISON': 0,
    'ORBON': 0,
    'ORCASITAS': 0,
    'ORCHANIAN': 0,
    'ORCHARD': 0,
    'ORCHOLSKI': 0,
    'ORCHOWSKI': 0,
    'ORCINO': 0,
    'ORCUTT': 0,
    'ORD': 0,
    'ORDAHL': 0,
    'ORDAKOWSKI': 0,
    'ORDAL': 0,
    'ORDAS': 0,
    'ORDAZ': 0,
    'ORDE': 0,
    'ORDEMANN': 0,
    'ORDEN': 0,
    'ORDENANA': 0,
    'ORDERS': 0,
    'ORDILLE': 0,
    'ORDINARIO': 0,
    'ORDING': 0,
    'ORDINOLA': 0,
    'ORDIWAY': 0,
    'ORDNER': 0,
    'ORDOGNE': 0,
    'ORDON': 0,
    'ORDONA': 0,
    'ORDONE': 0,
    'ORDONES': 0,
    'ORDONEZ': 0,
    'ORDONIA': 0,
    'ORDONIO': 0,
    'ORDONO': 0,
    'ORDORICA': 0,
    'ORDOYNE': 0,
    'ORDUNA': 0,
    'ORDUNEZ': 0,
    'ORDUNO': 0,
    'ORDWAY': 0,
    'ORE': 0,
    'OREA': 0,
    'OREAGAN': 0,
    'OREAR': 0,
    'OREBAUGH': 0,
    'ORECCHIO': 0,
    'OREE': 0,
    'OREFICE': 0,
    'OREGAN': 0,
    'OREGEL': 0,
    'OREGON': 0,
    'OREHEK': 0,
    'OREILLEY': 0,
    'OREILLY': 0,
    'OREJEL': 0,
    'OREJUELA': 0,
    'OREL': 0,
    'ORELIEN': 0,
    'ORELL': 0,
    'ORELLA': 0,
    'ORELLANA': 0,
    'ORELLANO': 0,
    'ORELUS': 0,
    'OREM': 0,
    'OREMUS': 0,
    'OREN': 0.8912655971479501,
    'ORENA': 0,
    'ORENCIA': 0,
    'ORENDAIN': 0,
    'ORENDAY': 0,
    'ORENDER': 0,
    'ORENDORF': 0,
    'ORENDORFF': 0,
    'ORENGO': 0,
    'ORENS': 0,
    'ORENSTEIN': 0,
    'ORENT': 0,
    'ORES': 0,
    'ORESKOVICH': 0,
    'ORESTE': 0,
    'ORETHA': 1,
    'OREWILER': 0,
    'OREY': 0,
    'ORF': 0,
    'ORFANOS': 0,
    'ORFE': 0,
    'ORFF': 0,
    'ORFIELD': 0,
    'ORFORD': 0,
    'ORGAIN': 0,
    'ORGAN': 0,
    'ORGANEK': 0,
    'ORGANISTA': 0,
    'ORGANO': 0,
    'ORGAS': 0,
    'ORGEL': 0,
    'ORGERA': 0,
    'ORGERON': 0,
    'ORGILL': 0,
    'ORGOVAN': 0,
    'ORI': 0,
    'ORIA': 0,
    'ORIANI': 0,
    'ORIANS': 0,
    'ORIAS': 0,
    'ORIBELLO': 0,
    'ORICK': 0,
    'ORIE': 0,
    'ORIEL': 0,
    'ORIELLY': 0,
    'ORIENT': 0,
    'ORIENTE': 0,
    'ORIFICE': 0,
    'ORIGEL': 0,
    'ORIGER': 0,
    'ORIHUELA': 0,
    'ORILEY': 0,
    'ORILLION': 0,
    'ORIN': 0,
    'ORING': 0,
    'ORINGDERFF': 0,
    'ORINGER': 0,
    'ORIO': 0,
    'ORIOL': 0,
    'ORIOLA': 0,
    'ORIOLO': 0,
    'ORION': 0,
    'ORIORDAN': 0,
    'ORIS': 0,
    'ORITI': 0,
    'ORITZ': 0,
    'ORIVE': 0,
    'ORIZABA': 0,
    'ORJI': 0,
    'ORJUELA': 0,
    'ORK': 0,
    'ORKIN': 0,
    'ORLAND': 0,
    'ORLANDELLA': 0,
    'ORLANDI': 0,
    'ORLANDINI': 0,
    'ORLANDO': 0.8898508898508898,
    'ORLANSKY': 0,
    'ORLEANS': 0,
    'ORLEMAN': 0,
    'ORLER': 0,
    'ORLEY': 0,
    'ORLIC': 0,
    'ORLICH': 0,
    'ORLICK': 0,
    'ORLIK': 0,
    'ORLIKOWSKI': 0,
    'ORLIN': 0,
    'ORLINA': 0,
    'ORLINSKI': 0,
    'ORLINSKY': 0,
    'ORLOFF': 0,
    'ORLOFSKY': 0,
    'ORLOPP': 0,
    'ORLOSKI': 0,
    'ORLOSKY': 0,
    'ORLOV': 0,
    'ORLOVA': 0,
    'ORLOVE': 0,
    'ORLOVSKY': 0,
    'ORLOW': 0,
    'ORLOWSKI': 0,
    'ORLOWSKY': 0,
    'ORLUCK': 0,
    'ORM': 0,
    'ORMAN': 0,
    'ORMAND': 0,
    'ORMANDY': 0,
    'ORME': 0,
    'ORMENO': 0,
    'ORMEROD': 0,
    'ORMES': 0,
    'ORMESHER': 0,
    'ORMISTON': 0,
    'ORMON': 0,
    'ORMOND': 0,
    'ORMONDE': 0,
    'ORMS': 0,
    'ORMSBEE': 0,
    'ORMSBY': 0,
    'ORMSETH': 0,
    'ORMSON': 0,
    'ORMSTON': 0,
    'ORN': 0,
    'ORNA': 0,
    'ORNALES': 0,
    'ORNBERG': 0,
    'ORNDOFF': 0,
    'ORNDORF': 0,
    'ORNDORFF': 0,
    'ORNDUFF': 0,
    'ORNE': 0,
    'ORNELAS': 0,
    'ORNELAZ': 0,
    'ORNELLAS': 0,
    'ORNER': 0,
    'ORNES': 0,
    'ORNS': 0,
    'ORNSTEIN': 0,
    'ORO': 0,
    'OROARK': 0,
    'OROCIO': 0,
    'OROFINO': 0,
    'OROLOGIO': 0,
    'ORONA': 0,
    'ORONIA': 0,
    'ORONOZ': 0,
    'OROPALLO': 0,
    'OROPESA': 0,
    'OROPEZA': 0,
    'ORORKE': 0,
    'OROS': 0,
    'OROSA': 0,
    'OROSCO': 0,
    'OROSS': 0,
    'OROSZ': 0,
    'OROUKE': 0,
    'OROURKE': 0,
    'OROW': 0,
    'OROZ': 0,
    'OROZCO': 0,
    'ORPEN': 0,
    'ORPHA': 1,
    'ORPHAN': 0,
    'ORPHANOS': 0,
    'ORPHEY': 0,
    'ORPILLA': 0,
    'ORPIN': 0,
    'ORPURT': 0,
    'ORQUIZ': 0,
    'ORR': 0,
    'ORRALA': 0,
    'ORRANTIA': 0,
    'ORRE': 0,
    'ORREGO': 0,
    'ORRELL': 0,
    'ORREN': 0,
    'ORRENDER': 0,
    'ORRICK': 0,
    'ORRICO': 0,
    'ORRILL': 0,
    'ORRIN': 0,
    'ORRINO': 0,
    'ORRIS': 0,
    'ORRISON': 0,
    'ORROCK': 0,
    'ORROSTIETA': 0,
    'ORS': 0,
    'ORSAG': 0,
    'ORSAK': 0,
    'ORSATTI': 0,
    'ORSBORN': 0,
    'ORSBORNE': 0,
    'ORSBURN': 0,
    'ORSCHELN': 0,
    'ORSENO': 0,
    'ORSER': 0,
    'ORSETTI': 0,
    'ORSI': 0,
    'ORSILLO': 0,
    'ORSINGER': 0,
    'ORSINI': 0,
    'ORSINO': 0,
    'ORSO': 0,
    'ORSON': 0,
    'ORSTAD': 0,
    'ORSTED': 0,
    'ORSULAK': 0,
    'ORSZULAK': 0,
    'ORT': 0,
    'ORTA': 0,
    'ORTADO': 0,
    'ORTAGA': 0,
    'ORTAGUS': 0,
    'ORTALE': 0,
    'ORTBALS': 0,
    'ORTBERG': 0,
    'ORTEGA': 0,
    'ORTEGO': 0,
    'ORTEGON': 0,
    'ORTEL': 0,
    'ORTELL': 0,
    'ORTEN': 0,
    'ORTENZI': 0,
    'ORTENZIO': 0,
    'ORTES': 0,
    'ORTEZ': 0,
    'ORTEZA': 0,
    'ORTGIES': 0,
    'ORTGIESEN': 0,
    'ORTH': 0,
    'ORTHMAN': 0,
    'ORTHMANN': 0,
    'ORTHWEIN': 0,
    'ORTIC': 0,
    'ORTIGOZA': 0,
    'ORTIS': 0,
    'ORTISI': 0,
    'ORTIVEZ': 0,
    'ORTIZ': 0,
    'ORTIZGARCIA': 0,
    'ORTIZHERNANDEZ': 0,
    'ORTIZLOPEZ': 0,
    'ORTIZMARTINEZ': 0,
    'ORTIZORTIZ': 0,
    'ORTIZRIVERA': 0,
    'ORTIZRODRIGUEZ': 0,
    'ORTIZSANCHEZ': 0,
    'ORTLIEB': 0,
    'ORTLIP': 0,
    'ORTLOFF': 0,
    'ORTMAN': 0,
    'ORTMANN': 0,
    'ORTMEIER': 0,
    'ORTMEYER': 0,
    'ORTNER': 0,
    'ORTO': 0,
    'ORTOLANI': 0,
    'ORTOLANO': 0,
    'ORTOLAZA': 0,
    'ORTON': 0,
    'ORTQUIST': 0,
    'ORTS': 0,
    'ORTT': 0,
    'ORTUNO': 0,
    'ORTWEIN': 0,
    'ORTWINE': 0,
    'ORTYL': 0,
    'ORTZ': 0,
    'ORUE': 0,
    'ORULLIAN': 0,
    'ORUM': 0,
    'ORVAL': 1,
    'ORVIK': 0,
    'ORVILLE': 0.9983361064891847,
    'ORVIN': 0,
    'ORVIS': 0,
    'ORWAN': 0,
    'ORWAT': 0,
    'ORWICK': 0,
    'ORWIG': 0,
    'ORWIN': 0,
    'ORY': 0,
    'ORYAN': 0,
    'ORZA': 0,
    'ORZECH': 0,
    'ORZECHOWSKI': 0,
    'ORZEL': 0,
    'ORZELL': 0,
    'ORZO': 0,
    'ORZOL': 0,
    'ORZOLEK': 0,
    'ORZUNA': 0,
    'OS': 0,
    'OSA': 0,
    'OSABEN': 0,
    'OSADA': 0,
    'OSADCHUK': 0,
    'OSAGE': 0,
    'OSAGIE': 0,
    'OSAK': 0,
    'OSAKA': 0,
    'OSAKI': 0,
    'OSAKO': 0,
    'OSANTOWSKI': 0,
    'OSARIO': 0,
    'OSATO': 0,
    'OSAWA': 0,
    'OSBAHR': 0,
    'OSBAN': 0,
    'OSBECK': 0,
    'OSBERG': 0,
    'OSBEY': 0,
    'OSBON': 0,
    'OSBORN': 0,
    'OSBORNE': 0,
    'OSBOURN': 0,
    'OSBOURNE': 0,
    'OSBRINK': 0,
    'OSBRON': 0,
    'OSBUN': 0,
    'OSBURN': 0,
    'OSBURNE': 0,
    'OSBY': 0,
    'OSCAR': 0.9957095442402656,
    'OSCARSON': 0,
    'OSCEOLA': 0,
    'OSCHE': 0,
    'OSCHMANN': 0,
    'OSCHWALD': 0,
    'OSE': 0,
    'OSEGUEDA': 0,
    'OSEGUERA': 0,
    'OSEI': 0,
    'OSEITUTU': 0,
    'OSEJO': 0,
    'OSELAND': 0,
    'OSELL': 0,
    'OSEN': 0,
    'OSENBACH': 0,
    'OSENBAUGH': 0,
    'OSENDORF': 0,
    'OSENGA': 0,
    'OSENI': 0,
    'OSENTOSKI': 0,
    'OSENTOWSKI': 0,
    'OSER': 0,
    'OSES': 0,
    'OSET': 0,
    'OSETEK': 0,
    'OSETH': 0,
    'OSGA': 0,
    'OSGOOD': 0,
    'OSGUTHORPE': 0,
    'OSHA': 0,
    'OSHANA': 0,
    'OSHAUGHNESSEY': 0,
    'OSHAUGHNESSY': 0,
    'OSHEA': 0,
    'OSHEI': 0,
    'OSHEIM': 0,
    'OSHEL': 0,
    'OSHELL': 0,
    'OSHER': 0,
    'OSHEROFF': 0,
    'OSHIELDS': 0,
    'OSHIER': 0,
    'OSHIMA': 0,
    'OSHINSKI': 0,
    'OSHINSKY': 0,
    'OSHIRO': 0,
    'OSHITA': 0,
    'OSHMAN': 0,
    'OSHODI': 0,
    'OSHRY': 0,
    'OSIAS': 0,
    'OSIECKI': 0,
    'OSIEK': 0,
    'OSIER': 0,
    'OSIF': 0,
    'OSIFE': 0,
    'OSIKA': 0,
    'OSINA': 0,
    'OSINGA': 0,
    'OSINOWO': 0,
    'OSINSKI': 0,
    'OSIO': 0,
    'OSIP': 0,
    'OSIPOV': 0,
    'OSKAM': 0,
    'OSKEY': 0,
    'OSKIN': 0,
    'OSKINS': 0,
    'OSKO': 0,
    'OSLAND': 0,
    'OSLE': 0,
    'OSLER': 0,
    'OSLEY': 0,
    'OSLIN': 0,
    'OSLOWSKI': 0,
    'OSLUND': 0,
    'OSMAN': 0,
    'OSMANI': 0,
    'OSMANOVIC': 0,
    'OSMANSKI': 0,
    'OSMENT': 0,
    'OSMER': 0,
    'OSMERA': 0,
    'OSMON': 0,
    'OSMOND': 0,
    'OSMONSON': 0,
    'OSMULSKI': 0,
    'OSMUN': 0,
    'OSMUNDSEN': 0,
    'OSMUNDSON': 0,
    'OSMUS': 0,
    'OSNATO': 0,
    'OSNAYA': 0,
    'OSNER': 0,
    'OSNES': 0,
    'OSNESS': 0,
    'OSO': 0,
    'OSOBA': 0,
    'OSOFSKY': 0,
    'OSOLIN': 0,
    'OSORES': 0,
    'OSORIA': 0,
    'OSORIO': 0,
    'OSORNIA': 0,
    'OSORNIO': 0,
    'OSORNO': 0,
    'OSORTO': 0,
    'OSOSKI': 0,
    'OSOSKIE': 0,
    'OSOWIECKI': 0,
    'OSOWSKI': 0,
    'OSOY': 0,
    'OSPINA': 0,
    'OSPINO': 0,
    'OSS': 0,
    'OSSA': 0,
    'OSSANNA': 0,
    'OSSE': 0,
    'OSSENFORT': 0,
    'OSSI': 0,
    'OSSIAN': 0,
    'OSSIE': 1,
    'OSSLER': 0,
    'OSSMAN': 0,
    'OSSMANN': 0,
    'OSSO': 0,
    'OSSOLA': 0,
    'OSSONT': 0,
    'OSSORIO': 0,
    'OSSOWSKI': 0,
    'OSSWALD': 0,
    'OST': 0,
    'OSTA': 0,
    'OSTAFIN': 0,
    'OSTAPENKO': 0,
    'OSTAPOWICZ': 0,
    'OSTASZEWSKI': 0,
    'OSTBERG': 0,
    'OSTBY': 0,
    'OSTDIEK': 0,
    'OSTEEN': 0,
    'OSTEN': 0,
    'OSTENBERG': 0,
    'OSTENDORF': 0,
    'OSTENSEN': 0,
    'OSTENSON': 0,
    'OSTER': 0,
    'OSTERBAUER': 0,
    'OSTERBERG': 0,
    'OSTERBERGER': 0,
    'OSTERBRINK': 0,
    'OSTERBROCK': 0,
    'OSTERBUHR': 0,
    'OSTERBUR': 0,
    'OSTERDAY': 0,
    'OSTERFELD': 0,
    'OSTERGAARD': 0,
    'OSTERGARD': 0,
    'OSTERGREN': 0,
    'OSTERHAGE': 0,
    'OSTERHAUS': 0,
    'OSTERHOFF': 0,
    'OSTERHOLM': 0,
    'OSTERHOLT': 0,
    'OSTERHOUDT': 0,
    'OSTERHOUSE': 0,
    'OSTERHOUT': 0,
    'OSTERHUES': 0,
    'OSTERHUS': 0,
    'OSTERKAMP': 0,
    'OSTERLAND': 0,
    'OSTERLING': 0,
    'OSTERLOH': 0,
    'OSTERLUND': 0,
    'OSTERMAN': 0,
    'OSTERMANN': 0,
    'OSTERMEIER': 0,
    'OSTERMEYER': 0,
    'OSTERMILLER': 0,
    'OSTERTAG': 0,
    'OSTGAARD': 0,
    'OSTHEIMER': 0,
    'OSTHOFF': 0,
    'OSTHUS': 0,
    'OSTI': 0,
    'OSTIC': 0,
    'OSTIEN': 0,
    'OSTIGUIN': 0,
    'OSTIGUY': 0,
    'OSTIN': 0,
    'OSTING': 0,
    'OSTLER': 0,
    'OSTLIE': 0,
    'OSTLING': 0,
    'OSTLUND': 0,
    'OSTMAN': 0,
    'OSTMANN': 0,
    'OSTMEYER': 0,
    'OSTOICH': 0,
    'OSTOJIC': 0,
    'OSTOLAZA': 0,
    'OSTORGA': 0,
    'OSTOS': 0,
    'OSTOVICH': 0,
    'OSTRAND': 0,
    'OSTRANDER': 0,
    'OSTREGA': 0,
    'OSTREICHER': 0,
    'OSTREM': 0,
    'OSTRENGA': 0,
    'OSTRICH': 0,
    'OSTRIN': 0,
    'OSTRO': 0,
    'OSTROFF': 0,
    'OSTROFSKY': 0,
    'OSTROM': 0,
    'OSTRONIC': 0,
    'OSTROOT': 0,
    'OSTROSKI': 0,
    'OSTROSKY': 0,
    'OSTROUT': 0,
    'OSTROV': 0,
    'OSTROVE': 0,
    'OSTROVSKAYA': 0,
    'OSTROVSKY': 0,
    'OSTROW': 0,
    'OSTROWSKI': 0,
    'OSTROWSKY': 0,
    'OSTRUM': 0,
    'OSTRY': 0,
    'OSTRYE': 0,
    'OSTUNI': 0,
    'OSTWALD': 0,
    'OSTWALT': 0,
    'OSTWINKLE': 0,
    'OSU': 0,
    'OSUCH': 0,
    'OSUGI': 0,
    'OSUJI': 0,
    'OSULLIVAN': 0,
    'OSUMI': 0,
    'OSUNA': 0,
    'OSUSKY': 0,
    'OSVALDO': 1,
    'OSVOLD': 0,
    'OSWALD': 0,
    'OSWALDO': 1,
    'OSWALT': 0,
    'OSWEILER': 0,
    'OSWELL': 0,
    'OSWOOD': 0,
    'OSZUST': 0,
    'OTA': 0,
    'OTAKE': 0,
    'OTALORA': 0,
    'OTALVARO': 0,
    'OTANEZ': 0,
    'OTANI': 0,
    'OTANO': 0,
    'OTAROLA': 0,
    'OTCHERE': 0,
    'OTELIA': 1,
    'OTEN': 0,
    'OTERI': 0,
    'OTERO': 0,
    'OTEY': 0,
    'OTHA': 1,
    'OTHMAN': 0,
    'OTHMER': 0,
    'OTHON': 0,
    'OTI': 0,
    'OTIENO': 0,
    'OTILIA': 1,
    'OTINGER': 0,
    'OTINIANO': 0,
    'OTIS': 0.9358593928326866,
    'OTLEY': 0,
    'OTLOWSKI': 0,
    'OTNESS': 0,
    'OTO': 0,
    'OTOMO': 0,
    'OTOO': 0,
    'OTOOL': 0,
    'OTOOLE': 0,
    'OTOYA': 0,
    'OTRADOVEC': 0,
    'OTREMBA': 0,
    'OTRUBA': 0,
    'OTSTOT': 0,
    'OTSU': 0,
    'OTSUBO': 0,
    'OTSUJI': 0,
    'OTSUKA': 0,
    'OTSUKI': 0,
    'OTT': 0,
    'OTTA': 0,
    'OTTATI': 0,
    'OTTAVIANI': 0,
    'OTTAVIANO': 0,
    'OTTAVIO': 0,
    'OTTAWAY': 0,
    'OTTE': 0,
    'OTTELE': 0,
    'OTTEM': 0,
    'OTTEMAN': 0,
    'OTTEN': 0,
    'OTTENBACHER': 0,
    'OTTENBERG': 0,
    'OTTENBREIT': 0,
    'OTTENHEIMER': 0,
    'OTTENI': 0,
    'OTTENS': 0,
    'OTTENSTEIN': 0,
    'OTTENWALDER': 0,
    'OTTENWELLER': 0,
    'OTTER': 0,
    'OTTERBACHER': 0,
    'OTTERBECK': 0,
    'OTTERBEIN': 0,
    'OTTERMAN': 0,
    'OTTERNESS': 0,
    'OTTERSBACH': 0,
    'OTTERSON': 0,
    'OTTERSTEIN': 0,
    'OTTERSTETTER': 0,
    'OTTERSTROM': 0,
    'OTTESEN': 0,
    'OTTESON': 0,
    'OTTEY': 0,
    'OTTING': 0,
    'OTTINGER': 0,
    'OTTINO': 0,
    'OTTIS': 0,
    'OTTLEY': 0,
    'OTTMAN': 0,
    'OTTMANN': 0,
    'OTTMAR': 0,
    'OTTMER': 0,
    'OTTMERS': 0,
    'OTTNEY': 0,
    'OTTO': 0.6880733944954129,
    'OTTOBONI': 0,
    'OTTOBRE': 0,
    'OTTOLINI': 0,
    'OTTOLINO': 0,
    'OTTOMANELLI': 0,
    'OTTON': 0,
    'OTTONE': 0,
    'OTTOSEN': 0,
    'OTTOSON': 0,
    'OTTOW': 0,
    'OTTS': 0,
    'OTTUM': 0,
    'OTTWELL': 0,
    'OTVOS': 0,
    'OTWAY': 0,
    'OTWELL': 0,
    'OTWORTH': 0,
    'OTY': 0,
    'OTZELBERGER': 0,
    'OU': 0,
    'OUANO': 0,
    'OUBRE': 0,
    'OUCH': 0,
    'OUCHI': 0,
    'OUCHIDA': 0,
    'OUDEKERK': 0,
    'OUDENHOVEN': 0,
    'OUDERKIRK': 0,
    'OUDIN': 0,
    'OUELETTE': 0,
    'OUELLET': 0,
    'OUELLETTE': 0,
    'OUGEL': 0,
    'OUGH': 0,
    'OUGHTON': 0,
    'OUIDA': 1,
    'OUILLETTE': 0,
    'OUIMET': 0,
    'OUIMETTE': 0,
    'OUK': 0,
    'OULDS': 0,
    'OULETTE': 0,
    'OULTON': 0,
    'OUM': 0,
    'OUN': 0,
    'OUNG': 0,
    'OURADA': 0,
    'OURADNIK': 0,
    'OURS': 0,
    'OURSLER': 0,
    'OURSO': 0,
    'OURY': 0,
    'OUSEY': 0,
    'OUSLEY': 0,
    'OUSTERHOUT': 0,
    'OUTAR': 0,
    'OUTCALT': 0,
    'OUTEN': 0,
    'OUTERBRIDGE': 0,
    'OUTHIER': 0,
    'OUTHOUSE': 0,
    'OUTING': 0,
    'OUTLAND': 0,
    'OUTLAW': 0,
    'OUTLER': 0,
    'OUTLEY': 0,
    'OUTMAN': 0,
    'OUTRAM': 0,
    'OUTTEN': 0,
    'OUTTERBRIDGE': 0,
    'OUTWATER': 0,
    'OUTZ': 0,
    'OUTZEN': 0,
    'OUVERSON': 0,
    'OUWINGA': 0,
    'OUYANG': 0,
    'OUYE': 0,
    'OUZOUNIAN': 0,
    'OUZTS': 0,
    'OVA': 0,
    'OVADIA': 0,
    'OVALL': 0,
    'OVALLE': 0,
    'OVALLES': 0,
    'OVANDO': 0,
    'OVARD': 0,
    'OVASKA': 0,
    'OVE': 0,
    'OVED': 0,
    'OVELLET': 0,
    'OVEN': 0,
    'OVENDEN': 0,
    'OVENS': 0,
    'OVENSHIRE': 0,
    'OVER': 0,
    'OVERA': 0,
    'OVERACKER': 0,
    'OVERALL': 0,
    'OVERBAUGH': 0,
    'OVERBAY': 0,
    'OVERBECK': 0,
    'OVERBEE': 0,
    'OVERBEEK': 0,
    'OVERBERG': 0,
    'OVERBEY': 0,
    'OVERBO': 0,
    'OVERBY': 0,
    'OVERBYE': 0,
    'OVERCASH': 0,
    'OVERCAST': 0,
    'OVERDORF': 0,
    'OVERDORFF': 0,
    'OVEREEM': 0,
    'OVEREND': 0,
    'OVERFELT': 0,
    'OVERFIELD': 0,
    'OVERGAARD': 0,
    'OVERGARD': 0,
    'OVERHISER': 0,
    'OVERHOFF': 0,
    'OVERHOLSER': 0,
    'OVERHOLT': 0,
    'OVERHOLTS': 0,
    'OVERHOLTZ': 0,
    'OVERHOLTZER': 0,
    'OVERHULSER': 0,
    'OVERKAMP': 0,
    'OVERLA': 0,
    'OVERLAND': 0,
    'OVERLANDER': 0,
    'OVERLEY': 0,
    'OVERLIE': 0,
    'OVERLIN': 0,
    'OVERLOCK': 0,
    'OVERLY': 0,
    'OVERMAN': 0,
    'OVERMANN': 0,
    'OVERMEYER': 0,
    'OVERMIER': 0,
    'OVERMILLER': 0,
    'OVERMIRE': 0,
    'OVERMYER': 0,
    'OVEROCKER': 0,
    'OVERPECK': 0,
    'OVERS': 0,
    'OVERSCHMIDT': 0,
    'OVERSHINER': 0,
    'OVERSHOWN': 0,
    'OVERSON': 0,
    'OVERSTAKE': 0,
    'OVERSTREET': 0,
    'OVERSTROM': 0,
    'OVERTON': 0,
    'OVERTURF': 0,
    'OVERTURFF': 0,
    'OVERVOLD': 0,
    'OVERWAY': 0,
    'OVERWEG': 0,
    'OVERY': 0,
    'OVESEN': 0,
    'OVESON': 0,
    'OVIATT': 0,
    'OVIDE': 0,
    'OVIEDO': 0,
    'OVINGTON': 0,
    'OVITT': 0,
    'OVSEPYAN': 0,
    'OW': 0,
    'OWAN': 0,
    'OWCA': 0,
    'OWCZARCZAK': 0,
    'OWCZAREK': 0,
    'OWCZARSKI': 0,
    'OWCZARZAK': 0,
    'OWEIS': 0,
    'OWEN': 0.5370791158851477,
    'OWENBY': 0,
    'OWENS': 0,
    'OWENSBY': 0,
    'OWER': 0,
    'OWERS': 0,
    'OWES': 0,
    'OWINGS': 0,
    'OWL': 0,
    'OWLE': 0,
    'OWLETT': 0,
    'OWNBEY': 0,
    'OWNBY': 0,
    'OWNES': 0,
    'OWNEY': 0,
    'OWNS': 0,
    'OWOC': 0,
    'OWOLABI': 0,
    'OWREY': 0,
    'OWSIAK': 0,
    'OWSIANY': 0,
    'OWSLEY': 0,
    'OWSTON': 0,
    'OWUSU': 0,
    'OWUSUANSAH': 0,
    'OWYANG': 0,
    'OWYOUNG': 0,
    'OXBOROUGH': 0,
    'OXBORROW': 0,
    'OXENDALE': 0,
    'OXENDER': 0,
    'OXENDINE': 0,
    'OXENFORD': 0,
    'OXENHAM': 0,
    'OXENREIDER': 0,
    'OXENRIDER': 0,
    'OXFORD': 0,
    'OXIER': 0,
    'OXLAJ': 0,
    'OXLEY': 0,
    'OXMAN': 0,
    'OXNER': 0,
    'OXTON': 0,
    'OXX': 0,
    'OXYER': 0,
    'OY': 0,
    'OYA': 0,
    'OYADOMARI': 0,
    'OYAMA': 0,
    'OYARZABAL': 0,
    'OYARZUN': 0,
    'OYE': 0,
    'OYEN': 0,
    'OYER': 0,
    'OYERVIDES': 0,
    'OYERVIDEZ': 0,
    'OYEWOLE': 0,
    'OYLER': 0,
    'OYOLA': 0,
    'OYOQUE': 0,
    'OYOUNG': 0,
    'OYSTER': 0,
    'OYUELA': 0,
    'OZ': 0,
    'OZA': 0,
    'OZAETA': 0,
    'OZAKI': 0,
    'OZAN': 0,
    'OZANICH': 0,
    'OZANNE': 0,
    'OZAR': 0,
    'OZARK': 0,
    'OZAROWSKI': 0,
    'OZAWA': 0,
    'OZBAY': 0,
    'OZBIRN': 0,
    'OZBOLT': 0,
    'OZBUN': 0,
    'OZBURN': 0,
    'OZCAN': 0,
    'OZDEMIR': 0,
    'OZEE': 0,
    'OZEKI': 0,
    'OZEL': 0,
    'OZELL': 1,
    'OZELLA': 0.9803921568627452,
    'OZEN': 0,
    'OZENBAUGH': 0,
    'OZENNE': 0,
    'OZER': 0,
    'OZGA': 0,
    'OZIAS': 0,
    'OZIE': 1,
    'OZIER': 0,
    'OZIMEK': 0,
    'OZINGA': 0,
    'OZKAN': 0,
    'OZLEY': 0,
    'OZMAN': 0,
    'OZMENT': 0,
    'OZMORE': 0,
    'OZMUN': 0,
    'OZOA': 0,
    'OZOG': 0,
    'OZOLINS': 0,
    'OZOLS': 0,
    'OZORIA': 0,
    'OZORIO': 0,
    'OZTURK': 0,
    'OZUNA': 0,
    'OZZELLO': 0,
    'PA': 0.8403361344537815,
    'PAA': 0,
    'PAAL': 0,
    'PAALMAN': 0,
    'PAANANEN': 0,
    'PAAP': 0,
    'PAAPE': 0,
    'PAAR': 0,
    'PAARLBERG': 0,
    'PAARMANN': 0,
    'PAAS': 0,
    'PAASCH': 0,
    'PAASCHE': 0,
    'PAAT': 0,
    'PAAUWE': 0,
    'PAAVOLA': 0,
    'PABALAN': 0,
    'PABALATE': 0,
    'PABELLON': 0,
    'PABEN': 0,
    'PABEY': 0,
    'PABIAN': 0,
    'PABICH': 0,
    'PABIN': 0,
    'PABIS': 0,
    'PABLA': 0,
    'PABLO': 0.9612817089452604,
    'PABLOS': 0,
    'PABON': 0,
    'PABST': 0,
    'PAC': 0,
    'PACA': 0,
    'PACAK': 0,
    'PACALA': 0,
    'PACANA': 0,
    'PACANOWSKI': 0,
    'PACAS': 0,
    'PACATTE': 0,
    'PACCIONE': 0,
    'PACE': 0,
    'PACEK': 0,
    'PACELEY': 0,
    'PACELLA': 0,
    'PACELLI': 0,
    'PACELLO': 0,
    'PACER': 0,
    'PACETTI': 0,
    'PACEWICZ': 0,
    'PACEY': 0,
    'PACH': 0,
    'PACHA': 0,
    'PACHAN': 0,
    'PACHAS': 0,
    'PACHE': 0,
    'PACHECANO': 0,
    'PACHECO': 0,
    'PACHELO': 0,
    'PACHEO': 0,
    'PACHER': 0,
    'PACHICANO': 0,
    'PACHICO': 0,
    'PACHL': 0,
    'PACHLA': 0,
    'PACHMAN': 0,
    'PACHMAYER': 0,
    'PACHNER': 0,
    'PACHO': 0,
    'PACHOLKE': 0,
    'PACHOLSKI': 0,
    'PACHON': 0,
    'PACHT': 0,
    'PACHTA': 0,
    'PACHTER': 0,
    'PACHUCA': 0,
    'PACHUCKI': 0,
    'PACHUTA': 0,
    'PACI': 0,
    'PACIA': 0,
    'PACIELLO': 0,
    'PACIFIC': 0,
    'PACIFICI': 0,
    'PACIFICO': 0,
    'PACIGA': 0,
    'PACILEO': 0,
    'PACILIO': 0,
    'PACILLAS': 0,
    'PACILLI': 0,
    'PACILLO': 0,
    'PACINI': 0,
    'PACINO': 0,
    'PACIO': 0,
    'PACIOCCO': 0,
    'PACIONE': 0,
    'PACIOREK': 0,
    'PACIOTTI': 0,
    'PACIS': 0,
    'PACITTI': 0,
    'PACITTO': 0,
    'PACIULLI': 0,
    'PACIULLO': 0,
    'PACK': 0,
    'PACKARD': 0,
    'PACKEBUSH': 0,
    'PACKER': 0,
    'PACKETT': 0,
    'PACKEY': 0,
    'PACKHAM': 0,
    'PACKINGHAM': 0,
    'PACKMAN': 0,
    'PACKNETT': 0,
    'PACKO': 0,
    'PACKWOOD': 0,
    'PACLEB': 0,
    'PACO': 0,
    'PACOCHA': 0,
    'PACOVSKY': 0,
    'PACQUING': 0,
    'PACULA': 0,
    'PACULBA': 0,
    'PACY': 0,
    'PACYGA': 0,
    'PACYNA': 0,
    'PACZESNY': 0,
    'PACZKOWSKI': 0,
    'PACZOSA': 0,
    'PACZYNSKI': 0,
    'PAD': 0,
    'PADA': 0,
    'PADALECKI': 0,
    'PADALINO': 0,
    'PADAVANO': 0,
    'PADAWER': 0,
    'PADAYAO': 0,
    'PADBERG': 0,
    'PADBURY': 0,
    'PADDA': 0,
    'PADDACK': 0,
    'PADDEN': 0,
    'PADDIE': 0,
    'PADDIO': 0,
    'PADDISON': 0,
    'PADDOCK': 0,
    'PADDON': 0,
    'PADDY': 0,
    'PADE': 0,
    'PADEL': 0,
    'PADELFORD': 0,
    'PADELLA': 0,
    'PADEN': 0,
    'PADER': 0,
    'PADERES': 0,
    'PADFIELD': 0,
    'PADGET': 0,
    'PADGETT': 0,
    'PADGETTE': 0,
    'PADGHAM': 0,
    'PADGITT': 0,
    'PADIA': 0,
    'PADIAN': 0,
    'PADIERNA': 0,
    'PADILLA': 0,
    'PADILLO': 0,
    'PADIN': 0,
    'PADJEN': 0,
    'PADLAN': 0,
    'PADLELLA': 0,
    'PADLETTI': 0,
    'PADLEY': 0,
    'PADLO': 0,
    'PADMANABHAN': 0,
    'PADMORE': 0,
    'PADO': 0,
    'PADON': 0,
    'PADOVA': 0,
    'PADOVAN': 0,
    'PADOVANI': 0,
    'PADOVANO': 0,
    'PADRE': 0,
    'PADRICK': 0,
    'PADRNOS': 0,
    'PADRO': 0,
    'PADRON': 0,
    'PADRUTT': 0,
    'PADUA': 0,
    'PADUANI': 0,
    'PADUANO': 0,
    'PADUCH': 0,
    'PADULA': 0,
    'PADWA': 0,
    'PADY': 0,
    'PADYKULA': 0,
    'PAE': 0,
    'PAEK': 0,
    'PAEPER': 0,
    'PAEPKE': 0,
    'PAES': 0,
    'PAESANO': 0,
    'PAESE': 0,
    'PAET': 0,
    'PAETH': 0,
    'PAETOW': 0,
    'PAETSCH': 0,
    'PAETZ': 0,
    'PAETZOLD': 0,
    'PAEZ': 0,
    'PAFF': 0,
    'PAFFEL': 0,
    'PAFFENROTH': 0,
    'PAFFHAUSEN': 0,
    'PAFFORD': 0,
    'PAFFRATH': 0,
    'PAFUMI': 0,
    'PAFUNDI': 0,
    'PAGA': 0,
    'PAGAC': 0,
    'PAGACH': 0,
    'PAGADOR': 0,
    'PAGADUAN': 0,
    'PAGALA': 0,
    'PAGAN': 0,
    'PAGANA': 0,
    'PAGANELLI': 0,
    'PAGANETTI': 0,
    'PAGANI': 0,
    'PAGANINI': 0,
    'PAGANO': 0,
    'PAGANS': 0,
    'PAGANUCCI': 0,
    'PAGARIGAN': 0,
    'PAGATPATAN': 0,
    'PAGDANGANAN': 0,
    'PAGDILAO': 0,
    'PAGE': 0.09135200974421437,
    'PAGEAU': 0,
    'PAGEL': 0,
    'PAGELER': 0,
    'PAGELS': 0,
    'PAGEN': 0,
    'PAGENKOPF': 0,
    'PAGER': 0,
    'PAGES': 0,
    'PAGET': 0,
    'PAGETT': 0,
    'PAGGEN': 0,
    'PAGGETT': 0,
    'PAGGI': 0,
    'PAGH': 0,
    'PAGILLO': 0,
    'PAGITT': 0,
    'PAGLEY': 0,
    'PAGLIA': 0,
    'PAGLIAI': 0,
    'PAGLIARA': 0,
    'PAGLIARD': 0,
    'PAGLIARI': 0,
    'PAGLIARINI': 0,
    'PAGLIARO': 0,
    'PAGLIAROLI': 0,
    'PAGLIARULO': 0,
    'PAGLIEI': 0,
    'PAGLIERANI': 0,
    'PAGLINAWAN': 0,
    'PAGLINO': 0,
    'PAGLIO': 0,
    'PAGLIONE': 0,
    'PAGLIUCA': 0,
    'PAGLIUCO': 0,
    'PAGLIUGHI': 0,
    'PAGLIUSO': 0,
    'PAGNANI': 0,
    'PAGNANO': 0,
    'PAGNI': 0,
    'PAGNINI': 0,
    'PAGNONI': 0,
    'PAGNOTTA': 0,
    'PAGNOTTI': 0,
    'PAGNOZZI': 0,
    'PAGNUCCO': 0,
    'PAGOADA': 0,
    'PAGOAGA': 0,
    'PAGON': 0,
    'PAGONE': 0,
    'PAGONES': 0,
    'PAGONIS': 0,
    'PAGORIA': 0,
    'PAGOTTO': 0,
    'PAGOULATOS': 0,
    'PAGTAKHAN': 0,
    'PAGUADA': 0,
    'PAGUAGA': 0,
    'PAGUAY': 0,
    'PAGUE': 0,
    'PAGUIA': 0,
    'PAGUIO': 0,
    'PAGUIRIGAN': 0,
    'PAGULAYAN': 0,
    'PAGUYO': 0,
    'PAHE': 0,
    'PAHEL': 0,
    'PAHIA': 0,
    'PAHL': 0,
    'PAHLAVAN': 0,
    'PAHLER': 0,
    'PAHLKE': 0,
    'PAHLMAN': 0,
    'PAHLOW': 0,
    'PAHLS': 0,
    'PAHNKE': 0,
    'PAHR': 0,
    'PAHUA': 0,
    'PAHULU': 0,
    'PAHWA': 0,
    'PAI': 0,
    'PAIANO': 0,
    'PAICE': 0,
    'PAICH': 0,
    'PAIDER': 0,
    'PAIGE': 0.7338740826573967,
    'PAIK': 0,
    'PAIL': 0,
    'PAILET': 0,
    'PAILLANT': 0,
    'PAILLE': 0,
    'PAIM': 0,
    'PAIMA': 0,
    'PAIN': 0,
    'PAINCHAUD': 0,
    'PAINE': 0,
    'PAINI': 0,
    'PAINO': 0,
    'PAINTER': 0,
    'PAINTIN': 0,
    'PAINTING': 0,
    'PAINTNER': 0,
    'PAINTON': 0,
    'PAIR': 0,
    'PAIRAN': 0,
    'PAIRE': 0,
    'PAIS': 0,
    'PAISANO': 0,
    'PAISER': 0,
    'PAISHON': 0,
    'PAISLEY': 0,
    'PAISNER': 0,
    'PAISON': 0,
    'PAIST': 0,
    'PAISTE': 0,
    'PAIT': 0,
    'PAITA': 0,
    'PAITSEL': 0,
    'PAIVA': 0,
    'PAIXAO': 0,
    'PAIZ': 0,
    'PAJAK': 0,
    'PAJARES': 0,
    'PAJARI': 0,
    'PAJARILLO': 0,
    'PAJARITO': 0,
    'PAJARO': 0,
    'PAJAZETOVIC': 0,
    'PAJE': 0,
    'PAJER': 0,
    'PAJERSKI': 0,
    'PAJEWSKI': 0,
    'PAJIC': 0,
    'PAJON': 0,
    'PAJOR': 0,
    'PAJOT': 0,
    'PAJUELO': 0,
    'PAK': 0,
    'PAKALA': 0,
    'PAKAN': 0,
    'PAKE': 0,
    'PAKELE': 0,
    'PAKENHAM': 0,
    'PAKER': 0,
    'PAKES': 0,
    'PAKKALA': 0,
    'PAKULA': 0,
    'PAKULSKI': 0,
    'PAL': 0,
    'PALA': 0,
    'PALAC': 0,
    'PALACE': 0,
    'PALACIO': 0,
    'PALACIOS': 0,
    'PALACIOUS': 0,
    'PALACZ': 0,
    'PALAD': 0,
    'PALADIN': 0,
    'PALADINES': 0,
    'PALADINI': 0,
    'PALADINO': 0,
    'PALAFOX': 0,
    'PALAGANAS': 0,
    'PALAGI': 0,
    'PALAGONIA': 0,
    'PALAGUACHI': 0,
    'PALAGYI': 0,
    'PALAIA': 0,
    'PALAIMA': 0,
    'PALAKIKO': 0,
    'PALALAY': 0,
    'PALAMA': 0,
    'PALAMAR': 0,
    'PALAMARA': 0,
    'PALAN': 0,
    'PALANCA': 0,
    'PALANDRO': 0,
    'PALANGE': 0,
    'PALANIAPPAN': 0,
    'PALANIUK': 0,
    'PALANK': 0,
    'PALANZA': 0,
    'PALAO': 0,
    'PALARDY': 0,
    'PALAS': 0,
    'PALASCHAK': 0,
    'PALASEK': 0,
    'PALASIOS': 0,
    'PALASKI': 0,
    'PALASOTA': 0,
    'PALASZ': 0,
    'PALASZEWSKI': 0,
    'PALATINO': 0,
    'PALATNIK': 0,
    'PALATO': 0,
    'PALATUCCI': 0,
    'PALAU': 0,
    'PALAY': 0,
    'PALAZOLA': 0,
    'PALAZUELOS': 0,
    'PALAZZI': 0,
    'PALAZZO': 0,
    'PALAZZOLA': 0,
    'PALAZZOLO': 0,
    'PALAZZOTTO': 0,
    'PALCHAK': 0,
    'PALCHER': 0,
    'PALCIC': 0,
    'PALCZEWSKI': 0,
    'PALCZYNSKI': 0,
    'PALD': 0,
    'PALDINO': 0,
    'PALE': 0,
    'PALECEK': 0,
    'PALECKI': 0,
    'PALECZNY': 0,
    'PALEFSKY': 0,
    'PALEK': 0,
    'PALELLA': 0,
    'PALEN': 0,
    'PALENCAR': 0,
    'PALENCHAR': 0,
    'PALENCIA': 0,
    'PALENIK': 0,
    'PALENSKE': 0,
    'PALENSKY': 0,
    'PALENZUELA': 0,
    'PALEO': 0,
    'PALEOLOGOS': 0,
    'PALER': 0,
    'PALERMO': 0,
    'PALES': 0,
    'PALESANO': 0,
    'PALESE': 0,
    'PALESTINA': 0,
    'PALESTINI': 0,
    'PALESTINO': 0,
    'PALETTA': 0,
    'PALETZ': 0,
    'PALEY': 0,
    'PALFFY': 0,
    'PALFI': 0,
    'PALFREY': 0,
    'PALFREYMAN': 0,
    'PALFY': 0,
    'PALGUTA': 0,
    'PALI': 0,
    'PALIANI': 0,
    'PALIC': 0,
    'PALICKA': 0,
    'PALICKI': 0,
    'PALIGA': 0,
    'PALIK': 0,
    'PALILEO': 0,
    'PALILLA': 0,
    'PALIN': 0,
    'PALING': 0,
    'PALINKAS': 0,
    'PALINO': 0,
    'PALINSKI': 0,
    'PALINSKY': 0,
    'PALIOTTA': 0,
    'PALIOTTI': 0,
    'PALIS': 0,
    'PALISANO': 0,
    'PALISI': 0,
    'PALISIN': 0,
    'PALISOC': 0,
    'PALIT': 0,
    'PALIWODA': 0,
    'PALJEVIC': 0,
    'PALK': 0,
    'PALKA': 0,
    'PALKER': 0,
    'PALKKI': 0,
    'PALKO': 0,
    'PALKOVIC': 0,
    'PALKOVICH': 0,
    'PALKOWSKI': 0,
    'PALL': 0,
    'PALLA': 0,
    'PALLACK': 0,
    'PALLADINI': 0,
    'PALLADINO': 0,
    'PALLAIS': 0,
    'PALLAN': 0,
    'PALLANES': 0,
    'PALLANSCH': 0,
    'PALLANTE': 0,
    'PALLARDY': 0,
    'PALLARES': 0,
    'PALLAS': 0,
    'PALLAY': 0,
    'PALLAZOLA': 0,
    'PALLEN': 0,
    'PALLER': 0,
    'PALLESCHI': 0,
    'PALLESEN': 0,
    'PALLETT': 0,
    'PALLETTE': 0,
    'PALLEY': 0,
    'PALLI': 0,
    'PALLIN': 0,
    'PALLINI': 0,
    'PALLIS': 0,
    'PALLISER': 0,
    'PALLISTER': 0,
    'PALLITTO': 0,
    'PALLMAN': 0,
    'PALLO': 0,
    'PALLONE': 0,
    'PALLOTTA': 0,
    'PALLOTTI': 0,
    'PALLOTTO': 0,
    'PALLOZZI': 0,
    'PALLUCK': 0,
    'PALM': 0,
    'PALMA': 0.3605769230769231,
    'PALMACCI': 0,
    'PALMAN': 0,
    'PALMAR': 0,
    'PALMARES': 0,
    'PALMAS': 0,
    'PALMATARY': 0,
    'PALMATEER': 0,
    'PALMATIER': 0,
    'PALMBERG': 0,
    'PALMBOS': 0,
    'PALME': 0,
    'PALMEIRA': 0,
    'PALMEIRO': 0,
    'PALMEN': 0,
    'PALMER': 0.06693440428380187,
    'PALMERE': 0,
    'PALMERI': 0,
    'PALMERIN': 0,
    'PALMERINI': 0,
    'PALMERINO': 0,
    'PALMERO': 0,
    'PALMERSHEIM': 0,
    'PALMERTON': 0,
    'PALMERTREE': 0,
    'PALMES': 0,
    'PALMESE': 0,
    'PALMETER': 0,
    'PALMGREN': 0,
    'PALMI': 0,
    'PALMIER': 0,
    'PALMIERE': 0,
    'PALMIERI': 0,
    'PALMIERO': 0,
    'PALMINTERI': 0,
    'PALMIOTTO': 0,
    'PALMIRA': 1,
    'PALMISANO': 0,
    'PALMISCIANO': 0,
    'PALMITER': 0,
    'PALMO': 0,
    'PALMORE': 0,
    'PALMOUR': 0,
    'PALMOWSKI': 0,
    'PALMQUIST': 0,
    'PALMROSE': 0,
    'PALMS': 0,
    'PALMUCCI': 0,
    'PALO': 0,
    'PALODICHUK': 0,
    'PALOMA': 0,
    'PALOMAKI': 0,
    'PALOMAR': 0,
    'PALOMARES': 0,
    'PALOMAREZ': 0,
    'PALOMBA': 0,
    'PALOMBI': 0,
    'PALOMBO': 0,
    'PALOMEQUE': 0,
    'PALOMERA': 0,
    'PALOMIN': 0,
    'PALOMINO': 0,
    'PALOMINOS': 0,
    'PALOMO': 0,
    'PALONE': 0,
    'PALONIS': 0,
    'PALOPOLI': 0,
    'PALOS': 0,
    'PALOSAARI': 0,
    'PALOVICH': 0,
    'PALOZZI': 0,
    'PALPALLATOC': 0,
    'PALS': 0,
    'PALSA': 0,
    'PALSER': 0,
    'PALSGROVE': 0,
    'PALTE': 0,
    'PALTER': 0,
    'PALTON': 0,
    'PALTZ': 0,
    'PALTZER': 0,
    'PALU': 0,
    'PALUBICKI': 0,
    'PALUCCI': 0,
    'PALUCH': 0,
    'PALUCK': 0,
    'PALUCKI': 0,
    'PALUGA': 0,
    'PALUMBO': 0,
    'PALUS': 0,
    'PALUSHAJ': 0,
    'PALUSKA': 0,
    'PALUSO': 0,
    'PALUSZEK': 0,
    'PALUZZI': 0,
    'PALY': 0,
    'PALYA': 0,
    'PALYO': 0,
    'PALYS': 0,
    'PALZER': 0,
    'PALZKILL': 0,
    'PAM': 0.9935205183585313,
    'PAMA': 0,
    'PAMALA': 1,
    'PAMATZ': 0,
    'PAMBIANCHI': 0,
    'PAMELA': 0.9998557900302841,
    'PAMELIA': 1,
    'PAMELLA': 1,
    'PAMER': 0,
    'PAMILA': 1,
    'PAMINTUAN': 0,
    'PAMMER': 0,
    'PAMPALONE': 0,
    'PAMPEL': 0,
    'PAMPELL': 0,
    'PAMPENA': 0,
    'PAMPERIN': 0,
    'PAMPHILE': 0,
    'PAMPINELLA': 0,
    'PAMPLIN': 0,
    'PAMPLONA': 0,
    'PAMPUCH': 0,
    'PAMULA': 0.9433962264150944,
    'PAN': 0,
    'PANA': 0,
    'PANACCIONE': 0,
    'PANAGAKIS': 0,
    'PANAGAKOS': 0,
    'PANAGGIO': 0,
    'PANAGIOTIDIS': 0,
    'PANAGIOTOPOULOS': 0,
    'PANAGIOTOU': 0,
    'PANAGOPOULOS': 0,
    'PANAGOS': 0,
    'PANAH': 0,
    'PANAHI': 0,
    'PANAIA': 0,
    'PANAK': 0,
    'PANALIGAN': 0,
    'PANAMA': 0,
    'PANAMENO': 0,
    'PANARA': 0,
    'PANARELLA': 0,
    'PANARELLI': 0,
    'PANARELLO': 0,
    'PANARESE': 0,
    'PANARIELLO': 0,
    'PANARO': 0,
    'PANAS': 0,
    'PANASCI': 0,
    'PANASIUK': 0,
    'PANASUK': 0,
    'PANATTONI': 0,
    'PANAYIOTOU': 0,
    'PANCAKE': 0,
    'PANCARI': 0,
    'PANCER': 0,
    'PANCHAK': 0,
    'PANCHAL': 0,
    'PANCHANA': 0,
    'PANCHENKO': 0,
    'PANCHERI': 0,
    'PANCHO': 0,
    'PANCHOLI': 0,
    'PANCHOT': 0,
    'PANCIERA': 0,
    'PANCO': 0,
    'PANCOAST': 0,
    'PANCOE': 0,
    'PANCOST': 0,
    'PANCRATZ': 0,
    'PANCRAZIO': 0,
    'PANCZAK': 0,
    'PANCZYK': 0,
    'PANDA': 0,
    'PANDAY': 0,
    'PANDE': 0,
    'PANDER': 0,
    'PANDEY': 0,
    'PANDIAN': 0,
    'PANDISCIO': 0,
    'PANDIT': 0,
    'PANDO': 0,
    'PANDOLA': 0,
    'PANDOLFI': 0,
    'PANDOLFINO': 0,
    'PANDOLFO': 0,
    'PANDOLPH': 0,
    'PANDORA': 0.9803921568627452,
    'PANDORF': 0,
    'PANDURO': 0,
    'PANDY': 0,
    'PANDYA': 0,
    'PANE': 0,
    'PANEBIANCO': 0,
    'PANEDA': 0,
    'PANEK': 0,
    'PANELL': 0,
    'PANELLA': 0,
    'PANELLI': 0,
    'PANELO': 0,
    'PANEPINTO': 0,
    'PANEQUE': 0,
    'PANER': 0,
    'PANES': 0,
    'PANESAR': 0,
    'PANESSA': 0,
    'PANETH': 0,
    'PANETO': 0,
    'PANETTA': 0,
    'PANETTI': 0,
    'PANETTIERE': 0,
    'PANETTIERI': 0,
    'PANFIL': 0,
    'PANFILE': 0,
    'PANFILI': 0,
    'PANFILO': 0,
    'PANG': 0,
    'PANGALLO': 0,
    'PANGAN': 0,
    'PANGANIBAN': 0,
    'PANGBORN': 0,
    'PANGBURN': 0,
    'PANGELINA': 0,
    'PANGELINAN': 0,
    'PANGER': 0,
    'PANGERL': 0,
    'PANGIA': 0,
    'PANGILINAN': 0,
    'PANGLE': 0,
    'PANGMAN': 0,
    'PANGRAC': 0,
    'PANGRAZIO': 0,
    'PANHORST': 0,
    'PANI': 0,
    'PANIAGUA': 0,
    'PANIAN': 0,
    'PANIC': 0,
    'PANICCIA': 0,
    'PANICH': 0,
    'PANICHELLA': 0,
    'PANICHELLI': 0,
    'PANICHI': 0,
    'PANICI': 0,
    'PANICK': 0,
    'PANICKER': 0,
    'PANICO': 0,
    'PANICOLA': 0,
    'PANICUCCI': 0,
    'PANIGHETTI': 0,
    'PANIK': 0,
    'PANIPINTO': 0,
    'PANIS': 0,
    'PANISH': 0,
    'PANITCH': 0,
    'PANITZ': 0,
    'PANITZKE': 0,
    'PANIZZI': 0,
    'PANJWANI': 0,
    'PANK': 0,
    'PANKA': 0,
    'PANKAKE': 0,
    'PANKAU': 0,
    'PANKE': 0,
    'PANKEN': 0,
    'PANKEY': 0,
    'PANKHURST': 0,
    'PANKIEWICZ': 0,
    'PANKIW': 0,
    'PANKNIN': 0,
    'PANKO': 0,
    'PANKOKE': 0,
    'PANKONIEN': 0,
    'PANKONIN': 0,
    'PANKOW': 0,
    'PANKOWSKI': 0,
    'PANKRATZ': 0,
    'PANKS': 0,
    'PANKUCH': 0,
    'PANLILIO': 0,
    'PANN': 0,
    'PANNEBAKER': 0,
    'PANNEBECKER': 0,
    'PANNEL': 0,
    'PANNELL': 0,
    'PANNELLA': 0,
    'PANNER': 0,
    'PANNETON': 0,
    'PANNETT': 0,
    'PANNIER': 0,
    'PANNILL': 0,
    'PANNING': 0,
    'PANNKUK': 0,
    'PANNO': 0,
    'PANNONE': 0,
    'PANNOZZO': 0,
    'PANNU': 0,
    'PANNUCCI': 0,
    'PANNULLO': 0,
    'PANNUNZIO': 0,
    'PANO': 0,
    'PANOFF': 0,
    'PANOPIO': 0,
    'PANOPOULOS': 0,
    'PANORA': 0,
    'PANOS': 0,
    'PANOSH': 0,
    'PANOSIAN': 0,
    'PANOSSIAN': 0,
    'PANOSYAN': 0,
    'PANOV': 0,
    'PANOWICZ': 0,
    'PANOZZO': 0,
    'PANSA': 0,
    'PANSCH': 0,
    'PANSE': 0,
    'PANSEGRAU': 0,
    'PANSING': 0,
    'PANSINI': 0,
    'PANSKE': 0,
    'PANSY': 1,
    'PANT': 0,
    'PANTA': 0,
    'PANTAGES': 0,
    'PANTALENA': 0,
    'PANTALEO': 0,
    'PANTALEON': 0,
    'PANTALEONE': 0,
    'PANTALION': 0,
    'PANTALL': 0,
    'PANTALONE': 0,
    'PANTANO': 0,
    'PANTAZIS': 0,
    'PANTAZOPOULOS': 0,
    'PANTE': 0,
    'PANTEA': 0,
    'PANTEL': 0,
    'PANTELIDES': 0,
    'PANTELIS': 0,
    'PANTELL': 0,
    'PANTER': 0,
    'PANTERA': 0,
    'PANTHER': 0,
    'PANTIER': 0,
    'PANTIG': 0,
    'PANTIN': 0,
    'PANTINA': 0,
    'PANTING': 0,
    'PANTLE': 0,
    'PANTO': 0,
    'PANTOJA': 0,
    'PANTOJAS': 0,
    'PANTON': 0,
    'PANTONE': 0,
    'PANTOS': 0,
    'PANTOYA': 0,
    'PANTUSO': 0,
    'PANTZER': 0,
    'PANUCCI': 0,
    'PANUCCIO': 0,
    'PANUCO': 0,
    'PANUNZIO': 0,
    'PANUS': 0,
    'PANUSKA': 0,
    'PANY': 0,
    'PANYANOUVONG': 0,
    'PANYARD': 0,
    'PANZA': 0,
    'PANZARELLA': 0,
    'PANZARINO': 0,
    'PANZECA': 0,
    'PANZELLA': 0,
    'PANZER': 0,
    'PANZERA': 0,
    'PANZICA': 0,
    'PANZINI': 0,
    'PANZINO': 0,
    'PANZITTA': 0,
    'PANZNER': 0,
    'PANZO': 0,
    'PANZONE': 0,
    'PAO': 0,
    'PAOLA': 0.9404388714733541,
    'PAOLANTONIO': 0,
    'PAOLELLA': 0,
    'PAOLELLO': 0,
    'PAOLERCIO': 0,
    'PAOLETTA': 0,
    'PAOLETTI': 0,
    'PAOLI': 0,
    'PAOLICELLI': 0,
    'PAOLILLI': 0,
    'PAOLILLO': 0,
    'PAOLINI': 0,
    'PAOLINO': 0,
    'PAOLO': 0,
    'PAOLONE': 0,
    'PAOLONI': 0,
    'PAOLOZZI': 0,
    'PAOLUCCI': 0,
    'PAONE': 0,
    'PAONESSA': 0,
    'PAONI': 0,
    'PAP': 0,
    'PAPA': 0,
    'PAPAC': 0,
    'PAPADAKIS': 0,
    'PAPADAKOS': 0,
    'PAPADATOS': 0,
    'PAPADIMITRIOU': 0,
    'PAPADOPOULOS': 0,
    'PAPADOPULOS': 0,
    'PAPAGEORGE': 0,
    'PAPAGEORGIOU': 0,
    'PAPAGNI': 0,
    'PAPAGNO': 0,
    'PAPAI': 0,
    'PAPAIOANNOU': 0,
    'PAPAJ': 0,
    'PAPAJOHN': 0,
    'PAPAK': 0,
    'PAPALE': 0,
    'PAPALEO': 0,
    'PAPALIA': 0,
    'PAPALLO': 0,
    'PAPAMICHAEL': 0,
    'PAPAN': 0,
    'PAPANDREA': 0,
    'PAPANEK': 0,
    'PAPANIA': 0,
    'PAPANICOLAOU': 0,
    'PAPANIKOLAOU': 0,
    'PAPANTONIOU': 0,
    'PAPAPIETRO': 0,
    'PAPARAZZO': 0,
    'PAPARELLA': 0,
    'PAPARELLI': 0,
    'PAPARO': 0,
    'PAPARONE': 0,
    'PAPAS': 0,
    'PAPATHANASIOU': 0,
    'PAPAVASILIOU': 0,
    'PAPAY': 0,
    'PAPAZIAN': 0,
    'PAPAZOGLOU': 0,
    'PAPAZYAN': 0,
    'PAPCIAK': 0,
    'PAPCUN': 0,
    'PAPE': 0,
    'PAPEN': 0,
    'PAPENBERG': 0,
    'PAPENDICK': 0,
    'PAPENDORF': 0,
    'PAPENFUS': 0,
    'PAPENFUSS': 0,
    'PAPENHAUSEN': 0,
    'PAPER': 0,
    'PAPERA': 0,
    'PAPES': 0,
    'PAPESH': 0,
    'PAPETTI': 0,
    'PAPEZ': 0,
    'PAPI': 0,
    'PAPIA': 0,
    'PAPIC': 0,
    'PAPICH': 0,
    'PAPIER': 0,
    'PAPIERNIK': 0,
    'PAPIERSKI': 0,
    'PAPIEZ': 0,
    'PAPIK': 0,
    'PAPILE': 0,
    'PAPILLION': 0,
    'PAPILLO': 0,
    'PAPILLON': 0,
    'PAPIN': 0,
    'PAPINCHAK': 0,
    'PAPINEAU': 0,
    'PAPINI': 0,
    'PAPION': 0,
    'PAPISH': 0,
    'PAPKA': 0,
    'PAPKE': 0,
    'PAPLHAM': 0,
    'PAPLOW': 0,
    'PAPO': 0,
    'PAPOI': 0,
    'PAPOLA': 0,
    'PAPOUTSIS': 0,
    'PAPP': 0,
    'PAPPA': 0,
    'PAPPADAKIS': 0,
    'PAPPAGALLO': 0,
    'PAPPAGEORGE': 0,
    'PAPPALARDO': 0,
    'PAPPAN': 0,
    'PAPPANO': 0,
    'PAPPAS': 0,
    'PAPPE': 0,
    'PAPPENFUS': 0,
    'PAPPERT': 0,
    'PAPPILLION': 0,
    'PAPPIN': 0,
    'PAPPS': 0,
    'PAPPY': 0,
    'PAPRANIKU': 0,
    'PAPROCKI': 0,
    'PAPSON': 0,
    'PAPST': 0,
    'PAPSTEIN': 0,
    'PAPUGA': 0,
    'PAPULA': 0,
    'PAPWORTH': 0,
    'PAQUE': 0,
    'PAQUET': 0,
    'PAQUETTE': 0,
    'PAQUIN': 0,
    'PAR': 0,
    'PARA': 0,
    'PARACHA': 0,
    'PARACHE': 0,
    'PARACHINI': 0,
    'PARACUELLES': 0,
    'PARADA': 0,
    'PARADAY': 0,
    'PARADEE': 0,
    'PARADELA': 0,
    'PARADES': 0,
    'PARADIES': 0,
    'PARADINE': 0,
    'PARADIS': 0,
    'PARADISE': 0,
    'PARADISO': 0,
    'PARADO': 0,
    'PARADOWSKI': 0,
    'PARADY': 0,
    'PARAG': 0,
    'PARAGAS': 0,
    'PARAH': 0,
    'PARAISO': 0,
    'PARAISON': 0,
    'PARAJON': 0,
    'PARAL': 0,
    'PARALES': 0,
    'PARAMESWARAN': 0,
    'PARAMO': 0,
    'PARAMORE': 0,
    'PARAN': 0,
    'PARANA': 0,
    'PARANADA': 0,
    'PARANGAN': 0,
    'PARANTO': 0,
    'PARANZINO': 0,
    'PARAS': 0,
    'PARASCANDOLA': 0,
    'PARASCANDOLO': 0,
    'PARASHAR': 0,
    'PARASILITI': 0,
    'PARASKEVAS': 0,
    'PARASRAM': 0,
    'PARATO': 0,
    'PARATORE': 0,
    'PARAVATI': 0,
    'PARAY': 0,
    'PARAYNO': 0,
    'PARAZ': 0,
    'PARAZOO': 0,
    'PARBS': 0,
    'PARCE': 0,
    'PARCEL': 0,
    'PARCELL': 0,
    'PARCELLS': 0,
    'PARCELS': 0,
    'PARCHEM': 0,
    'PARCHEN': 0,
    'PARCHER': 0,
    'PARCHERT': 0,
    'PARCHMAN': 0,
    'PARCHMENT': 0,
    'PARCIAK': 0,
    'PARCO': 0,
    'PARCUS': 0,
    'PARDA': 0,
    'PARDE': 0,
    'PARDEE': 0,
    'PARDEN': 0,
    'PARDES': 0,
    'PARDEW': 0,
    'PARDI': 0,
    'PARDIECK': 0,
    'PARDILLA': 0,
    'PARDILLO': 0,
    'PARDINAS': 0,
    'PARDINI': 0,
    'PARDO': 0,
    'PARDOE': 0,
    'PARDON': 0,
    'PARDUCCI': 0,
    'PARDUE': 0,
    'PARDUHN': 0,
    'PARDUN': 0,
    'PARDUS': 0,
    'PARDY': 0,
    'PARE': 0,
    'PARECE': 0,
    'PAREDES': 0,
    'PAREDEZ': 0,
    'PAREE': 0,
    'PAREJA': 0,
    'PAREKH': 0,
    'PAREL': 0,
    'PARELLA': 0,
    'PARELLI': 0,
    'PARELLO': 0,
    'PARENT': 0,
    'PARENTE': 0,
    'PARENTEAU': 0,
    'PARENTI': 0,
    'PARES': 0,
    'PARESA': 0,
    'PARESE': 0,
    'PARET': 0,
    'PARETI': 0,
    'PARETS': 0,
    'PARETTE': 0,
    'PARETTI': 0,
    'PAREZ': 0,
    'PARFAIT': 0,
    'PARFET': 0,
    'PARFITT': 0,
    'PARFREY': 0,
    'PARGA': 0,
    'PARGAS': 0,
    'PARGEON': 0,
    'PARGO': 0,
    'PARHAM': 0,
    'PARHAR': 0,
    'PARHM': 0,
    'PARI': 0,
    'PARIAN': 0,
    'PARIANI': 0,
    'PARIDO': 0,
    'PARIDON': 0,
    'PARIENTE': 0,
    'PARIETTI': 0,
    'PARIKH': 0,
    'PARILLA': 0,
    'PARILLO': 0,
    'PARIN': 0,
    'PARINAS': 0,
    'PARINI': 0,
    'PARINS': 0,
    'PARIS': 0.5291005291005291,
    'PARISE': 0,
    'PARISEAU': 0,
    'PARISEK': 0,
    'PARISELLA': 0,
    'PARISEN': 0,
    'PARISER': 0,
    'PARISH': 0,
    'PARISHER': 0,
    'PARISI': 0,
    'PARISIAN': 0,
    'PARISIEN': 0,
    'PARISIO': 0,
    'PARISO': 0,
    'PARISON': 0,
    'PARISOT': 0,
    'PARISOTTO': 0,
    'PARISSE': 0,
    'PARIZEK': 0,
    'PARIZO': 0,
    'PARK': 0,
    'PARKASH': 0,
    'PARKE': 0,
    'PARKEN': 0,
    'PARKER': 0.047543581616481784,
    'PARKERSON': 0,
    'PARKES': 0,
    'PARKEY': 0,
    'PARKHILL': 0,
    'PARKHOUSE': 0,
    'PARKHURST': 0,
    'PARKIN': 0,
    'PARKINGTON': 0,
    'PARKINS': 0,
    'PARKINSON': 0,
    'PARKIS': 0,
    'PARKISON': 0,
    'PARKKONEN': 0,
    'PARKMAN': 0,
    'PARKO': 0,
    'PARKOS': 0,
    'PARKS': 0,
    'PARKYN': 0,
    'PARLA': 0,
    'PARLANTE': 0,
    'PARLANTI': 0,
    'PARLAPIANO': 0,
    'PARLATO': 0,
    'PARLATORE': 0,
    'PARLE': 0,
    'PARLEE': 0,
    'PARLER': 0,
    'PARLET': 0,
    'PARLETT': 0,
    'PARLETTE': 0,
    'PARLEY': 0,
    'PARLI': 0,
    'PARLIAMENT': 0,
    'PARLIER': 0,
    'PARLIMAN': 0,
    'PARLIN': 0,
    'PARLO': 0,
    'PARLOR': 0,
    'PARLOW': 0,
    'PARM': 0,
    'PARMA': 0,
    'PARMALEE': 0,
    'PARMAN': 0,
    'PARMAR': 0,
    'PARMELE': 0,
    'PARMELEE': 0,
    'PARMELEY': 0,
    'PARMELY': 0,
    'PARMENTER': 0,
    'PARMENTIER': 0,
    'PARMER': 0,
    'PARMERLEE': 0,
    'PARMET': 0,
    'PARMETER': 0,
    'PARMIGIANI': 0,
    'PARMITER': 0,
    'PARMLEY': 0,
    'PARMS': 0,
    'PARNAS': 0,
    'PARNELL': 0,
    'PARNES': 0,
    'PARNESS': 0,
    'PARNHAM': 0,
    'PARNIN': 0,
    'PARNOW': 0,
    'PARO': 0,
    'PAROBEK': 0,
    'PAROCUA': 0,
    'PARODI': 0,
    'PARODY': 0,
    'PAROLA': 0,
    'PAROLINE': 0,
    'PAROLINI': 0,
    'PAROLISI': 0,
    'PARON': 0,
    'PARONE': 0,
    'PARONISH': 0,
    'PARONTO': 0,
    'PAROS': 0,
    'PAROT': 0,
    'PAROW': 0,
    'PARPART': 0,
    'PARQUET': 0,
    'PARQUETTE': 0,
    'PARR': 0,
    'PARRA': 0,
    'PARRACK': 0,
    'PARRADO': 0,
    'PARRAGA': 0,
    'PARRAL': 0,
    'PARRALES': 0,
    'PARRAM': 0,
    'PARRAMORE': 0,
    'PARRAN': 0,
    'PARRAS': 0,
    'PARRATT': 0,
    'PARRAZ': 0,
    'PARREIRA': 0,
    'PARRELL': 0,
    'PARRELLA': 0,
    'PARRELLI': 0,
    'PARREN': 0,
    'PARRENO': 0,
    'PARRENT': 0,
    'PARRES': 0,
    'PARRET': 0,
    'PARRETT': 0,
    'PARRETTE': 0,
    'PARRICK': 0,
    'PARRIE': 0,
    'PARRIES': 0,
    'PARRIGAN': 0,
    'PARRIGIN': 0,
    'PARRILL': 0,
    'PARRILLA': 0,
    'PARRILLI': 0,
    'PARRILLO': 0,
    'PARRINELLO': 0,
    'PARRINGTON': 0,
    'PARRINO': 0,
    'PARRIOTT': 0,
    'PARRIS': 0,
    'PARRISH': 0,
    'PARRITT': 0,
    'PARRO': 0,
    'PARRON': 0,
    'PARRONE': 0,
    'PARROT': 0,
    'PARROTT': 0,
    'PARROTTA': 0,
    'PARROTTE': 0,
    'PARROW': 0,
    'PARRY': 0,
    'PARSA': 0,
    'PARSCAL': 0,
    'PARSCH': 0,
    'PARSE': 0,
    'PARSEGHIAN': 0,
    'PARSELL': 0,
    'PARSELLS': 0,
    'PARSELS': 0,
    'PARSH': 0,
    'PARSHALL': 0,
    'PARSHLEY': 0,
    'PARSI': 0,
    'PARSLEY': 0,
    'PARSLOW': 0,
    'PARSON': 0,
    'PARSONAGE': 0,
    'PARSONS': 0,
    'PART': 0,
    'PARTAIN': 0,
    'PARTANEN': 0,
    'PARTCH': 0,
    'PARTEE': 0,
    'PARTELLO': 0,
    'PARTELOW': 0,
    'PARTEN': 0,
    'PARTENHEIMER': 0,
    'PARTER': 0,
    'PARTHASARATHY': 0,
    'PARTHEMER': 0,
    'PARTHEMORE': 0,
    'PARTHENIA': 1,
    'PARTHUM': 0,
    'PARTICIA': 1,
    'PARTIDA': 0,
    'PARTIDO': 0,
    'PARTIKA': 0,
    'PARTIN': 0,
    'PARTINGTON': 0,
    'PARTIPILO': 0,
    'PARTIS': 0,
    'PARTLO': 0,
    'PARTLOW': 0,
    'PARTMAN': 0,
    'PARTNER': 0,
    'PARTNEY': 0,
    'PARTON': 0,
    'PARTOVI': 0,
    'PARTRICK': 0,
    'PARTRIDGE': 0,
    'PARTSCH': 0,
    'PARTUSCH': 0,
    'PARTYKA': 0,
    'PARUCH': 0,
    'PARUCHURI': 0,
    'PARULIS': 0,
    'PARULSKI': 0,
    'PARUM': 0,
    'PARUNGAO': 0,
    'PARUOLO': 0,
    'PARUS': 0,
    'PARUSZKIEWICZ': 0,
    'PARUTA': 0,
    'PARVEEN': 0,
    'PARVEY': 0,
    'PARVEZ': 0,
    'PARVIN': 0,
    'PARVIS': 0,
    'PARVIZI': 0,
    'PARY': 0,
    'PARYLAK': 0,
    'PARYS': 0,
    'PARZANESE': 0,
    'PARZIALE': 0,
    'PARZYCH': 0,
    'PARZYCK': 0,
    'PARZYGNAT': 0,
    'PARZYNSKI': 0,
    'PAS': 0,
    'PASA': 0,
    'PASAG': 0,
    'PASALO': 0,
    'PASAMONTE': 0,
    'PASANEN': 0,
    'PASAY': 0,
    'PASAYE': 0,
    'PASBRIG': 0,
    'PASCACIO': 0,
    'PASCAL': 0,
    'PASCALE': 0,
    'PASCALI': 0,
    'PASCALL': 0,
    'PASCARELLA': 0,
    'PASCARELLI': 0,
    'PASCASCIO': 0,
    'PASCASIO': 0,
    'PASCAVAGE': 0,
    'PASCENTE': 0,
    'PASCERI': 0,
    'PASCH': 0,
    'PASCHAL': 0,
    'PASCHALL': 0,
    'PASCHE': 0,
    'PASCHEL': 0,
    'PASCHEN': 0,
    'PASCHKE': 0,
    'PASCIAK': 0,
    'PASCIUTO': 0,
    'PASCO': 0,
    'PASCOAL': 0,
    'PASCOE': 0,
    'PASCONE': 0,
    'PASCU': 0,
    'PASCUA': 0,
    'PASCUAL': 0,
    'PASCUCCI': 0,
    'PASCULLI': 0,
    'PASCUZZI': 0,
    'PASCUZZO': 0,
    'PASE': 0,
    'PASEK': 0,
    'PASEKA': 0,
    'PASELA': 0,
    'PASEUR': 0,
    'PASH': 0,
    'PASHA': 0,
    'PASHAK': 0,
    'PASHBY': 0,
    'PASHIA': 0,
    'PASHKO': 0,
    'PASHLEY': 0,
    'PASHO': 0,
    'PASHOLK': 0,
    'PASHOS': 0,
    'PASI': 0,
    'PASIA': 0,
    'PASIC': 0,
    'PASIEKA': 0,
    'PASIERB': 0,
    'PASIK': 0,
    'PASILLAS': 0,
    'PASINI': 0,
    'PASINSKI': 0,
    'PASION': 0,
    'PASIUK': 0,
    'PASK': 0,
    'PASKA': 0,
    'PASKE': 0,
    'PASKEL': 0,
    'PASKELL': 0,
    'PASKER': 0,
    'PASKERT': 0,
    'PASKET': 0,
    'PASKETT': 0,
    'PASKEWITZ': 0,
    'PASKEY': 0,
    'PASKIEWICZ': 0,
    'PASKIN': 0,
    'PASKINS': 0,
    'PASKO': 0,
    'PASKOFF': 0,
    'PASKOW': 0,
    'PASKOWITZ': 0,
    'PASKOWSKI': 0,
    'PASKUS': 0,
    'PASKVAN': 0,
    'PASKY': 0,
    'PASLAWSKI': 0,
    'PASLAY': 0,
    'PASLEY': 0,
    'PASMA': 0,
    'PASMAN': 0,
    'PASMORE': 0,
    'PASNIK': 0,
    'PASO': 0,
    'PASOL': 0,
    'PASON': 0,
    'PASOS': 0,
    'PASOUR': 0,
    'PASOWICZ': 0,
    'PASQUA': 0,
    'PASQUAL': 0,
    'PASQUALE': 0.8547008547008547,
    'PASQUALETTI': 0,
    'PASQUALETTO': 0,
    'PASQUALI': 0,
    'PASQUALICCHIO': 0,
    'PASQUALINI': 0,
    'PASQUALINO': 0,
    'PASQUALONE': 0,
    'PASQUALUCCI': 0,
    'PASQUANTONIO': 0,
    'PASQUARELLA': 0,
    'PASQUARELLI': 0,
    'PASQUARELLO': 0,
    'PASQUARIELLO': 0,
    'PASQUAROSA': 0,
    'PASQUE': 0,
    'PASQUEL': 0,
    'PASQUERELLA': 0,
    'PASQUESI': 0,
    'PASQUIER': 0,
    'PASQUIN': 0,
    'PASQUINELLI': 0,
    'PASQUINI': 0,
    'PASQUINO': 0,
    'PASRICHA': 0,
    'PASS': 0,
    'PASSA': 0,
    'PASSAFIUME': 0,
    'PASSAGE': 0,
    'PASSAGLIA': 0,
    'PASSALACQUA': 0,
    'PASSALAQUA': 0,
    'PASSAMONTE': 0,
    'PASSANANTE': 0,
    'PASSANISI': 0,
    'PASSANNANTE': 0,
    'PASSANO': 0,
    'PASSANTE': 0,
    'PASSANTINO': 0,
    'PASSARELL': 0,
    'PASSARELLA': 0,
    'PASSARELLI': 0,
    'PASSARELLO': 0,
    'PASSARETTI': 0,
    'PASSARIELLO': 0,
    'PASSARO': 0,
    'PASSAS': 0,
    'PASSAUER': 0,
    'PASSE': 0,
    'PASSEHL': 0,
    'PASSELL': 0,
    'PASSEN': 0,
    'PASSENO': 0,
    'PASSER': 0,
    'PASSERI': 0,
    'PASSERINI': 0,
    'PASSERO': 0,
    'PASSETTI': 0,
    'PASSEY': 0,
    'PASSI': 0,
    'PASSICK': 0,
    'PASSIG': 0,
    'PASSINEAU': 0,
    'PASSINI': 0,
    'PASSINO': 0,
    'PASSIONE': 0,
    'PASSLER': 0,
    'PASSLEY': 0,
    'PASSMAN': 0,
    'PASSMORE': 0,
    'PASSO': 0,
    'PASSON': 0,
    'PASSONS': 0,
    'PASSOS': 0,
    'PASSOW': 0,
    'PASSWATER': 0,
    'PASSWATERS': 0,
    'PAST': 0,
    'PASTA': 0,
    'PASTEL': 0,
    'PASTELLA': 0,
    'PASTEN': 0,
    'PASTENA': 0,
    'PASTER': 0,
    'PASTERCZYK': 0,
    'PASTERICK': 0,
    'PASTERIS': 0,
    'PASTERNACK': 0,
    'PASTERNAK': 0,
    'PASTERSKI': 0,
    'PASTEUR': 0,
    'PASTIAN': 0,
    'PASTIR': 0,
    'PASTIRIK': 0,
    'PASTO': 0,
    'PASTON': 0,
    'PASTOOR': 0,
    'PASTOR': 0,
    'PASTORA': 0,
    'PASTORE': 0,
    'PASTOREK': 0,
    'PASTORELLA': 0,
    'PASTORELLI': 0,
    'PASTORELLO': 0,
    'PASTORES': 0,
    'PASTORI': 0,
    'PASTORIA': 0,
    'PASTORINO': 0,
    'PASTORIUS': 0,
    'PASTORIZA': 0,
    'PASTRAN': 0,
    'PASTRANA': 0,
    'PASTRANO': 0,
    'PASTRE': 0,
    'PASTRICK': 0,
    'PASTUCH': 0,
    'PASTUCHA': 0,
    'PASTULA': 0,
    'PASTUSZAK': 0,
    'PASTVA': 0,
    'PASTY': 1,
    'PASWATERS': 0,
    'PASZEK': 0,
    'PASZKIEWICZ': 0,
    'PASZKO': 0,
    'PASZKOWSKI': 0,
    'PASZTOR': 0,
    'PAT': 0.9974259974259974,
    'PATA': 0,
    'PATACSIL': 0,
    'PATAFIO': 0,
    'PATAGUE': 0,
    'PATAK': 0,
    'PATAKI': 0,
    'PATAKY': 0,
    'PATAL': 0,
    'PATALANO': 0,
    'PATALON': 0,
    'PATANE': 0,
    'PATANELLA': 0,
    'PATANIA': 0,
    'PATANKAR': 0,
    'PATANO': 0,
    'PATAO': 0,
    'PATASKA': 0,
    'PATAT': 0,
    'PATAWARAN': 0,
    'PATCH': 0,
    'PATCHAK': 0,
    'PATCHAN': 0,
    'PATCHEL': 0,
    'PATCHELL': 0,
    'PATCHEN': 0,
    'PATCHES': 0,
    'PATCHETT': 0,
    'PATCHIN': 0,
    'PATE': 0,
    'PATEE': 0,
    'PATEFIELD': 0,
    'PATEK': 0,
    'PATEL': 0,
    'PATELLA': 0,
    'PATELLIS': 0,
    'PATEN': 0,
    'PATENA': 0,
    'PATENAUDE': 0,
    'PATENT': 0,
    'PATER': 0,
    'PATERA': 0,
    'PATERAKIS': 0,
    'PATERAS': 0,
    'PATEREK': 0,
    'PATERICK': 0,
    'PATERNA': 0,
    'PATERNI': 0,
    'PATERNITI': 0,
    'PATERNO': 0,
    'PATERNOSTER': 0,
    'PATERNOSTRO': 0,
    'PATERRA': 0,
    'PATERSON': 0,
    'PATES': 0,
    'PATETE': 0,
    'PATEY': 0,
    'PATH': 0,
    'PATHAK': 0,
    'PATHAMMAVONG': 0,
    'PATHAN': 0,
    'PATI': 0,
    'PATIDAR': 0,
    'PATIENCE': 0.9302325581395349,
    'PATIENT': 0,
    'PATIERNO': 0,
    'PATIK': 0,
    'PATIL': 0,
    'PATILLA': 0,
    'PATILLO': 0,
    'PATIN': 0,
    'PATINA': 0,
    'PATINELLA': 0,
    'PATINO': 0,
    'PATIO': 0,
    'PATIRE': 0,
    'PATITUCCI': 0,
    'PATKA': 0,
    'PATKE': 0,
    'PATKO': 0,
    'PATLA': 0,
    'PATLAN': 0,
    'PATMAN': 0,
    'PATMON': 0,
    'PATMORE': 0,
    'PATNAIK': 0,
    'PATNAUDE': 0,
    'PATNEAUDE': 0,
    'PATNETT': 0,
    'PATNO': 0,
    'PATNODE': 0,
    'PATNOE': 0,
    'PATO': 0,
    'PATOCKA': 0,
    'PATOINE': 0,
    'PATOKA': 0,
    'PATON': 0,
    'PATOUT': 0,
    'PATRA': 0,
    'PATRAM': 0,
    'PATRANELLA': 0,
    'PATRAS': 0,
    'PATRAW': 0,
    'PATRI': 0,
    'PATRIA': 0.9174311926605505,
    'PATRIARCA': 0,
    'PATRIAS': 0,
    'PATRIC': 0,
    'PATRICA': 1,
    'PATRICE': 0.9961685823754788,
    'PATRICELLI': 0,
    'PATRICH': 0,
    'PATRICIA': 0.999712246242957,
    'PATRICIAL': 0,
    'PATRICIAN': 0,
    'PATRICIO': 0,
    'PATRICK': 0.9477756286266924,
    'PATRICKS': 0,
    'PATRICO': 0,
    'PATRICOLA': 0,
    'PATRIDGE': 0,
    'PATRIE': 0,
    'PATRIN': 0,
    'PATRINA': 1,
    'PATRIQUIN': 0,
    'PATRISSI': 0,
    'PATRIZI': 0,
    'PATRIZIO': 0,
    'PATRIZZI': 0,
    'PATRO': 0,
    'PATROCINIO': 0,
    'PATRON': 0,
    'PATRONE': 0,
    'PATRONI': 0,
    'PATRONIK': 0,
    'PATRONIS': 0,
    'PATROS': 0,
    'PATROW': 0,
    'PATRUM': 0,
    'PATRUNO': 0,
    'PATRY': 0,
    'PATRYLAK': 0,
    'PATRYN': 0,
    'PATSCH': 0,
    'PATSCHKE': 0,
    'PATSEL': 0,
    'PATSEY': 0,
    'PATSKO': 0,
    'PATSON': 0,
    'PATSOS': 0,
    'PATSY': 0.9985547234266194,
    'PATT': 0,
    'PATTAN': 0,
    'PATTAVINA': 0,
    'PATTE': 0,
    'PATTEE': 0,
    'PATTEN': 0,
    'PATTENAUDE': 0,
    'PATTENGALE': 0,
    'PATTER': 0,
    'PATTERMANN': 0,
    'PATTERS': 0,
    'PATTERSON': 0,
    'PATTESON': 0,
    'PATTI': 0.9533201840894148,
    'PATTIE': 0.9695290858725761,
    'PATTILLO': 0,
    'PATTIN': 0,
    'PATTINSON': 0,
    'PATTIS': 0,
    'PATTISHALL': 0,
    'PATTISON': 0,
    'PATTMAN': 0,
    'PATTOCK': 0,
    'PATTON': 0,
    'PATTRIDGE': 0,
    'PATTS': 0,
    'PATTULLO': 0,
    'PATTY': 0.9739524348810872,
    'PATTYN': 0,
    'PATULA': 0,
    'PATULLO': 0,
    'PATULSKI': 0,
    'PATURZO': 0,
    'PATUTO': 0,
    'PATWA': 0,
    'PATWARDHAN': 0,
    'PATWARY': 0,
    'PATWELL': 0,
    'PATY': 0,
    'PATYK': 0,
    'PATZ': 0,
    'PATZAN': 0,
    'PATZELT': 0,
    'PATZER': 0,
    'PATZKE': 0,
    'PATZKOWSKY': 0,
    'PATZLAFF': 0,
    'PATZNER': 0,
    'PATZWALD': 0,
    'PAU': 0,
    'PAUCAR': 0,
    'PAUDA': 0,
    'PAUER': 0,
    'PAUFF': 0,
    'PAUGH': 0,
    'PAUK': 0,
    'PAUKEN': 0,
    'PAUKER': 0,
    'PAUKERT': 0,
    'PAUKNER': 0,
    'PAUKOVITS': 0,
    'PAUL': 0.972611425883123,
    'PAULA': 0.9974259974259974,
    'PAULAS': 0,
    'PAULAT': 0,
    'PAULAUSKAS': 0,
    'PAULDINE': 0,
    'PAULDING': 0,
    'PAULDO': 0,
    'PAULE': 0,
    'PAULEMON': 0,
    'PAULEN': 0,
    'PAULENE': 1,
    'PAULER': 0,
    'PAULES': 0,
    'PAULET': 0,
    'PAULETICH': 0,
    'PAULETT': 0,
    'PAULETTA': 1,
    'PAULETTE': 0.990916597853014,
    'PAULETTI': 0,
    'PAULETTO': 0,
    'PAULEY': 0,
    'PAULHAMUS': 0,
    'PAULHILL': 0,
    'PAULHUS': 0,
    'PAULI': 0,
    'PAULIC': 0,
    'PAULICH': 0,
    'PAULICK': 0,
    'PAULIE': 0,
    'PAULIK': 0,
    'PAULIN': 0,
    'PAULINA': 0.986842105263158,
    'PAULINE': 0.9977625929733326,
    'PAULING': 0,
    'PAULINI': 0,
    'PAULINO': 0,
    'PAULINSKI': 0,
    'PAULIS': 0,
    'PAULISH': 0,
    'PAULISON': 0,
    'PAULITA': 1,
    'PAULK': 0,
    'PAULL': 0,
    'PAULLEY': 0,
    'PAULLIN': 0,
    'PAULLUS': 0,
    'PAULMAN': 0,
    'PAULO': 0,
    'PAULOS': 0,
    'PAULOSE': 0,
    'PAULOSKI': 0,
    'PAULOVICH': 0,
    'PAULS': 0,
    'PAULSELL': 0,
    'PAULSEN': 0,
    'PAULSON': 0,
    'PAULSRUD': 0,
    'PAULTON': 0,
    'PAULUCCI': 0,
    'PAULUS': 0,
    'PAULY': 0,
    'PAULZINE': 0,
    'PAUMEN': 0,
    'PAUMIER': 0,
    'PAUN': 0,
    'PAUP': 0,
    'PAUR': 0,
    'PAURA': 0,
    'PAUS': 0,
    'PAUSCH': 0,
    'PAUSE': 0,
    'PAUST': 0,
    'PAUSTIAN': 0,
    'PAUTA': 0,
    'PAUTLER': 0,
    'PAUTSCH': 0,
    'PAUTZ': 0,
    'PAUTZKE': 0,
    'PAUWELS': 0,
    'PAUZA': 0,
    'PAUZE': 0,
    'PAV': 0,
    'PAVA': 0,
    'PAVAN': 0,
    'PAVANO': 0,
    'PAVAO': 0,
    'PAVEGLIO': 0,
    'PAVEK': 0,
    'PAVEL': 0,
    'PAVELA': 0,
    'PAVELCHAK': 0,
    'PAVELEC': 0,
    'PAVELEK': 0,
    'PAVELICH': 0,
    'PAVELKA': 0,
    'PAVELKO': 0,
    'PAVELL': 0,
    'PAVELOCK': 0,
    'PAVELSKI': 0,
    'PAVER': 0,
    'PAVESE': 0,
    'PAVESI': 0,
    'PAVESICH': 0,
    'PAVEY': 0,
    'PAVIA': 0,
    'PAVIC': 0,
    'PAVICH': 0,
    'PAVICIC': 0,
    'PAVICK': 0,
    'PAVIK': 0,
    'PAVILONIS': 0,
    'PAVIN': 0,
    'PAVIS': 0,
    'PAVITT': 0,
    'PAVKOV': 0,
    'PAVKOVICH': 0,
    'PAVLACKA': 0,
    'PAVLAK': 0,
    'PAVLAKIS': 0,
    'PAVLAKOS': 0,
    'PAVLAS': 0,
    'PAVLAT': 0,
    'PAVLATOS': 0,
    'PAVLENKO': 0,
    'PAVLETICH': 0,
    'PAVLIC': 0,
    'PAVLICA': 0,
    'PAVLICEK': 0,
    'PAVLICH': 0,
    'PAVLICK': 0,
    'PAVLIDES': 0,
    'PAVLIDIS': 0,
    'PAVLIK': 0,
    'PAVLIN': 0,
    'PAVLINA': 0,
    'PAVLIS': 0,
    'PAVLISH': 0,
    'PAVLO': 0,
    'PAVLOCK': 0,
    'PAVLOFF': 0,
    'PAVLOS': 0,
    'PAVLOSKI': 0,
    'PAVLOSKY': 0,
    'PAVLOU': 0,
    'PAVLOV': 0,
    'PAVLOVA': 0,
    'PAVLOVIC': 0,
    'PAVLOVICH': 0,
    'PAVLOVSKI': 0,
    'PAVLOVSKY': 0,
    'PAVLOW': 0,
    'PAVLU': 0,
    'PAVLUS': 0,
    'PAVOLINI': 0,
    'PAVOLKO': 0,
    'PAVON': 0,
    'PAVONE': 0,
    'PAVONI': 0,
    'PAVUK': 0,
    'PAVUR': 0,
    'PAVY': 0,
    'PAW': 0,
    'PAWAR': 0,
    'PAWELA': 0,
    'PAWELCZAK': 0,
    'PAWELCZYK': 0,
    'PAWELEC': 0,
    'PAWELEK': 0,
    'PAWELK': 0,
    'PAWELKO': 0,
    'PAWELSKI': 0,
    'PAWL': 0,
    'PAWLACZYK': 0,
    'PAWLAK': 0,
    'PAWLEY': 0,
    'PAWLICK': 0,
    'PAWLICKI': 0,
    'PAWLIK': 0,
    'PAWLIKOWSKI': 0,
    'PAWLINA': 0,
    'PAWLING': 0,
    'PAWLOSKI': 0,
    'PAWLOW': 0,
    'PAWLOWICZ': 0,
    'PAWLOWSKI': 0,
    'PAWLUK': 0,
    'PAWLUS': 0,
    'PAWLYK': 0,
    'PAWSON': 0,
    'PAX': 0,
    'PAXINOS': 0,
    'PAXMAN': 0,
    'PAXON': 0,
    'PAXOS': 0,
    'PAXSON': 0,
    'PAXTON': 0,
    'PAXTOR': 0,
    'PAY': 0,
    'PAYA': 0,
    'PAYAMPS': 0,
    'PAYAN': 0,
    'PAYANO': 0,
    'PAYANT': 0,
    'PAYARES': 0,
    'PAYAWAL': 0,
    'PAYDEN': 0,
    'PAYE': 0,
    'PAYEA': 0,
    'PAYEN': 0,
    'PAYER': 0,
    'PAYERO': 0,
    'PAYES': 0,
    'PAYETTE': 0,
    'PAYEUR': 0,
    'PAYLOR': 0,
    'PAYMENT': 0,
    'PAYN': 0,
    'PAYNE': 0,
    'PAYNES': 0,
    'PAYNO': 0,
    'PAYNTER': 0,
    'PAYO': 0,
    'PAYONK': 0,
    'PAYOR': 0,
    'PAYSEN': 0,
    'PAYSENO': 0,
    'PAYSEUR': 0,
    'PAYSINGER': 0,
    'PAYSON': 0,
    'PAYSOUR': 0,
    'PAYSSE': 0,
    'PAYTAS': 0,
    'PAYTE': 0,
    'PAYTES': 0,
    'PAYTON': 0,
    'PAYUMO': 0,
    'PAYZANT': 0,
    'PAZ': 0.13175230566534915,
    'PAZAR': 0,
    'PAZDAN': 0,
    'PAZDERA': 0,
    'PAZDERNIK': 0,
    'PAZERA': 0,
    'PAZIENZA': 0,
    'PAZIK': 0,
    'PAZIN': 0,
    'PAZMINO': 0,
    'PAZO': 0,
    'PAZOS': 0,
    'PAZOUR': 0,
    'PAZZAGLIA': 0,
    'PE': 0,
    'PEA': 0,
    'PEABODY': 0,
    'PEACE': 0,
    'PEACEMAKER': 0,
    'PEACH': 0,
    'PEACHEE': 0,
    'PEACHER': 0,
    'PEACHES': 0,
    'PEACHEY': 0,
    'PEACHY': 0,
    'PEACO': 0,
    'PEACOCK': 0,
    'PEAD': 0,
    'PEADEN': 0,
    'PEAGLER': 0,
    'PEAIRS': 0,
    'PEAK': 0,
    'PEAKE': 0,
    'PEAKER': 0,
    'PEAKES': 0,
    'PEAKS': 0,
    'PEAL': 0,
    'PEALE': 0,
    'PEALER': 0,
    'PEALO': 0,
    'PEALS': 0,
    'PEAN': 0,
    'PEAR': 0,
    'PEARCE': 0,
    'PEARCEY': 0,
    'PEARCH': 0,
    'PEARCY': 0,
    'PEARD': 0,
    'PEARDON': 0,
    'PEARE': 0,
    'PEARISH': 0,
    'PEARISON': 0,
    'PEARL': 0.9714758164530798,
    'PEARLE': 0.9756097560975611,
    'PEARLENE': 1,
    'PEARLEY': 0,
    'PEARLIE': 1,
    'PEARLINE': 1,
    'PEARLMAN': 0,
    'PEARLMUTTER': 0,
    'PEARLSTEIN': 0,
    'PEARLY': 1,
    'PEARMAN': 0,
    'PEARN': 0,
    'PEARO': 0,
    'PEARRE': 0,
    'PEARRELL': 0,
    'PEARROW': 0,
    'PEARS': 0,
    'PEARSALL': 0,
    'PEARSE': 0,
    'PEARSEY': 0,
    'PEARSON': 0,
    'PEARSONS': 0,
    'PEART': 0,
    'PEARTREE': 0,
    'PEARY': 0,
    'PEASANT': 0,
    'PEASE': 0,
    'PEASLEE': 0,
    'PEASLEY': 0,
    'PEASON': 0,
    'PEASTER': 0,
    'PEAT': 0,
    'PEATE': 0,
    'PEATMAN': 0,
    'PEATROSS': 0,
    'PEATROWSKY': 0,
    'PEATTIE': 0,
    'PEAVEY': 0,
    'PEAVIE': 0,
    'PEAVLER': 0,
    'PEAVLEY': 0,
    'PEAVY': 0,
    'PEAVYHOUSE': 0,
    'PEAY': 0,
    'PEBBLES': 0,
    'PEBENITO': 0,
    'PEBLER': 0,
    'PEBLEY': 0,
    'PEBSWORTH': 0,
    'PEBWORTH': 0,
    'PEC': 0,
    'PECA': 0,
    'PECAK': 0,
    'PECAR': 0,
    'PECAUT': 0,
    'PECCHIA': 0,
    'PECCHIO': 0,
    'PECCI': 0,
    'PECCIA': 0,
    'PECE': 0,
    'PECENKA': 0,
    'PECH': 0,
    'PECHA': 0,
    'PECHACEK': 0,
    'PECHAL': 0,
    'PECHAN': 0,
    'PECHAR': 0,
    'PECHARICH': 0,
    'PECHART': 0,
    'PECHE': 0,
    'PECHER': 0,
    'PECHETTE': 0,
    'PECHIE': 0,
    'PECHIN': 0,
    'PECHMAN': 0,
    'PECHMANN': 0,
    'PECHO': 0,
    'PECHOTA': 0,
    'PECHOUS': 0,
    'PECHT': 0,
    'PECHTEL': 0,
    'PECHTER': 0,
    'PECHULIS': 0,
    'PECINA': 0,
    'PECINOVSKY': 0,
    'PECJAK': 0,
    'PECK': 0,
    'PECKA': 0,
    'PECKELS': 0,
    'PECKENPAUGH': 0,
    'PECKENS': 0,
    'PECKER': 0,
    'PECKHAM': 0,
    'PECKINPAUGH': 0,
    'PECKLER': 0,
    'PECKMAN': 0,
    'PECNIK': 0,
    'PECO': 0,
    'PECOR': 0,
    'PECORA': 0,
    'PECORARO': 0,
    'PECORE': 0,
    'PECORELLA': 0,
    'PECORELLI': 0,
    'PECORI': 0,
    'PECORINO': 0,
    'PECOS': 0,
    'PECOT': 0,
    'PECQUET': 0,
    'PECSI': 0,
    'PECSOK': 0,
    'PECSON': 0,
    'PECTOL': 0,
    'PEDA': 0,
    'PEDALINO': 0,
    'PEDANO': 0,
    'PEDDE': 0,
    'PEDDER': 0,
    'PEDDICORD': 0,
    'PEDDIE': 0,
    'PEDDLE': 0,
    'PEDDY': 0,
    'PEDDYCOART': 0,
    'PEDDYCORD': 0,
    'PEDE': 0,
    'PEDELTY': 0,
    'PEDEMONTE': 0,
    'PEDEN': 0,
    'PEDERSEN': 0,
    'PEDERSON': 0,
    'PEDERZANI': 0,
    'PEDI': 0,
    'PEDICINI': 0,
    'PEDICONE': 0,
    'PEDIGO': 0,
    'PEDINI': 0,
    'PEDLAR': 0,
    'PEDLER': 0,
    'PEDLEY': 0,
    'PEDLOW': 0,
    'PEDONE': 0,
    'PEDOTA': 0,
    'PEDRAJA': 0,
    'PEDRASA': 0,
    'PEDRAZA': 0,
    'PEDRE': 0,
    'PEDREGO': 0,
    'PEDREGON': 0,
    'PEDREIRA': 0,
    'PEDRERO': 0,
    'PEDRETTI': 0,
    'PEDRI': 0,
    'PEDRICK': 0,
    'PEDRIN': 0,
    'PEDRINI': 0,
    'PEDRO': 0.9818875119161107,
    'PEDROLI': 0,
    'PEDRON': 0,
    'PEDRONCELLI': 0,
    'PEDRONI': 0,
    'PEDROSA': 0,
    'PEDROSO': 0,
    'PEDROTTI': 0,
    'PEDROTTY': 0,
    'PEDROW': 0,
    'PEDROZA': 0,
    'PEDROZO': 0,
    'PEDULLA': 0,
    'PEDUTO': 0,
    'PEDUZZI': 0,
    'PEE': 0,
    'PEEBLER': 0,
    'PEEBLES': 0,
    'PEECHER': 0,
    'PEED': 0,
    'PEEDE': 0,
    'PEEDEN': 0,
    'PEEDIN': 0,
    'PEEK': 0,
    'PEEKE': 0,
    'PEEKS': 0,
    'PEEL': 0,
    'PEELE': 0,
    'PEELEN': 0,
    'PEELER': 0,
    'PEELING': 0,
    'PEELLE': 0,
    'PEELMAN': 0,
    'PEELS': 0,
    'PEEPER': 0,
    'PEEPLES': 0,
    'PEER': 0,
    'PEERBOOM': 0,
    'PEERCE': 0,
    'PEERCY': 0,
    'PEERENBOOM': 0,
    'PEERMAN': 0,
    'PEERS': 0,
    'PEERSON': 0,
    'PEERY': 0,
    'PEES': 0,
    'PEESO': 0,
    'PEET': 0,
    'PEETE': 0,
    'PEETERS': 0,
    'PEETOOM': 0,
    'PEETS': 0,
    'PEETZ': 0,
    'PEEVEY': 0,
    'PEEVLER': 0,
    'PEEVY': 0,
    'PEEVYHOUSE': 0,
    'PEFFER': 0,
    'PEFFERMAN': 0,
    'PEFFERS': 0,
    'PEFFLEY': 0,
    'PEFFLY': 0,
    'PEFLEY': 0,
    'PEG': 1,
    'PEGAN': 0,
    'PEGEL': 0,
    'PEGELOW': 0,
    'PEGG': 0,
    'PEGGIE': 1,
    'PEGGINS': 0,
    'PEGGS': 0,
    'PEGGY': 1,
    'PEGHER': 0,
    'PEGLER': 0,
    'PEGLOW': 0,
    'PEGO': 0,
    'PEGODA': 0,
    'PEGORARO': 0,
    'PEGRAM': 0,
    'PEGUERO': 0,
    'PEGUEROS': 0,
    'PEGUES': 0,
    'PEGUESE': 0,
    'PEHANICH': 0,
    'PEHL': 0,
    'PEHLE': 0,
    'PEHLER': 0,
    'PEHLING': 0,
    'PEHLKE': 0,
    'PEHR': 0,
    'PEHRSON': 0,
    'PEI': 0.7874015748031497,
    'PEICHEL': 0,
    'PEICK': 0,
    'PEIFER': 0,
    'PEIFFER': 0,
    'PEIGHT': 0,
    'PEIGHTAL': 0,
    'PEIK': 0,
    'PEIKERT': 0,
    'PEIL': 0,
    'PEILA': 0,
    'PEILER': 0,
    'PEIN': 0,
    'PEINADO': 0,
    'PEINE': 0,
    'PEIPER': 0,
    'PEIRANO': 0,
    'PEIRCE': 0,
    'PEIRICK': 0,
    'PEIRIS': 0,
    'PEIRSOL': 0,
    'PEIRSON': 0,
    'PEISCHL': 0,
    'PEISER': 0,
    'PEISKER': 0,
    'PEISSIG': 0,
    'PEITSCH': 0,
    'PEITZ': 0,
    'PEITZMAN': 0,
    'PEITZMEIER': 0,
    'PEIXOTO': 0,
    'PEJIC': 0,
    'PEJSA': 0,
    'PEK': 0,
    'PEKA': 0,
    'PEKALA': 0,
    'PEKAR': 0,
    'PEKARCIK': 0,
    'PEKAREK': 0,
    'PEKARIK': 0,
    'PEKARSKI': 0,
    'PEKARSKY': 0,
    'PEKAS': 0,
    'PEKEL': 0,
    'PEKER': 0,
    'PEKICH': 0,
    'PEKINS': 0,
    'PEKKALA': 0,
    'PEKLO': 0,
    'PEKNY': 0,
    'PEKO': 0,
    'PEKRUL': 0,
    'PEKSA': 0,
    'PEL': 0,
    'PELA': 0,
    'PELACCIO': 0,
    'PELAEZ': 0,
    'PELAGIO': 0,
    'PELAK': 0,
    'PELAN': 0,
    'PELANT': 0,
    'PELAS': 0,
    'PELAYO': 0,
    'PELC': 0,
    'PELCASTRE': 0,
    'PELCH': 0,
    'PELCHAT': 0,
    'PELCHER': 0,
    'PELCZAR': 0,
    'PELCZARSKI': 0,
    'PELCZYNSKI': 0,
    'PELDO': 0,
    'PELE': 0,
    'PELECH': 0,
    'PELED': 0,
    'PELEG': 0,
    'PELEGRIN': 0,
    'PELEGRINO': 0,
    'PELEKAI': 0,
    'PELELLA': 0,
    'PELEN': 0,
    'PELES': 0,
    'PELESKY': 0,
    'PELFREY': 0,
    'PELGER': 0,
    'PELHAM': 0,
    'PELICAN': 0,
    'PELICO': 0,
    'PELIKAN': 0,
    'PELINA': 0,
    'PELINI': 0,
    'PELINO': 0,
    'PELIS': 0,
    'PELISH': 0,
    'PELISHEK': 0,
    'PELISSIER': 0,
    'PELKA': 0,
    'PELKE': 0,
    'PELKEY': 0,
    'PELKOLA': 0,
    'PELKOWSKI': 0,
    'PELKY': 0,
    'PELL': 0,
    'PELLA': 0,
    'PELLAM': 0,
    'PELLAND': 0,
    'PELLANT': 0,
    'PELLAR': 0,
    'PELLAS': 0,
    'PELLE': 0,
    'PELLECCHIA': 0,
    'PELLECER': 0,
    'PELLECHIA': 0,
    'PELLECHIO': 0,
    'PELLEGRIN': 0,
    'PELLEGRINE': 0,
    'PELLEGRINI': 0,
    'PELLEGRINO': 0,
    'PELLEGROM': 0,
    'PELLER': 0,
    'PELLERANO': 0,
    'PELLERIN': 0,
    'PELLERITO': 0,
    'PELLES': 0,
    'PELLET': 0,
    'PELLETIER': 0,
    'PELLETIERE': 0,
    'PELLETT': 0,
    'PELLETTIERE': 0,
    'PELLETTIERI': 0,
    'PELLEW': 0,
    'PELLEY': 0,
    'PELLHAM': 0,
    'PELLI': 0,
    'PELLICANE': 0,
    'PELLICANO': 0,
    'PELLICCI': 0,
    'PELLICCIA': 0,
    'PELLICCIO': 0,
    'PELLICCIONE': 0,
    'PELLICCIOTTI': 0,
    'PELLICER': 0,
    'PELLICIER': 0,
    'PELLICONE': 0,
    'PELLIGRA': 0,
    'PELLIGRINO': 0,
    'PELLIN': 0,
    'PELLINEN': 0,
    'PELLING': 0,
    'PELLINI': 0,
    'PELLINO': 0,
    'PELLIS': 0,
    'PELLISH': 0,
    'PELLISSIER': 0,
    'PELLITIER': 0,
    'PELLITTERI': 0,
    'PELLIZZARI': 0,
    'PELLIZZI': 0,
    'PELLMAN': 0,
    'PELLMANN': 0,
    'PELLO': 0,
    'PELLOCK': 0,
    'PELLOM': 0,
    'PELLON': 0,
    'PELLONI': 0,
    'PELLOT': 0,
    'PELLOW': 0,
    'PELLOWSKI': 0,
    'PELLS': 0,
    'PELLUM': 0,
    'PELLY': 0,
    'PELMAN': 0,
    'PELMORE': 0,
    'PELNAR': 0,
    'PELO': 0,
    'PELON': 0,
    'PELOQUIN': 0,
    'PELOSI': 0,
    'PELOSO': 0,
    'PELOT': 0,
    'PELOTE': 0,
    'PELOTTE': 0,
    'PELOW': 0,
    'PELOWSKI': 0,
    'PELOZA': 0,
    'PELPHREY': 0,
    'PELRINE': 0,
    'PELS': 0,
    'PELSER': 0,
    'PELSOR': 0,
    'PELSTER': 0,
    'PELSTON': 0,
    'PELSZYNSKI': 0,
    'PELT': 0,
    'PELTER': 0,
    'PELTIER': 0,
    'PELTO': 0,
    'PELTOLA': 0,
    'PELTON': 0,
    'PELTONEN': 0,
    'PELTS': 0,
    'PELTZ': 0,
    'PELTZER': 0,
    'PELTZMAN': 0,
    'PELUSI': 0,
    'PELUSIO': 0,
    'PELUSO': 0,
    'PELZ': 0,
    'PELZEK': 0,
    'PELZEL': 0,
    'PELZER': 0,
    'PELZL': 0,
    'PELZMAN': 0,
    'PEMA': 0,
    'PEMBER': 0,
    'PEMBERTON': 0,
    'PEMBLE': 0,
    'PEMBLETON': 0,
    'PEMBROKE': 0,
    'PEMBROOK': 0,
    'PEMELTON': 0,
    'PEMPEK': 0,
    'PEMRICK': 0,
    'PEN': 0,
    'PENA': 0,
    'PENADO': 0,
    'PENAFIEL': 0,
    'PENAFLOR': 0,
    'PENAGOS': 0,
    'PENAHERRERA': 0,
    'PENALBA': 0,
    'PENALBER': 0,
    'PENALO': 0,
    'PENALOSA': 0,
    'PENALOZA': 0,
    'PENALUNA': 0,
    'PENALVER': 0,
    'PENAR': 0,
    'PENARANDA': 0,
    'PENAS': 0,
    'PENATE': 0,
    'PENATZER': 0,
    'PENBERTHY': 0,
    'PENCA': 0,
    'PENCAK': 0,
    'PENCE': 0,
    'PENCEK': 0,
    'PENCIL': 0,
    'PENCILLE': 0,
    'PENCZAK': 0,
    'PENDARVIS': 0,
    'PENDAS': 0,
    'PENDEGRAFT': 0,
    'PENDEL': 0,
    'PENDELL': 0,
    'PENDELTON': 0,
    'PENDER': 0,
    'PENDERGAST': 0,
    'PENDERGRAFF': 0,
    'PENDERGRAFT': 0,
    'PENDERGRAPH': 0,
    'PENDERGRASS': 0,
    'PENDERGRAST': 0,
    'PENDERS': 0,
    'PENDERY': 0,
    'PENDEXTER': 0,
    'PENDINO': 0,
    'PENDL': 0,
    'PENDLAND': 0,
    'PENDLEBURY': 0,
    'PENDLETON': 0,
    'PENDLEY': 0,
    'PENDOLA': 0,
    'PENDOLINO': 0,
    'PENDON': 0,
    'PENDRAK': 0,
    'PENDREY': 0,
    'PENDRICK': 0,
    'PENDRY': 0,
    'PENDYGRAFT': 0,
    'PENDZICH': 0,
    'PENE': 0,
    'PENEAUX': 0,
    'PENEDA': 0,
    'PENEDO': 0,
    'PENEGAR': 0,
    'PENEGOR': 0,
    'PENELOPE': 1,
    'PENELTON': 0,
    'PENERA': 0,
    'PENFIELD': 0,
    'PENFOLD': 0,
    'PENG': 0,
    'PENGE': 0,
    'PENGELLY': 0,
    'PENGILLY': 0,
    'PENGRA': 0,
    'PENHA': 0,
    'PENHALE': 0,
    'PENHALL': 0,
    'PENHALLEGON': 0,
    'PENHOLLOW': 0,
    'PENHORWOOD': 0,
    'PENIC': 0,
    'PENICHE': 0,
    'PENICHET': 0,
    'PENICK': 0,
    'PENIGAR': 0,
    'PENILLA': 0,
    'PENINGER': 0,
    'PENINGTON': 0,
    'PENISTEN': 0,
    'PENISTER': 0,
    'PENISTON': 0,
    'PENIX': 0,
    'PENK': 0,
    'PENKA': 0,
    'PENKALA': 0,
    'PENKALSKI': 0,
    'PENKAVA': 0,
    'PENKE': 0,
    'PENKERT': 0,
    'PENKO': 0,
    'PENKSA': 0,
    'PENKWITZ': 0,
    'PENLAND': 0,
    'PENLEY': 0,
    'PENMAN': 0,
    'PENN': 0,
    'PENNA': 0,
    'PENNACCHIA': 0,
    'PENNACCHIO': 0,
    'PENNACHIO': 0,
    'PENNALA': 0,
    'PENNAMON': 0,
    'PENNANT': 0,
    'PENNARTZ': 0,
    'PENNE': 0,
    'PENNEBAKER': 0,
    'PENNEKAMP': 0,
    'PENNEL': 0,
    'PENNELL': 0,
    'PENNELLA': 0,
    'PENNELLO': 0,
    'PENNER': 0,
    'PENNETT': 0,
    'PENNETTA': 0,
    'PENNETTI': 0,
    'PENNEWELL': 0,
    'PENNEY': 0.4878048780487804,
    'PENNI': 1,
    'PENNICK': 0,
    'PENNIE': 0.9456264775413711,
    'PENNIMAN': 0,
    'PENNING': 0,
    'PENNINGER': 0,
    'PENNINGROTH': 0,
    'PENNINGS': 0,
    'PENNINGTON': 0,
    'PENNINI': 0,
    'PENNINO': 0,
    'PENNISI': 0,
    'PENNISON': 0,
    'PENNISTON': 0,
    'PENNIX': 0,
    'PENNO': 0,
    'PENNOCK': 0,
    'PENNOYER': 0,
    'PENNUCCI': 0,
    'PENNY': 0.9522532188841202,
    'PENNYBACKER': 0,
    'PENNYBAKER': 0,
    'PENNYCOOK': 0,
    'PENNYCUFF': 0,
    'PENNYMAN': 0,
    'PENNYPACKER': 0,
    'PENNYWELL': 0,
    'PENNYWITT': 0,
    'PENO': 0,
    'PENOR': 0,
    'PENOVICH': 0,
    'PENOYER': 0,
    'PENQUE': 0,
    'PENQUITE': 0,
    'PENRICE': 0,
    'PENROD': 0,
    'PENROSE': 0,
    'PENRY': 0,
    'PENSA': 0,
    'PENSABENE': 0,
    'PENSADO': 0,
    'PENSAK': 0,
    'PENSE': 0,
    'PENSHORN': 0,
    'PENSIERO': 0,
    'PENSINGER': 0,
    'PENSIS': 0,
    'PENSKE': 0,
    'PENSKI': 0,
    'PENSKY': 0,
    'PENSO': 0,
    'PENSON': 0,
    'PENSYL': 0,
    'PENT': 0,
    'PENTA': 0,
    'PENTECOST': 0,
    'PENTEK': 0,
    'PENTER': 0,
    'PENTICO': 0,
    'PENTICOFF': 0,
    'PENTICUFF': 0,
    'PENTLAND': 0,
    'PENTO': 0,
    'PENTON': 0,
    'PENTONEY': 0,
    'PENTONY': 0,
    'PENTTILA': 0,
    'PENTZ': 0,
    'PENUEL': 0,
    'PENUELA': 0,
    'PENUELAS': 0,
    'PENUNURI': 0,
    'PENVOSE': 0,
    'PENWARDEN': 0,
    'PENWELL': 0,
    'PENWRIGHT': 0,
    'PENYAK': 0,
    'PENZ': 0,
    'PENZA': 0,
    'PENZEL': 0,
    'PENZENSTADLER': 0,
    'PENZES': 0,
    'PENZIEN': 0,
    'PENZO': 0,
    'PENZONE': 0,
    'PEO': 0,
    'PEON': 0,
    'PEONE': 0,
    'PEOPLE': 0,
    'PEOPLES': 0,
    'PEOT': 0,
    'PEOTTER': 0,
    'PEOU': 0,
    'PEPA': 0,
    'PEPAJ': 0,
    'PEPE': 0,
    'PEPER': 0,
    'PEPERA': 0,
    'PEPI': 0,
    'PEPIN': 0,
    'PEPINO': 0,
    'PEPION': 0,
    'PEPIOT': 0,
    'PEPITO': 0,
    'PEPITONE': 0,
    'PEPKA': 0,
    'PEPKE': 0,
    'PEPLER': 0,
    'PEPLINSKI': 0,
    'PEPLOW': 0,
    'PEPLOWSKI': 0,
    'PEPP': 0,
    'PEPPARD': 0,
    'PEPPAS': 0,
    'PEPPE': 0,
    'PEPPEL': 0,
    'PEPPER': 0,
    'PEPPERDINE': 0,
    'PEPPERMAN': 0,
    'PEPPERS': 0,
    'PEPPIATT': 0,
    'PEPPIN': 0,
    'PEPPING': 0,
    'PEPPLE': 0,
    'PEPPLER': 0,
    'PEPPLES': 0,
    'PEPRAH': 0,
    'PEQUENO': 0,
    'PEQUIGNOT': 0,
    'PER': 0,
    'PERA': 0,
    'PERAGALLO': 0,
    'PERAGINE': 0,
    'PERAINO': 0,
    'PERAITA': 0,
    'PERAKIS': 0,
    'PERAL': 0,
    'PERALA': 0,
    'PERALDO': 0,
    'PERALES': 0,
    'PERALEZ': 0,
    'PERALTA': 0,
    'PERALTO': 0,
    'PERANIO': 0,
    'PERANTONI': 0,
    'PERASSO': 0,
    'PERATA': 0,
    'PERATT': 0,
    'PERAULT': 0,
    'PERAZA': 0,
    'PERAZZO': 0,
    'PERCE': 0,
    'PERCEFULL': 0,
    'PERCELL': 0,
    'PERCER': 0,
    'PERCEY': 0,
    'PERCH': 0,
    'PERCHA': 0,
    'PERCHES': 0,
    'PERCHEZ': 0,
    'PERCIAVALLE': 0,
    'PERCIBALLI': 0,
    'PERCIC': 0,
    'PERCICH': 0,
    'PERCIFIELD': 0,
    'PERCIFUL': 0,
    'PERCIVAL': 0,
    'PERCLE': 0,
    'PERCOCO': 0,
    'PERCONTI': 0,
    'PERCOSKI': 0,
    'PERCY': 0.9337483325922632,
    'PERDEW': 0,
    'PERDIDO': 0,
    'PERDIEU': 0,
    'PERDIGAO': 0,
    'PERDIGON': 0,
    'PERDIKIS': 0,
    'PERDOMO': 0,
    'PERDON': 0,
    'PERDUE': 0,
    'PERE': 0,
    'PEREA': 0,
    'PEREAU': 0,
    'PEREC': 0,
    'PEREDA': 0,
    'PEREDIA': 0,
    'PEREDO': 0,
    'PEREGO': 0,
    'PEREGOY': 0,
    'PEREGRIM': 0,
    'PEREGRIN': 0,
    'PEREGRINA': 0,
    'PEREGRINE': 0,
    'PEREGRINO': 0,
    'PEREIDA': 0,
    'PEREIRA': 0,
    'PEREIRO': 0,
    'PEREK': 0,
    'PEREL': 0,
    'PERELES': 0,
    'PERELL': 0,
    'PERELLA': 0,
    'PERELLI': 0,
    'PERELLO': 0,
    'PERELMAN': 0,
    'PERELMUTER': 0,
    'PERER': 0,
    'PERERA': 0,
    'PERERIA': 0,
    'PERES': 0,
    'PERESS': 0,
    'PERESSINI': 0,
    'PERET': 0,
    'PERETTI': 0,
    'PERETTO': 0,
    'PERETZ': 0,
    'PEREY': 0,
    'PEREYDA': 0,
    'PEREYRA': 0,
    'PEREZ': 0,
    'PEREZCHICA': 0,
    'PEREZCRUZ': 0,
    'PEREZDIAZ': 0,
    'PEREZFLORES': 0,
    'PEREZGARCIA': 0,
    'PEREZGOMEZ': 0,
    'PEREZGONZALEZ': 0,
    'PEREZHERNANDEZ': 0,
    'PEREZLOPEZ': 0,
    'PEREZMARTINEZ': 0,
    'PEREZNEGRON': 0,
    'PEREZORTIZ': 0,
    'PEREZPEREZ': 0,
    'PEREZRAMIREZ': 0,
    'PEREZREYES': 0,
    'PEREZRODRIGUEZ': 0,
    'PEREZSANCHEZ': 0,
    'PEREZTORRES': 0,
    'PEREZVARGAS': 0,
    'PERFATER': 0,
    'PERFECT': 0,
    'PERFECTO': 0,
    'PERFETTI': 0,
    'PERFETTO': 0,
    'PERFITT': 0,
    'PERGAMENT': 0,
    'PERGANDE': 0,
    'PERGE': 0,
    'PERGER': 0,
    'PERGERSON': 0,
    'PERGOLA': 0,
    'PERGOLIZZI': 0,
    'PERGRAM': 0,
    'PERGREM': 0,
    'PERHACH': 0,
    'PERHACS': 0,
    'PERHAM': 0,
    'PERI': 0,
    'PERIA': 0,
    'PERIAN': 0,
    'PERIARD': 0,
    'PERIC': 0,
    'PERICA': 0,
    'PERICAK': 0,
    'PERICH': 0,
    'PERICLES': 0,
    'PERICO': 0,
    'PERIERA': 0,
    'PERIGO': 0,
    'PERILLA': 0,
    'PERILLI': 0,
    'PERILLO': 0,
    'PERILLOUX': 0,
    'PERIMAN': 0,
    'PERIMUTTER': 0,
    'PERIN': 0,
    'PERINA': 0,
    'PERINE': 0,
    'PERINI': 0,
    'PERINO': 0,
    'PERIO': 0,
    'PERIS': 0,
    'PERISH': 0,
    'PERISHO': 0,
    'PERISIC': 0,
    'PERITO': 0,
    'PERITORE': 0,
    'PERITZ': 0,
    'PERIUS': 0,
    'PERK': 0,
    'PERKEL': 0,
    'PERKERSON': 0,
    'PERKES': 0,
    'PERKETT': 0,
    'PERKEY': 0,
    'PERKIN': 0,
    'PERKINS': 0,
    'PERKINSON': 0,
    'PERKIS': 0,
    'PERKO': 0,
    'PERKOSKI': 0,
    'PERKOVIC': 0,
    'PERKOVICH': 0,
    'PERKOWSKI': 0,
    'PERKS': 0,
    'PERKY': 0,
    'PERL': 0,
    'PERLA': 0.8726003490401396,
    'PERLAS': 0,
    'PERLAZA': 0,
    'PERLBERG': 0,
    'PERLE': 0,
    'PERLEBERG': 0,
    'PERLEE': 0,
    'PERLER': 0,
    'PERLERA': 0,
    'PERLES': 0,
    'PERLEY': 0,
    'PERLICH': 0,
    'PERLICK': 0,
    'PERLIK': 0,
    'PERLIN': 0,
    'PERLINE': 0,
    'PERLINGER': 0,
    'PERLIS': 0,
    'PERLMAN': 0,
    'PERLMUTTER': 0,
    'PERLOFF': 0,
    'PERLONGO': 0,
    'PERLOW': 0,
    'PERLOWITZ': 0,
    'PERLOWSKI': 0,
    'PERLSON': 0,
    'PERLSTEIN': 0,
    'PERMAN': 0,
    'PERMANN': 0,
    'PERMAR': 0,
    'PERMAUL': 0,
    'PERME': 0,
    'PERMENTER': 0,
    'PERMUT': 0,
    'PERMUY': 0,
    'PERNA': 0,
    'PERNAL': 0,
    'PERNAS': 0,
    'PERNELL': 0,
    'PERNER': 0,
    'PERNETT': 0,
    'PERNEY': 0,
    'PERNG': 0,
    'PERNIA': 0,
    'PERNICANO': 0,
    'PERNICE': 0,
    'PERNICIARO': 0,
    'PERNICK': 0,
    'PERNICONE': 0,
    'PERNO': 0,
    'PERNOT': 0,
    'PERNSTEINER': 0,
    'PERO': 0,
    'PERODIN': 0,
    'PERON': 0,
    'PERONA': 0,
    'PERONE': 0,
    'PERONI': 0,
    'PERONTO': 0,
    'PEROS': 0,
    'PEROSI': 0,
    'PEROT': 0,
    'PEROTTI': 0,
    'PEROTTO': 0,
    'PEROUTKA': 0,
    'PEROVIC': 0,
    'PEROVICH': 0,
    'PEROW': 0,
    'PEROZO': 0,
    'PEROZZI': 0,
    'PERPALL': 0,
    'PERPER': 0,
    'PERPETUA': 0,
    'PERPICH': 0,
    'PERQUE': 0,
    'PERR': 0,
    'PERRA': 0,
    'PERRAS': 0,
    'PERRAULT': 0,
    'PERRAUT': 0,
    'PERRE': 0,
    'PERREAULT': 0,
    'PERRECA': 0,
    'PERREIRA': 0,
    'PERRELL': 0,
    'PERRELLA': 0,
    'PERRELLI': 0,
    'PERRELLO': 0,
    'PERREN': 0,
    'PERRENOUD': 0,
    'PERRERA': 0,
    'PERRET': 0,
    'PERRETT': 0,
    'PERRETTA': 0,
    'PERRETTE': 0,
    'PERRETTI': 0,
    'PERREY': 0,
    'PERREZ': 0,
    'PERRI': 0,
    'PERRICELLI': 0,
    'PERRICONE': 0,
    'PERRIE': 0,
    'PERRIELLO': 0,
    'PERRIEN': 0,
    'PERRIER': 0,
    'PERRIERA': 0,
    'PERRIGAN': 0,
    'PERRIGIN': 0,
    'PERRIGO': 0,
    'PERRILL': 0,
    'PERRILLOUX': 0,
    'PERRIMAN': 0,
    'PERRIN': 0,
    'PERRINE': 0,
    'PERRING': 0,
    'PERRINGTON': 0,
    'PERRINI': 0,
    'PERRINO': 0,
    'PERRINS': 0,
    'PERRIS': 0,
    'PERRITANO': 0,
    'PERRITT': 0,
    'PERRITTE': 0,
    'PERRIZO': 0,
    'PERRO': 0,
    'PERRODIN': 0,
    'PERRON': 0,
    'PERRONE': 0,
    'PERRONI': 0,
    'PERRONNE': 0,
    'PERROS': 0,
    'PERROT': 0,
    'PERROTT': 0,
    'PERROTTA': 0,
    'PERROTTE': 0,
    'PERROTTI': 0,
    'PERROTTO': 0,
    'PERROW': 0,
    'PERRUCCI': 0,
    'PERRUCCIO': 0,
    'PERRUSO': 0,
    'PERRUZZI': 0,
    'PERRY': 0.39282138180697834,
    'PERRYMAN': 0,
    'PERRYMOND': 0,
    'PERS': 0,
    'PERSAD': 0,
    'PERSAILS': 0,
    'PERSAK': 0,
    'PERSALL': 0,
    'PERSAUD': 0,
    'PERSCH': 0,
    'PERSCHALL': 0,
    'PERSCHAU': 0,
    'PERSCHBACHER': 0,
    'PERSCHKE': 0,
    'PERSCHON': 0,
    'PERSE': 0,
    'PERSECHINO': 0,
    'PERSELL': 0,
    'PERSENAIRE': 0,
    'PERSER': 0,
    'PERSHA': 0,
    'PERSHALL': 0,
    'PERSHIN': 0,
    'PERSHING': 0,
    'PERSI': 0,
    'PERSIA': 0,
    'PERSIANI': 0,
    'PERSIC': 0,
    'PERSICH': 0,
    'PERSICHETTI': 0,
    'PERSICHILLI': 0,
    'PERSICK': 0,
    'PERSICO': 0,
    'PERSILVER': 0,
    'PERSIN': 0,
    'PERSING': 0,
    'PERSINGER': 0,
    'PERSKE': 0,
    'PERSKI': 0,
    'PERSKY': 0,
    'PERSLEY': 0,
    'PERSOHN': 0,
    'PERSON': 0,
    'PERSONA': 0,
    'PERSONETT': 0,
    'PERSONETTE': 0,
    'PERSONIUS': 0,
    'PERSONS': 0,
    'PERSOON': 0,
    'PERSSON': 0,
    'PERSUN': 0,
    'PERSYN': 0,
    'PERSZYK': 0,
    'PERT': 0,
    'PERTEE': 0,
    'PERTEET': 0,
    'PERTICONE': 0,
    'PERTIERRA': 0,
    'PERTILE': 0,
    'PERTL': 0,
    'PERTTULA': 0,
    'PERTUIT': 0,
    'PERTUSET': 0,
    'PERTUZ': 0,
    'PERTZ': 0,
    'PERTZBORN': 0,
    'PERU': 0,
    'PERUCCA': 0,
    'PERUCCI': 0,
    'PERUCH': 0,
    'PERUCHO': 0,
    'PERUGINI': 0,
    'PERUGINO': 0,
    'PERULLO': 0,
    'PERUMAL': 0,
    'PERUN': 0,
    'PERUSEK': 0,
    'PERUSICH': 0,
    'PERUSKI': 0,
    'PERUSO': 0,
    'PERUSQUIA': 0,
    'PERUSSE': 0,
    'PERUZZI': 0,
    'PERVAIZ': 0,
    'PERVAN': 0,
    'PERVEEN': 0,
    'PERVEZ': 0,
    'PERVIER': 0,
    'PERVIN': 0,
    'PERVIS': 0,
    'PERY': 0,
    'PERYEA': 0,
    'PERYER': 0,
    'PERZ': 0,
    'PERZAN': 0,
    'PERZANOWSKI': 0,
    'PERZE': 0,
    'PERZEL': 0,
    'PERZINSKI': 0,
    'PESA': 0,
    'PESAK': 0,
    'PESANO': 0,
    'PESANTE': 0,
    'PESANTES': 0,
    'PESANTEZ': 0,
    'PESARESI': 0,
    'PESATURO': 0,
    'PESAVENTO': 0,
    'PESCADOR': 0,
    'PESCATORE': 0,
    'PESCE': 0,
    'PESCH': 0,
    'PESCHEL': 0,
    'PESCHKA': 0,
    'PESCHKE': 0,
    'PESCHL': 0,
    'PESCHONG': 0,
    'PESCI': 0,
    'PESCO': 0,
    'PESCOSOLIDO': 0,
    'PESEK': 0,
    'PESHEK': 0,
    'PESHEL': 0,
    'PESHLAKAI': 0,
    'PESHOFF': 0,
    'PESIC': 0,
    'PESICKA': 0,
    'PESIK': 0,
    'PESIN': 0,
    'PESINA': 0,
    'PESIRI': 0,
    'PESKA': 0,
    'PESKAR': 0,
    'PESKE': 0,
    'PESKEY': 0,
    'PESKIE': 0,
    'PESKIN': 0,
    'PESKO': 0,
    'PESL': 0,
    'PESNELL': 0,
    'PESOLA': 0,
    'PESONEN': 0,
    'PESQUEDA': 0,
    'PESQUEIRA': 0,
    'PESQUERA': 0,
    'PESSA': 0,
    'PESSAGNO': 0,
    'PESSIN': 0,
    'PESSO': 0,
    'PESSOA': 0,
    'PESSOLANO': 0,
    'PESSON': 0,
    'PEST': 0,
    'PESTA': 0,
    'PESTANA': 0,
    'PESTANO': 0,
    'PESTEL': 0,
    'PESTER': 0,
    'PESTERFIELD': 0,
    'PESTI': 0,
    'PESTKA': 0,
    'PESTO': 0,
    'PESUT': 0,
    'PESZKO': 0,
    'PET': 0,
    'PETA': 0,
    'PETACCIO': 0,
    'PETAK': 0,
    'PETATAN': 0,
    'PETAWAY': 0,
    'PETCH': 0,
    'PETCHEL': 0,
    'PETCHER': 0,
    'PETCOFF': 0,
    'PETE': 0.9523809523809523,
    'PETEE': 0,
    'PETEET': 0,
    'PETEFISH': 0,
    'PETEK': 0,
    'PETEL': 0,
    'PETELIN': 0,
    'PETELL': 0,
    'PETELLE': 0,
    'PETENBRINK': 0,
    'PETER': 0.9916668829988837,
    'PETEREIT': 0,
    'PETEREK': 0,
    'PETERIE': 0,
    'PETERING': 0,
    'PETERKA': 0,
    'PETERKIN': 0,
    'PETERLIN': 0,
    'PETERMAN': 0,
    'PETERMANN': 0,
    'PETERMEIER': 0,
    'PETERNEL': 0,
    'PETERNELL': 0,
    'PETERO': 0,
    'PETERPAUL': 0,
    'PETERS': 0,
    'PETERSBURG': 0,
    'PETERSCHICK': 0,
    'PETERSCHMIDT': 0,
    'PETERSDORF': 0,
    'PETERSEN': 0,
    'PETERSHEIM': 0,
    'PETERSOHN': 0,
    'PETERSON': 0,
    'PETERSSON': 0,
    'PETERY': 0,
    'PETESCH': 0,
    'PETET': 0,
    'PETGRAVE': 0,
    'PETH': 0,
    'PETHAN': 0,
    'PETHEL': 0,
    'PETHERBRIDGE': 0,
    'PETHERICK': 0,
    'PETHERS': 0,
    'PETHICK': 0,
    'PETHKE': 0,
    'PETHO': 0,
    'PETHOUD': 0,
    'PETHTEL': 0,
    'PETICCA': 0,
    'PETICOLAS': 0,
    'PETILLO': 0,
    'PETION': 0,
    'PETIPRIN': 0,
    'PETIT': 0,
    'PETITE': 0,
    'PETITFILS': 0,
    'PETITFRERE': 0,
    'PETITHOMME': 0,
    'PETITJEAN': 0,
    'PETITO': 0,
    'PETITPAS': 0,
    'PETITT': 0,
    'PETITTE': 0,
    'PETITTI': 0,
    'PETITTO': 0,
    'PETIX': 0,
    'PETKA': 0,
    'PETKE': 0,
    'PETKER': 0,
    'PETKO': 0,
    'PETKOFF': 0,
    'PETKOV': 0,
    'PETKOVIC': 0,
    'PETKOVICH': 0,
    'PETKOVSEK': 0,
    'PETKUS': 0,
    'PETLEY': 0,
    'PETMECKY': 0,
    'PETNER': 0,
    'PETO': 0,
    'PETOCK': 0,
    'PETON': 0,
    'PETOSA': 0,
    'PETOSKEY': 0,
    'PETR': 0,
    'PETRA': 0.9942438513867086,
    'PETRACCA': 0,
    'PETRACCO': 0,
    'PETRACEK': 0,
    'PETRAGLIA': 0,
    'PETRAITIS': 0,
    'PETRAK': 0,
    'PETRAKIS': 0,
    'PETRAKOS': 0,
    'PETRALIA': 0,
    'PETRAMALE': 0,
    'PETRAN': 0,
    'PETRANCOSTA': 0,
    'PETRANEK': 0,
    'PETRANGELO': 0,
    'PETRANOVICH': 0,
    'PETRARCA': 0,
    'PETRAS': 0,
    'PETRASEK': 0,
    'PETRASH': 0,
    'PETRASKO': 0,
    'PETRATOS': 0,
    'PETRAUSKAS': 0,
    'PETRAY': 0,
    'PETRE': 0,
    'PETREA': 0,
    'PETRECCA': 0,
    'PETREE': 0,
    'PETREK': 0,
    'PETRELL': 0,
    'PETRELLA': 0,
    'PETRELLI': 0,
    'PETRELLO': 0,
    'PETRENKO': 0,
    'PETRESCU': 0,
    'PETRETTI': 0,
    'PETREY': 0,
    'PETRI': 0,
    'PETRIC': 0,
    'PETRICCA': 0,
    'PETRICCIONE': 0,
    'PETRICEK': 0,
    'PETRICH': 0,
    'PETRICK': 0,
    'PETRICKA': 0,
    'PETRICONE': 0,
    'PETRIDES': 0,
    'PETRIDIS': 0,
    'PETRIE': 0,
    'PETRIELLA': 0,
    'PETRIELLO': 0,
    'PETRIK': 0,
    'PETRILAK': 0,
    'PETRILL': 0,
    'PETRILLA': 0,
    'PETRILLI': 0,
    'PETRILLO': 0,
    'PETRIMOULX': 0,
    'PETRIN': 0,
    'PETRINA': 0.9433962264150944,
    'PETRINI': 0,
    'PETRINO': 0,
    'PETRIS': 0,
    'PETRISKO': 0,
    'PETRITSCH': 0,
    'PETRITZ': 0,
    'PETRIZZI': 0,
    'PETRIZZO': 0,
    'PETRO': 0,
    'PETROCCHI': 0,
    'PETROCCI': 0,
    'PETROCCO': 0,
    'PETROCELLI': 0,
    'PETROCHKO': 0,
    'PETROCK': 0,
    'PETROELJE': 0,
    'PETROFF': 0,
    'PETROFSKY': 0,
    'PETRON': 0,
    'PETRONE': 0,
    'PETRONELLA': 0,
    'PETRONELLI': 0,
    'PETRONGOLO': 0,
    'PETRONI': 0,
    'PETRONILA': 1,
    'PETRONIO': 0,
    'PETRONIS': 0,
    'PETRONZIO': 0,
    'PETROPOULOS': 0,
    'PETROPULOS': 0,
    'PETROS': 0,
    'PETROSIAN': 0,
    'PETROSINO': 0,
    'PETROSKE': 0,
    'PETROSKEY': 0,
    'PETROSKI': 0,
    'PETROSKY': 0,
    'PETROSS': 0,
    'PETROSSI': 0,
    'PETROSSIAN': 0,
    'PETROSYAN': 0,
    'PETROTTA': 0,
    'PETROU': 0,
    'PETROUS': 0,
    'PETROV': 0,
    'PETROVA': 0,
    'PETROVIC': 0,
    'PETROVICH': 0,
    'PETROVITCH': 0,
    'PETROVITS': 0,
    'PETROVSKI': 0,
    'PETROVSKY': 0,
    'PETROW': 0,
    'PETROWSKI': 0,
    'PETROWSKY': 0,
    'PETROY': 0,
    'PETROZZA': 0,
    'PETROZZI': 0,
    'PETRU': 0,
    'PETRUCCELLI': 0,
    'PETRUCCI': 0,
    'PETRUCELLI': 0,
    'PETRULIS': 0,
    'PETRULLO': 0,
    'PETRUNAK': 0,
    'PETRUS': 0,
    'PETRUSEK': 0,
    'PETRUSH': 0,
    'PETRUSHA': 0,
    'PETRUSKA': 0,
    'PETRUSKY': 0,
    'PETRUSO': 0,
    'PETRUZZELLA': 0,
    'PETRUZZELLI': 0,
    'PETRUZZI': 0,
    'PETRUZZIELLO': 0,
    'PETRUZZO': 0,
    'PETRY': 0,
    'PETRYK': 0,
    'PETRYKOWSKI': 0,
    'PETRYSZYN': 0,
    'PETRZELKA': 0,
    'PETSAS': 0,
    'PETSCH': 0,
    'PETSCHAUER': 0,
    'PETSCHE': 0,
    'PETSCHKE': 0,
    'PETSCHOW': 0,
    'PETSINGER': 0,
    'PETSKA': 0,
    'PETT': 0,
    'PETTA': 0,
    'PETTAS': 0,
    'PETTAWAY': 0,
    'PETTAY': 0,
    'PETTE': 0,
    'PETTEE': 0,
    'PETTEGREW': 0,
    'PETTENGER': 0,
    'PETTENGILL': 0,
    'PETTER': 0,
    'PETTERS': 0,
    'PETTERSEN': 0,
    'PETTERSON': 0,
    'PETTERSSON': 0,
    'PETTERUTI': 0,
    'PETTES': 0,
    'PETTET': 0,
    'PETTETT': 0,
    'PETTEWAY': 0,
    'PETTEY': 0,
    'PETTEYS': 0,
    'PETTI': 0,
    'PETTIBON': 0,
    'PETTIBONE': 0,
    'PETTICE': 0,
    'PETTICORD': 0,
    'PETTICREW': 0,
    'PETTIE': 0,
    'PETTIES': 0,
    'PETTIFER': 0,
    'PETTIFORD': 0,
    'PETTIGO': 0,
    'PETTIGREW': 0,
    'PETTIJOHN': 0,
    'PETTINATI': 0,
    'PETTINATO': 0,
    'PETTINE': 0,
    'PETTINELLI': 0,
    'PETTINEO': 0,
    'PETTINGA': 0,
    'PETTINGELL': 0,
    'PETTINGER': 0,
    'PETTINGILL': 0,
    'PETTIPAS': 0,
    'PETTIPIECE': 0,
    'PETTIS': 0,
    'PETTIT': 0,
    'PETTITT': 0,
    'PETTIWAY': 0,
    'PETTNER': 0,
    'PETTO': 0,
    'PETTON': 0,
    'PETTREY': 0,
    'PETTRONE': 0,
    'PETTRY': 0,
    'PETTS': 0,
    'PETTUS': 0,
    'PETTWAY': 0,
    'PETTY': 0,
    'PETTYGROVE': 0,
    'PETTYJOHN': 0,
    'PETTYPOOL': 0,
    'PETTYS': 0,
    'PETULLA': 0,
    'PETWAY': 0,
    'PETZ': 0,
    'PETZAK': 0,
    'PETZEL': 0,
    'PETZINGER': 0,
    'PETZKE': 0,
    'PETZNICK': 0,
    'PETZOLD': 0,
    'PETZOLDT': 0,
    'PEUGH': 0,
    'PEULER': 0,
    'PEURA': 0,
    'PEURIFOY': 0,
    'PEUSE': 0,
    'PEUSER': 0,
    'PEVAHOUSE': 0,
    'PEVARNIK': 0,
    'PEVEAR': 0,
    'PEVEHOUSE': 0,
    'PEVELER': 0,
    'PEVERILL': 0,
    'PEVERLY': 0,
    'PEVETO': 0,
    'PEVEY': 0,
    'PEVLER': 0,
    'PEVY': 0,
    'PEVZNER': 0,
    'PEW': 0,
    'PEWITT': 0,
    'PEWO': 0,
    'PEXA': 0,
    'PEXTON': 0,
    'PEYATT': 0,
    'PEYER': 0,
    'PEYERK': 0,
    'PEYMAN': 0,
    'PEYNADO': 0,
    'PEYRON': 0,
    'PEYROT': 0,
    'PEYSER': 0,
    'PEYTON': 0,
    'PEZANOWSKI': 0,
    'PEZESHKI': 0,
    'PEZEWSKI': 0,
    'PEZLEY': 0,
    'PEZO': 0,
    'PEZOLD': 0,
    'PEZZA': 0,
    'PEZZANO': 0,
    'PEZZE': 0,
    'PEZZELLA': 0,
    'PEZZELLO': 0,
    'PEZZETTI': 0,
    'PEZZI': 0,
    'PEZZILLO': 0,
    'PEZZIMENTI': 0,
    'PEZZINO': 0,
    'PEZZOLLA': 0,
    'PEZZOTTI': 0,
    'PEZZULLO': 0,
    'PEZZULO': 0,
    'PEZZUTI': 0,
    'PEZZUTO': 0,
    'PFAB': 0,
    'PFADT': 0,
    'PFAEFFLE': 0,
    'PFAEHLER': 0,
    'PFAENDER': 0,
    'PFAFF': 0,
    'PFAFFENBACH': 0,
    'PFAFFENBERGER': 0,
    'PFAFFINGER': 0,
    'PFAFFLE': 0,
    'PFAHL': 0,
    'PFAHLER': 0,
    'PFALLER': 0,
    'PFALTZGRAFF': 0,
    'PFALZER': 0,
    'PFALZGRAF': 0,
    'PFANDER': 0,
    'PFANKUCH': 0,
    'PFANNEBECKER': 0,
    'PFANNENSTEIN': 0,
    'PFANNENSTIEL': 0,
    'PFANNER': 0,
    'PFANNES': 0,
    'PFANSTIEL': 0,
    'PFANTZ': 0,
    'PFARR': 0,
    'PFAU': 0,
    'PFAUTSCH': 0,
    'PFAUTZ': 0,
    'PFEFFER': 0,
    'PFEFFERKORN': 0,
    'PFEFFERLE': 0,
    'PFEIFER': 0,
    'PFEIFF': 0,
    'PFEIFFENBERGER': 0,
    'PFEIFFER': 0,
    'PFEIFLE': 0,
    'PFEIL': 0,
    'PFEILER': 0,
    'PFEILSTICKER': 0,
    'PFEISTER': 0,
    'PFENDER': 0,
    'PFENDLER': 0,
    'PFENNIG': 0,
    'PFENNING': 0,
    'PFENNINGER': 0,
    'PFEUFFER': 0,
    'PFIEFER': 0,
    'PFIEFFER': 0,
    'PFIESTER': 0,
    'PFIFER': 0,
    'PFIFFNER': 0,
    'PFILE': 0,
    'PFINGST': 0,
    'PFINGSTEN': 0,
    'PFINGSTON': 0,
    'PFIRMAN': 0,
    'PFIRRMAN': 0,
    'PFISTER': 0,
    'PFISTERER': 0,
    'PFITZER': 0,
    'PFITZINGER': 0,
    'PFITZNER': 0,
    'PFIZENMAIER': 0,
    'PFIZENMAYER': 0,
    'PFLAGER': 0,
    'PFLANZ': 0,
    'PFLANZER': 0,
    'PFLASTER': 0,
    'PFLASTERER': 0,
    'PFLAUM': 0,
    'PFLAUMER': 0,
    'PFLEDERER': 0,
    'PFLEEGER': 0,
    'PFLEEGOR': 0,
    'PFLEGER': 0,
    'PFLEGHAAR': 0,
    'PFLEIDER': 0,
    'PFLEIDERER': 0,
    'PFLEIGER': 0,
    'PFLEPSEN': 0,
    'PFLIEGER': 0,
    'PFLIGER': 0,
    'PFLIPSEN': 0,
    'PFLUEGER': 0,
    'PFLUG': 0,
    'PFLUGER': 0,
    'PFLUGFELDER': 0,
    'PFLUGH': 0,
    'PFLUGHAUPT': 0,
    'PFLUGHOEFT': 0,
    'PFLUGRAD': 0,
    'PFLUGRADT': 0,
    'PFLUKE': 0,
    'PFLUM': 0,
    'PFLUMM': 0,
    'PFOFF': 0,
    'PFOHL': 0,
    'PFORR': 0,
    'PFORTMILLER': 0,
    'PFOST': 0,
    'PFOTENHAUER': 0,
    'PFOUTS': 0,
    'PFOUTZ': 0,
    'PFRANG': 0,
    'PFRIMMER': 0,
    'PFROMM': 0,
    'PFROMMER': 0,
    'PFUHL': 0,
    'PFUND': 0,
    'PFUNDSTEIN': 0,
    'PFUNDT': 0,
    'PFUNTNER': 0,
    'PHA': 0,
    'PHADKE': 0,
    'PHAGAN': 0,
    'PHAIR': 0,
    'PHAL': 0,
    'PHALEN': 0,
    'PHALIN': 0,
    'PHALON': 0,
    'PHAM': 0,
    'PHAN': 0,
    'PHANCO': 0,
    'PHANEUF': 0,
    'PHANG': 0,
    'PHANN': 0,
    'PHANOR': 0,
    'PHANORD': 0,
    'PHANOUVONG': 0,
    'PHANTHAVONG': 0,
    'PHARAOH': 0,
    'PHARES': 0,
    'PHARIS': 0,
    'PHARISS': 0,
    'PHARMER': 0,
    'PHARMS': 0,
    'PHARO': 0,
    'PHARR': 0,
    'PHARRIS': 0,
    'PHAT': 0,
    'PHATAK': 0,
    'PHAUP': 0,
    'PHAY': 0,
    'PHE': 0,
    'PHEA': 0,
    'PHEANIS': 0,
    'PHEASANT': 0,
    'PHEBE': 1,
    'PHEBUS': 0,
    'PHEE': 0,
    'PHEGLEY': 0,
    'PHEIFER': 0,
    'PHEIFFER': 0,
    'PHEIL': 0,
    'PHEIPS': 0,
    'PHELAN': 0,
    'PHELIX': 0,
    'PHELON': 0,
    'PHELPS': 0,
    'PHELTS': 0,
    'PHEMISTER': 0,
    'PHEN': 0,
    'PHEND': 0,
    'PHENEGER': 0,
    'PHENG': 0,
    'PHENICIE': 0,
    'PHENIS': 0,
    'PHENIX': 0,
    'PHERIGO': 0,
    'PHERNETTON': 0,
    'PHERSON': 0,
    'PHETSOMPHOU': 0,
    'PHETTEPLACE': 0,
    'PHI': 0,
    'PHIBBS': 0,
    'PHIEFER': 0,
    'PHIFER': 0,
    'PHIFFER': 0,
    'PHIL': 0.997624703087886,
    'PHILABAUM': 0,
    'PHILAVANH': 0,
    'PHILAVONG': 0,
    'PHILBECK': 0,
    'PHILBERT': 0,
    'PHILBIN': 0,
    'PHILBRICK': 0,
    'PHILBROOK': 0,
    'PHILBURN': 0,
    'PHILBY': 0,
    'PHILCOX': 0,
    'PHILE': 0,
    'PHILEMON': 0,
    'PHILEN': 0,
    'PHILHOWER': 0,
    'PHILIBERT': 0,
    'PHILIBIN': 0,
    'PHILION': 0,
    'PHILIP': 0.9914443885254152,
    'PHILIPOSE': 0,
    'PHILIPP': 0,
    'PHILIPPE': 0,
    'PHILIPPI': 0,
    'PHILIPPON': 0,
    'PHILIPPOU': 0,
    'PHILIPPS': 0,
    'PHILIPPSEN': 0,
    'PHILIPPUS': 0,
    'PHILIPS': 0,
    'PHILIPSEN': 0,
    'PHILIPSON': 0,
    'PHILISTIN': 0,
    'PHILL': 0,
    'PHILLABAUM': 0,
    'PHILLEO': 0,
    'PHILLEY': 0,
    'PHILLIBER': 0,
    'PHILLION': 0,
    'PHILLIP': 0.9896849735154726,
    'PHILLIPE': 0,
    'PHILLIPI': 0,
    'PHILLIPO': 0,
    'PHILLIPP': 0,
    'PHILLIPPE': 0,
    'PHILLIPPI': 0,
    'PHILLIPPO': 0,
    'PHILLIPPS': 0,
    'PHILLIPPY': 0,
    'PHILLIPS': 0,
    'PHILLIPSON': 0,
    'PHILLIPY': 0,
    'PHILLIS': 0.9389671361502346,
    'PHILLPOTT': 0,
    'PHILLPOTTS': 0,
    'PHILLS': 0,
    'PHILMAN': 0,
    'PHILMON': 0,
    'PHILMORE': 0,
    'PHILO': 0,
    'PHILOGENE': 0,
    'PHILOMENA': 1,
    'PHILON': 0,
    'PHILP': 0,
    'PHILPOT': 0,
    'PHILPOTT': 0,
    'PHILPOTTS': 0,
    'PHILPS': 0,
    'PHILSON': 0,
    'PHILYAW': 0,
    'PHIM': 0,
    'PHIMMASONE': 0,
    'PHIN': 0,
    'PHINAZEE': 0,
    'PHINISEE': 0,
    'PHINIZY': 0,
    'PHINN': 0,
    'PHINNESSEE': 0,
    'PHINNEY': 0,
    'PHIPPEN': 0,
    'PHIPPIN': 0,
    'PHIPPS': 0,
    'PHISTER': 0,
    'PHLEGAR': 0,
    'PHLIPOT': 0,
    'PHO': 0,
    'PHOEBE': 1,
    'PHOEBUS': 0,
    'PHOENIX': 0,
    'PHOK': 0,
    'PHOM': 0,
    'PHOMMACHACK': 0,
    'PHOMMACHANH': 0,
    'PHOMMAHAXAY': 0,
    'PHOMMARATH': 0,
    'PHOMMAVONG': 0,
    'PHOMPHAKDY': 0,
    'PHOMSOPHA': 0,
    'PHOMSOUVANH': 0,
    'PHON': 0,
    'PHONG': 0,
    'PHONGSA': 0,
    'PHONGSAVANH': 0,
    'PHONGSAVATH': 0,
    'PHORN': 0,
    'PHOTHIRATH': 0,
    'PHOTHISANE': 0,
    'PHOU': 0,
    'PHOUNG': 0,
    'PHOUNSAVATH': 0,
    'PHOUTHAVONG': 0,
    'PHU': 0,
    'PHUA': 0,
    'PHUN': 0,
    'PHUNG': 0.3333333333333333,
    'PHUONG': 0.9090909090909091,
    'PHY': 0,
    'PHYALL': 0,
    'PHYFER': 0,
    'PHYLICIA': 1,
    'PHYLIS': 1,
    'PHYLISS': 1,
    'PHYLLIS': 1,
    'PHYTHIAN': 0,
    'PI': 0,
    'PIA': 0.8771929824561403,
    'PIACENTE': 0,
    'PIACENTI': 0,
    'PIACENTINI': 0,
    'PIACENTINO': 0,
    'PIACENZA': 0,
    'PIACITELLI': 0,
    'PIACQUADIO': 0,
    'PIAMONTE': 0,
    'PIAMPIANO': 0,
    'PIAN': 0,
    'PIANA': 0,
    'PIANALTO': 0,
    'PIANE': 0,
    'PIANKA': 0,
    'PIANKO': 0,
    'PIANO': 0,
    'PIANOWSKI': 0,
    'PIANTANIDA': 0,
    'PIANTEDOSI': 0,
    'PIAO': 0,
    'PIAR': 0,
    'PIARD': 0,
    'PIARULLI': 0,
    'PIAS': 0,
    'PIASCIK': 0,
    'PIASECKI': 0,
    'PIASKOWSKI': 0,
    'PIASTA': 0,
    'PIATAK': 0,
    'PIATEK': 0,
    'PIATKOWSKI': 0,
    'PIATT': 0,
    'PIATTI': 0,
    'PIATZ': 0,
    'PIAZ': 0,
    'PIAZZA': 0,
    'PIAZZI': 0,
    'PIAZZOLA': 0,
    'PIBURN': 0,
    'PIC': 0,
    'PICA': 0,
    'PICADO': 0,
    'PICANCO': 0,
    'PICANO': 0,
    'PICANSO': 0,
    'PICAR': 0,
    'PICARAZZI': 0,
    'PICARD': 0,
    'PICARDAL': 0,
    'PICARDI': 0,
    'PICARDO': 0,
    'PICARELLA': 0,
    'PICARELLI': 0,
    'PICARELLO': 0,
    'PICARIELLO': 0,
    'PICART': 0,
    'PICASO': 0,
    'PICASSO': 0,
    'PICAZO': 0,
    'PICCA': 0,
    'PICCARD': 0,
    'PICCARI': 0,
    'PICCARRETO': 0,
    'PICCHI': 0,
    'PICCHIETTI': 0,
    'PICCHIONE': 0,
    'PICCHIONI': 0,
    'PICCIANO': 0,
    'PICCILLO': 0,
    'PICCIN': 0,
    'PICCINI': 0,
    'PICCINICH': 0,
    'PICCININI': 0,
    'PICCININNI': 0,
    'PICCIOLI': 0,
    'PICCIOLO': 0,
    'PICCIONE': 0,
    'PICCIONI': 0,
    'PICCIOTTI': 0,
    'PICCIOTTO': 0,
    'PICCIRILLI': 0,
    'PICCIRILLO': 0,
    'PICCIURRO': 0,
    'PICCIUTO': 0,
    'PICCO': 0,
    'PICCOLA': 0,
    'PICCOLI': 0,
    'PICCOLINO': 0,
    'PICCOLO': 0,
    'PICCOLOMINI': 0,
    'PICCONE': 0,
    'PICCONI': 0,
    'PICEK': 0,
    'PICENO': 0,
    'PICERNO': 0,
    'PICETTI': 0,
    'PICH': 0,
    'PICHA': 0,
    'PICHARD': 0,
    'PICHARDO': 0,
    'PICHAY': 0,
    'PICHE': 0,
    'PICHEL': 0,
    'PICHER': 0,
    'PICHETTE': 0,
    'PICHEY': 0,
    'PICHINTE': 0,
    'PICHLER': 0,
    'PICHOFF': 0,
    'PICHON': 0,
    'PICHOTTA': 0,
    'PICHT': 0,
    'PICI': 0,
    'PICILLO': 0,
    'PICINIC': 0,
    'PICINICH': 0,
    'PICK': 0,
    'PICKAR': 0,
    'PICKARD': 0,
    'PICKART': 0,
    'PICKEL': 0,
    'PICKELL': 0,
    'PICKELMAN': 0,
    'PICKELS': 0,
    'PICKELSIMER': 0,
    'PICKEN': 0,
    'PICKENPAUGH': 0,
    'PICKENS': 0,
    'PICKER': 0,
    'PICKERAL': 0,
    'PICKERD': 0,
    'PICKEREL': 0,
    'PICKERELL': 0,
    'PICKERILL': 0,
    'PICKERING': 0,
    'PICKERSGILL': 0,
    'PICKERT': 0,
    'PICKET': 0,
    'PICKETT': 0,
    'PICKETTE': 0,
    'PICKFORD': 0,
    'PICKHARDT': 0,
    'PICKING': 0,
    'PICKINPAUGH': 0,
    'PICKINS': 0,
    'PICKLE': 0,
    'PICKLER': 0,
    'PICKLES': 0,
    'PICKLESIMER': 0,
    'PICKLO': 0,
    'PICKMAN': 0,
    'PICKNELL': 0,
    'PICKNER': 0,
    'PICKNEY': 0,
    'PICKREIGN': 0,
    'PICKREL': 0,
    'PICKRELL': 0,
    'PICKREN': 0,
    'PICKRON': 0,
    'PICKUP': 0,
    'PICKUS': 0,
    'PICKWICK': 0,
    'PICKWORTH': 0,
    'PICO': 0,
    'PICOLO': 0,
    'PICON': 0,
    'PICONE': 0,
    'PICOS': 0,
    'PICOT': 0,
    'PICOTT': 0,
    'PICOTTE': 0,
    'PICOU': 0,
    'PICOZZI': 0,
    'PICQUET': 0,
    'PICTON': 0,
    'PICUCCI': 0,
    'PIDCOCK': 0,
    'PIDCOE': 0,
    'PIDDE': 0,
    'PIDDINGTON': 0,
    'PIDGEON': 0,
    'PIDO': 0,
    'PIE': 0,
    'PIEARCY': 0,
    'PIECE': 0,
    'PIECH': 0,
    'PIECHNIK': 0,
    'PIECHOCINSKI': 0,
    'PIECHOCKI': 0,
    'PIECHOTA': 0,
    'PIECHOWIAK': 0,
    'PIECHOWICZ': 0,
    'PIECHOWSKI': 0,
    'PIECIAK': 0,
    'PIECUCH': 0,
    'PIECYK': 0,
    'PIECZARKA': 0,
    'PIECZONKA': 0,
    'PIECZYNSKI': 0,
    'PIEDAD': 0.966183574879227,
    'PIEDADE': 0,
    'PIEDMONT': 0,
    'PIEDMONTE': 0,
    'PIEDRA': 0,
    'PIEDRAHITA': 0,
    'PIEDRAS': 0,
    'PIEDRASANTA': 0,
    'PIEFER': 0,
    'PIEFFER': 0,
    'PIEGARI': 0,
    'PIEH': 0,
    'PIEHL': 0,
    'PIEHLER': 0,
    'PIEK': 0,
    'PIEKARCZYK': 0,
    'PIEKARSKI': 0,
    'PIEKARZ': 0,
    'PIEKLO': 0,
    'PIEKOS': 0,
    'PIEKUT': 0,
    'PIEKUTOWSKI': 0,
    'PIEL': 0,
    'PIELA': 0,
    'PIELL': 0,
    'PIELLI': 0,
    'PIELMEIER': 0,
    'PIEMONTE': 0,
    'PIEN': 0,
    'PIENIAZEK': 0,
    'PIENING': 0,
    'PIENKOS': 0,
    'PIENKOWSKI': 0,
    'PIENTA': 0,
    'PIENTKA': 0,
    'PIEPENBRINK': 0,
    'PIEPENBURG': 0,
    'PIEPER': 0,
    'PIEPHO': 0,
    'PIEPKORN': 0,
    'PIEPLOW': 0,
    'PIEPMEIER': 0,
    'PIER': 0,
    'PIERACCI': 0,
    'PIERANGELI': 0,
    'PIERANTONI': 0,
    'PIERANTOZZI': 0,
    'PIERARD': 0,
    'PIERATT': 0,
    'PIERCE': 0,
    'PIERCEALL': 0,
    'PIERCEFIELD': 0,
    'PIERCEY': 0,
    'PIERCY': 0,
    'PIERE': 0,
    'PIEREN': 0,
    'PIERETTI': 0,
    'PIERGALLINI': 0,
    'PIERGIOVANNI': 0,
    'PIERGROSSI': 0,
    'PIERI': 0,
    'PIERICK': 0,
    'PIERIE': 0,
    'PIERIK': 0,
    'PIERING': 0,
    'PIERINI': 0,
    'PIERLE': 0,
    'PIERMAN': 0,
    'PIERMARINI': 0,
    'PIERNO': 0,
    'PIERO': 0,
    'PIEROG': 0,
    'PIERON': 0,
    'PIERONI': 0,
    'PIERORAZIO': 0,
    'PIEROTTI': 0,
    'PIERPOINT': 0,
    'PIERPONT': 0,
    'PIERQUET': 0,
    'PIERRARD': 0,
    'PIERRE': 0.646725949878739,
    'PIERREANTOINE': 0,
    'PIERRECHARLES': 0,
    'PIERRELOUIS': 0,
    'PIERREPAUL': 0,
    'PIERRET': 0,
    'PIERRI': 0,
    'PIERRO': 0,
    'PIERRON': 0,
    'PIERROT': 0,
    'PIERS': 0,
    'PIERSA': 0,
    'PIERSALL': 0,
    'PIERSANTI': 0,
    'PIERSE': 0,
    'PIERSKALLA': 0,
    'PIERSMA': 0,
    'PIERSOL': 0,
    'PIERSON': 0,
    'PIERSTORFF': 0,
    'PIERT': 0,
    'PIERUCCI': 0,
    'PIERZ': 0,
    'PIERZCHALA': 0,
    'PIERZCHALSKI': 0,
    'PIERZINA': 0,
    'PIERZYNSKI': 0,
    'PIES': 0,
    'PIESCHEL': 0,
    'PIESCHKE': 0,
    'PIESCO': 0,
    'PIESIK': 0,
    'PIESKE': 0,
    'PIESTER': 0,
    'PIESTRAK': 0,
    'PIET': 0,
    'PIETA': 0,
    'PIETAN': 0,
    'PIETANZA': 0,
    'PIETERICK': 0,
    'PIETERS': 0,
    'PIETERSE': 0,
    'PIETIG': 0,
    'PIETILA': 0,
    'PIETKA': 0,
    'PIETKIEWICZ': 0,
    'PIETRAFESA': 0,
    'PIETRAK': 0,
    'PIETRANDREA': 0,
    'PIETRANGELO': 0,
    'PIETRANTONI': 0,
    'PIETRANTONIO': 0,
    'PIETRAS': 0,
    'PIETRASZ': 0,
    'PIETRASZEK': 0,
    'PIETRASZEWSKI': 0,
    'PIETRI': 0,
    'PIETRINI': 0,
    'PIETRO': 0,
    'PIETROBONO': 0,
    'PIETROFORTE': 0,
    'PIETROK': 0,
    'PIETROMONACO': 0,
    'PIETRON': 0,
    'PIETROPAOLO': 0,
    'PIETROSKI': 0,
    'PIETROWICZ': 0,
    'PIETROWSKI': 0,
    'PIETRUCHA': 0,
    'PIETRUSZEWSKI': 0,
    'PIETRUSZKA': 0,
    'PIETRUSZYNSKI': 0,
    'PIETRYGA': 0,
    'PIETRYKA': 0,
    'PIETRYKOWSKI': 0,
    'PIETRZAK': 0,
    'PIETRZYK': 0,
    'PIETRZYKOWSKI': 0,
    'PIETSCH': 0,
    'PIETTE': 0,
    'PIETY': 0,
    'PIETZ': 0,
    'PIETZSCH': 0,
    'PIFER': 0,
    'PIFF': 0,
    'PIFFER': 0,
    'PIFHER': 0,
    'PIFKO': 0,
    'PIGA': 0,
    'PIGAO': 0,
    'PIGATT': 0,
    'PIGEON': 0,
    'PIGFORD': 0,
    'PIGG': 0,
    'PIGGEE': 0,
    'PIGGIE': 0,
    'PIGGOT': 0,
    'PIGGOTT': 0,
    'PIGGUE': 0,
    'PIGHETTI': 0,
    'PIGMAN': 0,
    'PIGNATARD': 0,
    'PIGNATARO': 0,
    'PIGNATELLI': 0,
    'PIGNATELLO': 0,
    'PIGNATIELLO': 0,
    'PIGNATO': 0,
    'PIGNONE': 0,
    'PIGNOTTI': 0,
    'PIGORS': 0,
    'PIGOTT': 0,
    'PIGRAM': 0,
    'PIGSLEY': 0,
    'PIGUE': 0,
    'PIGUES': 0,
    'PIGUET': 0,
    'PIGULA': 0,
    'PIHA': 0,
    'PIHL': 0,
    'PIHLAJA': 0,
    'PIIPPO': 0,
    'PIJANOWSKI': 0,
    'PIJUAN': 0,
    'PIKAART': 0,
    'PIKE': 0,
    'PIKER': 0,
    'PIKES': 0,
    'PIKEY': 0,
    'PIKOR': 0,
    'PIKUL': 0,
    'PIKULA': 0,
    'PIKULSKI': 0,
    'PIKUS': 0,
    'PIL': 0,
    'PILA': 0,
    'PILACHOWSKI': 0,
    'PILAND': 0,
    'PILANT': 0,
    'PILAPIL': 0,
    'PILAR': 0.96,
    'PILARCIK': 0,
    'PILARCZYK': 0,
    'PILARSKI': 0,
    'PILARTE': 0,
    'PILARZ': 0,
    'PILAT': 0,
    'PILATE': 0,
    'PILATI': 0,
    'PILATO': 0,
    'PILBEAM': 0,
    'PILCH': 0,
    'PILCHARD': 0,
    'PILCHER': 0,
    'PILE': 0,
    'PILECKI': 0,
    'PILEGGI': 0,
    'PILES': 0,
    'PILESKI': 0,
    'PILET': 0,
    'PILETTE': 0,
    'PILEWSKI': 0,
    'PILGER': 0,
    'PILGRAM': 0,
    'PILGREEN': 0,
    'PILGRIM': 0,
    'PILI': 0,
    'PILIBOSIAN': 0,
    'PILIERO': 0,
    'PILIGIAN': 0,
    'PILIPOVIC': 0,
    'PILIPOVICH': 0,
    'PILKENTON': 0,
    'PILKERTON': 0,
    'PILKEY': 0,
    'PILKINGTON': 0,
    'PILKINS': 0,
    'PILKINTON': 0,
    'PILL': 0,
    'PILLA': 0,
    'PILLADO': 0,
    'PILLAI': 0,
    'PILLANS': 0,
    'PILLAR': 0,
    'PILLARD': 0,
    'PILLARELLA': 0,
    'PILLARI': 0,
    'PILLARS': 0,
    'PILLATZKI': 0,
    'PILLAY': 0,
    'PILLCO': 0,
    'PILLE': 0,
    'PILLEN': 0,
    'PILLER': 0,
    'PILLERS': 0,
    'PILLETTE': 0,
    'PILLEY': 0,
    'PILLING': 0,
    'PILLINGER': 0,
    'PILLIOD': 0,
    'PILLION': 0,
    'PILLIS': 0,
    'PILLITTERI': 0,
    'PILLMAN': 0,
    'PILLO': 0,
    'PILLON': 0,
    'PILLOT': 0,
    'PILLOW': 0,
    'PILLOWS': 0,
    'PILLSBURY': 0,
    'PILMAN': 0,
    'PILMER': 0,
    'PILNEY': 0,
    'PILNY': 0,
    'PILO': 0,
    'PILON': 0,
    'PILONE': 0,
    'PILOSI': 0,
    'PILOT': 0,
    'PILOTO': 0,
    'PILOTTE': 0,
    'PILOTTI': 0,
    'PILS': 0,
    'PILSBURY': 0,
    'PILSNER': 0,
    'PILSON': 0,
    'PILTZ': 0,
    'PILUSO': 0,
    'PILZ': 0,
    'PIM': 0,
    'PIMBLE': 0,
    'PIMENTA': 0,
    'PIMENTAL': 0,
    'PIMENTEL': 0,
    'PIMENTO': 0,
    'PIMIENTA': 0,
    'PIMLEY': 0,
    'PIMLOTT': 0,
    'PIMM': 0,
    'PIMPINELLA': 0,
    'PIMPLETON': 0,
    'PIMPTON': 0,
    'PIN': 0,
    'PINA': 0,
    'PINACHO': 0,
    'PINADA': 0,
    'PINAIRE': 0,
    'PINAL': 0,
    'PINALES': 0,
    'PINAMONTI': 0,
    'PINAR': 0,
    'PINARD': 0,
    'PINARDI': 0,
    'PINASCO': 0,
    'PINAULT': 0,
    'PINC': 0,
    'PINCAY': 0,
    'PINCE': 0,
    'PINCH': 0,
    'PINCHAK': 0,
    'PINCHBACK': 0,
    'PINCHBECK': 0,
    'PINCHES': 0,
    'PINCHINAT': 0,
    'PINCHON': 0,
    'PINCHOT': 0,
    'PINCHUK': 0,
    'PINCIARO': 0,
    'PINCINCE': 0,
    'PINCIOTTI': 0,
    'PINCKARD': 0,
    'PINCKERT': 0,
    'PINCKLEY': 0,
    'PINCKNEY': 0,
    'PINCOCK': 0,
    'PINCOMBE': 0,
    'PINCUS': 0,
    'PIND': 0,
    'PINDA': 0,
    'PINDAR': 0,
    'PINDEL': 0,
    'PINDELL': 0,
    'PINDER': 0,
    'PINE': 0,
    'PINEAU': 0,
    'PINEAULT': 0,
    'PINEDA': 0,
    'PINEDO': 0,
    'PINEGAR': 0,
    'PINEIRA': 0,
    'PINEIRO': 0,
    'PINEL': 0,
    'PINELA': 0,
    'PINELL': 0,
    'PINELLA': 0,
    'PINELLI': 0,
    'PINELLO': 0,
    'PINELO': 0,
    'PINEO': 0,
    'PINER': 0,
    'PINERA': 0,
    'PINERO': 0,
    'PINEROS': 0,
    'PINES': 0,
    'PINET': 0,
    'PINETTE': 0,
    'PINEYRO': 0,
    'PING': 0.47393364928909953,
    'PINGATORE': 0,
    'PINGEL': 0,
    'PINGER': 0,
    'PINGITORE': 0,
    'PINGLE': 0,
    'PINGLETON': 0,
    'PINGLEY': 0,
    'PINGOL': 0,
    'PINGREE': 0,
    'PINGREY': 0,
    'PINGRY': 0,
    'PINGSTERHAUS': 0,
    'PINGUL': 0,
    'PINHAS': 0,
    'PINHEIRO': 0,
    'PINHO': 0,
    'PINI': 0,
    'PINICK': 0,
    'PINILLA': 0,
    'PINILLOS': 0,
    'PINION': 0,
    'PINIZZOTTO': 0,
    'PINK': 0,
    'PINKARD': 0,
    'PINKAS': 0,
    'PINKAVA': 0,
    'PINKE': 0,
    'PINKELMAN': 0,
    'PINKER': 0,
    'PINKERMAN': 0,
    'PINKERT': 0,
    'PINKERTON': 0,
    'PINKETT': 0,
    'PINKEY': 0,
    'PINKHAM': 0,
    'PINKHASOV': 0,
    'PINKHASOVA': 0,
    'PINKIE': 1,
    'PINKINS': 0,
    'PINKLETON': 0,
    'PINKLEY': 0,
    'PINKMAN': 0,
    'PINKNEY': 0,
    'PINKOS': 0,
    'PINKOSKI': 0,
    'PINKOWSKI': 0,
    'PINKS': 0,
    'PINKSTAFF': 0,
    'PINKSTON': 0,
    'PINKUS': 0,
    'PINLAC': 0,
    'PINLEY': 0,
    'PINN': 0,
    'PINNA': 0,
    'PINNEGAR': 0,
    'PINNELL': 0,
    'PINNELLA': 0,
    'PINNEO': 0,
    'PINNER': 0,
    'PINNEY': 0,
    'PINNICK': 0,
    'PINNIX': 0,
    'PINNO': 0,
    'PINNOCK': 0,
    'PINNOW': 0,
    'PINO': 0,
    'PINOL': 0,
    'PINOLA': 0,
    'PINON': 0,
    'PINONES': 0,
    'PINOS': 0,
    'PINOTTI': 0,
    'PINS': 0,
    'PINSKE': 0,
    'PINSKER': 0,
    'PINSKI': 0,
    'PINSKY': 0,
    'PINSON': 0,
    'PINSONNEAULT': 0,
    'PINT': 0,
    'PINTA': 0,
    'PINTADO': 0,
    'PINTAL': 0,
    'PINTAR': 0,
    'PINTARELLI': 0,
    'PINTER': 0,
    'PINTI': 0,
    'PINTLER': 0,
    'PINTO': 0,
    'PINTOR': 0,
    'PINTOS': 0,
    'PINTOZZI': 0,
    'PINTZ': 0,
    'PINUELAS': 0,
    'PINYAN': 0,
    'PINYERD': 0,
    'PINZ': 0,
    'PINZINO': 0,
    'PINZON': 0,
    'PINZONE': 0,
    'PIO': 0,
    'PIOCH': 0,
    'PIOCHE': 0,
    'PIOLI': 0,
    'PIOMBINO': 0,
    'PIOMBO': 0,
    'PION': 0,
    'PIONK': 0,
    'PIONKE': 0,
    'PIONTEK': 0,
    'PIONTER': 0,
    'PIONTKOWSKI': 0,
    'PIOQUINTO': 0,
    'PIORKOWSKI': 0,
    'PIOSKE': 0,
    'PIOT': 0,
    'PIOTRASCHKE': 0,
    'PIOTROWICZ': 0,
    'PIOTROWSKI': 0,
    'PIOTTER': 0,
    'PIOTTI': 0,
    'PIOVESAN': 0,
    'PIPA': 0,
    'PIPAL': 0,
    'PIPARO': 0,
    'PIPE': 0,
    'PIPER': 0.20040080160320642,
    'PIPERATA': 0,
    'PIPERATO': 0,
    'PIPERNO': 0,
    'PIPES': 0,
    'PIPHER': 0,
    'PIPHO': 0,
    'PIPIA': 0,
    'PIPINO': 0,
    'PIPITONE': 0,
    'PIPKIN': 0,
    'PIPKINS': 0,
    'PIPKORN': 0,
    'PIPOLO': 0,
    'PIPOLY': 0,
    'PIPP': 0,
    'PIPPEL': 0,
    'PIPPEN': 0,
    'PIPPENGER': 0,
    'PIPPENS': 0,
    'PIPPER': 0,
    'PIPPERT': 0,
    'PIPPIN': 0,
    'PIPPINS': 0,
    'PIPPITT': 0,
    'PIPPO': 0,
    'PIQUE': 0,
    'PIQUET': 0,
    'PIQUETTE': 0,
    'PIQUION': 0,
    'PIRA': 0,
    'PIRACHA': 0,
    'PIRAINO': 0,
    'PIRANI': 0,
    'PIRANIO': 0,
    'PIRAS': 0,
    'PIRC': 0,
    'PIRCH': 0,
    'PIRD': 0,
    'PIRE': 0,
    'PIRELA': 0,
    'PIRELLI': 0,
    'PIRELLO': 0,
    'PIRES': 0,
    'PIREZ': 0,
    'PIRI': 0,
    'PIRIE': 0,
    'PIRIGYI': 0,
    'PIRILLO': 0,
    'PIRIR': 0,
    'PIRIZ': 0,
    'PIRK': 0,
    'PIRKEY': 0,
    'PIRKL': 0,
    'PIRKLE': 0,
    'PIRKO': 0,
    'PIRKOLA': 0,
    'PIRL': 0,
    'PIRLOT': 0,
    'PIRMAN': 0,
    'PIRNAT': 0,
    'PIRNER': 0,
    'PIRNIE': 0,
    'PIRO': 0,
    'PIROG': 0,
    'PIROK': 0,
    'PIROLI': 0,
    'PIROLLI': 0,
    'PIROLLO': 0,
    'PIROLO': 0,
    'PIRON': 0,
    'PIRONE': 0,
    'PIRONTI': 0,
    'PIROS': 0,
    'PIROTTE': 0,
    'PIROZZI': 0,
    'PIROZZOLI': 0,
    'PIROZZOLO': 0,
    'PIRRAGLIA': 0,
    'PIRRE': 0,
    'PIRRELLO': 0,
    'PIRRERA': 0,
    'PIRRI': 0,
    'PIRRIE': 0,
    'PIRRITANO': 0,
    'PIRRO': 0,
    'PIRRONE': 0,
    'PIRROTTA': 0,
    'PIRRUCCELLO': 0,
    'PIRRUNG': 0,
    'PIRTLE': 0,
    'PIRWITZ': 0,
    'PIRZADA': 0,
    'PIRZADEH': 0,
    'PISA': 0,
    'PISACANE': 0,
    'PISACANO': 0,
    'PISACRETA': 0,
    'PISANA': 0,
    'PISANELLI': 0,
    'PISANESCHI': 0,
    'PISANI': 0,
    'PISANIELLO': 0,
    'PISANO': 0,
    'PISAPIA': 0,
    'PISARCIK': 0,
    'PISARCZYK': 0,
    'PISAREK': 0,
    'PISARIK': 0,
    'PISARSKI': 0,
    'PISARZ': 0,
    'PISATURO': 0,
    'PISAURO': 0,
    'PISCATELLI': 0,
    'PISCH': 0,
    'PISCHEL': 0,
    'PISCHKE': 0,
    'PISCIONE': 0,
    'PISCIONERI': 0,
    'PISCIOTTA': 0,
    'PISCIOTTI': 0,
    'PISCIOTTO': 0,
    'PISCITELLI': 0,
    'PISCITELLO': 0,
    'PISCO': 0,
    'PISCOPO': 0,
    'PISCOYA': 0,
    'PISEGNA': 0,
    'PISEL': 0,
    'PISELLI': 0,
    'PISENO': 0,
    'PISER': 0,
    'PISERCHIA': 0,
    'PISH': 0,
    'PISHA': 0,
    'PISHKO': 0,
    'PISHNER': 0,
    'PISK': 0,
    'PISKE': 0,
    'PISKO': 0,
    'PISKOR': 0,
    'PISKOROWSKI': 0,
    'PISKORSKI': 0,
    'PISKORZ': 0,
    'PISKULA': 0,
    'PISKUN': 0,
    'PISKURA': 0,
    'PISO': 0,
    'PISON': 0,
    'PISONI': 0,
    'PISOR': 0,
    'PISOWICZ': 0,
    'PISTER': 0,
    'PISTEY': 0,
    'PISTILLI': 0,
    'PISTNER': 0,
    'PISTO': 0,
    'PISTOCCO': 0,
    'PISTOIA': 0,
    'PISTOLE': 0,
    'PISTON': 0,
    'PISTONE': 0,
    'PISTOR': 0,
    'PISTORINO': 0,
    'PISTORIO': 0,
    'PISTORIUS': 0,
    'PISTRITTO': 0,
    'PISTULKA': 0,
    'PISULA': 0,
    'PISZ': 0,
    'PISZCZEK': 0,
    'PISZCZOR': 0,
    'PITA': 0,
    'PITARD': 0,
    'PITARO': 0,
    'PITARRESI': 0,
    'PITASSI': 0,
    'PITCAIRN': 0,
    'PITCAVAGE': 0,
    'PITCH': 0,
    'PITCHER': 0,
    'PITCHFORD': 0,
    'PITCOCK': 0,
    'PITCOX': 0,
    'PITEK': 0,
    'PITEL': 0,
    'PITEO': 0,
    'PITERA': 0,
    'PITHAN': 0,
    'PITINO': 0,
    'PITKA': 0,
    'PITKANEN': 0,
    'PITKIN': 0,
    'PITKO': 0,
    'PITLER': 0,
    'PITLICK': 0,
    'PITLIK': 0,
    'PITMAN': 0,
    'PITMON': 0,
    'PITNER': 0,
    'PITNEY': 0,
    'PITOCCO': 0,
    'PITON': 0,
    'PITONES': 0,
    'PITONIAK': 0,
    'PITONYAK': 0,
    'PITOSCIA': 0,
    'PITRA': 0,
    'PITRE': 0,
    'PITRELLI': 0,
    'PITRONE': 0,
    'PITROWSKI': 0,
    'PITRUZZELLO': 0,
    'PITSCH': 0,
    'PITSENBARGER': 0,
    'PITSENBERGER': 0,
    'PITSINGER': 0,
    'PITSTICK': 0,
    'PITT': 0,
    'PITTA': 0,
    'PITTACK': 0,
    'PITTALUGA': 0,
    'PITTAM': 0,
    'PITTARD': 0,
    'PITTARELLI': 0,
    'PITTARI': 0,
    'PITTAS': 0,
    'PITTAWAY': 0,
    'PITTEL': 0,
    'PITTELKOW': 0,
    'PITTELLI': 0,
    'PITTENGER': 0,
    'PITTER': 0,
    'PITTERLE': 0,
    'PITTERS': 0,
    'PITTERSON': 0,
    'PITTI': 0,
    'PITTIGLIO': 0,
    'PITTILLO': 0,
    'PITTINGER': 0,
    'PITTINGTON': 0,
    'PITTIS': 0,
    'PITTLER': 0,
    'PITTMAN': 0,
    'PITTMANN': 0,
    'PITTMON': 0,
    'PITTNER': 0,
    'PITTO': 0,
    'PITTOCK': 0,
    'PITTON': 0,
    'PITTORE': 0,
    'PITTROFF': 0,
    'PITTS': 0,
    'PITTSENBARGER': 0,
    'PITTSER': 0,
    'PITTSFORD': 0,
    'PITTSINGER': 0,
    'PITTSLEY': 0,
    'PITTSON': 0,
    'PITTZ': 0,
    'PITUCH': 0,
    'PITULA': 0,
    'PITZ': 0,
    'PITZEN': 0,
    'PITZER': 0,
    'PITZL': 0,
    'PITZNER': 0,
    'PIUNNO': 0,
    'PIUNTI': 0,
    'PIUS': 0,
    'PIVA': 0,
    'PIVAR': 0,
    'PIVARAL': 0,
    'PIVARNIK': 0,
    'PIVEC': 0,
    'PIVER': 0,
    'PIVIK': 0,
    'PIVIROTTO': 0,
    'PIVNICK': 0,
    'PIVONKA': 0,
    'PIVOVAR': 0,
    'PIWETZ': 0,
    'PIWINSKI': 0,
    'PIWKO': 0,
    'PIWONKA': 0,
    'PIWONSKI': 0,
    'PIWOWAR': 0,
    'PIWOWARCZYK': 0,
    'PIWOWARSKI': 0,
    'PIXLER': 0,
    'PIXLEY': 0,
    'PIXTON': 0,
    'PIZ': 0,
    'PIZA': 0,
    'PIZANA': 0,
    'PIZANI': 0,
    'PIZANO': 0,
    'PIZARRO': 0,
    'PIZER': 0,
    'PIZINGER': 0,
    'PIZOR': 0,
    'PIZUR': 0,
    'PIZZA': 0,
    'PIZZANO': 0,
    'PIZZARELLI': 0,
    'PIZZARELLO': 0,
    'PIZZARO': 0,
    'PIZZELLA': 0,
    'PIZZI': 0,
    'PIZZILLO': 0,
    'PIZZIMENTI': 0,
    'PIZZINI': 0,
    'PIZZINO': 0,
    'PIZZIRUSSO': 0,
    'PIZZITOLA': 0,
    'PIZZO': 0,
    'PIZZOFERRATO': 0,
    'PIZZOLA': 0,
    'PIZZOLATO': 0,
    'PIZZOLO': 0,
    'PIZZONIA': 0,
    'PIZZULO': 0,
    'PIZZURRO': 0,
    'PIZZUTI': 0,
    'PIZZUTO': 0,
    'PLA': 0,
    'PLACA': 0,
    'PLACE': 0,
    'PLACEK': 0,
    'PLACENCIA': 0,
    'PLACENCIO': 0,
    'PLACENSIA': 0,
    'PLACER': 0,
    'PLACERES': 0,
    'PLACEY': 0,
    'PLACHECKI': 0,
    'PLACHER': 0,
    'PLACHTA': 0,
    'PLACHY': 0,
    'PLACIDE': 0,
    'PLACIDO': 0,
    'PLACK': 0,
    'PLACKE': 0,
    'PLACKER': 0,
    'PLACKETT': 0,
    'PLACKO': 0,
    'PLACZEK': 0,
    'PLADSEN': 0,
    'PLADSON': 0,
    'PLAFCAN': 0,
    'PLAGA': 0,
    'PLAGE': 0,
    'PLAGEMAN': 0,
    'PLAGENS': 0,
    'PLAGER': 0,
    'PLAGGE': 0,
    'PLAGGEMEYER': 0,
    'PLAGMAN': 0,
    'PLAGMANN': 0,
    'PLAHN': 0,
    'PLAIA': 0,
    'PLAIN': 0,
    'PLAINE': 0,
    'PLAIR': 0,
    'PLAISANCE': 0,
    'PLAISIR': 0,
    'PLAISTED': 0,
    'PLAKAS': 0,
    'PLAKE': 0,
    'PLAMANN': 0,
    'PLAMBECK': 0,
    'PLAMONDON': 0,
    'PLAMP': 0,
    'PLAN': 0,
    'PLANA': 0,
    'PLANAS': 0,
    'PLANCARTE': 0,
    'PLANCE': 0,
    'PLANCHARD': 0,
    'PLANCHE': 0,
    'PLANCHER': 0,
    'PLANCHON': 0,
    'PLANCICH': 0,
    'PLANCK': 0,
    'PLANCON': 0,
    'PLANE': 0,
    'PLANER': 0,
    'PLANERT': 0,
    'PLANES': 0,
    'PLANETA': 0,
    'PLANEY': 0,
    'PLANK': 0,
    'PLANKENHORN': 0,
    'PLANKEY': 0,
    'PLANO': 0,
    'PLANSKY': 0,
    'PLANT': 0,
    'PLANTAMURA': 0,
    'PLANTE': 0,
    'PLANTENBERG': 0,
    'PLANTENGA': 0,
    'PLANTER': 0,
    'PLANTHOLT': 0,
    'PLANTIER': 0,
    'PLANTILLAS': 0,
    'PLANTIN': 0,
    'PLANTINGA': 0,
    'PLANTON': 0,
    'PLANTS': 0,
    'PLANTY': 0,
    'PLANTZ': 0,
    'PLANZ': 0,
    'PLAPP': 0,
    'PLAPPERT': 0,
    'PLAS': 0,
    'PLASCENCIA': 0,
    'PLASCH': 0,
    'PLASECKI': 0,
    'PLASEK': 0,
    'PLASENCIA': 0,
    'PLASENCIO': 0,
    'PLASKET': 0,
    'PLASKETT': 0,
    'PLASKI': 0,
    'PLASKON': 0,
    'PLASKY': 0,
    'PLASMAN': 0,
    'PLASS': 0,
    'PLASSE': 0,
    'PLASSMAN': 0,
    'PLASSMEYER': 0,
    'PLASTER': 0,
    'PLASTERER': 0,
    'PLASTERS': 0,
    'PLASTINO': 0,
    'PLASTOW': 0,
    'PLATA': 0,
    'PLATANIA': 0,
    'PLATAS': 0,
    'PLATE': 0,
    'PLATEK': 0,
    'PLATEL': 0,
    'PLATER': 0,
    'PLATERD': 0,
    'PLATERO': 0,
    'PLATFOOT': 0,
    'PLATH': 0,
    'PLATHE': 0,
    'PLATI': 0,
    'PLATIS': 0,
    'PLATKO': 0,
    'PLATKOWSKI': 0,
    'PLATNER': 0,
    'PLATO': 0,
    'PLATON': 0,
    'PLATT': 0,
    'PLATTA': 0,
    'PLATTE': 0,
    'PLATTEN': 0,
    'PLATTENBURG': 0,
    'PLATTER': 0,
    'PLATTETER': 0,
    'PLATTNER': 0,
    'PLATTO': 0,
    'PLATTS': 0,
    'PLATZ': 0,
    'PLATZER': 0,
    'PLATZKE': 0,
    'PLAUCHE': 0,
    'PLAUD': 0,
    'PLAUGER': 0,
    'PLAUGHER': 0,
    'PLAUNT': 0,
    'PLAUT': 0,
    'PLAUTZ': 0,
    'PLAVCAN': 0,
    'PLAWECKI': 0,
    'PLAXCO': 0,
    'PLAXICO': 0,
    'PLAYER': 0,
    'PLAYFORD': 0,
    'PLAYLE': 0,
    'PLAYTER': 0,
    'PLAZA': 0,
    'PLAZAS': 0,
    'PLAZOLA': 0,
    'PLEAK': 0,
    'PLEAKE': 0,
    'PLEAS': 0,
    'PLEASANT': 0,
    'PLEASANTON': 0,
    'PLEASANTS': 0,
    'PLEASURE': 0,
    'PLEAU': 0,
    'PLEBAN': 0,
    'PLECAS': 0,
    'PLECHA': 0,
    'PLECHATY': 0,
    'PLECKER': 0,
    'PLECKI': 0,
    'PLEDGE': 0,
    'PLEDGER': 0,
    'PLEGER': 0,
    'PLEGGE': 0,
    'PLEGGENKUHLE': 0,
    'PLEHN': 0,
    'PLEIMAN': 0,
    'PLEIMANN': 0,
    'PLEIN': 0,
    'PLEINES': 0,
    'PLEINESS': 0,
    'PLEIS': 0,
    'PLEISS': 0,
    'PLEITES': 0,
    'PLEITEZ': 0,
    'PLEMEL': 0,
    'PLEMMONS': 0,
    'PLEMONS': 0,
    'PLENCNER': 0,
    'PLENDL': 0,
    'PLENERT': 0,
    'PLENGE': 0,
    'PLENTY': 0,
    'PLESA': 0,
    'PLESCIA': 0,
    'PLESE': 0,
    'PLESH': 0,
    'PLESHA': 0,
    'PLESHEK': 0,
    'PLESKA': 0,
    'PLESKAC': 0,
    'PLESKACH': 0,
    'PLESKO': 0,
    'PLESNIAK': 0,
    'PLESS': 0,
    'PLESSER': 0,
    'PLESSINGER': 0,
    'PLESSNER': 0,
    'PLESZ': 0,
    'PLETCHER': 0,
    'PLETKA': 0,
    'PLETSCH': 0,
    'PLETSCHER': 0,
    'PLETT': 0,
    'PLETTNER': 0,
    'PLETZ': 0,
    'PLETZER': 0,
    'PLETZKE': 0,
    'PLEUS': 0,
    'PLEUSS': 0,
    'PLEVA': 0,
    'PLEVIN': 0,
    'PLEVYAK': 0,
    'PLEW': 0,
    'PLEWA': 0,
    'PLEWES': 0,
    'PLEWINSKI': 0,
    'PLEWS': 0,
    'PLEXICO': 0,
    'PLEZIA': 0,
    'PLICHTA': 0,
    'PLIEGO': 0,
    'PLIER': 0,
    'PLILER': 0,
    'PLIMMER': 0,
    'PLIMPTON': 0,
    'PLINE': 0,
    'PLINER': 0,
    'PLINSKI': 0,
    'PLIS': 0,
    'PLISCHKE': 0,
    'PLISHKA': 0,
    'PLISKA': 0,
    'PLISKE': 0,
    'PLISKIN': 0,
    'PLISKO': 0,
    'PLISS': 0,
    'PLISZKA': 0,
    'PLITT': 0,
    'PLIZGA': 0,
    'PLOCEK': 0,
    'PLOCH': 0,
    'PLOCHARCZYK': 0,
    'PLOCHER': 0,
    'PLOCHOCKI': 0,
    'PLOCINSKI': 0,
    'PLOCK': 0,
    'PLOCKI': 0,
    'PLOECKELMAN': 0,
    'PLOEG': 0,
    'PLOEGER': 0,
    'PLOEHN': 0,
    'PLOEN': 0,
    'PLOENSE': 0,
    'PLOESSER': 0,
    'PLOESSL': 0,
    'PLOETZ': 0,
    'PLOG': 0,
    'PLOGER': 0,
    'PLOGGER': 0,
    'PLOMBON': 0,
    'PLONA': 0,
    'PLONK': 0,
    'PLONKA': 0,
    'PLONSKI': 0,
    'PLONSKY': 0,
    'PLONT': 0,
    'PLOOF': 0,
    'PLOOG': 0,
    'PLOOR': 0,
    'PLOOSTER': 0,
    'PLOPPER': 0,
    'PLOSKI': 0,
    'PLOSKONKA': 0,
    'PLOSS': 0,
    'PLOSZAJ': 0,
    'PLOTKE': 0,
    'PLOTKIN': 0,
    'PLOTKOWSKI': 0,
    'PLOTNER': 0,
    'PLOTNICK': 0,
    'PLOTNIK': 0,
    'PLOTNIKOV': 0,
    'PLOTT': 0,
    'PLOTTS': 0,
    'PLOTZ': 0,
    'PLOTZKE': 0,
    'PLOUCHA': 0,
    'PLOUCHER': 0,
    'PLOUFF': 0,
    'PLOUFFE': 0,
    'PLOUGH': 0,
    'PLOUGHE': 0,
    'PLOUGHMAN': 0,
    'PLOURD': 0,
    'PLOURDE': 0,
    'PLOUSE': 0,
    'PLOUTZ': 0,
    'PLOVER': 0,
    'PLOWDEN': 0,
    'PLOWE': 0,
    'PLOWMAN': 0,
    'PLOWS': 0,
    'PLUARD': 0,
    'PLUBELL': 0,
    'PLUCHINO': 0,
    'PLUCHINSKY': 0,
    'PLUCINSKI': 0,
    'PLUCK': 0,
    'PLUCKER': 0,
    'PLUDE': 0,
    'PLUE': 0,
    'PLUEGER': 0,
    'PLUEMER': 0,
    'PLUES': 0,
    'PLUFF': 0,
    'PLUGER': 0,
    'PLUGGE': 0,
    'PLUHAR': 0,
    'PLUID': 0,
    'PLUIM': 0,
    'PLUM': 0,
    'PLUMA': 0,
    'PLUMADORE': 0,
    'PLUMB': 0,
    'PLUMBER': 0,
    'PLUMBO': 0,
    'PLUMBTREE': 0,
    'PLUME': 0,
    'PLUMER': 0,
    'PLUMERI': 0,
    'PLUMEY': 0,
    'PLUMHOFF': 0,
    'PLUMLEE': 0,
    'PLUMLEY': 0,
    'PLUMLY': 0,
    'PLUMMER': 0,
    'PLUMP': 0,
    'PLUMPTON': 0,
    'PLUMRIDGE': 0,
    'PLUMSTEAD': 0,
    'PLUNGIS': 0,
    'PLUNK': 0,
    'PLUNKARD': 0,
    'PLUNKET': 0,
    'PLUNKETT': 0,
    'PLUSH': 0,
    'PLUSKOTA': 0,
    'PLUSS': 0,
    'PLUT': 0,
    'PLUTA': 0,
    'PLUTCHAK': 0,
    'PLUTE': 0,
    'PLUTH': 0,
    'PLUTO': 0,
    'PLUTT': 0,
    'PLUTZ': 0,
    'PLUVIOSE': 0,
    'PLY': 0,
    'PLYBON': 0,
    'PLYER': 0,
    'PLYLER': 0,
    'PLYMALE': 0,
    'PLYMAN': 0,
    'PLYMATE': 0,
    'PLYMEL': 0,
    'PLYMELL': 0,
    'PLYMESSER': 0,
    'PLYMIRE': 0,
    'PLYMPTON': 0,
    'PLYS': 0,
    'PLZAK': 0,
    'PNIEWSKI': 0,
    'PO': 0,
    'POACH': 0,
    'POAD': 0,
    'POAG': 0,
    'POAGE': 0,
    'POAGUE': 0,
    'POARCH': 0,
    'POAST': 0,
    'POAT': 0,
    'POATES': 0,
    'POBANZ': 0,
    'POBLANO': 0,
    'POBLETE': 0,
    'POBLOCKI': 0,
    'POBRE': 0,
    'POBST': 0,
    'POBUDA': 0,
    'POCAN': 0,
    'POCASANGRE': 0,
    'POCCIA': 0,
    'POCH': 0,
    'POCHA': 0,
    'POCHARDT': 0,
    'POCHATKO': 0,
    'POCHE': 0,
    'POCHERT': 0,
    'POCHMARA': 0,
    'POCHOP': 0,
    'POCHRON': 0,
    'POCIASK': 0,
    'POCIUS': 0,
    'POCK': 0,
    'POCKAT': 0,
    'POCKETT': 0,
    'POCKLINGTON': 0,
    'POCKRANDT': 0,
    'POCKRUS': 0,
    'POCOCK': 0,
    'POCRNICH': 0,
    'POCZATEK': 0,
    'PODA': 0,
    'PODANY': 0,
    'PODBIELSKI': 0,
    'PODD': 0,
    'PODDAR': 0,
    'PODELL': 0,
    'PODEMSKI': 0,
    'PODESTA': 0,
    'PODESZWA': 0,
    'PODEWILS': 0,
    'PODGORNIK': 0,
    'PODGORNY': 0,
    'PODGORSKI': 0,
    'PODGURSKI': 0,
    'PODLAS': 0,
    'PODLASEK': 0,
    'PODLASKI': 0,
    'PODLESNY': 0,
    'PODLEWSKI': 0,
    'PODLOGAR': 0,
    'PODMORE': 0,
    'PODNAR': 0,
    'PODOBINSKI': 0,
    'PODOBNIK': 0,
    'PODOJIL': 0,
    'PODOLAK': 0,
    'PODOLAN': 0,
    'PODOLL': 0,
    'PODOLSKI': 0,
    'PODOLSKY': 0,
    'PODOSEK': 0,
    'PODOWSKI': 0,
    'PODPORA': 0,
    'PODRASKY': 0,
    'PODRATZ': 0,
    'PODRAZA': 0,
    'PODREBARAC': 0,
    'PODSIADLIK': 0,
    'PODSIADLO': 0,
    'PODULKA': 0,
    'PODURGIEL': 0,
    'PODUSKA': 0,
    'PODVIN': 0,
    'PODY': 0,
    'PODZIMEK': 0,
    'POE': 0,
    'POEHL': 0,
    'POEHLEIN': 0,
    'POEHLER': 0,
    'POEHLING': 0,
    'POEHLMAN': 0,
    'POEHLMANN': 0,
    'POEHLS': 0,
    'POEHNER': 0,
    'POEL': 0,
    'POELING': 0,
    'POELKER': 0,
    'POELL': 0,
    'POELLINGER': 0,
    'POELLNITZ': 0,
    'POELLOT': 0,
    'POELMA': 0,
    'POELMAN': 0,
    'POELSTRA': 0,
    'POEN': 0,
    'POENISCH': 0,
    'POEPOE': 0,
    'POEPPEL': 0,
    'POEPPELMAN': 0,
    'POEPPING': 0,
    'POER': 0,
    'POERIO': 0,
    'POERTNER': 0,
    'POESCHEL': 0,
    'POESCHL': 0,
    'POET': 0,
    'POETA': 0,
    'POETKER': 0,
    'POETSCH': 0,
    'POETTER': 0,
    'POETTKER': 0,
    'POETZ': 0,
    'POETZL': 0,
    'POETZSCH': 0,
    'POFAHL': 0,
    'POFF': 0,
    'POFFENBARGER': 0,
    'POFFENBERGER': 0,
    'POFFENROTH': 0,
    'POFFINBARGER': 0,
    'POGAN': 0,
    'POGANY': 0,
    'POGAR': 0,
    'POGATCHNIK': 0,
    'POGGE': 0,
    'POGGEMEYER': 0,
    'POGGENPOHL': 0,
    'POGGENSEE': 0,
    'POGGI': 0,
    'POGGIO': 0,
    'POGGIOLI': 0,
    'POGLITSCH': 0,
    'POGODA': 0,
    'POGODZINSKI': 0,
    'POGORZELSKI': 0,
    'POGOSIAN': 0,
    'POGOSYAN': 0,
    'POGOZELSKI': 0,
    'POGREBA': 0,
    'POGSON': 0,
    'POGUE': 0,
    'POH': 0,
    'POHAR': 0,
    'POHL': 0,
    'POHLAND': 0,
    'POHLE': 0,
    'POHLEN': 0,
    'POHLENZ': 0,
    'POHLER': 0,
    'POHLIG': 0,
    'POHLKAMP': 0,
    'POHLMAN': 0,
    'POHLMANN': 0,
    'POHLMEIER': 0,
    'POHLMEYER': 0,
    'POHLOD': 0,
    'POHLY': 0,
    'POHORENCE': 0,
    'POHREN': 0,
    'POHTO': 0,
    'POI': 0,
    'POIDOMANI': 0,
    'POIENCOT': 0,
    'POILLUCCI': 0,
    'POINDEXTER': 0,
    'POINEAU': 0,
    'POINSETT': 0,
    'POINSETTE': 0,
    'POINT': 0,
    'POINTDUJOUR': 0,
    'POINTE': 0,
    'POINTER': 0,
    'POINTON': 0,
    'POINTS': 0,
    'POIRE': 0,
    'POIRIER': 0,
    'POIROT': 0,
    'POIROUX': 0,
    'POIRRIER': 0,
    'POISAL': 0,
    'POISEL': 0,
    'POISSANT': 0,
    'POISSON': 0,
    'POIST': 0,
    'POITEVIEN': 0,
    'POITEVINT': 0,
    'POITIER': 0,
    'POITRA': 0,
    'POITRAS': 0,
    'POJAR': 0,
    'POJE': 0,
    'POJMAN': 0,
    'POK': 0.8849557522123894,
    'POKE': 0,
    'POKER': 0,
    'POKLEMBA': 0,
    'POKLUDA': 0,
    'POKORA': 0,
    'POKORNEY': 0,
    'POKORNY': 0,
    'POKORSKI': 0,
    'POKRAJAC': 0,
    'POKRANDT': 0,
    'POKRANT': 0,
    'POKRAS': 0,
    'POKRYWKA': 0,
    'POKRZYWA': 0,
    'POKRZYWINSKI': 0,
    'POKU': 0,
    'POL': 0,
    'POLA': 0,
    'POLACCO': 0,
    'POLACEK': 0,
    'POLACH': 0,
    'POLACHECK': 0,
    'POLACHEK': 0,
    'POLACK': 0,
    'POLACO': 0,
    'POLADIAN': 0,
    'POLAK': 0,
    'POLAKIEWICZ': 0,
    'POLAKOFF': 0,
    'POLAKOW': 0,
    'POLAKOWSKI': 0,
    'POLAN': 0,
    'POLANCO': 0,
    'POLAND': 0,
    'POLANDER': 0,
    'POLANDO': 0,
    'POLANIA': 0,
    'POLANOWSKI': 0,
    'POLANSKI': 0,
    'POLANSKY': 0,
    'POLAR': 0,
    'POLARD': 0,
    'POLAREK': 0,
    'POLASEK': 0,
    'POLASIK': 0,
    'POLASKI': 0,
    'POLASKO': 0,
    'POLASKY': 0,
    'POLAT': 0,
    'POLATSEK': 0,
    'POLATTY': 0,
    'POLAVARAPU': 0,
    'POLAY': 0,
    'POLCARI': 0,
    'POLCARO': 0,
    'POLCE': 0,
    'POLCHA': 0,
    'POLCHINSKI': 0,
    'POLCHLOPEK': 0,
    'POLCHOW': 0,
    'POLCYN': 0,
    'POLCZYNSKI': 0,
    'POLDER': 0,
    'POLE': 0,
    'POLEGA': 0,
    'POLEK': 0,
    'POLEN': 0,
    'POLENDEY': 0,
    'POLENDO': 0,
    'POLENSKE': 0,
    'POLENSKY': 0,
    'POLENZ': 0,
    'POLEO': 0,
    'POLEON': 0,
    'POLER': 0,
    'POLERA': 0,
    'POLES': 0,
    'POLESE': 0,
    'POLESKI': 0,
    'POLESKY': 0,
    'POLETE': 0,
    'POLETO': 0,
    'POLETTE': 0,
    'POLETTI': 0,
    'POLETTO': 0,
    'POLEVOY': 0,
    'POLEWSKI': 0,
    'POLEY': 0,
    'POLFER': 0,
    'POLFUS': 0,
    'POLGAR': 0,
    'POLHAMUS': 0,
    'POLHEMUS': 0,
    'POLHILL': 0,
    'POLI': 0,
    'POLIAK': 0,
    'POLIAKOFF': 0,
    'POLIC': 0,
    'POLICANO': 0,
    'POLICAR': 0,
    'POLICARD': 0,
    'POLICARE': 0,
    'POLICARPIO': 0,
    'POLICARPO': 0,
    'POLICASTRO': 0,
    'POLICE': 0,
    'POLICELLI': 0,
    'POLICH': 0,
    'POLICHETTI': 0,
    'POLICHT': 0,
    'POLICICCHIO': 0,
    'POLICK': 0,
    'POLICKY': 0,
    'POLICY': 0,
    'POLIDO': 0,
    'POLIDOR': 0,
    'POLIDORE': 0,
    'POLIDORI': 0,
    'POLIDORO': 0,
    'POLIFKA': 0,
    'POLIFRONE': 0,
    'POLIKOFF': 0,
    'POLILLO': 0,
    'POLIMENI': 0,
    'POLIN': 0,
    'POLINA': 0,
    'POLINDER': 0,
    'POLINER': 0,
    'POLING': 0,
    'POLINI': 0,
    'POLINO': 0,
    'POLINSKE': 0,
    'POLINSKI': 0,
    'POLINSKY': 0,
    'POLINTAN': 0,
    'POLIO': 0,
    'POLIQUIN': 0,
    'POLIS': 0,
    'POLISANO': 0,
    'POLISE': 0,
    'POLISENO': 0,
    'POLISH': 0,
    'POLISHCHUK': 0,
    'POLISHUK': 0,
    'POLISKY': 0,
    'POLIT': 0,
    'POLITAND': 0,
    'POLITANO': 0,
    'POLITE': 0,
    'POLITES': 0,
    'POLITI': 0,
    'POLITIS': 0,
    'POLITO': 0,
    'POLITOWICZ': 0,
    'POLITOWSKI': 0,
    'POLITRON': 0,
    'POLITSCH': 0,
    'POLITTE': 0,
    'POLITZ': 0,
    'POLITZER': 0,
    'POLIVKA': 0,
    'POLIZZANO': 0,
    'POLIZZI': 0,
    'POLIZZOTTI': 0,
    'POLIZZOTTO': 0,
    'POLJAK': 0,
    'POLK': 0,
    'POLKA': 0,
    'POLKE': 0,
    'POLKEY': 0,
    'POLKINGHORN': 0,
    'POLKINGHORNE': 0,
    'POLKOW': 0,
    'POLKOWSKI': 0,
    'POLL': 0,
    'POLLA': 0,
    'POLLACK': 0,
    'POLLAK': 0,
    'POLLAN': 0,
    'POLLAND': 0,
    'POLLARA': 0,
    'POLLARD': 0,
    'POLLARI': 0,
    'POLLARO': 0,
    'POLLASTRINI': 0,
    'POLLASTRO': 0,
    'POLLAUF': 0,
    'POLLAY': 0,
    'POLLE': 0,
    'POLLEI': 0,
    'POLLEMA': 0,
    'POLLEN': 0,
    'POLLER': 0,
    'POLLERT': 0,
    'POLLET': 0,
    'POLLETT': 0,
    'POLLETTA': 0,
    'POLLEX': 0,
    'POLLEY': 0,
    'POLLI': 0,
    'POLLIARD': 0,
    'POLLICE': 0,
    'POLLICH': 0,
    'POLLICINO': 0,
    'POLLICK': 0,
    'POLLIFRONE': 0,
    'POLLIN': 0,
    'POLLINA': 0,
    'POLLINGER': 0,
    'POLLINGTON': 0,
    'POLLINI': 0,
    'POLLINO': 0,
    'POLLINS': 0,
    'POLLIO': 0,
    'POLLION': 0,
    'POLLIS': 0,
    'POLLITT': 0,
    'POLLITZ': 0,
    'POLLMAN': 0,
    'POLLMANN': 0,
    'POLLNER': 0,
    'POLLNOW': 0,
    'POLLO': 0,
    'POLLOCK': 0,
    'POLLOK': 0,
    'POLLOM': 0,
    'POLLOW': 0,
    'POLLPETER': 0,
    'POLLREISZ': 0,
    'POLLUM': 0,
    'POLLY': 0.9611183923110529,
    'POLLYDORE': 0,
    'POLM': 0,
    'POLMAN': 0,
    'POLMANTEER': 0,
    'POLNIAK': 0,
    'POLNITZ': 0,
    'POLNOW': 0,
    'POLNY': 0,
    'POLO': 0,
    'POLODNA': 0,
    'POLOGRUTO': 0,
    'POLOMSKI': 0,
    'POLOMSKY': 0,
    'POLON': 0,
    'POLONI': 0,
    'POLONIA': 0,
    'POLONIO': 0,
    'POLONSKI': 0,
    'POLONSKY': 0,
    'POLOS': 0,
    'POLOSKEY': 0,
    'POLOSKI': 0,
    'POLOSKY': 0,
    'POLOVINA': 0,
    'POLOWY': 0,
    'POLS': 0,
    'POLSELLI': 0,
    'POLSGROVE': 0,
    'POLSINELLI': 0,
    'POLSKI': 0,
    'POLSKY': 0,
    'POLSLEY': 0,
    'POLSON': 0,
    'POLSTER': 0,
    'POLSTON': 0,
    'POLT': 0,
    'POLTA': 0,
    'POLTER': 0,
    'POLTON': 0,
    'POLTORAK': 0,
    'POLTROCK': 0,
    'POLUM': 0,
    'POLUMBO': 0,
    'POLUS': 0,
    'POLVADO': 0,
    'POLVERARI': 0,
    'POLVERE': 0,
    'POLVINO': 0,
    'POLY': 0,
    'POLYAK': 0,
    'POLYAKOV': 0,
    'POLYAKOVA': 0,
    'POLYCARPE': 0,
    'POLYCHRONIS': 0,
    'POLYNICE': 0,
    'POLYS': 0,
    'POLZ': 0,
    'POLZELLA': 0,
    'POLZER': 0,
    'POLZIEN': 0,
    'POLZIN': 0,
    'POMA': 0,
    'POMAINVILLE': 0,
    'POMALES': 0,
    'POMANTE': 0,
    'POMAR': 0,
    'POMARES': 0,
    'POMARICO': 0,
    'POMASL': 0,
    'POMATTO': 0,
    'POMAVILLE': 0,
    'POMBO': 0,
    'POMBRIO': 0,
    'POMELOW': 0,
    'POMER': 0,
    'POMERANCE': 0,
    'POMERANTZ': 0,
    'POMERANZ': 0,
    'POMERENKE': 0,
    'POMERINKE': 0,
    'POMERLEAU': 0,
    'POMEROY': 0,
    'POMERVILLE': 0,
    'POMES': 0,
    'POMFRET': 0,
    'POMFREY': 0,
    'POMICHTER': 0,
    'POMIER': 0,
    'POMIJE': 0,
    'POMILIO': 0,
    'POMILLA': 0,
    'POMINVILLE': 0,
    'POMMELLS': 0,
    'POMMER': 0,
    'POMMERENING': 0,
    'POMMIER': 0,
    'POMO': 0,
    'POMORSKI': 0,
    'POMP': 0,
    'POMPA': 0,
    'POMPE': 0,
    'POMPEI': 0,
    'POMPEII': 0,
    'POMPEO': 0,
    'POMPER': 0,
    'POMPEY': 0,
    'POMPI': 0,
    'POMPILI': 0,
    'POMPILIO': 0,
    'POMPILUS': 0,
    'POMPLUN': 0,
    'POMPO': 0,
    'POMPONI': 0,
    'POMPONIO': 0,
    'POMPOSELLI': 0,
    'POMPOSO': 0,
    'POMPURA': 0,
    'POMRANING': 0,
    'POMRANKY': 0,
    'POMRENKE': 0,
    'POMROY': 0,
    'POMYKAL': 0,
    'POMYKALA': 0,
    'PON': 0,
    'PONA': 0,
    'PONATH': 0,
    'PONCE': 0,
    'PONCEDELEON': 0,
    'PONCELET': 0,
    'PONCET': 0,
    'PONCHAK': 0,
    'PONCHO': 0,
    'PONCHOT': 0,
    'PONCIA': 0,
    'PONCIAND': 0,
    'PONCIANO': 0,
    'PONCIK': 0,
    'PONCIN': 0,
    'PONCIO': 0,
    'PONCY': 0,
    'PONCZEK': 0,
    'POND': 0,
    'PONDEL': 0,
    'PONDER': 0,
    'PONDERS': 0,
    'PONDEXTER': 0,
    'PONDILLO': 0,
    'PONDO': 0,
    'PONDS': 0,
    'PONE': 0,
    'PONESSA': 0,
    'PONG': 0,
    'PONGONIS': 0,
    'PONGRACZ': 0,
    'PONGRATZ': 0,
    'PONIATOWSKI': 0,
    'PONICHTERA': 0,
    'PONIEWAZ': 0,
    'PONIKVAR': 0,
    'PONITZ': 0,
    'PONKE': 0,
    'PONKO': 0,
    'PONN': 0,
    'PONOMARENKO': 0,
    'PONOMAREV': 0,
    'PONS': 0,
    'PONSE': 0,
    'PONSELL': 0,
    'PONSFORD': 0,
    'PONSLER': 0,
    'PONSON': 0,
    'PONSTEIN': 0,
    'PONT': 0,
    'PONTARELLI': 0,
    'PONTBRIAND': 0,
    'PONTE': 0,
    'PONTECORVO': 0,
    'PONTELLO': 0,
    'PONTER': 0,
    'PONTERIO': 0,
    'PONTES': 0,
    'PONTHIER': 0,
    'PONTHIEUX': 0,
    'PONTI': 0,
    'PONTICELLI': 0,
    'PONTICELLO': 0,
    'PONTIER': 0,
    'PONTIFF': 0,
    'PONTILLAS': 0,
    'PONTILLO': 0,
    'PONTING': 0,
    'PONTIOUS': 0,
    'PONTIUS': 0,
    'PONTO': 0,
    'PONTON': 0,
    'PONTONE': 0,
    'PONTOON': 0,
    'PONTORIERO': 0,
    'PONTOW': 0,
    'PONTRELLI': 0,
    'PONTREMOLI': 0,
    'PONTSLER': 0,
    'PONTZ': 0,
    'PONTZER': 0,
    'PONZE': 0,
    'PONZER': 0,
    'PONZETTI': 0,
    'PONZI': 0,
    'PONZIANI': 0,
    'PONZINI': 0,
    'PONZIO': 0,
    'PONZO': 0,
    'POO': 0,
    'POOCH': 0,
    'POOCK': 0,
    'POOK': 0,
    'POOL': 0,
    'POOLA': 0,
    'POOLAW': 0,
    'POOLE': 0,
    'POOLER': 0,
    'POOLEY': 0,
    'POOLMAN': 0,
    'POOLOS': 0,
    'POON': 0,
    'POONAWALA': 0,
    'POONI': 0,
    'POOR': 0,
    'POORAN': 0,
    'POORBAUGH': 0,
    'POORBEAR': 0,
    'POORE': 0,
    'POORMAN': 0,
    'POORT': 0,
    'POORTENGA': 0,
    'POORTINGA': 0,
    'POOS': 0,
    'POOSER': 0,
    'POOT': 0,
    'POOTS': 0,
    'POOVEY': 0,
    'POP': 0,
    'POPA': 0,
    'POPADAK': 0,
    'POPAL': 0,
    'POPAT': 0,
    'POPE': 0,
    'POPECK': 0,
    'POPEJOY': 0,
    'POPEK': 0,
    'POPEL': 0,
    'POPELKA': 0,
    'POPENHAGEN': 0,
    'POPER': 0,
    'POPESCU': 0,
    'POPHAL': 0,
    'POPHAM': 0,
    'POPICH': 0,
    'POPICK': 0,
    'POPIEL': 0,
    'POPIELA': 0,
    'POPIELARCZYK': 0,
    'POPIELARSKI': 0,
    'POPIELARZ': 0,
    'POPIELSKI': 0,
    'POPIK': 0,
    'POPILEK': 0,
    'POPIOLEK': 0,
    'POPISH': 0,
    'POPKE': 0,
    'POPKEN': 0,
    'POPKES': 0,
    'POPKEY': 0,
    'POPKIN': 0,
    'POPKINS': 0,
    'POPKO': 0,
    'POPLAR': 0,
    'POPLASKI': 0,
    'POPLAWSKI': 0,
    'POPLE': 0,
    'POPLIN': 0,
    'POPMA': 0,
    'POPO': 0,
    'POPOCA': 0,
    'POPOFF': 0,
    'POPOLA': 0,
    'POPOLI': 0,
    'POPOLIZIO': 0,
    'POPOLO': 0,
    'POPOOLA': 0,
    'POPOUR': 0,
    'POPOV': 0,
    'POPOVA': 0,
    'POPOVIC': 0,
    'POPOVICH': 0,
    'POPOVICI': 0,
    'POPOVITCH': 0,
    'POPOVITS': 0,
    'POPOVSKI': 0,
    'POPOW': 0,
    'POPOWICH': 0,
    'POPOWICZ': 0,
    'POPOWITZ': 0,
    'POPOWSKI': 0,
    'POPP': 0,
    'POPPA': 0,
    'POPPE': 0,
    'POPPEL': 0,
    'POPPELL': 0,
    'POPPELREITER': 0,
    'POPPEMA': 0,
    'POPPEN': 0,
    'POPPENBERG': 0,
    'POPPENGA': 0,
    'POPPENHAGEN': 0,
    'POPPENS': 0,
    'POPPER': 0,
    'POPPERT': 0,
    'POPPIE': 0,
    'POPPINGA': 0,
    'POPPINO': 0,
    'POPPITI': 0,
    'POPPLE': 0,
    'POPPLER': 0,
    'POPPLETON': 0,
    'POPPLEWELL': 0,
    'POPPS': 0,
    'POPPY': 0,
    'POPS': 0,
    'POPSON': 0,
    'POPULUS': 0,
    'POPWELL': 0,
    'POQUETTE': 0,
    'POQUIZ': 0,
    'POR': 0,
    'PORA': 0,
    'PORADA': 0,
    'PORAMBO': 0,
    'PORAT': 0,
    'PORATH': 0,
    'PORCARI': 0,
    'PORCARO': 0,
    'PORCAYO': 0,
    'PORCELLA': 0,
    'PORCELLI': 0,
    'PORCELLO': 0,
    'PORCH': 0,
    'PORCHA': 0,
    'PORCHAS': 0,
    'PORCHE': 0,
    'PORCHEA': 0,
    'PORCHER': 0,
    'PORCHIA': 0,
    'PORCIELLO': 0,
    'PORCIUNCULA': 0,
    'PORCO': 0,
    'PORDON': 0,
    'PORE': 0,
    'POREBSKI': 0,
    'POREDA': 0,
    'POREE': 0,
    'PORELL': 0,
    'POREMBA': 0,
    'POREMBSKI': 0,
    'POREMSKI': 0,
    'PORET': 0,
    'PORETSKY': 0,
    'PORFIDO': 0,
    'PORFILIO': 0,
    'PORFIRIO': 0.9803921568627452,
    'PORGES': 0,
    'PORIER': 0,
    'PORIS': 0,
    'PORK': 0,
    'PORLIER': 0,
    'PORN': 0,
    'POROPAT': 0,
    'POROWSKI': 0,
    'PORPIGLIA': 0,
    'PORPORA': 0,
    'PORR': 0,
    'PORRAS': 0,
    'PORRATA': 0,
    'PORRAZ': 0,
    'PORRAZZO': 0,
    'PORRECA': 0,
    'PORRECO': 0,
    'PORRELLO': 0,
    'PORRES': 0,
    'PORRETT': 0,
    'PORRETTA': 0,
    'PORRETTO': 0,
    'PORRINI': 0,
    'PORRINO': 0,
    'PORRITT': 0,
    'PORRO': 0,
    'PORROVECCHIO': 0,
    'PORSCH': 0,
    'PORSCHE': 0.9433962264150944,
    'PORSHA': 1,
    'PORT': 0,
    'PORTA': 0,
    'PORTAL': 0,
    'PORTALATIN': 0,
    'PORTALE': 0,
    'PORTALES': 0,
    'PORTANOVA': 0,
    'PORTARO': 0,
    'PORTAS': 0,
    'PORTCH': 0,
    'PORTE': 0,
    'PORTEE': 0,
    'PORTELA': 0,
    'PORTELL': 0,
    'PORTELLA': 0,
    'PORTELLI': 0,
    'PORTELLO': 0,
    'PORTEN': 0,
    'PORTENIER': 0,
    'PORTEOUS': 0,
    'PORTER': 0.0643707756678468,
    'PORTERA': 0,
    'PORTERFIELD': 0,
    'PORTERIE': 0,
    'PORTES': 0,
    'PORTEUS': 0,
    'PORTH': 0,
    'PORTIA': 1,
    'PORTICE': 0,
    'PORTIE': 0,
    'PORTIER': 0,
    'PORTILLA': 0,
    'PORTILLO': 0,
    'PORTILLOS': 0,
    'PORTING': 0,
    'PORTINGA': 0,
    'PORTIO': 0,
    'PORTIS': 0,
    'PORTLAND': 0,
    'PORTLEY': 0,
    'PORTLOCK': 0,
    'PORTMAN': 0,
    'PORTMANN': 0,
    'PORTNER': 0,
    'PORTNEY': 0,
    'PORTNOFF': 0,
    'PORTNOV': 0,
    'PORTNOY': 0,
    'PORTO': 0,
    'PORTOBANCO': 0,
    'PORTOCARRERO': 0,
    'PORTOLESE': 0,
    'PORTON': 0,
    'PORTOR': 0,
    'PORTORREAL': 0,
    'PORTREY': 0,
    'PORTS': 0,
    'PORTSCHELLER': 0,
    'PORTUESE': 0,
    'PORTUGAL': 0,
    'PORTUGUES': 0,
    'PORTUGUEZ': 0,
    'PORTUONDO': 0,
    'PORTWINE': 0,
    'PORTWOOD': 0,
    'PORTZ': 0,
    'PORTZEN': 0,
    'PORTZER': 0,
    'PORTZLINE': 0,
    'PORUBSKY': 0,
    'PORVAZNIK': 0,
    'PORZEL': 0,
    'PORZELT': 0,
    'PORZIO': 0,
    'POS': 0,
    'POSA': 0,
    'POSADA': 0,
    'POSADAS': 0,
    'POSAS': 0,
    'POSAVEC': 0,
    'POSCH': 0,
    'POSE': 0,
    'POSEKANY': 0,
    'POSEN': 0,
    'POSER': 0,
    'POSEY': 0,
    'POSH': 0,
    'POSHARD': 0,
    'POSIK': 0,
    'POSILLICO': 0,
    'POSIN': 0,
    'POSITANO': 0,
    'POSKA': 0,
    'POSKEY': 0,
    'POSKIN': 0,
    'POSKUS': 0,
    'POSLEY': 0,
    'POSLUSZNY': 0,
    'POSNER': 0,
    'POSNICK': 0,
    'POSO': 0,
    'POSOS': 0,
    'POSPICHAL': 0,
    'POSPIECH': 0,
    'POSPISHIL': 0,
    'POSPISIL': 0,
    'POSS': 0,
    'POSSE': 0,
    'POSSEHL': 0,
    'POSSELT': 0,
    'POSSEMATO': 0,
    'POSSER': 0,
    'POSSERT': 0,
    'POSSIN': 0,
    'POSSINGER': 0,
    'POSSLEY': 0,
    'POSSO': 0,
    'POSSON': 0,
    'POST': 0,
    'POSTA': 0,
    'POSTAL': 0,
    'POSTE': 0,
    'POSTEL': 0,
    'POSTELL': 0,
    'POSTELLE': 0,
    'POSTELWAIT': 0,
    'POSTEMA': 0,
    'POSTEN': 0,
    'POSTER': 0,
    'POSTERARO': 0,
    'POSTERICK': 0,
    'POSTHUMA': 0,
    'POSTHUMUS': 0,
    'POSTIER': 0,
    'POSTIGLIONE': 0,
    'POSTIGO': 0,
    'POSTIN': 0,
    'POSTL': 0,
    'POSTLE': 0,
    'POSTLER': 0,
    'POSTLES': 0,
    'POSTLETHWAIT': 0,
    'POSTLETHWAITE': 0,
    'POSTLEWAIT': 0,
    'POSTLEWAITE': 0,
    'POSTLEY': 0,
    'POSTMA': 0,
    'POSTMAN': 0,
    'POSTMUS': 0,
    'POSTOAK': 0,
    'POSTON': 0,
    'POSTORINO': 0,
    'POSTULA': 0,
    'POSUSTA': 0,
    'POSVAR': 0,
    'POSZ': 0,
    'POT': 0,
    'POTACZEK': 0,
    'POTAK': 0,
    'POTAPENKO': 0,
    'POTAPOV': 0,
    'POTAS': 0,
    'POTASH': 0,
    'POTE': 0,
    'POTEAT': 0,
    'POTEAU': 0,
    'POTEE': 0,
    'POTEET': 0,
    'POTEETE': 0,
    'POTEMPA': 0,
    'POTENTE': 0,
    'POTENZA': 0,
    'POTENZIANI': 0,
    'POTER': 0,
    'POTERACKI': 0,
    'POTERE': 0,
    'POTES': 0,
    'POTESTA': 0,
    'POTESTIO': 0,
    'POTGETER': 0,
    'POTH': 0,
    'POTHAST': 0,
    'POTHEN': 0,
    'POTHIER': 0,
    'POTHOFF': 0,
    'POTHOVEN': 0,
    'POTI': 0,
    'POTIER': 0,
    'POTILLO': 0,
    'POTITO': 0,
    'POTKAY': 0,
    'POTLURI': 0,
    'POTMESIL': 0,
    'POTO': 0,
    'POTOCHNIK': 0,
    'POTOCKI': 0,
    'POTOCNIK': 0,
    'POTOCZAK': 0,
    'POTOCZNY': 0,
    'POTOK': 0,
    'POTOKA': 0,
    'POTOKAR': 0,
    'POTORSKI': 0,
    'POTOSKI': 0,
    'POTOSKY': 0,
    'POTOSNAK': 0,
    'POTRATZ': 0,
    'POTRYKUS': 0,
    'POTRZEBA': 0,
    'POTRZEBOWSKI': 0,
    'POTRZUSKI': 0,
    'POTT': 0,
    'POTTBERG': 0,
    'POTTEBAUM': 0,
    'POTTEIGER': 0,
    'POTTENGER': 0,
    'POTTER': 0,
    'POTTERF': 0,
    'POTTERFIELD': 0,
    'POTTERS': 0,
    'POTTERTON': 0,
    'POTTHAST': 0,
    'POTTHOFF': 0,
    'POTTIER': 0,
    'POTTINGER': 0,
    'POTTKOTTER': 0,
    'POTTLE': 0,
    'POTTMEYER': 0,
    'POTTORF': 0,
    'POTTORFF': 0,
    'POTTRATZ': 0,
    'POTTS': 0,
    'POTTSCHMIDT': 0,
    'POTUCEK': 0,
    'POTURALSKI': 0,
    'POTVIN': 0,
    'POTWIN': 0,
    'POTWORA': 0,
    'POTYRALA': 0,
    'POTZ': 0,
    'POU': 0,
    'POUCH': 0,
    'POUCHER': 0,
    'POUCHIE': 0,
    'POUDER': 0,
    'POUDRIER': 0,
    'POUGE': 0,
    'POUGET': 0,
    'POUGH': 0,
    'POUK': 0,
    'POULAIN': 0,
    'POULAKIS': 0,
    'POULAKOS': 0,
    'POULARD': 0,
    'POULIN': 0,
    'POULIOS': 0,
    'POULIOT': 0,
    'POULIS': 0,
    'POULL': 0,
    'POULLARD': 0,
    'POULOPOULOS': 0,
    'POULOS': 0,
    'POULOSE': 0,
    'POULSEN': 0,
    'POULSON': 0,
    'POULTER': 0,
    'POULTNEY': 0,
    'POULTON': 0,
    'POUNCEY': 0,
    'POUNCIL': 0,
    'POUNCY': 0,
    'POUND': 0,
    'POUNDER': 0,
    'POUNDERS': 0,
    'POUNDS': 0,
    'POUNDSTONE': 0,
    'POUPARD': 0,
    'POUPART': 0,
    'POUPORE': 0,
    'POUR': 0,
    'POURCHOT': 0,
    'POURCIAU': 0,
    'POURIER': 0,
    'POURNARAS': 0,
    'POURROY': 0,
    'POUSH': 0,
    'POUSSARD': 0,
    'POUSSON': 0,
    'POUST': 0,
    'POUTRE': 0,
    'POUX': 0,
    'POV': 0,
    'POVEDA': 0,
    'POVENTUD': 0,
    'POVEROMO': 0,
    'POVEY': 0,
    'POVICH': 0,
    'POVILAITIS': 0,
    'POVINELLI': 0,
    'POVLICH': 0,
    'POVOLNY': 0,
    'POW': 0,
    'POWALISZ': 0,
    'POWANDA': 0,
    'POWDER': 0,
    'POWDERLY': 0,
    'POWDERS': 0,
    'POWDRILL': 0,
    'POWE': 0,
    'POWEL': 0,
    'POWELL': 0,
    'POWELLS': 0,
    'POWELS': 0,
    'POWELSON': 0,
    'POWER': 0,
    'POWERS': 0,
    'POWERY': 0,
    'POWIS': 0,
    'POWLAS': 0,
    'POWLEDGE': 0,
    'POWLEN': 0,
    'POWLES': 0,
    'POWLESS': 0,
    'POWLEY': 0,
    'POWLISON': 0,
    'POWLUS': 0,
    'POWNALL': 0,
    'POWNELL': 0,
    'POWNER': 0,
    'POWRIE': 0,
    'POWROZNIK': 0,
    'POWSER': 0,
    'POXON': 0,
    'POY': 0,
    'POYDRAS': 0,
    'POYE': 0,
    'POYER': 0,
    'POYFAIR': 0,
    'POYNER': 0,
    'POYNOR': 0,
    'POYNTER': 0,
    'POYNTON': 0,
    'POYSER': 0,
    'POYTHRESS': 0,
    'POZ': 0,
    'POZAR': 0,
    'POZAS': 0,
    'POZDOL': 0,
    'POZEGA': 0,
    'POZEK': 0,
    'POZEN': 0,
    'POZIN': 0,
    'POZNANSKI': 0,
    'POZNER': 0,
    'POZNIAK': 0,
    'POZNICK': 0,
    'POZO': 0,
    'POZORSKI': 0,
    'POZOS': 0,
    'POZUELOS': 0,
    'POZZA': 0,
    'POZZI': 0,
    'POZZO': 0,
    'POZZUOLI': 0,
    'POZZUTO': 0,
    'PPOOL': 0,
    'PRABHAKAR': 0,
    'PRABHAKARAN': 0,
    'PRABHU': 0,
    'PRACH': 0,
    'PRACHAR': 0,
    'PRACHT': 0,
    'PRACHYL': 0,
    'PRACK': 0,
    'PRADA': 0,
    'PRADE': 0,
    'PRADEL': 0,
    'PRADER': 0,
    'PRADHAN': 0,
    'PRADIA': 0,
    'PRADIER': 0,
    'PRADO': 0,
    'PRADOS': 0,
    'PRAEFKE': 0,
    'PRAEGER': 0,
    'PRAET': 0,
    'PRAETORIUS': 0,
    'PRAEUNER': 0,
    'PRAG': 0,
    'PRAGER': 0,
    'PRAGLE': 0,
    'PRAH': 0,
    'PRAHL': 0,
    'PRAHM': 0,
    'PRAIN': 0,
    'PRAINITO': 0,
    'PRAINO': 0,
    'PRAIRIE': 0,
    'PRAIS': 0,
    'PRAISWATER': 0,
    'PRAJAPATI': 0,
    'PRAJZNER': 0,
    'PRAK': 0,
    'PRAKASH': 0,
    'PRALL': 0,
    'PRALLE': 0,
    'PRAMANN': 0,
    'PRAMIK': 0,
    'PRAMUK': 0,
    'PRANCE': 0,
    'PRANG': 0,
    'PRANGE': 0,
    'PRANGER': 0,
    'PRANGLEY': 0,
    'PRANKE': 0,
    'PRANO': 0,
    'PRANSKY': 0,
    'PRANTE': 0,
    'PRANZO': 0,
    'PRASAD': 0,
    'PRASCH': 0,
    'PRASCHAK': 0,
    'PRASEK': 0,
    'PRASEUTH': 0,
    'PRASHAD': 0,
    'PRASHAW': 0,
    'PRASIL': 0,
    'PRASKA': 0,
    'PRASLA': 0,
    'PRASS': 0,
    'PRASSAS': 0,
    'PRASSE': 0,
    'PRASSER': 0,
    'PRAST': 0,
    'PRASUHN': 0,
    'PRAT': 0,
    'PRATA': 0,
    'PRATAP': 0,
    'PRATCHER': 0,
    'PRATE': 0,
    'PRATER': 0,
    'PRATHER': 0,
    'PRATI': 0,
    'PRATICO': 0,
    'PRATKA': 0,
    'PRATL': 0,
    'PRATLEY': 0,
    'PRATO': 0,
    'PRATOR': 0,
    'PRATS': 0,
    'PRATSCHER': 0,
    'PRATT': 0,
    'PRATTE': 0,
    'PRATTI': 0,
    'PRATTIS': 0,
    'PRATTO': 0,
    'PRATTS': 0,
    'PRATZ': 0,
    'PRAUGHT': 0,
    'PRAUL': 0,
    'PRAUS': 0,
    'PRAUSA': 0,
    'PRAUSE': 0,
    'PRAVATA': 0,
    'PRAVATO': 0,
    'PRAVECEK': 0,
    'PRAWDZIK': 0,
    'PRAWL': 0,
    'PRAX': 0,
    'PRAY': 0,
    'PRAYER': 0,
    'PRAYLOW': 0,
    'PRAYOR': 0,
    'PRAYTOR': 0,
    'PRAZAK': 0,
    'PRAZNIK': 0,
    'PRAZUCH': 0,
    'PRCHAL': 0,
    'PREACHER': 0,
    'PREAP': 0,
    'PREAS': 0,
    'PREAST': 0,
    'PREATOR': 0,
    'PREBBLE': 0,
    'PREBE': 0,
    'PREBIL': 0,
    'PREBISH': 0,
    'PREBLE': 0,
    'PREBULA': 0,
    'PRECHEL': 0,
    'PRECHT': 0,
    'PRECHTEL': 0,
    'PRECHTL': 0,
    'PRECIADO': 0,
    'PRECIOUS': 0.9900990099009901,
    'PRECISE': 0,
    'PRECORD': 0,
    'PRECOURT': 0,
    'PREDA': 0,
    'PREDDIE': 0,
    'PREDDY': 0,
    'PREDER': 0,
    'PREDIGER': 0,
    'PREDMORE': 0,
    'PREDOVICH': 0,
    'PREE': 0,
    'PREECE': 0,
    'PREER': 0,
    'PREFONTAINE': 0,
    'PREGEANT': 0,
    'PREGENT': 0,
    'PREGLER': 0,
    'PREGO': 0,
    'PREHEIM': 0,
    'PREHM': 0,
    'PREHN': 0,
    'PREHODA': 0,
    'PREIMESBERGER': 0,
    'PREINER': 0,
    'PREIS': 0,
    'PREISEL': 0,
    'PREISER': 0,
    'PREISING': 0,
    'PREISINGER': 0,
    'PREISLER': 0,
    'PREISNER': 0,
    'PREISS': 0,
    'PREISSER': 0,
    'PREISSLER': 0,
    'PREISSNER': 0,
    'PREISTER': 0,
    'PREITE': 0,
    'PREJEAN': 0,
    'PREJEANT': 0,
    'PREKKER': 0,
    'PREKOP': 0,
    'PRELESNIK': 0,
    'PRELI': 0,
    'PRELL': 0,
    'PRELLE': 0,
    'PRELLER': 0,
    'PRELLWITZ': 0,
    'PRELOW': 0,
    'PREM': 0,
    'PREMEAUX': 0,
    'PREMER': 0,
    'PREMINGER': 0,
    'PREMO': 0,
    'PREMPEH': 0,
    'PREMUS': 0,
    'PRENATT': 0,
    'PRENDERGAST': 0,
    'PRENDES': 0,
    'PRENDEVILLE': 0,
    'PRENDEZ': 0,
    'PRENDIVILLE': 0,
    'PRENETA': 0,
    'PRENEVOST': 0,
    'PRENGER': 0,
    'PRENOSIL': 0,
    'PRENOVOST': 0,
    'PRENTICE': 0,
    'PRENTIS': 0,
    'PRENTISS': 0,
    'PREPETIT': 0,
    'PRESA': 0,
    'PRESAS': 0,
    'PRESBERRY': 0,
    'PRESBREY': 0,
    'PRESBURY': 0,
    'PRESBY': 0,
    'PRESCHER': 0,
    'PRESCO': 0,
    'PRESCOD': 0,
    'PRESCOT': 0,
    'PRESCOTT': 0,
    'PRESEAU': 0,
    'PRESENDIEU': 0,
    'PRESENT': 0,
    'PRESGRAVES': 0,
    'PRESGROVE': 0,
    'PRESHA': 0,
    'PRESHER': 0,
    'PRESHO': 0,
    'PRESIADO': 0,
    'PRESIDENT': 0,
    'PRESKE': 0,
    'PRESKITT': 0,
    'PRESLAR': 0,
    'PRESLER': 0,
    'PRESLEY': 0,
    'PRESMAN': 0,
    'PRESNAL': 0,
    'PRESNALL': 0,
    'PRESNAR': 0,
    'PRESNELL': 0,
    'PRESOCK': 0,
    'PRESS': 0,
    'PRESSEL': 0,
    'PRESSER': 0,
    'PRESSEY': 0,
    'PRESSGROVE': 0,
    'PRESSIMONE': 0,
    'PRESSLER': 0,
    'PRESSLEY': 0,
    'PRESSLY': 0,
    'PRESSMAN': 0,
    'PRESSNALL': 0,
    'PRESSNELL': 0,
    'PRESSON': 0,
    'PRESSWOOD': 0,
    'PREST': 0,
    'PRESTA': 0,
    'PRESTAGE': 0,
    'PRESTANO': 0,
    'PRESTEGAARD': 0,
    'PRESTEGARD': 0,
    'PRESTEL': 0,
    'PRESTENBACH': 0,
    'PRESTER': 0,
    'PRESTERA': 0,
    'PRESTI': 0,
    'PRESTIA': 0,
    'PRESTIANNI': 0,
    'PRESTIDGE': 0,
    'PRESTIFILIPPO': 0,
    'PRESTIGIACOMO': 0,
    'PRESTIN': 0,
    'PRESTIPINO': 0,
    'PRESTLEY': 0,
    'PRESTLY': 0,
    'PRESTO': 0,
    'PRESTON': 0.6666666666666666,
    'PRESTRIDGE': 0,
    'PRESTWICH': 0,
    'PRESTWOOD': 0,
    'PRESUME': 0,
    'PRESUTTI': 0,
    'PRESUTTO': 0,
    'PRESZ': 0,
    'PRESZLER': 0,
    'PRETE': 0,
    'PRETEROTI': 0,
    'PRETI': 0,
    'PRETKO': 0,
    'PRETLOW': 0,
    'PRETO': 0,
    'PRETORIUS': 0,
    'PRETSCH': 0,
    'PRETTI': 0,
    'PRETTO': 0,
    'PRETTY': 0,
    'PRETTYMAN': 0,
    'PRETTYWEASEL': 0,
    'PRETZ': 0,
    'PRETZEL': 0,
    'PRETZER': 0,
    'PREUDHOMME': 0,
    'PREUETT': 0,
    'PREUIT': 0,
    'PREUITT': 0,
    'PREUNINGER': 0,
    'PREUS': 0,
    'PREUSCH': 0,
    'PREUSS': 0,
    'PREUSSE': 0,
    'PREUSSER': 0,
    'PREVAL': 0,
    'PREVATT': 0,
    'PREVATTE': 0,
    'PREVE': 0,
    'PREVEDEL': 0,
    'PREVETE': 0,
    'PREVETT': 0,
    'PREVETTE': 0,
    'PREVIDI': 0,
    'PREVIL': 0,
    'PREVILLE': 0,
    'PREVILON': 0,
    'PREVIS': 0,
    'PREVITE': 0,
    'PREVITERA': 0,
    'PREVITI': 0,
    'PREVO': 0,
    'PREVOST': 0,
    'PREVOT': 0,
    'PREW': 0,
    'PREWETT': 0,
    'PREWIT': 0,
    'PREWITT': 0,
    'PREY': 0,
    'PREYER': 0,
    'PREZA': 0,
    'PREZE': 0,
    'PREZIOSI': 0,
    'PREZIOSO': 0,
    'PREZZY': 0,
    'PRIAL': 0,
    'PRIANO': 0,
    'PRIAR': 0,
    'PRIBANIC': 0,
    'PRIBBENOW': 0,
    'PRIBBERNOW': 0,
    'PRIBBLE': 0,
    'PRIBEK': 0,
    'PRIBIL': 0,
    'PRIBILA': 0,
    'PRIBISH': 0,
    'PRIBLE': 0,
    'PRIBNOW': 0,
    'PRIBULA': 0,
    'PRIBYL': 0,
    'PRICE': 0,
    'PRICER': 0,
    'PRICHARD': 0,
    'PRICHER': 0,
    'PRICHETT': 0,
    'PRICILLA': 1,
    'PRICKEL': 0,
    'PRICKETT': 0,
    'PRIDA': 0,
    'PRIDAY': 0,
    'PRIDDLE': 0,
    'PRIDDY': 0,
    'PRIDE': 0,
    'PRIDEAUX': 0,
    'PRIDEMORE': 0,
    'PRIDGEN': 0,
    'PRIDGEON': 0,
    'PRIDGETT': 0,
    'PRIDHAM': 0,
    'PRIDMORE': 0,
    'PRIEB': 0,
    'PRIEBE': 0,
    'PRIEDE': 0,
    'PRIEFER': 0,
    'PRIEGEL': 0,
    'PRIEGO': 0,
    'PRIEHS': 0,
    'PRIEL': 0,
    'PRIELIPP': 0,
    'PRIEM': 0,
    'PRIEMER': 0,
    'PRIEN': 0,
    'PRIER': 0,
    'PRIES': 0,
    'PRIESKORN': 0,
    'PRIESMEYER': 0,
    'PRIESS': 0,
    'PRIEST': 0,
    'PRIESTAS': 0,
    'PRIESTER': 0,
    'PRIESTLEY': 0,
    'PRIESTLY': 0,
    'PRIESTMAN': 0,
    'PRIETO': 0,
    'PRIETZ': 0,
    'PRIEUR': 0,
    'PRIEVE': 0,
    'PRIEWE': 0,
    'PRIFOGLE': 0,
    'PRIFTI': 0,
    'PRIGG': 0,
    'PRIGGE': 0,
    'PRIGMORE': 0,
    'PRIGNANO': 0,
    'PRIHODA': 0,
    'PRIJATEL': 0,
    'PRIKRYL': 0,
    'PRILE': 0,
    'PRILL': 0,
    'PRILLAMAN': 0,
    'PRILLER': 0,
    'PRILLIMAN': 0,
    'PRILLWITZ': 0,
    'PRIM': 0,
    'PRIMA': 0,
    'PRIMACIO': 0,
    'PRIMACK': 0,
    'PRIMAK': 0,
    'PRIMAS': 0,
    'PRIMAVERA': 0,
    'PRIME': 0,
    'PRIMEAU': 0,
    'PRIMEAUX': 0,
    'PRIMER': 0,
    'PRIMERA': 0,
    'PRIMERANO': 0,
    'PRIMERO': 0,
    'PRIMES': 0,
    'PRIMIANI': 0,
    'PRIMIANO': 0,
    'PRIMICH': 0,
    'PRIMM': 0,
    'PRIMMER': 0,
    'PRIMO': 0,
    'PRIMOUS': 0,
    'PRIMOZIC': 0,
    'PRIMOZICH': 0,
    'PRIMROSE': 0,
    'PRIMUS': 0,
    'PRINA': 0,
    'PRINCE': 0.23201856148491878,
    'PRINCESS': 1,
    'PRINCIOTTA': 0,
    'PRINCIPATO': 0,
    'PRINCIPE': 0,
    'PRINCIPI': 0,
    'PRINCIPIO': 0,
    'PRINDIVILLE': 0,
    'PRINDLE': 0,
    'PRINE': 0,
    'PRING': 0,
    'PRINGLE': 0,
    'PRINGNITZ': 0,
    'PRINK': 0,
    'PRINKEY': 0,
    'PRINS': 0,
    'PRINSEN': 0,
    'PRINSTER': 0,
    'PRINTUP': 0,
    'PRINTY': 0,
    'PRINTZ': 0,
    'PRINZ': 0,
    'PRINZI': 0,
    'PRINZING': 0,
    'PRINZIVALLI': 0,
    'PRINZO': 0,
    'PRIOLA': 0,
    'PRIOLEAU': 0,
    'PRIOLETTI': 0,
    'PRIOLO': 0,
    'PRIOR': 0,
    'PRIORE': 0,
    'PRISBREY': 0,
    'PRISBY': 0,
    'PRISCILA': 1,
    'PRISCILLA': 1,
    'PRISCO': 0,
    'PRISE': 0,
    'PRISELAC': 0,
    'PRISER': 0,
    'PRISK': 0,
    'PRISKE': 0,
    'PRISOCK': 0,
    'PRISSEL': 0,
    'PRISTAS': 0,
    'PRISTASH': 0,
    'PRISTERA': 0,
    'PRITCHARD': 0,
    'PRITCHER': 0,
    'PRITCHET': 0,
    'PRITCHETT': 0,
    'PRITIKIN': 0,
    'PRITSKER': 0,
    'PRITT': 0,
    'PRITTIE': 0,
    'PRITTS': 0,
    'PRITZ': 0,
    'PRITZEL': 0,
    'PRITZKER': 0,
    'PRITZL': 0,
    'PRITZLAFF': 0,
    'PRIVADO': 0,
    'PRIVAT': 0,
    'PRIVATE': 0,
    'PRIVE': 0,
    'PRIVETT': 0,
    'PRIVETTE': 0,
    'PRIVITERA': 0,
    'PRIVITT': 0,
    'PRIVOTT': 0,
    'PRIVRATSKY': 0,
    'PRIZANT': 0,
    'PRIZER': 0,
    'PRIZIO': 0,
    'PRIZZI': 0,
    'PRO': 0,
    'PROA': 0,
    'PROANO': 0,
    'PROAPS': 0,
    'PROBASCO': 0,
    'PROBER': 0,
    'PROBERT': 0,
    'PROBST': 0,
    'PROBUS': 0,
    'PROBY': 0,
    'PROCACCI': 0,
    'PROCACCINI': 0,
    'PROCACCINO': 0,
    'PROCACCIO': 0,
    'PROCAK': 0,
    'PROCE': 0,
    'PROCEL': 0,
    'PROCELL': 0,
    'PROCESS': 0,
    'PROCH': 0,
    'PROCHASKA': 0,
    'PROCHAZKA': 0,
    'PROCHILO': 0,
    'PROCHNIAK': 0,
    'PROCHNOW': 0,
    'PROCIDA': 0,
    'PROCINO': 0,
    'PROCISE': 0,
    'PROCK': 0,
    'PROCKISH': 0,
    'PROCKNOW': 0,
    'PROCKO': 0,
    'PROCOPIO': 0,
    'PROCTER': 0,
    'PROCTOR': 0,
    'PROCUNIER': 0,
    'PROCYK': 0,
    'PRODAN': 0,
    'PRODIGALIDAD': 0,
    'PRODOEHL': 0,
    'PRODZINSKI': 0,
    'PROE': 0,
    'PROEBER': 0,
    'PROEFROCK': 0,
    'PROEHL': 0,
    'PROELL': 0,
    'PROENZA': 0,
    'PROFANT': 0,
    'PROFENNO': 0,
    'PROFERA': 0,
    'PROFETA': 0,
    'PROFFER': 0,
    'PROFFIT': 0,
    'PROFFITT': 0,
    'PROFIT': 0,
    'PROFITA': 0,
    'PROFITT': 0,
    'PROFT': 0,
    'PROFUMO': 0,
    'PROGAR': 0,
    'PROHASKA': 0,
    'PROHL': 0,
    'PROIA': 0,
    'PROIETTI': 0,
    'PROIETTO': 0,
    'PROIOS': 0,
    'PROK': 0,
    'PROKASH': 0,
    'PROKAY': 0,
    'PROKES': 0,
    'PROKO': 0,
    'PROKOP': 0,
    'PROKOPCHAK': 0,
    'PROKOPCHUK': 0,
    'PROKOPEC': 0,
    'PROKOPENKO': 0,
    'PROKOPIAK': 0,
    'PROKOPOVICH': 0,
    'PROKOPOWICZ': 0,
    'PROKOS': 0,
    'PROKOSCH': 0,
    'PROKOTT': 0,
    'PROKSCH': 0,
    'PROKUP': 0,
    'PROKUPEK': 0,
    'PROKUSKI': 0,
    'PROL': 0,
    'PROLA': 0,
    'PROM': 0,
    'PROMES': 0,
    'PROMISE': 0,
    'PRON': 0,
    'PRONDZINSKI': 0,
    'PRONESTI': 0,
    'PRONG': 0,
    'PRONGER': 0,
    'PRONIO': 0,
    'PRONK': 0,
    'PRONKO': 0,
    'PRONOVOST': 0,
    'PRONSCHINSKE': 0,
    'PRONTI': 0,
    'PRONTO': 0,
    'PROO': 0,
    'PROOS': 0,
    'PROPECK': 0,
    'PROPER': 0,
    'PROPES': 0,
    'PROPHET': 0,
    'PROPHETE': 0,
    'PROPHETER': 0,
    'PROPHETT': 0,
    'PROPHITT': 0,
    'PROPP': 0,
    'PROPPER': 0,
    'PROPPS': 0,
    'PROPS': 0,
    'PROPSON': 0,
    'PROPST': 0,
    'PROROK': 0,
    'PROSAK': 0,
    'PROSCH': 0,
    'PROSCIA': 0,
    'PROSE': 0,
    'PROSEK': 0,
    'PROSEN': 0,
    'PROSEUS': 0,
    'PROSHEK': 0,
    'PROSISE': 0,
    'PROSKE': 0,
    'PROSOSKI': 0,
    'PROSPER': 0,
    'PROSPERE': 0,
    'PROSPERI': 0,
    'PROSPERIE': 0,
    'PROSPERO': 0,
    'PROSS': 0,
    'PROSSER': 0,
    'PROST': 0,
    'PROSTKO': 0,
    'PROSZEK': 0,
    'PROTACIO': 0,
    'PROTANO': 0,
    'PROTAS': 0,
    'PROTEAU': 0,
    'PROTHE': 0,
    'PROTHERO': 0,
    'PROTHEROE': 0,
    'PROTHMAN': 0,
    'PROTHO': 0,
    'PROTHRO': 0,
    'PROTIVA': 0,
    'PROTO': 0,
    'PROTOPAPAS': 0,
    'PROTSMAN': 0,
    'PROTT': 0,
    'PROTZ': 0,
    'PROTZMAN': 0,
    'PROTZMANN': 0,
    'PROUD': 0,
    'PROUDFIT': 0,
    'PROUDFOOT': 0,
    'PROUDMAN': 0,
    'PROUGH': 0,
    'PROUHET': 0,
    'PROULX': 0,
    'PROUSE': 0,
    'PROUT': 0,
    'PROUTY': 0,
    'PROVAN': 0,
    'PROVANCE': 0,
    'PROVANCHA': 0,
    'PROVANCHER': 0,
    'PROVEAUX': 0,
    'PROVEN': 0,
    'PROVENCAL': 0,
    'PROVENCE': 0,
    'PROVENCHER': 0,
    'PROVENCIO': 0,
    'PROVENS': 0,
    'PROVENZA': 0,
    'PROVENZALE': 0,
    'PROVENZANO': 0,
    'PROVENZO': 0,
    'PROVIDENCE': 0,
    'PROVIDENCIA': 1,
    'PROVIN': 0,
    'PROVINCE': 0,
    'PROVINE': 0,
    'PROVINES': 0,
    'PROVINO': 0,
    'PROVINS': 0,
    'PROVITT': 0,
    'PROVO': 0,
    'PROVOLT': 0,
    'PROVONCHA': 0,
    'PROVORSE': 0,
    'PROVOST': 0,
    'PROVOW': 0,
    'PROW': 0,
    'PROWANT': 0,
    'PROWELL': 0,
    'PROWS': 0,
    'PROWSE': 0,
    'PROX': 0,
    'PROXMIRE': 0,
    'PROZINSKI': 0,
    'PRPICH': 0,
    'PRUCE': 0,
    'PRUCHA': 0,
    'PRUCHNICKI': 0,
    'PRUCHNIK': 0,
    'PRUCNAL': 0,
    'PRUDDEN': 0,
    'PRUDE': 0,
    'PRUDEN': 0,
    'PRUDENCE': 1,
    'PRUDENCIO': 0,
    'PRUDENT': 0,
    'PRUDENTE': 0,
    'PRUDENTI': 0,
    'PRUDHOME': 0,
    'PRUDHOMME': 0,
    'PRUE': 0,
    'PRUEHER': 0,
    'PRUEITT': 0,
    'PRUEMER': 0,
    'PRUENTE': 0,
    'PRUESS': 0,
    'PRUESSNER': 0,
    'PRUET': 0,
    'PRUETER': 0,
    'PRUETT': 0,
    'PRUETTE': 0,
    'PRUGAR': 0,
    'PRUGH': 0,
    'PRUIETT': 0,
    'PRUIKSMA': 0,
    'PRUIM': 0,
    'PRUIS': 0,
    'PRUISMANN': 0,
    'PRUIT': 0,
    'PRUITT': 0,
    'PRUITTE': 0,
    'PRUKOP': 0,
    'PRULL': 0,
    'PRUM': 0,
    'PRUNA': 0,
    'PRUNEAU': 0,
    'PRUNEDA': 0,
    'PRUNER': 0,
    'PRUNIER': 0,
    'PRUNTY': 0,
    'PRUS': 0,
    'PRUSA': 0,
    'PRUSACZYK': 0,
    'PRUSAK': 0,
    'PRUSAKIEWICZ': 0,
    'PRUSAKOWSKI': 0,
    'PRUSE': 0,
    'PRUSH': 0,
    'PRUSHA': 0,
    'PRUSHINSKI': 0,
    'PRUSIA': 0,
    'PRUSIK': 0,
    'PRUSINOWSKI': 0,
    'PRUSINSKI': 0,
    'PRUSKI': 0,
    'PRUSKO': 0,
    'PRUSKY': 0,
    'PRUSS': 0,
    'PRUSSACK': 0,
    'PRUSSIA': 0,
    'PRUSSING': 0,
    'PRUSSMAN': 0,
    'PRUST': 0,
    'PRUSZYNSKI': 0,
    'PRUTCH': 0,
    'PRUTER': 0,
    'PRUTSMAN': 0,
    'PRUTZ': 0,
    'PRUTZMAN': 0,
    'PRUYN': 0,
    'PRUYNE': 0,
    'PRUZAN': 0,
    'PRUZANSKY': 0,
    'PRUZINSKY': 0,
    'PRY': 0,
    'PRYAL': 0,
    'PRYBYLSKI': 0,
    'PRYCE': 0,
    'PRYDE': 0,
    'PRYE': 0,
    'PRYEAR': 0,
    'PRYER': 0,
    'PRYMAK': 0,
    'PRYNE': 0,
    'PRYOR': 0,
    'PRYS': 0,
    'PRYSE': 0,
    'PRYSOCK': 0,
    'PRZEKOP': 0,
    'PRZEPIORA': 0,
    'PRZEWOZNIK': 0,
    'PRZYBILLA': 0,
    'PRZYBOCKI': 0,
    'PRZYBOROWSKI': 0,
    'PRZYBYCIEN': 0,
    'PRZYBYL': 0,
    'PRZYBYLA': 0,
    'PRZYBYLEK': 0,
    'PRZYBYLINSKI': 0,
    'PRZYBYLO': 0,
    'PRZYBYLOWICZ': 0,
    'PRZYBYLOWSKI': 0,
    'PRZYBYLSKI': 0,
    'PRZYBYSZ': 0,
    'PRZYBYSZEWSKI': 0,
    'PRZYGOCKI': 0,
    'PRZYGODA': 0,
    'PRZYMUS': 0,
    'PRZYTULA': 0,
    'PRZYTULSKI': 0,
    'PRZYWARA': 0,
    'PSAILA': 0,
    'PSALTIS': 0,
    'PSARAS': 0,
    'PSAROS': 0,
    'PSENCIK': 0,
    'PSIMER': 0,
    'PSOMAS': 0,
    'PSOTA': 0,
    'PSZCZOLKOWSKI': 0,
    'PSZENICZNY': 0,
    'PSZENNY': 0,
    'PTACEK': 0,
    'PTAK': 0,
    'PTASINSKI': 0,
    'PTASNIK': 0,
    'PTASZEK': 0,
    'PTASZYNSKI': 0,
    'PTOMEY': 0,
    'PU': 0,
    'PUA': 0,
    'PUAC': 0,
    'PUBLIC': 0,
    'PUBLICO': 0,
    'PUBLICOVER': 0,
    'PUC': 0,
    'PUCA': 0,
    'PUCCETTI': 0,
    'PUCCI': 0,
    'PUCCIA': 0,
    'PUCCIARELLI': 0,
    'PUCCINELLI': 0,
    'PUCCINI': 0,
    'PUCCIO': 0,
    'PUCEK': 0,
    'PUCEL': 0,
    'PUCH': 0,
    'PUCHALA': 0,
    'PUCHALLA': 0,
    'PUCHALSKI': 0,
    'PUCHALSKY': 0,
    'PUCHE': 0,
    'PUCHER': 0,
    'PUCHEU': 0,
    'PUCHI': 0,
    'PUCHTA': 0,
    'PUCILLO': 0,
    'PUCILOWSKI': 0,
    'PUCINO': 0,
    'PUCK': 0,
    'PUCKER': 0,
    'PUCKERIN': 0,
    'PUCKET': 0,
    'PUCKETT': 0,
    'PUCKETTE': 0,
    'PUCKEY': 0,
    'PUCKHABER': 0,
    'PUCO': 0,
    'PUDAS': 0,
    'PUDDER': 0,
    'PUDDY': 0,
    'PUDELEK': 0,
    'PUDELKO': 0,
    'PUDENZ': 0,
    'PUDER': 0,
    'PUDERBAUGH': 0,
    'PUDIL': 0,
    'PUDLINER': 0,
    'PUDLO': 0,
    'PUDLOWSKI': 0,
    'PUDNEY': 0,
    'PUDVAH': 0,
    'PUDWILL': 0,
    'PUE': 0,
    'PUEBLA': 0,
    'PUEBLO': 0,
    'PUELLO': 0,
    'PUENT': 0,
    'PUENTE': 0,
    'PUENTES': 0,
    'PUEPPKE': 0,
    'PUERNER': 0,
    'PUERTA': 0,
    'PUERTAS': 0,
    'PUERTO': 0,
    'PUES': 0,
    'PUESCHEL': 0,
    'PUETT': 0,
    'PUETZ': 0,
    'PUFAHL': 0,
    'PUFALL': 0,
    'PUFF': 0,
    'PUFFENBARGER': 0,
    'PUFFENBERGER': 0,
    'PUFFER': 0,
    'PUFFETT': 0,
    'PUFFINBARGER': 0,
    'PUFFINBERGER': 0,
    'PUFFINBURGER': 0,
    'PUFFPAFF': 0,
    'PUFPAFF': 0,
    'PUGA': 0,
    'PUGACH': 0,
    'PUGATCH': 0,
    'PUGEDA': 0,
    'PUGEL': 0,
    'PUGH': 0,
    'PUGHE': 0,
    'PUGHSLEY': 0,
    'PUGLIA': 0,
    'PUGLIANO': 0,
    'PUGLIELLI': 0,
    'PUGLIESE': 0,
    'PUGLIESI': 0,
    'PUGLISE': 0,
    'PUGLISI': 0,
    'PUGMIRE': 0,
    'PUGSLEY': 0,
    'PUHA': 0,
    'PUHAK': 0,
    'PUHALA': 0,
    'PUHALLA': 0,
    'PUHALSKI': 0,
    'PUHEK': 0,
    'PUHL': 0,
    'PUHLMAN': 0,
    'PUHR': 0,
    'PUHRMANN': 0,
    'PUIG': 0,
    'PUJALS': 0,
    'PUJARA': 0,
    'PUJOL': 0,
    'PUJOLS': 0,
    'PUK': 0,
    'PUKAS': 0,
    'PULA': 0,
    'PULAK': 0,
    'PULANCO': 0,
    'PULASKI': 0,
    'PULCE': 0,
    'PULCHER': 0,
    'PULCIFER': 0,
    'PULCINELLA': 0,
    'PULCINI': 0,
    'PULCINO': 0,
    'PULDA': 0,
    'PULE': 0,
    'PULEC': 0,
    'PULEIO': 0,
    'PULEO': 0,
    'PULERA': 0,
    'PULFER': 0,
    'PULFORD': 0,
    'PULFREY': 0,
    'PULGAR': 0,
    'PULGARIN': 0,
    'PULHAM': 0,
    'PULIAFICO': 0,
    'PULICE': 0,
    'PULIDO': 0,
    'PULIS': 0,
    'PULITANO': 0,
    'PULITI': 0,
    'PULITO': 0,
    'PULIZZI': 0,
    'PULJU': 0,
    'PULK': 0,
    'PULKKINEN': 0,
    'PULKOWSKI': 0,
    'PULKRABEK': 0,
    'PULL': 0,
    'PULLA': 0,
    'PULLAM': 0,
    'PULLAN': 0,
    'PULLAND': 0,
    'PULLANO': 0,
    'PULLAR': 0,
    'PULLARA': 0,
    'PULLARO': 0,
    'PULLEM': 0,
    'PULLEN': 0,
    'PULLENS': 0,
    'PULLER': 0,
    'PULLES': 0,
    'PULLEY': 0,
    'PULLI': 0,
    'PULLIA': 0,
    'PULLIAM': 0,
    'PULLIAN': 0,
    'PULLIE': 0,
    'PULLIG': 0,
    'PULLIN': 0,
    'PULLING': 0,
    'PULLINGS': 0,
    'PULLINS': 0,
    'PULLIS': 0,
    'PULLIUM': 0,
    'PULLMAN': 0,
    'PULLO': 0,
    'PULLOM': 0,
    'PULLON': 0,
    'PULLUM': 0,
    'PULLY': 0,
    'PULMANO': 0,
    'PULOS': 0,
    'PULPHUS': 0,
    'PULS': 0,
    'PULSCHER': 0,
    'PULSE': 0,
    'PULSIFER': 0,
    'PULSINELLI': 0,
    'PULSIPHER': 0,
    'PULSKAMP': 0,
    'PULST': 0,
    'PULTE': 0,
    'PULTORAK': 0,
    'PULTS': 0,
    'PULTZ': 0,
    'PULU': 0,
    'PULVER': 0,
    'PULVERMACHER': 0,
    'PULVINO': 0,
    'PULVIRENTI': 0,
    'PUM': 0,
    'PUMA': 0,
    'PUMAREJO': 0,
    'PUMFORD': 0,
    'PUMFREY': 0,
    'PUMILIA': 0,
    'PUMMEL': 0,
    'PUMMELL': 0,
    'PUMMER': 0,
    'PUMMILL': 0,
    'PUMO': 0,
    'PUMP': 0,
    'PUMPELLY': 0,
    'PUMPER': 0,
    'PUMPHREY': 0,
    'PUMROY': 0,
    'PUN': 0,
    'PUNCH': 0,
    'PUNCHARD': 0,
    'PUNCHES': 0,
    'PUNCOCHAR': 0,
    'PUND': 0,
    'PUNDSACK': 0,
    'PUNDT': 0,
    'PUNG': 0,
    'PUNJABI': 0,
    'PUNJANI': 0,
    'PUNKE': 0,
    'PUNKO': 0,
    'PUNLA': 0,
    'PUNN': 0,
    'PUNNETT': 0,
    'PUNNOOSE': 0,
    'PUNO': 0,
    'PUNSALAN': 0,
    'PUNT': 0,
    'PUNTE': 0,
    'PUNTEL': 0,
    'PUNTENNEY': 0,
    'PUNTER': 0,
    'PUNTIEL': 0,
    'PUNTILLO': 0,
    'PUNTNEY': 0,
    'PUNZAL': 0,
    'PUNZALAN': 0,
    'PUNZEL': 0,
    'PUNZI': 0,
    'PUNZO': 0,
    'PUOPOLO': 0,
    'PUORRO': 0,
    'PUPA': 0,
    'PUPEK': 0,
    'PUPELLO': 0,
    'PUPILLO': 0,
    'PUPO': 0,
    'PUPP': 0,
    'PUPPE': 0,
    'PUPPO': 0,
    'PURA': 0.9090909090909091,
    'PURAN': 0,
    'PURANIK': 0,
    'PURBAUGH': 0,
    'PURCARO': 0,
    'PURCE': 0,
    'PURCEL': 0,
    'PURCELL': 0,
    'PURCELLA': 0,
    'PURCHASE': 0,
    'PURDEY': 0,
    'PURDHAM': 0,
    'PURDIE': 0,
    'PURDIMAN': 0,
    'PURDIN': 0,
    'PURDOM': 0,
    'PURDON': 0,
    'PURDUE': 0,
    'PURDUM': 0,
    'PURDY': 0,
    'PURE': 0,
    'PURECO': 0,
    'PUREFOY': 0,
    'PUREWAL': 0,
    'PURFEERST': 0,
    'PURFIELD': 0,
    'PURGANAN': 0,
    'PURGASON': 0,
    'PURHAM': 0,
    'PURI': 0,
    'PURICELLI': 0,
    'PURIFICATO': 0,
    'PURIFOY': 0,
    'PURINGTON': 0,
    'PURINTON': 0,
    'PURINTUN': 0,
    'PURISIMA': 0,
    'PURITT': 0,
    'PURITZ': 0,
    'PURK': 0,
    'PURKAPILE': 0,
    'PURKERSON': 0,
    'PURKETT': 0,
    'PURKEY': 0,
    'PURKEYPILE': 0,
    'PURKHISER': 0,
    'PURKINS': 0,
    'PURKIS': 0,
    'PURKISS': 0,
    'PURKS': 0,
    'PURL': 0,
    'PURLEE': 0,
    'PURLEY': 0,
    'PURMORT': 0,
    'PURNELL': 0,
    'PURNER': 0,
    'PURO': 0,
    'PUROHIT': 0,
    'PUROL': 0,
    'PUROLL': 0,
    'PURPERA': 0,
    'PURPLE': 0,
    'PURPORA': 0,
    'PURPURA': 0,
    'PURRIER': 0,
    'PURRINGTON': 0,
    'PURRY': 0,
    'PURSCELL': 0,
    'PURSCH': 0,
    'PURSCHE': 0,
    'PURSE': 0,
    'PURSEL': 0,
    'PURSELL': 0,
    'PURSELLEY': 0,
    'PURSER': 0,
    'PURSEY': 0,
    'PURSIFULL': 0,
    'PURSLEY': 0,
    'PURSLOW': 0,
    'PURSWELL': 0,
    'PURTA': 0,
    'PURTEE': 0,
    'PURTELL': 0,
    'PURTER': 0,
    'PURTILL': 0,
    'PURTLE': 0,
    'PURTLEBAUGH': 0,
    'PURUCKER': 0,
    'PURUGGANAN': 0,
    'PURVES': 0,
    'PURVEY': 0,
    'PURVIANCE': 0,
    'PURVIN': 0,
    'PURVINE': 0,
    'PURVIS': 0,
    'PURWIN': 0,
    'PURYEAR': 0,
    'PURZYCKI': 0,
    'PUSATERI': 0,
    'PUSCAS': 0,
    'PUSCH': 0,
    'PUSCHEL': 0,
    'PUSEY': 0,
    'PUSH': 0,
    'PUSHARD': 0,
    'PUSHEE': 0,
    'PUSHKAR': 0,
    'PUSHKIN': 0,
    'PUSHMAN': 0,
    'PUSHOR': 0,
    'PUSICH': 0,
    'PUSKA': 0,
    'PUSKAR': 0,
    'PUSKARIC': 0,
    'PUSKARICH': 0,
    'PUSKAS': 0,
    'PUSSER': 0,
    'PUST': 0,
    'PUSTAY': 0,
    'PUSTEJOVSKY': 0,
    'PUSTELNIK': 0,
    'PUSTER': 0,
    'PUSTILNIK': 0,
    'PUSTIZZI': 0,
    'PUSTKA': 0,
    'PUSZ': 0,
    'PUTALA': 0,
    'PUTERBAUGH': 0,
    'PUTH': 0,
    'PUTHOFF': 0,
    'PUTHUFF': 0,
    'PUTIGNANO': 0,
    'PUTKA': 0,
    'PUTMAN': 0,
    'PUTMON': 0,
    'PUTNAL': 0,
    'PUTNAM': 0,
    'PUTNEY': 0,
    'PUTNICK': 0,
    'PUTORTI': 0,
    'PUTRA': 0,
    'PUTRINO': 0,
    'PUTRUS': 0,
    'PUTT': 0,
    'PUTTER': 0,
    'PUTTERMAN': 0,
    'PUTTHOFF': 0,
    'PUTTICK': 0,
    'PUTTKAMMER': 0,
    'PUTTMAN': 0,
    'PUTTS': 0,
    'PUTTY': 0,
    'PUTVIN': 0,
    'PUTZ': 0,
    'PUTZE': 0,
    'PUTZEL': 0,
    'PUTZER': 0,
    'PUTZIER': 0,
    'PUTZIG': 0,
    'PUTZKE': 0,
    'PUU': 0,
    'PUVOGEL': 0,
    'PUYEAR': 0,
    'PUYLEART': 0,
    'PUZ': 0,
    'PUZA': 0,
    'PUZAK': 0,
    'PUZEY': 0,
    'PUZINO': 0,
    'PUZIO': 0,
    'PUZO': 0,
    'PUZON': 0,
    'PUZYCKI': 0,
    'PUZZO': 0,
    'PUZZUOLI': 0,
    'PY': 0,
    'PYANT': 0,
    'PYATT': 0,
    'PYATTE': 0,
    'PYBAS': 0,
    'PYBURN': 0,
    'PYBUS': 0,
    'PYC': 0,
    'PYCH': 0,
    'PYCIOR': 0,
    'PYE': 0,
    'PYEATT': 0,
    'PYER': 0,
    'PYERS': 0,
    'PYETT': 0,
    'PYFER': 0,
    'PYFROM': 0,
    'PYGOTT': 0,
    'PYKA': 0,
    'PYKE': 0,
    'PYLAND': 0,
    'PYLANT': 0,
    'PYLATE': 0,
    'PYLE': 0,
    'PYLES': 0,
    'PYLMAN': 0,
    'PYMM': 0,
    'PYNE': 0,
    'PYNES': 0,
    'PYNN': 0,
    'PYO': 0,
    'PYON': 0,
    'PYOTT': 0,
    'PYPER': 0,
    'PYRA': 0,
    'PYREK': 0,
    'PYRITZ': 0,
    'PYRON': 0,
    'PYRTLE': 0,
    'PYRYT': 0,
    'PYSH': 0,
    'PYSHER': 0,
    'PYSZ': 0,
    'PYSZKA': 0,
    'PYTEL': 0,
    'PYTKA': 0,
    'PYTKO': 0,
    'PYTLAK': 0,
    'PYTLARZ': 0,
    'PYTLESKI': 0,
    'PYTLIK': 0,
    'PYUN': 0,
    'PYZIK': 0,
    'QADEER': 0,
    'QADER': 0,
    'QADIR': 0,
    'QADRI': 0,
    'QAMAR': 0,
    'QAQISH': 0,
    'QASEM': 0,
    'QASIM': 0,
    'QAYYUM': 0,
    'QAZI': 0,
    'QI': 0,
    'QIAN': 0,
    'QIANA': 1,
    'QIANG': 0,
    'QIAO': 0,
    'QIN': 0,
    'QING': 0,
    'QIU': 0,
    'QU': 0,
    'QUA': 0,
    'QUAAL': 0,
    'QUAAS': 0,
    'QUACH': 0,
    'QUACKENBOSS': 0,
    'QUACKENBUSH': 0,
    'QUADA': 0,
    'QUADE': 0,
    'QUADER': 0,
    'QUADERER': 0,
    'QUADIR': 0,
    'QUADRI': 0,
    'QUADRINI': 0,
    'QUADRINO': 0,
    'QUADROS': 0,
    'QUADROZZI': 0,
    'QUAGLIA': 0,
    'QUAGLIANA': 0,
    'QUAGLIANO': 0,
    'QUAGLIARIELLO': 0,
    'QUAGLIAROLI': 0,
    'QUAGLIATA': 0,
    'QUAGLIATO': 0,
    'QUAGLIERI': 0,
    'QUAGLIETTA': 0,
    'QUAGLINO': 0,
    'QUAGLIO': 0,
    'QUAID': 0,
    'QUAIFE': 0,
    'QUAIL': 0,
    'QUAILE': 0,
    'QUAIN': 0,
    'QUAINE': 0,
    'QUAINTANCE': 0,
    'QUAINTON': 0,
    'QUAKENBUSH': 0,
    'QUAL': 0,
    'QUALE': 0,
    'QUALES': 0,
    'QUALEY': 0,
    'QUALIS': 0,
    'QUALKENBUSH': 0,
    'QUALKINBUSH': 0,
    'QUALL': 0,
    'QUALLE': 0,
    'QUALLEY': 0,
    'QUALLS': 0,
    'QUALMAN': 0,
    'QUALMANN': 0,
    'QUALTER': 0,
    'QUALTERS': 0,
    'QUAM': 0,
    'QUAMINA': 0,
    'QUAMME': 0,
    'QUAMMEN': 0,
    'QUAN': 0,
    'QUANBECK': 0,
    'QUANCE': 0,
    'QUANDAHL': 0,
    'QUANDER': 0,
    'QUANDT': 0,
    'QUANE': 0,
    'QUANEY': 0,
    'QUANG': 0,
    'QUANN': 0,
    'QUANRUD': 0,
    'QUANSAH': 0,
    'QUANSTROM': 0,
    'QUANT': 0,
    'QUANTE': 0,
    'QUANTRELL': 0,
    'QUANTRILLE': 0,
    'QUANTZ': 0,
    'QUARANTA': 0,
    'QUARANTILLO': 0,
    'QUARANTO': 0,
    'QUARBERG': 0,
    'QUARESMA': 0,
    'QUARLES': 0,
    'QUARLESS': 0,
    'QUARNBERG': 0,
    'QUARNSTROM': 0,
    'QUARRELS': 0,
    'QUARRIE': 0,
    'QUARRY': 0,
    'QUARSHIE': 0,
    'QUARTANA': 0,
    'QUARTARARO': 0,
    'QUARTARO': 0,
    'QUARTARONE': 0,
    'QUARTERMAN': 0,
    'QUARTERS': 0,
    'QUARTEY': 0,
    'QUARTO': 0,
    'QUARTON': 0,
    'QUARTUCCI': 0,
    'QUARTUCCIO': 0,
    'QUARTZ': 0,
    'QUARY': 0,
    'QUAS': 0,
    'QUASCHNICK': 0,
    'QUASEBARTH': 0,
    'QUASH': 0,
    'QUASHIE': 0,
    'QUASIUS': 0,
    'QUASNEY': 0,
    'QUASS': 0,
    'QUAST': 0,
    'QUATE': 0,
    'QUATES': 0,
    'QUATMAN': 0,
    'QUATRALE': 0,
    'QUATRANO': 0,
    'QUATRINI': 0,
    'QUATRO': 0,
    'QUATRONE': 0,
    'QUATTLEBAUM': 0,
    'QUATTRIN': 0,
    'QUATTRINI': 0,
    'QUATTRO': 0,
    'QUATTROCCHI': 0,
    'QUATTROCHI': 0,
    'QUATTROCIOCCHI': 0,
    'QUATTRONE': 0,
    'QUATTRUCCI': 0,
    'QUAVE': 0,
    'QUAY': 0,
    'QUAYE': 0,
    'QUAYLE': 0,
    'QUAZI': 0,
    'QUDDUS': 0,
    'QUE': 0,
    'QUEALLY': 0,
    'QUEALY': 0,
    'QUEAR': 0,
    'QUEARY': 0,
    'QUEBBEMAN': 0,
    'QUEBE': 0,
    'QUEBEC': 0,
    'QUEBEDEAUX': 0,
    'QUEBEDO': 0,
    'QUEBODEAUX': 0,
    'QUEBRADO': 0,
    'QUEBRAL': 0,
    'QUECK': 0,
    'QUEDNAU': 0,
    'QUEEN': 0.5758157389635316,
    'QUEENAN': 0,
    'QUEENER': 0,
    'QUEENEY': 0,
    'QUEENIE': 1,
    'QUEER': 0,
    'QUEHL': 0,
    'QUEIPO': 0,
    'QUEIROLO': 0,
    'QUEIROZ': 0,
    'QUEJA': 0,
    'QUEK': 0,
    'QUEL': 0,
    'QUELCH': 0,
    'QUELL': 0,
    'QUELLA': 0,
    'QUELLE': 0,
    'QUELLETTE': 0,
    'QUELLHORST': 0,
    'QUELLO': 0,
    'QUEMADA': 0,
    'QUEMADO': 0,
    'QUEMUEL': 0,
    'QUEN': 0,
    'QUENGA': 0,
    'QUENNEVILLE': 0,
    'QUENTAL': 0,
    'QUENTIN': 0.9940357852882704,
    'QUENZER': 0,
    'QUERCIA': 0,
    'QUERIDO': 0,
    'QUERIN': 0,
    'QUERIO': 0,
    'QUERNEMOEN': 0,
    'QUERO': 0,
    'QUEROL': 0,
    'QUERRY': 0,
    'QUERTERMOUS': 0,
    'QUERUBIN': 0,
    'QUERY': 0,
    'QUESADA': 0,
    'QUESENBERRY': 0,
    'QUESINBERRY': 0,
    'QUESNEL': 0,
    'QUESNELL': 0,
    'QUESSENBERRY': 0,
    'QUEST': 0,
    'QUESTAD': 0,
    'QUESTEL': 0,
    'QUESTELL': 0,
    'QUEVEDO': 0,
    'QUEVILLON': 0,
    'QUEZADA': 0,
    'QUEZON': 0,
    'QUI': 0,
    'QUIAMBAO': 0,
    'QUIAN': 0,
    'QUIANA': 1,
    'QUIBELL': 0,
    'QUIBODEAUX': 0,
    'QUIBUYEN': 0,
    'QUICENO': 0,
    'QUICHO': 0,
    'QUICHOCHO': 0,
    'QUICK': 0,
    'QUICKE': 0,
    'QUICKEL': 0,
    'QUICKLE': 0,
    'QUICKLEY': 0,
    'QUICKSALL': 0,
    'QUICKSEY': 0,
    'QUIDACHAY': 0,
    'QUIDLEY': 0,
    'QUIEL': 0,
    'QUIER': 0,
    'QUIET': 0,
    'QUIETT': 0,
    'QUIG': 0,
    'QUIGG': 0,
    'QUIGGINS': 0,
    'QUIGGLE': 0,
    'QUIGLEY': 0,
    'QUIHUIS': 0,
    'QUIHUIZ': 0,
    'QUIJADA': 0,
    'QUIJANO': 0,
    'QUIJAS': 0,
    'QUIJIJE': 0,
    'QUILALA': 0,
    'QUILANTAN': 0,
    'QUILANTANG': 0,
    'QUILES': 0,
    'QUILEZ': 0,
    'QUILICI': 0,
    'QUILIMACO': 0,
    'QUILL': 0,
    'QUILLAN': 0,
    'QUILLEN': 0,
    'QUILLER': 0,
    'QUILLIAM': 0,
    'QUILLIAN': 0,
    'QUILLIN': 0,
    'QUILLINAN': 0,
    'QUILLING': 0,
    'QUILLMAN': 0,
    'QUILON': 0,
    'QUILTER': 0,
    'QUILTY': 0,
    'QUIMBY': 0,
    'QUIMPO': 0,
    'QUIMSON': 0,
    'QUIN': 0,
    'QUINA': 0,
    'QUINALTY': 0,
    'QUINAN': 0,
    'QUINATA': 0,
    'QUINBY': 0,
    'QUINCE': 0,
    'QUINCEY': 0,
    'QUINCHE': 0,
    'QUINCI': 0,
    'QUINCY': 0.966183574879227,
    'QUINDE': 0,
    'QUINDLEN': 0,
    'QUINDT': 0,
    'QUINE': 0,
    'QUINER': 0,
    'QUINERLY': 0,
    'QUINES': 0,
    'QUINETTE': 0,
    'QUINEY': 0,
    'QUINLAN': 0,
    'QUINLEY': 0,
    'QUINLIN': 0,
    'QUINLISK': 0,
    'QUINLIVAN': 0,
    'QUINN': 0.17841213202497772,
    'QUINNAN': 0,
    'QUINNELL': 0,
    'QUINNELLY': 0,
    'QUINNETT': 0,
    'QUINNETTE': 0,
    'QUINNEY': 0,
    'QUINNIE': 0,
    'QUINO': 0,
    'QUINONES': 0,
    'QUINONEZ': 0,
    'QUINT': 0,
    'QUINTA': 0,
    'QUINTAL': 0,
    'QUINTANA': 0,
    'QUINTANAL': 0,
    'QUINTANAR': 0,
    'QUINTANIA': 0,
    'QUINTANILLA': 0,
    'QUINTANO': 0,
    'QUINTARD': 0,
    'QUINTAS': 0,
    'QUINTAVALLE': 0,
    'QUINTEL': 0,
    'QUINTELA': 0,
    'QUINTEN': 0,
    'QUINTER': 0,
    'QUINTERO': 0,
    'QUINTEROS': 0,
    'QUINTILIANI': 0,
    'QUINTIN': 0.9560229445506692,
    'QUINTINO': 0,
    'QUINTO': 0,
    'QUINTON': 0.916138125440451,
    'QUINTOS': 0,
    'QUINTRELL': 0,
    'QUINTUS': 0,
    'QUINTY': 0,
    'QUINTYNE': 0,
    'QUINZI': 0,
    'QUIOCHO': 0,
    'QUIONES': 0,
    'QUIRAM': 0,
    'QUIRANTE': 0,
    'QUIRARTE': 0,
    'QUIRE': 0,
    'QUIRICO': 0,
    'QUIRIN': 0,
    'QUIRINDONGO': 0,
    'QUIRING': 0,
    'QUIRINO': 0,
    'QUIRION': 0,
    'QUIRK': 0,
    'QUIRKE': 0,
    'QUIROA': 0,
    'QUIROGA': 0,
    'QUIROS': 0,
    'QUIROZ': 0,
    'QUISENBERRY': 0,
    'QUISH': 0,
    'QUISPE': 0,
    'QUIST': 0,
    'QUISTIAN': 0,
    'QUISTORFF': 0,
    'QUITERIO': 0,
    'QUITEVIS': 0,
    'QUITIQUIT': 0,
    'QUITMEYER': 0,
    'QUITO': 0,
    'QUITORIANO': 0,
    'QUITT': 0,
    'QUITTER': 0,
    'QUITTSCHREIBER': 0,
    'QUITUGUA': 0,
    'QUIVER': 0,
    'QUIVERS': 0,
    'QUIVEY': 0,
    'QUIZ': 0,
    'QUIZHPE': 0,
    'QUIZHPI': 0,
    'QUIZON': 0,
    'QUNELL': 0,
    'QUOCK': 0,
    'QUON': 0,
    'QUONG': 0,
    'QURAISHI': 0,
    'QURASHI': 0,
    'QURESHI': 0,
    'QUTOB': 0,
    'QUY': 0,
    'QUYEN': 1,
    'RA': 0,
    'RAAB': 0,
    'RAABE': 0,
    'RAAD': 0,
    'RAAEN': 0,
    'RAAF': 0,
    'RAAK': 0,
    'RAAP': 0,
    'RAASCH': 0,
    'RAATZ': 0,
    'RAAUM': 0,
    'RAB': 0,
    'RABA': 0,
    'RABADAN': 0,
    'RABADI': 0,
    'RABAGO': 0,
    'RABAH': 0,
    'RABALAIS': 0,
    'RABAN': 0,
    'RABANAL': 0,
    'RABANALES': 0,
    'RABANG': 0,
    'RABARA': 0,
    'RABAS': 0,
    'RABASCA': 0,
    'RABASCO': 0,
    'RABASSA': 0,
    'RABATIN': 0,
    'RABAUT': 0,
    'RABB': 0,
    'RABBAN': 0,
    'RABBANI': 0,
    'RABBAT': 0,
    'RABBE': 0,
    'RABBERS': 0,
    'RABBIT': 0,
    'RABBITT': 0,
    'RABE': 0,
    'RABEHL': 0,
    'RABEL': 0,
    'RABELL': 0,
    'RABELLO': 0,
    'RABELO': 0,
    'RABEN': 0,
    'RABENA': 0,
    'RABENAU': 0,
    'RABENBERG': 0,
    'RABENHORST': 0,
    'RABENOLD': 0,
    'RABENS': 0,
    'RABENSTEIN': 0,
    'RABER': 0,
    'RABERN': 0,
    'RABEY': 0,
    'RABI': 0,
    'RABIDEAU': 0,
    'RABIDEAUX': 0,
    'RABIDOU': 0,
    'RABIDOUX': 0,
    'RABIDUE': 0,
    'RABIE': 0,
    'RABIL': 0,
    'RABIN': 0,
    'RABINE': 0,
    'RABINER': 0,
    'RABINO': 0,
    'RABINOVICH': 0,
    'RABINOVITCH': 0,
    'RABINOVITZ': 0,
    'RABINOWITZ': 0,
    'RABINS': 0,
    'RABITO': 0,
    'RABITOY': 0,
    'RABIZADEH': 0,
    'RABJOHN': 0,
    'RABKIN': 0,
    'RABLE': 0,
    'RABOIN': 0,
    'RABOLD': 0,
    'RABON': 0,
    'RABORG': 0,
    'RABORN': 0,
    'RABOT': 0,
    'RABOURN': 0,
    'RABOY': 0,
    'RABREN': 0,
    'RABSATT': 0,
    'RABUCK': 0,
    'RABUN': 0,
    'RABURN': 0,
    'RABUS': 0,
    'RABUSE': 0,
    'RABY': 0,
    'RAC': 0,
    'RACADIO': 0,
    'RACANELLI': 0,
    'RACANIELLO': 0,
    'RACANO': 0,
    'RACCA': 0,
    'RACCIO': 0,
    'RACCO': 0,
    'RACCUGLIA': 0,
    'RACCUIA': 0,
    'RACE': 0,
    'RACEK': 0,
    'RACELA': 0,
    'RACELIS': 0,
    'RACER': 0,
    'RACETTE': 0,
    'RACEY': 0,
    'RACH': 0,
    'RACHAEL': 0.9989484752891693,
    'RACHAL': 0.46511627906976744,
    'RACHALL': 0,
    'RACHAU': 0,
    'RACHEAL': 1,
    'RACHEL': 0.9964178367027628,
    'RACHELE': 1,
    'RACHELL': 0.9615384615384616,
    'RACHELLE': 1,
    'RACHELS': 0,
    'RACHELSON': 0,
    'RACHER': 0,
    'RACHFORD': 0,
    'RACHID': 0,
    'RACHIELE': 0,
    'RACHKO': 0,
    'RACHLIN': 0,
    'RACHMAN': 0,
    'RACHO': 0,
    'RACHOR': 0,
    'RACHOW': 0,
    'RACHT': 0,
    'RACHUBA': 0,
    'RACHUY': 0,
    'RACHWAL': 0,
    'RACIC': 0,
    'RACICH': 0,
    'RACICOT': 0,
    'RACINE': 0,
    'RACINES': 0,
    'RACINOWSKI': 0,
    'RACIOPPI': 0,
    'RACIOPPO': 0,
    'RACITI': 0,
    'RACK': 0,
    'RACKARD': 0,
    'RACKAUSKAS': 0,
    'RACKE': 0,
    'RACKER': 0,
    'RACKERS': 0,
    'RACKETT': 0,
    'RACKEY': 0,
    'RACKHAM': 0,
    'RACKI': 0,
    'RACKLEFF': 0,
    'RACKLER': 0,
    'RACKLEY': 0,
    'RACKLIFF': 0,
    'RACKLIFFE': 0,
    'RACKOW': 0,
    'RACKOWSKI': 0,
    'RACO': 0,
    'RACOMA': 0,
    'RACQUEL': 1,
    'RACY': 0,
    'RACZ': 0,
    'RACZAK': 0,
    'RACZEK': 0,
    'RACZKA': 0,
    'RACZKOWSKI': 0,
    'RACZYNSKI': 0,
    'RAD': 0,
    'RADA': 0,
    'RADABAUGH': 0,
    'RADACH': 0,
    'RADACK': 0,
    'RADAK': 0,
    'RADAKE': 0,
    'RADAKER': 0,
    'RADAKOVIC': 0,
    'RADAKOVICH': 0,
    'RADAN': 0,
    'RADANDT': 0,
    'RADANO': 0,
    'RADANOVICH': 0,
    'RADANT': 0,
    'RADAR': 0,
    'RADATZ': 0,
    'RADAY': 0,
    'RADBILL': 0,
    'RADCLIFF': 0,
    'RADCLIFFE': 0,
    'RADD': 0,
    'RADDANT': 0,
    'RADDATZ': 0,
    'RADDE': 0,
    'RADDEN': 0,
    'RADDER': 0,
    'RADDING': 0,
    'RADDON': 0,
    'RADE': 0,
    'RADEBAUGH': 0,
    'RADECK': 0,
    'RADECKE': 0,
    'RADECKI': 0,
    'RADEK': 0,
    'RADEKE': 0,
    'RADEL': 0,
    'RADELL': 0,
    'RADEMACHER': 0,
    'RADEMAKER': 0,
    'RADEMAN': 0,
    'RADEN': 0,
    'RADENBAUGH': 0,
    'RADER': 0,
    'RADERMACHER': 0,
    'RADERSTORF': 0,
    'RADES': 0,
    'RADETSKY': 0,
    'RADEY': 0,
    'RADFAR': 0,
    'RADFORD': 0,
    'RADGOWSKI': 0,
    'RADHAKRISHNAN': 0,
    'RADI': 0,
    'RADIA': 0,
    'RADIC': 0,
    'RADICAN': 0,
    'RADICE': 0,
    'RADICH': 0,
    'RADICHEL': 0,
    'RADICIONI': 0,
    'RADICK': 0,
    'RADICKE': 0,
    'RADICS': 0,
    'RADIE': 0,
    'RADIG': 0,
    'RADIGAN': 0,
    'RADIKE': 0,
    'RADIL': 0,
    'RADILLA': 0,
    'RADILLO': 0,
    'RADIN': 0,
    'RADINSKY': 0,
    'RADIO': 0,
    'RADIS': 0,
    'RADISH': 0,
    'RADIX': 0,
    'RADJENOVICH': 0,
    'RADKA': 0,
    'RADKE': 0,
    'RADKIEWICZ': 0,
    'RADKO': 0,
    'RADKOWSKI': 0,
    'RADL': 0,
    'RADLE': 0,
    'RADLEIN': 0,
    'RADLER': 0,
    'RADLEY': 0,
    'RADLIFF': 0,
    'RADLINGER': 0,
    'RADLINSKI': 0,
    'RADLOFF': 0,
    'RADMACHER': 0,
    'RADMALL': 0,
    'RADMAN': 0,
    'RADMER': 0,
    'RADNER': 0,
    'RADNEY': 0,
    'RADO': 0,
    'RADOC': 0,
    'RADOCHA': 0,
    'RADOFF': 0,
    'RADOGNA': 0,
    'RADOM': 0,
    'RADOMSKI': 0,
    'RADOMSKY': 0,
    'RADON': 0,
    'RADONCIC': 0,
    'RADONICH': 0,
    'RADONSKI': 0,
    'RADOS': 0,
    'RADOSAVLJEVIC': 0,
    'RADOSEVIC': 0,
    'RADOSEVICH': 0,
    'RADOSH': 0,
    'RADOSTA': 0,
    'RADOSTI': 0,
    'RADOVAN': 0,
    'RADOVANOVIC': 0,
    'RADOVIC': 0,
    'RADOVICH': 0,
    'RADOWSKI': 0,
    'RADSPINNER': 0,
    'RADTKA': 0,
    'RADTKE': 0,
    'RADU': 0,
    'RADUE': 0,
    'RADUECHEL': 0,
    'RADUENZ': 0,
    'RADULESCU': 0,
    'RADULOVIC': 0,
    'RADULOVICH': 0,
    'RADULSKI': 0,
    'RADUNZ': 0,
    'RADVANSKY': 0,
    'RADWAN': 0,
    'RADWANSKI': 0,
    'RADWAY': 0,
    'RADY': 0,
    'RADZAK': 0,
    'RADZICKI': 0,
    'RADZIEWICZ': 0,
    'RADZIK': 0,
    'RADZIKOWSKI': 0,
    'RADZINSKI': 0,
    'RADZISZEWSKI': 0,
    'RADZIWON': 0,
    'RAE': 0.8866371120962635,
    'RAEANN': 1,
    'RAEBEL': 0,
    'RAEBER': 0,
    'RAEBURN': 0,
    'RAEDEKE': 0,
    'RAEDEL': 0,
    'RAEDER': 0,
    'RAEF': 0,
    'RAEFORD': 0,
    'RAEKE': 0,
    'RAEKER': 0,
    'RAEL': 0,
    'RAELENE': 1,
    'RAES': 0,
    'RAESE': 0,
    'RAESIDE': 0,
    'RAESS': 0,
    'RAETHER': 0,
    'RAETZ': 0,
    'RAEZ': 0,
    'RAEZER': 0,
    'RAFA': 0,
    'RAFACZ': 0,
    'RAFAEL': 0.9888902453912832,
    'RAFAELA': 1,
    'RAFAIL': 0,
    'RAFAILOV': 0,
    'RAFAL': 0,
    'RAFALA': 0,
    'RAFALKO': 0,
    'RAFALOWSKI': 0,
    'RAFALSKI': 0,
    'RAFANAN': 0,
    'RAFANELLI': 0,
    'RAFANELLO': 0,
    'RAFANIELLO': 0,
    'RAFAT': 0,
    'RAFATI': 0,
    'RAFEEDIE': 0,
    'RAFELD': 0,
    'RAFERT': 0,
    'RAFF': 0,
    'RAFFA': 0,
    'RAFFAELE': 0,
    'RAFFAELI': 0,
    'RAFFAELLI': 0,
    'RAFFALDT': 0,
    'RAFFANTI': 0,
    'RAFFEL': 0,
    'RAFFELSON': 0,
    'RAFFENSBERGER': 0,
    'RAFFENSPERGER': 0,
    'RAFFERTY': 0,
    'RAFFETTO': 0,
    'RAFFETY': 0,
    'RAFFI': 0,
    'RAFFIELD': 0,
    'RAFFIN': 0,
    'RAFFLE': 0,
    'RAFFLER': 0,
    'RAFFO': 0,
    'RAFFONE': 0,
    'RAFFORD': 0,
    'RAFFOUL': 0,
    'RAFFRAY': 0,
    'RAFI': 0,
    'RAFIDI': 0,
    'RAFIE': 0,
    'RAFII': 0,
    'RAFIQ': 0,
    'RAFIQUE': 0,
    'RAFKIN': 0,
    'RAFOLS': 0,
    'RAFT': 0,
    'RAFTER': 0,
    'RAFTERY': 0,
    'RAFTIS': 0,
    'RAFTOPOULOS': 0,
    'RAFUS': 0,
    'RAFUSE': 0,
    'RAG': 0,
    'RAGA': 0,
    'RAGAB': 0,
    'RAGADIO': 0,
    'RAGAGLIA': 0,
    'RAGAIN': 0,
    'RAGAINS': 0,
    'RAGAN': 0,
    'RAGANO': 0,
    'RAGANS': 0,
    'RAGAR': 0,
    'RAGAS': 0,
    'RAGASA': 0,
    'RAGATZ': 0,
    'RAGAZZO': 0,
    'RAGBIR': 0,
    'RAGE': 0,
    'RAGEL': 0,
    'RAGELS': 0,
    'RAGEN': 0,
    'RAGER': 0,
    'RAGETH': 0,
    'RAGG': 0,
    'RAGGETT': 0,
    'RAGGHIANTI': 0,
    'RAGGI': 0,
    'RAGGIO': 0,
    'RAGGS': 0,
    'RAGHAVAN': 0,
    'RAGHEB': 0,
    'RAGHU': 0,
    'RAGHUBIR': 0,
    'RAGHUNANDAN': 0,
    'RAGHUNATH': 0,
    'RAGHUNATHAN': 0,
    'RAGIN': 0,
    'RAGINS': 0,
    'RAGLAND': 0,
    'RAGLE': 0,
    'RAGLIN': 0,
    'RAGNAUTH': 0,
    'RAGNI': 0,
    'RAGNO': 0,
    'RAGNONE': 0,
    'RAGO': 0,
    'RAGON': 0,
    'RAGONA': 0,
    'RAGONE': 0,
    'RAGONESE': 0,
    'RAGONESI': 0,
    'RAGOO': 0,
    'RAGOONANAN': 0,
    'RAGOSTA': 0,
    'RAGOZZINO': 0,
    'RAGSDALE': 0,
    'RAGSDELL': 0,
    'RAGSTON': 0,
    'RAGUCCI': 0,
    'RAGUDO': 0,
    'RAGUE': 0,
    'RAGUEL': 1,
    'RAGUINDIN': 0,
    'RAGUS': 0,
    'RAGUSA': 0,
    'RAGUSE': 0,
    'RAGUSEO': 0,
    'RAGUSIN': 0,
    'RAGUSO': 0,
    'RAH': 0,
    'RAHA': 0,
    'RAHAIM': 0,
    'RAHAL': 0,
    'RAHALL': 0,
    'RAHAM': 0,
    'RAHAMAN': 0,
    'RAHBAR': 0,
    'RAHE': 0,
    'RAHEB': 0,
    'RAHEEM': 0,
    'RAHEJA': 0,
    'RAHER': 0,
    'RAHHAL': 0,
    'RAHI': 0,
    'RAHIER': 0,
    'RAHILL': 0,
    'RAHILLY': 0,
    'RAHIM': 0,
    'RAHIMI': 0,
    'RAHIMIAN': 0,
    'RAHIMZADEH': 0,
    'RAHL': 0,
    'RAHLF': 0,
    'RAHLFS': 0,
    'RAHM': 0,
    'RAHMAAN': 0,
    'RAHMAN': 0,
    'RAHMANI': 0,
    'RAHMATI': 0,
    'RAHME': 0,
    'RAHMER': 0,
    'RAHMING': 0,
    'RAHMINGS': 0,
    'RAHMLOW': 0,
    'RAHN': 0,
    'RAHNAMA': 0,
    'RAHNE': 0,
    'RAHNER': 0,
    'RAHO': 0,
    'RAHR': 0,
    'RAHRIG': 0,
    'RAHUBA': 0,
    'RAI': 0,
    'RAIA': 0,
    'RAIANO': 0,
    'RAIBLE': 0,
    'RAIBLEY': 0,
    'RAIBON': 0,
    'RAICA': 0,
    'RAICES': 0,
    'RAICH': 0,
    'RAICHART': 0,
    'RAICHE': 0,
    'RAICHEL': 0,
    'RAICHLE': 0,
    'RAID': 0,
    'RAIDA': 0,
    'RAIDEN': 0,
    'RAIDER': 0,
    'RAIDT': 0,
    'RAIF': 0,
    'RAIFF': 0,
    'RAIFORD': 0,
    'RAIFSNIDER': 0,
    'RAIGOSA': 0,
    'RAIGOZA': 0,
    'RAIHL': 0,
    'RAIKE': 0,
    'RAIKES': 0,
    'RAIL': 0,
    'RAILA': 0,
    'RAILE': 0,
    'RAILEY': 0,
    'RAILING': 0,
    'RAILSBACK': 0,
    'RAILTON': 0,
    'RAIMAN': 0,
    'RAIMANN': 0,
    'RAIMER': 0,
    'RAIMEY': 0,
    'RAIMO': 0,
    'RAIMOND': 0,
    'RAIMONDI': 0,
    'RAIMONDO': 0,
    'RAIMUNDO': 0,
    'RAIN': 0,
    'RAINA': 0.9345794392523364,
    'RAINALDI': 0,
    'RAINBOLT': 0,
    'RAINBOW': 0,
    'RAINE': 0,
    'RAINEAR': 0,
    'RAINER': 0,
    'RAINERI': 0,
    'RAINERO': 0,
    'RAINES': 0,
    'RAINEY': 0,
    'RAINFORD': 0,
    'RAINFORTH': 0,
    'RAINGE': 0,
    'RAINHA': 0,
    'RAINIER': 0,
    'RAINIERI': 0,
    'RAINIS': 0,
    'RAINO': 0,
    'RAINONE': 0,
    'RAINOSEK': 0,
    'RAINS': 0,
    'RAINSBERGER': 0,
    'RAINSFORD': 0,
    'RAINVILLE': 0,
    'RAINWATER': 0,
    'RAINWATERS': 0,
    'RAINY': 0,
    'RAIO': 0,
    'RAIOLA': 0,
    'RAIRDEN': 0,
    'RAIRDON': 0,
    'RAIRIGH': 0,
    'RAIS': 0,
    'RAISA': 1,
    'RAISANEN': 0,
    'RAISBECK': 0,
    'RAISCH': 0,
    'RAISER': 0,
    'RAISH': 0,
    'RAISLER': 0,
    'RAISLEY': 0,
    'RAISNER': 0,
    'RAISON': 0,
    'RAISOR': 0,
    'RAISTRICK': 0,
    'RAIT': 0,
    'RAITANO': 0,
    'RAITEN': 0,
    'RAITER': 0,
    'RAITH': 0,
    'RAITHEL': 0,
    'RAITI': 0,
    'RAITT': 0,
    'RAITZ': 0,
    'RAIZ': 0,
    'RAJ': 0,
    'RAJA': 0,
    'RAJAB': 0,
    'RAJABI': 0,
    'RAJAGOPAL': 0,
    'RAJAGOPALAN': 0,
    'RAJAH': 0,
    'RAJALA': 0,
    'RAJAMANI': 0,
    'RAJAN': 0,
    'RAJANI': 0,
    'RAJANIEMI': 0,
    'RAJAPAKSE': 0,
    'RAJARAM': 0,
    'RAJARATNAM': 0,
    'RAJASEKARAN': 0,
    'RAJCA': 0,
    'RAJCHEL': 0,
    'RAJE': 0,
    'RAJEK': 0,
    'RAJENDRAN': 0,
    'RAJESH': 0,
    'RAJEWSKI': 0,
    'RAJI': 0,
    'RAJIC': 0,
    'RAJKOVICH': 0,
    'RAJKOWSKI': 0,
    'RAJKUMAR': 0,
    'RAJO': 0,
    'RAJOTTE': 0,
    'RAJPAL': 0,
    'RAJPUT': 0,
    'RAJSKI': 0,
    'RAJU': 0,
    'RAJWANI': 0,
    'RAK': 0,
    'RAKAS': 0,
    'RAKAUSKAS': 0,
    'RAKE': 0,
    'RAKEL': 0,
    'RAKER': 0,
    'RAKERS': 0,
    'RAKES': 0,
    'RAKESTRAW': 0,
    'RAKIC': 0,
    'RAKICH': 0,
    'RAKIN': 0,
    'RAKITA': 0,
    'RAKOCY': 0,
    'RAKOCZY': 0,
    'RAKOFF': 0,
    'RAKOS': 0,
    'RAKOSKI': 0,
    'RAKOSKY': 0,
    'RAKOTZ': 0,
    'RAKOVIC': 0,
    'RAKOW': 0,
    'RAKOWICZ': 0,
    'RAKOWIECKI': 0,
    'RAKOWITZ': 0,
    'RAKOWSKI': 0,
    'RAKOWSKY': 0,
    'RAKUS': 0,
    'RALAT': 0,
    'RALBOVSKY': 0,
    'RALDA': 0,
    'RALEIGH': 0.778816199376947,
    'RALEY': 0,
    'RALFS': 0,
    'RALICH': 0,
    'RALICKI': 0,
    'RALL': 0,
    'RALLI': 0,
    'RALLINGS': 0,
    'RALLIS': 0,
    'RALLISON': 0,
    'RALLO': 0,
    'RALLS': 0,
    'RALLY': 0,
    'RALPH': 0.9896125772038181,
    'RALPHS': 0,
    'RALSON': 0,
    'RALSTIN': 0,
    'RALSTON': 0,
    'RALYA': 0,
    'RALYEA': 0,
    'RAM': 0,
    'RAMA': 0,
    'RAMACCIOTTI': 0,
    'RAMACHANDRA': 0,
    'RAMACHANDRAN': 0,
    'RAMACHER': 0,
    'RAMADAN': 0,
    'RAMADANI': 0,
    'RAMAEKERS': 0,
    'RAMAGE': 0,
    'RAMAGLIA': 0,
    'RAMAGOS': 0,
    'RAMAHI': 0,
    'RAMAKER': 0,
    'RAMAKRISHNA': 0,
    'RAMAKRISHNAN': 0,
    'RAMALES': 0,
    'RAMALEY': 0,
    'RAMALHO': 0,
    'RAMALINGAM': 0,
    'RAMAMOORTHY': 0,
    'RAMAMURTHY': 0,
    'RAMAN': 0,
    'RAMANAN': 0,
    'RAMANATHAN': 0,
    'RAMANAUSKAS': 0,
    'RAMANI': 0,
    'RAMANO': 0,
    'RAMANUJAM': 0,
    'RAMAR': 0,
    'RAMAREZ': 0,
    'RAMARIZ': 0,
    'RAMAS': 0,
    'RAMASAMY': 0,
    'RAMASWAMI': 0,
    'RAMASWAMY': 0,
    'RAMAY': 0,
    'RAMBACH': 0,
    'RAMBACHER': 0,
    'RAMBADT': 0,
    'RAMBARAN': 0,
    'RAMBARRAN': 0,
    'RAMBAUD': 0,
    'RAMBEAU': 0,
    'RAMBERG': 0,
    'RAMBERGER': 0,
    'RAMBERT': 0,
    'RAMBHAROSE': 0,
    'RAMBIN': 0,
    'RAMBLE': 0,
    'RAMBLER': 0,
    'RAMBO': 0,
    'RAMBONE': 0,
    'RAMBOUSEK': 0,
    'RAMBOW': 0,
    'RAMBUR': 0,
    'RAMBUS': 0,
    'RAMBY': 0,
    'RAMCHANDANI': 0,
    'RAMCHARAN': 0,
    'RAMCHARITAR': 0,
    'RAMCHARRAN': 0,
    'RAMCZYK': 0,
    'RAMDAS': 0,
    'RAMDASS': 0,
    'RAMDAT': 0,
    'RAMDATH': 0,
    'RAMDEEN': 0,
    'RAMDEO': 0,
    'RAMDHAN': 0,
    'RAMDHANIE': 0,
    'RAMDIAL': 0,
    'RAMDIN': 0,
    'RAME': 0,
    'RAMEAU': 0,
    'RAMEE': 0,
    'RAMEL': 0,
    'RAMELB': 0,
    'RAMELLA': 0,
    'RAMELLI': 0,
    'RAMENTO': 0,
    'RAMER': 0,
    'RAMERES': 0,
    'RAMERIEZ': 0,
    'RAMERO': 0,
    'RAMERT': 0,
    'RAMES': 0,
    'RAMESAR': 0,
    'RAMESH': 0,
    'RAMETTA': 0,
    'RAMEY': 0,
    'RAMEZANI': 0,
    'RAMGE': 0,
    'RAMI': 0,
    'RAMIA': 0,
    'RAMIAN': 0,
    'RAMIC': 0,
    'RAMICH': 0,
    'RAMICK': 0,
    'RAMIE': 0,
    'RAMIERZ': 0,
    'RAMIG': 0,
    'RAMIL': 0,
    'RAMILO': 0,
    'RAMIN': 0,
    'RAMIRAZ': 0,
    'RAMIRE': 0,
    'RAMIREC': 0,
    'RAMIRES': 0,
    'RAMIREZ': 0,
    'RAMIREZCRUZ': 0,
    'RAMIREZGARCIA': 0,
    'RAMIREZGONZALE': 0,
    'RAMIREZHERNAND': 0,
    'RAMIREZLOPEZ': 0,
    'RAMIREZMARTINE': 0,
    'RAMIREZPEREZ': 0,
    'RAMIREZRAMIREZ': 0,
    'RAMIREZSANCHEZ': 0,
    'RAMIREZTORRES': 0,
    'RAMIRIZ': 0,
    'RAMIRO': 0.9887640449438202,
    'RAMIS': 0,
    'RAMISCAL': 0,
    'RAMIZ': 0,
    'RAMJATTAN': 0,
    'RAMJI': 0,
    'RAMJIT': 0,
    'RAMJOHN': 0,
    'RAMKISHUN': 0,
    'RAMKISSOON': 0,
    'RAMKUMAR': 0,
    'RAML': 0,
    'RAMLAGAN': 0,
    'RAMLAKHAN': 0,
    'RAMLAL': 0,
    'RAMLALL': 0,
    'RAMLER': 0,
    'RAMLO': 0,
    'RAMLOCHAN': 0,
    'RAMLOGAN': 0,
    'RAMLOW': 0,
    'RAMM': 0,
    'RAMMACHER': 0,
    'RAMMAGE': 0,
    'RAMME': 0,
    'RAMMEL': 0,
    'RAMMELL': 0,
    'RAMMELSBERG': 0,
    'RAMMER': 0,
    'RAMMING': 0,
    'RAMMINGER': 0,
    'RAMNANAN': 0,
    'RAMNARACE': 0,
    'RAMNARAIN': 0,
    'RAMNARINE': 0,
    'RAMNATH': 0,
    'RAMNAUTH': 0,
    'RAMO': 0,
    'RAMOLD': 0,
    'RAMON': 0.9633911368015414,
    'RAMONA': 0.9993552546744036,
    'RAMONAS': 0,
    'RAMOND': 0,
    'RAMONDETTA': 0,
    'RAMONDO': 0,
    'RAMONE': 0,
    'RAMONES': 0,
    'RAMONITA': 1,
    'RAMONT': 0,
    'RAMOS': 0,
    'RAMOSGARCIA': 0,
    'RAMOSKA': 0,
    'RAMOSLOPEZ': 0,
    'RAMOTAR': 0,
    'RAMOTOWSKI': 0,
    'RAMOUTAR': 0,
    'RAMOZ': 0,
    'RAMP': 0,
    'RAMPA': 0,
    'RAMPE': 0,
    'RAMPENTHAL': 0,
    'RAMPERSAD': 0,
    'RAMPERSAUD': 0,
    'RAMPEY': 0,
    'RAMPHAL': 0,
    'RAMPINO': 0,
    'RAMPLEY': 0,
    'RAMPOLLA': 0,
    'RAMPONE': 0,
    'RAMPONI': 0,
    'RAMPRASAD': 0,
    'RAMPRASHAD': 0,
    'RAMPTON': 0,
    'RAMPULLA': 0,
    'RAMPY': 0,
    'RAMQUIST': 0,
    'RAMRATTAN': 0,
    'RAMRIEZ': 0,
    'RAMROOP': 0,
    'RAMRUP': 0,
    'RAMS': 0,
    'RAMSAHAI': 0,
    'RAMSAMMY': 0,
    'RAMSAMOOJ': 0,
    'RAMSARAN': 0,
    'RAMSAROOP': 0,
    'RAMSARRAN': 0,
    'RAMSAUER': 0,
    'RAMSAUR': 0,
    'RAMSAY': 0,
    'RAMSBOTTOM': 0,
    'RAMSBURG': 0,
    'RAMSBY': 0,
    'RAMSDALE': 0,
    'RAMSDELL': 0,
    'RAMSDEN': 0,
    'RAMSEIER': 0,
    'RAMSEL': 0,
    'RAMSELL': 0,
    'RAMSER': 0,
    'RAMSETH': 0,
    'RAMSEUR': 0,
    'RAMSEY': 0,
    'RAMSEYER': 0,
    'RAMSFIELD': 0,
    'RAMSHAW': 0,
    'RAMSHUR': 0,
    'RAMSIER': 0,
    'RAMSINGH': 0,
    'RAMSKI': 0,
    'RAMSLAND': 0,
    'RAMSON': 0,
    'RAMSOUR': 0,
    'RAMSOWER': 0,
    'RAMSTACK': 0,
    'RAMSTAD': 0,
    'RAMSTEAD': 0,
    'RAMSTETTER': 0,
    'RAMSTROM': 0,
    'RAMSUMAIR': 0,
    'RAMSUNDAR': 0,
    'RAMTAHAL': 0,
    'RAMTHUN': 0,
    'RAMUNDO': 0,
    'RAMUNNI': 0,
    'RAMUNNO': 0,
    'RAMUS': 0,
    'RAMY': 0,
    'RAMZAN': 0,
    'RAMZY': 0,
    'RAN': 0,
    'RANA': 0.5813953488372093,
    'RANADA': 0,
    'RANADE': 0,
    'RANAE': 1,
    'RANAHAN': 0,
    'RANALDI': 0,
    'RANALDO': 0,
    'RANALLI': 0,
    'RANALLO': 0,
    'RANARD': 0,
    'RANASINGHE': 0,
    'RANAUDO': 0,
    'RANCATORE': 0,
    'RANCE': 0,
    'RANCES': 0,
    'RANCH': 0,
    'RANCHER': 0,
    'RANCIER': 0,
    'RANCIFER': 0,
    'RANCILIO': 0,
    'RANCK': 0,
    'RANCOUR': 0,
    'RANCOURT': 0,
    'RAND': 0,
    'RANDA': 0.9202453987730062,
    'RANDAII': 0,
    'RANDAL': 0.984251968503937,
    'RANDALE': 0,
    'RANDALL': 0.8764130572843897,
    'RANDALLS': 0,
    'RANDANT': 0,
    'RANDAZZA': 0,
    'RANDAZZO': 0,
    'RANDECKER': 0,
    'RANDEE': 1,
    'RANDEL': 0,
    'RANDELL': 0.8782936010037641,
    'RANDELS': 0,
    'RANDERSON': 0,
    'RANDHAWA': 0,
    'RANDI': 0.9966777408637872,
    'RANDICH': 0,
    'RANDIE': 0,
    'RANDIG': 0,
    'RANDIS': 0,
    'RANDISI': 0,
    'RANDKLEV': 0,
    'RANDLE': 0,
    'RANDLEMAN': 0,
    'RANDLER': 0,
    'RANDLES': 0,
    'RANDLETT': 0,
    'RANDO': 0,
    'RANDOL': 0,
    'RANDOLF': 0,
    'RANDOLL': 0,
    'RANDOLPH': 0.6847849347314359,
    'RANDOM': 0,
    'RANDON': 0,
    'RANDONE': 0,
    'RANDOW': 0,
    'RANDRUP': 0,
    'RANDS': 0,
    'RANDT': 0,
    'RANDY': 0.9996596903181896,
    'RANE': 0,
    'RANEE': 1,
    'RANELLI': 0,
    'RANER': 0,
    'RANERI': 0,
    'RANERO': 0,
    'RANES': 0,
    'RANESES': 0,
    'RANEW': 0,
    'RANEY': 0,
    'RANFORD': 0,
    'RANFT': 0,
    'RANG': 0,
    'RANGAN': 0,
    'RANGANATHAN': 0,
    'RANGARAJAN': 0,
    'RANGASWAMY': 0,
    'RANGE': 0,
    'RANGEL': 0,
    'RANGER': 0,
    'RANGES': 0,
    'RANGITSCH': 0,
    'RANGLE': 0,
    'RANGLIN': 0,
    'RANGNOW': 0,
    'RANGO': 0,
    'RANGWALA': 0,
    'RANI': 0,
    'RANIA': 0,
    'RANIER': 0,
    'RANIERE': 0,
    'RANIERI': 0,
    'RANIOLO': 0,
    'RANIREZ': 0,
    'RANIS': 0,
    'RANISZEWSKI': 0,
    'RANJAN': 0,
    'RANJBAR': 0,
    'RANJEL': 0,
    'RANK': 0,
    'RANKE': 0,
    'RANKEL': 0,
    'RANKEN': 0,
    'RANKER': 0,
    'RANKEY': 0,
    'RANKHORN': 0,
    'RANKIN': 0,
    'RANKINE': 0,
    'RANKINS': 0,
    'RANKL': 0,
    'RANKS': 0,
    'RANLY': 0,
    'RANN': 0,
    'RANNALS': 0,
    'RANNAZZISI': 0,
    'RANNE': 0,
    'RANNEBARGER': 0,
    'RANNELLS': 0,
    'RANNELS': 0,
    'RANNEY': 0,
    'RANNIGER': 0,
    'RANNO': 0,
    'RANNOW': 0,
    'RANO': 0,
    'RANOLA': 0,
    'RANOS': 0,
    'RANOUS': 0,
    'RANS': 0,
    'RANSAW': 0,
    'RANSBERGER': 0,
    'RANSBOTTOM': 0,
    'RANSBURG': 0,
    'RANSBY': 0,
    'RANSDELL': 0,
    'RANSEY': 0,
    'RANSFER': 0,
    'RANSFORD': 0,
    'RANSHAW': 0,
    'RANSICK': 0,
    'RANSIER': 0,
    'RANSLEBEN': 0,
    'RANSLEM': 0,
    'RANSLEY': 0,
    'RANSLOW': 0,
    'RANSOM': 0,
    'RANSOME': 0,
    'RANSON': 0,
    'RANSONE': 0,
    'RANSONET': 0,
    'RANSTEAD': 0,
    'RANSTROM': 0,
    'RANT': 0,
    'RANTA': 0,
    'RANTALA': 0,
    'RANTANEN': 0,
    'RANTON': 0,
    'RANTS': 0,
    'RANTZ': 0,
    'RANUCCI': 0,
    'RANUM': 0,
    'RANVILLE': 0,
    'RANWEILER': 0,
    'RANZ': 0,
    'RANZAU': 0,
    'RANZENBERGER': 0,
    'RANZINGER': 0,
    'RAO': 0,
    'RAOOF': 0,
    'RAOUF': 0,
    'RAOUL': 0,
    'RAPA': 0,
    'RAPACH': 0,
    'RAPACKI': 0,
    'RAPACZ': 0,
    'RAPADA': 0,
    'RAPADAS': 0,
    'RAPAGLIA': 0,
    'RAPALA': 0,
    'RAPALEE': 0,
    'RAPALO': 0,
    'RAPAPORT': 0,
    'RAPCHAK': 0,
    'RAPCZYNSKI': 0,
    'RAPE': 0,
    'RAPELJE': 0,
    'RAPER': 0,
    'RAPERT': 0,
    'RAPETTI': 0,
    'RAPH': 0,
    'RAPHAEL': 0.8955223880597015,
    'RAPHAELSON': 0,
    'RAPHEL': 0,
    'RAPHIEL': 0,
    'RAPIEN': 0,
    'RAPIER': 0,
    'RAPIN': 0,
    'RAPINI': 0,
    'RAPISARDA': 0,
    'RAPISARDI': 0,
    'RAPISURA': 0,
    'RAPKIN': 0,
    'RAPKO': 0,
    'RAPLEE': 0,
    'RAPLEY': 0,
    'RAPOLLA': 0,
    'RAPONE': 0,
    'RAPONI': 0,
    'RAPOPORT': 0,
    'RAPOSA': 0,
    'RAPOSE': 0,
    'RAPOSO': 0,
    'RAPOZA': 0,
    'RAPOZO': 0,
    'RAPP': 0,
    'RAPPA': 0,
    'RAPPAPORT': 0,
    'RAPPAZZO': 0,
    'RAPPE': 0,
    'RAPPEL': 0,
    'RAPPENECKER': 0,
    'RAPPL': 0,
    'RAPPLEY': 0,
    'RAPPLEYE': 0,
    'RAPPLEYEA': 0,
    'RAPPOLD': 0,
    'RAPPOPORT': 0,
    'RAPPORT': 0,
    'RAPPOSELLI': 0,
    'RAPPS': 0,
    'RAPPUHN': 0,
    'RAPS': 0,
    'RAPSON': 0,
    'RAPSTINE': 0,
    'RAPTIS': 0,
    'RAPUANO': 0,
    'RAQUE': 0,
    'RAQUEL': 0.9951845906902087,
    'RAQUET': 0,
    'RARDEN': 0,
    'RARDIN': 0,
    'RARDON': 0,
    'RAREY': 0,
    'RARICK': 0,
    'RARIDEN': 0,
    'RARIDON': 0,
    'RARIG': 0,
    'RARRICK': 0,
    'RARY': 0,
    'RAS': 0,
    'RASA': 0,
    'RASANEN': 0,
    'RASAR': 0,
    'RASAVONG': 0,
    'RASAY': 0,
    'RASBACH': 0,
    'RASBAND': 0,
    'RASBERRY': 0,
    'RASBURY': 0,
    'RASCATI': 0,
    'RASCH': 0,
    'RASCHE': 0,
    'RASCHELLA': 0,
    'RASCHER': 0,
    'RASCHILLA': 0,
    'RASCHKA': 0,
    'RASCHKE': 0,
    'RASCO': 0,
    'RASCOE': 0,
    'RASCOL': 0,
    'RASCON': 0,
    'RASDALL': 0,
    'RASE': 0,
    'RASEL': 0,
    'RASELY': 0,
    'RASER': 0,
    'RASEY': 0,
    'RASH': 0,
    'RASHA': 0,
    'RASHAD': 0.9523809523809523,
    'RASHADA': 0,
    'RASHALL': 0,
    'RASHBAUM': 0,
    'RASHED': 0,
    'RASHEED': 0,
    'RASHEEDA': 1,
    'RASHER': 0,
    'RASHFORD': 0,
    'RASHID': 0,
    'RASHIDA': 1,
    'RASHIDI': 0,
    'RASHKIN': 0,
    'RASHLEIGH': 0,
    'RASHO': 0,
    'RASI': 0,
    'RASIC': 0,
    'RASICO': 0,
    'RASILE': 0,
    'RASIN': 0,
    'RASING': 0,
    'RASINSKI': 0,
    'RASK': 0,
    'RASKA': 0,
    'RASKE': 0,
    'RASKEY': 0,
    'RASKIN': 0,
    'RASKIND': 0,
    'RASKOB': 0,
    'RASKOPF': 0,
    'RASKY': 0,
    'RASLER': 0,
    'RASLEY': 0,
    'RASMUS': 0,
    'RASMUSEN': 0,
    'RASMUSON': 0,
    'RASMUSSEN': 0,
    'RASMUSSON': 0,
    'RASNAKE': 0,
    'RASNER': 0,
    'RASNIC': 0,
    'RASNICK': 0,
    'RASO': 0,
    'RASOOL': 0,
    'RASOR': 0,
    'RASOUL': 0,
    'RASP': 0,
    'RASPA': 0,
    'RASPANTE': 0,
    'RASPANTI': 0,
    'RASPBERRY': 0,
    'RASPER': 0,
    'RASPOTNIK': 0,
    'RASS': 0,
    'RASSAM': 0,
    'RASSBACH': 0,
    'RASSEL': 0,
    'RASSET': 0,
    'RASSETT': 0,
    'RASSI': 0,
    'RASSIER': 0,
    'RASSLER': 0,
    'RASSMAN': 0,
    'RASSMUSSEN': 0,
    'RASSO': 0,
    'RAST': 0,
    'RASTALL': 0,
    'RASTATTER': 0,
    'RASTEGAR': 0,
    'RASTELLI': 0,
    'RASTELLO': 0,
    'RASTETTER': 0,
    'RASTOGI': 0,
    'RASUL': 0,
    'RASULO': 0,
    'RASURE': 0,
    'RASZEWSKI': 0,
    'RASZKA': 0,
    'RAT': 0,
    'RATA': 0,
    'RATACZAK': 0,
    'RATAJ': 0,
    'RATAJCZAK': 0,
    'RATAJCZYK': 0,
    'RATAJSKI': 0,
    'RATAY': 0,
    'RATCHFORD': 0,
    'RATCLIFF': 0,
    'RATCLIFFE': 0,
    'RATE': 0,
    'RATEAU': 0,
    'RATEIKE': 0,
    'RATEKIN': 0,
    'RATEL': 0,
    'RATELIFF': 0,
    'RATELLE': 0,
    'RATER': 0,
    'RATERINK': 0,
    'RATERMAN': 0,
    'RATERMANN': 0,
    'RATES': 0,
    'RATH': 0,
    'RATHBONE': 0,
    'RATHBUN': 0,
    'RATHBURN': 0,
    'RATHE': 0,
    'RATHEL': 0,
    'RATHELL': 0,
    'RATHER': 0,
    'RATHERT': 0,
    'RATHFON': 0,
    'RATHGEB': 0,
    'RATHGEBER': 0,
    'RATHI': 0,
    'RATHJE': 0,
    'RATHJEN': 0,
    'RATHJENS': 0,
    'RATHKAMP': 0,
    'RATHKE': 0,
    'RATHMAN': 0,
    'RATHMANN': 0,
    'RATHMANNER': 0,
    'RATHMELL': 0,
    'RATHOD': 0,
    'RATHORE': 0,
    'RATHS': 0,
    'RATHSACK': 0,
    'RATICA': 0,
    'RATICAN': 0,
    'RATIGAN': 0,
    'RATIU': 0,
    'RATKA': 0,
    'RATKAY': 0,
    'RATKE': 0,
    'RATKIEWICZ': 0,
    'RATKOVIC': 0,
    'RATKOVICH': 0,
    'RATKOWSKI': 0,
    'RATLEDGE': 0,
    'RATLEFF': 0,
    'RATLEY': 0,
    'RATLIFF': 0,
    'RATLIFFE': 0,
    'RATNAM': 0,
    'RATNAYAKE': 0,
    'RATNER': 0,
    'RATSAVONG': 0,
    'RATSCH': 0,
    'RATTA': 0,
    'RATTAN': 0,
    'RATTANA': 0,
    'RATTANAVONG': 0,
    'RATTAY': 0,
    'RATTE': 0,
    'RATTENBURY': 0,
    'RATTER': 0,
    'RATTEREE': 0,
    'RATTERMAN': 0,
    'RATTERREE': 0,
    'RATTI': 0,
    'RATTIE': 0,
    'RATTIGAN': 0,
    'RATTIN': 0,
    'RATTLE': 0,
    'RATTLER': 0,
    'RATTLEY': 0,
    'RATTLIFF': 0,
    'RATTNER': 0,
    'RATTO': 0,
    'RATTON': 0,
    'RATTRAY': 0,
    'RATTS': 0,
    'RATTY': 0,
    'RATULOWSKI': 0,
    'RATY': 0,
    'RATYNSKI': 0,
    'RATZ': 0,
    'RATZA': 0,
    'RATZBURG': 0,
    'RATZEL': 0,
    'RATZER': 0,
    'RATZLAFF': 0,
    'RATZLOFF': 0,
    'RAU': 0,
    'RAUB': 0,
    'RAUBA': 0,
    'RAUBE': 0,
    'RAUBENSTINE': 0,
    'RAUBER': 0,
    'RAUCCI': 0,
    'RAUCH': 0,
    'RAUCHER': 0,
    'RAUCHFUSS': 0,
    'RAUCHLE': 0,
    'RAUCHUT': 0,
    'RAUCK': 0,
    'RAUCKHORST': 0,
    'RAUDA': 0,
    'RAUDABAUGH': 0,
    'RAUDALES': 0,
    'RAUDEBAUGH': 0,
    'RAUDENBUSH': 0,
    'RAUE': 0,
    'RAUEN': 0,
    'RAUENHORST': 0,
    'RAUENZAHN': 0,
    'RAUER': 0,
    'RAUERT': 0,
    'RAUF': 0,
    'RAUGH': 0,
    'RAUGHLEY': 0,
    'RAUGHT': 0,
    'RAUGHTON': 0,
    'RAUGUST': 0,
    'RAUH': 0,
    'RAUHAUSER': 0,
    'RAUHUFF': 0,
    'RAUHUT': 0,
    'RAUK': 0,
    'RAUL': 0.997726698661278,
    'RAULERSON': 0,
    'RAULLI': 0,
    'RAULS': 0,
    'RAULSTON': 0,
    'RAUM': 0,
    'RAUN': 0,
    'RAUNER': 0,
    'RAUP': 0,
    'RAUPACH': 0,
    'RAUPP': 0,
    'RAUR': 0,
    'RAUS': 0,
    'RAUSA': 0,
    'RAUSCH': 0,
    'RAUSCHENBACH': 0,
    'RAUSCHENBERG': 0,
    'RAUSCHENBERGER': 0,
    'RAUSCHER': 0,
    'RAUSCHERT': 0,
    'RAUSCHKOLB': 0,
    'RAUSCHUBER': 0,
    'RAUSE': 0,
    'RAUSEO': 0,
    'RAUSER': 0,
    'RAUSH': 0,
    'RAUSO': 0,
    'RAUSS': 0,
    'RAUT': 0,
    'RAUTENBERG': 0,
    'RAUTENSTRAUCH': 0,
    'RAUTER': 0,
    'RAUTERKUS': 0,
    'RAUTH': 0,
    'RAUTIO': 0,
    'RAUTIOLA': 0,
    'RAUTMANN': 0,
    'RAUTON': 0,
    'RAUZI': 0,
    'RAV': 0,
    'RAVA': 0,
    'RAVAGO': 0,
    'RAVAL': 0,
    'RAVAN': 0,
    'RAVANI': 0,
    'RAVAS': 0,
    'RAVE': 0,
    'RAVEL': 0,
    'RAVELD': 0,
    'RAVELING': 0,
    'RAVELL': 0,
    'RAVELLA': 0,
    'RAVELLETTE': 0,
    'RAVELLI': 0,
    'RAVELO': 0,
    'RAVEN': 0.8103727714748784,
    'RAVENCRAFT': 0,
    'RAVENEL': 0,
    'RAVENELL': 0,
    'RAVENELLE': 0,
    'RAVENHORST': 0,
    'RAVENNA': 0,
    'RAVENS': 0,
    'RAVENSCRAFT': 0,
    'RAVENSCROFT': 0,
    'RAVER': 0,
    'RAVERA': 0,
    'RAVERT': 0,
    'RAVERTY': 0,
    'RAVET': 0,
    'RAVETTO': 0,
    'RAVEY': 0,
    'RAVI': 0,
    'RAVIA': 0,
    'RAVICH': 0,
    'RAVICHANDRAN': 0,
    'RAVID': 0,
    'RAVIDA': 0,
    'RAVIKUMAR': 0,
    'RAVILLE': 0,
    'RAVIN': 0,
    'RAVINA': 0,
    'RAVINDRAN': 0,
    'RAVINE': 0,
    'RAVIS': 0,
    'RAVISHANKAR': 0,
    'RAVITCH': 0,
    'RAVITZ': 0,
    'RAVIV': 0,
    'RAVIZEE': 0,
    'RAVIZZA': 0,
    'RAVLIN': 0,
    'RAVN': 0,
    'RAVO': 0,
    'RAVOTTI': 0,
    'RAW': 0,
    'RAWA': 0,
    'RAWAL': 0,
    'RAWAT': 0,
    'RAWAY': 0,
    'RAWCLIFFE': 0,
    'RAWDING': 0,
    'RAWDON': 0,
    'RAWE': 0,
    'RAWHOUSER': 0,
    'RAWIE': 0,
    'RAWL': 0,
    'RAWLE': 0,
    'RAWLEIGH': 0,
    'RAWLES': 0,
    'RAWLEY': 0,
    'RAWLIN': 0,
    'RAWLING': 0,
    'RAWLINGS': 0,
    'RAWLINS': 0,
    'RAWLINSON': 0,
    'RAWLS': 0,
    'RAWLSTON': 0,
    'RAWN': 0,
    'RAWNSLEY': 0,
    'RAWSKI': 0,
    'RAWSON': 0,
    'RAX': 0,
    'RAXTER': 0,
    'RAY': 0.7679595606104791,
    'RAYA': 0,
    'RAYAN': 0,
    'RAYAS': 0,
    'RAYBIN': 0,
    'RAYBON': 0,
    'RAYBORN': 0,
    'RAYBOULD': 0,
    'RAYBOURN': 0,
    'RAYBOURNE': 0,
    'RAYBUCK': 0,
    'RAYBURG': 0,
    'RAYBURN': 0,
    'RAYCRAFT': 0,
    'RAYCROFT': 0,
    'RAYDER': 0,
    'RAYE': 0.7722007722007723,
    'RAYER': 0,
    'RAYFIELD': 0,
    'RAYFORD': 0.7207207207207207,
    'RAYGO': 0,
    'RAYGOR': 0,
    'RAYGOSA': 0,
    'RAYGOZA': 0,
    'RAYHILL': 0,
    'RAYL': 0,
    'RAYLE': 0,
    'RAYLENE': 1,
    'RAYLS': 0,
    'RAYMAKER': 0,
    'RAYMAN': 0,
    'RAYMENT': 0,
    'RAYMER': 0,
    'RAYMO': 0,
    'RAYMON': 0.9732360097323601,
    'RAYMOND': 0.9718771738050282,
    'RAYMONDE': 1,
    'RAYMONDI': 0,
    'RAYMONDO': 0,
    'RAYMONT': 0,
    'RAYMONVIL': 0,
    'RAYMOR': 0,
    'RAYMORE': 0,
    'RAYMOS': 0,
    'RAYMUNDO': 0.9070294784580499,
    'RAYN': 0,
    'RAYNA': 0.9708737864077669,
    'RAYNAK': 0,
    'RAYNAL': 0,
    'RAYNARD': 0,
    'RAYNAUD': 0,
    'RAYNE': 0,
    'RAYNER': 0,
    'RAYNES': 0,
    'RAYNO': 0,
    'RAYNOLDS': 0,
    'RAYNOR': 0,
    'RAYO': 0,
    'RAYOME': 0,
    'RAYON': 0,
    'RAYOS': 0,
    'RAYOUM': 0,
    'RAYPOLE': 0,
    'RAYRAY': 0,
    'RAYS': 0,
    'RAYSIDE': 0,
    'RAYSON': 0,
    'RAYSOR': 0,
    'RAYTON': 0,
    'RAYWOOD': 0,
    'RAYYAN': 0,
    'RAZ': 0,
    'RAZA': 0,
    'RAZACK': 0,
    'RAZAK': 0,
    'RAZAQ': 0,
    'RAZAVI': 0,
    'RAZDAN': 0,
    'RAZEE': 0,
    'RAZER': 0,
    'RAZEY': 0,
    'RAZI': 0,
    'RAZIANO': 0,
    'RAZICK': 0,
    'RAZIN': 0,
    'RAZLER': 0,
    'RAZMUS': 0,
    'RAZO': 0,
    'RAZON': 0,
    'RAZOOK': 0,
    'RAZOR': 0,
    'RAZVI': 0,
    'RAZZA': 0,
    'RAZZAK': 0,
    'RAZZANO': 0,
    'RAZZAQ': 0,
    'RAZZAQUE': 0,
    'RAZZI': 0,
    'RAZZO': 0,
    'RE': 0,
    'REA': 0.16447368421052633,
    'REABE': 0,
    'REABOLD': 0,
    'REACH': 0,
    'READ': 0,
    'READDY': 0,
    'READE': 0,
    'READEL': 0,
    'READER': 0,
    'READING': 0,
    'READINGER': 0,
    'READLING': 0,
    'READMAN': 0,
    'READMOND': 0,
    'READNOUR': 0,
    'READO': 0,
    'READON': 0,
    'READUS': 0,
    'READY': 0,
    'REAGAN': 0.14684287812041116,
    'REAGANS': 0,
    'REAGEN': 0,
    'REAGER': 0,
    'REAGH': 0,
    'REAGIN': 0,
    'REAGLE': 0,
    'REAGLES': 0,
    'REAGON': 0,
    'REAGOR': 0,
    'REAHARD': 0,
    'REAHM': 0,
    'REAID': 0,
    'REAK': 0,
    'REAKA': 0,
    'REAKES': 0,
    'REAL': 0,
    'REALBIRD': 0,
    'REALE': 0,
    'REALEGENO': 0,
    'REALES': 0,
    'REALI': 0,
    'REALINI': 0,
    'REALL': 0,
    'REALMUTO': 0,
    'REALS': 0,
    'REALYVASQUEZ': 0,
    'REALZOLA': 0,
    'REAM': 0,
    'REAMAN': 0,
    'REAMER': 0,
    'REAMES': 0,
    'REAMEY': 0,
    'REAMS': 0,
    'REAMSNYDER': 0,
    'REAMY': 0,
    'REAN': 0,
    'REANDEAU': 0,
    'REANDO': 0,
    'REANEY': 0,
    'REANNA': 1,
    'REANO': 0,
    'REANY': 0,
    'REAP': 0,
    'REAPE': 0,
    'REAPER': 0,
    'REAR': 0,
    'REARDEN': 0,
    'REARDON': 0,
    'REARICK': 0,
    'REARY': 0,
    'REAS': 0,
    'REASBECK': 0,
    'REASE': 0,
    'REASER': 0,
    'REASH': 0,
    'REASINGER': 0,
    'REASNER': 0,
    'REASON': 0,
    'REASONER': 0,
    'REASONOVER': 0,
    'REASONS': 0,
    'REASOR': 0,
    'REASTER': 0,
    'REATEGUI': 0,
    'REATH': 0,
    'REATHA': 1,
    'REATHER': 0,
    'REATHERFORD': 0,
    'REAU': 0,
    'REAUME': 0,
    'REAUX': 0,
    'REAVELY': 0,
    'REAVER': 0,
    'REAVES': 0,
    'REAVEY': 0,
    'REAVILL': 0,
    'REAVIS': 0,
    'REAVLEY': 0,
    'REAVY': 0,
    'REAY': 0,
    'REAZIN': 0,
    'REB': 0,
    'REBA': 0.9962640099626401,
    'REBACK': 0,
    'REBAR': 0,
    'REBARCHEK': 0,
    'REBB': 0,
    'REBBE': 0,
    'REBBECA': 1,
    'REBBECCA': 1,
    'REBBER': 0,
    'REBECA': 1,
    'REBECCA': 0.9996745245733947,
    'REBECCHI': 0,
    'REBECK': 0,
    'REBECKA': 1,
    'REBEIRO': 0,
    'REBEKAH': 1,
    'REBEL': 0,
    'REBELE': 0,
    'REBELES': 0,
    'REBELLO': 0,
    'REBELO': 0,
    'REBENSDORF': 0,
    'REBENTISCH': 0,
    'REBER': 0,
    'REBERG': 0,
    'REBERT': 0,
    'REBHAHN': 0,
    'REBHAN': 0,
    'REBHOLZ': 0,
    'REBHUN': 0,
    'REBIC': 0,
    'REBICH': 0,
    'REBIK': 0,
    'REBIMBAS': 0,
    'REBIS': 0,
    'REBISCHKE': 0,
    'REBISZ': 0,
    'REBLIN': 0,
    'REBMAN': 0,
    'REBMANN': 0,
    'REBO': 0,
    'REBOK': 0,
    'REBOL': 0,
    'REBOLD': 0,
    'REBOLLAR': 0,
    'REBOLLEDO': 0,
    'REBOLLO': 0,
    'REBOLLOSO': 0,
    'REBORI': 0,
    'REBOUL': 0,
    'REBOULET': 0,
    'REBOVICH': 0,
    'REBRO': 0,
    'REBROVICH': 0,
    'REBSTOCK': 0,
    'REBUCK': 0,
    'REBURN': 0,
    'REC': 0,
    'RECA': 0,
    'RECALDE': 0,
    'RECAR': 0,
    'RECARD': 0,
    'RECARTE': 0,
    'RECASNER': 0,
    'RECCA': 0,
    'RECCE': 0,
    'RECCHIA': 0,
    'RECCHIO': 0,
    'RECCO': 0,
    'RECE': 0,
    'RECEK': 0,
    'RECENDEZ': 0,
    'RECENDIZ': 0,
    'RECER': 0,
    'RECEVEUR': 0,
    'RECH': 0,
    'RECHEL': 0,
    'RECHENBERG': 0,
    'RECHENMACHER': 0,
    'RECHER': 0,
    'RECHIN': 0,
    'RECHKEMMER': 0,
    'RECHLIN': 0,
    'RECHNER': 0,
    'RECHSTEINER': 0,
    'RECHT': 0,
    'RECHTER': 0,
    'RECHTIEN': 0,
    'RECHTIN': 0,
    'RECHTZIGEL': 0,
    'RECILLAS': 0,
    'RECINE': 0,
    'RECINO': 0,
    'RECINOS': 0,
    'RECINTO': 0,
    'RECIO': 0,
    'RECK': 0,
    'RECKAMP': 0,
    'RECKARD': 0,
    'RECKART': 0,
    'RECKELHOFF': 0,
    'RECKER': 0,
    'RECKERS': 0,
    'RECKERT': 0,
    'RECKINGER': 0,
    'RECKLEIN': 0,
    'RECKLEY': 0,
    'RECKLING': 0,
    'RECKMAN': 0,
    'RECKNAGEL': 0,
    'RECKNER': 0,
    'RECKNOR': 0,
    'RECKO': 0,
    'RECKTENWALD': 0,
    'RECLA': 0,
    'RECLUSADO': 0,
    'RECOB': 0,
    'RECOR': 0,
    'RECORD': 0,
    'RECORDS': 0,
    'RECORE': 0,
    'RECTENWALD': 0,
    'RECTO': 0,
    'RECTOR': 0,
    'RECUPERO': 0,
    'RECZEK': 0,
    'RED': 0,
    'REDA': 0.6779661016949153,
    'REDAR': 0,
    'REDBEAR': 0,
    'REDBIRD': 0,
    'REDBURN': 0,
    'REDCAY': 0,
    'REDCLOUD': 0,
    'REDCROSS': 0,
    'REDD': 0,
    'REDDAN': 0,
    'REDDAWAY': 0,
    'REDDAY': 0,
    'REDDEKOPP': 0,
    'REDDEL': 0,
    'REDDELL': 0,
    'REDDEN': 0,
    'REDDER': 0,
    'REDDI': 0,
    'REDDIC': 0,
    'REDDICK': 0,
    'REDDICKS': 0,
    'REDDIE': 0,
    'REDDIG': 0,
    'REDDIN': 0,
    'REDDING': 0,
    'REDDINGER': 0,
    'REDDINGTON': 0,
    'REDDISH': 0,
    'REDDITT': 0,
    'REDDIX': 0,
    'REDDOCH': 0,
    'REDDOCK': 0,
    'REDDON': 0,
    'REDDOUT': 0,
    'REDDRICK': 0,
    'REDDY': 0,
    'REDE': 0,
    'REDEAGLE': 0,
    'REDEAUX': 0,
    'REDECKER': 0,
    'REDEKER': 0,
    'REDEL': 0,
    'REDELK': 0,
    'REDELL': 0,
    'REDELMAN': 0,
    'REDELSPERGER': 0,
    'REDEMANN': 0,
    'REDEN': 0,
    'REDENBAUGH': 0,
    'REDENIUS': 0,
    'REDEPENNING': 0,
    'REDER': 0,
    'REDETZKE': 0,
    'REDEYE': 0,
    'REDFEARN': 0,
    'REDFEATHER': 0,
    'REDFERN': 0,
    'REDFIELD': 0,
    'REDFOOT': 0,
    'REDFORD': 0,
    'REDFOX': 0,
    'REDGATE': 0,
    'REDGER': 0,
    'REDGRAVE': 0,
    'REDHAGE': 0,
    'REDHAIR': 0,
    'REDHEAD': 0,
    'REDHORSE': 0,
    'REDHOUSE': 0,
    'REDIC': 0,
    'REDICAN': 0,
    'REDICK': 0,
    'REDIFER': 0,
    'REDIG': 0,
    'REDIGER': 0,
    'REDIKER': 0,
    'REDIN': 0,
    'REDING': 0,
    'REDINGER': 0,
    'REDINGTON': 0,
    'REDISH': 0,
    'REDISKE': 0,
    'REDIX': 0,
    'REDKEY': 0,
    'REDL': 0,
    'REDLEAF': 0,
    'REDLER': 0,
    'REDLICH': 0,
    'REDLIN': 0,
    'REDLINE': 0,
    'REDLING': 0,
    'REDLINGER': 0,
    'REDLON': 0,
    'REDMAN': 0,
    'REDMANN': 0,
    'REDMER': 0,
    'REDMILES': 0,
    'REDMILL': 0,
    'REDMON': 0,
    'REDMOND': 0,
    'REDNER': 0,
    'REDNOUR': 0,
    'REDO': 0,
    'REDOBLE': 0,
    'REDON': 0,
    'REDONA': 0,
    'REDONDO': 0,
    'REDOUTEY': 0,
    'REDOWL': 0,
    'REDPATH': 0,
    'REDRICK': 0,
    'REDROW': 0,
    'REDSHAW': 0,
    'REDSHIRT': 0,
    'REDSTONE': 0,
    'REDUS': 0,
    'REDWAY': 0,
    'REDWINE': 0,
    'REDWING': 0,
    'REDWOOD': 0,
    'REDZIC': 0,
    'REE': 0,
    'REEB': 0,
    'REEBEL': 0,
    'REEBER': 0,
    'REECE': 0,
    'REECER': 0,
    'REECH': 0,
    'REECK': 0,
    'REED': 0.0916254352208173,
    'REEDE': 0,
    'REEDER': 0,
    'REEDMAN': 0,
    'REEDS': 0,
    'REEDUS': 0,
    'REEDY': 0,
    'REEF': 0,
    'REEFER': 0,
    'REEG': 0,
    'REEGER': 0,
    'REEH': 0,
    'REEHER': 0,
    'REEHL': 0,
    'REEK': 0,
    'REEKERS': 0,
    'REEKIE': 0,
    'REEKS': 0,
    'REEL': 0,
    'REELEY': 0,
    'REELS': 0,
    'REELY': 0,
    'REEM': 0,
    'REEMS': 0,
    'REEMSNYDER': 0,
    'REEMTS': 0,
    'REEN': 0,
    'REENA': 1,
    'REENDERS': 0,
    'REENTS': 0,
    'REEP': 0,
    'REEPING': 0,
    'REEPS': 0,
    'REER': 0,
    'REES': 0,
    'REESE': 0,
    'REESER': 0,
    'REESEY': 0,
    'REESMAN': 0,
    'REESON': 0,
    'REESOR': 0,
    'REETER': 0,
    'REETZ': 0,
    'REEVE': 0,
    'REEVER': 0,
    'REEVERTS': 0,
    'REEVES': 0,
    'REEVEY': 0,
    'REFAI': 0,
    'REFF': 0,
    'REFFEL': 0,
    'REFFETT': 0,
    'REFFITT': 0,
    'REFFNER': 0,
    'REFICE': 0,
    'REFIOR': 0,
    'REFSLAND': 0,
    'REFT': 0,
    'REFUERZO': 0,
    'REFUGIA': 1,
    'REFUGIO': 0.99009900990099,
    'REG': 0,
    'REGA': 0,
    'REGACHO': 0,
    'REGAL': 0,
    'REGALA': 0,
    'REGALADO': 0,
    'REGALBUTO': 0,
    'REGALDO': 0,
    'REGALIA': 0,
    'REGAN': 0.2722323049001815,
    'REGANS': 0,
    'REGAR': 0,
    'REGAS': 0,
    'REGAZZI': 0,
    'REGE': 0,
    'REGEHR': 0,
    'REGEL': 0,
    'REGELE': 0,
    'REGELIN': 0,
    'REGELMAN': 0,
    'REGELSKI': 0,
    'REGEN': 0,
    'REGENA': 1,
    'REGENIA': 1,
    'REGENNITTER': 0,
    'REGENOLD': 0,
    'REGENSBERG': 0,
    'REGENSBURG': 0,
    'REGENSBURGER': 0,
    'REGENSCHEID': 0,
    'REGENT': 0,
    'REGER': 0,
    'REGES': 0,
    'REGESTER': 0,
    'REGETS': 0,
    'REGG': 0,
    'REGGANS': 0,
    'REGGIANI': 0,
    'REGGIE': 0.9925558312655087,
    'REGGIO': 0,
    'REGIAN': 0,
    'REGIDOR': 0,
    'REGIEC': 0,
    'REGIER': 0,
    'REGIMBAL': 0,
    'REGIN': 0,
    'REGINA': 0.9957325746799431,
    'REGINALD': 0.9992862241256245,
    'REGINATO': 0,
    'REGINE': 0.9615384615384616,
    'REGINELLI': 0,
    'REGINIA': 1,
    'REGINO': 0,
    'REGIS': 0,
    'REGISTE': 0,
    'REGISTER': 0,
    'REGISTRE': 0,
    'REGITZ': 0,
    'REGLA': 0,
    'REGLER': 0,
    'REGLI': 0,
    'REGLIN': 0,
    'REGN': 0,
    'REGNA': 0,
    'REGNER': 0,
    'REGNERUS': 0,
    'REGNERY': 0,
    'REGNIER': 0,
    'REGO': 0,
    'REGOLI': 0,
    'REGOTTI': 0,
    'REGRUT': 0,
    'REGUEIRA': 0,
    'REGUEIRO': 0,
    'REGUERA': 0,
    'REGUERO': 0,
    'REGULA': 0,
    'REGULAR': 0,
    'REGULSKI': 0,
    'REGUS': 0,
    'REH': 0,
    'REHA': 0,
    'REHAGE': 0,
    'REHAGEN': 0,
    'REHAK': 0,
    'REHAL': 0,
    'REHAN': 0,
    'REHARD': 0,
    'REHBEIN': 0,
    'REHBERG': 0,
    'REHBERGER': 0,
    'REHBOCK': 0,
    'REHDER': 0,
    'REHE': 0,
    'REHEIS': 0,
    'REHER': 0,
    'REHERMAN': 0,
    'REHFELD': 0,
    'REHFELDT': 0,
    'REHFIELD': 0,
    'REHFUSS': 0,
    'REHG': 0,
    'REHILL': 0,
    'REHKAMP': 0,
    'REHKEMPER': 0,
    'REHKOP': 0,
    'REHKOPF': 0,
    'REHL': 0,
    'REHLING': 0,
    'REHM': 0,
    'REHMAN': 0,
    'REHMANN': 0,
    'REHME': 0,
    'REHMEL': 0,
    'REHMER': 0,
    'REHMERT': 0,
    'REHMEYER': 0,
    'REHMS': 0,
    'REHN': 0,
    'REHNBERG': 0,
    'REHNER': 0,
    'REHO': 0,
    'REHOR': 0,
    'REHORN': 0,
    'REHORST': 0,
    'REHR': 0,
    'REHRAUER': 0,
    'REHRER': 0,
    'REHRIG': 0,
    'REHS': 0,
    'REHSE': 0,
    'REHWALD': 0,
    'REHWALDT': 0,
    'REHWINKEL': 0,
    'REI': 0,
    'REIB': 0,
    'REIBEL': 0,
    'REIBER': 0,
    'REIBERT': 0,
    'REIBLE': 0,
    'REIBLING': 0,
    'REIBMAN': 0,
    'REIBOLD': 0,
    'REIBOLDT': 0,
    'REIBSOME': 0,
    'REICH': 0,
    'REICHARD': 0,
    'REICHARDT': 0,
    'REICHART': 0,
    'REICHBACH': 0,
    'REICHE': 0,
    'REICHEL': 0,
    'REICHELDERFER': 0,
    'REICHELT': 0,
    'REICHEN': 0,
    'REICHENBACH': 0,
    'REICHENBACHER': 0,
    'REICHENBAUGH': 0,
    'REICHENBERG': 0,
    'REICHENBERGER': 0,
    'REICHER': 0,
    'REICHERT': 0,
    'REICHERTER': 0,
    'REICHHART': 0,
    'REICHHOFF': 0,
    'REICHHOLD': 0,
    'REICHL': 0,
    'REICHLE': 0,
    'REICHLER': 0,
    'REICHLEY': 0,
    'REICHLIN': 0,
    'REICHLING': 0,
    'REICHMAN': 0,
    'REICHMANN': 0,
    'REICHMUTH': 0,
    'REICHNER': 0,
    'REICHOW': 0,
    'REICHSTADT': 0,
    'REICHSTEIN': 0,
    'REICHTER': 0,
    'REICHWALD': 0,
    'REICHWEIN': 0,
    'REICK': 0,
    'REICKS': 0,
    'REID': 0.15364354697102722,
    'REIDA': 0,
    'REIDEL': 0,
    'REIDELBACH': 0,
    'REIDELBERGER': 0,
    'REIDELL': 0,
    'REIDENBACH': 0,
    'REIDENBAUGH': 0,
    'REIDER': 0,
    'REIDHEAD': 0,
    'REIDINGER': 0,
    'REIDLE': 0,
    'REIDLER': 0,
    'REIDLING': 0,
    'REIDLINGER': 0,
    'REIDMILLER': 0,
    'REIDT': 0,
    'REIDY': 0,
    'REIER': 0,
    'REIERSEN': 0,
    'REIERSON': 0,
    'REIF': 0,
    'REIFEL': 0,
    'REIFENBERG': 0,
    'REIFENBERGER': 0,
    'REIFENRATH': 0,
    'REIFER': 0,
    'REIFERS': 0,
    'REIFERT': 0,
    'REIFF': 0,
    'REIFINGER': 0,
    'REIFLER': 0,
    'REIFMAN': 0,
    'REIFSCHNEIDER': 0,
    'REIFSNIDER': 0,
    'REIFSNYDER': 0,
    'REIFSTECK': 0,
    'REIG': 0,
    'REIGART': 0,
    'REIGEL': 0,
    'REIGELMAN': 0,
    'REIGELSPERGER': 0,
    'REIGER': 0,
    'REIGH': 0,
    'REIGHARD': 0,
    'REIGHLEY': 0,
    'REIGHN': 0,
    'REIGHTER': 0,
    'REIGHTLER': 0,
    'REIGLE': 0,
    'REIGNER': 0,
    'REIGSTAD': 0,
    'REIHART': 0,
    'REIHER': 0,
    'REIHING': 0,
    'REIHL': 0,
    'REIHS': 0,
    'REIK': 0,
    'REIKER': 0,
    'REIKO': 1,
    'REIKOFSKI': 0,
    'REIKOWSKI': 0,
    'REIL': 0,
    'REILAND': 0,
    'REILE': 0,
    'REILEY': 0,
    'REILING': 0,
    'REILL': 0,
    'REILLEY': 0,
    'REILLO': 0,
    'REILLY': 0,
    'REILMAN': 0,
    'REILY': 0,
    'REIM': 0,
    'REIMAN': 0,
    'REIMANN': 0,
    'REIMBOLD': 0,
    'REIMCHE': 0,
    'REIMEL': 0,
    'REIMELS': 0,
    'REIMER': 0,
    'REIMERS': 0,
    'REIMERT': 0,
    'REIMINK': 0,
    'REIMLER': 0,
    'REIMNITZ': 0,
    'REIMOLD': 0,
    'REIMONDO': 0,
    'REIMONENQ': 0,
    'REIMUND': 0,
    'REIN': 0,
    'REINA': 0.8287292817679558,
    'REINACHER': 0,
    'REINAGA': 0,
    'REINAGEL': 0,
    'REINALDO': 1,
    'REINARD': 0,
    'REINARDY': 0,
    'REINART': 0,
    'REINARTS': 0,
    'REINARTZ': 0,
    'REINARZ': 0,
    'REINAUER': 0,
    'REINBERG': 0,
    'REINBOLD': 0,
    'REINBOLT': 0,
    'REINCE': 0,
    'REINCKE': 0,
    'REINDEL': 0,
    'REINDERS': 0,
    'REINDL': 0,
    'REINDOLLAR': 0,
    'REINE': 0,
    'REINECCIUS': 0,
    'REINECK': 0,
    'REINECKE': 0,
    'REINECKER': 0,
    'REINEKE': 0,
    'REINEKING': 0,
    'REINELT': 0,
    'REINEMANN': 0,
    'REINEN': 0,
    'REINER': 0,
    'REINERS': 0,
    'REINERT': 0,
    'REINERTSEN': 0,
    'REINERTSON': 0,
    'REINES': 0,
    'REINFELD': 0,
    'REINFORD': 0,
    'REING': 0,
    'REINGOLD': 0,
    'REINHARD': 0,
    'REINHARDT': 0,
    'REINHART': 0,
    'REINHEIMER': 0,
    'REINHOLD': 0,
    'REINHOLDT': 0,
    'REINHOLT': 0,
    'REINHOLTZ': 0,
    'REINHOLZ': 0,
    'REINI': 0,
    'REINICHE': 0,
    'REINICK': 0,
    'REINICKE': 0,
    'REINIER': 0,
    'REINIG': 0,
    'REINIGER': 0,
    'REINING': 0,
    'REININGA': 0,
    'REININGER': 0,
    'REININK': 0,
    'REINIS': 0,
    'REINISCH': 0,
    'REINITZ': 0,
    'REINKE': 0,
    'REINKEMEYER': 0,
    'REINKEN': 0,
    'REINKER': 0,
    'REINKING': 0,
    'REINL': 0,
    'REINMAN': 0,
    'REINMANN': 0,
    'REINMILLER': 0,
    'REINMUTH': 0,
    'REINO': 0,
    'REINOEHL': 0,
    'REINOLD': 0,
    'REINOSA': 0,
    'REINOSO': 0,
    'REINS': 0,
    'REINSCH': 0,
    'REINSCHMIDT': 0,
    'REINSEL': 0,
    'REINSHAGEN': 0,
    'REINSMA': 0,
    'REINSMITH': 0,
    'REINSTEIN': 0,
    'REINTHALER': 0,
    'REINTJES': 0,
    'REINTS': 0,
    'REINWALD': 0,
    'REINWAND': 0,
    'REIP': 0,
    'REIS': 0,
    'REISBECK': 0,
    'REISBERG': 0,
    'REISBIG': 0,
    'REISCH': 0,
    'REISCHE': 0,
    'REISCHEL': 0,
    'REISCHER': 0,
    'REISCHL': 0,
    'REISCHMAN': 0,
    'REISDORF': 0,
    'REISDORFER': 0,
    'REISDORFF': 0,
    'REISDORPH': 0,
    'REISE': 0,
    'REISEL': 0,
    'REISEN': 0,
    'REISENAUER': 0,
    'REISENBICHLER': 0,
    'REISER': 0,
    'REISERT': 0,
    'REISETTER': 0,
    'REISH': 0,
    'REISHUS': 0,
    'REISIG': 0,
    'REISING': 0,
    'REISINGER': 0,
    'REISKE': 0,
    'REISLER': 0,
    'REISMAN': 0,
    'REISNER': 0,
    'REISS': 0,
    'REISSER': 0,
    'REISSIG': 0,
    'REISSMAN': 0,
    'REISSMANN': 0,
    'REISSNER': 0,
    'REIST': 0,
    'REISTAD': 0,
    'REISTER': 0,
    'REISTROFFER': 0,
    'REISWIG': 0,
    'REISZ': 0,
    'REIT': 0,
    'REITA': 1,
    'REITAN': 0,
    'REITAND': 0,
    'REITANO': 0,
    'REITE': 0,
    'REITEN': 0,
    'REITENBACH': 0,
    'REITER': 0,
    'REITERMAN': 0,
    'REITH': 0,
    'REITHEL': 0,
    'REITHER': 0,
    'REITINGER': 0,
    'REITLER': 0,
    'REITMAN': 0,
    'REITMEIER': 0,
    'REITMEYER': 0,
    'REITNAUER': 0,
    'REITSMA': 0,
    'REITTER': 0,
    'REITTINGER': 0,
    'REITZ': 0,
    'REITZEL': 0,
    'REITZELL': 0,
    'REITZER': 0,
    'REIVER': 0,
    'REIVES': 0,
    'REIZ': 0,
    'REJAS': 0,
    'REJCEK': 0,
    'REJINO': 0,
    'REJMAN': 0,
    'REJNIAK': 0,
    'REJON': 0,
    'REJOUIS': 0,
    'REK': 0,
    'REKART': 0,
    'REKAS': 0,
    'REKEMEYER': 0,
    'REKER': 0,
    'REKERS': 0,
    'REKEWEG': 0,
    'REKHI': 0,
    'REKIETA': 0,
    'REKOW': 0,
    'REKOWSKI': 0,
    'REKSTAD': 0,
    'REL': 0,
    'RELAFORD': 0,
    'RELATION': 0,
    'RELEFORD': 0,
    'RELERFORD': 0,
    'RELF': 0,
    'RELFORD': 0,
    'RELIC': 0,
    'RELICH': 0,
    'RELIFORD': 0,
    'RELIHAN': 0,
    'RELITZ': 0,
    'RELKIN': 0,
    'RELL': 0,
    'RELLA': 0,
    'RELLE': 0,
    'RELLER': 0,
    'RELLERGERT': 0,
    'RELLES': 0,
    'RELLINGER': 0,
    'RELLO': 0,
    'RELLY': 0,
    'RELPH': 0,
    'RELYEA': 0,
    'REM': 0,
    'REMA': 1,
    'REMACHE': 0,
    'REMACLE': 0,
    'REMAK': 0,
    'REMAKLUS': 0,
    'REMALEY': 0,
    'REMALY': 0,
    'REMAR': 0,
    'REMARK': 0,
    'REMBER': 0,
    'REMBERT': 0,
    'REMBIS': 0,
    'REMBISH': 0,
    'REMBISZ': 0,
    'REMBOLD': 0,
    'REMBOLDT': 0,
    'REMBOWSKI': 0,
    'REME': 0,
    'REMEDIES': 0,
    'REMEDIOS': 0.9259259259259258,
    'REMEIKA': 0,
    'REMEL': 0,
    'REMELE': 0,
    'REMELIUS': 0,
    'REMEN': 0,
    'REMENAR': 0,
    'REMENTER': 0,
    'REMER': 0,
    'REMES': 0,
    'REMIAS': 0,
    'REMICK': 0,
    'REMIEN': 0,
    'REMIGIO': 0,
    'REMIJIO': 0,
    'REMIKER': 0,
    'REMILLARD': 0,
    'REMILY': 0,
    'REMINDER': 0,
    'REMINE': 0,
    'REMINES': 0,
    'REMINGA': 0,
    'REMINGTON': 0,
    'REMIREZ': 0,
    'REMIS': 0,
    'REMISZEWSKI': 0,
    'REMKE': 0,
    'REMKUS': 0,
    'REMLER': 0,
    'REMLEY': 0,
    'REMLING': 0,
    'REMLINGER': 0,
    'REMM': 0,
    'REMME': 0,
    'REMMEL': 0,
    'REMMELE': 0,
    'REMMEN': 0,
    'REMMENGA': 0,
    'REMMER': 0,
    'REMMERS': 0,
    'REMMERT': 0,
    'REMMES': 0,
    'REMMEY': 0,
    'REMMICK': 0,
    'REMMY': 0,
    'REMO': 0,
    'REMON': 0,
    'REMONA': 1,
    'REMOND': 0,
    'REMONDET': 0,
    'REMONDINI': 0,
    'REMOS': 0,
    'REMP': 0,
    'REMPALA': 0,
    'REMPE': 0,
    'REMPEL': 0,
    'REMPERT': 0,
    'REMPFER': 0,
    'REMPHREY': 0,
    'REMPP': 0,
    'REMS': 0,
    'REMSBERG': 0,
    'REMSBURG': 0,
    'REMSEN': 0,
    'REMSING': 0,
    'REMSON': 0,
    'REMSTER': 0,
    'REMTER': 0,
    'REMUND': 0,
    'REMUS': 0,
    'REMY': 0,
    'REN': 0,
    'RENA': 0.9941089837997055,
    'RENAE': 1,
    'RENAGHAN': 0,
    'RENAKER': 0,
    'RENALDI': 0,
    'RENALDO': 0.9615384615384616,
    'RENALDS': 0,
    'RENARD': 0,
    'RENAS': 0,
    'RENATA': 1,
    'RENATE': 1,
    'RENATO': 1,
    'RENAUD': 0,
    'RENAULD': 0,
    'RENAULT': 0,
    'RENAY': 1,
    'RENBARGER': 0,
    'RENBERG': 0,
    'RENCH': 0,
    'RENCHEN': 0,
    'RENCHER': 0,
    'RENCK': 0,
    'RENDA': 0.5813953488372093,
    'RENDAHL': 0,
    'RENDALL': 0,
    'RENDE': 0,
    'RENDEIRO': 0,
    'RENDEL': 0,
    'RENDELL': 0,
    'RENDER': 0,
    'RENDEROS': 0,
    'RENDINA': 0,
    'RENDINE': 0,
    'RENDINO': 0,
    'RENDLE': 0,
    'RENDLEMAN': 0,
    'RENDLER': 0,
    'RENDO': 0,
    'RENDON': 0,
    'RENDULIC': 0,
    'RENE': 0.9875019287147044,
    'RENEA': 1,
    'RENEAU': 0,
    'RENECKER': 0,
    'RENEE': 0.9990841728415619,
    'RENEER': 0,
    'RENEGAR': 0,
    'RENEHAN': 0,
    'RENEKER': 0,
    'RENELLA': 0,
    'RENEMAN': 0,
    'RENER': 0,
    'RENERT': 0,
    'RENES': 0,
    'RENETTA': 1,
    'RENEW': 0,
    'RENEY': 0,
    'RENFER': 0,
    'RENFORD': 0,
    'RENFORTH': 0,
    'RENFREE': 0,
    'RENFREW': 0,
    'RENFRO': 0,
    'RENFROE': 0,
    'RENFROW': 0,
    'RENGA': 0,
    'RENGEL': 0,
    'RENGER': 0,
    'RENGERS': 0,
    'RENGERT': 0,
    'RENGIFO': 0,
    'RENGO': 0,
    'RENGSTORF': 0,
    'RENICK': 0,
    'RENICKER': 0,
    'RENIE': 0,
    'RENIER': 0,
    'RENIGAR': 0,
    'RENIHAN': 0,
    'RENIKER': 0,
    'RENINGER': 0,
    'RENISH': 0,
    'RENISON': 0,
    'RENITA': 1,
    'RENK': 0,
    'RENKAS': 0,
    'RENKE': 0,
    'RENKEL': 0,
    'RENKEMA': 0,
    'RENKEN': 0,
    'RENKENBERGER': 0,
    'RENKER': 0,
    'RENKERT': 0,
    'RENKES': 0,
    'RENKIEWICZ': 0,
    'RENKIN': 0,
    'RENKO': 0,
    'RENN': 0,
    'RENNA': 0.5882352941176471,
    'RENNAKER': 0,
    'RENNARD': 0,
    'RENNE': 0,
    'RENNEBERG': 0,
    'RENNECKER': 0,
    'RENNEGARBE': 0,
    'RENNEISEN': 0,
    'RENNEKAMP': 0,
    'RENNEKE': 0,
    'RENNEKER': 0,
    'RENNELL': 0,
    'RENNELLS': 0,
    'RENNELS': 0,
    'RENNER': 0,
    'RENNERT': 0,
    'RENNEY': 0,
    'RENNHACK': 0,
    'RENNICH': 0,
    'RENNICK': 0,
    'RENNICKE': 0,
    'RENNICKER': 0,
    'RENNIE': 0,
    'RENNIER': 0,
    'RENNING': 0,
    'RENNINGER': 0,
    'RENNISON': 0,
    'RENNIX': 0,
    'RENNO': 0,
    'RENNOLDS': 0,
    'RENNY': 0,
    'RENO': 0,
    'RENOE': 0,
    'RENOIS': 0,
    'RENOJ': 0,
    'RENOLL': 0,
    'RENOLLET': 0,
    'RENON': 0,
    'RENOUF': 0,
    'RENOVA': 0,
    'RENOVATO': 0,
    'RENQUIST': 0,
    'RENS': 0,
    'RENSBERGER': 0,
    'RENSCH': 0,
    'RENSCHEN': 0,
    'RENSCHLER': 0,
    'RENSEL': 0,
    'RENSHAW': 0,
    'RENSI': 0,
    'RENSING': 0,
    'RENSINK': 0,
    'RENSLOW': 0,
    'RENSON': 0,
    'RENSTROM': 0,
    'RENSVOLD': 0,
    'RENT': 0,
    'RENTA': 0,
    'RENTAS': 0,
    'RENTEL': 0,
    'RENTER': 0,
    'RENTERIA': 0,
    'RENTFRO': 0,
    'RENTFROW': 0,
    'RENTH': 0,
    'RENTIE': 0,
    'RENTMEESTER': 0,
    'RENTMEISTER': 0,
    'RENTNER': 0,
    'RENTON': 0,
    'RENTROP': 0,
    'RENTSCH': 0,
    'RENTSCHLER': 0,
    'RENTZ': 0,
    'RENTZEL': 0,
    'RENUART': 0,
    'RENVILLE': 0,
    'RENWICK': 0,
    'RENY': 0,
    'RENYER': 0,
    'RENYOLDS': 0,
    'RENZ': 0,
    'RENZA': 0,
    'RENZE': 0,
    'RENZELMAN': 0,
    'RENZETTI': 0,
    'RENZI': 0,
    'RENZO': 0,
    'RENZONI': 0,
    'RENZULLI': 0,
    'RENZULLO': 0,
    'REO': 0,
    'REOCH': 0,
    'REODICA': 0,
    'REOLA': 0,
    'REOME': 0,
    'REON': 0,
    'REOPELLE': 0,
    'REOTT': 0,
    'REPA': 0,
    'REPACI': 0,
    'REPAK': 0,
    'REPAS': 0,
    'REPASI': 0,
    'REPASKY': 0,
    'REPASS': 0,
    'REPASY': 0,
    'REPELLA': 0,
    'REPENNING': 0,
    'REPETA': 0,
    'REPETTI': 0,
    'REPETTO': 0,
    'REPH': 0,
    'REPIC': 0,
    'REPICE': 0,
    'REPICI': 0,
    'REPICKY': 0,
    'REPIK': 0,
    'REPINE': 0,
    'REPINSKI': 0,
    'REPKA': 0,
    'REPKE': 0,
    'REPKING': 0,
    'REPKO': 0,
    'REPLOGLE': 0,
    'REPMAN': 0,
    'REPOLA': 0,
    'REPOLE': 0,
    'REPOLI': 0,
    'REPOLLET': 0,
    'REPOSA': 0,
    'REPP': 0,
    'REPPART': 0,
    'REPPE': 0,
    'REPPEL': 0,
    'REPPEN': 0,
    'REPPENHAGEN': 0,
    'REPPER': 0,
    'REPPERT': 0,
    'REPPLINGER': 0,
    'REPPOND': 0,
    'REPPUCCI': 0,
    'REPPY': 0,
    'REPREZA': 0,
    'REPROGLE': 0,
    'REPS': 0,
    'REPSHER': 0,
    'REPTA': 0,
    'REPUCCI': 0,
    'REQUA': 0,
    'REQUARTH': 0,
    'REQUE': 0,
    'REQUEJO': 0,
    'REQUENA': 0,
    'REQUENEZ': 0,
    'REQUENO': 0,
    'RERA': 0,
    'RERECICH': 0,
    'RERES': 0,
    'RERICHA': 0,
    'RERICK': 0,
    'RERKO': 0,
    'RERUCHA': 0,
    'RES': 0,
    'RESA': 0,
    'RESAR': 0,
    'RESCH': 0,
    'RESCHKE': 0,
    'RESCHLY': 0,
    'RESCIGNO': 0,
    'RESCINITI': 0,
    'RESE': 0,
    'RESEBURG': 0,
    'RESECKER': 0,
    'RESEIGH': 0,
    'RESEK': 0,
    'RESENDE': 0,
    'RESENDES': 0,
    'RESENDEZ': 0,
    'RESENDIS': 0,
    'RESENDIZ': 0,
    'RESER': 0,
    'RESETAR': 0,
    'RESH': 0,
    'RESHA': 0,
    'RESHARD': 0,
    'RESHEL': 0,
    'RESHESKE': 0,
    'RESHETAR': 0,
    'RESIDE': 0,
    'RESIDES': 0,
    'RESIG': 0,
    'RESINGER': 0,
    'RESINOS': 0,
    'RESIO': 0,
    'RESKA': 0,
    'RESKE': 0,
    'RESKO': 0,
    'RESLER': 0,
    'RESLEY': 0,
    'RESMAN': 0,
    'RESMINI': 0,
    'RESMONDO': 0,
    'RESNER': 0,
    'RESNICK': 0,
    'RESNIK': 0,
    'RESNIKOFF': 0,
    'RESO': 0,
    'RESOP': 0,
    'RESOR': 0,
    'RESPASS': 0,
    'RESPESS': 0,
    'RESPICIO': 0,
    'RESPONDEK': 0,
    'RESPRESS': 0,
    'RESS': 0,
    'RESSA': 0,
    'RESSE': 0,
    'RESSEGUIE': 0,
    'RESSEL': 0,
    'RESSER': 0,
    'RESSIE': 1,
    'RESSLER': 0,
    'REST': 0,
    'RESTA': 0,
    'RESTAD': 0,
    'RESTAINO': 0,
    'RESTANI': 0,
    'RESTELLI': 0,
    'RESTER': 0,
    'RESTIFO': 0,
    'RESTITUYO': 0,
    'RESTIVO': 0,
    'RESTO': 0,
    'RESTON': 0,
    'RESTREPO': 0,
    'RESTUCCIA': 0,
    'RESTUCCIO': 0,
    'RESTUM': 0,
    'RESUE': 0,
    'RESURRECCION': 0,
    'RESWEBER': 0,
    'RESZ': 0,
    'RESZEL': 0,
    'RESZKA': 0,
    'RET': 0,
    'RETA': 0.9389671361502346,
    'RETALLACK': 0,
    'RETALLICK': 0,
    'RETAMAR': 0,
    'RETAMOZA': 0,
    'RETAMOZO': 0,
    'RETAN': 0,
    'RETANA': 0,
    'RETANO': 0,
    'RETCHER': 0,
    'RETCHLESS': 0,
    'RETELLE': 0,
    'RETES': 0,
    'RETH': 0,
    'RETHA': 1,
    'RETHERFORD': 0,
    'RETHLAKE': 0,
    'RETHMAN': 0,
    'RETHMEIER': 0,
    'RETHWISCH': 0,
    'RETIZ': 0,
    'RETKA': 0,
    'RETO': 0,
    'RETORT': 0,
    'RETRUM': 0,
    'RETT': 0,
    'RETTA': 0.9478672985781991,
    'RETTBERG': 0,
    'RETTENMAIER': 0,
    'RETTER': 0,
    'RETTERATH': 0,
    'RETTERER': 0,
    'RETTEW': 0,
    'RETTGER': 0,
    'RETTIE': 0,
    'RETTIG': 0,
    'RETTING': 0,
    'RETTINGER': 0,
    'RETTINO': 0,
    'RETTKE': 0,
    'RETTLER': 0,
    'RETTMAN': 0,
    'RETTMANN': 0,
    'RETUTA': 0,
    'RETZ': 0,
    'RETZER': 0,
    'RETZKE': 0,
    'RETZLAFF': 0,
    'RETZLER': 0,
    'RETZLOFF': 0,
    'REU': 0,
    'REUBEN': 0.9727626459143969,
    'REUBENS': 0,
    'REUBER': 0,
    'REUER': 0,
    'REUILLE': 0,
    'REUKAUF': 0,
    'REUL': 0,
    'REULAND': 0,
    'REULBACH': 0,
    'REULE': 0,
    'REULET': 0,
    'REULING': 0,
    'REUM': 0,
    'REUMAN': 0,
    'REUMANN': 0,
    'REURINK': 0,
    'REUS': 0,
    'REUSCH': 0,
    'REUSCHE': 0,
    'REUSCHEL': 0,
    'REUSCHER': 0,
    'REUSING': 0,
    'REUSS': 0,
    'REUSSER': 0,
    'REUST': 0,
    'REUSTLE': 0,
    'REUTEBUCH': 0,
    'REUTELER': 0,
    'REUTER': 0,
    'REUTHER': 0,
    'REUTLINGER': 0,
    'REUTOV': 0,
    'REUTTER': 0,
    'REUTZEL': 0,
    'REUVERS': 0,
    'REUWER': 0,
    'REVA': 1,
    'REVAK': 0,
    'REVALEE': 0,
    'REVARD': 0,
    'REVAS': 0,
    'REVAY': 0,
    'REVEAL': 0,
    'REVEL': 0,
    'REVELES': 0,
    'REVELEY': 0,
    'REVELEZ': 0,
    'REVELL': 0,
    'REVELLA': 0,
    'REVELLE': 0,
    'REVELLI': 0,
    'REVELLO': 0,
    'REVELLS': 0,
    'REVELO': 0,
    'REVELS': 0,
    'REVELY': 0,
    'REVEN': 0,
    'REVENAUGH': 0,
    'REVER': 0,
    'REVERCOMB': 0,
    'REVERE': 0,
    'REVERING': 0,
    'REVERMAN': 0,
    'REVERON': 0,
    'REVERS': 0,
    'REVES': 0,
    'REVESZ': 0,
    'REVETT': 0,
    'REVETTA': 0,
    'REVETTE': 0,
    'REVIA': 0,
    'REVIE': 0,
    'REVIER': 0,
    'REVIERE': 0,
    'REVILL': 0,
    'REVILLA': 0,
    'REVILLE': 0,
    'REVIS': 0,
    'REVLETT': 0,
    'REVOIR': 0,
    'REVOLINSKI': 0,
    'REVOLLAR': 0,
    'REVOLLO': 0,
    'REVOLORIO': 0,
    'REVOLT': 0,
    'REVORD': 0,
    'REVOREDO': 0,
    'REVUELTA': 0,
    'REVZIN': 0,
    'REW': 0,
    'REWA': 0,
    'REWALD': 0,
    'REWALT': 0,
    'REWERS': 0,
    'REWERTS': 0,
    'REWEY': 0,
    'REWIS': 0,
    'REWITZER': 0,
    'REWOLINSKI': 0,
    'REX': 0.9482316760635572,
    'REXACH': 0,
    'REXER': 0,
    'REXES': 0,
    'REXFORD': 0,
    'REXHA': 0,
    'REXHEPI': 0,
    'REXIN': 0,
    'REXING': 0,
    'REXIUS': 0,
    'REXROAD': 0,
    'REXROAT': 0,
    'REXRODE': 0,
    'REXROTH': 0,
    'REXWINKLE': 0,
    'REY': 0.5952380952380952,
    'REYAS': 0,
    'REYBURN': 0,
    'REYE': 0,
    'REYELL': 0,
    'REYELTS': 0,
    'REYENGA': 0,
    'REYER': 0,
    'REYERS': 0,
    'REYERSON': 0,
    'REYES': 0.054830573527799104,
    'REYESGARCIA': 0,
    'REYESGONZALEZ': 0,
    'REYESHERNANDEZ': 0,
    'REYESLOPEZ': 0,
    'REYESMARTINEZ': 0,
    'REYESPEREZ': 0,
    'REYESRODRIGUEZ': 0,
    'REYESSANCHEZ': 0,
    'REYEZ': 0,
    'REYHER': 0,
    'REYLING': 0,
    'REYMAN': 0,
    'REYMANN': 0,
    'REYMER': 0,
    'REYMOND': 0,
    'REYMUNDO': 0,
    'REYNA': 0.47145102147721324,
    'REYNAERT': 0,
    'REYNAGA': 0,
    'REYNALDA': 1,
    'REYNALDO': 0.994475138121547,
    'REYNARD': 0,
    'REYNAUD': 0,
    'REYNDERS': 0,
    'REYNEN': 0,
    'REYNER': 0,
    'REYNERO': 0,
    'REYNES': 0,
    'REYNHOUT': 0,
    'REYNO': 0,
    'REYNOLD': 0,
    'REYNOLDS': 0,
    'REYNOLDSON': 0,
    'REYNON': 0,
    'REYNOSA': 0,
    'REYNOSO': 0,
    'REYNOZA': 0,
    'REYNOZO': 0,
    'REYOME': 0,
    'REYS': 0,
    'REZA': 0,
    'REZABEK': 0,
    'REZAC': 0,
    'REZAEI': 0,
    'REZAI': 0,
    'REZAIE': 0,
    'REZAK': 0,
    'REZEK': 0,
    'REZENDE': 0,
    'REZENDES': 0,
    'REZENDEZ': 0,
    'REZENDIZ': 0,
    'REZENTES': 0,
    'REZIN': 0,
    'REZK': 0,
    'REZLER': 0,
    'REZMER': 0,
    'REZNER': 0,
    'REZNICEK': 0,
    'REZNICK': 0,
    'REZNIK': 0,
    'REZNIKOV': 0,
    'REZNY': 0,
    'REZVANI': 0,
    'REZZA': 0,
    'REZZONICO': 0,
    'RHA': 0,
    'RHABURN': 0,
    'RHAME': 0,
    'RHAMES': 0,
    'RHAMY': 0,
    'RHAN': 0,
    'RHANEY': 0,
    'RHATIGAN': 0,
    'RHEA': 0.7556675062972292,
    'RHEAD': 0,
    'RHEAM': 0,
    'RHEAMS': 0,
    'RHEAULT': 0,
    'RHEAUME': 0,
    'RHEBA': 1,
    'RHEE': 0,
    'RHEEM': 0,
    'RHEES': 0,
    'RHEIN': 0,
    'RHEINECKER': 0,
    'RHEINER': 0,
    'RHEINGANS': 0,
    'RHEINGOLD': 0,
    'RHEINHARDT': 0,
    'RHEINHEIMER': 0,
    'RHEINLANDER': 0,
    'RHEINSCHMIDT': 0,
    'RHEM': 0,
    'RHEN': 0,
    'RHETT': 0.9280742459396751,
    'RHEUARK': 0,
    'RHEUBOTTOM': 0,
    'RHEW': 0,
    'RHEY': 0,
    'RHIANNON': 1,
    'RHIEL': 0,
    'RHIM': 0,
    'RHIND': 0,
    'RHINE': 0,
    'RHINEBERGER': 0,
    'RHINEBOLT': 0,
    'RHINEHARDT': 0,
    'RHINEHART': 0,
    'RHINER': 0,
    'RHINERSON': 0,
    'RHINES': 0,
    'RHINESMITH': 0,
    'RHINIER': 0,
    'RHINO': 0,
    'RHO': 0,
    'RHOAD': 0,
    'RHOADARMER': 0,
    'RHOADES': 0,
    'RHOADS': 0,
    'RHODA': 0.9728978457261986,
    'RHODAN': 0,
    'RHODARMER': 0,
    'RHODD': 0,
    'RHODE': 0,
    'RHODEBECK': 0,
    'RHODEHAMEL': 0,
    'RHODEHOUSE': 0,
    'RHODEN': 0,
    'RHODENBAUGH': 0,
    'RHODENIZER': 0,
    'RHODERICK': 0,
    'RHODES': 0,
    'RHODIE': 0,
    'RHODMAN': 0,
    'RHODS': 0,
    'RHODUS': 0,
    'RHODY': 0,
    'RHOE': 0,
    'RHOLETTER': 0,
    'RHOM': 0,
    'RHOMBERG': 0,
    'RHOME': 0,
    'RHONA': 1,
    'RHONDA': 1,
    'RHONE': 0,
    'RHONEMUS': 0,
    'RHONEY': 0,
    'RHORER': 0,
    'RHOTEN': 0,
    'RHOTON': 0,
    'RHUBART': 0,
    'RHUDE': 0,
    'RHUDY': 0,
    'RHUE': 0,
    'RHULE': 0,
    'RHUM': 0,
    'RHYAN': 0,
    'RHYE': 0,
    'RHYM': 0,
    'RHYME': 0,
    'RHYMER': 0,
    'RHYMES': 0,
    'RHYNARD': 0,
    'RHYNE': 0,
    'RHYNER': 0,
    'RHYNES': 0,
    'RHYS': 0,
    'RI': 0,
    'RIA': 1,
    'RIACH': 0,
    'RIAD': 0,
    'RIAHI': 0,
    'RIAL': 0,
    'RIALE': 0,
    'RIALES': 0,
    'RIALL': 0,
    'RIALS': 0,
    'RIAN': 0,
    'RIANDA': 0,
    'RIANI': 0,
    'RIANO': 0,
    'RIAS': 0,
    'RIASCOS': 0,
    'RIAT': 0,
    'RIAZ': 0,
    'RIAZI': 0,
    'RIAZZI': 0,
    'RIBA': 0,
    'RIBACK': 0,
    'RIBAIL': 0,
    'RIBAK': 0,
    'RIBANDO': 0,
    'RIBAR': 0,
    'RIBARICH': 0,
    'RIBAS': 0,
    'RIBAUDO': 0,
    'RIBBE': 0,
    'RIBBECK': 0,
    'RIBBENS': 0,
    'RIBBING': 0,
    'RIBBLE': 0,
    'RIBBLETT': 0,
    'RIBE': 0,
    'RIBEIRO': 0,
    'RIBELIN': 0,
    'RIBER': 0,
    'RIBERA': 0,
    'RIBERDY': 0,
    'RIBERIO': 0,
    'RIBERO': 0,
    'RIBET': 0,
    'RIBIC': 0,
    'RIBICH': 0,
    'RIBIS': 0,
    'RIBLET': 0,
    'RIBLETT': 0,
    'RIBLEY': 0,
    'RIBNER': 0,
    'RIBONI': 0,
    'RIBORDY': 0,
    'RIBOT': 0,
    'RIBOTA': 0,
    'RICA': 0,
    'RICAFORT': 0,
    'RICAFRENTE': 0,
    'RICALDAY': 0,
    'RICALDE': 0,
    'RICAPITO': 0,
    'RICARD': 0,
    'RICARDA': 1,
    'RICARDEZ': 0,
    'RICARDI': 0,
    'RICARDO': 0.9896775566670214,
    'RICARDS': 0,
    'RICARDSON': 0,
    'RICART': 0,
    'RICARTE': 0,
    'RICAURTE': 0,
    'RICCA': 0,
    'RICCARDELLI': 0,
    'RICCARDI': 0,
    'RICCARDO': 0,
    'RICCELLI': 0,
    'RICCETTI': 0,
    'RICCHETTI': 0,
    'RICCHINI': 0,
    'RICCHIO': 0,
    'RICCHIUTI': 0,
    'RICCHIUTO': 0,
    'RICCI': 0,
    'RICCIARDELLA': 0,
    'RICCIARDELLI': 0,
    'RICCIARDI': 0,
    'RICCIARDO': 0,
    'RICCIARDONE': 0,
    'RICCIARELLI': 0,
    'RICCIO': 0,
    'RICCIOTTI': 0,
    'RICCITELLI': 0,
    'RICCIUTI': 0,
    'RICCO': 0,
    'RICCOBENE': 0,
    'RICCOBONI': 0,
    'RICCOBONO': 0,
    'RICCOMINI': 0,
    'RICE': 0,
    'RICER': 0,
    'RICEVUTO': 0,
    'RICH': 0.2845528455284553,
    'RICHA': 0,
    'RICHADSON': 0,
    'RICHAN': 0,
    'RICHAR': 0,
    'RICHARD': 0.9888028360742153,
    'RICHARDE': 0,
    'RICHARDET': 0,
    'RICHARDI': 0,
    'RICHARDO': 0,
    'RICHARDS': 0,
    'RICHARDSON': 0,
    'RICHARDT': 0,
    'RICHARDVILLE': 0,
    'RICHARS': 0,
    'RICHARSON': 0,
    'RICHART': 0,
    'RICHARTE': 0,
    'RICHARTZ': 0,
    'RICHARZ': 0,
    'RICHASON': 0,
    'RICHAU': 0,
    'RICHBERG': 0,
    'RICHBOURG': 0,
    'RICHBOW': 0,
    'RICHBURG': 0,
    'RICHCREEK': 0,
    'RICHE': 0,
    'RICHEAL': 0,
    'RICHEL': 0,
    'RICHELIEU': 0,
    'RICHELLE': 1,
    'RICHELSON': 0,
    'RICHEMOND': 0,
    'RICHEN': 0,
    'RICHENBERG': 0,
    'RICHENDOLLAR': 0,
    'RICHENS': 0,
    'RICHER': 0,
    'RICHERDSON': 0,
    'RICHERS': 0,
    'RICHERSON': 0,
    'RICHERT': 0,
    'RICHES': 0,
    'RICHESIN': 0,
    'RICHESON': 0,
    'RICHETTI': 0,
    'RICHEY': 0,
    'RICHFIELD': 0,
    'RICHFORD': 0,
    'RICHGELS': 0,
    'RICHHART': 0,
    'RICHICHI': 0,
    'RICHIE': 0.6596306068601584,
    'RICHIEZ': 0,
    'RICHINS': 0,
    'RICHISON': 0,
    'RICHKO': 0,
    'RICHLAND': 0,
    'RICHLEN': 0,
    'RICHLEY': 0,
    'RICHLIN': 0,
    'RICHLINE': 0,
    'RICHLING': 0,
    'RICHMAN': 0,
    'RICHMANN': 0,
    'RICHMEIER': 0,
    'RICHMER': 0,
    'RICHMON': 0,
    'RICHMOND': 0,
    'RICHNER': 0,
    'RICHO': 0,
    'RICHOTTE': 0,
    'RICHOUX': 0,
    'RICHSON': 0,
    'RICHT': 0,
    'RICHTER': 0,
    'RICHTERS': 0,
    'RICHTMYER': 0,
    'RICHTSMEIER': 0,
    'RICHWALSKI': 0,
    'RICHWINE': 0,
    'RICHY': 0,
    'RICIGLIANO': 0,
    'RICK': 0.9793370641411967,
    'RICKABAUGH': 0,
    'RICKABY': 0,
    'RICKARD': 0,
    'RICKARDS': 0,
    'RICKART': 0,
    'RICKE': 0,
    'RICKEL': 0,
    'RICKELMAN': 0,
    'RICKELS': 0,
    'RICKEN': 0,
    'RICKENBACH': 0,
    'RICKENBACKER': 0,
    'RICKENBAKER': 0,
    'RICKENBAUGH': 0,
    'RICKENBERG': 0,
    'RICKENBRODE': 0,
    'RICKENS': 0,
    'RICKER': 0,
    'RICKERD': 0,
    'RICKERL': 0,
    'RICKERMAN': 0,
    'RICKERS': 0,
    'RICKERSON': 0,
    'RICKERT': 0,
    'RICKERTSEN': 0,
    'RICKET': 0,
    'RICKETS': 0,
    'RICKETSON': 0,
    'RICKETT': 0,
    'RICKETTS': 0,
    'RICKEY': 0.9733036707452725,
    'RICKFORD': 0,
    'RICKHOFF': 0,
    'RICKI': 1,
    'RICKIE': 1,
    'RICKLE': 0,
    'RICKLEFS': 0,
    'RICKLES': 0,
    'RICKLEY': 0,
    'RICKLI': 0,
    'RICKMAN': 0,
    'RICKMON': 0,
    'RICKNER': 0,
    'RICKRODE': 0,
    'RICKS': 0,
    'RICKSECKER': 0,
    'RICKSON': 0,
    'RICKUS': 0,
    'RICKY': 0.9995746490854956,
    'RICO': 0.46332046332046334,
    'RICONDO': 0,
    'RICORD': 0,
    'RICOTTA': 0,
    'RICOTTILLI': 0,
    'RICOY': 0,
    'RICTOR': 0,
    'RICUCCI': 0,
    'RICUPERO': 0,
    'RIDA': 0,
    'RIDALL': 0,
    'RIDD': 0,
    'RIDDEL': 0,
    'RIDDELL': 0,
    'RIDDER': 0,
    'RIDDERHOFF': 0,
    'RIDDERING': 0,
    'RIDDICK': 0,
    'RIDDIOUGH': 0,
    'RIDDLE': 0,
    'RIDDLEBARGER': 0,
    'RIDDLEBERGER': 0,
    'RIDDLES': 0,
    'RIDDLESPERGER': 0,
    'RIDDLEY': 0,
    'RIDEAU': 0,
    'RIDEAUX': 0,
    'RIDEL': 0,
    'RIDEN': 0,
    'RIDENBAUGH': 0,
    'RIDENER': 0,
    'RIDENHOUR': 0,
    'RIDENOUR': 0,
    'RIDENS': 0,
    'RIDEOUT': 0,
    'RIDER': 0,
    'RIDGE': 0,
    'RIDGEL': 0,
    'RIDGELL': 0,
    'RIDGELY': 0,
    'RIDGES': 0,
    'RIDGEWAY': 0,
    'RIDGEWELL': 0,
    'RIDGILL': 0,
    'RIDGLE': 0,
    'RIDGLEY': 0,
    'RIDGWAY': 0,
    'RIDILLA': 0,
    'RIDING': 0,
    'RIDINGER': 0,
    'RIDINGS': 0,
    'RIDL': 0,
    'RIDLE': 0,
    'RIDLEHOOVER': 0,
    'RIDLEHUBER': 0,
    'RIDLEN': 0,
    'RIDLER': 0,
    'RIDLEY': 0,
    'RIDLING': 0,
    'RIDLON': 0,
    'RIDNER': 0,
    'RIDNOUR': 0,
    'RIDOLFI': 0,
    'RIDOLFO': 0,
    'RIDORE': 0,
    'RIDOUT': 0,
    'RIDPATH': 0,
    'RIDSDALE': 0,
    'RIE': 0,
    'RIEB': 0,
    'RIEBAU': 0,
    'RIEBE': 0,
    'RIEBEL': 0,
    'RIEBELING': 0,
    'RIEBEN': 0,
    'RIEBER': 0,
    'RIEBLI': 0,
    'RIEBLING': 0,
    'RIEBOLD': 0,
    'RIEBOW': 0,
    'RIECH': 0,
    'RIECHEL': 0,
    'RIECHERS': 0,
    'RIECHMAN': 0,
    'RIECHMANN': 0,
    'RIECK': 0,
    'RIECKE': 0,
    'RIECKEN': 0,
    'RIECKENBERG': 0,
    'RIECKER': 0,
    'RIECKERS': 0,
    'RIECKHOFF': 0,
    'RIECKMAN': 0,
    'RIECKMANN': 0,
    'RIECKS': 0,
    'RIED': 0,
    'RIEDE': 0,
    'RIEDEL': 0,
    'RIEDELL': 0,
    'RIEDEMAN': 0,
    'RIEDEMANN': 0,
    'RIEDEN': 0,
    'RIEDER': 0,
    'RIEDERER': 0,
    'RIEDESEL': 0,
    'RIEDINGER': 0,
    'RIEDL': 0,
    'RIEDLE': 0,
    'RIEDLER': 0,
    'RIEDLINGER': 0,
    'RIEDMAN': 0,
    'RIEDMANN': 0,
    'RIEDMILLER': 0,
    'RIEDNER': 0,
    'RIEDY': 0,
    'RIEF': 0,
    'RIEFER': 0,
    'RIEFF': 0,
    'RIEFFEL': 0,
    'RIEFFER': 0,
    'RIEFLER': 0,
    'RIEG': 0,
    'RIEGE': 0,
    'RIEGEL': 0,
    'RIEGELMAN': 0,
    'RIEGER': 0,
    'RIEGERT': 0,
    'RIEGGER': 0,
    'RIEGLE': 0,
    'RIEGLER': 0,
    'RIEGNER': 0,
    'RIEGO': 0,
    'RIEGSECKER': 0,
    'RIEHL': 0,
    'RIEHLE': 0,
    'RIEHM': 0,
    'RIEHN': 0,
    'RIEHS': 0,
    'RIEK': 0,
    'RIEKE': 0,
    'RIEKEN': 0,
    'RIEKENA': 0,
    'RIEKENBERG': 0,
    'RIEKER': 0,
    'RIEKS': 0,
    'RIEL': 0,
    'RIELAND': 0,
    'RIELEY': 0,
    'RIELLO': 0,
    'RIELLY': 0,
    'RIELS': 0,
    'RIELY': 0,
    'RIEM': 0,
    'RIEMAN': 0,
    'RIEMANN': 0,
    'RIEMENSCHNEIDER': 0,
    'RIEMER': 0,
    'RIEMERSMA': 0,
    'RIEN': 0,
    'RIENDEAU': 0,
    'RIENECKER': 0,
    'RIENER': 0,
    'RIENHARDT': 0,
    'RIENIETS': 0,
    'RIENKS': 0,
    'RIENSCHE': 0,
    'RIENSTRA': 0,
    'RIENTS': 0,
    'RIENZI': 0,
    'RIENZO': 0,
    'RIEPE': 0,
    'RIEPENHOFF': 0,
    'RIEPER': 0,
    'RIEPL': 0,
    'RIEPMA': 0,
    'RIER': 0,
    'RIERA': 0,
    'RIERSON': 0,
    'RIES': 0,
    'RIESBECK': 0,
    'RIESBERG': 0,
    'RIESCH': 0,
    'RIESCHICK': 0,
    'RIESCO': 0,
    'RIESE': 0,
    'RIESEL': 0,
    'RIESEN': 0,
    'RIESENBECK': 0,
    'RIESENBERG': 0,
    'RIESENBERGER': 0,
    'RIESER': 0,
    'RIESGO': 0,
    'RIESGRAF': 0,
    'RIESINGER': 0,
    'RIESKE': 0,
    'RIESLAND': 0,
    'RIESMEYER': 0,
    'RIESNER': 0,
    'RIESS': 0,
    'RIESSELMAN': 0,
    'RIESSEN': 0,
    'RIESTENBERG': 0,
    'RIESTER': 0,
    'RIESTERER': 0,
    'RIESTRA': 0,
    'RIESZ': 0,
    'RIETA': 0,
    'RIETEMA': 0,
    'RIETER': 0,
    'RIETH': 0,
    'RIETHER': 0,
    'RIETHMAN': 0,
    'RIETHMILLER': 0,
    'RIETKERK': 0,
    'RIETMAN': 0,
    'RIETMANN': 0,
    'RIETVELD': 0,
    'RIETZ': 0,
    'RIETZKE': 0,
    'RIEVE': 0,
    'RIEVES': 0,
    'RIEVLEY': 0,
    'RIEWE': 0,
    'RIEWER': 0,
    'RIEWERTS': 0,
    'RIEXINGER': 0,
    'RIFAI': 0,
    'RIFE': 0,
    'RIFENBARK': 0,
    'RIFENBERG': 0,
    'RIFENBURG': 0,
    'RIFENBURGH': 0,
    'RIFF': 0,
    'RIFFE': 0,
    'RIFFEE': 0,
    'RIFFEL': 0,
    'RIFFELL': 0,
    'RIFFENBURG': 0,
    'RIFFER': 0,
    'RIFFERT': 0,
    'RIFFEY': 0,
    'RIFFLE': 0,
    'RIFICI': 0,
    'RIFKIN': 0,
    'RIFKIND': 0,
    'RIGA': 0,
    'RIGAL': 0,
    'RIGALI': 0,
    'RIGANO': 0,
    'RIGAS': 0,
    'RIGATTI': 0,
    'RIGAUD': 0,
    'RIGAZIO': 0,
    'RIGBY': 0,
    'RIGDEN': 0,
    'RIGDON': 0,
    'RIGEL': 0,
    'RIGELMAN': 0,
    'RIGER': 0,
    'RIGERT': 0,
    'RIGG': 0,
    'RIGGALL': 0,
    'RIGGAN': 0,
    'RIGGANS': 0,
    'RIGGAR': 0,
    'RIGGEN': 0,
    'RIGGENBACH': 0,
    'RIGGENS': 0,
    'RIGGER': 0,
    'RIGGERS': 0,
    'RIGGERT': 0,
    'RIGGI': 0,
    'RIGGIE': 0,
    'RIGGIN': 0,
    'RIGGINS': 0,
    'RIGGIO': 0,
    'RIGGLE': 0,
    'RIGGLEMAN': 0,
    'RIGGLES': 0,
    'RIGGOTT': 0,
    'RIGGS': 0,
    'RIGGSBEE': 0,
    'RIGGSBY': 0,
    'RIGHETTI': 0,
    'RIGHI': 0,
    'RIGHTER': 0,
    'RIGHTLEY': 0,
    'RIGHTMER': 0,
    'RIGHTMIRE': 0,
    'RIGHTMYER': 0,
    'RIGHTNOUR': 0,
    'RIGHTNOWAR': 0,
    'RIGHTSELL': 0,
    'RIGLER': 0,
    'RIGLEY': 0,
    'RIGLING': 0,
    'RIGMAIDEN': 0,
    'RIGNEY': 0,
    'RIGO': 0,
    'RIGOBERTO': 1,
    'RIGOLI': 0,
    'RIGONI': 0,
    'RIGOPOULOS': 0,
    'RIGOR': 0,
    'RIGOS': 0,
    'RIGOT': 0,
    'RIGOTTI': 0,
    'RIGOULOT': 0,
    'RIGSBEE': 0,
    'RIGSBY': 0,
    'RIGTERINK': 0,
    'RIGTRUP': 0,
    'RIGUAL': 0,
    'RIHA': 0,
    'RIHANI': 0,
    'RIHEL': 0,
    'RIHERD': 0,
    'RIHM': 0,
    'RIHN': 0,
    'RIHNER': 0,
    'RIINA': 0,
    'RIIS': 0,
    'RIJO': 0,
    'RIJOS': 0,
    'RIKARD': 0,
    'RIKE': 0,
    'RIKER': 0,
    'RIKKERS': 0,
    'RIKKI': 1,
    'RIKLI': 0,
    'RILAND': 0,
    'RILE': 0,
    'RILEA': 0,
    'RILEE': 0,
    'RILES': 0,
    'RILEY': 0.17412502176562772,
    'RILING': 0,
    'RILL': 0,
    'RILLAMAS': 0,
    'RILLERA': 0,
    'RILLEY': 0,
    'RILLING': 0,
    'RILLO': 0,
    'RIM': 0,
    'RIMA': 0.8333333333333334,
    'RIMAL': 0,
    'RIMANDO': 0,
    'RIMAR': 0,
    'RIMAS': 0,
    'RIMAWI': 0,
    'RIMBACH': 0,
    'RIMBERT': 0,
    'RIMBEY': 0,
    'RIME': 0,
    'RIMEL': 0,
    'RIMER': 0,
    'RIMES': 0,
    'RIMINGTON': 0,
    'RIMKUS': 0,
    'RIMLAND': 0,
    'RIMLER': 0,
    'RIMLINGER': 0,
    'RIMM': 0,
    'RIMMEL': 0,
    'RIMMELE': 0,
    'RIMMER': 0,
    'RIMMEY': 0,
    'RIMOLDI': 0,
    'RIMPEL': 0,
    'RIMPSON': 0,
    'RIMSKY': 0,
    'RIMSON': 0,
    'RIN': 0,
    'RINA': 0.9803921568627452,
    'RINACA': 0,
    'RINALDI': 0,
    'RINALDO': 0,
    'RINAMAN': 0,
    'RINARD': 0,
    'RINAS': 0,
    'RINAUDO': 0,
    'RINCHIUSO': 0,
    'RINCK': 0,
    'RINCKER': 0,
    'RINCKEY': 0,
    'RINCON': 0,
    'RINCONES': 0,
    'RIND': 0,
    'RINDA': 0,
    'RINDAHL': 0,
    'RINDAL': 0,
    'RINDE': 0,
    'RINDELS': 0,
    'RINDER': 0,
    'RINDERER': 0,
    'RINDERKNECHT': 0,
    'RINDERLE': 0,
    'RINDFLEISCH': 0,
    'RINDFUSS': 0,
    'RINDLER': 0,
    'RINDLISBACHER': 0,
    'RINDONE': 0,
    'RINDOS': 0,
    'RINDT': 0,
    'RINDY': 0,
    'RINE': 0,
    'RINEAR': 0,
    'RINEARSON': 0,
    'RINEBOLD': 0,
    'RINECK': 0,
    'RINEER': 0,
    'RINEHARDT': 0,
    'RINEHART': 0,
    'RINEHEART': 0,
    'RINEHIMER': 0,
    'RINEHOLD': 0,
    'RINEHOLT': 0,
    'RINELL': 0,
    'RINELLA': 0,
    'RINELLI': 0,
    'RINEMAN': 0,
    'RINER': 0,
    'RINES': 0,
    'RINESMITH': 0,
    'RINESS': 0,
    'RINEY': 0,
    'RINFRET': 0,
    'RING': 0,
    'RINGDAHL': 0,
    'RINGE': 0,
    'RINGEISEN': 0,
    'RINGEL': 0,
    'RINGELBERG': 0,
    'RINGELSTETTER': 0,
    'RINGEN': 0,
    'RINGENBACH': 0,
    'RINGENBERG': 0,
    'RINGER': 0,
    'RINGERING': 0,
    'RINGGENBERG': 0,
    'RINGGER': 0,
    'RINGGOLD': 0,
    'RINGHAM': 0,
    'RINGHAND': 0,
    'RINGHAUSEN': 0,
    'RINGHOFER': 0,
    'RINGHOLZ': 0,
    'RINGKAMP': 0,
    'RINGLAND': 0,
    'RINGLE': 0,
    'RINGLEIN': 0,
    'RINGLER': 0,
    'RINGLEY': 0,
    'RINGLING': 0,
    'RINGMAN': 0,
    'RINGO': 0,
    'RINGOLD': 0,
    'RINGOR': 0,
    'RINGQUIST': 0,
    'RINGROSE': 0,
    'RINGS': 0,
    'RINGSTAD': 0,
    'RINGSTAFF': 0,
    'RINGSTROM': 0,
    'RINGUETTE': 0,
    'RINGWALD': 0,
    'RINGWALT': 0,
    'RINGWELSKI': 0,
    'RINGWOOD': 0,
    'RINI': 0,
    'RINIER': 0,
    'RINIKER': 0,
    'RININGER': 0,
    'RINK': 0,
    'RINKA': 0,
    'RINKE': 0,
    'RINKEL': 0,
    'RINKENBERGER': 0,
    'RINKER': 0,
    'RINKES': 0,
    'RINKLE': 0,
    'RINKO': 0,
    'RINKS': 0,
    'RINKUS': 0,
    'RINN': 0,
    'RINNA': 0,
    'RINNE': 0,
    'RINNELS': 0,
    'RINNER': 0,
    'RINNERT': 0,
    'RINO': 0,
    'RINTA': 0,
    'RINTALA': 0,
    'RINTAMAKI': 0,
    'RINTOUL': 0,
    'RINTZ': 0,
    'RINZ': 0,
    'RINZEL': 0,
    'RINZLER': 0,
    'RIO': 0,
    'RIOFRIO': 0,
    'RIOJA': 0,
    'RIOJAS': 0,
    'RIOLA': 0,
    'RIOLLANO': 0,
    'RIOLO': 0,
    'RION': 0,
    'RIONDA': 0,
    'RIOPEL': 0,
    'RIOPELLE': 0,
    'RIORDAN': 0,
    'RIORDON': 0,
    'RIOS': 0,
    'RIOSECO': 0,
    'RIOTTO': 0,
    'RIOU': 0,
    'RIOUS': 0,
    'RIOUX': 0,
    'RIOZ': 0,
    'RIPA': 0,
    'RIPALDA': 0,
    'RIPANI': 0,
    'RIPBERGER': 0,
    'RIPEPI': 0,
    'RIPKA': 0,
    'RIPKE': 0,
    'RIPKOWSKI': 0,
    'RIPLEY': 0,
    'RIPOLI': 0,
    'RIPOLL': 0,
    'RIPORTELLA': 0,
    'RIPP': 0,
    'RIPPA': 0,
    'RIPPBERGER': 0,
    'RIPPE': 0,
    'RIPPEE': 0,
    'RIPPEL': 0,
    'RIPPEN': 0,
    'RIPPENTROP': 0,
    'RIPPEON': 0,
    'RIPPER': 0,
    'RIPPERDA': 0,
    'RIPPERGER': 0,
    'RIPPERT': 0,
    'RIPPETH': 0,
    'RIPPETO': 0,
    'RIPPETOE': 0,
    'RIPPEY': 0,
    'RIPPIE': 0,
    'RIPPIN': 0,
    'RIPPLE': 0,
    'RIPPLEY': 0,
    'RIPPLINGER': 0,
    'RIPPON': 0,
    'RIPPS': 0,
    'RIPPSTEIN': 0,
    'RIPPY': 0,
    'RIPS': 0,
    'RIQUELME': 0,
    'RIQUIER': 0,
    'RIRIE': 0,
    'RIS': 0,
    'RISA': 0.9756097560975611,
    'RISACHER': 0,
    'RISBERG': 0,
    'RISBON': 0,
    'RISBY': 0,
    'RISCH': 0,
    'RISCHAR': 0,
    'RISCHE': 0,
    'RISCHER': 0,
    'RISCO': 0,
    'RISDAL': 0,
    'RISDEN': 0,
    'RISDON': 0,
    'RISE': 0,
    'RISEDEN': 0,
    'RISELING': 0,
    'RISEMAN': 0,
    'RISEN': 0,
    'RISENER': 0,
    'RISENHOOVER': 0,
    'RISER': 0,
    'RISH': 0,
    'RISHA': 0,
    'RISHE': 0,
    'RISHEL': 0,
    'RISHELL': 0,
    'RISHER': 0,
    'RISHI': 0,
    'RISHTY': 0,
    'RISI': 0,
    'RISING': 0,
    'RISINGER': 0,
    'RISIUS': 0,
    'RISK': 0,
    'RISKA': 0,
    'RISKE': 0,
    'RISKEY': 0,
    'RISKIN': 0,
    'RISKO': 0,
    'RISKUS': 0,
    'RISLER': 0,
    'RISLEY': 0,
    'RISMAN': 0,
    'RISMILLER': 0,
    'RISNER': 0,
    'RISO': 0,
    'RISOLA': 0,
    'RISOLDI': 0,
    'RISOLI': 0,
    'RISON': 0,
    'RISOR': 0,
    'RISPER': 0,
    'RISPO': 0,
    'RISPOLI': 0,
    'RISS': 0,
    'RISSANEN': 0,
    'RISSE': 0,
    'RISSEEUW': 0,
    'RISSEL': 0,
    'RISSELL': 0,
    'RISSER': 0,
    'RISSI': 0,
    'RISSINGER': 0,
    'RISSLER': 0,
    'RISSMAN': 0,
    'RISSMANN': 0,
    'RISSMILLER': 0,
    'RISSO': 0,
    'RIST': 0,
    'RISTAINO': 0,
    'RISTAU': 0,
    'RISTE': 0,
    'RISTEEN': 0,
    'RISTER': 0,
    'RISTIC': 0,
    'RISTICH': 0,
    'RISTICK': 0,
    'RISTINE': 0,
    'RISTON': 0,
    'RISTOVSKI': 0,
    'RISTOW': 0,
    'RISTUCCIA': 0,
    'RISTY': 0,
    'RISUCCI': 0,
    'RISVOLD': 0,
    'RITA': 0.9977989728539984,
    'RITACCO': 0,
    'RITARI': 0,
    'RITCH': 0,
    'RITCHART': 0,
    'RITCHASON': 0,
    'RITCHEA': 0,
    'RITCHEL': 0,
    'RITCHER': 0,
    'RITCHESON': 0,
    'RITCHEY': 0,
    'RITCHHART': 0,
    'RITCHIE': 0,
    'RITCHINGS': 0,
    'RITCHISON': 0,
    'RITCHOTTE': 0,
    'RITENOUR': 0,
    'RITER': 0,
    'RITGER': 0,
    'RITH': 0,
    'RITI': 0,
    'RITLAND': 0,
    'RITMAN': 0,
    'RITNER': 0,
    'RITO': 0,
    'RITOLA': 0,
    'RITORTO': 0,
    'RITROVATO': 0,
    'RITSCH': 0,
    'RITSCHARD': 0,
    'RITSCHEL': 0,
    'RITSCHER': 0,
    'RITSEMA': 0,
    'RITSICK': 0,
    'RITSON': 0,
    'RITT': 0,
    'RITTBERG': 0,
    'RITTEL': 0,
    'RITTEN': 0,
    'RITTENBACH': 0,
    'RITTENBERG': 0,
    'RITTENBERRY': 0,
    'RITTENBURG': 0,
    'RITTENHOUSE': 0,
    'RITTENOUR': 0,
    'RITTER': 0,
    'RITTERBECK': 0,
    'RITTERBUSCH': 0,
    'RITTERBUSH': 0,
    'RITTERMAN': 0,
    'RITTERSDORF': 0,
    'RITTERSON': 0,
    'RITTGERS': 0,
    'RITTHALER': 0,
    'RITTINGER': 0,
    'RITTLE': 0,
    'RITTLER': 0,
    'RITTMAN': 0,
    'RITTMANN': 0,
    'RITTMEYER': 0,
    'RITTMILLER': 0,
    'RITTNER': 0,
    'RITTS': 0,
    'RITTWEGER': 0,
    'RITUCCI': 0,
    'RITZ': 0,
    'RITZE': 0,
    'RITZEL': 0,
    'RITZEMA': 0,
    'RITZENTHALER': 0,
    'RITZER': 0,
    'RITZERT': 0,
    'RITZHEIMER': 0,
    'RITZI': 0,
    'RITZIE': 0,
    'RITZINGER': 0,
    'RITZLER': 0,
    'RITZMAN': 0,
    'RITZMANN': 0,
    'RITZO': 0,
    'RIUS': 0,
    'RIUTTA': 0,
    'RIVA': 0.6944444444444444,
    'RIVADENEIRA': 0,
    'RIVADENEYRA': 0,
    'RIVAL': 0,
    'RIVALDO': 0,
    'RIVARA': 0,
    'RIVARD': 0,
    'RIVAS': 0,
    'RIVEIRA': 0,
    'RIVEIRO': 0,
    'RIVELA': 0,
    'RIVELAND': 0,
    'RIVELL': 0,
    'RIVELLI': 0,
    'RIVELLO': 0,
    'RIVEN': 0,
    'RIVENBARK': 0,
    'RIVENBURG': 0,
    'RIVENBURGH': 0,
    'RIVENS': 0,
    'RIVER': 0,
    'RIVERA': 0,
    'RIVERAGARCIA': 0,
    'RIVERAGONZALEZ': 0,
    'RIVERALOPEZ': 0,
    'RIVERAMARTINEZ': 0,
    'RIVERAPEREZ': 0,
    'RIVERARIVERA': 0,
    'RIVERARODRIGUE': 0,
    'RIVERATORRES': 0,
    'RIVERE': 0,
    'RIVERO': 0,
    'RIVEROL': 0,
    'RIVERON': 0,
    'RIVEROS': 0,
    'RIVERS': 0,
    'RIVERSO': 0,
    'RIVES': 0,
    'RIVEST': 0,
    'RIVET': 0,
    'RIVETT': 0,
    'RIVETTE': 0,
    'RIVETTI': 0,
    'RIVIECCIO': 0,
    'RIVIELLO': 0,
    'RIVIERA': 0,
    'RIVIERE': 0,
    'RIVIEZZO': 0,
    'RIVIN': 0,
    'RIVINIUS': 0,
    'RIVIRA': 0,
    'RIVITUSO': 0,
    'RIVKA': 1,
    'RIVKIN': 0,
    'RIVKIND': 0,
    'RIVLIN': 0,
    'RIVOIRE': 0,
    'RIVOLI': 0,
    'RIVORD': 0,
    'RIX': 0,
    'RIXEN': 0,
    'RIXEY': 0,
    'RIXFORD': 0,
    'RIXIE': 0,
    'RIXNER': 0,
    'RIXON': 0,
    'RIZ': 0,
    'RIZA': 0,
    'RIZEK': 0,
    'RIZER': 0,
    'RIZIK': 0,
    'RIZIO': 0,
    'RIZK': 0,
    'RIZKALLA': 0,
    'RIZKALLAH': 0,
    'RIZNER': 0,
    'RIZO': 0,
    'RIZOR': 0,
    'RIZOS': 0,
    'RIZUI': 0,
    'RIZVANOVIC': 0,
    'RIZVI': 0,
    'RIZVIC': 0,
    'RIZWAN': 0,
    'RIZZA': 0,
    'RIZZARDI': 0,
    'RIZZI': 0,
    'RIZZIO': 0,
    'RIZZITANO': 0,
    'RIZZITELLO': 0,
    'RIZZO': 0,
    'RIZZOLO': 0,
    'RIZZOTTI': 0,
    'RIZZOTTO': 0,
    'RIZZUTI': 0,
    'RIZZUTO': 0,
    'RO': 0,
    'ROA': 0,
    'ROACH': 0,
    'ROACHE': 0,
    'ROACHELL': 0,
    'ROACHFORD': 0,
    'ROACHO': 0,
    'ROAD': 0,
    'ROADARMEL': 0,
    'ROADCAP': 0,
    'ROADEN': 0,
    'ROADES': 0,
    'ROADHOUSE': 0,
    'ROADIFER': 0,
    'ROADMAN': 0,
    'ROADRUCK': 0,
    'ROADS': 0,
    'ROADY': 0,
    'ROAF': 0,
    'ROAHRIG': 0,
    'ROAK': 0,
    'ROAKE': 0,
    'ROAKES': 0,
    'ROAM': 0,
    'ROAN': 0,
    'ROANE': 0,
    'ROANHORSE': 0,
    'ROAR': 0,
    'ROARK': 0,
    'ROARKE': 0,
    'ROARTY': 0,
    'ROARY': 0,
    'ROAT': 0,
    'ROATCH': 0,
    'ROATE': 0,
    'ROATEN': 0,
    'ROATH': 0,
    'ROB': 0.9900990099009901,
    'ROBA': 0,
    'ROBACH': 0,
    'ROBACK': 0,
    'ROBACKER': 0,
    'ROBAINA': 0,
    'ROBAIR': 0,
    'ROBAK': 0,
    'ROBALINO': 0,
    'ROBANCHO': 0,
    'ROBAR': 0,
    'ROBARDS': 0,
    'ROBARE': 0,
    'ROBARGE': 0,
    'ROBART': 0,
    'ROBARTS': 0,
    'ROBATEAU': 0,
    'ROBAYO': 0,
    'ROBB': 0,
    'ROBBA': 0,
    'ROBBE': 0,
    'ROBBEN': 0,
    'ROBBENNOLT': 0,
    'ROBBERS': 0,
    'ROBBERSON': 0,
    'ROBBERT': 0,
    'ROBBERTS': 0,
    'ROBBI': 1,
    'ROBBIE': 0.9960760639903411,
    'ROBBIN': 0.9722222222222223,
    'ROBBINS': 0,
    'ROBBINSON': 0,
    'ROBBIO': 0,
    'ROBBLEE': 0,
    'ROBBS': 0,
    'ROBBY': 1,
    'ROBBYN': 1,
    'ROBE': 0,
    'ROBEAU': 0,
    'ROBECK': 0,
    'ROBEDEAU': 0,
    'ROBEL': 0,
    'ROBELEN': 0,
    'ROBELIA': 0,
    'ROBELL': 0,
    'ROBELLO': 0,
    'ROBELO': 0,
    'ROBEN': 0,
    'ROBENA': 1,
    'ROBENALT': 0,
    'ROBENOLT': 0,
    'ROBENS': 0,
    'ROBENSON': 0,
    'ROBER': 0,
    'ROBERDS': 0,
    'ROBERG': 0,
    'ROBERGE': 0,
    'ROBERIE': 0,
    'ROBERS': 0,
    'ROBERSHAW': 0,
    'ROBERSON': 0,
    'ROBERT': 0.9985739185549041,
    'ROBERTA': 0.9990607121509691,
    'ROBERTAZZI': 0,
    'ROBERTE': 0,
    'ROBERTELLO': 0,
    'ROBERTI': 0,
    'ROBERTIELLO': 0,
    'ROBERTO': 0.9868089819756318,
    'ROBERTON': 0,
    'ROBERTS': 0,
    'ROBERTSHAW': 0,
    'ROBERTSON': 0,
    'ROBERTUS': 0,
    'ROBES': 0,
    'ROBESON': 0,
    'ROBETS': 0,
    'ROBETSON': 0,
    'ROBEY': 0,
    'ROBI': 0,
    'ROBICH': 0,
    'ROBICHAU': 0,
    'ROBICHAUD': 0,
    'ROBICHAUX': 0,
    'ROBICHEAU': 0,
    'ROBICHEAUX': 0,
    'ROBIDA': 0,
    'ROBIDAS': 0,
    'ROBIDEAU': 0,
    'ROBIDEAUX': 0,
    'ROBIDOU': 0,
    'ROBIDOUX': 0,
    'ROBIE': 0,
    'ROBIES': 0,
    'ROBILLARD': 0,
    'ROBILOTTA': 0,
    'ROBILOTTO': 0,
    'ROBIN': 0.9919404835709857,
    'ROBINE': 0,
    'ROBINET': 0,
    'ROBINETT': 0,
    'ROBINETTE': 0,
    'ROBINO': 0,
    'ROBINS': 0,
    'ROBINSON': 0,
    'ROBINZINE': 0,
    'ROBIRDS': 0,
    'ROBISCH': 0,
    'ROBISHAW': 0,
    'ROBISON': 0,
    'ROBITAILLE': 0,
    'ROBITZSCH': 0,
    'ROBKE': 0,
    'ROBL': 0,
    'ROBLE': 0,
    'ROBLEDO': 0,
    'ROBLEE': 0,
    'ROBLERO': 0,
    'ROBLES': 0,
    'ROBLETO': 0,
    'ROBLEY': 0,
    'ROBLEZ': 0,
    'ROBLIN': 0,
    'ROBLING': 0,
    'ROBLYER': 0,
    'ROBNETT': 0,
    'ROBOTHAM': 0,
    'ROBOTTI': 0,
    'ROBRAHN': 0,
    'ROBRECHT': 0,
    'ROBSHAW': 0,
    'ROBSON': 0,
    'ROBT': 1,
    'ROBTOY': 0,
    'ROBUCK': 0,
    'ROBUS': 0,
    'ROBUSTELLI': 0,
    'ROBUSTO': 0,
    'ROBY': 0,
    'ROBYN': 0.9971874200971618,
    'ROC': 0,
    'ROCA': 0,
    'ROCABADO': 0,
    'ROCAFORT': 0,
    'ROCAMONTES': 0,
    'ROCAMORA': 0,
    'ROCAP': 0,
    'ROCCA': 0,
    'ROCCAFORTE': 0,
    'ROCCANOVA': 0,
    'ROCCHI': 0,
    'ROCCHIO': 0,
    'ROCCI': 0,
    'ROCCIA': 0,
    'ROCCIO': 0,
    'ROCCO': 0.8227374719521315,
    'ROCCONI': 0,
    'ROCES': 0,
    'ROCH': 0,
    'ROCHA': 0,
    'ROCHAT': 0,
    'ROCHE': 0,
    'ROCHEFORD': 0,
    'ROCHEFORT': 0,
    'ROCHEL': 0.8547008547008547,
    'ROCHELEAU': 0,
    'ROCHELL': 0.9132420091324202,
    'ROCHELLE': 0.9615384615384616,
    'ROCHER': 0,
    'ROCHES': 0,
    'ROCHESTER': 0,
    'ROCHET': 0,
    'ROCHETTE': 0,
    'ROCHEZ': 0,
    'ROCHFORD': 0,
    'ROCHHOLZ': 0,
    'ROCHIN': 0,
    'ROCHKIND': 0,
    'ROCHLIN': 0,
    'ROCHLITZ': 0,
    'ROCHMAN': 0,
    'ROCHO': 0,
    'ROCHON': 0,
    'ROCHOW': 0,
    'ROCHOWIAK': 0,
    'ROCHTE': 0,
    'ROCIO': 0.9852216748768473,
    'ROCK': 0,
    'ROCKA': 0,
    'ROCKAFELLOW': 0,
    'ROCKE': 0,
    'ROCKEFELLER': 0,
    'ROCKEL': 0,
    'ROCKENBACH': 0,
    'ROCKENBAUGH': 0,
    'ROCKENSTEIN': 0,
    'ROCKER': 0,
    'ROCKERS': 0,
    'ROCKETT': 0,
    'ROCKETTE': 0,
    'ROCKEY': 0,
    'ROCKFORD': 0,
    'ROCKHILL': 0,
    'ROCKHOLD': 0,
    'ROCKHOLT': 0,
    'ROCKINGHAM': 0,
    'ROCKLEIN': 0,
    'ROCKLEY': 0,
    'ROCKLIN': 0,
    'ROCKMAN': 0,
    'ROCKMORE': 0,
    'ROCKNE': 0,
    'ROCKNEY': 0,
    'ROCKOFF': 0,
    'ROCKOW': 0,
    'ROCKOWER': 0,
    'ROCKOWITZ': 0,
    'ROCKS': 0,
    'ROCKSTAD': 0,
    'ROCKSTROH': 0,
    'ROCKWEILER': 0,
    'ROCKWELL': 0,
    'ROCKWOOD': 0,
    'ROCKY': 0.9962640099626402,
    'ROCKYMORE': 0,
    'ROCO': 0,
    'ROCQUE': 0,
    'ROCQUEMORE': 0,
    'ROD': 0.9651076466221232,
    'RODA': 0,
    'RODABAUGH': 0,
    'RODACK': 0,
    'RODACKER': 0,
    'RODAHL': 0,
    'RODAK': 0,
    'RODAL': 0,
    'RODAMAKER': 0,
    'RODAMMER': 0,
    'RODAN': 0,
    'RODANO': 0,
    'RODARMEL': 0,
    'RODARTE': 0,
    'RODAS': 0,
    'RODBELL': 0,
    'RODBERG': 0,
    'RODD': 0,
    'RODDA': 0,
    'RODDAM': 0,
    'RODDE': 0,
    'RODDEN': 0,
    'RODDENBERRY': 0,
    'RODDEWIG': 0,
    'RODDEY': 0,
    'RODDICK': 0,
    'RODDIE': 0,
    'RODDY': 0,
    'RODE': 0,
    'RODEA': 0,
    'RODEBACK': 0,
    'RODEBAUGH': 0,
    'RODEBUSH': 0,
    'RODECAP': 0,
    'RODECK': 0,
    'RODECKER': 0,
    'RODEEN': 0,
    'RODEFELD': 0,
    'RODEFER': 0,
    'RODEFFER': 0,
    'RODEGHERO': 0,
    'RODEGHIER': 0,
    'RODEGHIERO': 0,
    'RODEHAVER': 0,
    'RODEHEAVER': 0,
    'RODEHEFFER': 0,
    'RODEHORST': 0,
    'RODEL': 0,
    'RODELA': 0,
    'RODELAS': 0,
    'RODELL': 0,
    'RODELLA': 0,
    'RODELO': 0,
    'RODEMAN': 0,
    'RODEMEYER': 0,
    'RODEMOYER': 0,
    'RODEMS': 0,
    'RODEN': 0,
    'RODENAS': 0,
    'RODENBACH': 0,
    'RODENBAUGH': 0,
    'RODENBECK': 0,
    'RODENBERG': 0,
    'RODENBERGER': 0,
    'RODENBORN': 0,
    'RODENBOUGH': 0,
    'RODENBURG': 0,
    'RODENCAL': 0,
    'RODENHAUSER': 0,
    'RODENHISER': 0,
    'RODENHIZER': 0,
    'RODENHOUSE': 0,
    'RODENKIRCH': 0,
    'RODER': 0,
    'RODERER': 0,
    'RODERICK': 0.9338521400778209,
    'RODERICKS': 0,
    'RODERIGUES': 0,
    'RODERIGUEZ': 0,
    'RODERIQUE': 0,
    'RODERIQUES': 0,
    'RODERMAN': 0,
    'RODERS': 0,
    'RODERY': 0,
    'RODES': 0,
    'RODEWALD': 0,
    'RODEY': 0,
    'RODEZNO': 0,
    'RODGER': 0.9626274065685164,
    'RODGERS': 0,
    'RODGERSON': 0,
    'RODGES': 0,
    'RODGUEZ': 0,
    'RODI': 0,
    'RODIA': 0,
    'RODIBAUGH': 0,
    'RODICH': 0,
    'RODICK': 0,
    'RODIE': 0,
    'RODIER': 0,
    'RODIG': 0,
    'RODIL': 0,
    'RODILES': 0,
    'RODIN': 0,
    'RODINA': 0,
    'RODINE': 0,
    'RODINO': 0,
    'RODINSON': 0,
    'RODIO': 0,
    'RODIQUEZ': 0,
    'RODIRGUEZ': 0,
    'RODIS': 0,
    'RODISH': 0,
    'RODITIS': 0,
    'RODKEY': 0,
    'RODKIN': 0,
    'RODLAND': 0,
    'RODMAN': 0,
    'RODNER': 0,
    'RODNEY': 0.9870044415199869,
    'RODOCKER': 0,
    'RODOLFO': 0.9976720984369803,
    'RODOLICO': 0,
    'RODOLPH': 0,
    'RODON': 0,
    'RODONI': 0,
    'RODOWICZ': 0,
    'RODREGEZ': 0,
    'RODREGUS': 0,
    'RODREQUEZ': 0,
    'RODRGUEZ': 0,
    'RODRIAN': 0,
    'RODRICK': 0.947867298578199,
    'RODRICKS': 0,
    'RODRIDUEZ': 0,
    'RODRIEGUEZ': 0,
    'RODRIGES': 0,
    'RODRIGEUZ': 0,
    'RODRIGO': 0.9649122807017544,
    'RODRIGOEZ': 0,
    'RODRIGUE': 0,
    'RODRIGUEA': 0,
    'RODRIGUEC': 0,
    'RODRIGUEL': 0,
    'RODRIGUES': 0,
    'RODRIGUEZ': 0,
    'RODRIGUEZCRUZ': 0,
    'RODRIGUEZDIAZ': 0,
    'RODRIGUEZGARCI': 0,
    'RODRIGUEZLOPEZ': 0,
    'RODRIGUEZPEREZ': 0,
    'RODRIGUEZTORRE': 0,
    'RODRIGUZE': 0,
    'RODRIQUE': 0,
    'RODRIQUES': 0,
    'RODRIQUEZ': 0,
    'RODRIUEZ': 0,
    'RODRUGUEZ': 0,
    'RODSTROM': 0,
    'RODTS': 0,
    'RODULFO': 0,
    'RODUNER': 0,
    'RODWAY': 0,
    'RODWELL': 0,
    'RODY': 0,
    'RODZEN': 0,
    'RODZIEWICZ': 0,
    'ROE': 0,
    'ROEBEN': 0,
    'ROEBER': 0,
    'ROEBKE': 0,
    'ROEBLING': 0,
    'ROEBUCK': 0,
    'ROECK': 0,
    'ROECKER': 0,
    'ROED': 0,
    'ROEDE': 0,
    'ROEDEL': 0,
    'ROEDELL': 0,
    'ROEDEMA': 0,
    'ROEDER': 0,
    'ROEDERER': 0,
    'ROEDERSHEIMER': 0,
    'ROEDIG': 0,
    'ROEDIGER': 0,
    'ROEDING': 0,
    'ROEDL': 0,
    'ROEGER': 0,
    'ROEGGE': 0,
    'ROEGIERS': 0,
    'ROEGLIN': 0,
    'ROEGNER': 0,
    'ROEHL': 0,
    'ROEHLER': 0,
    'ROEHLING': 0,
    'ROEHM': 0,
    'ROEHNER': 0,
    'ROEHR': 0,
    'ROEHRBORN': 0,
    'ROEHRICH': 0,
    'ROEHRICK': 0,
    'ROEHRIG': 0,
    'ROEHRS': 0,
    'ROEKER': 0,
    'ROEL': 0,
    'ROELAND': 0,
    'ROELFS': 0,
    'ROELING': 0,
    'ROELKE': 0,
    'ROELL': 0,
    'ROELLE': 0,
    'ROELLER': 0,
    'ROELLIG': 0,
    'ROELOFS': 0,
    'ROELOFSEN': 0,
    'ROELS': 0,
    'ROELSE': 0,
    'ROEMBKE': 0,
    'ROEMELING': 0,
    'ROEMEN': 0,
    'ROEMER': 0,
    'ROEMHILD': 0,
    'ROEMHILDT': 0,
    'ROEMISCH': 0,
    'ROEMKE': 0,
    'ROEMMICH': 0,
    'ROEN': 0,
    'ROENFELDT': 0,
    'ROENICKE': 0,
    'ROENIGK': 0,
    'ROENKER': 0,
    'ROENSCH': 0,
    'ROEPCKE': 0,
    'ROEPE': 0,
    'ROEPER': 0,
    'ROEPKE': 0,
    'ROER': 0,
    'ROERICK': 0,
    'ROERIG': 0,
    'ROERING': 0,
    'ROERS': 0,
    'ROES': 0,
    'ROESCH': 0,
    'ROESCHLEIN': 0,
    'ROESE': 0,
    'ROESEL': 0,
    'ROESELER': 0,
    'ROESENER': 0,
    'ROESER': 0,
    'ROESING': 0,
    'ROESKE': 0,
    'ROESLER': 0,
    'ROESLY': 0,
    'ROESNER': 0,
    'ROESS': 0,
    'ROESSEL': 0,
    'ROESSER': 0,
    'ROESSING': 0,
    'ROESSLE': 0,
    'ROESSLEIN': 0,
    'ROESSLER': 0,
    'ROESSNER': 0,
    'ROEST': 0,
    'ROETCISOENDER': 0,
    'ROETERS': 0,
    'ROETH': 0,
    'ROETHE': 0,
    'ROETHEL': 0,
    'ROETHEMEYER': 0,
    'ROETHER': 0,
    'ROETHKE': 0,
    'ROETHLE': 0,
    'ROETHLER': 0,
    'ROETHLISBERGER': 0,
    'ROETKER': 0,
    'ROETMAN': 0,
    'ROETS': 0,
    'ROETTELE': 0,
    'ROETTER': 0,
    'ROETTGEN': 0,
    'ROETTGER': 0,
    'ROETTING': 0,
    'ROETTO': 0,
    'ROETZEL': 0,
    'ROETZER': 0,
    'ROEUN': 0,
    'ROEVER': 0,
    'ROEWE': 0,
    'ROEWER': 0,
    'ROFE': 0,
    'ROFF': 0,
    'ROFFE': 0,
    'ROFFERS': 0,
    'ROFFEY': 0,
    'ROFFLER': 0,
    'ROFFMAN': 0,
    'ROFFO': 0,
    'ROFKAHR': 0,
    'ROFRANO': 0,
    'ROG': 0,
    'ROGACKI': 0,
    'ROGAHN': 0,
    'ROGAL': 0,
    'ROGALA': 0,
    'ROGALINSKI': 0,
    'ROGALLA': 0,
    'ROGALSKI': 0,
    'ROGALSKY': 0,
    'ROGAN': 0,
    'ROGAS': 0,
    'ROGE': 0,
    'ROGEL': 0,
    'ROGELIO': 1,
    'ROGEN': 0,
    'ROGENSKI': 0,
    'ROGER': 0.9946560405276001,
    'ROGERO': 0,
    'ROGERS': 0,
    'ROGERSON': 0,
    'ROGET': 0,
    'ROGG': 0,
    'ROGGE': 0,
    'ROGGEMAN': 0,
    'ROGGEMANN': 0,
    'ROGGENBUCK': 0,
    'ROGGENKAMP': 0,
    'ROGGENSACK': 0,
    'ROGGERO': 0,
    'ROGGIE': 0,
    'ROGGIO': 0,
    'ROGGOW': 0,
    'ROGGY': 0,
    'ROGHAIR': 0,
    'ROGICH': 0,
    'ROGIER': 0,
    'ROGIERS': 0,
    'ROGILLIO': 0,
    'ROGIN': 0,
    'ROGINA': 0,
    'ROGINSKI': 0,
    'ROGINSKY': 0,
    'ROGINSON': 0,
    'ROGISH': 0,
    'ROGLER': 0,
    'ROGLES': 0,
    'ROGMAN': 0,
    'ROGNE': 0,
    'ROGNER': 0,
    'ROGNESS': 0,
    'ROGNEY': 0,
    'ROGNLIE': 0,
    'ROGNLIEN': 0,
    'ROGNON': 0,
    'ROGNSTAD': 0,
    'ROGO': 0,
    'ROGOFF': 0,
    'ROGOSKI': 0,
    'ROGOTZKE': 0,
    'ROGOVIN': 0,
    'ROGOW': 0,
    'ROGOWSKI': 0,
    'ROGOZ': 0,
    'ROGOZINSKI': 0,
    'ROGSTAD': 0,
    'ROGUE': 0,
    'ROGULSKI': 0,
    'ROGUS': 0,
    'ROGUSKI': 0,
    'ROH': 0,
    'ROHA': 0,
    'ROHACH': 0,
    'ROHAL': 0,
    'ROHALEY': 0,
    'ROHALL': 0,
    'ROHALY': 0,
    'ROHAN': 0,
    'ROHANI': 0,
    'ROHANNA': 0,
    'ROHATGI': 0,
    'ROHDE': 0,
    'ROHDY': 0,
    'ROHE': 0,
    'ROHEN': 0,
    'ROHENA': 0,
    'ROHER': 0,
    'ROHL': 0,
    'ROHLA': 0,
    'ROHLAND': 0,
    'ROHLEDER': 0,
    'ROHLER': 0,
    'ROHLF': 0,
    'ROHLFING': 0,
    'ROHLFS': 0,
    'ROHLFSEN': 0,
    'ROHLIK': 0,
    'ROHLIN': 0,
    'ROHLING': 0,
    'ROHLINGER': 0,
    'ROHLK': 0,
    'ROHLMAN': 0,
    'ROHLOFF': 0,
    'ROHLWING': 0,
    'ROHM': 0,
    'ROHMAN': 0,
    'ROHMANN': 0,
    'ROHME': 0,
    'ROHMER': 0,
    'ROHN': 0,
    'ROHNE': 0,
    'ROHNER': 0,
    'ROHOLT': 0,
    'ROHR': 0,
    'ROHRABAUGH': 0,
    'ROHRBACH': 0,
    'ROHRBACHER': 0,
    'ROHRBACK': 0,
    'ROHRBACKER': 0,
    'ROHRBAUGH': 0,
    'ROHRBECK': 0,
    'ROHRBERG': 0,
    'ROHRBOUGH': 0,
    'ROHRDANZ': 0,
    'ROHRER': 0,
    'ROHRET': 0,
    'ROHRICH': 0,
    'ROHRIG': 0,
    'ROHRING': 0,
    'ROHRMAN': 0,
    'ROHRS': 0,
    'ROHRSCHEIB': 0,
    'ROHRSSEN': 0,
    'ROHS': 0,
    'ROHUS': 0,
    'ROHWEDDER': 0,
    'ROHWEDER': 0,
    'ROHWER': 0,
    'ROI': 0,
    'ROICE': 0,
    'ROIG': 0,
    'ROIGER': 0,
    'ROILAND': 0,
    'ROIS': 0,
    'ROISMAN': 0,
    'ROISUM': 0,
    'ROITER': 0,
    'ROITMAN': 0,
    'ROIX': 0,
    'ROIZ': 0,
    'ROJA': 0,
    'ROJAHN': 0,
    'ROJAN': 0,
    'ROJANO': 0,
    'ROJAS': 0,
    'ROJEK': 0,
    'ROJEL': 0,
    'ROJERO': 0,
    'ROJESKI': 0,
    'ROJEWSKI': 0,
    'ROJO': 0,
    'ROJOS': 0,
    'ROK': 0,
    'ROKA': 0,
    'ROKAS': 0,
    'ROKE': 0,
    'ROKER': 0,
    'ROKES': 0,
    'ROKEY': 0,
    'ROKICKI': 0,
    'ROKITA': 0,
    'ROKKE': 0,
    'ROKOS': 0,
    'ROKOSKY': 0,
    'ROKOSZ': 0,
    'ROKOWSKI': 0,
    'ROKUS': 0,
    'ROKUSEK': 0,
    'ROL': 0,
    'ROLA': 0,
    'ROLACK': 0,
    'ROLADER': 0,
    'ROLAIN': 0,
    'ROLAN': 0,
    'ROLAND': 0.9119696010132995,
    'ROLANDA': 1,
    'ROLANDE': 1,
    'ROLANDELLI': 0,
    'ROLANDER': 0,
    'ROLANDO': 0.9845288326300985,
    'ROLANDS': 0,
    'ROLAX': 0,
    'ROLBIECKI': 0,
    'ROLD': 0,
    'ROLDAN': 0,
    'ROLE': 0,
    'ROLEK': 0,
    'ROLEN': 0,
    'ROLENS': 0,
    'ROLER': 0,
    'ROLES': 0,
    'ROLEWICZ': 0,
    'ROLEY': 0,
    'ROLF': 0.8196721311475409,
    'ROLFE': 0,
    'ROLFES': 0,
    'ROLFING': 0,
    'ROLFS': 0,
    'ROLFSEN': 0,
    'ROLFSMEYER': 0,
    'ROLFSON': 0,
    'ROLFZEN': 0,
    'ROLIN': 0,
    'ROLING': 0,
    'ROLINSKI': 0,
    'ROLISON': 0,
    'ROLKA': 0,
    'ROLKE': 0,
    'ROLL': 0,
    'ROLLA': 0,
    'ROLLAG': 0,
    'ROLLAN': 0,
    'ROLLAND': 0.8250825082508251,
    'ROLLANS': 0,
    'ROLLASON': 0,
    'ROLLE': 0,
    'ROLLEFSON': 0,
    'ROLLEN': 0,
    'ROLLENHAGEN': 0,
    'ROLLER': 0,
    'ROLLERI': 0,
    'ROLLERSON': 0,
    'ROLLERT': 0,
    'ROLLES': 0,
    'ROLLESTON': 0,
    'ROLLET': 0,
    'ROLLETT': 0,
    'ROLLEY': 0,
    'ROLLF': 0,
    'ROLLHEISER': 0,
    'ROLLI': 0,
    'ROLLICK': 0,
    'ROLLIE': 0,
    'ROLLIN': 0,
    'ROLLING': 0,
    'ROLLINGER': 0,
    'ROLLINGS': 0,
    'ROLLINS': 0,
    'ROLLINSON': 0,
    'ROLLIS': 0,
    'ROLLISON': 0,
    'ROLLMAN': 0,
    'ROLLMANN': 0,
    'ROLLO': 0,
    'ROLLOCK': 0,
    'ROLLOFF': 0,
    'ROLLOW': 0,
    'ROLLS': 0,
    'ROLLSTON': 0,
    'ROLLYSON': 0,
    'ROLNICK': 0,
    'ROLNIK': 0,
    'ROLO': 0,
    'ROLOFF': 0,
    'ROLOFSON': 0,
    'ROLON': 0,
    'ROLOSON': 0,
    'ROLPH': 0,
    'ROLSTAD': 0,
    'ROLSTON': 0,
    'ROLUFS': 0,
    'ROLWES': 0,
    'ROLWING': 0,
    'ROM': 0,
    'ROMA': 0.8865248226950355,
    'ROMACK': 0,
    'ROMAGE': 0,
    'ROMAGNA': 0,
    'ROMAGNANO': 0,
    'ROMAGNOLI': 0,
    'ROMAGNOLO': 0,
    'ROMAGOSA': 0,
    'ROMAGUERA': 0,
    'ROMAIN': 0,
    'ROMAINE': 0.7380073800738007,
    'ROMAKER': 0,
    'ROMAN': 0.47755491881566386,
    'ROMANA': 0.9740259740259739,
    'ROMANAK': 0,
    'ROMANCE': 0,
    'ROMANCHAK': 0,
    'ROMANCHIK': 0,
    'ROMANCHUK': 0,
    'ROMANCZUK': 0,
    'ROMANDIA': 0,
    'ROMANE': 0,
    'ROMANEK': 0,
    'ROMANELLI': 0,
    'ROMANELLO': 0,
    'ROMANENKO': 0,
    'ROMANI': 0,
    'ROMANIA': 0,
    'ROMANIAK': 0,
    'ROMANIC': 0,
    'ROMANICK': 0,
    'ROMANIELLO': 0,
    'ROMANIK': 0,
    'ROMANINI': 0,
    'ROMANIUK': 0,
    'ROMANKO': 0,
    'ROMANN': 0,
    'ROMANO': 0,
    'ROMANOFF': 0,
    'ROMANOS': 0,
    'ROMANOSKI': 0,
    'ROMANOSKY': 0,
    'ROMANOV': 0,
    'ROMANOVA': 0,
    'ROMANOVICH': 0,
    'ROMANOVSKY': 0,
    'ROMANOW': 0,
    'ROMANOWICZ': 0,
    'ROMANOWSKI': 0,
    'ROMANOWSKY': 0,
    'ROMANS': 0,
    'ROMANSKI': 0,
    'ROMANSKY': 0,
    'ROMANUS': 0,
    'ROMANYSHYN': 0,
    'ROMANYUK': 0,
    'ROMAO': 0,
    'ROMAR': 0,
    'ROMARO': 0,
    'ROMARY': 0,
    'ROMAS': 0,
    'ROMASANTA': 0,
    'ROMASCO': 0,
    'ROMATOWSKI': 0,
    'ROMATZ': 0,
    'ROMAY': 0,
    'ROMAYOR': 0,
    'ROMBA': 0,
    'ROMBACH': 0,
    'ROMBALSKI': 0,
    'ROMBERG': 0,
    'ROMBERGER': 0,
    'ROMBOLA': 0,
    'ROMBOLD': 0,
    'ROMBOUGH': 0,
    'ROME': 0,
    'ROMEI': 0,
    'ROMEIS': 0,
    'ROMEISER': 0,
    'ROMEL': 0,
    'ROMELIA': 1,
    'ROMELL': 0,
    'ROMELUS': 0,
    'ROMEN': 0,
    'ROMENESKO': 0,
    'ROMENS': 0,
    'ROMEO': 0.7674597083653109,
    'ROMER': 0,
    'ROMERA': 0,
    'ROMEREZ': 0,
    'ROMERIL': 0,
    'ROMERO': 0,
    'ROMES': 0,
    'ROMESBERG': 0,
    'ROMESBURG': 0,
    'ROMEU': 0,
    'ROMEUS': 0,
    'ROMEY': 0,
    'ROMEYN': 0,
    'ROMFO': 0,
    'ROMICH': 0,
    'ROMICK': 0,
    'ROMIE': 0,
    'ROMIG': 0,
    'ROMIGH': 0,
    'ROMIN': 0,
    'ROMINE': 0,
    'ROMINES': 0,
    'ROMINGER': 0,
    'ROMINSKI': 0,
    'ROMIREZ': 0,
    'ROMITI': 0,
    'ROMITO': 0,
    'ROMJUE': 0,
    'ROMLEY': 0,
    'ROMM': 0,
    'ROMME': 0,
    'ROMMEL': 0,
    'ROMMELFANGER': 0,
    'ROMMES': 0,
    'ROMNEY': 0,
    'ROMO': 0,
    'ROMOLO': 0,
    'ROMON': 0,
    'ROMONA': 1,
    'ROMOS': 0,
    'ROMOSER': 0,
    'ROMP': 0,
    'ROMPALA': 0,
    'ROMPF': 0,
    'ROMPREY': 0,
    'ROMRELL': 0,
    'ROMRIELL': 0,
    'ROMSA': 0,
    'ROMSDAHL': 0,
    'ROMSTAD': 0,
    'ROMSTADT': 0,
    'ROMUALDO': 0,
    'ROMULO': 0,
    'ROMULUS': 0,
    'ROMZEK': 0,
    'RON': 0.9950248756218906,
    'RONA': 0.9828009828009829,
    'RONALD': 0.9994363563877319,
    'RONALDSON': 0,
    'RONAN': 0,
    'RONAY': 0,
    'RONAYNE': 0,
    'RONCA': 0,
    'RONCAGLIONE': 0,
    'RONCAL': 0,
    'RONCANCIO': 0,
    'RONCES': 0,
    'RONCHETTI': 0,
    'RONCHETTO': 0,
    'RONCHI': 0,
    'RONCI': 0,
    'RONCO': 0,
    'RONCONE': 0,
    'RONCONI': 0,
    'ROND': 0,
    'RONDA': 0.9919877909194964,
    'RONDAN': 0,
    'RONDEAU': 0,
    'RONDINA': 0,
    'RONDINELLA': 0,
    'RONDINELLI': 0,
    'RONDINI': 0,
    'RONDINONE': 0,
    'RONDO': 0,
    'RONDON': 0,
    'RONDONE': 0,
    'RONDORF': 0,
    'RONDOT': 0,
    'RONDY': 0,
    'RONE': 0,
    'RONEK': 0,
    'RONEMUS': 0,
    'RONEN': 0,
    'RONER': 0,
    'RONERO': 0,
    'RONES': 0,
    'RONEY': 0,
    'RONFELDT': 0,
    'RONG': 0,
    'RONGA': 0,
    'RONGE': 0,
    'RONGEY': 0,
    'RONGIONE': 0,
    'RONGO': 0,
    'RONGSTAD': 0,
    'RONI': 1,
    'RONIGER': 0,
    'RONIN': 0,
    'RONIS': 0,
    'RONISH': 0,
    'RONK': 0,
    'RONKE': 0,
    'RONKEN': 0,
    'RONN': 0,
    'RONNA': 1,
    'RONNAU': 0,
    'RONNE': 0,
    'RONNEBAUM': 0,
    'RONNEBERG': 0,
    'RONNENBERG': 0,
    'RONNER': 0,
    'RONNFELDT': 0,
    'RONNI': 1,
    'RONNIE': 0.9992313604919292,
    'RONNING': 0,
    'RONNINGEN': 0,
    'RONNOW': 0,
    'RONNY': 1,
    'RONO': 0,
    'RONQUILLE': 0,
    'RONQUILLO': 0,
    'RONS': 0,
    'RONSHAUSEN': 0,
    'RONSICK': 0,
    'RONSMAN': 0,
    'RONSON': 0,
    'RONSONET': 0,
    'RONSPIES': 0,
    'RONSSE': 0,
    'RONSTADT': 0,
    'RONTO': 0,
    'RONYAK': 0,
    'RONZIO': 0,
    'RONZO': 0,
    'RONZONE': 0,
    'ROO': 0,
    'ROOB': 0,
    'ROOD': 0,
    'ROODE': 0,
    'ROOF': 0,
    'ROOFE': 0,
    'ROOFENER': 0,
    'ROOFNER': 0,
    'ROOHI': 0,
    'ROOHR': 0,
    'ROOK': 0,
    'ROOKARD': 0,
    'ROOKE': 0,
    'ROOKER': 0,
    'ROOKEY': 0,
    'ROOKS': 0,
    'ROOKSBERRY': 0,
    'ROOKSTOOL': 0,
    'ROOKWOOD': 0,
    'ROOM': 0,
    'ROOME': 0,
    'ROOMSBURG': 0,
    'ROON': 0,
    'ROONEY': 0,
    'ROOP': 0,
    'ROOPCHAND': 0,
    'ROOPE': 0,
    'ROOPER': 0,
    'ROOPNARINE': 0,
    'ROORDA': 0,
    'ROORK': 0,
    'ROOS': 0,
    'ROOSA': 0,
    'ROOSE': 0,
    'ROOSEN': 0,
    'ROOSEVELT': 0.9873060648801129,
    'ROOSMA': 0,
    'ROOSSIEN': 0,
    'ROOST': 0,
    'ROOT': 0,
    'ROOTE': 0,
    'ROOTES': 0,
    'ROOTH': 0,
    'ROOTS': 0,
    'ROOYAKKERS': 0,
    'ROOZE': 0,
    'ROOZEBOOM': 0,
    'ROOZEN': 0,
    'ROP': 0,
    'ROPE': 0,
    'ROPEL': 0,
    'ROPELEWSKI': 0,
    'ROPER': 0,
    'ROPERS': 0,
    'ROPES': 0,
    'ROPIAK': 0,
    'ROPKA': 0,
    'ROPKE': 0,
    'ROPP': 0,
    'ROPPE': 0,
    'ROPPEL': 0,
    'ROPPELT': 0,
    'ROPPO': 0,
    'ROPPOLO': 0,
    'ROPSON': 0,
    'ROQUE': 0,
    'ROQUEMORE': 0,
    'ROQUES': 0,
    'ROQUET': 0,
    'ROQUETA': 0,
    'RORABACK': 0,
    'RORABAUGH': 0,
    'RORAFF': 0,
    'ROREM': 0,
    'RORER': 0,
    'ROREX': 0,
    'RORICK': 0,
    'RORIE': 0,
    'RORIGUEZ': 0,
    'RORISON': 0,
    'RORK': 0,
    'RORKE': 0,
    'RORMAN': 0,
    'RORRER': 0,
    'RORTVEDT': 0,
    'RORVIG': 0,
    'RORVIK': 0,
    'RORY': 0.9969325153374232,
    'ROS': 0,
    'ROSA': 0.9485624877762566,
    'ROSAAEN': 0,
    'ROSABAL': 0,
    'ROSACKER': 0,
    'ROSADA': 0,
    'ROSADO': 0,
    'ROSAL': 0,
    'ROSALBA': 1,
    'ROSALEE': 1,
    'ROSALES': 0,
    'ROSALEZ': 0,
    'ROSALIA': 0.99009900990099,
    'ROSALIE': 1,
    'ROSALINA': 1,
    'ROSALIND': 1,
    'ROSALINDA': 1,
    'ROSALINE': 1,
    'ROSALIO': 0,
    'ROSALVA': 1,
    'ROSALY': 0,
    'ROSALYN': 1,
    'ROSAMARIA': 1,
    'ROSAMILIA': 0,
    'ROSAMOND': 0.8658008658008658,
    'ROSAN': 0,
    'ROSANA': 0.9803921568627452,
    'ROSAND': 0,
    'ROSANDER': 0,
    'ROSANDICH': 0,
    'ROSANE': 0,
    'ROSANELLI': 0,
    'ROSANIA': 0,
    'ROSANIO': 0,
    'ROSANN': 1,
    'ROSANNA': 1,
    'ROSANNE': 1,
    'ROSANO': 0,
    'ROSANOVA': 0,
    'ROSANSKY': 0,
    'ROSAR': 0,
    'ROSARIA': 1,
    'ROSARIO': 0.6486766995329528,
    'ROSARO': 0,
    'ROSAS': 0,
    'ROSASCHI': 0,
    'ROSASCO': 0,
    'ROSATI': 0,
    'ROSATO': 0,
    'ROSATTI': 0,
    'ROSAUER': 0,
    'ROSAURA': 1,
    'ROSBACH': 0,
    'ROSBERG': 0,
    'ROSBOROUGH': 0,
    'ROSBROOK': 0,
    'ROSBRUGH': 0,
    'ROSBURG': 0,
    'ROSBURY': 0,
    'ROSBY': 0,
    'ROSCA': 0,
    'ROSCH': 0,
    'ROSCHE': 0,
    'ROSCHEL': 0,
    'ROSCHEN': 0,
    'ROSCHER': 0,
    'ROSCIGNO': 0,
    'ROSCIOLI': 0,
    'ROSCO': 0,
    'ROSCOE': 0.8730691739422431,
    'ROSCOM': 0,
    'ROSCOW': 0,
    'ROSDAHL': 0,
    'ROSE': 0.8446042344347429,
    'ROSEANN': 1,
    'ROSEANNA': 1,
    'ROSEANNE': 1,
    'ROSEBAUGH': 0,
    'ROSEBERG': 0,
    'ROSEBERRY': 0,
    'ROSEBOOM': 0,
    'ROSEBORO': 0,
    'ROSEBOROUGH': 0,
    'ROSEBRAUGH': 0,
    'ROSEBROCK': 0,
    'ROSEBROOK': 0,
    'ROSEBROUGH': 0,
    'ROSEBRUGH': 0,
    'ROSEBUD': 0,
    'ROSEBURGH': 0,
    'ROSEBUSH': 0,
    'ROSECRANS': 0,
    'ROSEDALE': 0,
    'ROSEEN': 0,
    'ROSEHILL': 0,
    'ROSEK': 0,
    'ROSEKRANS': 0,
    'ROSEL': 0,
    'ROSELAND': 0,
    'ROSELEE': 1,
    'ROSELIA': 1,
    'ROSELINE': 1,
    'ROSELIUS': 0,
    'ROSELL': 0,
    'ROSELLA': 0.9910802775024777,
    'ROSELLE': 0.7633587786259542,
    'ROSELLI': 0,
    'ROSELLINI': 0,
    'ROSELLO': 0,
    'ROSELUND': 0,
    'ROSELYN': 1,
    'ROSEMA': 0,
    'ROSEMAN': 0,
    'ROSEMANN': 0,
    'ROSEMARIE': 1,
    'ROSEMARK': 0,
    'ROSEMARY': 0.9994395665981693,
    'ROSEMEIER': 0,
    'ROSEMEYER': 0,
    'ROSEMON': 0,
    'ROSEMOND': 0,
    'ROSEMONT': 0,
    'ROSEMORE': 0,
    'ROSEN': 0,
    'ROSENA': 1,
    'ROSENAU': 0,
    'ROSENAUER': 0,
    'ROSENBACH': 0,
    'ROSENBALM': 0,
    'ROSENBAUER': 0,
    'ROSENBAUM': 0,
    'ROSENBECK': 0,
    'ROSENBERG': 0,
    'ROSENBERGER': 0,
    'ROSENBERRY': 0,
    'ROSENBLAD': 0,
    'ROSENBLAT': 0,
    'ROSENBLATT': 0,
    'ROSENBLOOM': 0,
    'ROSENBLUM': 0,
    'ROSENBLUTH': 0,
    'ROSENBOHM': 0,
    'ROSENBOOM': 0,
    'ROSENBROCK': 0,
    'ROSENBROOK': 0,
    'ROSENBURG': 0,
    'ROSENBURGH': 0,
    'ROSENBUSCH': 0,
    'ROSENBUSH': 0,
    'ROSENCRANCE': 0,
    'ROSENCRANS': 0,
    'ROSENCRANTS': 0,
    'ROSENCRANTZ': 0,
    'ROSENCRANZ': 0,
    'ROSENCUTTER': 0,
    'ROSENDA': 1,
    'ROSENDAHL': 0,
    'ROSENDALE': 0,
    'ROSENDALL': 0,
    'ROSENDO': 0.9554140127388534,
    'ROSENDORF': 0,
    'ROSENE': 0,
    'ROSENER': 0,
    'ROSENFELD': 0,
    'ROSENFELDER': 0,
    'ROSENFELDT': 0,
    'ROSENFELT': 0,
    'ROSENFIELD': 0,
    'ROSENGARD': 0,
    'ROSENGARTEN': 0,
    'ROSENGRANT': 0,
    'ROSENGREEN': 0,
    'ROSENGREN': 0,
    'ROSENHAGEN': 0,
    'ROSENHAN': 0,
    'ROSENHAUS': 0,
    'ROSENHECK': 0,
    'ROSENHEIM': 0,
    'ROSENKOETTER': 0,
    'ROSENKRANS': 0,
    'ROSENKRANTZ': 0,
    'ROSENKRANZ': 0,
    'ROSENLIEB': 0,
    'ROSENLOF': 0,
    'ROSENLUND': 0,
    'ROSENMAN': 0,
    'ROSENOW': 0,
    'ROSENQUIST': 0,
    'ROSENSON': 0,
    'ROSENSTEEL': 0,
    'ROSENSTEIN': 0,
    'ROSENSTIEL': 0,
    'ROSENSTOCK': 0,
    'ROSENSTRAUCH': 0,
    'ROSENSWEIG': 0,
    'ROSENTHAL': 0,
    'ROSENTHALL': 0,
    'ROSENTRATER': 0,
    'ROSENTRETER': 0,
    'ROSENWALD': 0,
    'ROSENWASSER': 0,
    'ROSENWINKEL': 0,
    'ROSENZWEIG': 0,
    'ROSEQUIST': 0,
    'ROSER': 0,
    'ROSERA': 0,
    'ROSERO': 0,
    'ROSERS': 0,
    'ROSES': 0,
    'ROSETE': 0,
    'ROSETH': 0,
    'ROSETO': 0,
    'ROSETT': 0,
    'ROSETTA': 0.990990990990991,
    'ROSETTE': 0.7751937984496124,
    'ROSETTI': 0,
    'ROSETTO': 0,
    'ROSEVEAR': 0,
    'ROSEWALL': 0,
    'ROSEWARNE': 0,
    'ROSEWELL': 0,
    'ROSEWICZ': 0,
    'ROSEY': 0,
    'ROSFELD': 0,
    'ROSH': 0,
    'ROSHAK': 0,
    'ROSHAN': 0,
    'ROSHAU': 0,
    'ROSHEIM': 0,
    'ROSHELL': 0,
    'ROSHER': 0,
    'ROSHOLT': 0,
    'ROSHON': 0,
    'ROSHONG': 0,
    'ROSHTO': 0,
    'ROSI': 0,
    'ROSIA': 0.9803921568627452,
    'ROSIAK': 0,
    'ROSIAN': 0,
    'ROSIC': 0,
    'ROSICA': 0,
    'ROSICH': 0,
    'ROSICK': 0,
    'ROSIE': 0.9976419372392528,
    'ROSIEK': 0,
    'ROSIELLO': 0,
    'ROSIER': 0,
    'ROSIERE': 0,
    'ROSILES': 0,
    'ROSILLO': 0,
    'ROSIN': 0,
    'ROSINA': 0.9876543209876544,
    'ROSINE': 0,
    'ROSING': 0,
    'ROSINI': 0,
    'ROSINSKI': 0,
    'ROSINSKY': 0,
    'ROSIO': 0.9345794392523364,
    'ROSITA': 1,
    'ROSITANO': 0,
    'ROSITAS': 0,
    'ROSKA': 0,
    'ROSKAM': 0,
    'ROSKAMP': 0,
    'ROSKE': 0,
    'ROSKELLEY': 0,
    'ROSKELLY': 0,
    'ROSKENS': 0,
    'ROSKEY': 0,
    'ROSKI': 0,
    'ROSKILLY': 0,
    'ROSKIN': 0,
    'ROSKO': 0,
    'ROSKOM': 0,
    'ROSKOP': 0,
    'ROSKOPF': 0,
    'ROSKOS': 0,
    'ROSKOSKI': 0,
    'ROSKOWSKI': 0,
    'ROSKY': 0,
    'ROSLAN': 0,
    'ROSLER': 0,
    'ROSLING': 0,
    'ROSLUND': 0,
    'ROSLYN': 1,
    'ROSMAN': 0,
    'ROSMARIN': 0,
    'ROSMUS': 0,
    'ROSNER': 0,
    'ROSNICK': 0,
    'ROSNO': 0,
    'ROSO': 0,
    'ROSOFF': 0,
    'ROSOFSKY': 0,
    'ROSOL': 0,
    'ROSOLOWSKI': 0,
    'ROSONE': 0,
    'ROSONKE': 0,
    'ROSOW': 0,
    'ROSOWSKI': 0,
    'ROSPERT': 0,
    'ROSPIERSKI': 0,
    'ROSPLOCH': 0,
    'ROSPLOCK': 0,
    'ROSPOND': 0,
    'ROSQUETE': 0,
    'ROSQUIST': 0,
    'ROSS': 0.38011251330393797,
    'ROSSA': 0,
    'ROSSANA': 1,
    'ROSSANO': 0,
    'ROSSATO': 0,
    'ROSSBACH': 0,
    'ROSSBACK': 0,
    'ROSSBERG': 0,
    'ROSSBOROUGH': 0,
    'ROSSE': 0,
    'ROSSEAU': 0,
    'ROSSEL': 0,
    'ROSSELAND': 0,
    'ROSSELL': 0,
    'ROSSELLE': 0,
    'ROSSELLI': 0,
    'ROSSELLO': 0,
    'ROSSELOT': 0,
    'ROSSEN': 0,
    'ROSSER': 0,
    'ROSSET': 0,
    'ROSSETER': 0,
    'ROSSETT': 0,
    'ROSSETTE': 0,
    'ROSSETTER': 0,
    'ROSSETTI': 0,
    'ROSSETTO': 0,
    'ROSSEY': 0,
    'ROSSI': 0,
    'ROSSIE': 0.8695652173913043,
    'ROSSIELLO': 0,
    'ROSSIER': 0,
    'ROSSIGNOL': 0,
    'ROSSILLI': 0,
    'ROSSILLO': 0,
    'ROSSIN': 0,
    'ROSSING': 0,
    'ROSSINI': 0,
    'ROSSINO': 0,
    'ROSSIO': 0,
    'ROSSITER': 0,
    'ROSSITTO': 0,
    'ROSSKOPF': 0,
    'ROSSLER': 0,
    'ROSSLEY': 0,
    'ROSSMAN': 0,
    'ROSSMANN': 0,
    'ROSSMEISL': 0,
    'ROSSMILLER': 0,
    'ROSSNAGEL': 0,
    'ROSSNER': 0,
    'ROSSO': 0,
    'ROSSOL': 0,
    'ROSSOMANDO': 0,
    'ROSSON': 0,
    'ROSSOW': 0,
    'ROSSUM': 0,
    'ROSSWURM': 0,
    'ROSSY': 0,
    'ROST': 0,
    'ROSTA': 0,
    'ROSTAD': 0,
    'ROSTAMI': 0,
    'ROSTAN': 0,
    'ROSTAS': 0,
    'ROSTECK': 0,
    'ROSTEK': 0,
    'ROSTEN': 0,
    'ROSTER': 0,
    'ROSTKOWSKI': 0,
    'ROSTOCK': 0,
    'ROSTON': 0,
    'ROSTORFER': 0,
    'ROSTRAN': 0,
    'ROSTRO': 0,
    'ROSTRON': 0,
    'ROSU': 0,
    'ROSVALL': 0,
    'ROSVOLD': 0,
    'ROSWELL': 0,
    'ROSY': 1,
    'ROSZAK': 0,
    'ROSZEL': 0,
    'ROSZELL': 0,
    'ROSZKO': 0,
    'ROSZKOWSKI': 0,
    'ROSZMAN': 0,
    'ROT': 0,
    'ROTA': 0,
    'ROTACH': 0,
    'ROTAN': 0,
    'ROTANTE': 0,
    'ROTAR': 0,
    'ROTARIUS': 0,
    'ROTATORI': 0,
    'ROTBERG': 0,
    'ROTCHFORD': 0,
    'ROTE': 0,
    'ROTELL': 0,
    'ROTELLA': 0,
    'ROTELLI': 0,
    'ROTELLINI': 0,
    'ROTELLO': 0,
    'ROTEN': 0,
    'ROTENBERG': 0,
    'ROTENBERGER': 0,
    'ROTENBERRY': 0,
    'ROTER': 0,
    'ROTERING': 0,
    'ROTERMUND': 0,
    'ROTERT': 0,
    'ROTGER': 0,
    'ROTH': 0,
    'ROTHACHER': 0,
    'ROTHACKER': 0,
    'ROTHAMEL': 0,
    'ROTHAN': 0,
    'ROTHAUS': 0,
    'ROTHBARD': 0,
    'ROTHBART': 0,
    'ROTHBAUER': 0,
    'ROTHBAUM': 0,
    'ROTHBERG': 0,
    'ROTHBERGER': 0,
    'ROTHBLATT': 0,
    'ROTHCHILD': 0,
    'ROTHE': 0,
    'ROTHELL': 0,
    'ROTHEN': 0,
    'ROTHENBACH': 0,
    'ROTHENBERG': 0,
    'ROTHENBERGER': 0,
    'ROTHENBUHLER': 0,
    'ROTHENBURGER': 0,
    'ROTHENHOEFER': 0,
    'ROTHER': 0,
    'ROTHERHAM': 0,
    'ROTHERING': 0,
    'ROTHERMEL': 0,
    'ROTHERMICH': 0,
    'ROTHERMUND': 0,
    'ROTHERT': 0,
    'ROTHERY': 0,
    'ROTHEY': 0,
    'ROTHFELD': 0,
    'ROTHFUS': 0,
    'ROTHFUSS': 0,
    'ROTHGEB': 0,
    'ROTHGERY': 0,
    'ROTHHAAR': 0,
    'ROTHKOPF': 0,
    'ROTHLEIN': 0,
    'ROTHLEUTNER': 0,
    'ROTHLEY': 0,
    'ROTHLISBERGER': 0,
    'ROTHMAN': 0,
    'ROTHMANN': 0,
    'ROTHMEIER': 0,
    'ROTHMEYER': 0,
    'ROTHMUND': 0,
    'ROTHOVE': 0,
    'ROTHRAUFF': 0,
    'ROTHROCK': 0,
    'ROTHS': 0,
    'ROTHSCHADL': 0,
    'ROTHSCHILD': 0,
    'ROTHSCHILLER': 0,
    'ROTHSTEIN': 0,
    'ROTHWEILER': 0,
    'ROTHWELL': 0,
    'ROTI': 0,
    'ROTMAN': 0,
    'ROTNER': 0,
    'ROTOLA': 0,
    'ROTOLD': 0,
    'ROTOLI': 0,
    'ROTOLO': 0,
    'ROTON': 0,
    'ROTONDA': 0,
    'ROTONDI': 0,
    'ROTONDO': 0,
    'ROTRAMEL': 0,
    'ROTROFF': 0,
    'ROTRUCK': 0,
    'ROTSTEIN': 0,
    'ROTT': 0,
    'ROTTA': 0,
    'ROTTENBERG': 0,
    'ROTTER': 0,
    'ROTTERMAN': 0,
    'ROTTET': 0,
    'ROTTGER': 0,
    'ROTTI': 0,
    'ROTTIER': 0,
    'ROTTIERS': 0,
    'ROTTINGHAUS': 0,
    'ROTTKAMP': 0,
    'ROTTLER': 0,
    'ROTTMAN': 0,
    'ROTTMANN': 0,
    'ROTTNER': 0,
    'ROTTO': 0,
    'ROTTON': 0,
    'ROTTSCHAFER': 0,
    'ROTUNDA': 0,
    'ROTUNDO': 0,
    'ROTUNNO': 0,
    'ROTZ': 0,
    'ROTZIEN': 0,
    'ROU': 0,
    'ROUB': 0,
    'ROUBAL': 0,
    'ROUBIDEAUX': 0,
    'ROUBIDOUX': 0,
    'ROUBIK': 0,
    'ROUBIQUE': 0,
    'ROUCH': 0,
    'ROUCHON': 0,
    'ROUCO': 0,
    'ROUDA': 0,
    'ROUDABUSH': 0,
    'ROUDEBUSH': 0,
    'ROUDYBUSH': 0,
    'ROUECHE': 0,
    'ROUEN': 0,
    'ROUF': 0,
    'ROUFF': 0,
    'ROUFS': 0,
    'ROUGE': 0,
    'ROUGEAU': 0,
    'ROUGELY': 0,
    'ROUGEMONT': 0,
    'ROUGEOU': 0,
    'ROUGEUX': 0,
    'ROUGH': 0,
    'ROUGHAN': 0,
    'ROUGHGARDEN': 0,
    'ROUGHLEY': 0,
    'ROUGHT': 0,
    'ROUGHTON': 0,
    'ROUGIER': 0,
    'ROUHANA': 0,
    'ROUHANI': 0,
    'ROUHIER': 0,
    'ROUILLARD': 0,
    'ROUILLE': 0,
    'ROUILLIER': 0,
    'ROUKE': 0,
    'ROULAND': 0,
    'ROULE': 0,
    'ROULEAU': 0,
    'ROULET': 0,
    'ROULETTE': 0,
    'ROULHAC': 0,
    'ROULIER': 0,
    'ROULLIER': 0,
    'ROULO': 0,
    'ROULSTON': 0,
    'ROUM': 0,
    'ROUMELIOTIS': 0,
    'ROUMILLAT': 0,
    'ROUN': 0,
    'ROUND': 0,
    'ROUNDS': 0,
    'ROUNDTREE': 0,
    'ROUNDY': 0,
    'ROUNER': 0,
    'ROUNKLES': 0,
    'ROUNSAVALL': 0,
    'ROUNSAVILLE': 0,
    'ROUNSEVILLE': 0,
    'ROUNSLEY': 0,
    'ROUNSVILLE': 0,
    'ROUNTREE': 0,
    'ROUP': 0,
    'ROUPAS': 0,
    'ROUPE': 0,
    'ROUPP': 0,
    'ROURA': 0,
    'ROURK': 0,
    'ROURKE': 0,
    'ROUS': 0,
    'ROUSAN': 0,
    'ROUSCH': 0,
    'ROUSCULP': 0,
    'ROUSE': 0,
    'ROUSELL': 0,
    'ROUSER': 0,
    'ROUSEY': 0,
    'ROUSH': 0,
    'ROUSHAR': 0,
    'ROUSHEY': 0,
    'ROUSHIA': 0,
    'ROUSON': 0,
    'ROUSOS': 0,
    'ROUSS': 0,
    'ROUSSE': 0,
    'ROUSSEAU': 0,
    'ROUSSEL': 0,
    'ROUSSELL': 0,
    'ROUSSELLE': 0,
    'ROUSSET': 0,
    'ROUSSEVE': 0,
    'ROUSSEY': 0,
    'ROUSSIN': 0,
    'ROUSSO': 0,
    'ROUSSOS': 0,
    'ROUSTER': 0,
    'ROUSU': 0,
    'ROUT': 0,
    'ROUTE': 0,
    'ROUTEN': 0,
    'ROUTH': 0,
    'ROUTHIER': 0,
    'ROUTIER': 0,
    'ROUTION': 0,
    'ROUTLEDGE': 0,
    'ROUTLEY': 0,
    'ROUTMAN': 0,
    'ROUTON': 0,
    'ROUTSON': 0,
    'ROUTSONG': 0,
    'ROUTT': 0,
    'ROUTTE': 0,
    'ROUTTEN': 0,
    'ROUTZAHN': 0,
    'ROUW': 0,
    'ROUWHORST': 0,
    'ROUX': 0,
    'ROUZAN': 0,
    'ROUZE': 0,
    'ROUZER': 0,
    'ROVA': 0,
    'ROVAI': 0,
    'ROVANG': 0,
    'ROVEGNO': 0,
    'ROVELLI': 0,
    'ROVELLO': 0,
    'ROVELO': 0,
    'ROVENOLT': 0,
    'ROVENSTINE': 0,
    'ROVER': 0,
    'ROVERE': 0,
    'ROVERO': 0,
    'ROVETO': 0,
    'ROVETTO': 0,
    'ROVIG': 0,
    'ROVIN': 0,
    'ROVINSKI': 0,
    'ROVINSKY': 0,
    'ROVIRA': 0,
    'ROVITO': 0,
    'ROVNAK': 0,
    'ROVNER': 0,
    'ROW': 0,
    'ROWAN': 0,
    'ROWAND': 0,
    'ROWBERRY': 0,
    'ROWBOTHAM': 0,
    'ROWBOTTOM': 0,
    'ROWBURY': 0,
    'ROWCLIFFE': 0,
    'ROWDEN': 0,
    'ROWDON': 0,
    'ROWE': 0,
    'ROWEDDER': 0,
    'ROWEKAMP': 0,
    'ROWELL': 0,
    'ROWELLS': 0,
    'ROWEN': 0,
    'ROWENA': 1,
    'ROWENHORST': 0,
    'ROWER': 0,
    'ROWETT': 0,
    'ROWH': 0,
    'ROWIN': 0,
    'ROWINSKI': 0,
    'ROWINSKY': 0,
    'ROWL': 0,
    'ROWLAN': 0,
    'ROWLAND': 0,
    'ROWLANDS': 0,
    'ROWLEE': 0,
    'ROWLEN': 0,
    'ROWLES': 0,
    'ROWLETT': 0,
    'ROWLETTE': 0,
    'ROWLEY': 0,
    'ROWLING': 0,
    'ROWLINGS': 0,
    'ROWLINSON': 0,
    'ROWLISON': 0,
    'ROWLS': 0,
    'ROWLSON': 0,
    'ROWND': 0,
    'ROWNEY': 0,
    'ROWNTREE': 0,
    'ROWOLD': 0,
    'ROWOLDT': 0,
    'ROWRY': 0,
    'ROWSE': 0,
    'ROWSELL': 0,
    'ROWSER': 0,
    'ROWSEY': 0,
    'ROWSON': 0,
    'ROWTON': 0,
    'ROWZEE': 0,
    'ROX': 0,
    'ROXANA': 1,
    'ROXANE': 1,
    'ROXANN': 1,
    'ROXANNA': 1,
    'ROXANNE': 1,
    'ROXAS': 0,
    'ROXBERRY': 0,
    'ROXBURGH': 0,
    'ROXBURY': 0,
    'ROXBY': 0,
    'ROXIE': 1,
    'ROXY': 1,
    'ROY': 0.9369763704134323,
    'ROYA': 0,
    'ROYAL': 0.5235602094240838,
    'ROYALE': 0,
    'ROYALL': 0,
    'ROYALS': 0,
    'ROYALTY': 0,
    'ROYBAL': 0,
    'ROYCE': 0.8999470619375332,
    'ROYCHOWDHURY': 0,
    'ROYCRAFT': 0,
    'ROYCROFT': 0,
    'ROYDS': 0,
    'ROYE': 0,
    'ROYEA': 0,
    'ROYER': 0,
    'ROYES': 0,
    'ROYKO': 0,
    'ROYLANCE': 0,
    'ROYLAND': 0,
    'ROYLE': 0,
    'ROYO': 0,
    'ROYS': 0,
    'ROYSDEN': 0,
    'ROYSDON': 0,
    'ROYSE': 0,
    'ROYSTER': 0,
    'ROYSTON': 0,
    'ROYTER': 0,
    'ROYTMAN': 0,
    'ROYVAL': 0,
    'ROYZMAN': 0,
    'ROZ': 0,
    'ROZA': 0,
    'ROZAK': 0,
    'ROZAKIS': 0,
    'ROZALES': 0,
    'ROZAN': 0,
    'ROZANNE': 1,
    'ROZANSKI': 0,
    'ROZANSKY': 0,
    'ROZAR': 0,
    'ROZARIO': 0,
    'ROZAS': 0,
    'ROZBORIL': 0,
    'ROZE': 0,
    'ROZEBOOM': 0,
    'ROZEK': 0,
    'ROZELL': 0,
    'ROZELLA': 1,
    'ROZELLE': 0,
    'ROZEMA': 0,
    'ROZEN': 0,
    'ROZENBAUM': 0,
    'ROZENBERG': 0,
    'ROZENBLAT': 0,
    'ROZENBOOM': 0,
    'ROZENDAAL': 0,
    'ROZENFELD': 0,
    'ROZENTAL': 0,
    'ROZEWICZ': 0,
    'ROZEWSKI': 0,
    'ROZGA': 0,
    'ROZHON': 0,
    'ROZIC': 0,
    'ROZICH': 0,
    'ROZIER': 0,
    'ROZIN': 0,
    'ROZINSKI': 0,
    'ROZINSKY': 0,
    'ROZLER': 0,
    'ROZMAN': 0,
    'ROZMIAREK': 0,
    'ROZMUS': 0,
    'ROZNER': 0,
    'ROZNOS': 0,
    'ROZNOVSKY': 0,
    'ROZNOWSKI': 0,
    'ROZO': 0,
    'ROZON': 0,
    'ROZSA': 0,
    'ROZUM': 0,
    'ROZWADOWSKI': 0,
    'ROZYCKI': 0,
    'ROZZANO': 0,
    'ROZZELL': 0,
    'ROZZELLE': 0,
    'ROZZI': 0,
    'ROZZO': 0,
    'RU': 0,
    'RUA': 0,
    'RUACHO': 0,
    'RUALES': 0,
    'RUALO': 0,
    'RUAN': 0,
    'RUANE': 0,
    'RUANO': 0,
    'RUARK': 0,
    'RUAS': 0,
    'RUB': 0,
    'RUBA': 0,
    'RUBACH': 0,
    'RUBACHA': 0,
    'RUBACK': 0,
    'RUBADO': 0,
    'RUBADUE': 0,
    'RUBAL': 0,
    'RUBALCABA': 0,
    'RUBALCADO': 0,
    'RUBALCAVA': 0,
    'RUBAN': 0,
    'RUBANO': 0,
    'RUBASH': 0,
    'RUBBELKE': 0,
    'RUBBERT': 0,
    'RUBBO': 0,
    'RUBE': 0,
    'RUBECK': 0,
    'RUBEL': 0,
    'RUBELL': 0,
    'RUBEN': 0.98747591522158,
    'RUBENACKER': 0,
    'RUBENDALL': 0,
    'RUBENFELD': 0,
    'RUBENS': 0,
    'RUBENSTEIN': 0,
    'RUBENZER': 0,
    'RUBEO': 0,
    'RUBER': 0,
    'RUBERA': 0,
    'RUBERG': 0,
    'RUBERO': 0,
    'RUBERRY': 0,
    'RUBERT': 0,
    'RUBERTE': 0,
    'RUBERTI': 0,
    'RUBERTO': 0,
    'RUBERTONE': 0,
    'RUBEY': 0,
    'RUBI': 0.6451612903225806,
    'RUBIA': 0,
    'RUBIANES': 0,
    'RUBIANO': 0,
    'RUBIC': 0,
    'RUBICK': 0,
    'RUBIDOUX': 0,
    'RUBIE': 0.9569377990430621,
    'RUBIERA': 0,
    'RUBIN': 0.4135079255685734,
    'RUBINA': 0,
    'RUBINCHIK': 0,
    'RUBINETTI': 0,
    'RUBINFELD': 0,
    'RUBINGER': 0,
    'RUBINGH': 0,
    'RUBINI': 0,
    'RUBINIC': 0,
    'RUBINO': 0,
    'RUBINOFF': 0,
    'RUBINOS': 0,
    'RUBINOV': 0,
    'RUBINS': 0,
    'RUBINSHTEYN': 0,
    'RUBINSKY': 0,
    'RUBINSON': 0,
    'RUBINSTEIN': 0,
    'RUBIO': 0,
    'RUBIRA': 0,
    'RUBIS': 0,
    'RUBISH': 0,
    'RUBLE': 0,
    'RUBLEE': 0,
    'RUBLES': 0,
    'RUBLEY': 0,
    'RUBLY': 0,
    'RUBNER': 0,
    'RUBNITZ': 0,
    'RUBO': 0,
    'RUBOTTOM': 0,
    'RUBOW': 0,
    'RUBRECHT': 0,
    'RUBRIGHT': 0,
    'RUBSAM': 0,
    'RUBUSH': 0,
    'RUBY': 0.9851997146932953,
    'RUBYE': 1,
    'RUCCI': 0,
    'RUCCIO': 0,
    'RUCCO': 0,
    'RUCH': 0,
    'RUCHALA': 0,
    'RUCHALSKI': 0,
    'RUCHOTZKE': 0,
    'RUCHTI': 0,
    'RUCINSKI': 0,
    'RUCK': 0,
    'RUCKA': 0,
    'RUCKDASCHEL': 0,
    'RUCKDESCHEL': 0,
    'RUCKEL': 0,
    'RUCKER': 0,
    'RUCKERT': 0,
    'RUCKI': 0,
    'RUCKLE': 0,
    'RUCKMAN': 0,
    'RUCKRIEGEL': 0,
    'RUCKS': 0,
    'RUCKSTUHL': 0,
    'RUCOBO': 0,
    'RUCZYNSKI': 0,
    'RUD': 0,
    'RUDA': 0,
    'RUDACILLE': 0,
    'RUDAN': 0,
    'RUDAS': 0,
    'RUDASILL': 0,
    'RUDAT': 0,
    'RUDBERG': 0,
    'RUDD': 0,
    'RUDDELL': 0,
    'RUDDEN': 0,
    'RUDDER': 0,
    'RUDDEROW': 0,
    'RUDDICK': 0,
    'RUDDLE': 0,
    'RUDDOCK': 0,
    'RUDDUCK': 0,
    'RUDDY': 0,
    'RUDE': 0,
    'RUDEBECK': 0,
    'RUDEBUSCH': 0,
    'RUDEEN': 0,
    'RUDEK': 0,
    'RUDEL': 0,
    'RUDELL': 0,
    'RUDEN': 0,
    'RUDENICK': 0,
    'RUDENKO': 0,
    'RUDER': 0,
    'RUDERMAN': 0,
    'RUDERT': 0,
    'RUDES': 0,
    'RUDESEAL': 0,
    'RUDESILL': 0,
    'RUDEWICZ': 0,
    'RUDGE': 0,
    'RUDGERS': 0,
    'RUDH': 0,
    'RUDI': 0,
    'RUDIBAUGH': 0,
    'RUDICEL': 0,
    'RUDICH': 0,
    'RUDICIL': 0,
    'RUDICK': 0,
    'RUDIE': 0,
    'RUDIG': 0,
    'RUDIGER': 0,
    'RUDIK': 0,
    'RUDIN': 0,
    'RUDINGER': 0,
    'RUDINSKI': 0,
    'RUDINSKY': 0,
    'RUDIO': 0,
    'RUDIS': 0,
    'RUDISEL': 0,
    'RUDISELL': 0,
    'RUDISH': 0,
    'RUDISILL': 0,
    'RUDISON': 0,
    'RUDKIN': 0,
    'RUDKO': 0,
    'RUDLAFF': 0,
    'RUDLAND': 0,
    'RUDLER': 0,
    'RUDLEY': 0,
    'RUDLOFF': 0,
    'RUDMAN': 0,
    'RUDMANN': 0,
    'RUDNER': 0,
    'RUDNICK': 0,
    'RUDNICKI': 0,
    'RUDNIK': 0,
    'RUDNITSKI': 0,
    'RUDNITSKY': 0,
    'RUDO': 0,
    'RUDOCK': 0,
    'RUDOFF': 0,
    'RUDOLF': 0.898876404494382,
    'RUDOLPH': 0.8250424654210143,
    'RUDOLPHI': 0,
    'RUDOMETKIN': 0,
    'RUDOW': 0,
    'RUDOWSKI': 0,
    'RUDQUIST': 0,
    'RUDRIGUEZ': 0,
    'RUDROFF': 0,
    'RUDROW': 0,
    'RUDRUD': 0,
    'RUDY': 0.9302325581395349,
    'RUDYK': 0,
    'RUDZIK': 0,
    'RUDZINSKI': 0,
    'RUDZITIS': 0,
    'RUDZKI': 0,
    'RUE': 0,
    'RUEB': 0,
    'RUEBEL': 0,
    'RUEBEN': 0.9876543209876544,
    'RUEBER': 0,
    'RUEBSAMEN': 0,
    'RUEBUSCH': 0,
    'RUEBUSH': 0,
    'RUECHEL': 0,
    'RUECK': 0,
    'RUECKER': 0,
    'RUECKERT': 0,
    'RUED': 0,
    'RUEDA': 0,
    'RUEDAS': 0,
    'RUEDE': 0,
    'RUEDEBUSCH': 0,
    'RUEDEN': 0,
    'RUEDI': 0,
    'RUEDIGER': 0,
    'RUEDINGER': 0,
    'RUEDISUELI': 0,
    'RUEDY': 0,
    'RUEF': 0,
    'RUEFER': 0,
    'RUEFF': 0,
    'RUEFFER': 0,
    'RUEGE': 0,
    'RUEGEMER': 0,
    'RUEGER': 0,
    'RUEGG': 0,
    'RUEGGE': 0,
    'RUEGGER': 0,
    'RUEGSEGGER': 0,
    'RUEHL': 0,
    'RUEHLE': 0,
    'RUEHLEN': 0,
    'RUEHLING': 0,
    'RUEHLMAN': 0,
    'RUEHLOW': 0,
    'RUEHR': 0,
    'RUEHS': 0,
    'RUEL': 0,
    'RUELA': 0,
    'RUELAS': 0,
    'RUELL': 0,
    'RUELLE': 0,
    'RUELOS': 0,
    'RUEMLER': 0,
    'RUEMMELE': 0,
    'RUEN': 0,
    'RUENGER': 0,
    'RUEPPEL': 0,
    'RUES': 0,
    'RUESCH': 0,
    'RUESCHHOFF': 0,
    'RUESGA': 0,
    'RUESING': 0,
    'RUESINK': 0,
    'RUESS': 0,
    'RUEST': 0,
    'RUETER': 0,
    'RUETH': 0,
    'RUETHER': 0,
    'RUETTEN': 0,
    'RUETTGERS': 0,
    'RUETTIGER': 0,
    'RUETZ': 0,
    'RUEVE': 0,
    'RUEZ': 0,
    'RUEZGA': 0,
    'RUF': 0,
    'RUFA': 0,
    'RUFE': 0,
    'RUFENACHT': 0,
    'RUFENER': 0,
    'RUFER': 0,
    'RUFF': 0,
    'RUFFA': 0,
    'RUFFALO': 0,
    'RUFFATTO': 0,
    'RUFFCORN': 0,
    'RUFFELL': 0,
    'RUFFENACH': 0,
    'RUFFER': 0,
    'RUFFIER': 0,
    'RUFFIN': 0,
    'RUFFING': 0,
    'RUFFINI': 0,
    'RUFFINO': 0,
    'RUFFINS': 0,
    'RUFFLE': 0,
    'RUFFLEY': 0,
    'RUFFNER': 0,
    'RUFFO': 0,
    'RUFFOLO': 0,
    'RUFIN': 0,
    'RUFINA': 1,
    'RUFINO': 0,
    'RUFKAHR': 0,
    'RUFNER': 0,
    'RUFO': 0,
    'RUFOLO': 0,
    'RUFRANO': 0,
    'RUFTY': 0,
    'RUFUS': 0.9815469179426777,
    'RUGA': 0,
    'RUGAMA': 0,
    'RUGAMAS': 0,
    'RUGANI': 0,
    'RUGAR': 0,
    'RUGE': 0,
    'RUGEL': 0,
    'RUGELEY': 0,
    'RUGEN': 0,
    'RUGENSTEIN': 0,
    'RUGER': 0,
    'RUGERIO': 0,
    'RUGG': 0,
    'RUGGEBERG': 0,
    'RUGGER': 0,
    'RUGGERI': 0,
    'RUGGERIO': 0,
    'RUGGERO': 0,
    'RUGGIANO': 0,
    'RUGGIERE': 0,
    'RUGGIERI': 0,
    'RUGGIERO': 0,
    'RUGGIO': 0,
    'RUGGIRELLO': 0,
    'RUGGLES': 0,
    'RUGGS': 0,
    'RUGH': 0,
    'RUGLAND': 0,
    'RUGLEY': 0,
    'RUGNETTA': 0,
    'RUGO': 0,
    'RUGOLO': 0,
    'RUGOVA': 0,
    'RUGRODEN': 0,
    'RUH': 0,
    'RUHE': 0,
    'RUHF': 0,
    'RUHL': 0,
    'RUHLAND': 0,
    'RUHLE': 0,
    'RUHLEN': 0,
    'RUHLIG': 0,
    'RUHLIN': 0,
    'RUHLING': 0,
    'RUHLMAN': 0,
    'RUHM': 0,
    'RUHMAN': 0,
    'RUHMANN': 0,
    'RUHNKE': 0,
    'RUHNOW': 0,
    'RUHOFF': 0,
    'RUHOLL': 0,
    'RUHR': 0,
    'RUHS': 0,
    'RUHTER': 0,
    'RUI': 0,
    'RUIBAL': 0,
    'RUIC': 0,
    'RUID': 0,
    'RUILOBA': 0,
    'RUIS': 0,
    'RUISE': 0,
    'RUISI': 0,
    'RUITER': 0,
    'RUIVO': 0,
    'RUIZ': 0,
    'RUIZDIAZ': 0,
    'RUIZESPARZA': 0,
    'RUIZGARCIA': 0,
    'RUIZGONZALEZ': 0,
    'RUIZHERNANDEZ': 0,
    'RUIZLOPEZ': 0,
    'RUIZMARTINEZ': 0,
    'RUIZRODRIGUEZ': 0,
    'RUIZSANCHEZ': 0,
    'RUIZVELASCO': 0,
    'RUK': 0,
    'RUKA': 0,
    'RUKAB': 0,
    'RUKAMP': 0,
    'RUKAS': 0,
    'RUKAVINA': 0,
    'RUKES': 0,
    'RULA': 0,
    'RULAND': 0,
    'RULAPAUGH': 0,
    'RULE': 0,
    'RULEMAN': 0,
    'RULEY': 0,
    'RULIFFSON': 0,
    'RULIS': 0,
    'RULISON': 0,
    'RULL': 0,
    'RULLAN': 0,
    'RULLI': 0,
    'RULLMAN': 0,
    'RULLO': 0,
    'RULLODA': 0,
    'RULO': 0,
    'RULON': 0,
    'RULONG': 0,
    'RULZ': 0,
    'RUM': 0,
    'RUMA': 0,
    'RUMAGE': 0,
    'RUMAN': 0,
    'RUMANS': 0,
    'RUMBAOA': 0,
    'RUMBARGER': 0,
    'RUMBAUGH': 0,
    'RUMBEL': 0,
    'RUMBERG': 0,
    'RUMBERGER': 0,
    'RUMBLE': 0,
    'RUMBLEY': 0,
    'RUMBO': 0,
    'RUMBOLD': 0,
    'RUMBOLZ': 0,
    'RUMBURG': 0,
    'RUMEL': 0,
    'RUMELHART': 0,
    'RUMER': 0,
    'RUMERY': 0,
    'RUMFELT': 0,
    'RUMFIELD': 0,
    'RUMFOLA': 0,
    'RUMFORD': 0,
    'RUMINER': 0,
    'RUMINSKI': 0,
    'RUML': 0,
    'RUMLER': 0,
    'RUMLEY': 0,
    'RUMMAGE': 0,
    'RUMMANS': 0,
    'RUMMEL': 0,
    'RUMMELHART': 0,
    'RUMMELL': 0,
    'RUMMER': 0,
    'RUMMERFIELD': 0,
    'RUMMERY': 0,
    'RUMMINGS': 0,
    'RUMMLER': 0,
    'RUMNEY': 0,
    'RUMOHR': 0,
    'RUMORA': 0,
    'RUMORE': 0,
    'RUMP': 0,
    'RUMPCA': 0,
    'RUMPEL': 0,
    'RUMPF': 0,
    'RUMPFF': 0,
    'RUMPH': 0,
    'RUMPKE': 0,
    'RUMPLE': 0,
    'RUMPLER': 0,
    'RUMPS': 0,
    'RUMPZA': 0,
    'RUMRILL': 0,
    'RUMSCHLAG': 0,
    'RUMSEY': 0,
    'RUN': 0,
    'RUNBERG': 0,
    'RUNCHEY': 0,
    'RUNCI': 0,
    'RUNCIE': 0,
    'RUNCIMAN': 0,
    'RUNCK': 0,
    'RUNCO': 0,
    'RUND': 0,
    'RUNDALL': 0,
    'RUNDBERG': 0,
    'RUNDE': 0,
    'RUNDEL': 0,
    'RUNDELL': 0,
    'RUNDGREN': 0,
    'RUNDIO': 0,
    'RUNDLE': 0,
    'RUNDLES': 0,
    'RUNDLETT': 0,
    'RUNDQUIST': 0,
    'RUNDSTROM': 0,
    'RUNELS': 0,
    'RUNESTAD': 0,
    'RUNEY': 0,
    'RUNFOLA': 0,
    'RUNG': 0,
    'RUNGE': 0,
    'RUNIA': 0,
    'RUNION': 0,
    'RUNIONS': 0,
    'RUNK': 0,
    'RUNKE': 0,
    'RUNKEL': 0,
    'RUNKLE': 0,
    'RUNKLES': 0,
    'RUNNALLS': 0,
    'RUNNALS': 0,
    'RUNNE': 0,
    'RUNNEBAUM': 0,
    'RUNNELLS': 0,
    'RUNNELS': 0,
    'RUNNER': 0,
    'RUNNING': 0,
    'RUNNINGBEAR': 0,
    'RUNNINGCRANE': 0,
    'RUNNINGEN': 0,
    'RUNNION': 0,
    'RUNNOE': 0,
    'RUNO': 0,
    'RUNOLFSON': 0,
    'RUNQUIST': 0,
    'RUNSER': 0,
    'RUNSTROM': 0,
    'RUNTE': 0,
    'RUNTZ': 0,
    'RUNYAN': 0,
    'RUNYANS': 0,
    'RUNYARD': 0,
    'RUNYEN': 0,
    'RUNYON': 0,
    'RUO': 0,
    'RUOCCO': 0,
    'RUOF': 0,
    'RUOFF': 0,
    'RUONA': 0,
    'RUONAVAARA': 0,
    'RUOPP': 0,
    'RUOSS': 0,
    'RUOT': 0,
    'RUOTOLO': 0,
    'RUP': 0,
    'RUPANI': 0,
    'RUPAR': 0,
    'RUPARD': 0,
    'RUPE': 0,
    'RUPEL': 0,
    'RUPER': 0,
    'RUPERT': 0.6313131313131314,
    'RUPERTO': 0,
    'RUPERTUS': 0,
    'RUPINSKI': 0,
    'RUPIPER': 0,
    'RUPKE': 0,
    'RUPKEY': 0,
    'RUPLE': 0,
    'RUPLEY': 0,
    'RUPLINGER': 0,
    'RUPNICK': 0,
    'RUPNIK': 0,
    'RUPNOW': 0,
    'RUPOLO': 0,
    'RUPORT': 0,
    'RUPP': 0,
    'RUPPE': 0,
    'RUPPEL': 0,
    'RUPPELT': 0,
    'RUPPENTHAL': 0,
    'RUPPERT': 0,
    'RUPPLE': 0,
    'RUPPRECHT': 0,
    'RUPRECHT': 0,
    'RUPRIGHT': 0,
    'RURA': 0,
    'RURAK': 0,
    'RURKA': 0,
    'RURUP': 0,
    'RURY': 0,
    'RUS': 0,
    'RUSAK': 0,
    'RUSAN': 0,
    'RUSAW': 0,
    'RUSCA': 0,
    'RUSCETTA': 0,
    'RUSCH': 0,
    'RUSCHAK': 0,
    'RUSCHE': 0,
    'RUSCHEINSKY': 0,
    'RUSCHEL': 0,
    'RUSCHELL': 0,
    'RUSCHER': 0,
    'RUSCHMAN': 0,
    'RUSCHMANN': 0,
    'RUSCHMEIER': 0,
    'RUSCHMEYER': 0,
    'RUSCIANO': 0,
    'RUSCIGNO': 0,
    'RUSCIN': 0,
    'RUSCIO': 0,
    'RUSCIOLELLI': 0,
    'RUSCITO': 0,
    'RUSCITTI': 0,
    'RUSCITTO': 0,
    'RUSCO': 0,
    'RUSCOE': 0,
    'RUSCONI': 0,
    'RUSE': 0,
    'RUSEK': 0,
    'RUSELL': 0,
    'RUSEN': 0,
    'RUSER': 0,
    'RUSERT': 0,
    'RUSEV': 0,
    'RUSH': 0,
    'RUSHBROOK': 0,
    'RUSHDAN': 0,
    'RUSHE': 0,
    'RUSHEN': 0,
    'RUSHER': 0,
    'RUSHFORD': 0,
    'RUSHFORTH': 0,
    'RUSHIA': 0,
    'RUSHIN': 0,
    'RUSHING': 0,
    'RUSHLOW': 0,
    'RUSHMAN': 0,
    'RUSHMEYER': 0,
    'RUSHMORE': 0,
    'RUSHO': 0,
    'RUSHTON': 0,
    'RUSHWORTH': 0,
    'RUSICH': 0,
    'RUSIE': 0,
    'RUSIECKI': 0,
    'RUSIGNUOLO': 0,
    'RUSIN': 0,
    'RUSINAK': 0,
    'RUSINEK': 0,
    'RUSINIAK': 0,
    'RUSINKO': 0,
    'RUSINSKI': 0,
    'RUSK': 0,
    'RUSKA': 0,
    'RUSKAMP': 0,
    'RUSKE': 0,
    'RUSKEY': 0,
    'RUSKIN': 0,
    'RUSKO': 0,
    'RUSKOWSKI': 0,
    'RUSLER': 0,
    'RUSLEY': 0,
    'RUSLI': 0,
    'RUSLING': 0,
    'RUSMISEL': 0,
    'RUSNACK': 0,
    'RUSNAK': 0,
    'RUSNELL': 0,
    'RUSNOCK': 0,
    'RUSO': 0,
    'RUSOFF': 0,
    'RUSS': 0.5243445692883896,
    'RUSSACK': 0,
    'RUSSAK': 0,
    'RUSSANO': 0,
    'RUSSAW': 0,
    'RUSSE': 0,
    'RUSSEAU': 0,
    'RUSSEK': 0,
    'RUSSEL': 0.8982035928143712,
    'RUSSELBURG': 0,
    'RUSSELL': 0.7380436921865775,
    'RUSSELLO': 0,
    'RUSSEN': 0,
    'RUSSENBERGER': 0,
    'RUSSERT': 0,
    'RUSSETT': 0,
    'RUSSETTE': 0,
    'RUSSEY': 0,
    'RUSSI': 0,
    'RUSSIAN': 0,
    'RUSSICK': 0,
    'RUSSIE': 0,
    'RUSSILLO': 0,
    'RUSSIN': 0,
    'RUSSLER': 0,
    'RUSSMAN': 0,
    'RUSSO': 0,
    'RUSSOM': 0,
    'RUSSOMANNO': 0,
    'RUSSOMANO': 0,
    'RUSSON': 0,
    'RUSSONIELLO': 0,
    'RUSSOTTI': 0,
    'RUSSOTTO': 0,
    'RUSSOW': 0,
    'RUSSUM': 0,
    'RUST': 0,
    'RUSTAD': 0,
    'RUSTAN': 0,
    'RUSTAND': 0,
    'RUSTAY': 0,
    'RUSTEMEYER': 0,
    'RUSTEN': 0,
    'RUSTER': 0,
    'RUSTERHOLZ': 0,
    'RUSTHOVEN': 0,
    'RUSTIA': 0,
    'RUSTIC': 0,
    'RUSTICI': 0,
    'RUSTICK': 0,
    'RUSTICUS': 0,
    'RUSTIN': 0,
    'RUSTMAN': 0,
    'RUSTOM': 0,
    'RUSTON': 0,
    'RUSTRIAN': 0,
    'RUSTVOLD': 0,
    'RUSTY': 1,
    'RUSU': 0,
    'RUSYN': 0,
    'RUSZ': 0,
    'RUSZALA': 0,
    'RUSZCZYK': 0,
    'RUSZKIEWICZ': 0,
    'RUSZKOWSKI': 0,
    'RUT': 0,
    'RUTA': 0,
    'RUTAN': 0,
    'RUTAR': 0,
    'RUTBERG': 0,
    'RUTE': 0,
    'RUTECKI': 0,
    'RUTENBECK': 0,
    'RUTENBERG': 0,
    'RUTER': 0,
    'RUTGERS': 0,
    'RUTH': 0.9898897382604713,
    'RUTHA': 1,
    'RUTHANN': 1,
    'RUTHANNE': 1,
    'RUTHARDT': 0,
    'RUTHART': 0,
    'RUTHE': 0.9433962264150944,
    'RUTHEFORD': 0,
    'RUTHENBECK': 0,
    'RUTHENBERG': 0,
    'RUTHER': 0,
    'RUTHERFORD': 0,
    'RUTHFORD': 0,
    'RUTHIE': 1,
    'RUTHIG': 0,
    'RUTHLEDGE': 0,
    'RUTHMAN': 0,
    'RUTHRAUFF': 0,
    'RUTHRUFF': 0,
    'RUTHS': 0,
    'RUTHSTROM': 0,
    'RUTHVEN': 0,
    'RUTIAGA': 0,
    'RUTIGLIANO': 0,
    'RUTISHAUSER': 0,
    'RUTKA': 0,
    'RUTKAUSKAS': 0,
    'RUTKIEWICZ': 0,
    'RUTKIN': 0,
    'RUTKOSKI': 0,
    'RUTKOSKY': 0,
    'RUTKOWSKI': 0,
    'RUTKOWSKY': 0,
    'RUTLAND': 0,
    'RUTLEDGE': 0,
    'RUTLER': 0,
    'RUTLEY': 0,
    'RUTLIN': 0,
    'RUTMAN': 0,
    'RUTNER': 0,
    'RUTOWSKI': 0,
    'RUTROUGH': 0,
    'RUTSCH': 0,
    'RUTSCHILLING': 0,
    'RUTSCHKE': 0,
    'RUTSCHMAN': 0,
    'RUTSKY': 0,
    'RUTSTEIN': 0,
    'RUTT': 0,
    'RUTTA': 0,
    'RUTTAN': 0,
    'RUTTEN': 0,
    'RUTTENBERG': 0,
    'RUTTENBUR': 0,
    'RUTTER': 0,
    'RUTTI': 0,
    'RUTTINGER': 0,
    'RUTTLE': 0,
    'RUTTLEY': 0,
    'RUTTMAN': 0,
    'RUTTNER': 0,
    'RUTTY': 0,
    'RUTYNA': 0,
    'RUTZ': 0,
    'RUTZEN': 0,
    'RUUD': 0,
    'RUUSKA': 0,
    'RUVALCABA': 0,
    'RUVALCAVA': 0,
    'RUVIO': 0,
    'RUVO': 0,
    'RUVOLO': 0,
    'RUWE': 0,
    'RUX': 0,
    'RUXER': 0,
    'RUXTON': 0,
    'RUYBAL': 0,
    'RUYBALID': 0,
    'RUYLE': 0,
    'RUYS': 0,
    'RUYTER': 0,
    'RUZ': 0,
    'RUZANSKI': 0,
    'RUZBASAN': 0,
    'RUZEK': 0,
    'RUZIC': 0,
    'RUZICH': 0,
    'RUZICK': 0,
    'RUZICKA': 0,
    'RUZYCKI': 0,
    'RUZZANO': 0,
    'RUZZI': 0,
    'RUZZO': 0,
    'RY': 0,
    'RYAL': 0,
    'RYALL': 0,
    'RYALLS': 0,
    'RYALS': 0,
    'RYAN': 0.8660702709710878,
    'RYANN': 1,
    'RYANS': 0,
    'RYANT': 0,
    'RYBA': 0,
    'RYBACK': 0,
    'RYBACKI': 0,
    'RYBAK': 0,
    'RYBAKOV': 0,
    'RYBAR': 0,
    'RYBARCZYK': 0,
    'RYBARSKI': 0,
    'RYBCZYK': 0,
    'RYBCZYNSKI': 0,
    'RYBECK': 0,
    'RYBERG': 0,
    'RYBICKI': 0,
    'RYBIN': 0,
    'RYBINSKI': 0,
    'RYBKA': 0,
    'RYBOLT': 0,
    'RYBSKI': 0,
    'RYBURN': 0,
    'RYCE': 0,
    'RYCERZ': 0,
    'RYCHEL': 0,
    'RYCHENER': 0,
    'RYCHLICKI': 0,
    'RYCHLIK': 0,
    'RYCKMAN': 0,
    'RYCRAFT': 0,
    'RYCROFT': 0,
    'RYCZEK': 0,
    'RYDALCH': 0,
    'RYDBERG': 0,
    'RYDBOM': 0,
    'RYDEEN': 0,
    'RYDEL': 0,
    'RYDELL': 0,
    'RYDEN': 0,
    'RYDER': 0,
    'RYDHOLM': 0,
    'RYDIN': 0,
    'RYDING': 0,
    'RYDMAN': 0,
    'RYDQUIST': 0,
    'RYDSTROM': 0,
    'RYDZ': 0,
    'RYDZAK': 0,
    'RYDZEWSKI': 0,
    'RYDZIK': 0,
    'RYDZINSKI': 0,
    'RYDZYNSKI': 0,
    'RYE': 0,
    'RYEA': 0,
    'RYEL': 0,
    'RYEN': 0,
    'RYER': 0,
    'RYERSE': 0,
    'RYERSON': 0,
    'RYES': 0,
    'RYF': 0,
    'RYFF': 0,
    'RYG': 0,
    'RYGALSKI': 0,
    'RYGG': 0,
    'RYGH': 0,
    'RYGIEL': 0,
    'RYHAL': 0,
    'RYHERD': 0,
    'RYKACZEWSKI': 0,
    'RYKAL': 0,
    'RYKARD': 0,
    'RYKEN': 0,
    'RYKER': 0,
    'RYKERT': 0,
    'RYKHUS': 0,
    'RYKIEL': 0,
    'RYKKEN': 0,
    'RYKOWSKI': 0,
    'RYKS': 0,
    'RYKSE': 0,
    'RYLANCE': 0,
    'RYLAND': 0,
    'RYLANDER': 0,
    'RYLANDS': 0,
    'RYLANT': 0,
    'RYLE': 0,
    'RYLEE': 0,
    'RYLES': 0,
    'RYLEY': 0,
    'RYLKO': 0,
    'RYLL': 0,
    'RYMAL': 0,
    'RYMAN': 0,
    'RYMAR': 0,
    'RYMARZ': 0,
    'RYMEL': 0,
    'RYMER': 0,
    'RYMERS': 0,
    'RYMES': 0,
    'RYMSZA': 0,
    'RYMUT': 0,
    'RYNARD': 0,
    'RYND': 0,
    'RYNDA': 0,
    'RYNDAK': 0,
    'RYNDERS': 0,
    'RYNE': 0,
    'RYNEARSON': 0,
    'RYNER': 0,
    'RYNERSON': 0,
    'RYNES': 0,
    'RYNIAK': 0,
    'RYNIEC': 0,
    'RYNKIEWICZ': 0,
    'RYNKOWSKI': 0,
    'RYNN': 0,
    'RYNNE': 0,
    'RYNNING': 0,
    'RYNO': 0,
    'RYON': 0,
    'RYOO': 0,
    'RYOU': 0,
    'RYPKEMA': 0,
    'RYPMA': 0,
    'RYS': 0,
    'RYSAVY': 0,
    'RYSDAM': 0,
    'RYSER': 0,
    'RYSKAMP': 0,
    'RYSTROM': 0,
    'RYSZ': 0,
    'RYTEL': 0,
    'RYTER': 0,
    'RYTERSKI': 0,
    'RYTHER': 0,
    'RYTLEWSKI': 0,
    'RYTTER': 0,
    'RYTTING': 0,
    'RYU': 0,
    'RYUN': 0,
    'RYZA': 0,
    'RYZAK': 0,
    'RYZNAR': 0,
    'RYZNER': 0,
    'RZASA': 0,
    'RZECZKOWSKI': 0,
    'RZEPECKI': 0,
    'RZEPKA': 0,
    'RZEPKOWSKI': 0,
    'RZEPPA': 0,
    'RZESZUT': 0,
    'RZESZUTEK': 0,
    'RZESZUTKO': 0,
    'RZEWNICKI': 0,
    'RZEZNIK': 0,
    'RZONCA': 0,
    'RZUCIDLO': 0,
    'SA': 0,
    'SAA': 0,
    'SAAB': 0,
    'SAABEDRA': 0,
    'SAAD': 0,
    'SAADA': 0,
    'SAADAT': 0,
    'SAADE': 0,
    'SAADEH': 0,
    'SAADI': 0,
    'SAAF': 0,
    'SAAFIR': 0,
    'SAAGER': 0,
    'SAAH': 0,
    'SAAK': 0,
    'SAAKE': 0,
    'SAAKIAN': 0,
    'SAAKYAN': 0,
    'SAAL': 0,
    'SAALE': 0,
    'SAALFELD': 0,
    'SAALFRANK': 0,
    'SAALMAN': 0,
    'SAALWAECHTER': 0,
    'SAAM': 0,
    'SAAR': 0,
    'SAARELA': 0,
    'SAARI': 0,
    'SAARINEN': 0,
    'SAAS': 0,
    'SAATHOFF': 0,
    'SAATKAMP': 0,
    'SAATZER': 0,
    'SAAVEDRA': 0,
    'SABA': 0,
    'SABADO': 0,
    'SABADOS': 0,
    'SABAG': 0,
    'SABAH': 0,
    'SABAJ': 0,
    'SABAL': 0,
    'SABALA': 0,
    'SABALLA': 0,
    'SABALLOS': 0,
    'SABALZA': 0,
    'SABAN': 0,
    'SABANAGIC': 0,
    'SABANDO': 0,
    'SABANGAN': 0,
    'SABANI': 0,
    'SABANOVIC': 0,
    'SABAS': 0,
    'SABAT': 0,
    'SABATA': 0,
    'SABATE': 0,
    'SABATELLA': 0,
    'SABATELLI': 0,
    'SABATELLO': 0,
    'SABATER': 0,
    'SABATES': 0,
    'SABATH': 0,
    'SABATIER': 0,
    'SABATINE': 0,
    'SABATINI': 0,
    'SABATINO': 0,
    'SABATKA': 0,
    'SABATKE': 0,
    'SABATO': 0,
    'SABB': 0,
    'SABBAG': 0,
    'SABBAGH': 0,
    'SABBAH': 0,
    'SABBATH': 0,
    'SABBATINI': 0,
    'SABBATINO': 0,
    'SABBE': 0,
    'SABBIA': 0,
    'SABBS': 0,
    'SABBY': 0,
    'SABEAN': 0,
    'SABEC': 0,
    'SABEDRA': 0,
    'SABEH': 0,
    'SABEL': 0,
    'SABELHAUS': 0,
    'SABELKO': 0,
    'SABELL': 0,
    'SABELLA': 0,
    'SABELLI': 0,
    'SABELLICO': 0,
    'SABEN': 0,
    'SABENS': 0,
    'SABER': 0,
    'SABERI': 0,
    'SABERON': 0,
    'SABERS': 0,
    'SABET': 0,
    'SABETI': 0,
    'SABETTA': 0,
    'SABETTI': 0,
    'SABEY': 0,
    'SABHARWAL': 0,
    'SABIA': 0,
    'SABIC': 0,
    'SABIDO': 0,
    'SABIE': 0,
    'SABIK': 0,
    'SABILLON': 0,
    'SABIN': 0,
    'SABINA': 0.9689922480620156,
    'SABINE': 0.9036144578313253,
    'SABINI': 0,
    'SABINO': 0,
    'SABINS': 0,
    'SABIO': 0,
    'SABIR': 0,
    'SABISCH': 0,
    'SABISTON': 0,
    'SABLAN': 0,
    'SABLATURA': 0,
    'SABLE': 0,
    'SABLICH': 0,
    'SABLON': 0,
    'SABLOSKY': 0,
    'SABNIS': 0,
    'SABO': 0,
    'SABOE': 0,
    'SABOGAL': 0,
    'SABOL': 0,
    'SABON': 0,
    'SABONIS': 0,
    'SABORI': 0,
    'SABORIO': 0,
    'SABOT': 0,
    'SABOTA': 0,
    'SABOTKA': 0,
    'SABOURIN': 0,
    'SABOVIC': 0,
    'SABRA': 0.9646302250803858,
    'SABRE': 0,
    'SABREE': 0,
    'SABRI': 0,
    'SABRINA': 1,
    'SABROWSKI': 0,
    'SABROWSKY': 0,
    'SABRSULA': 0,
    'SABU': 0,
    'SABUDA': 0,
    'SABUGO': 0,
    'SABULSKY': 0,
    'SABUR': 0,
    'SABUS': 0,
    'SABY': 0,
    'SAC': 0,
    'SACA': 0,
    'SACASA': 0,
    'SACCA': 0,
    'SACCARDI': 0,
    'SACCARDO': 0,
    'SACCARO': 0,
    'SACCENTE': 0,
    'SACCHETTI': 0,
    'SACCHI': 0,
    'SACCO': 0,
    'SACCOCCIA': 0,
    'SACCOCCIO': 0,
    'SACCOMAN': 0,
    'SACCOMANNO': 0,
    'SACCOMANO': 0,
    'SACCONE': 0,
    'SACCUCCI': 0,
    'SACDALAN': 0,
    'SACERDOTE': 0,
    'SACH': 0,
    'SACHA': 0.8849557522123894,
    'SACHAR': 0,
    'SACHAU': 0,
    'SACHDEV': 0,
    'SACHDEVA': 0,
    'SACHELI': 0,
    'SACHEN': 0,
    'SACHER': 0,
    'SACHETTI': 0,
    'SACHIKO': 1,
    'SACHLEBEN': 0,
    'SACHS': 0,
    'SACHSE': 0,
    'SACHTJEN': 0,
    'SACHTLEBEN': 0,
    'SACIA': 0,
    'SACILOWSKI': 0,
    'SACINO': 0,
    'SACK': 0,
    'SACKEL': 0,
    'SACKENHEIM': 0,
    'SACKER': 0,
    'SACKET': 0,
    'SACKETT': 0,
    'SACKEY': 0,
    'SACKIE': 0,
    'SACKIN': 0,
    'SACKLER': 0,
    'SACKMAN': 0,
    'SACKMANN': 0,
    'SACKMASTER': 0,
    'SACKO': 0,
    'SACKREITER': 0,
    'SACKRIDER': 0,
    'SACKRISON': 0,
    'SACKS': 0,
    'SACKSON': 0,
    'SACKSTEDER': 0,
    'SACO': 0,
    'SACRA': 0,
    'SACRAMENTO': 0,
    'SACRAMONE': 0,
    'SACRE': 0,
    'SACRO': 0,
    'SACZAWA': 0,
    'SAD': 0,
    'SADA': 0,
    'SADAK': 0,
    'SADAKA': 0,
    'SADANG': 0,
    'SADAR': 0,
    'SADARANGANI': 0,
    'SADAT': 0,
    'SADAUSKAS': 0,
    'SADBERRY': 0,
    'SADD': 0,
    'SADDLEMIRE': 0,
    'SADDLER': 0,
    'SADDORIS': 0,
    'SADE': 0.9523809523809524,
    'SADECKI': 0,
    'SADEGHI': 0,
    'SADEGHIAN': 0,
    'SADEK': 0,
    'SADER': 0,
    'SADEWASSER': 0,
    'SADHU': 0,
    'SADHWANI': 0,
    'SADI': 0,
    'SADIA': 0,
    'SADICK': 0,
    'SADIE': 0.9984639016897081,
    'SADIGH': 0,
    'SADIGHI': 0,
    'SADIK': 0,
    'SADIKU': 0,
    'SADILEK': 0,
    'SADIQ': 0,
    'SADKOWSKI': 0,
    'SADLEIR': 0,
    'SADLER': 0,
    'SADLEY': 0,
    'SADLIER': 0,
    'SADLO': 0,
    'SADLON': 0,
    'SADLOWSKI': 0,
    'SADO': 0,
    'SADOFF': 0,
    'SADOFSKY': 0,
    'SADORF': 0,
    'SADORRA': 0,
    'SADOSKI': 0,
    'SADOSKY': 0,
    'SADOW': 0,
    'SADOWSKI': 0,
    'SADOWSKY': 0,
    'SADOWY': 0,
    'SADR': 0,
    'SADRI': 0,
    'SADRUDDIN': 0,
    'SADSAD': 0,
    'SADTLER': 0,
    'SADUSKY': 0,
    'SADY': 0,
    'SADYE': 1,
    'SADZEWICZ': 0,
    'SAE': 0,
    'SAECHAO': 0,
    'SAECHIN': 0,
    'SAED': 0,
    'SAEDI': 0,
    'SAEED': 0,
    'SAEEDI': 0,
    'SAEFONG': 0,
    'SAEGER': 0,
    'SAEGERT': 0,
    'SAEKI': 0,
    'SAELEE': 0,
    'SAELENS': 0,
    'SAELER': 0,
    'SAELI': 0,
    'SAEMAN': 0,
    'SAENGER': 0,
    'SAENS': 0,
    'SAENZ': 0,
    'SAEPHAN': 0,
    'SAEPHANH': 0,
    'SAEPHARN': 0,
    'SAESEE': 0,
    'SAETANG': 0,
    'SAETERN': 0,
    'SAETEURN': 0,
    'SAETHER': 0,
    'SAETTA': 0,
    'SAETURN': 0,
    'SAEVA': 0,
    'SAEVANG': 0,
    'SAEWERT': 0,
    'SAEYANG': 0,
    'SAEZ': 0,
    'SAFA': 0,
    'SAFADI': 0,
    'SAFADY': 0,
    'SAFAI': 0,
    'SAFAR': 0,
    'SAFARI': 0,
    'SAFARIAN': 0,
    'SAFARIK': 0,
    'SAFARYAN': 0,
    'SAFAVI': 0,
    'SAFDAR': 0,
    'SAFDARI': 0,
    'SAFDIE': 0,
    'SAFDIEH': 0,
    'SAFE': 0,
    'SAFER': 0,
    'SAFERIGHT': 0,
    'SAFERSTEIN': 0,
    'SAFEWRIGHT': 0,
    'SAFFA': 0,
    'SAFFEL': 0,
    'SAFFELL': 0,
    'SAFFELS': 0,
    'SAFFER': 0,
    'SAFFERT': 0,
    'SAFFERY': 0,
    'SAFFIOTI': 0,
    'SAFFLE': 0,
    'SAFFLES': 0,
    'SAFFO': 0,
    'SAFFOLD': 0,
    'SAFFORD': 0,
    'SAFFORE': 0,
    'SAFFRAN': 0,
    'SAFFRON': 0,
    'SAFI': 0,
    'SAFIAN': 0,
    'SAFIER': 0,
    'SAFIN': 0,
    'SAFINA': 0,
    'SAFIR': 0,
    'SAFKO': 0,
    'SAFLEY': 0,
    'SAFO': 0,
    'SAFRAN': 0,
    'SAFRANEK': 0,
    'SAFRANSKI': 0,
    'SAFREED': 0,
    'SAFRIET': 0,
    'SAFRIN': 0,
    'SAFRIT': 0,
    'SAFRON': 0,
    'SAFSTROM': 0,
    'SAFT': 0,
    'SAGA': 0,
    'SAGADRACA': 0,
    'SAGAL': 0,
    'SAGALA': 0,
    'SAGAN': 0,
    'SAGAPOLU': 0,
    'SAGAR': 0,
    'SAGARA': 0,
    'SAGARIO': 0,
    'SAGARNAGA': 0,
    'SAGASER': 0,
    'SAGASTA': 0,
    'SAGASTIZADO': 0,
    'SAGASTUME': 0,
    'SAGAT': 0,
    'SAGAWA': 0,
    'SAGE': 0.20161290322580647,
    'SAGEBIEL': 0,
    'SAGEHORN': 0,
    'SAGEL': 0,
    'SAGELY': 0,
    'SAGEMAN': 0,
    'SAGEN': 0,
    'SAGENDORF': 0,
    'SAGENDORPH': 0,
    'SAGER': 0,
    'SAGERS': 0,
    'SAGERT': 0,
    'SAGESER': 0,
    'SAGET': 0,
    'SAGGAU': 0,
    'SAGGESE': 0,
    'SAGGIO': 0,
    'SAGGUS': 0,
    'SAGHAFI': 0,
    'SAGHERIAN': 0,
    'SAGHIAN': 0,
    'SAGHIR': 0,
    'SAGHY': 0,
    'SAGI': 0,
    'SAGINARIO': 0,
    'SAGISI': 0,
    'SAGLE': 0,
    'SAGLIMBENE': 0,
    'SAGLIMBENI': 0,
    'SAGNELLA': 0,
    'SAGNER': 0,
    'SAGO': 0,
    'SAGON': 0,
    'SAGONA': 0,
    'SAGOR': 0,
    'SAGRAVES': 0,
    'SAGREDO': 0,
    'SAGRERA': 0,
    'SAGRERO': 0,
    'SAGSTETTER': 0,
    'SAGUCIO': 0,
    'SAGUE': 0,
    'SAGUILAN': 0,
    'SAGUN': 0,
    'SAH': 0,
    'SAHA': 0,
    'SAHADEO': 0,
    'SAHADI': 0,
    'SAHAGIAN': 0,
    'SAHAGUN': 0,
    'SAHAI': 0,
    'SAHAKIAN': 0,
    'SAHAKYAN': 0,
    'SAHAR': 0,
    'SAHARA': 0,
    'SAHAWNEH': 0,
    'SAHAY': 0,
    'SAHD': 0,
    'SAHGAL': 0,
    'SAHI': 0,
    'SAHIN': 0,
    'SAHL': 0,
    'SAHLBERG': 0,
    'SAHLE': 0,
    'SAHLER': 0,
    'SAHLI': 0,
    'SAHLIN': 0,
    'SAHLMAN': 0,
    'SAHLSTROM': 0,
    'SAHM': 0,
    'SAHN': 0,
    'SAHNI': 0,
    'SAHNOW': 0,
    'SAHO': 0,
    'SAHOO': 0,
    'SAHOTA': 0,
    'SAHR': 0,
    'SAHS': 0,
    'SAHU': 0,
    'SAHYOUN': 0,
    'SAI': 0,
    'SAIA': 0,
    'SAIAS': 0,
    'SAIAZAR': 0,
    'SAICE': 0,
    'SAICH': 0,
    'SAID': 0,
    'SAIDANA': 0,
    'SAIDE': 0,
    'SAIDEL': 0,
    'SAIDI': 0,
    'SAIDY': 0,
    'SAIED': 0,
    'SAIENNI': 0,
    'SAIEVA': 0,
    'SAIF': 0,
    'SAIFI': 0,
    'SAIGADO': 0,
    'SAIGAL': 0,
    'SAIGE': 0,
    'SAIGER': 0,
    'SAIGH': 0,
    'SAIIA': 0,
    'SAIKI': 0,
    'SAILAS': 0,
    'SAILE': 0,
    'SAILER': 0,
    'SAILERS': 0,
    'SAILES': 0,
    'SAILING': 0,
    'SAILLANT': 0,
    'SAILOR': 0,
    'SAILORS': 0,
    'SAILS': 0,
    'SAILSBURY': 0,
    'SAIN': 0,
    'SAINATO': 0,
    'SAINDON': 0,
    'SAINE': 0,
    'SAINES': 0,
    'SAING': 0,
    'SAINI': 0,
    'SAINS': 0,
    'SAINSBURY': 0,
    'SAINT': 0,
    'SAINTAMAND': 0,
    'SAINTCLAIR': 0,
    'SAINTCYR': 0,
    'SAINTE': 0,
    'SAINTELUS': 0,
    'SAINTFLEUR': 0,
    'SAINTFORT': 0,
    'SAINTGERMAIN': 0,
    'SAINTHILAIRE': 0,
    'SAINTIL': 0,
    'SAINTILUS': 0,
    'SAINTJEAN': 0,
    'SAINTJOHN': 0,
    'SAINTJUSTE': 0,
    'SAINTLOUIS': 0,
    'SAINTONGE': 0,
    'SAINTPIERRE': 0,
    'SAINTPREUX': 0,
    'SAINTSING': 0,
    'SAINTSURIN': 0,
    'SAINTVICTOR': 0,
    'SAINTVIL': 0,
    'SAINTZ': 0,
    'SAINVIL': 0,
    'SAINZ': 0,
    'SAIS': 0,
    'SAITA': 0,
    'SAITER': 0,
    'SAITO': 0,
    'SAITTA': 0,
    'SAITZ': 0,
    'SAIYED': 0,
    'SAIZ': 0,
    'SAIZA': 0,
    'SAIZAN': 0,
    'SAJ': 0,
    'SAJA': 0,
    'SAJDAK': 0,
    'SAJEWSKI': 0,
    'SAJID': 0,
    'SAJJAD': 0,
    'SAJOR': 0,
    'SAJOUS': 0,
    'SAJUAN': 0,
    'SAK': 0,
    'SAKA': 0,
    'SAKACH': 0,
    'SAKAGUCHI': 0,
    'SAKAHARA': 0,
    'SAKAI': 0,
    'SAKAKIBARA': 0,
    'SAKAL': 0,
    'SAKALA': 0,
    'SAKAMOTO': 0,
    'SAKANOVIC': 0,
    'SAKAR': 0,
    'SAKARIA': 0,
    'SAKAS': 0,
    'SAKATA': 0,
    'SAKAUYE': 0,
    'SAKE': 0,
    'SAKELARIS': 0,
    'SAKELLARIOU': 0,
    'SAKELLARIS': 0,
    'SAKER': 0,
    'SAKERS': 0,
    'SAKHI': 0,
    'SAKI': 0,
    'SAKIHARA': 0,
    'SAKIN': 0,
    'SAKIS': 0,
    'SAKKAL': 0,
    'SAKKAS': 0,
    'SAKMAR': 0,
    'SAKO': 0,
    'SAKODA': 0,
    'SAKOVICH': 0,
    'SAKOWICZ': 0,
    'SAKOWITZ': 0,
    'SAKOWSKI': 0,
    'SAKR': 0,
    'SAKRY': 0,
    'SAKS': 0,
    'SAKSA': 0,
    'SAKUDA': 0,
    'SAKUMA': 0,
    'SAKUMOTO': 0,
    'SAKURADA': 0,
    'SAKURAI': 0,
    'SAL': 0.9803921568627452,
    'SALA': 0,
    'SALAAM': 0,
    'SALABA': 0,
    'SALABARRIA': 0,
    'SALAC': 0,
    'SALACH': 0,
    'SALACUP': 0,
    'SALAD': 0,
    'SALADA': 0,
    'SALADIN': 0,
    'SALADINO': 0,
    'SALADO': 0,
    'SALADRIGAS': 0,
    'SALAFIA': 0,
    'SALAH': 0,
    'SALAHI': 0,
    'SALAHUDDIN': 0,
    'SALAICES': 0,
    'SALAIS': 0,
    'SALAISES': 0,
    'SALAIZ': 0,
    'SALAK': 0,
    'SALAKO': 0,
    'SALAM': 0,
    'SALAMA': 0,
    'SALAMACHA': 0,
    'SALAMAN': 0,
    'SALAMANCA': 0,
    'SALAMAT': 0,
    'SALAME': 0,
    'SALAMEH': 0,
    'SALAMI': 0,
    'SALAMIDA': 0,
    'SALAMON': 0,
    'SALAMONE': 0,
    'SALAMY': 0,
    'SALAN': 0,
    'SALANDANAN': 0,
    'SALANDER': 0,
    'SALANDRA': 0,
    'SALANDY': 0,
    'SALANGA': 0,
    'SALANGSANG': 0,
    'SALANI': 0,
    'SALANITRO': 0,
    'SALANO': 0,
    'SALANOA': 0,
    'SALANSKY': 0,
    'SALANT': 0,
    'SALARD': 0,
    'SALARI': 0,
    'SALARY': 0,
    'SALAS': 0,
    'SALASAR': 0,
    'SALASSI': 0,
    'SALAT': 0,
    'SALATA': 0,
    'SALATHE': 0,
    'SALATI': 0,
    'SALATIN': 0,
    'SALATINO': 0,
    'SALATO': 0,
    'SALAUN': 0,
    'SALAVA': 0,
    'SALAVARRIA': 0,
    'SALAVERRIA': 0,
    'SALAY': 0,
    'SALAYANDIA': 0,
    'SALAZ': 0,
    'SALAZAR': 0,
    'SALAZER': 0,
    'SALB': 0,
    'SALBER': 0,
    'SALBERG': 0,
    'SALCE': 0,
    'SALCEDA': 0,
    'SALCEDO': 0,
    'SALCH': 0,
    'SALCHERT': 0,
    'SALCHOW': 0,
    'SALCIDO': 0,
    'SALCITO': 0,
    'SALDANA': 0,
    'SALDANHA': 0,
    'SALDANIA': 0,
    'SALDANO': 0,
    'SALDARRIAGA': 0,
    'SALDATE': 0,
    'SALDEN': 0,
    'SALDI': 0,
    'SALDIBAR': 0,
    'SALDIERNA': 0,
    'SALDIN': 0,
    'SALDIVA': 0,
    'SALDIVAR': 0,
    'SALDO': 0,
    'SALDUA': 0,
    'SALDUTTI': 0,
    'SALE': 0,
    'SALEE': 0,
    'SALEEBA': 0,
    'SALEEBY': 0,
    'SALEEM': 0,
    'SALEEN': 0,
    'SALEH': 0,
    'SALEHI': 0,
    'SALEK': 0,
    'SALEM': 0,
    'SALEMA': 0,
    'SALEME': 0,
    'SALEMI': 0,
    'SALEMME': 0,
    'SALEN': 0,
    'SALENA': 1,
    'SALENGA': 0,
    'SALENTINE': 0,
    'SALER': 0,
    'SALERA': 0,
    'SALERNI': 0,
    'SALERNO': 0,
    'SALERS': 0,
    'SALERY': 0,
    'SALES': 0,
    'SALESE': 0,
    'SALESKI': 0,
    'SALESKY': 0,
    'SALESMAN': 0,
    'SALET': 0,
    'SALETNIK': 0,
    'SALETTA': 0,
    'SALEWSKI': 0,
    'SALEWSKY': 0,
    'SALEY': 0,
    'SALFER': 0,
    'SALFI': 0,
    'SALG': 0,
    'SALGADO': 0,
    'SALGAT': 0,
    'SALGE': 0,
    'SALGER': 0,
    'SALGUEIRO': 0,
    'SALGUERO': 0,
    'SALHA': 0,
    'SALHAB': 0,
    'SALHANY': 0,
    'SALHUS': 0,
    'SALI': 0,
    'SALIB': 0,
    'SALIBA': 0,
    'SALIBI': 0,
    'SALIC': 0,
    'SALICE': 0,
    'SALICK': 0,
    'SALIDO': 0,
    'SALIE': 0,
    'SALIERNO': 0,
    'SALIGA': 0,
    'SALIGAN': 0,
    'SALIH': 0,
    'SALIHOVIC': 0,
    'SALIK': 0,
    'SALIM': 0,
    'SALIMA': 0,
    'SALIMAN': 0,
    'SALIMBENE': 0,
    'SALIMI': 0,
    'SALIN': 0,
    'SALINA': 0.9456264775413711,
    'SALINAS': 0,
    'SALINAZ': 0,
    'SALINE': 0,
    'SALINES': 0,
    'SALING': 0,
    'SALINGER': 0,
    'SALINGS': 0,
    'SALINO': 0,
    'SALINS': 0,
    'SALINSKY': 0,
    'SALIS': 0,
    'SALISBURY': 0,
    'SALIT': 0,
    'SALITA': 0,
    'SALIU': 0,
    'SALIVA': 0,
    'SALIZAR': 0,
    'SALK': 0,
    'SALKA': 0,
    'SALKELD': 0,
    'SALKEY': 0,
    'SALKIC': 0,
    'SALKIN': 0,
    'SALKIND': 0,
    'SALKO': 0,
    'SALKOWSKI': 0,
    'SALL': 0,
    'SALLA': 0,
    'SALLACH': 0,
    'SALLADA': 0,
    'SALLADAY': 0,
    'SALLADE': 0,
    'SALLAH': 0,
    'SALLAM': 0,
    'SALLARD': 0,
    'SALLAS': 0,
    'SALLAWAY': 0,
    'SALLAY': 0,
    'SALLAZ': 0,
    'SALLE': 0,
    'SALLEE': 0,
    'SALLEN': 0,
    'SALLER': 0,
    'SALLES': 0,
    'SALLESE': 0,
    'SALLET': 0,
    'SALLETTE': 0,
    'SALLEY': 0.33444816053511706,
    'SALLI': 0,
    'SALLIE': 0.9864364981504316,
    'SALLIER': 0,
    'SALLIN': 0,
    'SALLING': 0,
    'SALLINGER': 0,
    'SALLINGS': 0,
    'SALLIOTTE': 0,
    'SALLIS': 0,
    'SALLMAN': 0,
    'SALLMEN': 0,
    'SALLO': 0,
    'SALLOUM': 0,
    'SALLOWS': 0,
    'SALLS': 0,
    'SALLUSTIO': 0,
    'SALLY': 0.9966777408637875,
    'SALM': 0,
    'SALMA': 0,
    'SALMAN': 0,
    'SALMANS': 0,
    'SALMELA': 0,
    'SALMEN': 0,
    'SALMERI': 0,
    'SALMERON': 0,
    'SALMI': 0,
    'SALMIERI': 0,
    'SALMINEN': 0,
    'SALMO': 0,
    'SALMON': 0,
    'SALMOND': 0,
    'SALMONS': 0,
    'SALMONSEN': 0,
    'SALMONSON': 0,
    'SALNAVE': 0,
    'SALO': 0,
    'SALOIS': 0,
    'SALOKA': 0,
    'SALOM': 0,
    'SALOMAN': 0,
    'SALOME': 0.8968609865470852,
    'SALOMON': 0,
    'SALOMONE': 0,
    'SALOMONSON': 0,
    'SALON': 0,
    'SALONE': 0,
    'SALONEK': 0,
    'SALONEN': 0,
    'SALONGA': 0,
    'SALONIA': 0,
    'SALONY': 0,
    'SALOOM': 0,
    'SALOPEK': 0,
    'SALOTTI': 0,
    'SALOTTO': 0,
    'SALOUM': 0,
    'SALOW': 0,
    'SALOWITZ': 0,
    'SALPETER': 0,
    'SALPIETRO': 0,
    'SALRIN': 0,
    'SALSA': 0,
    'SALSBERG': 0,
    'SALSBERRY': 0,
    'SALSBERY': 0,
    'SALSBURG': 0,
    'SALSBURY': 0,
    'SALSE': 0,
    'SALSEDO': 0,
    'SALSER': 0,
    'SALSGIVER': 0,
    'SALSIDO': 0,
    'SALSMAN': 0,
    'SALSTROM': 0,
    'SALT': 0,
    'SALTA': 0,
    'SALTALAMACCHIA': 0,
    'SALTARELLI': 0,
    'SALTARES': 0,
    'SALTER': 0,
    'SALTERS': 0,
    'SALTI': 0,
    'SALTIEL': 0,
    'SALTIS': 0,
    'SALTKILL': 0,
    'SALTMAN': 0,
    'SALTMARSH': 0,
    'SALTO': 0,
    'SALTON': 0,
    'SALTONSTALL': 0,
    'SALTOS': 0,
    'SALTS': 0,
    'SALTSGAVER': 0,
    'SALTSGIVER': 0,
    'SALTSMAN': 0,
    'SALTUS': 0,
    'SALTZ': 0,
    'SALTZBERG': 0,
    'SALTZBURG': 0,
    'SALTZER': 0,
    'SALTZGIVER': 0,
    'SALTZMAN': 0,
    'SALTZMANN': 0,
    'SALUD': 0,
    'SALUDARES': 0,
    'SALUDES': 0,
    'SALUGA': 0,
    'SALUJA': 0,
    'SALUM': 0,
    'SALUMBIDES': 0,
    'SALUPO': 0,
    'SALUS': 0,
    'SALUSTRO': 0,
    'SALUTA': 0,
    'SALUTE': 0,
    'SALVA': 0,
    'SALVACION': 0,
    'SALVADO': 0,
    'SALVADOR': 0.937440214272049,
    'SALVADORE': 0,
    'SALVADORI': 0,
    'SALVAGE': 0,
    'SALVAGGIO': 0,
    'SALVAGIO': 0,
    'SALVAGNI': 0,
    'SALVAGNO': 0,
    'SALVAIL': 0,
    'SALVANO': 0,
    'SALVANT': 0,
    'SALVAS': 0,
    'SALVAT': 0,
    'SALVATERRA': 0,
    'SALVATI': 0,
    'SALVATIERRA': 0,
    'SALVATO': 0,
    'SALVATOR': 0,
    'SALVATORE': 0.9348807221147647,
    'SALVATORI': 0,
    'SALVATORIELLO': 0,
    'SALVEMINI': 0,
    'SALVERSON': 0,
    'SALVESEN': 0,
    'SALVESON': 0,
    'SALVETTI': 0,
    'SALVI': 0,
    'SALVIA': 0,
    'SALVIEJO': 0,
    'SALVIN': 0,
    'SALVINI': 0,
    'SALVINO': 0,
    'SALVIO': 0,
    'SALVITTI': 0,
    'SALVO': 0,
    'SALVUCCI': 0,
    'SALWASSER': 0,
    'SALWAY': 0,
    'SALWEI': 0,
    'SALWEN': 0,
    'SALY': 0,
    'SALYARDS': 0,
    'SALYER': 0,
    'SALYERS': 0,
    'SALZ': 0,
    'SALZA': 0,
    'SALZANO': 0,
    'SALZAR': 0,
    'SALZARULO': 0,
    'SALZBERG': 0,
    'SALZBRENNER': 0,
    'SALZER': 0,
    'SALZGEBER': 0,
    'SALZILLO': 0,
    'SALZL': 0,
    'SALZMAN': 0,
    'SALZMANN': 0,
    'SALZSIEDER': 0,
    'SALZWEDEL': 0,
    'SAM': 0.963509635096351,
    'SAMA': 0,
    'SAMAAN': 0,
    'SAMAD': 0,
    'SAMADI': 0,
    'SAMAHA': 0,
    'SAMALA': 0,
    'SAMALOT': 0,
    'SAMAN': 0,
    'SAMAND': 0,
    'SAMANI': 0,
    'SAMANIE': 0,
    'SAMANIEGO': 0,
    'SAMANO': 0,
    'SAMANT': 0,
    'SAMANTA': 0,
    'SAMANTHA': 0.9995969367190648,
    'SAMAR': 0,
    'SAMARA': 0.8810572687224669,
    'SAMARAS': 0,
    'SAMARCO': 0,
    'SAMARDZIC': 0,
    'SAMARDZIJA': 0,
    'SAMARIN': 0,
    'SAMARIO': 0,
    'SAMARIPA': 0,
    'SAMARITANO': 0,
    'SAMARO': 0,
    'SAMAROO': 0,
    'SAMARRIPA': 0,
    'SAMARRIPAS': 0,
    'SAMARRON': 0,
    'SAMARTINO': 0,
    'SAMAS': 0,
    'SAMATAR': 0,
    'SAMATHA': 1,
    'SAMAWI': 0,
    'SAMAY': 0,
    'SAMAYOA': 0,
    'SAMB': 0,
    'SAMBA': 0,
    'SAMBATARO': 0,
    'SAMBER': 0,
    'SAMBERG': 0,
    'SAMBLANET': 0,
    'SAMBO': 0,
    'SAMBOL': 0,
    'SAMBOLA': 0,
    'SAMBOLIN': 0,
    'SAMBOR': 0,
    'SAMBORSKI': 0,
    'SAMBORSKY': 0,
    'SAMBOY': 0,
    'SAMBRANO': 0,
    'SAMBROOK': 0,
    'SAMBUCCI': 0,
    'SAMBUCO': 0,
    'SAMBULA': 0,
    'SAMEAS': 0,
    'SAMEC': 0,
    'SAMEDI': 0,
    'SAMEDY': 0,
    'SAMEK': 0,
    'SAMEL': 0,
    'SAMELA': 0,
    'SAMELLA': 1,
    'SAMELS': 0,
    'SAMELSON': 0,
    'SAMER': 0,
    'SAMES': 0,
    'SAMESHIMA': 0,
    'SAMET': 0,
    'SAMFORD': 0,
    'SAMI': 0,
    'SAMIA': 0,
    'SAMICK': 0,
    'SAMIDE': 0,
    'SAMII': 0,
    'SAMIMI': 0,
    'SAMIOS': 0,
    'SAMIRA': 1,
    'SAMIS': 0,
    'SAMKO': 0,
    'SAMLAL': 0,
    'SAMLAND': 0,
    'SAMLER': 0,
    'SAMM': 0,
    'SAMMAN': 0,
    'SAMMANN': 0,
    'SAMMARCO': 0,
    'SAMMARTANO': 0,
    'SAMMARTINO': 0,
    'SAMMEL': 0,
    'SAMMER': 0,
    'SAMMET': 0,
    'SAMMIE': 1,
    'SAMMIS': 0,
    'SAMMON': 0,
    'SAMMONS': 0,
    'SAMMS': 0,
    'SAMMUT': 0,
    'SAMMY': 0.9950248756218907,
    'SAMO': 0,
    'SAMOA': 0,
    'SAMOL': 0,
    'SAMOLINSKI': 0,
    'SAMOLIS': 0,
    'SAMON': 0,
    'SAMONA': 0,
    'SAMONS': 0,
    'SAMONTE': 0,
    'SAMORA': 0,
    'SAMORANO': 0,
    'SAMOS': 0,
    'SAMOSKA': 0,
    'SAMOSKY': 0,
    'SAMOUR': 0,
    'SAMOWITZ': 0,
    'SAMOY': 0,
    'SAMP': 0,
    'SAMPAGA': 0,
    'SAMPAID': 0,
    'SAMPAIO': 0,
    'SAMPANG': 0,
    'SAMPAT': 0,
    'SAMPATH': 0,
    'SAMPAY': 0,
    'SAMPAYAN': 0,
    'SAMPAYO': 0,
    'SAMPE': 0,
    'SAMPEDRO': 0,
    'SAMPEL': 0,
    'SAMPER': 0,
    'SAMPERE': 0,
    'SAMPERI': 0,
    'SAMPERIO': 0,
    'SAMPEY': 0,
    'SAMPICA': 0,
    'SAMPIER': 0,
    'SAMPIERI': 0,
    'SAMPIETRO': 0,
    'SAMPLAWSKI': 0,
    'SAMPLE': 0,
    'SAMPLER': 0,
    'SAMPLES': 0,
    'SAMPLEY': 0,
    'SAMPO': 0,
    'SAMPOGNA': 0,
    'SAMPOGNARO': 0,
    'SAMPSEL': 0,
    'SAMPSELL': 0,
    'SAMPSON': 0,
    'SAMPY': 0,
    'SAMRA': 0,
    'SAMRETH': 0,
    'SAMS': 0,
    'SAMSA': 0,
    'SAMSAL': 0,
    'SAMSEL': 0,
    'SAMSELL': 0,
    'SAMSKY': 0,
    'SAMSON': 0,
    'SAMSTAG': 0,
    'SAMTANI': 0,
    'SAMU': 0,
    'SAMUAL': 0.99009900990099,
    'SAMUDA': 0,
    'SAMUDIO': 0,
    'SAMUEL': 0.9773023907299526,
    'SAMUELIAN': 0,
    'SAMUELL': 0,
    'SAMUELS': 0,
    'SAMUELSEN': 0,
    'SAMUELSON': 0,
    'SAMUL': 0,
    'SAMULES': 0,
    'SAMULSKI': 0,
    'SAMURA': 0,
    'SAMWAYS': 0,
    'SAMY': 0,
    'SAMYN': 0,
    'SAMZ': 0,
    'SAN': 0,
    'SANA': 0.8771929824561403,
    'SANABIA': 0,
    'SANABRIA': 0,
    'SANACORE': 0,
    'SANADA': 0,
    'SANAGUSTIN': 0,
    'SANANDRES': 0,
    'SANANGELO': 0,
    'SANANGO': 0,
    'SANANIKONE': 0,
    'SANANTONIO': 0,
    'SANBERG': 0,
    'SANBORN': 0,
    'SANBOWER': 0,
    'SANBURG': 0,
    'SANBURN': 0,
    'SANCE': 0,
    'SANCEN': 0,
    'SANCES': 0,
    'SANCEZ': 0,
    'SANCHAZ': 0,
    'SANCHE': 0,
    'SANCHEC': 0,
    'SANCHES': 0,
    'SANCHEZ': 0,
    'SANCHEZDIAZ': 0,
    'SANCHEZFLORES': 0,
    'SANCHEZGARCIA': 0,
    'SANCHEZGOMEZ': 0,
    'SANCHEZGONZALE': 0,
    'SANCHEZHERNAND': 0,
    'SANCHEZLOPEZ': 0,
    'SANCHEZMARTINE': 0,
    'SANCHEZORTIZ': 0,
    'SANCHEZPEREZ': 0,
    'SANCHEZRAMIREZ': 0,
    'SANCHEZSANCHEZ': 0,
    'SANCHEZTORRES': 0,
    'SANCHIOUS': 0,
    'SANCHIRICO': 0,
    'SANCHO': 0,
    'SANCKEN': 0,
    'SANCLEMENTE': 0,
    'SANCOMB': 0,
    'SANCRANT': 0,
    'SAND': 0,
    'SANDA': 0.8620689655172414,
    'SANDAGE': 0,
    'SANDAGER': 0,
    'SANDAHL': 0,
    'SANDAK': 0,
    'SANDAL': 0,
    'SANDALL': 0,
    'SANDATE': 0,
    'SANDAU': 0,
    'SANDAVAL': 0,
    'SANDBACH': 0,
    'SANDBAKKEN': 0,
    'SANDBECK': 0,
    'SANDBERG': 0,
    'SANDBLOM': 0,
    'SANDBO': 0,
    'SANDBORN': 0,
    'SANDBOTHE': 0,
    'SANDBULTE': 0,
    'SANDBURG': 0,
    'SANDE': 0,
    'SANDECKI': 0,
    'SANDEE': 0.9615384615384616,
    'SANDEEN': 0,
    'SANDEFER': 0,
    'SANDEFUR': 0,
    'SANDEL': 0,
    'SANDELIN': 0,
    'SANDELL': 0,
    'SANDELLA': 0,
    'SANDEN': 0,
    'SANDENO': 0,
    'SANDER': 0,
    'SANDERA': 0,
    'SANDERBECK': 0,
    'SANDERCOCK': 0,
    'SANDERFER': 0,
    'SANDERFOOT': 0,
    'SANDERFORD': 0,
    'SANDERLIN': 0,
    'SANDERMAN': 0,
    'SANDERS': 0,
    'SANDERSEN': 0,
    'SANDERSFELD': 0,
    'SANDERSON': 0,
    'SANDES': 0,
    'SANDEZ': 0,
    'SANDFER': 0,
    'SANDFORD': 0,
    'SANDFORT': 0,
    'SANDFOSS': 0,
    'SANDGREN': 0,
    'SANDHAGEN': 0,
    'SANDHAM': 0,
    'SANDHAR': 0,
    'SANDHAUS': 0,
    'SANDHEINRICH': 0,
    'SANDHOFF': 0,
    'SANDHOLM': 0,
    'SANDHOP': 0,
    'SANDHU': 0,
    'SANDI': 0.9803921568627452,
    'SANDIDGE': 0,
    'SANDIE': 0.9523809523809523,
    'SANDIEGO': 0,
    'SANDIFER': 0,
    'SANDIFORD': 0,
    'SANDIFUR': 0,
    'SANDIGO': 0,
    'SANDILANDS': 0,
    'SANDIN': 0,
    'SANDINE': 0,
    'SANDINO': 0,
    'SANDISON': 0,
    'SANDLAND': 0,
    'SANDLE': 0,
    'SANDLER': 0,
    'SANDLES': 0,
    'SANDLIN': 0,
    'SANDLING': 0,
    'SANDMAN': 0,
    'SANDMANN': 0,
    'SANDMEIER': 0,
    'SANDMEYER': 0,
    'SANDMIRE': 0,
    'SANDNER': 0,
    'SANDNES': 0,
    'SANDNESS': 0,
    'SANDO': 0,
    'SANDOBAL': 0,
    'SANDOE': 0,
    'SANDON': 0,
    'SANDONA': 0,
    'SANDONATO': 0,
    'SANDONE': 0,
    'SANDOR': 0,
    'SANDORA': 0,
    'SANDOS': 0,
    'SANDOUAL': 0,
    'SANDOVAL': 0,
    'SANDOVAR': 0,
    'SANDOW': 0,
    'SANDOZ': 0,
    'SANDQUIST': 0,
    'SANDRA': 0.9997615830882938,
    'SANDRAS': 0,
    'SANDRE': 0,
    'SANDRES': 0,
    'SANDRETTO': 0,
    'SANDRI': 0,
    'SANDRICK': 0,
    'SANDRIDGE': 0,
    'SANDRIK': 0,
    'SANDRO': 0,
    'SANDROCK': 0,
    'SANDRONI': 0,
    'SANDRU': 0,
    'SANDRY': 0,
    'SANDS': 0,
    'SANDSMARK': 0,
    'SANDSTEDT': 0,
    'SANDSTROM': 0,
    'SANDT': 0,
    'SANDU': 0,
    'SANDUSKY': 0,
    'SANDVEN': 0,
    'SANDVICK': 0,
    'SANDVIG': 0,
    'SANDVIK': 0,
    'SANDVOLD': 0,
    'SANDWELL': 0,
    'SANDWICK': 0,
    'SANDWISCH': 0,
    'SANDWITH': 0,
    'SANDY': 0.967238689547582,
    'SANDYS': 0,
    'SANE': 0,
    'SANELLI': 0,
    'SANER': 0,
    'SANES': 0,
    'SANEZ': 0,
    'SANFACON': 0,
    'SANFELICE': 0,
    'SANFELIPE': 0,
    'SANFELIPPO': 0,
    'SANFILIPPO': 0,
    'SANFILLIPO': 0,
    'SANFILLIPPO': 0,
    'SANFORD': 0.40577096483318303,
    'SANFRATELLO': 0,
    'SANFT': 0,
    'SANFTNER': 0,
    'SANG': 0.9324009324009324,
    'SANGA': 0,
    'SANGABRIEL': 0,
    'SANGALANG': 0,
    'SANGALLI': 0,
    'SANGANI': 0,
    'SANGARE': 0,
    'SANGER': 0,
    'SANGERMAN': 0,
    'SANGERMANO': 0,
    'SANGES': 0,
    'SANGH': 0,
    'SANGHA': 0,
    'SANGHANI': 0,
    'SANGHAVI': 0,
    'SANGHERA': 0,
    'SANGHVI': 0,
    'SANGIACOMO': 0,
    'SANGIL': 0,
    'SANGILLO': 0,
    'SANGIORGI': 0,
    'SANGIORGIO': 0,
    'SANGIOVANNI': 0,
    'SANGIRARDI': 0,
    'SANGL': 0,
    'SANGO': 0,
    'SANGREN': 0,
    'SANGREY': 0,
    'SANGSTER': 0,
    'SANGSTON': 0,
    'SANGUEDOLCE': 0,
    'SANGUINETTI': 0,
    'SANGUINO': 0,
    'SANHUEZA': 0,
    'SANI': 0,
    'SANICHAR': 0,
    'SANICOLA': 0,
    'SANIDAD': 0,
    'SANIN': 0,
    'SANINOCENCIO': 0,
    'SANISLO': 0,
    'SANITA': 0,
    'SANITATE': 0,
    'SANIUK': 0,
    'SANJINES': 0,
    'SANJOSE': 0,
    'SANJUAN': 0,
    'SANJUANA': 1,
    'SANJUANITA': 1,
    'SANJURJO': 0,
    'SANK': 0,
    'SANKA': 0,
    'SANKAR': 0,
    'SANKARAN': 0,
    'SANKER': 0,
    'SANKEY': 0,
    'SANKO': 0,
    'SANKOH': 0,
    'SANKOVICH': 0,
    'SANKOWSKI': 0,
    'SANKS': 0,
    'SANLUCAS': 0,
    'SANLUIS': 0,
    'SANMARCO': 0,
    'SANMARTIN': 0,
    'SANMIGUEL': 0,
    'SANN': 0,
    'SANNA': 0,
    'SANNAR': 0,
    'SANNE': 0,
    'SANNELLA': 0,
    'SANNEMAN': 0,
    'SANNER': 0,
    'SANNES': 0,
    'SANNEY': 0,
    'SANNI': 0,
    'SANNICANDRO': 0,
    'SANNICOLAS': 0,
    'SANNING': 0,
    'SANNINO': 0,
    'SANNS': 0,
    'SANNY': 0,
    'SANO': 0,
    'SANOCKI': 0,
    'SANOK': 0,
    'SANON': 0,
    'SANOR': 0,
    'SANORA': 1,
    'SANOUVONG': 0,
    'SANOW': 0,
    'SANPAOLO': 0,
    'SANPEDRO': 0,
    'SANPIETRO': 0,
    'SANQUIST': 0,
    'SANROMAN': 0,
    'SANS': 0,
    'SANSALONE': 0,
    'SANSANO': 0,
    'SANSBURY': 0,
    'SANSCHAGRIN': 0,
    'SANSEVERE': 0,
    'SANSEVERINO': 0,
    'SANSEVERO': 0,
    'SANSING': 0,
    'SANSO': 0,
    'SANSOM': 0,
    'SANSON': 0,
    'SANSONE': 0,
    'SANSONETTI': 0,
    'SANSONI': 0,
    'SANSORES': 0,
    'SANSOSTI': 0,
    'SANSOTTA': 0,
    'SANSOUCI': 0,
    'SANSOUCIE': 0,
    'SANSOUCY': 0,
    'SANSPREE': 0,
    'SANT': 0,
    'SANTA': 0.8875739644970414,
    'SANTAANA': 0,
    'SANTAANNA': 0,
    'SANTABARBARA': 0,
    'SANTACROCE': 0,
    'SANTACRUZ': 0,
    'SANTAELLA': 0,
    'SANTAGATA': 0,
    'SANTAGO': 0,
    'SANTAGUIDA': 0,
    'SANTALA': 0,
    'SANTALIZ': 0,
    'SANTALLA': 0,
    'SANTALUCIA': 0,
    'SANTAMARIA': 0,
    'SANTAMARINA': 0,
    'SANTAMORE': 0,
    'SANTAMOUR': 0,
    'SANTAN': 0,
    'SANTANA': 0.10952902519167579,
    'SANTANDER': 0,
    'SANTANDREA': 0,
    'SANTANELLO': 0,
    'SANTANGELO': 0,
    'SANTANIELLO': 0,
    'SANTANNA': 0,
    'SANTANO': 0,
    'SANTARCANGELO': 0,
    'SANTARELLI': 0,
    'SANTAROSA': 0,
    'SANTARPIA': 0,
    'SANTARPIO': 0,
    'SANTARSIERO': 0,
    'SANTAS': 0,
    'SANTAVICCA': 0,
    'SANTAW': 0,
    'SANTAY': 0,
    'SANTAYANA': 0,
    'SANTE': 0,
    'SANTEE': 0,
    'SANTEL': 0,
    'SANTELICES': 0,
    'SANTELISES': 0,
    'SANTELIZ': 0,
    'SANTELL': 0,
    'SANTELLA': 0,
    'SANTELLAN': 0,
    'SANTELLANA': 0,
    'SANTELLANES': 0,
    'SANTELLANO': 0,
    'SANTELLI': 0,
    'SANTELLO': 0,
    'SANTEMA': 0,
    'SANTEN': 0,
    'SANTER': 0,
    'SANTERAMO': 0,
    'SANTERO': 0,
    'SANTERRE': 0,
    'SANTES': 0,
    'SANTHANAM': 0,
    'SANTHUFF': 0,
    'SANTI': 0,
    'SANTIA': 0,
    'SANTIAGO': 0.39483129935391237,
    'SANTIANO': 0,
    'SANTIBANES': 0,
    'SANTIBANEZ': 0,
    'SANTIESTEBAN': 0,
    'SANTIFER': 0,
    'SANTIFUL': 0,
    'SANTILLA': 0,
    'SANTILLAN': 0,
    'SANTILLANA': 0,
    'SANTILLANES': 0,
    'SANTILLANEZ': 0,
    'SANTILLANO': 0,
    'SANTILLI': 0,
    'SANTILLO': 0,
    'SANTIMAW': 0,
    'SANTIN': 0,
    'SANTINA': 0.9756097560975611,
    'SANTINE': 0,
    'SANTINELLI': 0,
    'SANTINI': 0,
    'SANTINO': 0,
    'SANTIS': 0,
    'SANTISI': 0,
    'SANTISO': 0,
    'SANTISTEBAN': 0,
    'SANTISTEVAN': 0,
    'SANTIVANEZ': 0,
    'SANTIZO': 0,
    'SANTJER': 0,
    'SANTMAN': 0,
    'SANTMYER': 0,
    'SANTNER': 0,
    'SANTO': 0.7272727272727273,
    'SANTODOMINGO': 0,
    'SANTOIANNI': 0,
    'SANTOLERI': 0,
    'SANTOLI': 0,
    'SANTOLLA': 0,
    'SANTOLUCITO': 0,
    'SANTOMAURO': 0,
    'SANTON': 0,
    'SANTONASTASO': 0,
    'SANTONE': 0,
    'SANTONI': 0,
    'SANTOPADRE': 0,
    'SANTOPIETRO': 0,
    'SANTOR': 0,
    'SANTORA': 0,
    'SANTORE': 0,
    'SANTORELLA': 0,
    'SANTORELLI': 0,
    'SANTORI': 0,
    'SANTORIELLO': 0,
    'SANTORO': 0,
    'SANTOS': 0.38525963149078724,
    'SANTOSCOY': 0,
    'SANTOSO': 0,
    'SANTOSTEFANO': 0,
    'SANTOSUOSSO': 0,
    'SANTOVENIA': 0,
    'SANTOWSKI': 0,
    'SANTOY': 0,
    'SANTOYA': 0,
    'SANTOYO': 0,
    'SANTROCK': 0,
    'SANTRY': 0,
    'SANTSCHI': 0,
    'SANTTI': 0,
    'SANTUCCI': 0,
    'SANTULLI': 0,
    'SANTURE': 0,
    'SANTURRI': 0,
    'SANTUS': 0,
    'SANTY': 0,
    'SANUDO': 0,
    'SANUSI': 0,
    'SANVICENTE': 0,
    'SANVILLE': 0,
    'SANWALD': 0,
    'SANWICK': 0,
    'SANYAL': 0,
    'SANZ': 0,
    'SANZA': 0,
    'SANZARI': 0,
    'SANZI': 0,
    'SANZO': 0,
    'SANZONE': 0,
    'SAO': 0,
    'SAOUD': 0,
    'SAP': 0,
    'SAPA': 0,
    'SAPATA': 0,
    'SAPAUGH': 0,
    'SAPER': 0,
    'SAPERSTEIN': 0,
    'SAPIA': 0,
    'SAPIDA': 0,
    'SAPIEN': 0,
    'SAPIENS': 0,
    'SAPIENZA': 0,
    'SAPIGAO': 0,
    'SAPIN': 0,
    'SAPINOSO': 0,
    'SAPINSKI': 0,
    'SAPIO': 0,
    'SAPIR': 0,
    'SAPIRO': 0,
    'SAPKO': 0,
    'SAPON': 0,
    'SAPONARA': 0,
    'SAPONARO': 0,
    'SAPONE': 0,
    'SAPORITA': 0,
    'SAPORITO': 0,
    'SAPORTA': 0,
    'SAPOZHNIKOV': 0,
    'SAPP': 0,
    'SAPPE': 0,
    'SAPPENFIELD': 0,
    'SAPPER': 0,
    'SAPPERSTEIN': 0,
    'SAPPINGFIELD': 0,
    'SAPPINGTON': 0,
    'SAPRA': 0,
    'SAPUTO': 0,
    'SAPYTA': 0,
    'SAQIB': 0,
    'SAQUIC': 0,
    'SAR': 0,
    'SARA': 0.9983433603627169,
    'SARABI': 0,
    'SARABIA': 0,
    'SARAC': 0,
    'SARACAY': 0,
    'SARACCO': 0,
    'SARACENI': 0,
    'SARACENO': 0,
    'SARACHO': 0,
    'SARACINA': 0,
    'SARACINO': 0,
    'SARACO': 0,
    'SARAF': 0,
    'SARAFIAN': 0,
    'SARAFIN': 0,
    'SARAGA': 0,
    'SARAGO': 0,
    'SARAGOSA': 0,
    'SARAGOZA': 0,
    'SARAGUSA': 0,
    'SARAH': 0.9996457947971192,
    'SARAI': 0.9523809523809523,
    'SARAIVA': 0,
    'SARAIYA': 0,
    'SARAMA': 0,
    'SARAN': 0.8403361344537815,
    'SARANDOS': 0,
    'SARANDREA': 0,
    'SARANG': 0,
    'SARANGO': 0,
    'SARANITI': 0,
    'SARANTIS': 0,
    'SARANTOPOULOS': 0,
    'SARANTOS': 0,
    'SARAO': 0,
    'SARAS': 0,
    'SARASIN': 0,
    'SARASUA': 0,
    'SARAT': 0,
    'SARATE': 0,
    'SARATHY': 0,
    'SARAUER': 0,
    'SARAULT': 0,
    'SARAVIA': 0,
    'SARAY': 0,
    'SARAZEN': 0,
    'SARAZIN': 0,
    'SARB': 0,
    'SARBACHER': 0,
    'SARBACKER': 0,
    'SARBAUGH': 0,
    'SARBER': 0,
    'SARBU': 0,
    'SARCENO': 0,
    'SARCHET': 0,
    'SARCHETT': 0,
    'SARCIA': 0,
    'SARCIONE': 0,
    'SARCO': 0,
    'SARCONA': 0,
    'SARCONE': 0,
    'SARD': 0,
    'SARDA': 0,
    'SARDANA': 0,
    'SARDAR': 0,
    'SARDEGNA': 0,
    'SARDELLA': 0,
    'SARDELLI': 0,
    'SARDEN': 0,
    'SARDESON': 0,
    'SARDI': 0,
    'SARDIN': 0,
    'SARDINA': 0,
    'SARDINAS': 0,
    'SARDINHA': 0,
    'SARDIS': 0,
    'SARDISCO': 0,
    'SARDO': 0,
    'SARDON': 0,
    'SARDONE': 0,
    'SARDUY': 0,
    'SARE': 0,
    'SAREEN': 0,
    'SARELLANO': 0,
    'SAREMI': 0,
    'SAREN': 0,
    'SARENANA': 0,
    'SARES': 0,
    'SARETTE': 0,
    'SARFATI': 0,
    'SARFATY': 0,
    'SARFF': 0,
    'SARFO': 0,
    'SARFRAZ': 0,
    'SARGE': 0,
    'SARGEANT': 0,
    'SARGENT': 0,
    'SARGENTI': 0,
    'SARGINSON': 0,
    'SARGIS': 0,
    'SARGO': 0,
    'SARGSYAN': 0,
    'SARHAN': 0,
    'SARI': 0.888888888888889,
    'SARIA': 0,
    'SARIAN': 0,
    'SARIANO': 0,
    'SARIC': 0,
    'SARICH': 0,
    'SARIEGO': 0,
    'SARIN': 0,
    'SARINA': 0.9803921568627452,
    'SARINANA': 0,
    'SARINO': 0,
    'SARIO': 0,
    'SARIOL': 0,
    'SARIS': 0,
    'SARISKY': 0,
    'SARITA': 0.9740259740259739,
    'SARJEANT': 0,
    'SARJU': 0,
    'SARK': 0,
    'SARKA': 0,
    'SARKAR': 0,
    'SARKEES': 0,
    'SARKELA': 0,
    'SARKER': 0,
    'SARKES': 0,
    'SARKESIAN': 0,
    'SARKIN': 0,
    'SARKINEN': 0,
    'SARKIS': 0,
    'SARKISIAN': 0,
    'SARKISOVA': 0,
    'SARKISSIAN': 0,
    'SARKISYAN': 0,
    'SARKKINEN': 0,
    'SARKO': 0,
    'SARKOZI': 0,
    'SARKOZY': 0,
    'SARLES': 0,
    'SARLEY': 0,
    'SARLI': 0,
    'SARLO': 0,
    'SARMA': 0,
    'SARMENTO': 0,
    'SARMIENTO': 0,
    'SARNA': 0,
    'SARNACKI': 0,
    'SARNE': 0,
    'SARNECKI': 0,
    'SARNECKY': 0,
    'SARNELLI': 0,
    'SARNER': 0,
    'SARNES': 0,
    'SARNESE': 0,
    'SARNI': 0,
    'SARNICOLA': 0,
    'SARNIE': 0,
    'SARNO': 0,
    'SARNOFF': 0,
    'SARNOSKI': 0,
    'SARNOWSKI': 0,
    'SARNS': 0,
    'SARO': 0,
    'SAROFF': 0,
    'SAROKA': 0,
    'SARON': 0,
    'SAROS': 0,
    'SAROSI': 0,
    'SAROSY': 0,
    'SAROW': 0,
    'SAROYAN': 0,
    'SARPONG': 0,
    'SARPY': 0,
    'SARR': 0,
    'SARRA': 0,
    'SARRACCO': 0,
    'SARRACINO': 0,
    'SARRADET': 0,
    'SARRAF': 0,
    'SARRAN': 0,
    'SARRASIN': 0,
    'SARRATT': 0,
    'SARRAZIN': 0,
    'SARREAL': 0,
    'SARRELS': 0,
    'SARRETT': 0,
    'SARRIA': 0,
    'SARRICA': 0,
    'SARRIS': 0,
    'SARRO': 0,
    'SARROS': 0,
    'SARSFIELD': 0,
    'SARSON': 0,
    'SARSOUR': 0,
    'SARTAIN': 0,
    'SARTE': 0,
    'SARTELL': 0,
    'SARTEN': 0,
    'SARTER': 0,
    'SARTI': 0,
    'SARTIN': 0,
    'SARTINI': 0,
    'SARTO': 0,
    'SARTOR': 0,
    'SARTORE': 0,
    'SARTORELLI': 0,
    'SARTORI': 0,
    'SARTORIO': 0,
    'SARTORIS': 0,
    'SARTORIUS': 0,
    'SARTUCHE': 0,
    'SARTWELL': 0,
    'SARTY': 0,
    'SARUBBI': 0,
    'SARULLO': 0,
    'SARUWATARI': 0,
    'SARVAS': 0,
    'SARVELA': 0,
    'SARVER': 0,
    'SARVEY': 0,
    'SARVIS': 0,
    'SARWAR': 0,
    'SARWARI': 0,
    'SARWARY': 0,
    'SARY': 0,
    'SARYAN': 0,
    'SARZYNSKI': 0,
    'SAS': 0,
    'SASA': 0,
    'SASADA': 0,
    'SASAHARA': 0,
    'SASAK': 0,
    'SASAKI': 0,
    'SASALA': 0,
    'SASAMOTO': 0,
    'SASANO': 0,
    'SASEK': 0,
    'SASH': 0,
    'SASHA': 1,
    'SASIN': 0,
    'SASKA': 0,
    'SASKO': 0,
    'SASKOWSKI': 0,
    'SASLOW': 0,
    'SASMAN': 0,
    'SASNETT': 0,
    'SASO': 0,
    'SASON': 0,
    'SASS': 0,
    'SASSA': 0,
    'SASSAMAN': 0,
    'SASSANI': 0,
    'SASSANO': 0,
    'SASSCER': 0,
    'SASSE': 0,
    'SASSEEN': 0,
    'SASSEN': 0,
    'SASSER': 0,
    'SASSEVILLE': 0,
    'SASSI': 0,
    'SASSIN': 0,
    'SASSINE': 0,
    'SASSMAN': 0,
    'SASSMANN': 0,
    'SASSO': 0,
    'SASSON': 0,
    'SASSONE': 0,
    'SASSOON': 0,
    'SASTRE': 0,
    'SASTRY': 0,
    'SAT': 0,
    'SATA': 0,
    'SATAKE': 0,
    'SATALA': 0,
    'SATALINO': 0,
    'SATANA': 0,
    'SATAR': 0,
    'SATARIANO': 0,
    'SATAVA': 0,
    'SATCHEL': 0,
    'SATCHELL': 0,
    'SATCHER': 0,
    'SATCHWELL': 0,
    'SATCHWILL': 0,
    'SATELE': 0,
    'SATER': 0,
    'SATEREN': 0,
    'SATERFIELD': 0,
    'SATERIALE': 0,
    'SATERN': 0,
    'SATH': 0,
    'SATHE': 0,
    'SATHER': 0,
    'SATHOFF': 0,
    'SATHRE': 0,
    'SATIAGO': 0,
    'SATIN': 0,
    'SATINSKY': 0,
    'SATISH': 0,
    'SATKO': 0,
    'SATKOWIAK': 0,
    'SATKOWSKI': 0,
    'SATLER': 0,
    'SATMARY': 0,
    'SATO': 0,
    'SATOR': 0,
    'SATORI': 0,
    'SATORIUS': 0,
    'SATOW': 0,
    'SATRAN': 0,
    'SATRE': 0,
    'SATRIANO': 0,
    'SATROM': 0,
    'SATSKY': 0,
    'SATTA': 0,
    'SATTAR': 0,
    'SATTARI': 0,
    'SATTAUR': 0,
    'SATTAZAHN': 0,
    'SATTELBERG': 0,
    'SATTER': 0,
    'SATTERBERG': 0,
    'SATTERFIELD': 0,
    'SATTERLEE': 0,
    'SATTERLEY': 0,
    'SATTERLUND': 0,
    'SATTERLY': 0,
    'SATTERTHWAITE': 0,
    'SATTERWHITE': 0,
    'SATTI': 0,
    'SATTIEWHITE': 0,
    'SATTIZAHN': 0,
    'SATTLER': 0,
    'SATTLEY': 0,
    'SATURDAY': 0,
    'SATURLEY': 0,
    'SATURN': 0,
    'SATURNE': 0,
    'SATURNINA': 1,
    'SATURNINO': 0,
    'SATURNO': 0,
    'SATZ': 0,
    'SAU': 0.9174311926605505,
    'SAUAGE': 0,
    'SAUBER': 0,
    'SAUBERAN': 0,
    'SAUBERT': 0,
    'SAUBLE': 0,
    'SAUCE': 0,
    'SAUCEDA': 0,
    'SAUCEDO': 0,
    'SAUCEMAN': 0,
    'SAUCER': 0,
    'SAUCERMAN': 0,
    'SAUCHELLI': 0,
    'SAUCIER': 0,
    'SAUCILLO': 0,
    'SAUCK': 0,
    'SAUD': 0,
    'SAUDE': 0,
    'SAUDER': 0,
    'SAUDERS': 0,
    'SAUER': 0,
    'SAUERBIER': 0,
    'SAUERBREI': 0,
    'SAUERBREY': 0,
    'SAUERESSIG': 0,
    'SAUERLAND': 0,
    'SAUERMAN': 0,
    'SAUERS': 0,
    'SAUERWALD': 0,
    'SAUERWEIN': 0,
    'SAUERWINE': 0,
    'SAUFLEY': 0,
    'SAUGSTAD': 0,
    'SAUL': 0.8865248226950355,
    'SAULA': 0,
    'SAULER': 0,
    'SAULEY': 0,
    'SAULINO': 0,
    'SAULL': 0,
    'SAULLE': 0,
    'SAULLO': 0,
    'SAULMON': 0,
    'SAULNIER': 0,
    'SAULOG': 0,
    'SAULPAUGH': 0,
    'SAULS': 0,
    'SAULSBERRY': 0,
    'SAULSBERY': 0,
    'SAULSBURY': 0,
    'SAULSBY': 0,
    'SAULSGIVER': 0,
    'SAULT': 0,
    'SAULTER': 0,
    'SAULTERS': 0,
    'SAULTS': 0,
    'SAULTZ': 0,
    'SAUM': 0,
    'SAUMELL': 0,
    'SAUMIER': 0,
    'SAUNDER': 0,
    'SAUNDERS': 0,
    'SAUNDERSON': 0,
    'SAUNDRA': 1,
    'SAUNIER': 0,
    'SAUNOOKE': 0,
    'SAUPE': 0,
    'SAUPP': 0,
    'SAUR': 0,
    'SAURA': 0,
    'SAURAGE': 0,
    'SAURE': 0,
    'SAURER': 0,
    'SAUREY': 0,
    'SAUREZ': 0,
    'SAURI': 0,
    'SAURINI': 0,
    'SAURIOL': 0,
    'SAURMAN': 0,
    'SAURO': 0,
    'SAUS': 0,
    'SAUSA': 0,
    'SAUSAMAN': 0,
    'SAUSE': 0,
    'SAUSEDA': 0,
    'SAUSEDO': 0,
    'SAUSEN': 0,
    'SAUSER': 0,
    'SAUSMAN': 0,
    'SAUSSER': 0,
    'SAUSSY': 0,
    'SAUSVILLE': 0,
    'SAUTER': 0,
    'SAUTNER': 0,
    'SAUTTER': 0,
    'SAUVAGE': 0,
    'SAUVAGEAU': 0,
    'SAUVAIN': 0,
    'SAUVE': 0,
    'SAUVEUR': 0,
    'SAUVOLA': 0,
    'SAUZA': 0,
    'SAVA': 0,
    'SAVACOOL': 0,
    'SAVAGE': 0,
    'SAVAGEAU': 0,
    'SAVAGLIO': 0,
    'SAVAIANO': 0,
    'SAVAL': 0,
    'SAVALA': 0,
    'SAVALIA': 0,
    'SAVALLI': 0,
    'SAVANI': 0,
    'SAVANNA': 1,
    'SAVANNAH': 0.9813542688910696,
    'SAVANT': 0,
    'SAVAR': 0,
    'SAVARD': 0,
    'SAVARESE': 0,
    'SAVARIA': 0,
    'SAVARINO': 0,
    'SAVARY': 0,
    'SAVAS': 0,
    'SAVASTA': 0,
    'SAVASTAND': 0,
    'SAVASTANO': 0,
    'SAVAT': 0,
    'SAVATH': 0,
    'SAVAYA': 0,
    'SAVCEDO': 0,
    'SAVCHENKO': 0,
    'SAVCHUK': 0,
    'SAVE': 0,
    'SAVEA': 0,
    'SAVEDGE': 0,
    'SAVEDRA': 0,
    'SAVEL': 0,
    'SAVELA': 0,
    'SAVELL': 0,
    'SAVELLA': 0,
    'SAVELLE': 0,
    'SAVELLI': 0,
    'SAVELY': 0,
    'SAVERANCE': 0,
    'SAVERCOOL': 0,
    'SAVERINO': 0,
    'SAVERY': 0,
    'SAVEY': 0,
    'SAVI': 0,
    'SAVIA': 0,
    'SAVIANO': 0,
    'SAVIC': 0,
    'SAVICH': 0,
    'SAVICK': 0,
    'SAVICKAS': 0,
    'SAVICKI': 0,
    'SAVIDES': 0,
    'SAVIDGE': 0,
    'SAVIERS': 0,
    'SAVIGNAC': 0,
    'SAVIGNANO': 0,
    'SAVILL': 0,
    'SAVILLE': 0,
    'SAVIN': 0,
    'SAVINA': 0,
    'SAVINE': 0,
    'SAVINELLI': 0,
    'SAVING': 0,
    'SAVINI': 0,
    'SAVINO': 0,
    'SAVINON': 0,
    'SAVINSKI': 0,
    'SAVINSKY': 0,
    'SAVIO': 0,
    'SAVIOLA': 0,
    'SAVIOR': 0,
    'SAVIS': 0,
    'SAVISKY': 0,
    'SAVITCH': 0,
    'SAVITSKI': 0,
    'SAVITSKY': 0,
    'SAVITT': 0,
    'SAVITZ': 0,
    'SAVKA': 0,
    'SAVKO': 0,
    'SAVO': 0,
    'SAVOCA': 0,
    'SAVOIA': 0,
    'SAVOIE': 0,
    'SAVOIR': 0,
    'SAVOLA': 0,
    'SAVOLAINEN': 0,
    'SAVOLDI': 0,
    'SAVOLE': 0,
    'SAVON': 0,
    'SAVONA': 0,
    'SAVONE': 0,
    'SAVOPOULOS': 0,
    'SAVOR': 0,
    'SAVORY': 0,
    'SAVOY': 0,
    'SAVOYE': 0,
    'SAVU': 0,
    'SAVVA': 0,
    'SAVVAS': 0,
    'SAVVIDES': 0,
    'SAVY': 0,
    'SAW': 0,
    'SAWA': 0,
    'SAWADA': 0,
    'SAWADE': 0,
    'SAWAGED': 0,
    'SAWAI': 0,
    'SAWALL': 0,
    'SAWAMURA': 0,
    'SAWAN': 0,
    'SAWANT': 0,
    'SAWATSKY': 0,
    'SAWATZKE': 0,
    'SAWATZKI': 0,
    'SAWATZKY': 0,
    'SAWAYA': 0,
    'SAWCHAK': 0,
    'SAWCHUK': 0,
    'SAWCZUK': 0,
    'SAWCZYN': 0,
    'SAWDEY': 0,
    'SAWDON': 0,
    'SAWDY': 0,
    'SAWER': 0,
    'SAWERS': 0,
    'SAWEY': 0,
    'SAWH': 0,
    'SAWHILL': 0,
    'SAWHNEY': 0,
    'SAWICK': 0,
    'SAWICKI': 0,
    'SAWICKY': 0,
    'SAWIN': 0,
    'SAWINSKI': 0,
    'SAWKA': 0,
    'SAWLE': 0,
    'SAWLER': 0,
    'SAWMILLER': 0,
    'SAWN': 0,
    'SAWNEY': 0,
    'SAWREY': 0,
    'SAWTELL': 0,
    'SAWTELLE': 0,
    'SAWVEL': 0,
    'SAWVELL': 0,
    'SAWYER': 0,
    'SAWYERS': 0,
    'SAX': 0,
    'SAXBERG': 0,
    'SAXBURY': 0,
    'SAXBY': 0,
    'SAXE': 0,
    'SAXEN': 0,
    'SAXENA': 0,
    'SAXER': 0,
    'SAXEY': 0,
    'SAXION': 0,
    'SAXMAN': 0,
    'SAXON': 0,
    'SAXTON': 0,
    'SAY': 0,
    'SAYA': 0,
    'SAYAD': 0,
    'SAYADIAN': 0,
    'SAYAGO': 0,
    'SAYAH': 0,
    'SAYAN': 0,
    'SAYANI': 0,
    'SAYARATH': 0,
    'SAYAS': 0,
    'SAYASANE': 0,
    'SAYAVONG': 0,
    'SAYCE': 0,
    'SAYCOCIE': 0,
    'SAYE': 0,
    'SAYED': 0,
    'SAYEED': 0,
    'SAYEGH': 0,
    'SAYEN': 0,
    'SAYER': 0,
    'SAYERS': 0,
    'SAYES': 0,
    'SAYGER': 0,
    'SAYKO': 0,
    'SAYLE': 0,
    'SAYLER': 0,
    'SAYLES': 0,
    'SAYLOR': 0,
    'SAYLORS': 0,
    'SAYMAN': 0,
    'SAYNE': 0,
    'SAYO': 0,
    'SAYRE': 0,
    'SAYRES': 0,
    'SAYSON': 0,
    'SAYWARD': 0,
    'SAYYAD': 0,
    'SAYYAH': 0,
    'SAYYED': 0,
    'SAZAMA': 0,
    'SAZO': 0,
    'SAZON': 0,
    'SBARBARO': 0,
    'SBARDELLA': 0,
    'SBARRA': 0,
    'SBARRO': 0,
    'SBERNA': 0,
    'SBLENDORIO': 0,
    'SBORDONE': 0,
    'SBRACCIA': 0,
    'SBRAGIA': 0,
    'SBROCCO': 0,
    'SC': 0,
    'SCACCHETTI': 0,
    'SCACCIA': 0,
    'SCACCIANOCE': 0,
    'SCACCO': 0,
    'SCACE': 0,
    'SCADDEN': 0,
    'SCADUTO': 0,
    'SCAFE': 0,
    'SCAFF': 0,
    'SCAFFE': 0,
    'SCAFFIDI': 0,
    'SCAFIDE': 0,
    'SCAFIDI': 0,
    'SCAFURI': 0,
    'SCAGGS': 0,
    'SCAGLIA': 0,
    'SCAGLIARINI': 0,
    'SCAGLIONE': 0,
    'SCAGLIOTTI': 0,
    'SCAGNELLI': 0,
    'SCAHILL': 0,
    'SCAIA': 0,
    'SCAIFE': 0,
    'SCALA': 0,
    'SCALABRINO': 0,
    'SCALCIONE': 0,
    'SCALCO': 0,
    'SCALE': 0,
    'SCALERA': 0,
    'SCALERCIO': 0,
    'SCALERO': 0,
    'SCALES': 0,
    'SCALESE': 0,
    'SCALESSE': 0,
    'SCALETTA': 0,
    'SCALETTI': 0,
    'SCALF': 0,
    'SCALFANI': 0,
    'SCALFARO': 0,
    'SCALI': 0,
    'SCALIA': 0,
    'SCALICE': 0,
    'SCALICI': 0,
    'SCALISE': 0,
    'SCALISI': 0,
    'SCALLAN': 0,
    'SCALLEN': 0,
    'SCALLEY': 0,
    'SCALLION': 0,
    'SCALLIONS': 0,
    'SCALLON': 0,
    'SCALLORN': 0,
    'SCALLY': 0,
    'SCALO': 0,
    'SCALONE': 0,
    'SCALORA': 0,
    'SCALZI': 0,
    'SCALZITTI': 0,
    'SCALZO': 0,
    'SCAMAHORN': 0,
    'SCAMAN': 0,
    'SCAMARDELLA': 0,
    'SCAMARDO': 0,
    'SCAMEHORN': 0,
    'SCAMIHORN': 0,
    'SCAMMAHORN': 0,
    'SCAMMAN': 0,
    'SCAMMELL': 0,
    'SCAMMON': 0,
    'SCAMP': 0,
    'SCAMPINI': 0,
    'SCAMPOLI': 0,
    'SCANDALE': 0,
    'SCANDARIATO': 0,
    'SCANDIFFIO': 0,
    'SCANDONE': 0,
    'SCANDRETT': 0,
    'SCANDRICK': 0,
    'SCANDURA': 0,
    'SCANDURRA': 0,
    'SCANGA': 0,
    'SCANIO': 0,
    'SCANK': 0,
    'SCANLAN': 0,
    'SCANLAND': 0,
    'SCANLIN': 0,
    'SCANLON': 0,
    'SCANNAPIECO': 0,
    'SCANNELL': 0,
    'SCANNELLA': 0,
    'SCANNELLI': 0,
    'SCANO': 0,
    'SCANTLAND': 0,
    'SCANTLEBURY': 0,
    'SCANTLEN': 0,
    'SCANTLIN': 0,
    'SCANTLING': 0,
    'SCANZILLO': 0,
    'SCAPICCHIO': 0,
    'SCAPIN': 0,
    'SCAPLEN': 0,
    'SCAPPATICCI': 0,
    'SCARA': 0,
    'SCARABINO': 0,
    'SCARAFILE': 0,
    'SCARAMELLA': 0,
    'SCARAMUZZI': 0,
    'SCARAMUZZINO': 0,
    'SCARAMUZZO': 0,
    'SCARANGELLA': 0,
    'SCARANGELLO': 0,
    'SCARANO': 0,
    'SCARANTINO': 0,
    'SCARBARY': 0,
    'SCARBER': 0,
    'SCARBERRY': 0,
    'SCARBORD': 0,
    'SCARBORO': 0,
    'SCARBOROUGH': 0,
    'SCARBOUGH': 0,
    'SCARBRO': 0,
    'SCARBROUGH': 0,
    'SCARCE': 0,
    'SCARCELLA': 0,
    'SCARCELLI': 0,
    'SCARCELLO': 0,
    'SCARCHILLI': 0,
    'SCARCIA': 0,
    'SCARCLIFF': 0,
    'SCARDIGNO': 0,
    'SCARDINA': 0,
    'SCARDINO': 0,
    'SCARDUZIO': 0,
    'SCARF': 0,
    'SCARFE': 0,
    'SCARFF': 0,
    'SCARFI': 0,
    'SCARFO': 0,
    'SCARFONE': 0,
    'SCARIANO': 0,
    'SCARINCI': 0,
    'SCARINGE': 0,
    'SCARINGI': 0,
    'SCARINZI': 0,
    'SCARLATA': 0,
    'SCARLATO': 0,
    'SCARLET': 0.9615384615384616,
    'SCARLETT': 0.7233273056057866,
    'SCARLETTE': 0,
    'SCARMARDO': 0,
    'SCARNATI': 0,
    'SCARNATO': 0,
    'SCARNECCHIA': 0,
    'SCAROLA': 0,
    'SCARPA': 0,
    'SCARPACE': 0,
    'SCARPACI': 0,
    'SCARPATI': 0,
    'SCARPATO': 0,
    'SCARPELLI': 0,
    'SCARPELLO': 0,
    'SCARPETTA': 0,
    'SCARPETTI': 0,
    'SCARPINATO': 0,
    'SCARPINO': 0,
    'SCARPITTA': 0,
    'SCARPITTI': 0,
    'SCARPONE': 0,
    'SCARPONI': 0,
    'SCARPULLA': 0,
    'SCARR': 0,
    'SCARROW': 0,
    'SCARRY': 0,
    'SCARSELLA': 0,
    'SCARTH': 0,
    'SCARTON': 0,
    'SCARTOZZI': 0,
    'SCARVER': 0,
    'SCASNY': 0,
    'SCATA': 0,
    'SCATENA': 0,
    'SCATES': 0,
    'SCATLIFFE': 0,
    'SCATTERDAY': 0,
    'SCATTERGOOD': 0,
    'SCATTON': 0,
    'SCATURRO': 0,
    'SCAVELLA': 0,
    'SCAVELLI': 0,
    'SCAVELLO': 0,
    'SCAVETTA': 0,
    'SCAVO': 0,
    'SCAVONE': 0,
    'SCAVOTTO': 0,
    'SCAVUZZO': 0,
    'SCEARCE': 0,
    'SCEARCY': 0,
    'SCEARS': 0,
    'SCEGO': 0,
    'SCELFO': 0,
    'SCELSI': 0,
    'SCELZA': 0,
    'SCELZI': 0,
    'SCELZO': 0,
    'SCENNA': 0,
    'SCEPANIAK': 0,
    'SCERBA': 0,
    'SCERBO': 0,
    'SCERCY': 0,
    'SCERRA': 0,
    'SCERRI': 0,
    'SCESNY': 0,
    'SCH': 0,
    'SCHAA': 0,
    'SCHAAB': 0,
    'SCHAACK': 0,
    'SCHAAD': 0,
    'SCHAADT': 0,
    'SCHAAF': 0,
    'SCHAAFF': 0,
    'SCHAAFSMA': 0,
    'SCHAAK': 0,
    'SCHAAKE': 0,
    'SCHAAL': 0,
    'SCHAALMA': 0,
    'SCHAAN': 0,
    'SCHAAP': 0,
    'SCHAAPVELD': 0,
    'SCHAAR': 0,
    'SCHAARSCHMIDT': 0,
    'SCHAB': 0,
    'SCHABACKER': 0,
    'SCHABEL': 0,
    'SCHABEN': 0,
    'SCHABER': 0,
    'SCHABERG': 0,
    'SCHABERT': 0,
    'SCHABES': 0,
    'SCHABLE': 0,
    'SCHABO': 0,
    'SCHABOW': 0,
    'SCHACH': 0,
    'SCHACHER': 0,
    'SCHACHERER': 0,
    'SCHACHERL': 0,
    'SCHACHINGER': 0,
    'SCHACHLE': 0,
    'SCHACHNER': 0,
    'SCHACHT': 0,
    'SCHACHTE': 0,
    'SCHACHTEL': 0,
    'SCHACHTER': 0,
    'SCHACHTERLE': 0,
    'SCHACHTNER': 0,
    'SCHACHTSCHNEIDE': 0,
    'SCHACK': 0,
    'SCHACKART': 0,
    'SCHACKMAN': 0,
    'SCHACKMANN': 0,
    'SCHACKOW': 0,
    'SCHACTER': 0,
    'SCHAD': 0,
    'SCHADE': 0,
    'SCHADEGG': 0,
    'SCHADEL': 0,
    'SCHADEN': 0,
    'SCHADER': 0,
    'SCHADEWALD': 0,
    'SCHADLE': 0,
    'SCHADLER': 0,
    'SCHADOW': 0,
    'SCHADT': 0,
    'SCHAECHER': 0,
    'SCHAECHTER': 0,
    'SCHAEDEL': 0,
    'SCHAEDIG': 0,
    'SCHAEDLER': 0,
    'SCHAEF': 0,
    'SCHAEFBAUER': 0,
    'SCHAEFER': 0,
    'SCHAEFERS': 0,
    'SCHAEFFER': 0,
    'SCHAEFFLER': 0,
    'SCHAEKEL': 0,
    'SCHAEN': 0,
    'SCHAENZER': 0,
    'SCHAEPER': 0,
    'SCHAEPPI': 0,
    'SCHAER': 0,
    'SCHAERER': 0,
    'SCHAETZ': 0,
    'SCHAETZEL': 0,
    'SCHAETZLE': 0,
    'SCHAF': 0,
    'SCHAFBUCH': 0,
    'SCHAFER': 0,
    'SCHAFERS': 0,
    'SCHAFF': 0,
    'SCHAFFEL': 0,
    'SCHAFFELD': 0,
    'SCHAFFER': 0,
    'SCHAFFERT': 0,
    'SCHAFFHAUSEN': 0,
    'SCHAFFHAUSER': 0,
    'SCHAFFINO': 0,
    'SCHAFFLER': 0,
    'SCHAFFNER': 0,
    'SCHAFFNIT': 0,
    'SCHAFFRAN': 0,
    'SCHAFFRATH': 0,
    'SCHAFFRICK': 0,
    'SCHAFFTER': 0,
    'SCHAFHAUSER': 0,
    'SCHAFLER': 0,
    'SCHAFMAN': 0,
    'SCHAFRAN': 0,
    'SCHAFROTH': 0,
    'SCHAFSTALL': 0,
    'SCHAFTLEIN': 0,
    'SCHAG': 0,
    'SCHAGER': 0,
    'SCHAIBLE': 0,
    'SCHAICH': 0,
    'SCHAID': 0,
    'SCHAIDT': 0,
    'SCHAIN': 0,
    'SCHAIRER': 0,
    'SCHAITEL': 0,
    'SCHAK': 0,
    'SCHAKE': 0,
    'SCHAKEL': 0,
    'SCHALCK': 0,
    'SCHALE': 0,
    'SCHALER': 0,
    'SCHALES': 0,
    'SCHALK': 0,
    'SCHALL': 0,
    'SCHALLA': 0,
    'SCHALLENBERG': 0,
    'SCHALLENBERGER': 0,
    'SCHALLER': 0,
    'SCHALLERT': 0,
    'SCHALLES': 0,
    'SCHALLHORN': 0,
    'SCHALLIOL': 0,
    'SCHALLMO': 0,
    'SCHALLOCK': 0,
    'SCHALM': 0,
    'SCHALOW': 0,
    'SCHALTENBRAND': 0,
    'SCHAMBACH': 0,
    'SCHAMBER': 0,
    'SCHAMBERG': 0,
    'SCHAMBERGER': 0,
    'SCHAMBERS': 0,
    'SCHAMBURG': 0,
    'SCHAMEL': 0,
    'SCHAMENS': 0,
    'SCHAMERHORN': 0,
    'SCHAMING': 0,
    'SCHAMMEL': 0,
    'SCHAMP': 0,
    'SCHAMS': 0,
    'SCHAN': 0,
    'SCHANAMAN': 0,
    'SCHANBACHER': 0,
    'SCHANBERGER': 0,
    'SCHANCK': 0,
    'SCHANDA': 0,
    'SCHANDEL': 0,
    'SCHANDELMEIER': 0,
    'SCHANDER': 0,
    'SCHANE': 0,
    'SCHANEMAN': 0,
    'SCHANEN': 0,
    'SCHANER': 0,
    'SCHANG': 0,
    'SCHANILEC': 0,
    'SCHANK': 0,
    'SCHANKE': 0,
    'SCHANKER': 0,
    'SCHANKIN': 0,
    'SCHANKS': 0,
    'SCHANKWEILER': 0,
    'SCHANNE': 0,
    'SCHANNO': 0,
    'SCHANTZ': 0,
    'SCHANTZEN': 0,
    'SCHANUEL': 0,
    'SCHANZ': 0,
    'SCHANZE': 0,
    'SCHANZENBACH': 0,
    'SCHANZER': 0,
    'SCHAP': 0,
    'SCHAPANSKY': 0,
    'SCHAPER': 0,
    'SCHAPIRA': 0,
    'SCHAPIRO': 0,
    'SCHAPKER': 0,
    'SCHAPP': 0,
    'SCHAPPACHER': 0,
    'SCHAPPAUGH': 0,
    'SCHAPPE': 0,
    'SCHAPPELL': 0,
    'SCHAPPERT': 0,
    'SCHAPS': 0,
    'SCHAR': 0,
    'SCHARA': 0,
    'SCHARBACH': 0,
    'SCHARBER': 0,
    'SCHARBROUGH': 0,
    'SCHARDEIN': 0,
    'SCHARDIN': 0,
    'SCHARDT': 0,
    'SCHAREN': 0,
    'SCHARENBERG': 0,
    'SCHARENBROCH': 0,
    'SCHARER': 0,
    'SCHARES': 0,
    'SCHARETT': 0,
    'SCHARF': 0,
    'SCHARFE': 0,
    'SCHARFENBERG': 0,
    'SCHARFENBERGER': 0,
    'SCHARFF': 0,
    'SCHARFMAN': 0,
    'SCHARFSTEIN': 0,
    'SCHARICH': 0,
    'SCHARIO': 0,
    'SCHARLACH': 0,
    'SCHARLAU': 0,
    'SCHARLOW': 0,
    'SCHARMAN': 0,
    'SCHARMANN': 0,
    'SCHARMER': 0,
    'SCHARN': 0,
    'SCHARNBERG': 0,
    'SCHARNHORST': 0,
    'SCHARNWEBER': 0,
    'SCHARON': 0,
    'SCHAROUN': 0,
    'SCHARP': 0,
    'SCHARPF': 0,
    'SCHARPHORN': 0,
    'SCHARPING': 0,
    'SCHARR': 0,
    'SCHARRER': 0,
    'SCHARRINGHAUSEN': 0,
    'SCHARTIGER': 0,
    'SCHARTNER': 0,
    'SCHARTON': 0,
    'SCHARTZ': 0,
    'SCHARVER': 0,
    'SCHASER': 0,
    'SCHASTEEN': 0,
    'SCHAT': 0,
    'SCHATT': 0,
    'SCHATTE': 0,
    'SCHATTEL': 0,
    'SCHATTEN': 0,
    'SCHATTNER': 0,
    'SCHATTSCHNEIDER': 0,
    'SCHATZ': 0,
    'SCHATZBERG': 0,
    'SCHATZEL': 0,
    'SCHATZER': 0,
    'SCHATZKE': 0,
    'SCHATZLE': 0,
    'SCHATZLEIN': 0,
    'SCHATZMAN': 0,
    'SCHAU': 0,
    'SCHAUB': 0,
    'SCHAUBEL': 0,
    'SCHAUBER': 0,
    'SCHAUBERT': 0,
    'SCHAUBHUT': 0,
    'SCHAUBLE': 0,
    'SCHAUBLIN': 0,
    'SCHAUBROECK': 0,
    'SCHAUDER': 0,
    'SCHAUDT': 0,
    'SCHAUER': 0,
    'SCHAUF': 0,
    'SCHAUFELBERGER': 0,
    'SCHAUFELE': 0,
    'SCHAUFF': 0,
    'SCHAUFFLER': 0,
    'SCHAUFLER': 0,
    'SCHAUGAARD': 0,
    'SCHAUL': 0,
    'SCHAUM': 0,
    'SCHAUMAN': 0,
    'SCHAUMANN': 0,
    'SCHAUMBERG': 0,
    'SCHAUMBURG': 0,
    'SCHAUMLEFFEL': 0,
    'SCHAUNAMAN': 0,
    'SCHAUPP': 0,
    'SCHAURER': 0,
    'SCHAUS': 0,
    'SCHAUSS': 0,
    'SCHAUST': 0,
    'SCHAUT': 0,
    'SCHAUWECKER': 0,
    'SCHAVE': 0,
    'SCHAVER': 0,
    'SCHAVEY': 0,
    'SCHAWE': 0,
    'SCHAY': 0,
    'SCHEAFER': 0,
    'SCHEAFFER': 0,
    'SCHEALL': 0,
    'SCHEAR': 0,
    'SCHEARER': 0,
    'SCHEBEL': 0,
    'SCHEBLER': 0,
    'SCHECH': 0,
    'SCHECHER': 0,
    'SCHECHINGER': 0,
    'SCHECHNER': 0,
    'SCHECHTER': 0,
    'SCHECHTMAN': 0,
    'SCHECK': 0,
    'SCHECKEL': 0,
    'SCHECKELHOFF': 0,
    'SCHECKER': 0,
    'SCHECTER': 0,
    'SCHECTMAN': 0,
    'SCHEDEL': 0,
    'SCHEDIN': 0,
    'SCHEDLBAUER': 0,
    'SCHEDLER': 0,
    'SCHEE': 0,
    'SCHEEF': 0,
    'SCHEEL': 0,
    'SCHEELE': 0,
    'SCHEELER': 0,
    'SCHEELS': 0,
    'SCHEEN': 0,
    'SCHEER': 0,
    'SCHEERER': 0,
    'SCHEERINGA': 0,
    'SCHEESE': 0,
    'SCHEET': 0,
    'SCHEETS': 0,
    'SCHEETZ': 0,
    'SCHEEVEL': 0,
    'SCHEFER': 0,
    'SCHEFERS': 0,
    'SCHEFF': 0,
    'SCHEFFE': 0,
    'SCHEFFEL': 0,
    'SCHEFFER': 0,
    'SCHEFFERS': 0,
    'SCHEFFERT': 0,
    'SCHEFFEY': 0,
    'SCHEFFLER': 0,
    'SCHEFFNER': 0,
    'SCHEFKE': 0,
    'SCHEFTER': 0,
    'SCHEG': 0,
    'SCHEHL': 0,
    'SCHEHR': 0,
    'SCHEI': 0,
    'SCHEIB': 0,
    'SCHEIBE': 0,
    'SCHEIBEL': 0,
    'SCHEIBELHUT': 0,
    'SCHEIBER': 0,
    'SCHEIBLE': 0,
    'SCHEIBLER': 0,
    'SCHEIBNER': 0,
    'SCHEICH': 0,
    'SCHEICK': 0,
    'SCHEID': 0,
    'SCHEIDE': 0,
    'SCHEIDECKER': 0,
    'SCHEIDEGGER': 0,
    'SCHEIDEL': 0,
    'SCHEIDELER': 0,
    'SCHEIDELL': 0,
    'SCHEIDEMAN': 0,
    'SCHEIDEMANTEL': 0,
    'SCHEIDEMANTLE': 0,
    'SCHEIDER': 0,
    'SCHEIDERER': 0,
    'SCHEIDING': 0,
    'SCHEIDLER': 0,
    'SCHEIDT': 0,
    'SCHEIE': 0,
    'SCHEIER': 0,
    'SCHEIFELE': 0,
    'SCHEIHING': 0,
    'SCHEIL': 0,
    'SCHEIMAN': 0,
    'SCHEIN': 0,
    'SCHEINBERG': 0,
    'SCHEINER': 0,
    'SCHEINERT': 0,
    'SCHEINFELD': 0,
    'SCHEINMAN': 0,
    'SCHEINOST': 0,
    'SCHEIRER': 0,
    'SCHEIRMAN': 0,
    'SCHEITER': 0,
    'SCHEITHAUER': 0,
    'SCHEITLER': 0,
    'SCHEITLIN': 0,
    'SCHEIVERT': 0,
    'SCHEIWE': 0,
    'SCHELB': 0,
    'SCHELBLE': 0,
    'SCHELD': 0,
    'SCHELER': 0,
    'SCHELHAAS': 0,
    'SCHELHORN': 0,
    'SCHELICH': 0,
    'SCHELIN': 0,
    'SCHELL': 0,
    'SCHELLBERG': 0,
    'SCHELLE': 0,
    'SCHELLENBERG': 0,
    'SCHELLENBERGER': 0,
    'SCHELLENGER': 0,
    'SCHELLER': 0,
    'SCHELLHAAS': 0,
    'SCHELLHAMER': 0,
    'SCHELLHAMMER': 0,
    'SCHELLHARDT': 0,
    'SCHELLHAS': 0,
    'SCHELLHASE': 0,
    'SCHELLHORN': 0,
    'SCHELLIN': 0,
    'SCHELLING': 0,
    'SCHELLINGER': 0,
    'SCHELLMAN': 0,
    'SCHELLPFEFFER': 0,
    'SCHELLY': 0,
    'SCHELM': 0,
    'SCHELP': 0,
    'SCHELSKE': 0,
    'SCHELTER': 0,
    'SCHEMA': 0,
    'SCHEMAN': 0,
    'SCHEMANSKY': 0,
    'SCHEMBARI': 0,
    'SCHEMBER': 0,
    'SCHEMBRE': 0,
    'SCHEMBRI': 0,
    'SCHEMEL': 0,
    'SCHEMENAUER': 0,
    'SCHEMER': 0,
    'SCHEMM': 0,
    'SCHEMMEL': 0,
    'SCHEMMER': 0,
    'SCHEMPER': 0,
    'SCHEMPF': 0,
    'SCHEMPP': 0,
    'SCHENA': 0,
    'SCHENBERG': 0,
    'SCHENCK': 0,
    'SCHENDEL': 0,
    'SCHENDT': 0,
    'SCHENE': 0,
    'SCHENEMAN': 0,
    'SCHENEWERK': 0,
    'SCHENFELD': 0,
    'SCHENK': 0,
    'SCHENKE': 0,
    'SCHENKEL': 0,
    'SCHENKELBERG': 0,
    'SCHENKENBERGER': 0,
    'SCHENKER': 0,
    'SCHENKMAN': 0,
    'SCHENNING': 0,
    'SCHENONE': 0,
    'SCHENZ': 0,
    'SCHEPENS': 0,
    'SCHEPER': 0,
    'SCHEPERS': 0,
    'SCHEPIS': 0,
    'SCHEPISI': 0,
    'SCHEPKER': 0,
    'SCHEPLER': 0,
    'SCHEPMAN': 0,
    'SCHEPP': 0,
    'SCHEPPER': 0,
    'SCHEPPERS': 0,
    'SCHEPPLER': 0,
    'SCHEPPMANN': 0,
    'SCHEPPS': 0,
    'SCHEPS': 0,
    'SCHER': 0,
    'SCHERB': 0,
    'SCHERBA': 0,
    'SCHERBAN': 0,
    'SCHERBARTH': 0,
    'SCHERBEL': 0,
    'SCHERBENSKE': 0,
    'SCHERBER': 0,
    'SCHERBERT': 0,
    'SCHERBING': 0,
    'SCHERBRING': 0,
    'SCHERCK': 0,
    'SCHERDER': 0,
    'SCHERE': 0,
    'SCHERER': 0,
    'SCHERF': 0,
    'SCHERFF': 0,
    'SCHERFFIUS': 0,
    'SCHERGER': 0,
    'SCHERI': 0,
    'SCHERICH': 0,
    'SCHERIFF': 0,
    'SCHERING': 0,
    'SCHERKENBACH': 0,
    'SCHERL': 0,
    'SCHERLE': 0,
    'SCHERLER': 0,
    'SCHERLING': 0,
    'SCHERM': 0,
    'SCHERMAN': 0,
    'SCHERMANN': 0,
    'SCHERMER': 0,
    'SCHERMERHORN': 0,
    'SCHERMETZLER': 0,
    'SCHERNER': 0,
    'SCHERPING': 0,
    'SCHERR': 0,
    'SCHERRER': 0,
    'SCHERRY': 0,
    'SCHERSCHEL': 0,
    'SCHERSCHLIGT': 0,
    'SCHERTLER': 0,
    'SCHERTZ': 0,
    'SCHERTZER': 0,
    'SCHERWINSKI': 0,
    'SCHERZ': 0,
    'SCHERZER': 0,
    'SCHERZINGER': 0,
    'SCHESKE': 0,
    'SCHESSER': 0,
    'SCHESSLER': 0,
    'SCHETROMPF': 0,
    'SCHETTER': 0,
    'SCHETTINI': 0,
    'SCHETTINO': 0,
    'SCHETTLER': 0,
    'SCHEU': 0,
    'SCHEUBER': 0,
    'SCHEUBLE': 0,
    'SCHEUCH': 0,
    'SCHEUER': 0,
    'SCHEUERLEIN': 0,
    'SCHEUERMAN': 0,
    'SCHEUERMANN': 0,
    'SCHEUERS': 0,
    'SCHEUFELE': 0,
    'SCHEUFFELE': 0,
    'SCHEUFLER': 0,
    'SCHEUING': 0,
    'SCHEULEN': 0,
    'SCHEULER': 0,
    'SCHEUMANN': 0,
    'SCHEUNEMAN': 0,
    'SCHEUNEMANN': 0,
    'SCHEUREN': 0,
    'SCHEURER': 0,
    'SCHEURICH': 0,
    'SCHEURING': 0,
    'SCHEURMAN': 0,
    'SCHEUTZOW': 0,
    'SCHEVE': 0,
    'SCHEVER': 0,
    'SCHEVERS': 0,
    'SCHEVING': 0,
    'SCHEWE': 0,
    'SCHEXNAIDER': 0,
    'SCHEXNAYDER': 0,
    'SCHEXNAYDRE': 0,
    'SCHEXNEIDER': 0,
    'SCHEXNIDER': 0,
    'SCHEXNYDER': 0,
    'SCHEY': 0,
    'SCHEYER': 0,
    'SCHIACHTER': 0,
    'SCHIAFFINO': 0,
    'SCHIAFFO': 0,
    'SCHIANO': 0,
    'SCHIAPPA': 0,
    'SCHIAPPACASSE': 0,
    'SCHIAVELLO': 0,
    'SCHIAVI': 0,
    'SCHIAVO': 0,
    'SCHIAVONE': 0,
    'SCHIAVONI': 0,
    'SCHIAZZA': 0,
    'SCHIBI': 0,
    'SCHIBLER': 0,
    'SCHIBLEY': 0,
    'SCHICHTEL': 0,
    'SCHICHTL': 0,
    'SCHICK': 0,
    'SCHICKE': 0,
    'SCHICKEDANZ': 0,
    'SCHICKEL': 0,
    'SCHICKER': 0,
    'SCHICKERT': 0,
    'SCHICKLER': 0,
    'SCHICKLING': 0,
    'SCHIE': 0,
    'SCHIEB': 0,
    'SCHIEBE': 0,
    'SCHIEBEL': 0,
    'SCHIEBER': 0,
    'SCHIEBERL': 0,
    'SCHIEBLE': 0,
    'SCHIEBOUT': 0,
    'SCHIECK': 0,
    'SCHIED': 0,
    'SCHIEDEL': 0,
    'SCHIEDER': 0,
    'SCHIEDERMAYER': 0,
    'SCHIEFELBEIN': 0,
    'SCHIEFEN': 0,
    'SCHIEFER': 0,
    'SCHIEFERDECKER': 0,
    'SCHIEFERSTEIN': 0,
    'SCHIEFFELIN': 0,
    'SCHIEFFER': 0,
    'SCHIEK': 0,
    'SCHIEL': 0,
    'SCHIELD': 0,
    'SCHIELDS': 0,
    'SCHIELE': 0,
    'SCHIELER': 0,
    'SCHIELKE': 0,
    'SCHIELTZ': 0,
    'SCHIEMAN': 0,
    'SCHIEMANN': 0,
    'SCHIEMER': 0,
    'SCHIER': 0,
    'SCHIERBAUM': 0,
    'SCHIERBEEK': 0,
    'SCHIERENBECK': 0,
    'SCHIERER': 0,
    'SCHIERHOLZ': 0,
    'SCHIERING': 0,
    'SCHIERLING': 0,
    'SCHIERLOH': 0,
    'SCHIERMAN': 0,
    'SCHIERMEISTER': 0,
    'SCHIERMEYER': 0,
    'SCHIERS': 0,
    'SCHIES': 0,
    'SCHIESEL': 0,
    'SCHIESL': 0,
    'SCHIESS': 0,
    'SCHIESSER': 0,
    'SCHIESSL': 0,
    'SCHIEVE': 0,
    'SCHIEVELBEIN': 0,
    'SCHIEWE': 0,
    'SCHIFAND': 0,
    'SCHIFANO': 0,
    'SCHIFER': 0,
    'SCHIFERL': 0,
    'SCHIFF': 0,
    'SCHIFFBAUER': 0,
    'SCHIFFELBEIN': 0,
    'SCHIFFER': 0,
    'SCHIFFERDECKER': 0,
    'SCHIFFERLE': 0,
    'SCHIFFERT': 0,
    'SCHIFFHAUER': 0,
    'SCHIFFLER': 0,
    'SCHIFFLI': 0,
    'SCHIFFMACHER': 0,
    'SCHIFFMAN': 0,
    'SCHIFFNER': 0,
    'SCHIFINO': 0,
    'SCHIFRIN': 0,
    'SCHIFSKY': 0,
    'SCHIFTER': 0,
    'SCHIHL': 0,
    'SCHIKORA': 0,
    'SCHILB': 0,
    'SCHILCHER': 0,
    'SCHILD': 0,
    'SCHILDER': 0,
    'SCHILDGEN': 0,
    'SCHILDHAUER': 0,
    'SCHILDKNECHT': 0,
    'SCHILDKRAUT': 0,
    'SCHILDMEYER': 0,
    'SCHILDROTH': 0,
    'SCHILDT': 0,
    'SCHILDWACHTER': 0,
    'SCHILE': 0,
    'SCHILF': 0,
    'SCHILHAB': 0,
    'SCHILIRO': 0,
    'SCHILK': 0,
    'SCHILKE': 0,
    'SCHILL': 0,
    'SCHILLA': 0,
    'SCHILLACE': 0,
    'SCHILLACI': 0,
    'SCHILLE': 0,
    'SCHILLECI': 0,
    'SCHILLER': 0,
    'SCHILLEREFF': 0,
    'SCHILLERSTROM': 0,
    'SCHILLI': 0,
    'SCHILLIG': 0,
    'SCHILLING': 0,
    'SCHILLINGER': 0,
    'SCHILLINGS': 0,
    'SCHILLIZZI': 0,
    'SCHILLO': 0,
    'SCHILLY': 0,
    'SCHILMOELLER': 0,
    'SCHILPEROORT': 0,
    'SCHILPP': 0,
    'SCHILS': 0,
    'SCHILT': 0,
    'SCHILTER': 0,
    'SCHILTZ': 0,
    'SCHILZ': 0,
    'SCHIMA': 0,
    'SCHIMANSKI': 0,
    'SCHIMBERG': 0,
    'SCHIMDT': 0,
    'SCHIMEK': 0,
    'SCHIMEL': 0,
    'SCHIMELPFENIG': 0,
    'SCHIMENTI': 0,
    'SCHIMIZZI': 0,
    'SCHIMKE': 0,
    'SCHIMMEL': 0,
    'SCHIMMELPFENNIG': 0,
    'SCHIMMELS': 0,
    'SCHIMMENTI': 0,
    'SCHIMMER': 0,
    'SCHIMMING': 0,
    'SCHIMMOELLER': 0,
    'SCHIMMOLLER': 0,
    'SCHIMP': 0,
    'SCHIMPF': 0,
    'SCHIMPFF': 0,
    'SCHINDEL': 0,
    'SCHINDELDECKER': 0,
    'SCHINDELE': 0,
    'SCHINDER': 0,
    'SCHINDERLE': 0,
    'SCHINDEWOLF': 0,
    'SCHINDLBECK': 0,
    'SCHINDLER': 0,
    'SCHINE': 0,
    'SCHINELLA': 0,
    'SCHINK': 0,
    'SCHINKE': 0,
    'SCHINKEL': 0,
    'SCHINKER': 0,
    'SCHINNER': 0,
    'SCHINNERER': 0,
    'SCHINSKE': 0,
    'SCHINSKI': 0,
    'SCHINSTOCK': 0,
    'SCHINTGEN': 0,
    'SCHINTZ': 0,
    'SCHINTZIUS': 0,
    'SCHINZEL': 0,
    'SCHINZING': 0,
    'SCHIPANI': 0,
    'SCHIPKE': 0,
    'SCHIPMAN': 0,
    'SCHIPP': 0,
    'SCHIPPER': 0,
    'SCHIPPERS': 0,
    'SCHIPPERT': 0,
    'SCHIPULL': 0,
    'SCHIRA': 0,
    'SCHIRADO': 0,
    'SCHIRALDI': 0,
    'SCHIRALLI': 0,
    'SCHIRATO': 0,
    'SCHIRER': 0,
    'SCHIRF': 0,
    'SCHIRK': 0,
    'SCHIRLE': 0,
    'SCHIRM': 0,
    'SCHIRMACHER': 0,
    'SCHIRMER': 0,
    'SCHIRMERS': 0,
    'SCHIRO': 0,
    'SCHIRRA': 0,
    'SCHIRRIPA': 0,
    'SCHIRTZINGER': 0,
    'SCHISEL': 0,
    'SCHISLER': 0,
    'SCHISSEL': 0,
    'SCHISSLER': 0,
    'SCHKADE': 0,
    'SCHLAACK': 0,
    'SCHLAAK': 0,
    'SCHLABACH': 0,
    'SCHLABAUGH': 0,
    'SCHLABS': 0,
    'SCHLACHT': 0,
    'SCHLACHTER': 0,
    'SCHLACK': 0,
    'SCHLACTER': 0,
    'SCHLADER': 0,
    'SCHLADWEILER': 0,
    'SCHLAEFER': 0,
    'SCHLAEFLI': 0,
    'SCHLAEGEL': 0,
    'SCHLAEGER': 0,
    'SCHLAEPFER': 0,
    'SCHLAF': 0,
    'SCHLAFER': 0,
    'SCHLAFF': 0,
    'SCHLAFFER': 0,
    'SCHLAFKE': 0,
    'SCHLAFLY': 0,
    'SCHLAG': 0,
    'SCHLAGEL': 0,
    'SCHLAGENHAFT': 0,
    'SCHLAGENHAUF': 0,
    'SCHLAGER': 0,
    'SCHLAGETER': 0,
    'SCHLAGHECK': 0,
    'SCHLAGLE': 0,
    'SCHLAHT': 0,
    'SCHLAICH': 0,
    'SCHLAIS': 0,
    'SCHLAK': 0,
    'SCHLAKE': 0,
    'SCHLAMAN': 0,
    'SCHLAMP': 0,
    'SCHLANDER': 0,
    'SCHLANG': 0,
    'SCHLANGE': 0,
    'SCHLANGEN': 0,
    'SCHLANGER': 0,
    'SCHLAPFER': 0,
    'SCHLAPIA': 0,
    'SCHLAPKOHL': 0,
    'SCHLAPPI': 0,
    'SCHLAPPICH': 0,
    'SCHLARB': 0,
    'SCHLARBAUM': 0,
    'SCHLARMAN': 0,
    'SCHLARMANN': 0,
    'SCHLATER': 0,
    'SCHLATHER': 0,
    'SCHLATTER': 0,
    'SCHLATTMAN': 0,
    'SCHLAU': 0,
    'SCHLAUCH': 0,
    'SCHLAUD': 0,
    'SCHLAUDERAFF': 0,
    'SCHLAUTMAN': 0,
    'SCHLAX': 0,
    'SCHLEBEN': 0,
    'SCHLECHT': 0,
    'SCHLECHTE': 0,
    'SCHLECHTER': 0,
    'SCHLECHTY': 0,
    'SCHLECK': 0,
    'SCHLEDER': 0,
    'SCHLEDEWITZ': 0,
    'SCHLEE': 0,
    'SCHLEEDE': 0,
    'SCHLEEF': 0,
    'SCHLEEPER': 0,
    'SCHLEETER': 0,
    'SCHLEGEL': 0,
    'SCHLEGELMILCH': 0,
    'SCHLEH': 0,
    'SCHLEHUBER': 0,
    'SCHLEI': 0,
    'SCHLEICH': 0,
    'SCHLEICHER': 0,
    'SCHLEIDEN': 0,
    'SCHLEIDER': 0,
    'SCHLEIER': 0,
    'SCHLEIF': 0,
    'SCHLEIFER': 0,
    'SCHLEIFF': 0,
    'SCHLEIG': 0,
    'SCHLEIGER': 0,
    'SCHLEIGH': 0,
    'SCHLEIMER': 0,
    'SCHLEIN': 0,
    'SCHLEINING': 0,
    'SCHLEINKOFER': 0,
    'SCHLEIS': 0,
    'SCHLEISMAN': 0,
    'SCHLEMER': 0,
    'SCHLEMM': 0,
    'SCHLEMMER': 0,
    'SCHLENDER': 0,
    'SCHLENER': 0,
    'SCHLENGER': 0,
    'SCHLENK': 0,
    'SCHLENKER': 0,
    'SCHLENSKER': 0,
    'SCHLENVOGT': 0,
    'SCHLENZ': 0,
    'SCHLEPER': 0,
    'SCHLEPP': 0,
    'SCHLEPPENBACH': 0,
    'SCHLEPPI': 0,
    'SCHLEPPY': 0,
    'SCHLER': 0,
    'SCHLERETH': 0,
    'SCHLERF': 0,
    'SCHLESENER': 0,
    'SCHLESIER': 0,
    'SCHLESINGER': 0,
    'SCHLESNER': 0,
    'SCHLESS': 0,
    'SCHLESSELMAN': 0,
    'SCHLESSER': 0,
    'SCHLESSINGER': 0,
    'SCHLESSMAN': 0,
    'SCHLETER': 0,
    'SCHLETT': 0,
    'SCHLETTE': 0,
    'SCHLEUNING': 0,
    'SCHLEUSENER': 0,
    'SCHLEUSNER': 0,
    'SCHLEUTER': 0,
    'SCHLEY': 0,
    'SCHLEYER': 0,
    'SCHLICH': 0,
    'SCHLICHENMAYER': 0,
    'SCHLICHER': 0,
    'SCHLICHT': 0,
    'SCHLICHTE': 0,
    'SCHLICHTER': 0,
    'SCHLICHTING': 0,
    'SCHLICHTMANN': 0,
    'SCHLICK': 0,
    'SCHLICKER': 0,
    'SCHLICKMAN': 0,
    'SCHLIE': 0,
    'SCHLIEBE': 0,
    'SCHLIEDER': 0,
    'SCHLIEF': 0,
    'SCHLIEM': 0,
    'SCHLIEMAN': 0,
    'SCHLIEMANN': 0,
    'SCHLIENTZ': 0,
    'SCHLIENZ': 0,
    'SCHLIEP': 0,
    'SCHLIEPER': 0,
    'SCHLIES': 0,
    'SCHLIESMAN': 0,
    'SCHLIESSER': 0,
    'SCHLIEVE': 0,
    'SCHLIEVERT': 0,
    'SCHLIEWE': 0,
    'SCHLIM': 0,
    'SCHLIMGEN': 0,
    'SCHLIMM': 0,
    'SCHLIMME': 0,
    'SCHLIMMER': 0,
    'SCHLINDWEIN': 0,
    'SCHLINGER': 0,
    'SCHLINGMAN': 0,
    'SCHLINK': 0,
    'SCHLINKE': 0,
    'SCHLINKERT': 0,
    'SCHLINSOG': 0,
    'SCHLIPF': 0,
    'SCHLIPP': 0,
    'SCHLISSEL': 0,
    'SCHLITT': 0,
    'SCHLITTENHART': 0,
    'SCHLITTER': 0,
    'SCHLITTLER': 0,
    'SCHLITZ': 0,
    'SCHLITZER': 0,
    'SCHLOBOHM': 0,
    'SCHLOEDER': 0,
    'SCHLOEGEL': 0,
    'SCHLOEGL': 0,
    'SCHLOEMAN': 0,
    'SCHLOEMER': 0,
    'SCHLOER': 0,
    'SCHLOESSER': 0,
    'SCHLOFF': 0,
    'SCHLOMANN': 0,
    'SCHLOMER': 0,
    'SCHLORFF': 0,
    'SCHLOSBERG': 0,
    'SCHLOSS': 0,
    'SCHLOSSBERG': 0,
    'SCHLOSSER': 0,
    'SCHLOSSMAN': 0,
    'SCHLOTE': 0,
    'SCHLOTFELDT': 0,
    'SCHLOTHAUER': 0,
    'SCHLOTMAN': 0,
    'SCHLOTT': 0,
    'SCHLOTTER': 0,
    'SCHLOTTERBACK': 0,
    'SCHLOTTERBECK': 0,
    'SCHLOTTERER': 0,
    'SCHLOTTHAUER': 0,
    'SCHLOTTMAN': 0,
    'SCHLOTTMANN': 0,
    'SCHLOTZHAUER': 0,
    'SCHLOUGH': 0,
    'SCHLUCHTER': 0,
    'SCHLUCKEBIER': 0,
    'SCHLUETER': 0,
    'SCHLUMBOHM': 0,
    'SCHLUMBRECHT': 0,
    'SCHLUMP': 0,
    'SCHLUMPBERGER': 0,
    'SCHLUMPF': 0,
    'SCHLUND': 0,
    'SCHLUNDT': 0,
    'SCHLUNTZ': 0,
    'SCHLUP': 0,
    'SCHLUPP': 0,
    'SCHLUSSEL': 0,
    'SCHLUSSER': 0,
    'SCHLUTER': 0,
    'SCHLUTERMAN': 0,
    'SCHLYER': 0,
    'SCHMADEKE': 0,
    'SCHMADER': 0,
    'SCHMAELING': 0,
    'SCHMAHL': 0,
    'SCHMAL': 0,
    'SCHMALBACH': 0,
    'SCHMALE': 0,
    'SCHMALENBERGER': 0,
    'SCHMALFELDT': 0,
    'SCHMALING': 0,
    'SCHMALL': 0,
    'SCHMALTZ': 0,
    'SCHMALZ': 0,
    'SCHMALZER': 0,
    'SCHMALZRIED': 0,
    'SCHMANDT': 0,
    'SCHMANSKI': 0,
    'SCHMATZ': 0,
    'SCHMAUCH': 0,
    'SCHMAUDER': 0,
    'SCHMAUS': 0,
    'SCHMAUSS': 0,
    'SCHMAUTZ': 0,
    'SCHMECHEL': 0,
    'SCHMECK': 0,
    'SCHMECKPEPER': 0,
    'SCHMEDDING': 0,
    'SCHMEDEKE': 0,
    'SCHMEDES': 0,
    'SCHMEECKLE': 0,
    'SCHMEELK': 0,
    'SCHMEER': 0,
    'SCHMEHL': 0,
    'SCHMEICHEL': 0,
    'SCHMEIDER': 0,
    'SCHMEIDLER': 0,
    'SCHMEISER': 0,
    'SCHMEISSER': 0,
    'SCHMELING': 0,
    'SCHMELL': 0,
    'SCHMELLING': 0,
    'SCHMELTER': 0,
    'SCHMELTZ': 0,
    'SCHMELTZER': 0,
    'SCHMELZ': 0,
    'SCHMELZER': 0,
    'SCHMELZLE': 0,
    'SCHMENK': 0,
    'SCHMER': 0,
    'SCHMERBECK': 0,
    'SCHMERBER': 0,
    'SCHMERGE': 0,
    'SCHMERLER': 0,
    'SCHMERLING': 0,
    'SCHMERSAHL': 0,
    'SCHMERSAL': 0,
    'SCHMETZER': 0,
    'SCHMICH': 0,
    'SCHMICK': 0,
    'SCHMID': 0,
    'SCHMIDBAUER': 0,
    'SCHMIDER': 0,
    'SCHMIDGALL': 0,
    'SCHMIDL': 0,
    'SCHMIDLAPP': 0,
    'SCHMIDLE': 0,
    'SCHMIDLI': 0,
    'SCHMIDLIN': 0,
    'SCHMIDLING': 0,
    'SCHMIDLKOFER': 0,
    'SCHMIDT': 0,
    'SCHMIDTBAUER': 0,
    'SCHMIDTBERGER': 0,
    'SCHMIDTKE': 0,
    'SCHMIDTKNECHT': 0,
    'SCHMIDTLEIN': 0,
    'SCHMIDTMANN': 0,
    'SCHMIED': 0,
    'SCHMIEDEBERG': 0,
    'SCHMIEDEKNECHT': 0,
    'SCHMIEDEL': 0,
    'SCHMIEDER': 0,
    'SCHMIEDESKAMP': 0,
    'SCHMIEDING': 0,
    'SCHMIEDLIN': 0,
    'SCHMIEDT': 0,
    'SCHMIEG': 0,
    'SCHMIEGE': 0,
    'SCHMIEL': 0,
    'SCHMIER': 0,
    'SCHMIERER': 0,
    'SCHMIESING': 0,
    'SCHMIG': 0,
    'SCHMIGEL': 0,
    'SCHMILL': 0,
    'SCHMILLEN': 0,
    'SCHMINCKE': 0,
    'SCHMINK': 0,
    'SCHMINKE': 0,
    'SCHMINKEY': 0,
    'SCHMIOT': 0,
    'SCHMIRLER': 0,
    'SCHMIT': 0,
    'SCHMITH': 0,
    'SCHMITKE': 0,
    'SCHMITMEYER': 0,
    'SCHMITS': 0,
    'SCHMITT': 0,
    'SCHMITTEL': 0,
    'SCHMITTER': 0,
    'SCHMITTGENS': 0,
    'SCHMITTINGER': 0,
    'SCHMITTLE': 0,
    'SCHMITTLER': 0,
    'SCHMITTLING': 0,
    'SCHMITTOU': 0,
    'SCHMITZ': 0,
    'SCHMITZER': 0,
    'SCHMOCK': 0,
    'SCHMOE': 0,
    'SCHMOEKEL': 0,
    'SCHMOHL': 0,
    'SCHMOKE': 0,
    'SCHMOKER': 0,
    'SCHMOLDT': 0,
    'SCHMOLKE': 0,
    'SCHMOLL': 0,
    'SCHMOLLER': 0,
    'SCHMOLLINGER': 0,
    'SCHMOOCK': 0,
    'SCHMOOK': 0,
    'SCHMOTZER': 0,
    'SCHMOYER': 0,
    'SCHMUCK': 0,
    'SCHMUCKER': 0,
    'SCHMUDE': 0,
    'SCHMUDLACH': 0,
    'SCHMUECKER': 0,
    'SCHMUHL': 0,
    'SCHMUKER': 0,
    'SCHMUKLER': 0,
    'SCHMUNK': 0,
    'SCHMUS': 0,
    'SCHMUTTE': 0,
    'SCHMUTZ': 0,
    'SCHMUTZER': 0,
    'SCHMUTZLER': 0,
    'SCHNAARE': 0,
    'SCHNAARS': 0,
    'SCHNABEL': 0,
    'SCHNABL': 0,
    'SCHNABLE': 0,
    'SCHNACK': 0,
    'SCHNACKEL': 0,
    'SCHNACKENBERG': 0,
    'SCHNACKER': 0,
    'SCHNACKY': 0,
    'SCHNADER': 0,
    'SCHNAIBLE': 0,
    'SCHNAIDT': 0,
    'SCHNAKE': 0,
    'SCHNAKENBERG': 0,
    'SCHNALL': 0,
    'SCHNAPP': 0,
    'SCHNARE': 0,
    'SCHNARR': 0,
    'SCHNARRE': 0,
    'SCHNARRS': 0,
    'SCHNARS': 0,
    'SCHNASE': 0,
    'SCHNATHORST': 0,
    'SCHNATTER': 0,
    'SCHNATZ': 0,
    'SCHNAUBELT': 0,
    'SCHNAUFER': 0,
    'SCHNAUTZ': 0,
    'SCHNEBEL': 0,
    'SCHNEBELEN': 0,
    'SCHNEBERGER': 0,
    'SCHNEBLE': 0,
    'SCHNEBLY': 0,
    'SCHNECK': 0,
    'SCHNECKENBURGER': 0,
    'SCHNECKLOTH': 0,
    'SCHNEDLER': 0,
    'SCHNEE': 0,
    'SCHNEEBERG': 0,
    'SCHNEEBERGER': 0,
    'SCHNEEKLOTH': 0,
    'SCHNEEMAN': 0,
    'SCHNEEMANN': 0,
    'SCHNEER': 0,
    'SCHNEEWEIS': 0,
    'SCHNEEWEISS': 0,
    'SCHNEGG': 0,
    'SCHNEGGENBURGER': 0,
    'SCHNEIBEL': 0,
    'SCHNEIBLE': 0,
    'SCHNEID': 0,
    'SCHNEIDER': 0,
    'SCHNEIDERHAN': 0,
    'SCHNEIDERMAN': 0,
    'SCHNEIDERS': 0,
    'SCHNEIDEWIND': 0,
    'SCHNEIDLER': 0,
    'SCHNEIDMAN': 0,
    'SCHNEIDMILLER': 0,
    'SCHNEIDT': 0,
    'SCHNEIER': 0,
    'SCHNEIR': 0,
    'SCHNEITER': 0,
    'SCHNELKER': 0,
    'SCHNELL': 0,
    'SCHNELLE': 0,
    'SCHNELLER': 0,
    'SCHNEPEL': 0,
    'SCHNEPF': 0,
    'SCHNEPP': 0,
    'SCHNEPPER': 0,
    'SCHNERING': 0,
    'SCHNERINGER': 0,
    'SCHNESE': 0,
    'SCHNETTER': 0,
    'SCHNETTGOECKE': 0,
    'SCHNETTLER': 0,
    'SCHNETZER': 0,
    'SCHNETZLER': 0,
    'SCHNEWEIS': 0,
    'SCHNEYER': 0,
    'SCHNICK': 0,
    'SCHNICKE': 0,
    'SCHNICKER': 0,
    'SCHNIDER': 0,
    'SCHNIDT': 0,
    'SCHNIEDER': 0,
    'SCHNIEDERS': 0,
    'SCHNIEPP': 0,
    'SCHNIER': 0,
    'SCHNIERS': 0,
    'SCHNIPKE': 0,
    'SCHNIPPER': 0,
    'SCHNITGER': 0,
    'SCHNITKER': 0,
    'SCHNITKEY': 0,
    'SCHNITTGER': 0,
    'SCHNITTKER': 0,
    'SCHNITZ': 0,
    'SCHNITZER': 0,
    'SCHNITZIUS': 0,
    'SCHNITZLER': 0,
    'SCHNOBRICH': 0,
    'SCHNOEBELEN': 0,
    'SCHNOES': 0,
    'SCHNOLL': 0,
    'SCHNOOR': 0,
    'SCHNOPP': 0,
    'SCHNORBUS': 0,
    'SCHNORENBERG': 0,
    'SCHNORF': 0,
    'SCHNORR': 0,
    'SCHNUCK': 0,
    'SCHNUELLE': 0,
    'SCHNUG': 0,
    'SCHNULLE': 0,
    'SCHNUPP': 0,
    'SCHNUR': 0,
    'SCHNURBUSCH': 0,
    'SCHNURE': 0,
    'SCHNURER': 0,
    'SCHNURR': 0,
    'SCHNURSTEIN': 0,
    'SCHNYDER': 0,
    'SCHNYER': 0,
    'SCHOAF': 0,
    'SCHOB': 0,
    'SCHOBEL': 0,
    'SCHOBER': 0,
    'SCHOBERG': 0,
    'SCHOBERT': 0,
    'SCHOBORG': 0,
    'SCHOBY': 0,
    'SCHOCH': 0,
    'SCHOCHET': 0,
    'SCHOCK': 0,
    'SCHOCKE': 0,
    'SCHOCKER': 0,
    'SCHODER': 0,
    'SCHODOWSKI': 0,
    'SCHOEB': 0,
    'SCHOEBEL': 0,
    'SCHOEBERL': 0,
    'SCHOEBERLEIN': 0,
    'SCHOECH': 0,
    'SCHOECK': 0,
    'SCHOEDEL': 0,
    'SCHOEDER': 0,
    'SCHOEFF': 0,
    'SCHOEFFEL': 0,
    'SCHOEFFLER': 0,
    'SCHOEL': 0,
    'SCHOELEN': 0,
    'SCHOELER': 0,
    'SCHOELKOPF': 0,
    'SCHOELL': 0,
    'SCHOELLER': 0,
    'SCHOELLES': 0,
    'SCHOELLKOPF': 0,
    'SCHOELLMAN': 0,
    'SCHOELZEL': 0,
    'SCHOEMAKER': 0,
    'SCHOEMAN': 0,
    'SCHOEMANN': 0,
    'SCHOEMEHL': 0,
    'SCHOEMER': 0,
    'SCHOEN': 0,
    'SCHOENAUER': 0,
    'SCHOENBACH': 0,
    'SCHOENBACHLER': 0,
    'SCHOENBAECHLER': 0,
    'SCHOENBAUER': 0,
    'SCHOENBAUM': 0,
    'SCHOENBECK': 0,
    'SCHOENBEIN': 0,
    'SCHOENBERG': 0,
    'SCHOENBERGER': 0,
    'SCHOENBORN': 0,
    'SCHOENBRUN': 0,
    'SCHOENDORF': 0,
    'SCHOENE': 0,
    'SCHOENEBERG': 0,
    'SCHOENEBERGER': 0,
    'SCHOENECK': 0,
    'SCHOENECKER': 0,
    'SCHOENEMAN': 0,
    'SCHOENEMANN': 0,
    'SCHOENEN': 0,
    'SCHOENENBERGER': 0,
    'SCHOENER': 0,
    'SCHOENEWALD': 0,
    'SCHOENEWEIS': 0,
    'SCHOENFELD': 0,
    'SCHOENFELDER': 0,
    'SCHOENFELDT': 0,
    'SCHOENFIELD': 0,
    'SCHOENGARTH': 0,
    'SCHOENHALS': 0,
    'SCHOENHARD': 0,
    'SCHOENHARDT': 0,
    'SCHOENHEIT': 0,
    'SCHOENHERR': 0,
    'SCHOENHOFEN': 0,
    'SCHOENHOFER': 0,
    'SCHOENHOFF': 0,
    'SCHOENHOLTZ': 0,
    'SCHOENHOLZ': 0,
    'SCHOENICK': 0,
    'SCHOENIG': 0,
    'SCHOENIKE': 0,
    'SCHOENING': 0,
    'SCHOENINGER': 0,
    'SCHOENKE': 0,
    'SCHOENKNECHT': 0,
    'SCHOENLE': 0,
    'SCHOENLEBER': 0,
    'SCHOENLEIN': 0,
    'SCHOENLY': 0,
    'SCHOENMAN': 0,
    'SCHOENMANN': 0,
    'SCHOENROCK': 0,
    'SCHOENSTEIN': 0,
    'SCHOENTHAL': 0,
    'SCHOENTHALER': 0,
    'SCHOENUNG': 0,
    'SCHOENWALD': 0,
    'SCHOENWETTER': 0,
    'SCHOENY': 0,
    'SCHOEP': 0,
    'SCHOEPF': 0,
    'SCHOEPFER': 0,
    'SCHOEPFLIN': 0,
    'SCHOEPHOERSTER': 0,
    'SCHOEPKE': 0,
    'SCHOEPP': 0,
    'SCHOEPPNER': 0,
    'SCHOER': 0,
    'SCHOERNER': 0,
    'SCHOESSLER': 0,
    'SCHOESSOW': 0,
    'SCHOETTLE': 0,
    'SCHOETTLER': 0,
    'SCHOETTLIN': 0,
    'SCHOETTMER': 0,
    'SCHOEWE': 0,
    'SCHOFER': 0,
    'SCHOFF': 0,
    'SCHOFFNER': 0,
    'SCHOFFSTALL': 0,
    'SCHOFIELD': 0,
    'SCHOFILL': 0,
    'SCHOGER': 0,
    'SCHOGGINS': 0,
    'SCHOHL': 0,
    'SCHOHN': 0,
    'SCHOL': 0,
    'SCHOLAR': 0,
    'SCHOLBROCK': 0,
    'SCHOLD': 0,
    'SCHOLDER': 0,
    'SCHOLEFIELD': 0,
    'SCHOLER': 0,
    'SCHOLES': 0,
    'SCHOLEY': 0,
    'SCHOLFIELD': 0,
    'SCHOLIN': 0,
    'SCHOLL': 0,
    'SCHOLLA': 0,
    'SCHOLLAERT': 0,
    'SCHOLLE': 0,
    'SCHOLLENBERGER': 0,
    'SCHOLLER': 0,
    'SCHOLLIAN': 0,
    'SCHOLLMEIER': 0,
    'SCHOLLMEYER': 0,
    'SCHOLLY': 0,
    'SCHOLNICK': 0,
    'SCHOLTE': 0,
    'SCHOLTEN': 0,
    'SCHOLTENS': 0,
    'SCHOLTES': 0,
    'SCHOLTING': 0,
    'SCHOLTZ': 0,
    'SCHOLZ': 0,
    'SCHOLZE': 0,
    'SCHOLZEN': 0,
    'SCHOMAKER': 0,
    'SCHOMBER': 0,
    'SCHOMBERG': 0,
    'SCHOMBURG': 0,
    'SCHOMER': 0,
    'SCHOMISCH': 0,
    'SCHOMMER': 0,
    'SCHOMP': 0,
    'SCHON': 0,
    'SCHONAUER': 0,
    'SCHONBERG': 0,
    'SCHONBERGER': 0,
    'SCHONBRUN': 0,
    'SCHONDER': 0,
    'SCHONE': 0,
    'SCHONEBAUM': 0,
    'SCHONECK': 0,
    'SCHONEFELD': 0,
    'SCHONEMAN': 0,
    'SCHONER': 0,
    'SCHONERT': 0,
    'SCHONES': 0,
    'SCHONEWOLF': 0,
    'SCHONFELD': 0,
    'SCHONHARDT': 0,
    'SCHONHOFF': 0,
    'SCHONING': 0,
    'SCHONROCK': 0,
    'SCHONS': 0,
    'SCHONSCHECK': 0,
    'SCHOO': 0,
    'SCHOOF': 0,
    'SCHOOFS': 0,
    'SCHOOK': 0,
    'SCHOOL': 0,
    'SCHOOLCRAFT': 0,
    'SCHOOLER': 0,
    'SCHOOLEY': 0,
    'SCHOOLFIELD': 0,
    'SCHOOLING': 0,
    'SCHOOLMAN': 0,
    'SCHOOLS': 0,
    'SCHOON': 0,
    'SCHOONE': 0,
    'SCHOONER': 0,
    'SCHOONHOVEN': 0,
    'SCHOONMAKER': 0,
    'SCHOONOVER': 0,
    'SCHOONVELD': 0,
    'SCHOOP': 0,
    'SCHOOR': 0,
    'SCHOOS': 0,
    'SCHOPEN': 0,
    'SCHOPF': 0,
    'SCHOPFER': 0,
    'SCHOPIERAY': 0,
    'SCHOPMEYER': 0,
    'SCHOPP': 0,
    'SCHOPPA': 0,
    'SCHOPPE': 0,
    'SCHOPPER': 0,
    'SCHOPPERT': 0,
    'SCHOPPMANN': 0,
    'SCHOR': 0,
    'SCHORE': 0,
    'SCHORER': 0,
    'SCHORI': 0,
    'SCHORK': 0,
    'SCHORLE': 0,
    'SCHORLING': 0,
    'SCHORN': 0,
    'SCHORNACK': 0,
    'SCHORNAK': 0,
    'SCHORNICK': 0,
    'SCHORNSTEIN': 0,
    'SCHORPP': 0,
    'SCHORR': 0,
    'SCHORSCH': 0,
    'SCHORTGEN': 0,
    'SCHORY': 0,
    'SCHORZMAN': 0,
    'SCHOSSOW': 0,
    'SCHOSTAG': 0,
    'SCHOTANUS': 0,
    'SCHOTT': 0,
    'SCHOTTE': 0,
    'SCHOTTEL': 0,
    'SCHOTTENFELD': 0,
    'SCHOTTENSTEIN': 0,
    'SCHOTTER': 0,
    'SCHOTTLER': 0,
    'SCHOTTMILLER': 0,
    'SCHOTTS': 0,
    'SCHOTZ': 0,
    'SCHOU': 0,
    'SCHOUEST': 0,
    'SCHOULTZ': 0,
    'SCHOUT': 0,
    'SCHOUTEN': 0,
    'SCHOUVILLER': 0,
    'SCHOUWEILER': 0,
    'SCHOVAJSA': 0,
    'SCHOVANEC': 0,
    'SCHOVILLE': 0,
    'SCHOW': 0,
    'SCHOWALTER': 0,
    'SCHOWE': 0,
    'SCHOWENGERDT': 0,
    'SCHRACK': 0,
    'SCHRAD': 0,
    'SCHRADE': 0,
    'SCHRADER': 0,
    'SCHRAEDER': 0,
    'SCHRAER': 0,
    'SCHRAFF': 0,
    'SCHRAFFENBERGER': 0,
    'SCHRAFT': 0,
    'SCHRAG': 0,
    'SCHRAGE': 0,
    'SCHRAGER': 0,
    'SCHRAM': 0,
    'SCHRAMEK': 0,
    'SCHRAMEL': 0,
    'SCHRAMER': 0,
    'SCHRAMKE': 0,
    'SCHRAML': 0,
    'SCHRAMM': 0,
    'SCHRAMMEL': 0,
    'SCHRAMSKI': 0,
    'SCHRAN': 0,
    'SCHRANCK': 0,
    'SCHRAND': 0,
    'SCHRANDT': 0,
    'SCHRANER': 0,
    'SCHRANK': 0,
    'SCHRANT': 0,
    'SCHRANTZ': 0,
    'SCHRANZ': 0,
    'SCHRATZ': 0,
    'SCHRAUB': 0,
    'SCHRAUBEN': 0,
    'SCHRAUFNAGEL': 0,
    'SCHRAUT': 0,
    'SCHRAUTH': 0,
    'SCHRAVEN': 0,
    'SCHRAW': 0,
    'SCHRAY': 0,
    'SCHREADER': 0,
    'SCHRECENGOST': 0,
    'SCHRECK': 0,
    'SCHRECKENGAST': 0,
    'SCHRECKENGOST': 0,
    'SCHRECKER': 0,
    'SCHRECONGOST': 0,
    'SCHREDER': 0,
    'SCHREFFLER': 0,
    'SCHREIB': 0,
    'SCHREIBEIS': 0,
    'SCHREIBER': 0,
    'SCHREIBMAN': 0,
    'SCHREIDER': 0,
    'SCHREIER': 0,
    'SCHREIFELS': 0,
    'SCHREIN': 0,
    'SCHREINER': 0,
    'SCHREITER': 0,
    'SCHREMMER': 0,
    'SCHREMP': 0,
    'SCHREMPF': 0,
    'SCHREMPP': 0,
    'SCHREMS': 0,
    'SCHREMSER': 0,
    'SCHRENK': 0,
    'SCHRENKER': 0,
    'SCHREPEL': 0,
    'SCHREPFER': 0,
    'SCHREPPEL': 0,
    'SCHREUDER': 0,
    'SCHREUR': 0,
    'SCHREURS': 0,
    'SCHREY': 0,
    'SCHREYER': 0,
    'SCHRIBER': 0,
    'SCHRICK': 0,
    'SCHRICKEL': 0,
    'SCHRICKER': 0,
    'SCHRIDER': 0,
    'SCHRIEBER': 0,
    'SCHRIEFER': 0,
    'SCHRIENER': 0,
    'SCHRIER': 0,
    'SCHRIEVER': 0,
    'SCHRIEWER': 0,
    'SCHRIFT': 0,
    'SCHRIMP': 0,
    'SCHRIMPF': 0,
    'SCHRIMPSHER': 0,
    'SCHRIMSHER': 0,
    'SCHRINER': 0,
    'SCHRIPSEMA': 0,
    'SCHRITTER': 0,
    'SCHRIVER': 0,
    'SCHROADER': 0,
    'SCHROCK': 0,
    'SCHRODE': 0,
    'SCHRODER': 0,
    'SCHRODT': 0,
    'SCHROECK': 0,
    'SCHROEDEL': 0,
    'SCHROEDER': 0,
    'SCHROEDL': 0,
    'SCHROEDTER': 0,
    'SCHROEN': 0,
    'SCHROEPFER': 0,
    'SCHROEPPEL': 0,
    'SCHROER': 0,
    'SCHROERING': 0,
    'SCHROERLUCKE': 0,
    'SCHROERS': 0,
    'SCHROETER': 0,
    'SCHROETLIN': 0,
    'SCHROETTER': 0,
    'SCHROFF': 0,
    'SCHROLL': 0,
    'SCHROLLER': 0,
    'SCHROM': 0,
    'SCHRON': 0,
    'SCHRONCE': 0,
    'SCHROPE': 0,
    'SCHROPP': 0,
    'SCHROT': 0,
    'SCHROTBERGER': 0,
    'SCHROTENBOER': 0,
    'SCHROTER': 0,
    'SCHROTH': 0,
    'SCHROTT': 0,
    'SCHROY': 0,
    'SCHROYER': 0,
    'SCHRUBBE': 0,
    'SCHRUEFER': 0,
    'SCHRULL': 0,
    'SCHRUM': 0,
    'SCHRUMP': 0,
    'SCHRUMPF': 0,
    'SCHRUNK': 0,
    'SCHRUPP': 0,
    'SCHRYER': 0,
    'SCHRYVER': 0,
    'SCHU': 0,
    'SCHUB': 0,
    'SCHUBACH': 0,
    'SCHUBART': 0,
    'SCHUBARTH': 0,
    'SCHUBAUER': 0,
    'SCHUBBE': 0,
    'SCHUBE': 0,
    'SCHUBEL': 0,
    'SCHUBER': 0,
    'SCHUBERG': 0,
    'SCHUBERT': 0,
    'SCHUBERTH': 0,
    'SCHUBLE': 0,
    'SCHUBMEHL': 0,
    'SCHUBRING': 0,
    'SCHUCH': 0,
    'SCHUCHARD': 0,
    'SCHUCHARDT': 0,
    'SCHUCHART': 0,
    'SCHUCHERT': 0,
    'SCHUCHMAN': 0,
    'SCHUCHMANN': 0,
    'SCHUCK': 0,
    'SCHUCKER': 0,
    'SCHUCKERS': 0,
    'SCHUCKERT': 0,
    'SCHUCKMAN': 0,
    'SCHUDA': 0,
    'SCHUDEL': 0,
    'SCHUDER': 0,
    'SCHUDY': 0,
    'SCHUE': 0,
    'SCHUEBEL': 0,
    'SCHUELE': 0,
    'SCHUELER': 0,
    'SCHUELKE': 0,
    'SCHUELLER': 0,
    'SCHUEMAN': 0,
    'SCHUEMANN': 0,
    'SCHUENEMAN': 0,
    'SCHUENEMANN': 0,
    'SCHUENEMEYER': 0,
    'SCHUENKE': 0,
    'SCHUEPBACH': 0,
    'SCHUEREN': 0,
    'SCHUERER': 0,
    'SCHUERGER': 0,
    'SCHUERING': 0,
    'SCHUERMAN': 0,
    'SCHUERMANN': 0,
    'SCHUESSIER': 0,
    'SCHUESSLER': 0,
    'SCHUETH': 0,
    'SCHUETT': 0,
    'SCHUETTE': 0,
    'SCHUETTER': 0,
    'SCHUETTLER': 0,
    'SCHUETTPELZ': 0,
    'SCHUETZ': 0,
    'SCHUETZE': 0,
    'SCHUETZLE': 0,
    'SCHUFF': 0,
    'SCHUFFERT': 0,
    'SCHUFT': 0,
    'SCHUG': 0,
    'SCHUGEL': 0,
    'SCHUH': 0,
    'SCHUHARDT': 0,
    'SCHUHART': 0,
    'SCHUHMACHER': 0,
    'SCHUHMANN': 0,
    'SCHUILING': 0,
    'SCHUIT': 0,
    'SCHUITEMA': 0,
    'SCHUITEMAN': 0,
    'SCHUK': 0,
    'SCHUKAR': 0,
    'SCHUKEI': 0,
    'SCHUKNECHT': 0,
    'SCHUKRAFT': 0,
    'SCHUL': 0,
    'SCHULBERG': 0,
    'SCHULD': 0,
    'SCHULDES': 0,
    'SCHULDT': 0,
    'SCHULE': 0,
    'SCHULEIN': 0,
    'SCHULENBERG': 0,
    'SCHULENBURG': 0,
    'SCHULER': 0,
    'SCHULGEN': 0,
    'SCHULHOF': 0,
    'SCHULHOFF': 0,
    'SCHULIEN': 0,
    'SCHULIST': 0,
    'SCHULKE': 0,
    'SCHULKEN': 0,
    'SCHULKERS': 0,
    'SCHULL': 0,
    'SCHULLE': 0,
    'SCHULLER': 0,
    'SCHULLO': 0,
    'SCHULMAN': 0,
    'SCHULMEISTER': 0,
    'SCHULSTAD': 0,
    'SCHULT': 0,
    'SCHULTE': 0,
    'SCHULTEIS': 0,
    'SCHULTEN': 0,
    'SCHULTER': 0,
    'SCHULTES': 0,
    'SCHULTHEIS': 0,
    'SCHULTHEISS': 0,
    'SCHULTHESS': 0,
    'SCHULTHIES': 0,
    'SCHULTIES': 0,
    'SCHULTIS': 0,
    'SCHULTS': 0,
    'SCHULTZ': 0,
    'SCHULTZE': 0,
    'SCHULZ': 0,
    'SCHULZE': 0,
    'SCHULZETENBERG': 0,
    'SCHUM': 0,
    'SCHUMACHER': 0,
    'SCHUMACK': 0,
    'SCHUMACKER': 0,
    'SCHUMAKER': 0,
    'SCHUMAN': 0,
    'SCHUMANN': 0,
    'SCHUMER': 0,
    'SCHUMM': 0,
    'SCHUMMER': 0,
    'SCHUMP': 0,
    'SCHUMPERT': 0,
    'SCHUNCK': 0,
    'SCHUNEMAN': 0,
    'SCHUNEMANN': 0,
    'SCHUNK': 0,
    'SCHUNKE': 0,
    'SCHUNN': 0,
    'SCHUON': 0,
    'SCHUPAK': 0,
    'SCHUPBACH': 0,
    'SCHUPP': 0,
    'SCHUPPAN': 0,
    'SCHUPPE': 0,
    'SCHUPPEL': 0,
    'SCHUPPERT': 0,
    'SCHUR': 0,
    'SCHURCH': 0,
    'SCHURE': 0,
    'SCHUREMAN': 0,
    'SCHURER': 0,
    'SCHURG': 0,
    'SCHURICHT': 0,
    'SCHURIG': 0,
    'SCHURING': 0,
    'SCHURK': 0,
    'SCHURKE': 0,
    'SCHURLE': 0,
    'SCHURMAN': 0,
    'SCHURMANN': 0,
    'SCHURR': 0,
    'SCHURTER': 0,
    'SCHURTZ': 0,
    'SCHURZ': 0,
    'SCHUSLER': 0,
    'SCHUSS': 0,
    'SCHUSSLER': 0,
    'SCHUSSMAN': 0,
    'SCHUSTER': 0,
    'SCHUSTERMAN': 0,
    'SCHUT': 0,
    'SCHUTE': 0,
    'SCHUTH': 0,
    'SCHUTJER': 0,
    'SCHUTT': 0,
    'SCHUTTA': 0,
    'SCHUTTE': 0,
    'SCHUTTEN': 0,
    'SCHUTTER': 0,
    'SCHUTTLER': 0,
    'SCHUTTS': 0,
    'SCHUTZ': 0,
    'SCHUTZA': 0,
    'SCHUTZE': 0,
    'SCHUTZENHOFER': 0,
    'SCHUTZER': 0,
    'SCHUTZIUS': 0,
    'SCHUTZLER': 0,
    'SCHUTZMAN': 0,
    'SCHUUR': 0,
    'SCHUURMAN': 0,
    'SCHUURMANS': 0,
    'SCHUVER': 0,
    'SCHUYLER': 0,
    'SCHVANEVELDT': 0,
    'SCHWAAB': 0,
    'SCHWAB': 0,
    'SCHWABAUER': 0,
    'SCHWABE': 0,
    'SCHWABENBAUER': 0,
    'SCHWABENLAND': 0,
    'SCHWABER': 0,
    'SCHWACH': 0,
    'SCHWADE': 0,
    'SCHWADER': 0,
    'SCHWADERER': 0,
    'SCHWADRON': 0,
    'SCHWAGEL': 0,
    'SCHWAGER': 0,
    'SCHWAGERL': 0,
    'SCHWAHN': 0,
    'SCHWAIGER': 0,
    'SCHWAKE': 0,
    'SCHWALB': 0,
    'SCHWALBACH': 0,
    'SCHWALBE': 0,
    'SCHWALEN': 0,
    'SCHWALENBERG': 0,
    'SCHWALL': 0,
    'SCHWALLER': 0,
    'SCHWALLIE': 0,
    'SCHWALLIER': 0,
    'SCHWALM': 0,
    'SCHWAM': 0,
    'SCHWAMB': 0,
    'SCHWAMBERGER': 0,
    'SCHWAN': 0,
    'SCHWANBECK': 0,
    'SCHWANDER': 0,
    'SCHWANDNER': 0,
    'SCHWANDT': 0,
    'SCHWANE': 0,
    'SCHWANEBECK': 0,
    'SCHWANER': 0,
    'SCHWANGER': 0,
    'SCHWANINGER': 0,
    'SCHWANITZ': 0,
    'SCHWANK': 0,
    'SCHWANKE': 0,
    'SCHWANKL': 0,
    'SCHWANTES': 0,
    'SCHWANTNER': 0,
    'SCHWANTZ': 0,
    'SCHWANZ': 0,
    'SCHWAPPACH': 0,
    'SCHWAR': 0,
    'SCHWARBER': 0,
    'SCHWARBERG': 0,
    'SCHWARCK': 0,
    'SCHWARCZ': 0,
    'SCHWARK': 0,
    'SCHWARM': 0,
    'SCHWART': 0,
    'SCHWARTE': 0,
    'SCHWARTEN': 0,
    'SCHWARTING': 0,
    'SCHWARTZ': 0,
    'SCHWARTZBAUER': 0,
    'SCHWARTZBECK': 0,
    'SCHWARTZBERG': 0,
    'SCHWARTZE': 0,
    'SCHWARTZENBERGE': 0,
    'SCHWARTZENBURG': 0,
    'SCHWARTZER': 0,
    'SCHWARTZHOFF': 0,
    'SCHWARTZKOPF': 0,
    'SCHWARTZLOW': 0,
    'SCHWARTZMAN': 0,
    'SCHWARTZMILLER': 0,
    'SCHWARTZWALD': 0,
    'SCHWARZ': 0,
    'SCHWARZBACH': 0,
    'SCHWARZBAUER': 0,
    'SCHWARZBERG': 0,
    'SCHWARZE': 0,
    'SCHWARZENBACH': 0,
    'SCHWARZENBERG': 0,
    'SCHWARZENBERGER': 0,
    'SCHWARZER': 0,
    'SCHWARZKOPF': 0,
    'SCHWARZLOSE': 0,
    'SCHWARZMAN': 0,
    'SCHWARZMANN': 0,
    'SCHWARZROCK': 0,
    'SCHWARZTRAUBER': 0,
    'SCHWARZWALDER': 0,
    'SCHWASS': 0,
    'SCHWATKA': 0,
    'SCHWAUSCH': 0,
    'SCHWEBACH': 0,
    'SCHWEBEL': 0,
    'SCHWEBER': 0,
    'SCHWEBKE': 0,
    'SCHWEBS': 0,
    'SCHWECKE': 0,
    'SCHWED': 0,
    'SCHWEDA': 0,
    'SCHWEDE': 0,
    'SCHWEDER': 0,
    'SCHWEDLER': 0,
    'SCHWEER': 0,
    'SCHWEERS': 0,
    'SCHWEFEL': 0,
    'SCHWEGEL': 0,
    'SCHWEGLER': 0,
    'SCHWEGMAN': 0,
    'SCHWEGMANN': 0,
    'SCHWEHM': 0,
    'SCHWEHR': 0,
    'SCHWEI': 0,
    'SCHWEIBINZ': 0,
    'SCHWEICH': 0,
    'SCHWEICKART': 0,
    'SCHWEICKERT': 0,
    'SCHWEICKHARDT': 0,
    'SCHWEID': 0,
    'SCHWEIG': 0,
    'SCHWEIGART': 0,
    'SCHWEIGEL': 0,
    'SCHWEIGER': 0,
    'SCHWEIGERT': 0,
    'SCHWEIGHARDT': 0,
    'SCHWEIGHART': 0,
    'SCHWEIHOFER': 0,
    'SCHWEIHS': 0,
    'SCHWEIKART': 0,
    'SCHWEIKER': 0,
    'SCHWEIKERT': 0,
    'SCHWEIM': 0,
    'SCHWEIN': 0,
    'SCHWEINBERG': 0,
    'SCHWEINER': 0,
    'SCHWEINFURTH': 0,
    'SCHWEINHART': 0,
    'SCHWEINSBERG': 0,
    'SCHWEISS': 0,
    'SCHWEISTHAL': 0,
    'SCHWEITZ': 0,
    'SCHWEITZER': 0,
    'SCHWEIZER': 0,
    'SCHWELLENBACH': 0,
    'SCHWELLER': 0,
    'SCHWEMER': 0,
    'SCHWEMIN': 0,
    'SCHWEMMER': 0,
    'SCHWEN': 0,
    'SCHWENCK': 0,
    'SCHWEND': 0,
    'SCHWENDEMAN': 0,
    'SCHWENDEMANN': 0,
    'SCHWENDER': 0,
    'SCHWENDIMAN': 0,
    'SCHWENDINGER': 0,
    'SCHWENGEL': 0,
    'SCHWENGER': 0,
    'SCHWENGLER': 0,
    'SCHWENINGER': 0,
    'SCHWENK': 0,
    'SCHWENKE': 0,
    'SCHWENKER': 0,
    'SCHWENN': 0,
    'SCHWENNEKER': 0,
    'SCHWENSEN': 0,
    'SCHWENT': 0,
    'SCHWENTKER': 0,
    'SCHWENZER': 0,
    'SCHWEPPE': 0,
    'SCHWER': 0,
    'SCHWERDT': 0,
    'SCHWERDTFEGER': 0,
    'SCHWERER': 0,
    'SCHWERIN': 0,
    'SCHWERING': 0,
    'SCHWERMAN': 0,
    'SCHWERS': 0,
    'SCHWERT': 0,
    'SCHWERTFEGER': 0,
    'SCHWERTNER': 0,
    'SCHWERTZ': 0,
    'SCHWERY': 0,
    'SCHWERZLER': 0,
    'SCHWETER': 0,
    'SCHWETTMAN': 0,
    'SCHWETTMANN': 0,
    'SCHWETZ': 0,
    'SCHWEYER': 0,
    'SCHWICHTENBERG': 0,
    'SCHWICKERATH': 0,
    'SCHWICKRATH': 0,
    'SCHWIEBERT': 0,
    'SCHWIEDER': 0,
    'SCHWIEGER': 0,
    'SCHWIEN': 0,
    'SCHWIER': 0,
    'SCHWIESOW': 0,
    'SCHWIETERMAN': 0,
    'SCHWIETERS': 0,
    'SCHWIETERT': 0,
    'SCHWIETZ': 0,
    'SCHWILK': 0,
    'SCHWIMER': 0,
    'SCHWIMMER': 0,
    'SCHWIN': 0,
    'SCHWIND': 0,
    'SCHWINDEL': 0,
    'SCHWINDENHAMMER': 0,
    'SCHWINDT': 0,
    'SCHWING': 0,
    'SCHWINGEL': 0,
    'SCHWINGER': 0,
    'SCHWINGHAMER': 0,
    'SCHWINGHAMMER': 0,
    'SCHWINGLE': 0,
    'SCHWINN': 0,
    'SCHWINT': 0,
    'SCHWIRIAN': 0,
    'SCHWIRTZ': 0,
    'SCHWISOW': 0,
    'SCHWISTER': 0,
    'SCHWITTERS': 0,
    'SCHWITZ': 0,
    'SCHWITZER': 0,
    'SCHWOB': 0,
    'SCHWOCH': 0,
    'SCHWOCHERT': 0,
    'SCHWOCHOW': 0,
    'SCHWOEBEL': 0,
    'SCHWOEGLER': 0,
    'SCHWOEPPE': 0,
    'SCHWOERER': 0,
    'SCHWOPE': 0,
    'SCHWORER': 0,
    'SCHWORM': 0,
    'SCHWOYER': 0,
    'SCHWUCHOW': 0,
    'SCHWULST': 0,
    'SCHWYHART': 0,
    'SCHWYN': 0,
    'SCHY': 0,
    'SCIABARRASI': 0,
    'SCIABICA': 0,
    'SCIACCA': 0,
    'SCIACCHITANO': 0,
    'SCIALABBA': 0,
    'SCIALDONE': 0,
    'SCIALLA': 0,
    'SCIALLO': 0,
    'SCIALO': 0,
    'SCIALPI': 0,
    'SCIAMANNA': 0,
    'SCIAME': 0,
    'SCIANCALEPORE': 0,
    'SCIANDRA': 0,
    'SCIANNA': 0,
    'SCIANNI': 0,
    'SCIANO': 0,
    'SCIARA': 0,
    'SCIARABBA': 0,
    'SCIARAFFA': 0,
    'SCIARAPPA': 0,
    'SCIARINI': 0,
    'SCIARONI': 0,
    'SCIARRA': 0,
    'SCIARRATTA': 0,
    'SCIARRETTA': 0,
    'SCIARRILLO': 0,
    'SCIARRINO': 0,
    'SCIARRONE': 0,
    'SCIARROTTA': 0,
    'SCIASCIA': 0,
    'SCIBA': 0,
    'SCIBEK': 0,
    'SCIBELLI': 0,
    'SCIBERRAS': 0,
    'SCIBETTA': 0,
    'SCIBILIA': 0,
    'SCIBONA': 0,
    'SCICCHITANO': 0,
    'SCICHILONE': 0,
    'SCICLUNA': 0,
    'SCICUTELLA': 0,
    'SCIDMORE': 0,
    'SCIESZINSKI': 0,
    'SCIESZKA': 0,
    'SCIFO': 0,
    'SCIFRES': 0,
    'SCIGLIANO': 0,
    'SCILEPPI': 0,
    'SCILINGO': 0,
    'SCILLA': 0,
    'SCILLIA': 0,
    'SCILLIERI': 0,
    'SCIME': 0,
    'SCIMECA': 0,
    'SCIMEMI': 0,
    'SCIMONE': 0,
    'SCINTA': 0,
    'SCINTO': 0,
    'SCIOCCHETTI': 0,
    'SCIOLA': 0,
    'SCIOLI': 0,
    'SCIOLINO': 0,
    'SCIONEAUX': 0,
    'SCIONTI': 0,
    'SCIORE': 0,
    'SCIORTINO': 0,
    'SCIOSCIA': 0,
    'SCIOTTI': 0,
    'SCIOTTO': 0,
    'SCIPIO': 0,
    'SCIPIONE': 0,
    'SCIPIONI': 0,
    'SCIPLE': 0,
    'SCIPPIO': 0,
    'SCIRE': 0,
    'SCIRICA': 0,
    'SCIROCCO': 0,
    'SCIRROTTO': 0,
    'SCISCOE': 0,
    'SCISLOWICZ': 0,
    'SCISM': 0,
    'SCISNEY': 0,
    'SCISSOM': 0,
    'SCISSONS': 0,
    'SCITES': 0,
    'SCIUBBA': 0,
    'SCIULLI': 0,
    'SCIULLO': 0,
    'SCIURBA': 0,
    'SCIUTO': 0,
    'SCIUTTO': 0,
    'SCIVALLY': 0,
    'SCLAFANI': 0,
    'SCLAR': 0,
    'SCLATER': 0,
    'SCMIDT': 0,
    'SCOBEE': 0,
    'SCOBELL': 0,
    'SCOBEY': 0,
    'SCOBIE': 0,
    'SCOBLE': 0,
    'SCOBY': 0,
    'SCOCA': 0,
    'SCOCCA': 0,
    'SCOCCO': 0,
    'SCOCOZZA': 0,
    'SCOFFIELD': 0,
    'SCOFIELD': 0,
    'SCOGGAN': 0,
    'SCOGGIN': 0,
    'SCOGGINS': 0,
    'SCOGIN': 0,
    'SCOGINS': 0,
    'SCOGLIO': 0,
    'SCOGNA': 0,
    'SCOGNAMIGLIO': 0,
    'SCOGNAMILLO': 0,
    'SCOLA': 0,
    'SCOLARD': 0,
    'SCOLARI': 0,
    'SCOLARO': 0,
    'SCOLERI': 0,
    'SCOLES': 0,
    'SCOLIERI': 0,
    'SCOLLAN': 0,
    'SCOLLARD': 0,
    'SCOLLIN': 0,
    'SCOLLO': 0,
    'SCOLLON': 0,
    'SCOLNICK': 0,
    'SCOMA': 0,
    'SCONCE': 0,
    'SCONIERS': 0,
    'SCONYERS': 0,
    'SCONZO': 0,
    'SCOON': 0,
    'SCOPA': 0,
    'SCOPE': 0,
    'SCOPEL': 0,
    'SCOPELLITI': 0,
    'SCOPINO': 0,
    'SCOPPA': 0,
    'SCORCIA': 0,
    'SCORDATO': 0,
    'SCORDINO': 0,
    'SCORDO': 0,
    'SCORE': 0,
    'SCORESBY': 0,
    'SCORPIO': 0,
    'SCORSE': 0,
    'SCORSONE': 0,
    'SCORZA': 0,
    'SCORZELLI': 0,
    'SCOT': 1,
    'SCOTCH': 0,
    'SCOTESE': 0,
    'SCOTHERN': 0,
    'SCOTHORN': 0,
    'SCOTLAND': 0,
    'SCOTT': 0.7787077430264447,
    'SCOTTEN': 0,
    'SCOTTI': 0,
    'SCOTTIE': 1,
    'SCOTTO': 0,
    'SCOTTON': 0,
    'SCOTTY': 1,
    'SCOULAR': 0,
    'SCOURAS': 0,
    'SCOUT': 0,
    'SCOUTEN': 0,
    'SCOVEL': 0,
    'SCOVELL': 0,
    'SCOVERN': 0,
    'SCOVIL': 0,
    'SCOVILL': 0,
    'SCOVILLE': 0,
    'SCOW': 0,
    'SCOWCROFT': 0,
    'SCOWDEN': 0,
    'SCOWN': 0,
    'SCOZZAFAVA': 0,
    'SCOZZARI': 0,
    'SCOZZARO': 0,
    'SCRABECK': 0,
    'SCRAFFORD': 0,
    'SCRAGG': 0,
    'SCRAGGS': 0,
    'SCRAM': 0,
    'SCRAMLIN': 0,
    'SCRANTON': 0,
    'SCRAPE': 0,
    'SCRAPER': 0,
    'SCRAY': 0,
    'SCREEN': 0,
    'SCREETON': 0,
    'SCRENCI': 0,
    'SCREVEN': 0,
    'SCREWS': 0,
    'SCRIBA': 0,
    'SCRIBER': 0,
    'SCRIBNER': 0,
    'SCRIMA': 0,
    'SCRIMENTI': 0,
    'SCRIMGEOUR': 0,
    'SCRIMGER': 0,
    'SCRIMPSHER': 0,
    'SCRIMSHAW': 0,
    'SCRIMSHER': 0,
    'SCRIMSHIRE': 0,
    'SCRIP': 0,
    'SCRIPP': 0,
    'SCRIPPS': 0,
    'SCRIPTER': 0,
    'SCRIPTURE': 0,
    'SCRITCHFIELD': 0,
    'SCRIVANI': 0,
    'SCRIVANICH': 0,
    'SCRIVANO': 0,
    'SCRIVEN': 0,
    'SCRIVENER': 0,
    'SCRIVENS': 0,
    'SCRIVER': 0,
    'SCRIVNER': 0,
    'SCRIVO': 0,
    'SCRO': 0,
    'SCROFANI': 0,
    'SCROGER': 0,
    'SCROGGIE': 0,
    'SCROGGIN': 0,
    'SCROGGINS': 0,
    'SCROGGS': 0,
    'SCROGGY': 0,
    'SCROGHAM': 0,
    'SCROGIN': 0,
    'SCROGUM': 0,
    'SCRONCE': 0,
    'SCRUBB': 0,
    'SCRUBY': 0,
    'SCRUDATO': 0,
    'SCRUGGS': 0,
    'SCRUTCHINS': 0,
    'SCRUTON': 0,
    'SCUDDER': 0,
    'SCUDERI': 0,
    'SCUDERO': 0,
    'SCUDIERI': 0,
    'SCUDIERO': 0,
    'SCULL': 0,
    'SCULLARK': 0,
    'SCULLEN': 0,
    'SCULLEY': 0,
    'SCULLIN': 0,
    'SCULLION': 0,
    'SCULLY': 0,
    'SCULTHORPE': 0,
    'SCUMACI': 0,
    'SCUNGIO': 0,
    'SCURA': 0,
    'SCURLARK': 0,
    'SCURLOCK': 0,
    'SCURRIA': 0,
    'SCURRY': 0,
    'SCURTI': 0,
    'SCURTO': 0,
    'SCUSSEL': 0,
    'SCUTARI': 0,
    'SCUTCHFIELD': 0,
    'SCUTELLA': 0,
    'SCUTERI': 0,
    'SCUTT': 0,
    'SCUTTI': 0,
    'SCWARTZ': 0,
    'SCYOC': 0,
    'SCYPHERS': 0,
    'SCZEPANSKI': 0,
    'SCZESNY': 0,
    'SDAO': 0,
    'SE': 0,
    'SEA': 0,
    'SEABA': 0,
    'SEABAUGH': 0,
    'SEABECK': 0,
    'SEABERG': 0,
    'SEABERRY': 0,
    'SEABERT': 0,
    'SEABLOM': 0,
    'SEABLOOM': 0,
    'SEABOLD': 0,
    'SEABOLDT': 0,
    'SEABOLT': 0,
    'SEABORG': 0,
    'SEABORN': 0,
    'SEABORNE': 0,
    'SEABOURN': 0,
    'SEABOURNE': 0,
    'SEABRA': 0,
    'SEABREASE': 0,
    'SEABRIDGE': 0,
    'SEABRIGHT': 0,
    'SEABRON': 0,
    'SEABROOK': 0,
    'SEABROOKE': 0,
    'SEABROOKS': 0,
    'SEABURG': 0,
    'SEABURN': 0,
    'SEABURY': 0,
    'SEACAT': 0,
    'SEACE': 0,
    'SEACH': 0,
    'SEACHRIS': 0,
    'SEACHRIST': 0,
    'SEACORD': 0,
    'SEACREST': 0,
    'SEACRIST': 0,
    'SEADER': 0,
    'SEADLER': 0,
    'SEADORF': 0,
    'SEAFORD': 0,
    'SEAGER': 0,
    'SEAGERS': 0,
    'SEAGLE': 0,
    'SEAGO': 0,
    'SEAGRAVE': 0,
    'SEAGRAVES': 0,
    'SEAGREAVES': 0,
    'SEAGREN': 0,
    'SEAGROVES': 0,
    'SEAH': 0,
    'SEAHOLM': 0,
    'SEAHORN': 0,
    'SEAL': 0,
    'SEALANDER': 0,
    'SEALE': 0,
    'SEALES': 0,
    'SEALEY': 0,
    'SEALOCK': 0,
    'SEALOVER': 0,
    'SEALS': 0,
    'SEALUND': 0,
    'SEALY': 0,
    'SEAM': 0,
    'SEAMAN': 0,
    'SEAMANDS': 0,
    'SEAMANN': 0,
    'SEAMANS': 0,
    'SEAMEN': 0,
    'SEAMES': 0,
    'SEAMON': 0,
    'SEAMONS': 0,
    'SEAMS': 0,
    'SEAMSTER': 0,
    'SEAN': 0.9986951721369065,
    'SEANEY': 0,
    'SEANEZ': 0,
    'SEANG': 0,
    'SEANOR': 0,
    'SEAQUIST': 0,
    'SEAR': 0,
    'SEARA': 0,
    'SEARBY': 0,
    'SEARCEY': 0,
    'SEARCH': 0,
    'SEARCY': 0,
    'SEARE': 0,
    'SEARER': 0,
    'SEARFOSS': 0,
    'SEARGEANT': 0,
    'SEARGENT': 0,
    'SEARIGHT': 0,
    'SEARING': 0,
    'SEARL': 0,
    'SEARLE': 0,
    'SEARLES': 0,
    'SEARLS': 0,
    'SEARS': 0,
    'SEARSON': 0,
    'SEARY': 0,
    'SEAS': 0,
    'SEASE': 0,
    'SEASHOLTZ': 0,
    'SEASHORE': 0,
    'SEASOCK': 0,
    'SEASON': 1,
    'SEASTRAND': 0,
    'SEASTROM': 0,
    'SEASTRUNK': 0,
    'SEAT': 0,
    'SEATE': 0,
    'SEATER': 0,
    'SEATH': 0,
    'SEATON': 0,
    'SEATS': 0,
    'SEAUX': 0,
    'SEAVER': 0,
    'SEAVERS': 0,
    'SEAVERT': 0,
    'SEAVEY': 0,
    'SEAVY': 0,
    'SEAWARD': 0,
    'SEAWELL': 0,
    'SEAWOOD': 0,
    'SEAWRIGHT': 0,
    'SEAY': 0,
    'SEBA': 0,
    'SEBADE': 0,
    'SEBAG': 0,
    'SEBALD': 0,
    'SEBALLOS': 0,
    'SEBASTIAN': 0.7127583749109052,
    'SEBASTIANELLI': 0,
    'SEBASTIANI': 0,
    'SEBASTIANO': 0,
    'SEBASTIAO': 0,
    'SEBASTIEN': 0,
    'SEBASTION': 0,
    'SEBAUGH': 0,
    'SEBBEN': 0,
    'SEBBY': 0,
    'SEBECK': 0,
    'SEBEK': 0,
    'SEBELIUS': 0,
    'SEBENS': 0,
    'SEBER': 0,
    'SEBERA': 0,
    'SEBERG': 0,
    'SEBERGER': 0,
    'SEBERN': 0,
    'SEBERT': 0,
    'SEBES': 0,
    'SEBESTA': 0,
    'SEBESTYEN': 0,
    'SEBETKA': 0,
    'SEBHATU': 0,
    'SEBION': 0,
    'SEBO': 0,
    'SEBOK': 0,
    'SEBOLD': 0,
    'SEBOLT': 0,
    'SEBOR': 0,
    'SEBOURN': 0,
    'SEBRA': 0,
    'SEBRANEK': 0,
    'SEBREE': 0,
    'SEBRELL': 0,
    'SEBREN': 0,
    'SEBRIGHT': 0,
    'SEBRINA': 1,
    'SEBRING': 0,
    'SEBRO': 0,
    'SEBULSKY': 0,
    'SEBURN': 0,
    'SECADA': 0,
    'SECAIDA': 0,
    'SECATERO': 0,
    'SECAUR': 0,
    'SECCIA': 0,
    'SECCO': 0,
    'SECCOMBE': 0,
    'SECH': 0,
    'SECHELSKI': 0,
    'SECHER': 0,
    'SECHLER': 0,
    'SECHMAN': 0,
    'SECHREST': 0,
    'SECHRIST': 0,
    'SECHSER': 0,
    'SECIC': 0,
    'SECK': 0,
    'SECKA': 0,
    'SECKAR': 0,
    'SECKEL': 0,
    'SECKER': 0,
    'SECKINGER': 0,
    'SECKLER': 0,
    'SECKMAN': 0,
    'SECO': 0,
    'SECODY': 0,
    'SECOLA': 0,
    'SECOND': 0,
    'SECONDI': 0,
    'SECONDINO': 0,
    'SECONDO': 0,
    'SECOR': 0,
    'SECORA': 0,
    'SECORD': 0,
    'SECORE': 0,
    'SECOSKY': 0,
    'SECOY': 0,
    'SECREASE': 0,
    'SECREST': 0,
    'SECRET': 0,
    'SECRETO': 0,
    'SECRIST': 0,
    'SECULA': 0,
    'SECULES': 0,
    'SECUNDA': 0,
    'SECUNDINO': 0,
    'SED': 0,
    'SEDA': 0,
    'SEDACCA': 0,
    'SEDAGHAT': 0,
    'SEDAM': 0,
    'SEDAN': 0,
    'SEDAND': 0,
    'SEDANO': 0,
    'SEDAR': 0,
    'SEDBERRY': 0,
    'SEDBROOK': 0,
    'SEDDON': 0,
    'SEDELL': 0,
    'SEDENO': 0,
    'SEDER': 0,
    'SEDERBERG': 0,
    'SEDERBURG': 0,
    'SEDERHOLM': 0,
    'SEDERQUIST': 0,
    'SEDERSTROM': 0,
    'SEDEY': 0,
    'SEDGEMAN': 0,
    'SEDGEWICK': 0,
    'SEDGHI': 0,
    'SEDGLEY': 0,
    'SEDGWICK': 0,
    'SEDIG': 0,
    'SEDILLO': 0,
    'SEDILLOS': 0,
    'SEDITA': 0,
    'SEDIVEC': 0,
    'SEDIVY': 0,
    'SEDLACEK': 0,
    'SEDLACK': 0,
    'SEDLACKO': 0,
    'SEDLAK': 0,
    'SEDLAR': 0,
    'SEDLER': 0,
    'SEDLMAYR': 0,
    'SEDLOCK': 0,
    'SEDMAK': 0,
    'SEDMAN': 0,
    'SEDO': 0,
    'SEDON': 0,
    'SEDOR': 0,
    'SEDORE': 0,
    'SEDORIS': 0,
    'SEDRICK': 0,
    'SEDWICK': 0,
    'SEE': 0.24271844660194178,
    'SEEBA': 0,
    'SEEBACH': 0,
    'SEEBACHER': 0,
    'SEEBACK': 0,
    'SEEBECK': 0,
    'SEEBER': 0,
    'SEEBERG': 0,
    'SEEBERGER': 0,
    'SEEBODE': 0,
    'SEEBOLD': 0,
    'SEEBURGER': 0,
    'SEECH': 0,
    'SEECHAN': 0,
    'SEECHARAN': 0,
    'SEECHARRAN': 0,
    'SEED': 0,
    'SEEDEN': 0,
    'SEEDERS': 0,
    'SEEDORF': 0,
    'SEEDORFF': 0,
    'SEEDS': 0,
    'SEEFELD': 0,
    'SEEFELDT': 0,
    'SEEFRIED': 0,
    'SEEGAR': 0,
    'SEEGARS': 0,
    'SEEGER': 0,
    'SEEGERS': 0,
    'SEEGERT': 0,
    'SEEGMILLER': 0,
    'SEEGOBIN': 0,
    'SEEGRAVES': 0,
    'SEEHAFER': 0,
    'SEEHASE': 0,
    'SEEHAUSEN': 0,
    'SEEHAVER': 0,
    'SEEHOLZER': 0,
    'SEEHORN': 0,
    'SEEHUSEN': 0,
    'SEEK': 0,
    'SEEKAMP': 0,
    'SEEKATZ': 0,
    'SEEKELL': 0,
    'SEEKER': 0,
    'SEEKFORD': 0,
    'SEEKINGS': 0,
    'SEEKINS': 0,
    'SEEL': 0,
    'SEELA': 0,
    'SEELAND': 0,
    'SEELBACH': 0,
    'SEELBINDER': 0,
    'SEELE': 0,
    'SEELEN': 0,
    'SEELER': 0,
    'SEELEY': 0,
    'SEELHOFF': 0,
    'SEELHORST': 0,
    'SEELIG': 0,
    'SEELIGER': 0,
    'SEELING': 0,
    'SEELINGER': 0,
    'SEELKE': 0,
    'SEELMAN': 0,
    'SEELOFF': 0,
    'SEELOW': 0,
    'SEELY': 0,
    'SEELYE': 0,
    'SEEM': 0,
    'SEEMA': 1,
    'SEEMAN': 0,
    'SEEMANN': 0,
    'SEEMILLER': 0,
    'SEEMS': 0,
    'SEEN': 0,
    'SEENARINE': 0,
    'SEENEY': 0,
    'SEENO': 0,
    'SEEP': 0,
    'SEEPAUL': 0,
    'SEEPERSAD': 0,
    'SEEPERSAUD': 0,
    'SEER': 0,
    'SEERAM': 0,
    'SEERING': 0,
    'SEERY': 0,
    'SEES': 0,
    'SEESE': 0,
    'SEESHOLTZ': 0,
    'SEETARAM': 0,
    'SEETHALER': 0,
    'SEETHARAMAN': 0,
    'SEETO': 0,
    'SEETON': 0,
    'SEETS': 0,
    'SEEVER': 0,
    'SEEVERS': 0,
    'SEEWALD': 0,
    'SEEWER': 0,
    'SEFCHICK': 0,
    'SEFCIK': 0,
    'SEFCOVIC': 0,
    'SEFERIAN': 0,
    'SEFEROVIC': 0,
    'SEFF': 0,
    'SEFFENS': 0,
    'SEFFERNICK': 0,
    'SEFFROOD': 0,
    'SEFTON': 0,
    'SEGA': 0,
    'SEGAL': 0,
    'SEGALA': 0,
    'SEGALE': 0,
    'SEGALINI': 0,
    'SEGALL': 0,
    'SEGALLA': 0,
    'SEGAN': 0,
    'SEGAR': 0,
    'SEGARD': 0,
    'SEGARRA': 0,
    'SEGARS': 0,
    'SEGAWA': 0,
    'SEGAY': 0,
    'SEGEAR': 0,
    'SEGEBART': 0,
    'SEGEBARTH': 0,
    'SEGEDI': 0,
    'SEGEDY': 0,
    'SEGEE': 0,
    'SEGEL': 0,
    'SEGELKE': 0,
    'SEGELKEN': 0,
    'SEGELSTROM': 0,
    'SEGER': 0,
    'SEGERS': 0,
    'SEGERSON': 0,
    'SEGERSTROM': 0,
    'SEGERT': 0,
    'SEGGEBRUCH': 0,
    'SEGGERMAN': 0,
    'SEGHERS': 0,
    'SEGHETTI': 0,
    'SEGHI': 0,
    'SEGINA': 0,
    'SEGLEM': 0,
    'SEGLER': 0,
    'SEGNA': 0,
    'SEGNER': 0,
    'SEGNERI': 0,
    'SEGO': 0,
    'SEGOBIA': 0,
    'SEGOBIANO': 0,
    'SEGOVIA': 0,
    'SEGOVIAND': 0,
    'SEGOVIANO': 0,
    'SEGRAVE': 0,
    'SEGRAVES': 0,
    'SEGRE': 0,
    'SEGREE': 0,
    'SEGREST': 0,
    'SEGRETI': 0,
    'SEGRETO': 0,
    'SEGRETTO': 0,
    'SEGRIST': 0,
    'SEGRO': 0,
    'SEGROVES': 0,
    'SEGRUE': 0,
    'SEGUI': 0,
    'SEGUIN': 0,
    'SEGUINE': 0,
    'SEGUINOT': 0,
    'SEGUNDO': 0,
    'SEGUR': 0,
    'SEGURA': 0,
    'SEGURO': 0,
    'SEHER': 0,
    'SEHGAL': 0,
    'SEHI': 0,
    'SEHIC': 0,
    'SEHL': 0,
    'SEHLHORST': 0,
    'SEHLMEYER': 0,
    'SEHN': 0,
    'SEHNERT': 0,
    'SEHON': 0,
    'SEHORN': 0,
    'SEHOVIC': 0,
    'SEHR': 0,
    'SEHRING': 0,
    'SEHRT': 0,
    'SEHY': 0,
    'SEI': 0,
    'SEIB': 0,
    'SEIBEL': 0,
    'SEIBER': 0,
    'SEIBERLICH': 0,
    'SEIBERLING': 0,
    'SEIBERS': 0,
    'SEIBERT': 0,
    'SEIBLES': 0,
    'SEIBOLD': 0,
    'SEIBT': 0,
    'SEICH': 0,
    'SEICHTER': 0,
    'SEICK': 0,
    'SEID': 0,
    'SEIDA': 0,
    'SEIDE': 0,
    'SEIDEL': 0,
    'SEIDELL': 0,
    'SEIDELMAN': 0,
    'SEIDELMANN': 0,
    'SEIDEMAN': 0,
    'SEIDEMANN': 0,
    'SEIDEN': 0,
    'SEIDENBERG': 0,
    'SEIDENBERGER': 0,
    'SEIDENFELD': 0,
    'SEIDENKRANZ': 0,
    'SEIDENSTICKER': 0,
    'SEIDENSTRICKER': 0,
    'SEIDER': 0,
    'SEIDERS': 0,
    'SEIDITA': 0,
    'SEIDL': 0,
    'SEIDLE': 0,
    'SEIDLER': 0,
    'SEIDLING': 0,
    'SEIDLITZ': 0,
    'SEIDMAN': 0,
    'SEIDNER': 0,
    'SEIER': 0,
    'SEIF': 0,
    'SEIFER': 0,
    'SEIFERS': 0,
    'SEIFERT': 0,
    'SEIFERTH': 0,
    'SEIFF': 0,
    'SEIFFERT': 0,
    'SEIFRIED': 0,
    'SEIFRIT': 0,
    'SEIFTS': 0,
    'SEIFU': 0,
    'SEIG': 0,
    'SEIGAL': 0,
    'SEIGARS': 0,
    'SEIGEL': 0,
    'SEIGER': 0,
    'SEIGFREID': 0,
    'SEIGFRIED': 0,
    'SEIGH': 0,
    'SEIGHMAN': 0,
    'SEIGLE': 0,
    'SEIGLER': 0,
    'SEIGMAN': 0,
    'SEIGNEUR': 0,
    'SEIGNIOUS': 0,
    'SEIGRIST': 0,
    'SEIGWORTH': 0,
    'SEIJAS': 0,
    'SEIJO': 0,
    'SEIKEL': 0,
    'SEIL': 0,
    'SEILER': 0,
    'SEILEY': 0,
    'SEILHAMER': 0,
    'SEILHAN': 0,
    'SEILHEIMER': 0,
    'SEILING': 0,
    'SEILS': 0,
    'SEIM': 0,
    'SEIMEARS': 0,
    'SEIMER': 0,
    'SEIMS': 0,
    'SEIN': 0,
    'SEINER': 0,
    'SEINFELD': 0,
    'SEINO': 0,
    'SEIP': 0,
    'SEIPEL': 0,
    'SEIPERT': 0,
    'SEIPLE': 0,
    'SEIPP': 0,
    'SEIPPEL': 0,
    'SEIS': 0,
    'SEISE': 0,
    'SEISER': 0,
    'SEISS': 0,
    'SEITEL': 0,
    'SEITER': 0,
    'SEITH': 0,
    'SEITHEL': 0,
    'SEITHER': 0,
    'SEITLER': 0,
    'SEITSINGER': 0,
    'SEITTER': 0,
    'SEITZ': 0,
    'SEITZER': 0,
    'SEITZINGER': 0,
    'SEIVER': 0,
    'SEIVERS': 0,
    'SEIVERT': 0,
    'SEIWELL': 0,
    'SEIWERT': 0,
    'SEIXAS': 0,
    'SEIZ': 0,
    'SEJA': 0,
    'SEJAS': 0,
    'SEJOUR': 0,
    'SEK': 0,
    'SEKAR': 0,
    'SEKEL': 0,
    'SEKELA': 0,
    'SEKELSKY': 0,
    'SEKELY': 0,
    'SEKERA': 0,
    'SEKERAK': 0,
    'SEKERES': 0,
    'SEKHAR': 0,
    'SEKHON': 0,
    'SEKI': 0,
    'SEKIGUCHI': 0,
    'SEKINE': 0,
    'SEKINGER': 0,
    'SEKIYA': 0,
    'SEKO': 0,
    'SEKOL': 0,
    'SEKONA': 0,
    'SEKORA': 0,
    'SEKOWSKI': 0,
    'SEKULA': 0,
    'SEKULIC': 0,
    'SEKULICH': 0,
    'SEKULSKI': 0,
    'SELA': 0,
    'SELAH': 0,
    'SELAK': 0,
    'SELAN': 0,
    'SELAND': 0,
    'SELANDER': 0,
    'SELANDERS': 0,
    'SELASSIE': 0,
    'SELAYA': 0,
    'SELB': 0,
    'SELBACH': 0,
    'SELBE': 0,
    'SELBEE': 0,
    'SELBERG': 0,
    'SELBERT': 0,
    'SELBITSCHKA': 0,
    'SELBO': 0,
    'SELBST': 0,
    'SELBURG': 0,
    'SELBY': 0,
    'SELCER': 0,
    'SELCH': 0,
    'SELCHERT': 0,
    'SELCHOW': 0,
    'SELCK': 0,
    'SELDAL': 0,
    'SELDEN': 0,
    'SELDER': 0,
    'SELDERS': 0,
    'SELDIN': 0,
    'SELDOMRIDGE': 0,
    'SELDON': 0,
    'SELE': 0,
    'SELECKY': 0,
    'SELEE': 0,
    'SELEEN': 0,
    'SELENA': 1,
    'SELENE': 1,
    'SELENSKY': 0,
    'SELENT': 0,
    'SELEP': 0,
    'SELES': 0,
    'SELESKI': 0,
    'SELESKY': 0,
    'SELEWSKI': 0,
    'SELEY': 0,
    'SELF': 0,
    'SELFE': 0,
    'SELFRIDGE': 0,
    'SELGA': 0,
    'SELGADO': 0,
    'SELHORST': 0,
    'SELIG': 0,
    'SELIGA': 0,
    'SELIGER': 0,
    'SELIGMAN': 0,
    'SELIGMANN': 0,
    'SELIGSOHN': 0,
    'SELIGSON': 0,
    'SELIM': 0,
    'SELIMI': 0,
    'SELIMOVIC': 0,
    'SELIN': 0,
    'SELINA': 1,
    'SELINE': 0,
    'SELING': 0,
    'SELINGER': 0,
    'SELINSKI': 0,
    'SELINSKY': 0,
    'SELIS': 0,
    'SELISSEN': 0,
    'SELITTO': 0,
    'SELIX': 0,
    'SELK': 0,
    'SELKE': 0,
    'SELKEN': 0,
    'SELKER': 0,
    'SELKING': 0,
    'SELKIRK': 0,
    'SELKO': 0,
    'SELKOW': 0,
    'SELKOWITZ': 0,
    'SELL': 0,
    'SELLA': 0,
    'SELLAND': 0,
    'SELLAR': 0,
    'SELLARD': 0,
    'SELLARDS': 0,
    'SELLARI': 0,
    'SELLARS': 0,
    'SELLAS': 0,
    'SELLBERG': 0,
    'SELLE': 0,
    'SELLECK': 0,
    'SELLEN': 0,
    'SELLENS': 0,
    'SELLER': 0,
    'SELLERS': 0,
    'SELLES': 0,
    'SELLEW': 0,
    'SELLEY': 0,
    'SELLICK': 0,
    'SELLIE': 0,
    'SELLIER': 0,
    'SELLIN': 0,
    'SELLING': 0,
    'SELLINGER': 0,
    'SELLIS': 0,
    'SELLITTI': 0,
    'SELLITTO': 0,
    'SELLKE': 0,
    'SELLMAN': 0,
    'SELLMER': 0,
    'SELLMEYER': 0,
    'SELLNER': 0,
    'SELLNOW': 0,
    'SELLON': 0,
    'SELLS': 0,
    'SELLSTROM': 0,
    'SELLWOOD': 0,
    'SELLY': 0,
    'SELM': 0,
    'SELMA': 0.9962640099626402,
    'SELMAN': 0,
    'SELMANI': 0,
    'SELMER': 0,
    'SELMI': 0,
    'SELMON': 0,
    'SELNER': 0,
    'SELNESS': 0,
    'SELNICK': 0,
    'SELOCK': 0,
    'SELOVER': 0,
    'SELPH': 0,
    'SELSER': 0,
    'SELSKY': 0,
    'SELSOR': 0,
    'SELSTAD': 0,
    'SELTENREICH': 0,
    'SELTER': 0,
    'SELTMAN': 0,
    'SELTMANN': 0,
    'SELTZ': 0,
    'SELTZER': 0,
    'SELVA': 0,
    'SELVAGE': 0,
    'SELVAGGI': 0,
    'SELVAGGIO': 0,
    'SELVARAJ': 0,
    'SELVERA': 0,
    'SELVES': 0,
    'SELVEY': 0,
    'SELVIA': 0,
    'SELVIDGE': 0,
    'SELVIE': 0,
    'SELVIG': 0,
    'SELVIN': 0,
    'SELVOG': 0,
    'SELVY': 0,
    'SELWA': 0,
    'SELWAY': 0,
    'SELWOOD': 0,
    'SELWYN': 0,
    'SELZ': 0,
    'SELZER': 0,
    'SELZLER': 0,
    'SELZNICK': 0,
    'SEM': 0,
    'SEMA': 0,
    'SEMAAN': 0,
    'SEMAK': 0,
    'SEMAN': 0,
    'SEMANA': 0,
    'SEMANCHIK': 0,
    'SEMANCIK': 0,
    'SEMANCO': 0,
    'SEMANEK': 0,
    'SEMANKO': 0,
    'SEMANS': 0,
    'SEMANSKI': 0,
    'SEMAR': 0,
    'SEMAS': 0,
    'SEMB': 0,
    'SEMBACH': 0,
    'SEMBER': 0,
    'SEMBERA': 0,
    'SEMBLER': 0,
    'SEMBLY': 0,
    'SEMBRANO': 0,
    'SEMBRAT': 0,
    'SEME': 0,
    'SEMEDO': 0,
    'SEMEL': 0,
    'SEMELKA': 0,
    'SEMELSBERGER': 0,
    'SEMENCHUK': 0,
    'SEMENICK': 0,
    'SEMENIUK': 0,
    'SEMENKO': 0,
    'SEMENOV': 0,
    'SEMENTA': 0,
    'SEMENTELLI': 0,
    'SEMENTILLI': 0,
    'SEMENUK': 0,
    'SEMENYUK': 0,
    'SEMENZA': 0,
    'SEMER': 0,
    'SEMERAD': 0,
    'SEMERARO': 0,
    'SEMERDJIAN': 0,
    'SEMERE': 0,
    'SEMERJIAN': 0,
    'SEMEXANT': 0,
    'SEMIAN': 0,
    'SEMICH': 0,
    'SEMIDEY': 0,
    'SEMIEN': 0,
    'SEMIN': 0,
    'SEMINARA': 0,
    'SEMINARIO': 0,
    'SEMINATORE': 0,
    'SEMINERIO': 0,
    'SEMINGSON': 0,
    'SEMINO': 0,
    'SEMKE': 0,
    'SEMKO': 0,
    'SEMLER': 0,
    'SEMLING': 0,
    'SEMM': 0,
    'SEMMEL': 0,
    'SEMMENS': 0,
    'SEMMER': 0,
    'SEMMES': 0,
    'SEMMLER': 0,
    'SEMMONS': 0,
    'SEMO': 0,
    'SEMON': 0,
    'SEMONES': 0,
    'SEMONS': 0,
    'SEMORE': 0,
    'SEMPEK': 0,
    'SEMPER': 0,
    'SEMPF': 0,
    'SEMPLE': 0,
    'SEMPRINI': 0,
    'SEMPRIT': 0,
    'SEMPSROTT': 0,
    'SEMRAD': 0,
    'SEMRAU': 0,
    'SEMRO': 0,
    'SEMROW': 0,
    'SEMSCH': 0,
    'SEMTNER': 0,
    'SEN': 0,
    'SENA': 0.28328611898017003,
    'SENAC': 0,
    'SENAIDA': 1,
    'SENART': 0,
    'SENAT': 0,
    'SENATOR': 0,
    'SENATORE': 0,
    'SENATUS': 0,
    'SENAY': 0,
    'SENCER': 0,
    'SENCHAK': 0,
    'SENCHUK': 0,
    'SENCINDIVER': 0,
    'SENCION': 0,
    'SEND': 0,
    'SENDA': 0,
    'SENDEJAS': 0,
    'SENDEJO': 0,
    'SENDEK': 0,
    'SENDELBACH': 0,
    'SENDEN': 0,
    'SENDER': 0,
    'SENDERLING': 0,
    'SENDERS': 0,
    'SENDLER': 0,
    'SENDRA': 0,
    'SENDZIK': 0,
    'SENE': 0,
    'SENECA': 0,
    'SENECAL': 0,
    'SENECHAL': 0,
    'SENEFF': 0,
    'SENEGAL': 0,
    'SENEKER': 0,
    'SENER': 0,
    'SENERCHIA': 0,
    'SENESAC': 0,
    'SENESE': 0,
    'SENESI': 0,
    'SENEVIRATNE': 0,
    'SENEY': 0,
    'SENF': 0,
    'SENFF': 0,
    'SENFFNER': 0,
    'SENFT': 0,
    'SENFTEN': 0,
    'SENG': 0,
    'SENGBUSCH': 0,
    'SENGCHANH': 0,
    'SENGDARA': 0,
    'SENGE': 0,
    'SENGEL': 0,
    'SENGER': 0,
    'SENGMANY': 0,
    'SENGSAVANG': 0,
    'SENGSTOCK': 0,
    'SENGUPTA': 0,
    'SENIA': 0,
    'SENICA': 0,
    'SENICH': 0,
    'SENICK': 0,
    'SENIFF': 0,
    'SENIOR': 0,
    'SENISE': 0,
    'SENITA': 0,
    'SENIUK': 0,
    'SENIW': 0,
    'SENK': 0,
    'SENKBEIL': 0,
    'SENKEL': 0,
    'SENKER': 0,
    'SENKO': 0,
    'SENKOW': 0,
    'SENKOWSKI': 0,
    'SENKUS': 0,
    'SENN': 0,
    'SENNA': 0,
    'SENNE': 0,
    'SENNEFF': 0,
    'SENNER': 0,
    'SENNET': 0,
    'SENNETT': 0,
    'SENNHENN': 0,
    'SENNING': 0,
    'SENNINGER': 0,
    'SENNO': 0,
    'SENNOTT': 0,
    'SENO': 0,
    'SENOR': 0,
    'SENOUR': 0,
    'SENQUIZ': 0,
    'SENRA': 0,
    'SENS': 0,
    'SENSABAUGH': 0,
    'SENSALE': 0,
    'SENSAT': 0,
    'SENSE': 0,
    'SENSEL': 0,
    'SENSEMAN': 0,
    'SENSENBACH': 0,
    'SENSENBAUGH': 0,
    'SENSENBRENNER': 0,
    'SENSENEY': 0,
    'SENSENICH': 0,
    'SENSENIG': 0,
    'SENSER': 0,
    'SENSI': 0,
    'SENSIBA': 0,
    'SENSIBAUGH': 0,
    'SENSING': 0,
    'SENSINGER': 0,
    'SENSKE': 0,
    'SENSLEY': 0,
    'SENSMEIER': 0,
    'SENSOR': 0,
    'SENST': 0,
    'SENTEL': 0,
    'SENTELL': 0,
    'SENTELLE': 0,
    'SENTENEY': 0,
    'SENTENO': 0,
    'SENTER': 0,
    'SENTERFITT': 0,
    'SENTERS': 0,
    'SENTI': 0,
    'SENTILLES': 0,
    'SENTMAN': 0,
    'SENTNER': 0,
    'SENTS': 0,
    'SENTZ': 0,
    'SENUTA': 0,
    'SENYK': 0,
    'SENZ': 0,
    'SENZIG': 0,
    'SEO': 0,
    'SEOANE': 0,
    'SEOK': 0,
    'SEOL': 0,
    'SEON': 0,
    'SEONG': 0,
    'SEOW': 0,
    'SEPANIK': 0,
    'SEPANSKI': 0,
    'SEPE': 0,
    'SEPEDA': 0,
    'SEPEHRI': 0,
    'SEPELAK': 0,
    'SEPER': 0,
    'SEPESI': 0,
    'SEPESY': 0,
    'SEPHUS': 0,
    'SEPIC': 0,
    'SEPICH': 0,
    'SEPKO': 0,
    'SEPP': 0,
    'SEPPA': 0,
    'SEPPALA': 0,
    'SEPPANEN': 0,
    'SEPPELT': 0,
    'SEPPI': 0,
    'SEPRISH': 0,
    'SEPT': 0,
    'SEPTEMBER': 1,
    'SEPTER': 0,
    'SEPTIMUS': 0,
    'SEPTON': 0,
    'SEPULBEDA': 0,
    'SEPULUEDA': 0,
    'SEPULVADO': 0,
    'SEPULVEDA': 0,
    'SEQUEIRA': 0,
    'SEQUERA': 0,
    'SEQUIN': 0,
    'SER': 0,
    'SERA': 0,
    'SERABIAN': 0,
    'SERAFICA': 0,
    'SERAFIN': 0,
    'SERAFINA': 1,
    'SERAFINE': 0,
    'SERAFINI': 0,
    'SERAFINO': 0,
    'SERAGO': 0,
    'SERAILE': 0,
    'SERAJ': 0,
    'SERAK': 0,
    'SERAMUR': 0,
    'SERAN': 0,
    'SERANO': 0,
    'SERAPHIN': 0,
    'SERAPHINE': 0,
    'SERAPIGLIA': 0,
    'SERAPIO': 0,
    'SERATO': 0,
    'SERATT': 0,
    'SERATTE': 0,
    'SERB': 0,
    'SERBA': 0,
    'SERBAN': 0,
    'SERBANTEZ': 0,
    'SERBER': 0,
    'SERBIN': 0,
    'SERBOUSEK': 0,
    'SERBUS': 0,
    'SERCK': 0,
    'SERCU': 0,
    'SERDA': 0,
    'SERDAR': 0,
    'SERDYNSKI': 0,
    'SEREAL': 0,
    'SEREDA': 0,
    'SEREDAY': 0,
    'SEREIKA': 0,
    'SEREMET': 0,
    'SEREMETIS': 0,
    'SERENA': 0.975975975975976,
    'SERENE': 0,
    'SERENI': 0,
    'SERENIL': 0,
    'SERENO': 0,
    'SERES': 0,
    'SERETIS': 0,
    'SEREY': 0,
    'SERFAS': 0,
    'SERFASS': 0,
    'SERFLING': 0,
    'SERFOSS': 0,
    'SERFOZO': 0,
    'SERGE': 0,
    'SERGEANT': 0,
    'SERGEL': 0,
    'SERGENT': 0,
    'SERGEYEV': 0,
    'SERGI': 0,
    'SERGIO': 0.9941164536417123,
    'SERGO': 0,
    'SERGOTT': 0,
    'SERHAN': 0,
    'SERI': 0,
    'SERIAN': 0,
    'SERIANNI': 0,
    'SERICH': 0,
    'SERIE': 0,
    'SERIGHT': 0,
    'SERIGNE': 0,
    'SERIGNESE': 0,
    'SERIGNY': 0,
    'SERIN': 0,
    'SERINA': 0.9569377990430621,
    'SERING': 0,
    'SERINI': 0,
    'SERINO': 0,
    'SERIO': 0,
    'SERITA': 1,
    'SERITT': 0,
    'SERKES': 0,
    'SERKIN': 0,
    'SERL': 0,
    'SERLE': 0,
    'SERLES': 0,
    'SERLIN': 0,
    'SERLING': 0,
    'SERMAN': 0,
    'SERMENO': 0,
    'SERMERSHEIM': 0,
    'SERMON': 0,
    'SERMONS': 0,
    'SERNA': 0,
    'SERNAS': 0,
    'SERNETT': 0,
    'SERO': 0,
    'SEROCKI': 0,
    'SEROKA': 0,
    'SERON': 0,
    'SEROPIAN': 0,
    'SEROTA': 0,
    'SEROWIK': 0,
    'SERPA': 0,
    'SERPAS': 0,
    'SERPE': 0,
    'SERPICO': 0,
    'SERQUINA': 0,
    'SERR': 0,
    'SERRA': 0,
    'SERRAINO': 0,
    'SERRALTA': 0,
    'SERRAND': 0,
    'SERRANI': 0,
    'SERRANO': 0,
    'SERRANT': 0,
    'SERRAO': 0,
    'SERRAT': 0,
    'SERRATA': 0,
    'SERRATELLI': 0,
    'SERRATO': 0,
    'SERRATORE': 0,
    'SERRATOS': 0,
    'SERRATT': 0,
    'SERRE': 0,
    'SERRECCHIA': 0,
    'SERRELL': 0,
    'SERRES': 0,
    'SERRET': 0,
    'SERRETT': 0,
    'SERRETTE': 0,
    'SERRITELLA': 0,
    'SERRO': 0,
    'SERRONE': 0,
    'SERROS': 0,
    'SERRY': 0,
    'SERSCH': 0,
    'SERSEN': 0,
    'SERSHEN': 0,
    'SERTIC': 0,
    'SERTICH': 0,
    'SERTUCHE': 0,
    'SERUM': 0,
    'SERUYA': 0,
    'SERVA': 0,
    'SERVAES': 0,
    'SERVAIS': 0,
    'SERVANCE': 0,
    'SERVANT': 0,
    'SERVANTES': 0,
    'SERVANTEZ': 0,
    'SERVATIUS': 0,
    'SERVEDIO': 0,
    'SERVELLO': 0,
    'SERVELLON': 0,
    'SERVEN': 0,
    'SERVENTI': 0,
    'SERVER': 0,
    'SERVERA': 0,
    'SERVEY': 0,
    'SERVI': 0,
    'SERVICE': 0,
    'SERVIDEO': 0,
    'SERVIDIO': 0,
    'SERVIES': 0,
    'SERVIN': 0,
    'SERVINO': 0,
    'SERVIS': 0,
    'SERVISS': 0,
    'SERVO': 0,
    'SERVOS': 0,
    'SERVOSS': 0,
    'SERWA': 0,
    'SERWATKA': 0,
    'SERWE': 0,
    'SERWIN': 0,
    'SERY': 0,
    'SESAY': 0,
    'SESCO': 0,
    'SESE': 0,
    'SESHADRI': 0,
    'SESI': 0,
    'SESKER': 0,
    'SESKIN': 0,
    'SESKO': 0,
    'SESLAR': 0,
    'SESLER': 0,
    'SESMA': 0,
    'SESMAS': 0,
    'SESOCK': 0,
    'SESSA': 0,
    'SESSER': 0,
    'SESSION': 0,
    'SESSIONS': 0,
    'SESSLER': 0,
    'SESSO': 0,
    'SESSOM': 0,
    'SESSOMS': 0,
    'SESSON': 0,
    'SESSONS': 0,
    'SESSOR': 0,
    'SESSUM': 0,
    'SESSUMS': 0,
    'SESTA': 0,
    'SESTAK': 0,
    'SESTER': 0,
    'SESTI': 0,
    'SESTITO': 0,
    'SESTO': 0,
    'SESTRICH': 0,
    'SET': 0,
    'SETA': 0,
    'SETAREH': 0,
    'SETARO': 0,
    'SETCHEL': 0,
    'SETCHELL': 0,
    'SETER': 0,
    'SETERA': 0,
    'SETH': 0.9807928075194116,
    'SETHER': 0,
    'SETHI': 0,
    'SETHMAN': 0,
    'SETHNA': 0,
    'SETHURAMAN': 0,
    'SETIAN': 0,
    'SETIAWAN': 0,
    'SETINA': 0,
    'SETKA': 0,
    'SETLAK': 0,
    'SETLER': 0,
    'SETLIFF': 0,
    'SETLIK': 0,
    'SETLOCK': 0,
    'SETO': 0,
    'SETON': 0,
    'SETSER': 0,
    'SETSUKO': 1,
    'SETTA': 0,
    'SETTANNI': 0,
    'SETTE': 0,
    'SETTECASE': 0,
    'SETTEDUCATO': 0,
    'SETTELL': 0,
    'SETTEMBRE': 0,
    'SETTEMBRINO': 0,
    'SETTER': 0,
    'SETTERBERG': 0,
    'SETTERGREN': 0,
    'SETTERHOLM': 0,
    'SETTERLUND': 0,
    'SETTERS': 0,
    'SETTERSTROM': 0,
    'SETTI': 0,
    'SETTIMO': 0,
    'SETTINERI': 0,
    'SETTING': 0,
    'SETTINO': 0,
    'SETTJE': 0,
    'SETTLAGE': 0,
    'SETTLE': 0,
    'SETTLEMIER': 0,
    'SETTLEMIRE': 0,
    'SETTLEMIRES': 0,
    'SETTLEMOIR': 0,
    'SETTLEMYER': 0,
    'SETTLEMYRE': 0,
    'SETTLER': 0,
    'SETTLES': 0,
    'SETTON': 0,
    'SETTOON': 0,
    'SETTY': 0,
    'SETZ': 0,
    'SETZER': 0,
    'SETZKE': 0,
    'SETZLER': 0,
    'SEU': 0,
    'SEUBERT': 0,
    'SEUELL': 0,
    'SEUFER': 0,
    'SEUFERER': 0,
    'SEUFERT': 0,
    'SEUFFERT': 0,
    'SEUL': 0,
    'SEUM': 0,
    'SEUNG': 0,
    'SEURER': 0,
    'SEUS': 0,
    'SEUSS': 0,
    'SEUTTER': 0,
    'SEVAK': 0,
    'SEVART': 0,
    'SEVCIK': 0,
    'SEVEDGE': 0,
    'SEVEN': 0,
    'SEVENER': 0,
    'SEVENICH': 0,
    'SEVENSKI': 0,
    'SEVENSTAR': 0,
    'SEVER': 0,
    'SEVERA': 0,
    'SEVERANCE': 0,
    'SEVERE': 0,
    'SEVEREID': 0,
    'SEVERI': 0,
    'SEVERIANO': 0,
    'SEVERIN': 0,
    'SEVERINI': 0,
    'SEVERINO': 0,
    'SEVERINSEN': 0,
    'SEVERIO': 0,
    'SEVERN': 0,
    'SEVERNS': 0,
    'SEVERO': 0,
    'SEVERS': 0,
    'SEVERSEN': 0,
    'SEVERSON': 0,
    'SEVERT': 0,
    'SEVERTSON': 0,
    'SEVERY': 0,
    'SEVERYN': 0,
    'SEVEY': 0,
    'SEVI': 0,
    'SEVIC': 0,
    'SEVICK': 0,
    'SEVIER': 0,
    'SEVIGNY': 0,
    'SEVILLA': 0,
    'SEVILLANO': 0,
    'SEVILLE': 0,
    'SEVIN': 0,
    'SEVINSKY': 0,
    'SEVISON': 0,
    'SEVITS': 0,
    'SEVON': 0,
    'SEVY': 0,
    'SEWAK': 0,
    'SEWALD': 0,
    'SEWALL': 0,
    'SEWARD': 0,
    'SEWARDS': 0,
    'SEWART': 0,
    'SEWELL': 0,
    'SEWER': 0,
    'SEWICK': 0,
    'SEWING': 0,
    'SEXAUER': 0,
    'SEXE': 0,
    'SEXSMITH': 0,
    'SEXSON': 0,
    'SEXTON': 0,
    'SEXTRO': 0,
    'SEY': 0,
    'SEYB': 0,
    'SEYBERT': 0,
    'SEYBOLD': 0,
    'SEYBOLT': 0,
    'SEYBOTH': 0,
    'SEYDEL': 0,
    'SEYE': 0,
    'SEYER': 0,
    'SEYFANG': 0,
    'SEYFARTH': 0,
    'SEYFER': 0,
    'SEYFERT': 0,
    'SEYFERTH': 0,
    'SEYFFERT': 0,
    'SEYFRIED': 0,
    'SEYKORA': 0,
    'SEYL': 0,
    'SEYLE': 0,
    'SEYLER': 0,
    'SEYLLER': 0,
    'SEYMER': 0,
    'SEYMORE': 0,
    'SEYMOUR': 0.43586550435865506,
    'SEYMOURE': 0,
    'SEYOUM': 0,
    'SEYS': 0,
    'SEZER': 0,
    'SFEIR': 0,
    'SFERLAZZA': 0,
    'SFERRA': 0,
    'SFERRAZZA': 0,
    'SFIKAS': 0,
    'SFORZA': 0,
    'SFREDDO': 0,
    'SGAMBATI': 0,
    'SGAMBATO': 0,
    'SGAMBELLURI': 0,
    'SGANGA': 0,
    'SGARLATA': 0,
    'SGARLATO': 0,
    'SGOBBO': 0,
    'SGRIGNOLI': 0,
    'SGRO': 0,
    'SGROI': 0,
    'SGUEGLIA': 0,
    'SH': 0,
    'SHA': 0.8849557522123894,
    'SHAABAN': 0,
    'SHAAK': 0,
    'SHAAR': 0,
    'SHABA': 0,
    'SHABAN': 0,
    'SHABANI': 0,
    'SHABAT': 0,
    'SHABAZ': 0,
    'SHABAZIAN': 0,
    'SHABAZZ': 0,
    'SHABBIR': 0,
    'SHABEL': 0,
    'SHABER': 0,
    'SHABI': 0,
    'SHABO': 0,
    'SHACHAR': 0,
    'SHACK': 0,
    'SHACKELFORD': 0,
    'SHACKELTON': 0,
    'SHACKETT': 0,
    'SHACKFORD': 0,
    'SHACKLE': 0,
    'SHACKLEFORD': 0,
    'SHACKLES': 0,
    'SHACKLETON': 0,
    'SHACKLETT': 0,
    'SHACKLETTE': 0,
    'SHACKLEY': 0,
    'SHACKLOCK': 0,
    'SHACTER': 0,
    'SHAD': 0.936768149882904,
    'SHADA': 0,
    'SHADBOLT': 0,
    'SHADBURN': 0,
    'SHADD': 0,
    'SHADDAY': 0,
    'SHADDEN': 0,
    'SHADDIX': 0,
    'SHADDOCK': 0,
    'SHADDON': 0,
    'SHADDOX': 0,
    'SHADDUCK': 0,
    'SHADDY': 0,
    'SHADE': 0,
    'SHADECK': 0,
    'SHADEED': 0,
    'SHADEL': 0,
    'SHADELL': 0,
    'SHADER': 0,
    'SHADICK': 0,
    'SHADID': 0,
    'SHADINGER': 0,
    'SHADIS': 0,
    'SHADIX': 0,
    'SHADLE': 0,
    'SHADLER': 0,
    'SHADLEY': 0,
    'SHADLOW': 0,
    'SHADMAN': 0,
    'SHADOAN': 0,
    'SHADOIN': 0,
    'SHADOW': 0,
    'SHADOWEN': 0,
    'SHADOWENS': 0,
    'SHADRACH': 0,
    'SHADRICK': 0,
    'SHADRIX': 0,
    'SHADRON': 0,
    'SHADWELL': 0,
    'SHADWICK': 0,
    'SHADY': 0,
    'SHAE': 0.9523809523809523,
    'SHAEFER': 0,
    'SHAEFFER': 0,
    'SHAER': 0,
    'SHAEVITZ': 0,
    'SHAFA': 0,
    'SHAFAR': 0,
    'SHAFE': 0,
    'SHAFER': 0,
    'SHAFF': 0,
    'SHAFFAR': 0,
    'SHAFFER': 0,
    'SHAFFERMAN': 0,
    'SHAFFERY': 0,
    'SHAFFETT': 0,
    'SHAFFNER': 0,
    'SHAFFORD': 0,
    'SHAFFSTALL': 0,
    'SHAFI': 0,
    'SHAFIE': 0,
    'SHAFIK': 0,
    'SHAFIQ': 0,
    'SHAFIQUE': 0,
    'SHAFIR': 0,
    'SHAFNER': 0,
    'SHAFRAN': 0,
    'SHAFRANSKI': 0,
    'SHAFRON': 0,
    'SHAFT': 0,
    'SHAFTER': 0,
    'SHAFTO': 0,
    'SHAGENA': 0,
    'SHAGER': 0,
    'SHAGINAW': 0,
    'SHAH': 0,
    'SHAHA': 0,
    'SHAHAB': 0,
    'SHAHABI': 0,
    'SHAHAN': 0,
    'SHAHANI': 0,
    'SHAHAR': 0,
    'SHAHBAZ': 0,
    'SHAHBAZI': 0,
    'SHAHBAZIAN': 0,
    'SHAHEED': 0,
    'SHAHEEN': 0,
    'SHAHI': 0,
    'SHAHID': 0,
    'SHAHIDI': 0,
    'SHAHIN': 0,
    'SHAHINIAN': 0,
    'SHAHNAZARIAN': 0,
    'SHAHRIARI': 0,
    'SHAHVERDIAN': 0,
    'SHAHWAN': 0,
    'SHAHZAD': 0,
    'SHAI': 0,
    'SHAIA': 0,
    'SHAIBI': 0,
    'SHAIFER': 0,
    'SHAIK': 0,
    'SHAIKA': 0,
    'SHAIKH': 0,
    'SHAIMAN': 0,
    'SHAIN': 0,
    'SHAINA': 1,
    'SHAIR': 0,
    'SHAK': 0,
    'SHAKAL': 0,
    'SHAKARIAN': 0,
    'SHAKE': 0,
    'SHAKED': 0,
    'SHAKEEL': 0,
    'SHAKER': 0,
    'SHAKERI': 0,
    'SHAKES': 0,
    'SHAKESHAFT': 0,
    'SHAKESPEAR': 0,
    'SHAKESPEARE': 0,
    'SHAKIA': 1,
    'SHAKIB': 0,
    'SHAKIL': 0,
    'SHAKIN': 0,
    'SHAKIR': 0,
    'SHAKIRA': 1,
    'SHAKITA': 1,
    'SHAKLEE': 0,
    'SHAKLEY': 0,
    'SHAKOOR': 0,
    'SHAKUR': 0,
    'SHAKYA': 0,
    'SHALA': 0.9009009009009009,
    'SHALABI': 0,
    'SHALABY': 0,
    'SHALANDA': 1,
    'SHALASH': 0,
    'SHALE': 0,
    'SHALEEN': 0,
    'SHALEK': 0,
    'SHALER': 0,
    'SHALES': 0,
    'SHALEV': 0,
    'SHALHOUB': 0,
    'SHALIT': 0,
    'SHALKOWSKI': 0,
    'SHALL': 0,
    'SHALLA': 0,
    'SHALLAL': 0,
    'SHALLCROSS': 0,
    'SHALLENBERGER': 0,
    'SHALLER': 0,
    'SHALLEY': 0,
    'SHALLO': 0,
    'SHALLOW': 0,
    'SHALOM': 0,
    'SHALON': 1,
    'SHALONDA': 1,
    'SHALOSKY': 0,
    'SHALVEY': 0,
    'SHALZ': 0,
    'SHAM': 0,
    'SHAMA': 0,
    'SHAMAH': 0,
    'SHAMALY': 0,
    'SHAMAN': 0,
    'SHAMANSKY': 0,
    'SHAMAS': 0,
    'SHAMASH': 0,
    'SHAMBACH': 0,
    'SHAMBARGER': 0,
    'SHAMBAUGH': 0,
    'SHAMBEAU': 0,
    'SHAMBERG': 0,
    'SHAMBERGER': 0,
    'SHAMBLEE': 0,
    'SHAMBLEN': 0,
    'SHAMBLEY': 0,
    'SHAMBLIN': 0,
    'SHAMBO': 0,
    'SHAMBRY': 0,
    'SHAMBURG': 0,
    'SHAMBURGER': 0,
    'SHAMEKA': 1,
    'SHAMEL': 0,
    'SHAMER': 0,
    'SHAMES': 0,
    'SHAMEY': 0,
    'SHAMHART': 0,
    'SHAMI': 0,
    'SHAMIE': 0,
    'SHAMIEH': 0,
    'SHAMIKA': 1,
    'SHAMIM': 0,
    'SHAMIR': 0,
    'SHAMIS': 0,
    'SHAMLEY': 0,
    'SHAMLIAN': 0,
    'SHAMLIN': 0,
    'SHAMLOO': 0,
    'SHAMMA': 0,
    'SHAMMAMI': 0,
    'SHAMMAS': 0,
    'SHAMMO': 0,
    'SHAMO': 0,
    'SHAMON': 0,
    'SHAMOON': 0,
    'SHAMOUN': 0,
    'SHAMP': 0,
    'SHAMPINE': 0,
    'SHAMPO': 0,
    'SHAMROCK': 0,
    'SHAMS': 0,
    'SHAMSI': 0,
    'SHAMSIDDEEN': 0,
    'SHAMSUDDIN': 0,
    'SHAMUS': 0,
    'SHAMY': 0,
    'SHAN': 0.5780346820809249,
    'SHANA': 0.9977827050997782,
    'SHANABARGER': 0,
    'SHANABERGER': 0,
    'SHANABROOK': 0,
    'SHANAE': 1,
    'SHANAFELT': 0,
    'SHANAHAN': 0,
    'SHANAMAN': 0,
    'SHANBHAG': 0,
    'SHANCHEZ': 0,
    'SHAND': 0,
    'SHANDA': 0.9917355371900827,
    'SHANDER': 0,
    'SHANDERA': 0,
    'SHANDI': 1,
    'SHANDLER': 0,
    'SHANDLEY': 0,
    'SHANDOR': 0,
    'SHANDORF': 0,
    'SHANDRA': 0.9803921568627452,
    'SHANDS': 0,
    'SHANDY': 0,
    'SHANE': 0.9734603955323291,
    'SHANEBROOK': 0,
    'SHANEKA': 1,
    'SHANEL': 1,
    'SHANELL': 1,
    'SHANELLE': 1,
    'SHANER': 0,
    'SHANES': 0,
    'SHANEY': 0,
    'SHANEYFELT': 0,
    'SHANG': 0,
    'SHANGLE': 0,
    'SHANGRAW': 0,
    'SHANGREAUX': 0,
    'SHANHOLTZ': 0,
    'SHANHOLTZER': 0,
    'SHANI': 0.9836065573770493,
    'SHANICE': 1,
    'SHANIKA': 1,
    'SHANIQUA': 1,
    'SHANITA': 1,
    'SHANK': 0,
    'SHANKAR': 0,
    'SHANKEL': 0,
    'SHANKER': 0,
    'SHANKEY': 0,
    'SHANKIN': 0,
    'SHANKLAND': 0,
    'SHANKLE': 0,
    'SHANKLES': 0,
    'SHANKLIN': 0,
    'SHANKMAN': 0,
    'SHANKO': 0,
    'SHANKS': 0,
    'SHANKSTER': 0,
    'SHANKWEILER': 0,
    'SHANLE': 0,
    'SHANLEY': 0,
    'SHANMUGAM': 0,
    'SHANN': 0,
    'SHANNA': 1,
    'SHANNAHAN': 0,
    'SHANNAN': 1,
    'SHANNO': 0,
    'SHANNON': 0.9281243254910425,
    'SHANNONHOUSE': 0,
    'SHANON': 0.9823182711198428,
    'SHANOR': 0,
    'SHANOWER': 0,
    'SHANS': 0,
    'SHANTA': 0.9803921568627452,
    'SHANTAE': 1,
    'SHANTAY': 1,
    'SHANTE': 1,
    'SHANTEAU': 0,
    'SHANTEL': 1,
    'SHANTELL': 1,
    'SHANTELLE': 1,
    'SHANTI': 0.9615384615384616,
    'SHANTIE': 0,
    'SHANTON': 0,
    'SHANTY': 0,
    'SHANTZ': 0,
    'SHAO': 0,
    'SHAPARD': 0,
    'SHAPE': 0,
    'SHAPER': 0,
    'SHAPERO': 0,
    'SHAPIRA': 0,
    'SHAPIRO': 0,
    'SHAPLAND': 0,
    'SHAPLEIGH': 0,
    'SHAPLEY': 0,
    'SHAPP': 0,
    'SHAPPARD': 0,
    'SHAPPEE': 0,
    'SHAPPELL': 0,
    'SHAPPLEY': 0,
    'SHAPPY': 0,
    'SHAPTER': 0,
    'SHAQUANA': 1,
    'SHAQUITA': 1,
    'SHAR': 0,
    'SHARA': 0.9803921568627452,
    'SHARABI': 0,
    'SHARABY': 0,
    'SHARAF': 0,
    'SHARAFI': 0,
    'SHARAK': 0,
    'SHARAN': 0.9259259259259258,
    'SHARAR': 0,
    'SHARBAUGH': 0,
    'SHARBER': 0,
    'SHARBONO': 0,
    'SHARBUTT': 0,
    'SHARD': 0,
    'SHARDA': 0.9433962264150944,
    'SHARE': 0,
    'SHAREE': 1,
    'SHAREEF': 0,
    'SHAREK': 0,
    'SHARELL': 1,
    'SHAREN': 1,
    'SHARER': 0,
    'SHARF': 0,
    'SHARFF': 0,
    'SHARFMAN': 0,
    'SHARFSTEIN': 0,
    'SHARI': 0.9985734664764622,
    'SHARICE': 1,
    'SHARICK': 0,
    'SHARIE': 1,
    'SHARIEF': 0,
    'SHARIER': 0,
    'SHARIF': 0,
    'SHARIFF': 0,
    'SHARIFI': 0,
    'SHARIK': 0,
    'SHARIKA': 1,
    'SHARILYN': 1,
    'SHARIT': 0,
    'SHARITA': 1,
    'SHARITS': 0,
    'SHARITZ': 0,
    'SHARK': 0,
    'SHARKEY': 0,
    'SHARKO': 0,
    'SHARKUS': 0,
    'SHARKY': 0,
    'SHARLA': 1,
    'SHARLAND': 0,
    'SHARLEEN': 1,
    'SHARLENE': 1,
    'SHARLEY': 0,
    'SHARLOW': 0,
    'SHARMA': 0,
    'SHARMAINE': 1,
    'SHARMAN': 0,
    'SHARO': 0,
    'SHAROLYN': 1,
    'SHARON': 0.9976682848514964,
    'SHARONDA': 1,
    'SHARP': 0,
    'SHARPE': 0,
    'SHARPEE': 0,
    'SHARPER': 0,
    'SHARPERSON': 0,
    'SHARPES': 0,
    'SHARPLES': 0,
    'SHARPLESS': 0,
    'SHARPLEY': 0,
    'SHARPNACK': 0,
    'SHARPS': 0,
    'SHARPSTEEN': 0,
    'SHARPTON': 0,
    'SHARR': 0,
    'SHARRAH': 0,
    'SHARRAR': 0,
    'SHARRARD': 0,
    'SHARRATT': 0,
    'SHARRER': 0,
    'SHARRETT': 0,
    'SHARRETTS': 0,
    'SHARRI': 1,
    'SHARRIEFF': 0,
    'SHARROCK': 0,
    'SHARRON': 0.9838369641602248,
    'SHARROW': 0,
    'SHARRY': 0,
    'SHARTLE': 0,
    'SHARTS': 0,
    'SHARTZER': 0,
    'SHARUM': 0,
    'SHARY': 0,
    'SHARYL': 1,
    'SHARYN': 1,
    'SHASHA': 0,
    'SHASHATY': 0,
    'SHASKE': 0,
    'SHASKY': 0,
    'SHASTA': 1,
    'SHASTEEN': 0,
    'SHASTID': 0,
    'SHASTRI': 0,
    'SHASTRY': 0,
    'SHATARA': 0,
    'SHATEK': 0,
    'SHATKIN': 0,
    'SHATLEY': 0,
    'SHATNEY': 0,
    'SHATRAW': 0,
    'SHATS': 0,
    'SHATSWELL': 0,
    'SHATTLES': 0,
    'SHATTO': 0,
    'SHATTUCK': 0,
    'SHATWELL': 0,
    'SHATZ': 0,
    'SHATZEL': 0,
    'SHATZER': 0,
    'SHAU': 0,
    'SHAUB': 0,
    'SHAUD': 0,
    'SHAUER': 0,
    'SHAUF': 0,
    'SHAUGER': 0,
    'SHAUGHNESSY': 0,
    'SHAUKAT': 0,
    'SHAUL': 0,
    'SHAULIS': 0,
    'SHAULL': 0,
    'SHAUM': 0,
    'SHAUN': 1,
    'SHAUNA': 1,
    'SHAUNDA': 1,
    'SHAUNNA': 1,
    'SHAUNTA': 1,
    'SHAUNTE': 1,
    'SHAURETTE': 0,
    'SHAUT': 0,
    'SHAUVER': 0,
    'SHAVALIER': 0,
    'SHAVE': 0,
    'SHAVEL': 0,
    'SHAVER': 0,
    'SHAVERS': 0,
    'SHAVLIK': 0,
    'SHAVON': 1,
    'SHAVONDA': 1,
    'SHAVONNE': 1,
    'SHAVOR': 0,
    'SHAW': 0,
    'SHAWANA': 1,
    'SHAWANDA': 1,
    'SHAWANNA': 1,
    'SHAWBACK': 0,
    'SHAWCROFT': 0,
    'SHAWCROSS': 0,
    'SHAWEN': 0,
    'SHAWGER': 0,
    'SHAWGO': 0,
    'SHAWHAN': 0,
    'SHAWKEY': 0,
    'SHAWL': 0,
    'SHAWLER': 0,
    'SHAWLEY': 0,
    'SHAWN': 0.9983064444246368,
    'SHAWNA': 1,
    'SHAWNDA': 1,
    'SHAWNEE': 1,
    'SHAWNNA': 1,
    'SHAWNTA': 1,
    'SHAWVER': 0,
    'SHAWYER': 0,
    'SHAY': 0.4651162790697674,
    'SHAYA': 0,
    'SHAYAN': 0,
    'SHAYER': 0,
    'SHAYLA': 1,
    'SHAYLER': 0,
    'SHAYLOR': 0,
    'SHAYNA': 1,
    'SHAYNE': 0.9765625,
    'SHAYS': 0,
    'SHAZER': 0,
    'SHAZIER': 0,
    'SHCHERBAKOV': 0,
    'SHCHERBINA': 0,
    'SHE': 0,
    'SHEA': 0.14398848092152627,
    'SHEAD': 0,
    'SHEAF': 0,
    'SHEAFER': 0,
    'SHEAFF': 0,
    'SHEAFFER': 0,
    'SHEAHAN': 0,
    'SHEAHEN': 0,
    'SHEAK': 0,
    'SHEAKLEY': 0,
    'SHEAKS': 0,
    'SHEALER': 0,
    'SHEALEY': 0,
    'SHEALY': 0,
    'SHEAN': 0,
    'SHEAR': 0,
    'SHEARBURN': 0,
    'SHEARD': 0,
    'SHEAREN': 0,
    'SHEARER': 0,
    'SHEARHART': 0,
    'SHEARIN': 0,
    'SHEARING': 0,
    'SHEARL': 0,
    'SHEARMAN': 0,
    'SHEARN': 0,
    'SHEARON': 0,
    'SHEAROUSE': 0,
    'SHEARRER': 0,
    'SHEARROW': 0,
    'SHEARS': 0,
    'SHEARY': 0,
    'SHEASBY': 0,
    'SHEASLEY': 0,
    'SHEATS': 0,
    'SHEAVES': 0,
    'SHEBA': 1,
    'SHEBER': 0,
    'SHEBESTA': 0,
    'SHEBLE': 0,
    'SHECHTER': 0,
    'SHECHTMAN': 0,
    'SHECK': 0,
    'SHECKELLS': 0,
    'SHECKELS': 0,
    'SHECKLER': 0,
    'SHECKLES': 0,
    'SHECTER': 0,
    'SHED': 0,
    'SHEDD': 0,
    'SHEDDAN': 0,
    'SHEDDEN': 0,
    'SHEDDY': 0,
    'SHEDENHELM': 0,
    'SHEDIVY': 0,
    'SHEDLOCK': 0,
    'SHEDRICK': 0,
    'SHEDRON': 0,
    'SHEE': 0,
    'SHEEAN': 0,
    'SHEED': 0,
    'SHEEDER': 0,
    'SHEEDY': 0,
    'SHEEHAN': 0,
    'SHEEHE': 0,
    'SHEEHEY': 0,
    'SHEEHY': 0,
    'SHEEK': 0,
    'SHEEKS': 0,
    'SHEELAR': 0,
    'SHEELER': 0,
    'SHEELEY': 0,
    'SHEELY': 0,
    'SHEEN': 0,
    'SHEENA': 0.9947337624341721,
    'SHEENAN': 0,
    'SHEENE': 0,
    'SHEER': 0,
    'SHEERAN': 0,
    'SHEERER': 0,
    'SHEERIN': 0,
    'SHEERS': 0,
    'SHEESE': 0,
    'SHEESLEY': 0,
    'SHEETER': 0,
    'SHEETS': 0,
    'SHEETZ': 0,
    'SHEFCHIK': 0,
    'SHEFF': 0,
    'SHEFFEL': 0,
    'SHEFFER': 0,
    'SHEFFERLY': 0,
    'SHEFFEY': 0,
    'SHEFFIELD': 0,
    'SHEFFLER': 0,
    'SHEFFY': 0,
    'SHEFIELD': 0,
    'SHEFLER': 0,
    'SHEFLIN': 0,
    'SHEFTALL': 0,
    'SHEFTEL': 0,
    'SHEFTIC': 0,
    'SHEGA': 0,
    'SHEGOG': 0,
    'SHEH': 0,
    'SHEHAB': 0,
    'SHEHADEH': 0,
    'SHEHADI': 0,
    'SHEHAN': 0,
    'SHEHANE': 0,
    'SHEHATA': 0,
    'SHEHEE': 0,
    'SHEHORN': 0,
    'SHEHU': 0,
    'SHEI': 0,
    'SHEIBLEY': 0,
    'SHEID': 0,
    'SHEIDLER': 0,
    'SHEIDY': 0,
    'SHEIK': 0,
    'SHEIKA': 0,
    'SHEIKH': 0,
    'SHEIL': 0,
    'SHEILA': 1,
    'SHEILAH': 1,
    'SHEILDS': 0,
    'SHEILS': 0,
    'SHEIMAN': 0,
    'SHEIN': 0,
    'SHEINBAUM': 0,
    'SHEINBERG': 0,
    'SHEINER': 0,
    'SHEINFELD': 0,
    'SHEK': 0,
    'SHEKAR': 0,
    'SHEKELL': 0,
    'SHEKER': 0,
    'SHEKHTER': 0,
    'SHEKHTMAN': 0,
    'SHEKLETON': 0,
    'SHELA': 1,
    'SHELANDER': 0,
    'SHELAR': 0,
    'SHELAT': 0,
    'SHELBA': 1,
    'SHELBOURN': 0,
    'SHELBOURNE': 0,
    'SHELBURG': 0,
    'SHELBURN': 0,
    'SHELBURNE': 0,
    'SHELBY': 0.8930786405358472,
    'SHELDAHL': 0,
    'SHELDEN': 0,
    'SHELDON': 0.7633587786259542,
    'SHELDRAKE': 0,
    'SHELDRICK': 0,
    'SHELER': 0,
    'SHELEY': 0,
    'SHELFER': 0,
    'SHELFORD': 0,
    'SHELGREN': 0,
    'SHELHAMER': 0,
    'SHELHART': 0,
    'SHELHORSE': 0,
    'SHELIA': 1,
    'SHELINE': 0,
    'SHELITE': 0,
    'SHELKEY': 0,
    'SHELKO': 0,
    'SHELL': 0,
    'SHELLA': 1,
    'SHELLABARGER': 0,
    'SHELLARD': 0,
    'SHELLBERG': 0,
    'SHELLEDY': 0,
    'SHELLEM': 0,
    'SHELLENBARGER': 0,
    'SHELLENBERG': 0,
    'SHELLENBERGER': 0,
    'SHELLER': 0,
    'SHELLEY': 0.9042258719320908,
    'SHELLHAAS': 0,
    'SHELLHAMER': 0,
    'SHELLHAMMER': 0,
    'SHELLHART': 0,
    'SHELLHORN': 0,
    'SHELLHOUSE': 0,
    'SHELLI': 1,
    'SHELLIE': 1,
    'SHELLING': 0,
    'SHELLINGTON': 0,
    'SHELLITO': 0,
    'SHELLMAN': 0,
    'SHELLNUT': 0,
    'SHELLS': 0,
    'SHELLUM': 0,
    'SHELLY': 0.9685986564599282,
    'SHELMADINE': 0,
    'SHELMAN': 0,
    'SHELMIDINE': 0,
    'SHELMIRE': 0,
    'SHELMON': 0,
    'SHELNUT': 0,
    'SHELNUTT': 0,
    'SHELOR': 0,
    'SHELOW': 0,
    'SHELP': 0,
    'SHELPMAN': 0,
    'SHELSTAD': 0,
    'SHELT': 0,
    'SHELTER': 0,
    'SHELTERS': 0,
    'SHELTON': 0.19636720667648502,
    'SHELTRA': 0,
    'SHELTROWN': 0,
    'SHELVIN': 0,
    'SHELY': 0,
    'SHEM': 0,
    'SHEMA': 0,
    'SHEMANSKI': 0,
    'SHEMANSKY': 0,
    'SHEMEKA': 1,
    'SHEMENSKI': 0,
    'SHEMER': 0,
    'SHEMESH': 0,
    'SHEMIKA': 1,
    'SHEMO': 0,
    'SHEMON': 0,
    'SHEMORY': 0,
    'SHEMPERT': 0,
    'SHEMTOV': 0,
    'SHEMWELL': 0,
    'SHEN': 0,
    'SHENA': 1,
    'SHENBERGER': 0,
    'SHENDO': 0,
    'SHENE': 0,
    'SHENEFELT': 0,
    'SHENEFIELD': 0,
    'SHENEMAN': 0,
    'SHENFELD': 0,
    'SHENG': 0,
    'SHENIKA': 1,
    'SHENITA': 1,
    'SHENK': 0,
    'SHENKEL': 0,
    'SHENKER': 0,
    'SHENKLE': 0,
    'SHENKMAN': 0,
    'SHENKO': 0,
    'SHENNA': 1,
    'SHENNETT': 0,
    'SHENOUDA': 0,
    'SHENOY': 0,
    'SHENTON': 0,
    'SHEPARD': 0,
    'SHEPARDSON': 0,
    'SHEPEARD': 0,
    'SHEPERD': 0,
    'SHEPERSKY': 0,
    'SHEPHARD': 0,
    'SHEPHEARD': 0,
    'SHEPHERD': 0,
    'SHEPHERDSON': 0,
    'SHEPLER': 0,
    'SHEPLEY': 0,
    'SHEPP': 0,
    'SHEPPARD': 0,
    'SHEPPEARD': 0,
    'SHEPPERD': 0,
    'SHEPPERSON': 0,
    'SHEPPHARD': 0,
    'SHEPPHERD': 0,
    'SHEPPICK': 0,
    'SHEPPS': 0,
    'SHEPRO': 0,
    'SHEPS': 0,
    'SHEPTOCK': 0,
    'SHER': 0,
    'SHERA': 0.9009009009009009,
    'SHERADEN': 0,
    'SHERALD': 0,
    'SHERAN': 0,
    'SHERAR': 0,
    'SHERARD': 0,
    'SHERBA': 0,
    'SHERBAHN': 0,
    'SHERBAN': 0,
    'SHERBERT': 0,
    'SHERBET': 0,
    'SHERBINE': 0,
    'SHERBO': 0,
    'SHERBON': 0,
    'SHERBONDY': 0,
    'SHERBOURNE': 0,
    'SHERBURN': 0,
    'SHERBURNE': 0,
    'SHERBY': 0,
    'SHERCK': 0,
    'SHERD': 0,
    'SHERE': 0,
    'SHERECK': 0,
    'SHEREDA': 0,
    'SHEREDY': 0,
    'SHEREE': 1,
    'SHEREK': 0,
    'SHERELL': 1,
    'SHEREMET': 0,
    'SHEREMETA': 0,
    'SHEREN': 0,
    'SHERER': 0,
    'SHERERTZ': 0,
    'SHERF': 0,
    'SHERFEY': 0,
    'SHERFICK': 0,
    'SHERFIELD': 0,
    'SHERFINSKI': 0,
    'SHERFY': 0,
    'SHERGILL': 0,
    'SHERI': 1,
    'SHERICE': 1,
    'SHERICK': 0,
    'SHERIDAN': 0.1107419712070875,
    'SHERIE': 1,
    'SHERIF': 0,
    'SHERIFF': 0,
    'SHERIKA': 1,
    'SHERILL': 0.9345794392523364,
    'SHERILYN': 1,
    'SHERIN': 0,
    'SHERISE': 1,
    'SHERITA': 1,
    'SHERK': 0,
    'SHERLAND': 0,
    'SHERLENE': 1,
    'SHERLEY': 0.9009009009009009,
    'SHERLIN': 0,
    'SHERLINE': 0,
    'SHERLING': 0,
    'SHERLOCK': 0,
    'SHERLUND': 0,
    'SHERLY': 1,
    'SHERLYN': 1,
    'SHERMAN': 0.5195769159398775,
    'SHERMER': 0,
    'SHERMEYER': 0,
    'SHERN': 0,
    'SHERO': 0,
    'SHEROD': 0,
    'SHERON': 0.9584664536741214,
    'SHEROUSE': 0,
    'SHEROW': 0,
    'SHERPA': 0,
    'SHERR': 0,
    'SHERRARD': 0,
    'SHERRATT': 0,
    'SHERRED': 0,
    'SHERRELL': 0.6666666666666666,
    'SHERREN': 0,
    'SHERRER': 0,
    'SHERRETS': 0,
    'SHERRI': 1,
    'SHERRICK': 0,
    'SHERRIE': 1,
    'SHERRIER': 0,
    'SHERRIFF': 0,
    'SHERRIL': 0.9523809523809523,
    'SHERRILL': 0.4464285714285714,
    'SHERRIN': 0,
    'SHERRINGTON': 0,
    'SHERRITT': 0,
    'SHERROCK': 0,
    'SHERROD': 0,
    'SHERRON': 0.8498583569405098,
    'SHERROUSE': 0,
    'SHERROW': 0,
    'SHERRY': 0.9851126238308705,
    'SHERRYL': 1,
    'SHERTZ': 0,
    'SHERTZER': 0,
    'SHERVA': 0,
    'SHERVEN': 0,
    'SHERVEY': 0,
    'SHERVIN': 0,
    'SHERVINGTON': 0,
    'SHERWANI': 0,
    'SHERWIN': 0,
    'SHERWOOD': 0.3395585738539898,
    'SHERY': 1,
    'SHERYL': 1,
    'SHERYLL': 1,
    'SHESKEY': 0,
    'SHESTAK': 0,
    'SHETH': 0,
    'SHETKA': 0,
    'SHETLER': 0,
    'SHETLEY': 0,
    'SHETRON': 0,
    'SHETRONE': 0,
    'SHETTEL': 0,
    'SHETTER': 0,
    'SHETTERLY': 0,
    'SHETTERS': 0,
    'SHETTLE': 0,
    'SHETTLER': 0,
    'SHETTLES': 0,
    'SHETTLESWORTH': 0,
    'SHETTY': 0,
    'SHEU': 0,
    'SHEUMAKER': 0,
    'SHEVCHENKO': 0,
    'SHEVCHIK': 0,
    'SHEVCHUK': 0,
    'SHEVEL': 0,
    'SHEVELAND': 0,
    'SHEVER': 0,
    'SHEVITZ': 0,
    'SHEVLIN': 0,
    'SHEVOCK': 0,
    'SHEW': 0,
    'SHEWALTER': 0,
    'SHEWAN': 0,
    'SHEWARD': 0,
    'SHEWBART': 0,
    'SHEWBERT': 0,
    'SHEWBRIDGE': 0,
    'SHEWCHUK': 0,
    'SHEWELL': 0,
    'SHEWEY': 0,
    'SHEWFELT': 0,
    'SHEWMAKE': 0,
    'SHEWMAKER': 0,
    'SHEWMAN': 0,
    'SHEY': 0,
    'SHI': 0,
    'SHIA': 0,
    'SHIAH': 0,
    'SHIAO': 0,
    'SHIAU': 0,
    'SHIBA': 0,
    'SHIBATA': 0,
    'SHIBAYAMA': 0,
    'SHIBER': 0,
    'SHIBLER': 0,
    'SHIBLES': 0,
    'SHIBLEY': 0,
    'SHIBUYA': 0,
    'SHICK': 0,
    'SHIDELER': 0,
    'SHIDER': 0,
    'SHIDLER': 0,
    'SHIE': 0,
    'SHIEH': 0,
    'SHIEK': 0,
    'SHIEL': 0,
    'SHIELA': 1,
    'SHIELD': 0,
    'SHIELDS': 0,
    'SHIELL': 0,
    'SHIELS': 0,
    'SHIER': 0,
    'SHIERLING': 0,
    'SHIERS': 0,
    'SHIERY': 0,
    'SHIEVER': 0,
    'SHIFERAW': 0,
    'SHIFF': 0,
    'SHIFFER': 0,
    'SHIFFERLY': 0,
    'SHIFFERT': 0,
    'SHIFFLER': 0,
    'SHIFFLET': 0,
    'SHIFFLETT': 0,
    'SHIFFLETTE': 0,
    'SHIFFMAN': 0,
    'SHIFFRIN': 0,
    'SHIFLER': 0,
    'SHIFLET': 0,
    'SHIFLETT': 0,
    'SHIFLEY': 0,
    'SHIFMAN': 0,
    'SHIFRIN': 0,
    'SHIFTER': 0,
    'SHIGAKI': 0,
    'SHIGEMATSU': 0,
    'SHIGEMOTO': 0,
    'SHIGEMURA': 0,
    'SHIGETA': 0,
    'SHIGGS': 0,
    'SHIGLEY': 0,
    'SHIGO': 0,
    'SHIH': 0,
    'SHIHADEH': 0,
    'SHIJE': 0,
    'SHIKANY': 0,
    'SHIKE': 0,
    'SHIKHMAN': 0,
    'SHIKLES': 0,
    'SHILA': 1,
    'SHILDT': 0,
    'SHILES': 0,
    'SHILEY': 0,
    'SHILL': 0,
    'SHILLEH': 0,
    'SHILLER': 0,
    'SHILLING': 0,
    'SHILLINGBURG': 0,
    'SHILLINGER': 0,
    'SHILLINGFORD': 0,
    'SHILLINGLAW': 0,
    'SHILLINGS': 0,
    'SHILLINGTON': 0,
    'SHILLITO': 0,
    'SHILLOW': 0,
    'SHILMAN': 0,
    'SHILO': 0,
    'SHILOH': 0.9174311926605505,
    'SHILOW': 0,
    'SHILT': 0,
    'SHILTON': 0,
    'SHILTS': 0,
    'SHILTZ': 0,
    'SHIM': 0,
    'SHIMA': 0,
    'SHIMABUKU': 0,
    'SHIMABUKURO': 0,
    'SHIMADA': 0,
    'SHIMAMOTO': 0,
    'SHIMAMURA': 0,
    'SHIMAN': 0,
    'SHIMANEK': 0,
    'SHIMANSKY': 0,
    'SHIMASAKI': 0,
    'SHIMAZU': 0,
    'SHIMBERG': 0,
    'SHIMEK': 0,
    'SHIMEL': 0,
    'SHIMER': 0,
    'SHIMIZU': 0,
    'SHIMKO': 0,
    'SHIMKUS': 0,
    'SHIMMEL': 0,
    'SHIMMIN': 0,
    'SHIMO': 0,
    'SHIMODA': 0,
    'SHIMOKAWA': 0,
    'SHIMOMURA': 0,
    'SHIMON': 0,
    'SHIMONO': 0,
    'SHIMONOV': 0,
    'SHIMOTA': 0,
    'SHIMP': 0,
    'SHIMSHOCK': 0,
    'SHIMUNOV': 0,
    'SHIMURA': 0,
    'SHIN': 0.14534883720930233,
    'SHINA': 0,
    'SHINABARGAR': 0,
    'SHINABARGER': 0,
    'SHINABERRY': 0,
    'SHINABERY': 0,
    'SHINAGAWA': 0,
    'SHINALL': 0,
    'SHINAULT': 0,
    'SHINAVER': 0,
    'SHINDE': 0,
    'SHINDEL': 0,
    'SHINDELAR': 0,
    'SHINDELDECKER': 0,
    'SHINDELL': 0,
    'SHINDER': 0,
    'SHINDLE': 0,
    'SHINDLEDECKER': 0,
    'SHINDLER': 0,
    'SHINDO': 0,
    'SHINDORF': 0,
    'SHINE': 0,
    'SHINEMAN': 0,
    'SHINER': 0,
    'SHINES': 0,
    'SHING': 0,
    'SHINGARA': 0,
    'SHINGLE': 0,
    'SHINGLEDECKER': 0,
    'SHINGLER': 0,
    'SHINGLES': 0,
    'SHINGLETON': 0,
    'SHINHOLSTER': 0,
    'SHINHOSTER': 0,
    'SHININGER': 0,
    'SHINK': 0,
    'SHINKLE': 0,
    'SHINKO': 0,
    'SHINN': 0,
    'SHINNEMAN': 0,
    'SHINNER': 0,
    'SHINNERS': 0,
    'SHINNICK': 0,
    'SHINO': 0,
    'SHINODA': 0,
    'SHINOHARA': 0,
    'SHINOZAKI': 0,
    'SHINPAUGH': 0,
    'SHINSATO': 0,
    'SHINSKE': 0,
    'SHINSKY': 0,
    'SHINTAKU': 0,
    'SHINTANI': 0,
    'SHINTON': 0,
    'SHIOTA': 0,
    'SHIOTANI': 0,
    'SHIOZAKI': 0,
    'SHIP': 0,
    'SHIPE': 0,
    'SHIPES': 0,
    'SHIPKA': 0,
    'SHIPLE': 0,
    'SHIPLER': 0,
    'SHIPLET': 0,
    'SHIPLETT': 0,
    'SHIPLEY': 0,
    'SHIPMAN': 0,
    'SHIPMON': 0,
    'SHIPP': 0,
    'SHIPPEE': 0,
    'SHIPPEN': 0,
    'SHIPPER': 0,
    'SHIPPERT': 0,
    'SHIPPEY': 0,
    'SHIPPLEY': 0,
    'SHIPPS': 0,
    'SHIPPY': 0,
    'SHIPTON': 0,
    'SHIPWASH': 0,
    'SHIPWAY': 0,
    'SHIR': 0,
    'SHIRA': 0.8810572687224669,
    'SHIRAH': 0,
    'SHIRAI': 0,
    'SHIRAISHI': 0,
    'SHIRAKAWA': 0,
    'SHIRAKI': 0,
    'SHIRAR': 0,
    'SHIRAZI': 0,
    'SHIRCEL': 0,
    'SHIRCLIFF': 0,
    'SHIRD': 0,
    'SHIRE': 0,
    'SHIREK': 0,
    'SHIREL': 0,
    'SHIRELY': 0.9523809523809523,
    'SHIREMAN': 0,
    'SHIRER': 0,
    'SHIRES': 0,
    'SHIREY': 0,
    'SHIRILLA': 0,
    'SHIRING': 0,
    'SHIRINIAN': 0,
    'SHIRK': 0,
    'SHIRKEY': 0,
    'SHIRL': 1,
    'SHIRLEE': 1,
    'SHIRLEEN': 1,
    'SHIRLENE': 1,
    'SHIRLEY': 0.9796427421950434,
    'SHIRLING': 0,
    'SHIRLY': 1,
    'SHIRMAN': 0,
    'SHIRO': 0,
    'SHIROMA': 0,
    'SHIROTA': 0,
    'SHIRREFFS': 0,
    'SHIRRELL': 0,
    'SHIRTS': 0,
    'SHIRTZ': 0,
    'SHIRVANI': 0,
    'SHIRVANIAN': 0,
    'SHISHIDO': 0,
    'SHISLER': 0,
    'SHISSLER': 0,
    'SHITTU': 0,
    'SHIU': 0,
    'SHIVA': 0,
    'SHIVAK': 0,
    'SHIVAR': 0,
    'SHIVE': 0,
    'SHIVEL': 0,
    'SHIVELEY': 0,
    'SHIVELY': 0,
    'SHIVENER': 0,
    'SHIVER': 0,
    'SHIVERDECKER': 0,
    'SHIVERS': 0,
    'SHIVERY': 0,
    'SHIVES': 0,
    'SHIVLEY': 0,
    'SHIYOU': 0,
    'SHIZUE': 1,
    'SHIZUKO': 1,
    'SHKLYAR': 0,
    'SHKOLNIK': 0,
    'SHKOLNIKOV': 0,
    'SHKRELI': 0,
    'SHMIDT': 0,
    'SHMUKLER': 0,
    'SHNAYDER': 0,
    'SHNAYDERMAN': 0,
    'SHNEIDER': 0,
    'SHNEYDER': 0,
    'SHNIDER': 0,
    'SHO': 0,
    'SHOAF': 0,
    'SHOAFF': 0,
    'SHOAIB': 0,
    'SHOALS': 0,
    'SHOAP': 0,
    'SHOATE': 0,
    'SHOATES': 0,
    'SHOATS': 0,
    'SHOBE': 0,
    'SHOBER': 0,
    'SHOBERG': 0,
    'SHOBERT': 0,
    'SHOCK': 0,
    'SHOCKENCY': 0,
    'SHOCKEY': 0,
    'SHOCKLEE': 0,
    'SHOCKLEY': 0,
    'SHOCKMAN': 0,
    'SHOCKNEY': 0,
    'SHODA': 0,
    'SHOE': 0,
    'SHOEBRIDGE': 0,
    'SHOECRAFT': 0,
    'SHOELL': 0,
    'SHOEMAKE': 0,
    'SHOEMAKER': 0,
    'SHOEMAN': 0,
    'SHOEMATE': 0,
    'SHOEMO': 0,
    'SHOEN': 0,
    'SHOENBERGER': 0,
    'SHOENER': 0,
    'SHOENFELD': 0,
    'SHOENFELT': 0,
    'SHOESMITH': 0,
    'SHOFF': 0,
    'SHOFFEITT': 0,
    'SHOFFIT': 0,
    'SHOFFNER': 0,
    'SHOFFSTALL': 0,
    'SHOFNER': 0,
    'SHOFSTALL': 0,
    'SHOGAN': 0,
    'SHOGER': 0,
    'SHOGREN': 0,
    'SHOHAM': 0,
    'SHOHATEE': 0,
    'SHOHET': 0,
    'SHOJI': 0,
    'SHOKES': 0,
    'SHOLANDER': 0,
    'SHOLAR': 0,
    'SHOLARS': 0,
    'SHOLD': 0,
    'SHOLDER': 0,
    'SHOLDERS': 0,
    'SHOLER': 0,
    'SHOLES': 0,
    'SHOLEY': 0,
    'SHOLIN': 0,
    'SHOLL': 0,
    'SHOLLENBERGER': 0,
    'SHOLLER': 0,
    'SHOLLEY': 0,
    'SHOLLY': 0,
    'SHOLTES': 0,
    'SHOLTIS': 0,
    'SHOLTS': 0,
    'SHOLTY': 0,
    'SHOLTZ': 0,
    'SHOMAKER': 0,
    'SHOMAN': 0,
    'SHOMBER': 0,
    'SHOMER': 0,
    'SHOMIN': 0,
    'SHOMO': 0,
    'SHOMPER': 0,
    'SHOMSKY': 0,
    'SHON': 0.9302325581395349,
    'SHONA': 1,
    'SHONDA': 1,
    'SHONDEL': 0,
    'SHONDRA': 1,
    'SHONE': 0,
    'SHONEBARGER': 0,
    'SHONES': 0,
    'SHONG': 0,
    'SHONK': 0,
    'SHONKA': 0,
    'SHONKWILER': 0,
    'SHONNA': 1,
    'SHONTA': 1,
    'SHONTS': 0,
    'SHONTZ': 0,
    'SHONYO': 0,
    'SHOOK': 0,
    'SHOOKS': 0,
    'SHOOLTZ': 0,
    'SHOOP': 0,
    'SHOOPMAN': 0,
    'SHOOT': 0,
    'SHOOTER': 0,
    'SHOOTS': 0,
    'SHOPBELL': 0,
    'SHOPE': 0,
    'SHOPP': 0,
    'SHOPPA': 0,
    'SHOPPELL': 0,
    'SHOPSHIRE': 0,
    'SHOPTAUGH': 0,
    'SHOPTAW': 0,
    'SHOQUIST': 0,
    'SHOR': 0,
    'SHORB': 0,
    'SHORE': 0,
    'SHORES': 0,
    'SHORETTE': 0,
    'SHOREY': 0,
    'SHORKEY': 0,
    'SHORMAN': 0,
    'SHORR': 0,
    'SHORROCK': 0,
    'SHORT': 0,
    'SHORTAL': 0,
    'SHORTALL': 0,
    'SHORTELL': 0,
    'SHORTEN': 0,
    'SHORTER': 0,
    'SHORTES': 0,
    'SHORTESS': 0,
    'SHORTHAIR': 0,
    'SHORTHOUSE': 0,
    'SHORTINO': 0,
    'SHORTLAND': 0,
    'SHORTLE': 0,
    'SHORTLEY': 0,
    'SHORTLIDGE': 0,
    'SHORTMAN': 0,
    'SHORTNACY': 0,
    'SHORTREED': 0,
    'SHORTRIDGE': 0,
    'SHORTS': 0,
    'SHORTSLEEVE': 0,
    'SHORTSLEEVES': 0,
    'SHORTT': 0,
    'SHORTY': 0,
    'SHORTZ': 0,
    'SHOSHAN': 0,
    'SHOSHANA': 1,
    'SHOSTAK': 0,
    'SHOTKOSKI': 0,
    'SHOTLIFF': 0,
    'SHOTO': 0,
    'SHOTT': 0,
    'SHOTTENKIRK': 0,
    'SHOTTON': 0,
    'SHOTTS': 0,
    'SHOTWELL': 0,
    'SHOTZBERGER': 0,
    'SHOU': 0,
    'SHOUB': 0,
    'SHOUCAIR': 0,
    'SHOUDY': 0,
    'SHOUEY': 0,
    'SHOUGH': 0,
    'SHOUKRY': 0,
    'SHOULARS': 0,
    'SHOULDER': 0,
    'SHOULDERS': 0,
    'SHOULDICE': 0,
    'SHOULDIS': 0,
    'SHOULTS': 0,
    'SHOULTZ': 0,
    'SHOUMAN': 0,
    'SHOUN': 0,
    'SHOUP': 0,
    'SHOUPE': 0,
    'SHOUPPE': 0,
    'SHOURD': 0,
    'SHOURDS': 0,
    'SHOUSE': 0,
    'SHOUTZ': 0,
    'SHOVAN': 0,
    'SHOVE': 0,
    'SHOVEIN': 0,
    'SHOVER': 0,
    'SHOVLIN': 0,
    'SHOW': 0,
    'SHOWALTER': 0,
    'SHOWE': 0,
    'SHOWELL': 0,
    'SHOWEN': 0,
    'SHOWER': 0,
    'SHOWERMAN': 0,
    'SHOWERS': 0,
    'SHOWLER': 0,
    'SHOWMAKER': 0,
    'SHOWMAN': 0,
    'SHOWN': 0,
    'SHOWS': 0,
    'SHOY': 0,
    'SHOYKHET': 0,
    'SHPAK': 0,
    'SHPIGEL': 0,
    'SHRABLE': 0,
    'SHRACK': 0,
    'SHRADER': 0,
    'SHRAGER': 0,
    'SHRAGO': 0,
    'SHRAKE': 0,
    'SHRAMEK': 0,
    'SHRAUGER': 0,
    'SHRAUNER': 0,
    'SHRAWDER': 0,
    'SHRECK': 0,
    'SHRECKENGAST': 0,
    'SHRECKENGOST': 0,
    'SHREEVE': 0,
    'SHREEVES': 0,
    'SHREFFLER': 0,
    'SHREINER': 0,
    'SHREM': 0,
    'SHRESTHA': 0,
    'SHREVE': 0,
    'SHREVES': 0,
    'SHREWSBERRY': 0,
    'SHREWSBURY': 0,
    'SHRIBER': 0,
    'SHRIDER': 0,
    'SHRIER': 0,
    'SHRIEVE': 0,
    'SHRIEVES': 0,
    'SHRIFT': 0,
    'SHRIGLEY': 0,
    'SHRIMPLIN': 0,
    'SHRIMPTON': 0,
    'SHRINER': 0,
    'SHRIVASTAVA': 0,
    'SHRIVER': 0,
    'SHROADES': 0,
    'SHROADS': 0,
    'SHROBA': 0,
    'SHROCK': 0,
    'SHRODE': 0,
    'SHRODER': 0,
    'SHRODES': 0,
    'SHROEDER': 0,
    'SHROFF': 0,
    'SHROLL': 0,
    'SHROM': 0,
    'SHRONTZ': 0,
    'SHROPE': 0,
    'SHROPSHIRE': 0,
    'SHROUDER': 0,
    'SHROUT': 0,
    'SHROYER': 0,
    'SHRULL': 0,
    'SHRUM': 0,
    'SHRY': 0,
    'SHRYACK': 0,
    'SHRYER': 0,
    'SHRYOCK': 0,
    'SHTERN': 0,
    'SHTEYMAN': 0,
    'SHTEYN': 0,
    'SHTEYNBERG': 0,
    'SHU': 0.7407407407407407,
    'SHUAIB': 0,
    'SHUART': 0,
    'SHUB': 0,
    'SHUBA': 0,
    'SHUBACK': 0,
    'SHUBAT': 0,
    'SHUBECK': 0,
    'SHUBER': 0,
    'SHUBERT': 0,
    'SHUBIN': 0,
    'SHUBRICK': 0,
    'SHUCK': 0,
    'SHUCKHART': 0,
    'SHUDA': 0,
    'SHUDY': 0,
    'SHUE': 0,
    'SHUELL': 0,
    'SHUEMAKE': 0,
    'SHUEMAKER': 0,
    'SHUEY': 0,
    'SHUFELDT': 0,
    'SHUFELT': 0,
    'SHUFF': 0,
    'SHUFFETT': 0,
    'SHUFFIELD': 0,
    'SHUFFITT': 0,
    'SHUFFLEBARGER': 0,
    'SHUFFLER': 0,
    'SHUFFORD': 0,
    'SHUFORD': 0,
    'SHUGA': 0,
    'SHUGAR': 0,
    'SHUGARMAN': 0,
    'SHUGARS': 0,
    'SHUGART': 0,
    'SHUGARTS': 0,
    'SHUGERT': 0,
    'SHUGG': 0,
    'SHUGHART': 0,
    'SHUGRUE': 0,
    'SHUH': 0,
    'SHUHART': 0,
    'SHUI': 0,
    'SHUJA': 0,
    'SHUKER': 0,
    'SHUKIS': 0,
    'SHUKLA': 0,
    'SHUKRI': 0,
    'SHULA': 0,
    'SHULAR': 0,
    'SHULAW': 0,
    'SHULDA': 0,
    'SHULENBERGER': 0,
    'SHULER': 0,
    'SHULFER': 0,
    'SHULGA': 0,
    'SHULICK': 0,
    'SHULKIN': 0,
    'SHULL': 0,
    'SHULLAW': 0,
    'SHULLER': 0,
    'SHULMAN': 0,
    'SHULSE': 0,
    'SHULSTAD': 0,
    'SHULT': 0,
    'SHULTES': 0,
    'SHULTIS': 0,
    'SHULTS': 0,
    'SHULTZ': 0,
    'SHULTZABERGER': 0,
    'SHULZ': 0,
    'SHULZE': 0,
    'SHUM': 0,
    'SHUMA': 0,
    'SHUMACK': 0,
    'SHUMAKE': 0,
    'SHUMAKER': 0,
    'SHUMAN': 0,
    'SHUMAR': 0,
    'SHUMARD': 0,
    'SHUMATE': 0,
    'SHUMER': 0,
    'SHUMOCK': 0,
    'SHUMP': 0,
    'SHUMPERT': 0,
    'SHUMSKI': 0,
    'SHUMSKY': 0,
    'SHUMWAY': 0,
    'SHUN': 0,
    'SHUNG': 0,
    'SHUNK': 0,
    'SHUNKWILER': 0,
    'SHUNN': 0,
    'SHUNNARAH': 0,
    'SHUPAK': 0,
    'SHUPE': 0,
    'SHUPERT': 0,
    'SHUPING': 0,
    'SHUPP': 0,
    'SHUPPERT': 0,
    'SHUPTRINE': 0,
    'SHUR': 0,
    'SHURA': 0,
    'SHURBET': 0,
    'SHURDEN': 0,
    'SHURE': 0,
    'SHURINA': 0,
    'SHURLEY': 0,
    'SHURLING': 0,
    'SHURLOW': 0,
    'SHURMAN': 0,
    'SHURN': 0,
    'SHURR': 0,
    'SHURSON': 0,
    'SHURTE': 0,
    'SHURTER': 0,
    'SHURTLEFF': 0,
    'SHURTLIFF': 0,
    'SHURTS': 0,
    'SHURTZ': 0,
    'SHUSS': 0,
    'SHUST': 0,
    'SHUSTA': 0,
    'SHUSTACK': 0,
    'SHUSTER': 0,
    'SHUSTERMAN': 0,
    'SHUTA': 0,
    'SHUTACK': 0,
    'SHUTAK': 0,
    'SHUTE': 0,
    'SHUTER': 0,
    'SHUTES': 0,
    'SHUTLER': 0,
    'SHUTT': 0,
    'SHUTTE': 0,
    'SHUTTER': 0,
    'SHUTTERS': 0,
    'SHUTTLE': 0,
    'SHUTTLESWORTH': 0,
    'SHUTTLEWORTH': 0,
    'SHUTTS': 0,
    'SHUTTY': 0,
    'SHUTZ': 0,
    'SHUYLER': 0,
    'SHVARTS': 0,
    'SHVARTSMAN': 0,
    'SHVETS': 0,
    'SHWARTZ': 0,
    'SHWE': 0,
    'SHWEKY': 0,
    'SHY': 0,
    'SHYE': 0,
    'SHYER': 0,
    'SHYKES': 0,
    'SHYLA': 1,
    'SHYMANSKI': 0,
    'SHYMANSKY': 0,
    'SHYNE': 0,
    'SHYTLE': 0,
    'SHYU': 0,
    'SI': 0,
    'SIA': 0,
    'SIACK': 0,
    'SIADE': 0,
    'SIAHAAN': 0,
    'SIAL': 0,
    'SIAM': 0,
    'SIAN': 0,
    'SIANA': 0,
    'SIANEZ': 0,
    'SIANI': 0,
    'SIANO': 0,
    'SIAO': 0,
    'SIAPNO': 0,
    'SIAR': 0,
    'SIARKOWSKI': 0,
    'SIAS': 0,
    'SIATER': 0,
    'SIATKOWSKI': 0,
    'SIAU': 0,
    'SIAW': 0,
    'SIAZON': 0,
    'SIBAJA': 0,
    'SIBAL': 0,
    'SIBAYAN': 0,
    'SIBBALD': 0,
    'SIBBET': 0,
    'SIBBETT': 0,
    'SIBBING': 0,
    'SIBBITT': 0,
    'SIBBLE': 0,
    'SIBBLIES': 0,
    'SIBBY': 0,
    'SIBEL': 0,
    'SIBELL': 0,
    'SIBENALLER': 0,
    'SIBER': 0,
    'SIBERT': 0,
    'SIBIGA': 0,
    'SIBIGTROTH': 0,
    'SIBILA': 0,
    'SIBILIA': 0,
    'SIBILIO': 0,
    'SIBILLA': 0,
    'SIBILLE': 0,
    'SIBILSKY': 0,
    'SIBIO': 0,
    'SIBISKI': 0,
    'SIBLE': 0,
    'SIBLEY': 0,
    'SIBOLD': 0,
    'SIBOLE': 0,
    'SIBREL': 0,
    'SIBRI': 0,
    'SIBRIAN': 0,
    'SIBSON': 0,
    'SIBURT': 0,
    'SIBYL': 1,
    'SIC': 0,
    'SICA': 0,
    'SICAIROS': 0,
    'SICAL': 0,
    'SICARD': 0,
    'SICARI': 0,
    'SICAT': 0,
    'SICELOFF': 0,
    'SICH': 0,
    'SICHAK': 0,
    'SICHEL': 0,
    'SICHENEDER': 0,
    'SICHER': 0,
    'SICHERI': 0,
    'SICHERMAN': 0,
    'SICHLER': 0,
    'SICHMELLER': 0,
    'SICHTING': 0,
    'SICIGNANO': 0,
    'SICILIA': 0,
    'SICILIAN': 0,
    'SICILIANO': 0,
    'SICINSKI': 0,
    'SICK': 0,
    'SICKAFOOSE': 0,
    'SICKBERT': 0,
    'SICKEL': 0,
    'SICKELS': 0,
    'SICKENBERGER': 0,
    'SICKER': 0,
    'SICKING': 0,
    'SICKINGER': 0,
    'SICKLE': 0,
    'SICKLER': 0,
    'SICKLES': 0,
    'SICKMAN': 0,
    'SICKMANN': 0,
    'SICKMEIER': 0,
    'SICKMILLER': 0,
    'SICKO': 0,
    'SICKS': 0,
    'SICLARI': 0,
    'SICO': 0,
    'SICOLA': 0,
    'SICOLI': 0,
    'SICONOLFI': 0,
    'SICORA': 0,
    'SICOTTE': 0,
    'SICRE': 0,
    'SICURANZA': 0,
    'SICURELLA': 0,
    'SICURO': 0,
    'SID': 0.9852216748768473,
    'SIDA': 0,
    'SIDAN': 0,
    'SIDARI': 0,
    'SIDAWAY': 0,
    'SIDBERRY': 0,
    'SIDBURY': 0,
    'SIDDALL': 0,
    'SIDDELL': 0,
    'SIDDEN': 0,
    'SIDDENS': 0,
    'SIDDERS': 0,
    'SIDDIQ': 0,
    'SIDDIQI': 0,
    'SIDDIQUE': 0,
    'SIDDIQUI': 0,
    'SIDDLE': 0,
    'SIDDON': 0,
    'SIDDONS': 0,
    'SIDDOWAY': 0,
    'SIDE': 0,
    'SIDEBOTHAM': 0,
    'SIDEBOTTOM': 0,
    'SIDEL': 0,
    'SIDELINGER': 0,
    'SIDELINKER': 0,
    'SIDELL': 0,
    'SIDEN': 0,
    'SIDENER': 0,
    'SIDENSTRICKER': 0,
    'SIDER': 0,
    'SIDERIO': 0,
    'SIDERIS': 0,
    'SIDERIUS': 0,
    'SIDERS': 0,
    'SIDES': 0,
    'SIDEY': 0,
    'SIDHOM': 0,
    'SIDHU': 0,
    'SIDI': 0,
    'SIDIBE': 0,
    'SIDIE': 0,
    'SIDIQI': 0,
    'SIDIROPOULOS': 0,
    'SIDLAUSKAS': 0,
    'SIDLE': 0,
    'SIDLER': 0,
    'SIDLES': 0,
    'SIDLEY': 0,
    'SIDLO': 0,
    'SIDLOW': 0,
    'SIDLOWSKI': 0,
    'SIDMAN': 0,
    'SIDMORE': 0,
    'SIDNER': 0,
    'SIDNEY': 0.986784140969163,
    'SIDO': 0,
    'SIDOCK': 0,
    'SIDON': 0,
    'SIDOR': 0,
    'SIDORENKO': 0,
    'SIDOROV': 0,
    'SIDOROWICZ': 0,
    'SIDORSKI': 0,
    'SIDOTE': 0,
    'SIDOTI': 0,
    'SIDUN': 0,
    'SIDWELL': 0,
    'SIE': 0,
    'SIEB': 0,
    'SIEBE': 0,
    'SIEBECKER': 0,
    'SIEBEL': 0,
    'SIEBELS': 0,
    'SIEBEN': 0,
    'SIEBENALER': 0,
    'SIEBENALLER': 0,
    'SIEBENECK': 0,
    'SIEBENHAAR': 0,
    'SIEBENLIST': 0,
    'SIEBENMORGEN': 0,
    'SIEBENS': 0,
    'SIEBENTHAL': 0,
    'SIEBER': 0,
    'SIEBERG': 0,
    'SIEBERS': 0,
    'SIEBERT': 0,
    'SIEBLER': 0,
    'SIEBOLD': 0,
    'SIEBRANDT': 0,
    'SIEBRECHT': 0,
    'SIEBUHR': 0,
    'SIEBURG': 0,
    'SIECH': 0,
    'SIECINSKI': 0,
    'SIECK': 0,
    'SIECKMAN': 0,
    'SIECKMANN': 0,
    'SIECZKA': 0,
    'SIECZKOWSKI': 0,
    'SIEDEL': 0,
    'SIEDENBURG': 0,
    'SIEDHOFF': 0,
    'SIEDLECKI': 0,
    'SIEDLER': 0,
    'SIEDLIK': 0,
    'SIEDMAN': 0,
    'SIEDOW': 0,
    'SIEDSCHLAG': 0,
    'SIEFER': 0,
    'SIEFERS': 0,
    'SIEFERT': 0,
    'SIEFF': 0,
    'SIEFFERMAN': 0,
    'SIEFFERT': 0,
    'SIEFKAS': 0,
    'SIEFKE': 0,
    'SIEFKEN': 0,
    'SIEFKER': 0,
    'SIEFKES': 0,
    'SIEFRING': 0,
    'SIEG': 0,
    'SIEGAL': 0,
    'SIEGE': 0,
    'SIEGEL': 0,
    'SIEGELE': 0,
    'SIEGELMAN': 0,
    'SIEGENTHALER': 0,
    'SIEGER': 0,
    'SIEGERS': 0,
    'SIEGERT': 0,
    'SIEGFRIED': 0,
    'SIEGL': 0,
    'SIEGLE': 0,
    'SIEGLER': 0,
    'SIEGMAN': 0,
    'SIEGMANN': 0,
    'SIEGMUND': 0,
    'SIEGNER': 0,
    'SIEGRIST': 0,
    'SIEGWALD': 0,
    'SIEGWARTH': 0,
    'SIEGWORTH': 0,
    'SIEH': 0,
    'SIEHL': 0,
    'SIEHR': 0,
    'SIEJA': 0,
    'SIEK': 0,
    'SIEKER': 0,
    'SIEKERT': 0,
    'SIEKIERKA': 0,
    'SIEKIERSKI': 0,
    'SIEKKINEN': 0,
    'SIEKMAN': 0,
    'SIEKMANN': 0,
    'SIEL': 0,
    'SIELAFF': 0,
    'SIELER': 0,
    'SIELICKI': 0,
    'SIELING': 0,
    'SIELOFF': 0,
    'SIELSKI': 0,
    'SIEM': 0,
    'SIEMAN': 0,
    'SIEMANN': 0,
    'SIEMBAB': 0,
    'SIEMBIDA': 0,
    'SIEMBIEDA': 0,
    'SIEMEK': 0,
    'SIEMEN': 0,
    'SIEMENS': 0,
    'SIEMER': 0,
    'SIEMERING': 0,
    'SIEMERS': 0,
    'SIEMINSKI': 0,
    'SIEMION': 0,
    'SIEMON': 0,
    'SIEMONS': 0,
    'SIEMONSMA': 0,
    'SIEMS': 0,
    'SIEMSEN': 0,
    'SIEN': 0,
    'SIENA': 0,
    'SIENER': 0,
    'SIENG': 0,
    'SIENICKI': 0,
    'SIENKIEWICZ': 0,
    'SIENKNECHT': 0,
    'SIENKO': 0,
    'SIENKOWSKI': 0,
    'SIENS': 0,
    'SIEPERT': 0,
    'SIEPKER': 0,
    'SIEPMANN': 0,
    'SIER': 0,
    'SIERA': 0,
    'SIERACKI': 0,
    'SIERADZKI': 0,
    'SIERAKOWSKI': 0,
    'SIERANT': 0,
    'SIERCHIO': 0,
    'SIERCKS': 0,
    'SIEREN': 0,
    'SIERENS': 0,
    'SIERER': 0,
    'SIEREVELD': 0,
    'SIERING': 0,
    'SIERK': 0,
    'SIERKS': 0,
    'SIERMINSKI': 0,
    'SIERON': 0,
    'SIERRA': 0.4517221908526256,
    'SIERRAS': 0,
    'SIERS': 0,
    'SIERZEGA': 0,
    'SIERZPUTOWSKI': 0,
    'SIES': 0,
    'SIESEL': 0,
    'SIESS': 0,
    'SIETING': 0,
    'SIETSEMA': 0,
    'SIETSMA': 0,
    'SIETZ': 0,
    'SIEV': 0,
    'SIEVE': 0,
    'SIEVEKING': 0,
    'SIEVER': 0,
    'SIEVERDING': 0,
    'SIEVERS': 0,
    'SIEVERT': 0,
    'SIEVERTS': 0,
    'SIEVERTSEN': 0,
    'SIEVING': 0,
    'SIEW': 0,
    'SIEWERS': 0,
    'SIEWERT': 0,
    'SIFERD': 0,
    'SIFERS': 0,
    'SIFF': 0,
    'SIFFERMAN': 0,
    'SIFFORD': 0,
    'SIFONTES': 0,
    'SIFORD': 0,
    'SIFRE': 0,
    'SIFRIT': 0,
    'SIFUENTES': 0,
    'SIFUENTEZ': 0,
    'SIGAFOOS': 0,
    'SIGAFOOSE': 0,
    'SIGAFUS': 0,
    'SIGAL': 0,
    'SIGALA': 0,
    'SIGALAS': 0,
    'SIGARAN': 0,
    'SIGARS': 0,
    'SIGEL': 0,
    'SIGERS': 0,
    'SIGETY': 0,
    'SIGG': 0,
    'SIGGELKOW': 0,
    'SIGGERS': 0,
    'SIGGIA': 0,
    'SIGGINS': 0,
    'SIGH': 0,
    'SIGHTLER': 0,
    'SIGHTS': 0,
    'SIGISMONDI': 0,
    'SIGL': 0,
    'SIGLAR': 0,
    'SIGLE': 0,
    'SIGLER': 0,
    'SIGLEY': 0,
    'SIGLIN': 0,
    'SIGLOW': 0,
    'SIGMAN': 0,
    'SIGMON': 0,
    'SIGMOND': 0,
    'SIGMUND': 0,
    'SIGNA': 0,
    'SIGNAIGO': 0,
    'SIGNAL': 0,
    'SIGNE': 1,
    'SIGNER': 0,
    'SIGNOR': 0,
    'SIGNORE': 0,
    'SIGNORELLI': 0,
    'SIGNORELLO': 0,
    'SIGNORETTI': 0,
    'SIGNORI': 0,
    'SIGNORIELLO': 0,
    'SIGNORILE': 0,
    'SIGNORINI': 0,
    'SIGNORINO': 0,
    'SIGNS': 0,
    'SIGO': 0,
    'SIGONA': 0,
    'SIGOUIN': 0,
    'SIGOURNEY': 0,
    'SIGREST': 0,
    'SIGRID': 1,
    'SIGRIST': 0,
    'SIGSBEE': 0,
    'SIGSBY': 0,
    'SIGSWORTH': 0,
    'SIGUA': 0,
    'SIGUE': 0,
    'SIGUENCIA': 0,
    'SIGUENZA': 0,
    'SIGUR': 0,
    'SIGURDSON': 0,
    'SIGURDSSON': 0,
    'SIGWALT': 0,
    'SIGWART': 0,
    'SIGWORTH': 0,
    'SIH': 0,
    'SIHARATH': 0,
    'SIHAVONG': 0,
    'SIHLER': 0,
    'SIHOTA': 0,
    'SIINO': 0,
    'SIIRA': 0,
    'SIK': 0,
    'SIKA': 0,
    'SIKAND': 0,
    'SIKANDER': 0,
    'SIKDER': 0,
    'SIKES': 0,
    'SIKET': 0,
    'SIKICH': 0,
    'SIKKA': 0,
    'SIKKEMA': 0,
    'SIKKENGA': 0,
    'SIKKILA': 0,
    'SIKKING': 0,
    'SIKKINK': 0,
    'SIKMA': 0,
    'SIKO': 0,
    'SIKON': 0,
    'SIKORA': 0,
    'SIKORSKI': 0,
    'SIKORSKY': 0,
    'SIKORYAK': 0,
    'SIKULA': 0,
    'SIL': 0,
    'SILA': 0,
    'SILACCI': 0,
    'SILAGI': 0,
    'SILAGO': 0,
    'SILAGY': 0,
    'SILAGYI': 0,
    'SILANCE': 0,
    'SILANO': 0,
    'SILAO': 0,
    'SILAR': 0,
    'SILAS': 0.8538899430740038,
    'SILBA': 0,
    'SILBAUGH': 0,
    'SILBER': 0,
    'SILBERBERG': 0,
    'SILBERG': 0,
    'SILBERHORN': 0,
    'SILBERMAN': 0,
    'SILBERMANN': 0,
    'SILBERNAGEL': 0,
    'SILBERSTEIN': 0,
    'SILBERT': 0,
    'SILBIGER': 0,
    'SILBY': 0,
    'SILCHUK': 0,
    'SILCOCK': 0,
    'SILCOTT': 0,
    'SILCOX': 0,
    'SILECCHIA': 0,
    'SILEN': 0,
    'SILENCE': 0,
    'SILEO': 0,
    'SILER': 0,
    'SILERIO': 0,
    'SILES': 0,
    'SILFA': 0,
    'SILFEE': 0,
    'SILFEN': 0,
    'SILFIES': 0,
    'SILGUERO': 0,
    'SILHA': 0,
    'SILHAN': 0,
    'SILHAVY': 0,
    'SILICH': 0,
    'SILIEZAR': 0,
    'SILIGA': 0,
    'SILIN': 0,
    'SILIPO': 0,
    'SILIS': 0,
    'SILK': 0,
    'SILKA': 0,
    'SILKE': 0,
    'SILKER': 0,
    'SILKETT': 0,
    'SILKEY': 0,
    'SILKMAN': 0,
    'SILKNITTER': 0,
    'SILKO': 0,
    'SILKOWSKI': 0,
    'SILKS': 0,
    'SILKWOOD': 0,
    'SILKWORTH': 0,
    'SILL': 0,
    'SILLA': 0,
    'SILLAH': 0,
    'SILLAMAN': 0,
    'SILLANPAA': 0,
    'SILLARS': 0,
    'SILLAS': 0,
    'SILLAVAN': 0,
    'SILLER': 0,
    'SILLERS': 0,
    'SILLERY': 0,
    'SILLETT': 0,
    'SILLETTI': 0,
    'SILLETTO': 0,
    'SILLIK': 0,
    'SILLIMAN': 0,
    'SILLIN': 0,
    'SILLINGS': 0,
    'SILLIVAN': 0,
    'SILLMAN': 0,
    'SILLMON': 0,
    'SILLOWAY': 0,
    'SILLS': 0,
    'SILLYMAN': 0,
    'SILMAN': 0,
    'SILMON': 0,
    'SILO': 0,
    'SILON': 0,
    'SILOS': 0,
    'SILSBEE': 0,
    'SILSBY': 0,
    'SILTALA': 0,
    'SILTANEN': 0,
    'SILTMAN': 0,
    'SILTON': 0,
    'SILUK': 0,
    'SILVA': 0.041008816895632565,
    'SILVAGGIO': 0,
    'SILVAGNI': 0,
    'SILVAGNOLI': 0,
    'SILVAIN': 0,
    'SILVAN': 0,
    'SILVANA': 1,
    'SILVANI': 0,
    'SILVANO': 0,
    'SILVAR': 0,
    'SILVAS': 0,
    'SILVASY': 0,
    'SILVEIRA': 0,
    'SILVEOUS': 0,
    'SILVER': 0,
    'SILVERA': 0,
    'SILVERBERG': 0,
    'SILVERBLATT': 0,
    'SILVERHORN': 0,
    'SILVERI': 0,
    'SILVERIA': 0,
    'SILVERIO': 0,
    'SILVERMAN': 0,
    'SILVERNAGEL': 0,
    'SILVERNAIL': 0,
    'SILVERNALE': 0,
    'SILVERS': 0,
    'SILVERSMITH': 0,
    'SILVERSON': 0,
    'SILVERSTEIN': 0,
    'SILVERSTONE': 0,
    'SILVERT': 0,
    'SILVERTHORN': 0,
    'SILVERTHORNE': 0,
    'SILVERTON': 0,
    'SILVERTOOTH': 0,
    'SILVERWOOD': 0,
    'SILVES': 0,
    'SILVESTER': 0,
    'SILVESTRE': 0,
    'SILVESTRI': 0,
    'SILVESTRINI': 0,
    'SILVESTRO': 0,
    'SILVETTI': 0,
    'SILVEUS': 0,
    'SILVEY': 0,
    'SILVEYRA': 0,
    'SILVI': 0,
    'SILVIA': 0.9351821992905515,
    'SILVIO': 0,
    'SILVIOUS': 0,
    'SILVIS': 0,
    'SILVIUS': 0,
    'SILVUS': 0,
    'SILVY': 0,
    'SILZER': 0,
    'SIM': 0,
    'SIMA': 0.7575757575757576,
    'SIMAC': 0,
    'SIMACEK': 0,
    'SIMAK': 0,
    'SIMAN': 0,
    'SIMANCAS': 0,
    'SIMANDL': 0,
    'SIMANEK': 0,
    'SIMANK': 0,
    'SIMANSKI': 0,
    'SIMANTEL': 0,
    'SIMANTON': 0,
    'SIMANTS': 0,
    'SIMAO': 0,
    'SIMAR': 0,
    'SIMARD': 0,
    'SIMARI': 0,
    'SIMAS': 0,
    'SIMBECK': 0,
    'SIMBOLI': 0,
    'SIMBRO': 0,
    'SIMBULAN': 0,
    'SIMCHAK': 0,
    'SIMCHICK': 0,
    'SIMCIC': 0,
    'SIMCIK': 0,
    'SIMCO': 0,
    'SIMCOCK': 0,
    'SIMCOE': 0,
    'SIMCOX': 0,
    'SIME': 0,
    'SIMECEK': 0,
    'SIMEK': 0,
    'SIMELTON': 0,
    'SIMEN': 0,
    'SIMENDINGER': 0,
    'SIMENSEN': 0,
    'SIMENSON': 0,
    'SIMENTAL': 0,
    'SIMEON': 0,
    'SIMEONA': 0,
    'SIMEONE': 0,
    'SIMEONI': 0,
    'SIMER': 0,
    'SIMERAL': 0,
    'SIMERLY': 0,
    'SIMERMAN': 0,
    'SIMEROTH': 0,
    'SIMERS': 0,
    'SIMERSON': 0,
    'SIMES': 0,
    'SIMET': 0,
    'SIMEUS': 0,
    'SIMI': 0,
    'SIMIC': 0,
    'SIMICH': 0,
    'SIMICICH': 0,
    'SIMIELE': 0,
    'SIMIEN': 0,
    'SIMILA': 0,
    'SIMILE': 0,
    'SIMILIEN': 0,
    'SIMILTON': 0,
    'SIMINGTON': 0,
    'SIMINO': 0,
    'SIMINSKI': 0,
    'SIMION': 0,
    'SIMIONE': 0,
    'SIMIS': 0,
    'SIMISON': 0,
    'SIMISTER': 0,
    'SIMKIN': 0,
    'SIMKINS': 0,
    'SIMKO': 0,
    'SIMKOVICH': 0,
    'SIMKUS': 0,
    'SIMLER': 0,
    'SIMLEY': 0,
    'SIMM': 0,
    'SIMMA': 0,
    'SIMMEL': 0,
    'SIMMELINK': 0,
    'SIMMEN': 0,
    'SIMMENS': 0,
    'SIMMER': 0,
    'SIMMERER': 0,
    'SIMMERING': 0,
    'SIMMERLY': 0,
    'SIMMERMAN': 0,
    'SIMMERMON': 0,
    'SIMMERS': 0,
    'SIMMERSON': 0,
    'SIMMES': 0,
    'SIMMET': 0,
    'SIMMINS': 0,
    'SIMMIONS': 0,
    'SIMMON': 0,
    'SIMMONDS': 0,
    'SIMMONS': 0,
    'SIMMS': 0,
    'SIMNICK': 0,
    'SIMNING': 0,
    'SIMNITT': 0,
    'SIMO': 0,
    'SIMOENS': 0,
    'SIMOES': 0,
    'SIMON': 0.48381094157052473,
    'SIMONA': 1,
    'SIMONAR': 0,
    'SIMONCELLI': 0,
    'SIMONCIC': 0,
    'SIMONCINI': 0,
    'SIMONDS': 0,
    'SIMONE': 0.8517887563884156,
    'SIMONEAU': 0,
    'SIMONEAUX': 0,
    'SIMONEK': 0,
    'SIMONELLI': 0,
    'SIMONES': 0,
    'SIMONET': 0,
    'SIMONETTA': 0,
    'SIMONETTE': 0,
    'SIMONETTI': 0,
    'SIMONI': 0,
    'SIMONIAN': 0,
    'SIMONIC': 0,
    'SIMONICH': 0,
    'SIMONIK': 0,
    'SIMONIN': 0,
    'SIMONINI': 0,
    'SIMONIS': 0,
    'SIMONNE': 1,
    'SIMONO': 0,
    'SIMONOFF': 0,
    'SIMONOVICH': 0,
    'SIMONS': 0,
    'SIMONSEN': 0,
    'SIMONSON': 0,
    'SIMONTON': 0,
    'SIMONY': 0,
    'SIMONYAN': 0,
    'SIMOS': 0,
    'SIMPER': 0,
    'SIMPERS': 0,
    'SIMPKIN': 0,
    'SIMPKINS': 0,
    'SIMPLE': 0,
    'SIMPLER': 0,
    'SIMPLICIANO': 0,
    'SIMPLICIO': 0,
    'SIMPLOT': 0,
    'SIMPSON': 0,
    'SIMRELL': 0,
    'SIMRIL': 0,
    'SIMS': 0,
    'SIMSER': 0,
    'SIMSHAUSER': 0,
    'SIMSON': 0,
    'SIMUEL': 0,
    'SIMULA': 0,
    'SIMUNEK': 0,
    'SIMUNICH': 0,
    'SIMUNOVIC': 0,
    'SIN': 0,
    'SINA': 0.9009009009009009,
    'SINACOLA': 0,
    'SINACORE': 0,
    'SINACORI': 0,
    'SINAGRA': 0,
    'SINAI': 0,
    'SINAK': 0,
    'SINAN': 0,
    'SINANAN': 0,
    'SINANI': 0,
    'SINANIAN': 0,
    'SINANOVIC': 0,
    'SINAPI': 0,
    'SINARD': 0,
    'SINATRA': 0,
    'SINAY': 0,
    'SINCAVAGE': 0,
    'SINCERBEAUX': 0,
    'SINCERE': 0,
    'SINCHAK': 0,
    'SINCHE': 0,
    'SINCHI': 0,
    'SINCLAIR': 0,
    'SINCLAIRE': 0,
    'SINCO': 0,
    'SINCOCK': 0,
    'SINCOX': 0,
    'SINDA': 0,
    'SINDE': 0,
    'SINDEL': 0,
    'SINDELAR': 0,
    'SINDEN': 0,
    'SINDER': 0,
    'SINDERS': 0,
    'SINDHU': 0,
    'SINDI': 0,
    'SINDLE': 0,
    'SINDLEDECKER': 0,
    'SINDLER': 0,
    'SINDLINGER': 0,
    'SINDONE': 0,
    'SINDONI': 0,
    'SINDORF': 0,
    'SINDT': 0,
    'SINDY': 0.966183574879227,
    'SINE': 0,
    'SINEATH': 0,
    'SINEGAL': 0,
    'SINELLI': 0,
    'SINENI': 0,
    'SINER': 0,
    'SINES': 0,
    'SINESI': 0,
    'SINEX': 0,
    'SINEY': 0,
    'SINFIELD': 0,
    'SING': 0,
    'SINGA': 0,
    'SINGAL': 0,
    'SINGEL': 0,
    'SINGELTARY': 0,
    'SINGELTON': 0,
    'SINGELYN': 0,
    'SINGER': 0,
    'SINGERMAN': 0,
    'SINGEWALD': 0,
    'SINGFIELD': 0,
    'SINGH': 0,
    'SINGHAL': 0,
    'SINGHARATH': 0,
    'SINGHAS': 0,
    'SINGLA': 0,
    'SINGLE': 0,
    'SINGLER': 0,
    'SINGLES': 0,
    'SINGLETARY': 0,
    'SINGLETERRY': 0,
    'SINGLETON': 0,
    'SINGLEY': 0,
    'SINGLTON': 0,
    'SINGMAN': 0,
    'SINGMASTER': 0,
    'SINGO': 0,
    'SINGREY': 0,
    'SINGS': 0,
    'SINGSON': 0,
    'SINGSTOCK': 0,
    'SINHA': 0,
    'SINI': 0,
    'SINIARD': 0,
    'SINIAWSKI': 0,
    'SINIBALDI': 0,
    'SINICKI': 0,
    'SINICROPE': 0,
    'SINICROPI': 0,
    'SINIFF': 0,
    'SINIFT': 0,
    'SININGER': 0,
    'SINISCALCHI': 0,
    'SINISGALLI': 0,
    'SINISHTAJ': 0,
    'SINISI': 0,
    'SINISTERRA': 0,
    'SINITIERE': 0,
    'SINK': 0,
    'SINKA': 0,
    'SINKE': 0,
    'SINKER': 0,
    'SINKEVICH': 0,
    'SINKEY': 0,
    'SINKFIELD': 0,
    'SINKHORN': 0,
    'SINKIEWICZ': 0,
    'SINKINSON': 0,
    'SINKLER': 0,
    'SINKO': 0,
    'SINKOVICH': 0,
    'SINKOVITZ': 0,
    'SINKS': 0,
    'SINKULA': 0,
    'SINKULE': 0,
    'SINKUS': 0,
    'SINN': 0,
    'SINNAMON': 0,
    'SINNARD': 0,
    'SINNEMA': 0,
    'SINNEN': 0,
    'SINNER': 0,
    'SINNES': 0,
    'SINNETT': 0,
    'SINNI': 0,
    'SINNING': 0,
    'SINNO': 0,
    'SINNOCK': 0,
    'SINNOTT': 0,
    'SINNWELL': 0,
    'SINO': 0,
    'SINOHUI': 0,
    'SINON': 0,
    'SINOPOLI': 0,
    'SINOR': 0,
    'SINOTTE': 0,
    'SINQUEFIELD': 0,
    'SINRAM': 0,
    'SINS': 0,
    'SINSABAUGH': 0,
    'SINSEL': 0,
    'SINSHEIMER': 0,
    'SINSKI': 0,
    'SINSKY': 0,
    'SINSLEY': 0,
    'SINSON': 0,
    'SINTAS': 0,
    'SINTIC': 0,
    'SINTON': 0,
    'SINYARD': 0,
    'SINZ': 0,
    'SIO': 0,
    'SIOAN': 0,
    'SIOBHAN': 1,
    'SIOK': 0,
    'SION': 0,
    'SIONE': 0,
    'SIONG': 0,
    'SIONS': 0,
    'SIORDIA': 0,
    'SIOSON': 0,
    'SIOW': 0,
    'SIP': 0,
    'SIPALA': 0,
    'SIPE': 0,
    'SIPEK': 0,
    'SIPES': 0,
    'SIPICH': 0,
    'SIPILA': 0,
    'SIPIN': 0,
    'SIPIORA': 0,
    'SIPKA': 0,
    'SIPKO': 0,
    'SIPLE': 0,
    'SIPLER': 0,
    'SIPLES': 0,
    'SIPLEY': 0,
    'SIPLIN': 0,
    'SIPLING': 0,
    'SIPMA': 0,
    'SIPOLA': 0,
    'SIPOS': 0,
    'SIPOWICZ': 0,
    'SIPP': 0,
    'SIPPEL': 0,
    'SIPPER': 0,
    'SIPPERLEY': 0,
    'SIPPIO': 0,
    'SIPPL': 0,
    'SIPPLE': 0,
    'SIPPOLA': 0,
    'SIPPRELL': 0,
    'SIPPS': 0,
    'SIPPY': 0,
    'SIQUEIRA': 0,
    'SIQUEIROS': 0,
    'SIR': 0,
    'SIRA': 0,
    'SIRABELLA': 0,
    'SIRACO': 0,
    'SIRACUSA': 0,
    'SIRACUSE': 0,
    'SIRAGUSA': 0,
    'SIRAJ': 0,
    'SIRAK': 0,
    'SIRARD': 0,
    'SIRATT': 0,
    'SIRAVO': 0,
    'SIRBAUGH': 0,
    'SIRBU': 0,
    'SIRCAR': 0,
    'SIRCHER': 0,
    'SIRCHIA': 0,
    'SIRCY': 0,
    'SIRE': 0,
    'SIRECI': 0,
    'SIREGAR': 0,
    'SIREK': 0,
    'SIREN': 0,
    'SIRENA': 1,
    'SIRENO': 0,
    'SIRES': 0,
    'SIRESS': 0,
    'SIRGO': 0,
    'SIRI': 0,
    'SIRIA': 0,
    'SIRIANI': 0,
    'SIRIANNI': 0,
    'SIRIANO': 0,
    'SIRIAS': 0,
    'SIRICA': 0,
    'SIRICO': 0,
    'SIRIGNANO': 0,
    'SIRIO': 0,
    'SIRK': 0,
    'SIRKEL': 0,
    'SIRKIN': 0,
    'SIRKIS': 0,
    'SIRKO': 0,
    'SIRLEAF': 0,
    'SIRLES': 0,
    'SIRLIN': 0,
    'SIRLS': 0,
    'SIRMAN': 0,
    'SIRMANS': 0,
    'SIRMON': 0,
    'SIRMONS': 0,
    'SIRNA': 0,
    'SIROCHMAN': 0,
    'SIROIS': 0,
    'SIROKY': 0,
    'SIRON': 0,
    'SIRONEN': 0,
    'SIROTA': 0,
    'SIROTKIN': 0,
    'SIROVATKA': 0,
    'SIROVY': 0,
    'SIRRINE': 0,
    'SIRY': 0,
    'SIS': 0,
    'SISAK': 0,
    'SISAVATH': 0,
    'SISAY': 0,
    'SISBARRO': 0,
    'SISCA': 0,
    'SISCHO': 0,
    'SISCO': 0,
    'SISCOE': 0,
    'SISE': 0,
    'SISEL': 0,
    'SISEMORE': 0,
    'SISIC': 0,
    'SISK': 0,
    'SISKA': 0,
    'SISKE': 0,
    'SISKEY': 0,
    'SISKIN': 0,
    'SISKIND': 0,
    'SISKO': 0,
    'SISLER': 0,
    'SISLEY': 0,
    'SISLO': 0,
    'SISNEROS': 0,
    'SISNEROZ': 0,
    'SISNEY': 0,
    'SISO': 0,
    'SISOLAK': 0,
    'SISOMBATH': 0,
    'SISON': 0,
    'SISOUPHANH': 0,
    'SISSECK': 0,
    'SISSEL': 0,
    'SISSELL': 0,
    'SISSELMAN': 0,
    'SISSOKO': 0,
    'SISSOM': 0,
    'SISSON': 0,
    'SISSONS': 0,
    'SISTARE': 0,
    'SISTEK': 0,
    'SISTER': 0,
    'SISTI': 0,
    'SISTO': 0,
    'SISTOS': 0,
    'SISTRUNK': 0,
    'SISUL': 0,
    'SISUNG': 0,
    'SIT': 0,
    'SITA': 0,
    'SITAL': 0,
    'SITAR': 0,
    'SITARAM': 0,
    'SITARAS': 0,
    'SITAREK': 0,
    'SITARSKI': 0,
    'SITARZ': 0,
    'SITCH': 0,
    'SITEK': 0,
    'SITER': 0,
    'SITERLET': 0,
    'SITERS': 0,
    'SITES': 0,
    'SITH': 0,
    'SITKA': 0,
    'SITKIEWICZ': 0,
    'SITKO': 0,
    'SITKOWSKI': 0,
    'SITLER': 0,
    'SITLINGER': 0,
    'SITMAN': 0,
    'SITNIK': 0,
    'SITO': 0,
    'SITOMER': 0,
    'SITRIN': 0,
    'SITT': 0,
    'SITTE': 0,
    'SITTER': 0,
    'SITTERDING': 0,
    'SITTERLE': 0,
    'SITTERLEY': 0,
    'SITTERLY': 0,
    'SITTERSON': 0,
    'SITTIG': 0,
    'SITTINGER': 0,
    'SITTLER': 0,
    'SITTLOH': 0,
    'SITTMAN': 0,
    'SITTNER': 0,
    'SITTO': 0,
    'SITTON': 0,
    'SITTS': 0,
    'SITU': 0,
    'SITZ': 0,
    'SITZBERGER': 0,
    'SITZE': 0,
    'SITZER': 0,
    'SITZES': 0,
    'SITZLER': 0,
    'SITZMAN': 0,
    'SITZMANN': 0,
    'SIU': 0.4166666666666667,
    'SIUDA': 0,
    'SIUDZINSKI': 0,
    'SIUTA': 0,
    'SIV': 0,
    'SIVA': 0,
    'SIVAK': 0,
    'SIVAKUMAR': 0,
    'SIVARAMAN': 0,
    'SIVARD': 0,
    'SIVEC': 0,
    'SIVEK': 0,
    'SIVELL': 0,
    'SIVELLS': 0,
    'SIVELS': 0,
    'SIVER': 0,
    'SIVERAND': 0,
    'SIVERD': 0,
    'SIVERHUS': 0,
    'SIVERIO': 0,
    'SIVERLING': 0,
    'SIVERLY': 0,
    'SIVERS': 0,
    'SIVERSON': 0,
    'SIVERT': 0,
    'SIVERTSEN': 0,
    'SIVERTSON': 0,
    'SIVESIND': 0,
    'SIVIA': 0,
    'SIVIGNY': 0,
    'SIVIK': 0,
    'SIVIL': 0,
    'SIVILAY': 0,
    'SIVILLO': 0,
    'SIVILS': 0,
    'SIVITS': 0,
    'SIVLEY': 0,
    'SIVO': 0,
    'SIVONGXAY': 0,
    'SIVORI': 0,
    'SIVRET': 0,
    'SIVULA': 0,
    'SIVYER': 0,
    'SIWA': 0,
    'SIWAK': 0,
    'SIWEK': 0,
    'SIWICKI': 0,
    'SIWIEC': 0,
    'SIWIK': 0,
    'SIWINSKI': 0,
    'SIWULA': 0,
    'SIWY': 0,
    'SIX': 0,
    'SIXBERRY': 0,
    'SIXBEY': 0,
    'SIXEL': 0,
    'SIXKILLER': 0,
    'SIXSMITH': 0,
    'SIXT': 0,
    'SIXTA': 0.9259259259259258,
    'SIXTO': 0,
    'SIXTOS': 0,
    'SIY': 0,
    'SIZE': 0,
    'SIZELOVE': 0,
    'SIZEMORE': 0,
    'SIZER': 0,
    'SJAARDA': 0,
    'SJERVEN': 0,
    'SJOBERG': 0,
    'SJOBLOM': 0,
    'SJODIN': 0,
    'SJOERDSMA': 0,
    'SJOGREN': 0,
    'SJOHOLM': 0,
    'SJOLANDER': 0,
    'SJOLIN': 0,
    'SJOLUND': 0,
    'SJOQUIST': 0,
    'SJOSTEDT': 0,
    'SJOSTRAND': 0,
    'SJOSTROM': 0,
    'SJURSEN': 0,
    'SKAAR': 0,
    'SKAARE': 0,
    'SKAARUP': 0,
    'SKABELUND': 0,
    'SKABO': 0,
    'SKACH': 0,
    'SKADBERG': 0,
    'SKADSEM': 0,
    'SKAER': 0,
    'SKAF': 0,
    'SKAFF': 0,
    'SKAGEN': 0,
    'SKAGER': 0,
    'SKAGGS': 0,
    'SKAHAN': 0,
    'SKAHILL': 0,
    'SKAIFE': 0,
    'SKAINS': 0,
    'SKAJ': 0,
    'SKAJA': 0,
    'SKAL': 0,
    'SKALA': 0,
    'SKALAK': 0,
    'SKALBERG': 0,
    'SKALECKI': 0,
    'SKALESKI': 0,
    'SKALET': 0,
    'SKALICKY': 0,
    'SKALING': 0,
    'SKALISKY': 0,
    'SKALITZKY': 0,
    'SKALKA': 0,
    'SKALKO': 0,
    'SKALL': 0,
    'SKALLA': 0,
    'SKALSKI': 0,
    'SKALSKY': 0,
    'SKANE': 0,
    'SKANES': 0,
    'SKAPIK': 0,
    'SKAR': 0,
    'SKARBEK': 0,
    'SKARDA': 0,
    'SKARE': 0,
    'SKARET': 0,
    'SKARIA': 0,
    'SKARIAH': 0,
    'SKARIE': 0,
    'SKARIN': 0,
    'SKARKA': 0,
    'SKARKE': 0,
    'SKARO': 0,
    'SKARPHOL': 0,
    'SKARR': 0,
    'SKARSTEN': 0,
    'SKARUPA': 0,
    'SKARVAN': 0,
    'SKARZYNSKI': 0,
    'SKATES': 0,
    'SKATTEBO': 0,
    'SKATTUM': 0,
    'SKAU': 0,
    'SKAUG': 0,
    'SKAUGE': 0,
    'SKAW': 0,
    'SKAWINSKI': 0,
    'SKAWSKI': 0,
    'SKAY': 0,
    'SKEA': 0,
    'SKEAN': 0,
    'SKEANS': 0,
    'SKEBA': 0,
    'SKEDEL': 0,
    'SKEEL': 0,
    'SKEELE': 0,
    'SKEELS': 0,
    'SKEEM': 0,
    'SKEEN': 0,
    'SKEENE': 0,
    'SKEENS': 0,
    'SKEES': 0,
    'SKEET': 0,
    'SKEETE': 0,
    'SKEETER': 0,
    'SKEETERS': 0,
    'SKEETS': 0,
    'SKEFFINGTON': 0,
    'SKEGGS': 0,
    'SKEHAN': 0,
    'SKEIE': 0,
    'SKEITH': 0,
    'SKELDING': 0,
    'SKELDON': 0,
    'SKELLENGER': 0,
    'SKELLETT': 0,
    'SKELLEY': 0,
    'SKELLIE': 0,
    'SKELLINGTON': 0,
    'SKELLY': 0,
    'SKELNIK': 0,
    'SKELTON': 0,
    'SKEMP': 0,
    'SKENANDORE': 0,
    'SKENDER': 0,
    'SKENE': 0,
    'SKENES': 0,
    'SKERIK': 0,
    'SKERL': 0,
    'SKERRETT': 0,
    'SKERRITT': 0,
    'SKERRY': 0,
    'SKERTICH': 0,
    'SKETCH': 0,
    'SKETO': 0,
    'SKEVINGTON': 0,
    'SKEWES': 0,
    'SKEWIS': 0,
    'SKIADAS': 0,
    'SKIBA': 0,
    'SKIBBA': 0,
    'SKIBBE': 0,
    'SKIBICKI': 0,
    'SKIBINSKI': 0,
    'SKIBO': 0,
    'SKIDDS': 0,
    'SKIDGEL': 0,
    'SKIDGELL': 0,
    'SKIDMORE': 0,
    'SKIEF': 0,
    'SKIERA': 0,
    'SKIERKA': 0,
    'SKIERSKI': 0,
    'SKIFF': 0,
    'SKIFFINGTON': 0,
    'SKILES': 0,
    'SKILL': 0,
    'SKILLE': 0,
    'SKILLEN': 0,
    'SKILLERN': 0,
    'SKILLETT': 0,
    'SKILLICORN': 0,
    'SKILLIN': 0,
    'SKILLING': 0,
    'SKILLINGS': 0,
    'SKILLINGSTAD': 0,
    'SKILLINGTON': 0,
    'SKILLMAN': 0,
    'SKILTON': 0,
    'SKIME': 0,
    'SKINAWAY': 0,
    'SKINGER': 0,
    'SKINKIS': 0,
    'SKINKLE': 0,
    'SKINNELL': 0,
    'SKINNER': 0,
    'SKIPP': 0,
    'SKIPPER': 0,
    'SKIPTON': 0,
    'SKIPWITH': 0,
    'SKIPWORTH': 0,
    'SKIRPAN': 0,
    'SKIRVIN': 0,
    'SKITT': 0,
    'SKIVER': 0,
    'SKIVERS': 0,
    'SKIVINGTON': 0,
    'SKJEI': 0,
    'SKLADANY': 0,
    'SKLAR': 0,
    'SKLAROFF': 0,
    'SKLARSKI': 0,
    'SKLARZ': 0,
    'SKLENAR': 0,
    'SKLENICKA': 0,
    'SKLODOWSKI': 0,
    'SKLOSS': 0,
    'SKLUT': 0,
    'SKLUZACEK': 0,
    'SKOBEL': 0,
    'SKOCH': 0,
    'SKOCIK': 0,
    'SKOCZEK': 0,
    'SKOCZEN': 0,
    'SKOCZYLAS': 0,
    'SKODA': 0,
    'SKOFF': 0,
    'SKOG': 0,
    'SKOGEN': 0,
    'SKOGERBOE': 0,
    'SKOGLAND': 0,
    'SKOGLUND': 0,
    'SKOGMAN': 0,
    'SKOGSBERG': 0,
    'SKOGSTAD': 0,
    'SKOIEN': 0,
    'SKOK': 0,
    'SKOKAN': 0,
    'SKOKOS': 0,
    'SKOKOWSKI': 0,
    'SKOLASKI': 0,
    'SKOLD': 0,
    'SKOLFIELD': 0,
    'SKOLNICK': 0,
    'SKOLNIK': 0,
    'SKOLODA': 0,
    'SKOMP': 0,
    'SKOMRA': 0,
    'SKOMSKI': 0,
    'SKON': 0,
    'SKONBERG': 0,
    'SKONECKI': 0,
    'SKONIECZNY': 0,
    'SKOOG': 0,
    'SKOP': 0,
    'SKOPEC': 0,
    'SKOPEK': 0,
    'SKOPP': 0,
    'SKOR': 0,
    'SKORA': 0,
    'SKORCZ': 0,
    'SKORCZEWSKI': 0,
    'SKORHEIM': 0,
    'SKORICH': 0,
    'SKORKA': 0,
    'SKORNIA': 0,
    'SKORNICKA': 0,
    'SKORO': 0,
    'SKORONSKI': 0,
    'SKORSKI': 0,
    'SKORUP': 0,
    'SKORUPA': 0,
    'SKORUPSKI': 0,
    'SKOTNICKI': 0,
    'SKOTZKE': 0,
    'SKOUBY': 0,
    'SKOUG': 0,
    'SKOURAS': 0,
    'SKOUSEN': 0,
    'SKOV': 0,
    'SKOVIRA': 0,
    'SKOVRAN': 0,
    'SKOVRON': 0,
    'SKOW': 0,
    'SKOWRON': 0,
    'SKOWRONEK': 0,
    'SKOWRONSKI': 0,
    'SKOWYRA': 0,
    'SKRABA': 0,
    'SKRABACZ': 0,
    'SKRABAK': 0,
    'SKRABANEK': 0,
    'SKRADSKI': 0,
    'SKRAMSTAD': 0,
    'SKRAPITS': 0,
    'SKRDLANT': 0,
    'SKREDE': 0,
    'SKRINE': 0,
    'SKRIP': 0,
    'SKRIVAN': 0,
    'SKRIVANEK': 0,
    'SKRIVSETH': 0,
    'SKROBOT': 0,
    'SKROCH': 0,
    'SKROCKI': 0,
    'SKRODZKI': 0,
    'SKROK': 0,
    'SKROVE': 0,
    'SKRYPEK': 0,
    'SKRZYCKI': 0,
    'SKRZYNIARZ': 0,
    'SKRZYNSKI': 0,
    'SKRZYPCZAK': 0,
    'SKRZYPEK': 0,
    'SKRZYPIEC': 0,
    'SKUBA': 0,
    'SKUBAL': 0,
    'SKUBE': 0,
    'SKUBIC': 0,
    'SKUBIS': 0,
    'SKUBISZ': 0,
    'SKUCE': 0,
    'SKUDLAREK': 0,
    'SKUFCA': 0,
    'SKULA': 0,
    'SKULL': 0,
    'SKULLY': 0,
    'SKULSKI': 0,
    'SKULSKY': 0,
    'SKULTETY': 0,
    'SKUNDA': 0,
    'SKUPIEN': 0,
    'SKURA': 0,
    'SKURAT': 0,
    'SKURKA': 0,
    'SKURLA': 0,
    'SKURSKI': 0,
    'SKURSKY': 0,
    'SKUSE': 0,
    'SKUTA': 0,
    'SKUTNIK': 0,
    'SKUTT': 0,
    'SKUZA': 0,
    'SKVARLA': 0,
    'SKWARA': 0,
    'SKWAREK': 0,
    'SKWERES': 0,
    'SKWIRA': 0,
    'SKWIRUT': 0,
    'SKY': 0,
    'SKYBERG': 0,
    'SKYE': 0.9433962264150944,
    'SKYERS': 0,
    'SKYES': 0,
    'SKYLAR': 0,
    'SKYLER': 0,
    'SKYLES': 0,
    'SKYM': 0,
    'SKYRM': 0,
    'SLABA': 0,
    'SLABACH': 0,
    'SLABACK': 0,
    'SLABAUGH': 0,
    'SLABE': 0,
    'SLABINSKI': 0,
    'SLABY': 0,
    'SLACHTA': 0,
    'SLACHTER': 0,
    'SLACK': 0,
    'SLACKS': 0,
    'SLACUM': 0,
    'SLADE': 0,
    'SLADEK': 0,
    'SLADEN': 0,
    'SLADER': 0,
    'SLADEWSKI': 0,
    'SLADICK': 0,
    'SLADKY': 0,
    'SLAFF': 0,
    'SLAGA': 0,
    'SLAGEL': 0,
    'SLAGELL': 0,
    'SLAGER': 0,
    'SLAGG': 0,
    'SLAGH': 0,
    'SLAGHT': 0,
    'SLAGLE': 0,
    'SLAGLEY': 0,
    'SLAGOWSKI': 0,
    'SLAGTER': 0,
    'SLAIGHT': 0,
    'SLAIN': 0,
    'SLAIS': 0,
    'SLAK': 0,
    'SLAKER': 0,
    'SLAKEY': 0,
    'SLAMA': 0,
    'SLAMAN': 0,
    'SLAMIN': 0,
    'SLAMKA': 0,
    'SLAMON': 0,
    'SLAN': 0,
    'SLANE': 0,
    'SLANEC': 0,
    'SLANEY': 0,
    'SLANINA': 0,
    'SLANKARD': 0,
    'SLANKER': 0,
    'SLANSKY': 0,
    'SLAPE': 0,
    'SLAPPEY': 0,
    'SLAPPY': 0,
    'SLARK': 0,
    'SLASKI': 0,
    'SLASON': 0,
    'SLASOR': 0,
    'SLATCHER': 0,
    'SLATE': 0,
    'SLATEN': 0,
    'SLATER': 0,
    'SLATES': 0,
    'SLATIN': 0,
    'SLATINSKY': 0,
    'SLATKIN': 0,
    'SLATKY': 0,
    'SLATON': 0,
    'SLATOR': 0,
    'SLATT': 0,
    'SLATTEN': 0,
    'SLATTER': 0,
    'SLATTERY': 0,
    'SLATTON': 0,
    'SLATTUM': 0,
    'SLATZER': 0,
    'SLAUBAUGH': 0,
    'SLAUENWHITE': 0,
    'SLAUGENHAUPT': 0,
    'SLAUGH': 0,
    'SLAUGHENHAUPT': 0,
    'SLAUGHTER': 0,
    'SLAUGHTERBECK': 0,
    'SLAUSON': 0,
    'SLAUTER': 0,
    'SLAVEN': 0,
    'SLAVENS': 0,
    'SLAVER': 0,
    'SLAVEY': 0,
    'SLAVIC': 0,
    'SLAVICEK': 0,
    'SLAVICH': 0,
    'SLAVICK': 0,
    'SLAVIERO': 0,
    'SLAVIK': 0,
    'SLAVIN': 0,
    'SLAVINGS': 0,
    'SLAVINSKI': 0,
    'SLAVINSKY': 0,
    'SLAVISH': 0,
    'SLAVSKY': 0,
    'SLAW': 0,
    'SLAWEK': 0,
    'SLAWINSKI': 0,
    'SLAWSKI': 0,
    'SLAWSON': 0,
    'SLAWTER': 0,
    'SLAY': 0,
    'SLAYBACK': 0,
    'SLAYBAUGH': 0,
    'SLAYDEN': 0,
    'SLAYDON': 0,
    'SLAYMAKER': 0,
    'SLAYMAN': 0,
    'SLAYTER': 0,
    'SLAYTON': 0,
    'SLAZYK': 0,
    'SLEAD': 0,
    'SLEAR': 0,
    'SLEASE': 0,
    'SLEASMAN': 0,
    'SLEATER': 0,
    'SLEBODA': 0,
    'SLEBODNICK': 0,
    'SLEBODNIK': 0,
    'SLECHTA': 0,
    'SLED': 0,
    'SLEDD': 0,
    'SLEDER': 0,
    'SLEDGE': 0,
    'SLEDZ': 0,
    'SLEDZIK': 0,
    'SLEDZINSKI': 0,
    'SLEE': 0,
    'SLEEGER': 0,
    'SLEEK': 0,
    'SLEEM': 0,
    'SLEEMAN': 0,
    'SLEEP': 0,
    'SLEEPER': 0,
    'SLEESMAN': 0,
    'SLEET': 0,
    'SLEETER': 0,
    'SLEETH': 0,
    'SLEEZER': 0,
    'SLEGEL': 0,
    'SLEGER': 0,
    'SLEGERS': 0,
    'SLEICHTER': 0,
    'SLEIGH': 0,
    'SLEIGHER': 0,
    'SLEIGHT': 0,
    'SLEIGHTER': 0,
    'SLEIK': 0,
    'SLEIMAN': 0,
    'SLEISTER': 0,
    'SLEMMER': 0,
    'SLEMMONS': 0,
    'SLEMONS': 0,
    'SLEMP': 0,
    'SLENK': 0,
    'SLENKER': 0,
    'SLENTZ': 0,
    'SLEPIAN': 0,
    'SLEPICKA': 0,
    'SLEPPY': 0,
    'SLEPSKI': 0,
    'SLESINGER': 0,
    'SLESINSKI': 0,
    'SLESSER': 0,
    'SLETTA': 0,
    'SLETTE': 0,
    'SLETTEN': 0,
    'SLETTO': 0,
    'SLEVA': 0,
    'SLEVIN': 0,
    'SLEZAK': 0,
    'SLICE': 0,
    'SLICER': 0,
    'SLICHTER': 0,
    'SLICK': 0,
    'SLICKER': 0,
    'SLIDER': 0,
    'SLIFE': 0,
    'SLIFER': 0,
    'SLIFKA': 0,
    'SLIFKIN': 0,
    'SLIFKO': 0,
    'SLIGAR': 0,
    'SLIGER': 0,
    'SLIGH': 0,
    'SLIGHT': 0,
    'SLIGHTOM': 0,
    'SLIKE': 0,
    'SLIKER': 0,
    'SLIM': 0,
    'SLIMAK': 0,
    'SLIMAN': 0,
    'SLIMICK': 0,
    'SLIMM': 0,
    'SLIMMER': 0,
    'SLIMP': 0,
    'SLIND': 0,
    'SLINDE': 0,
    'SLINEY': 0,
    'SLINGER': 0,
    'SLINGERLAND': 0,
    'SLINGLUFF': 0,
    'SLINGSBY': 0,
    'SLININGER': 0,
    'SLINKARD': 0,
    'SLINKER': 0,
    'SLINKEY': 0,
    'SLINKMAN': 0,
    'SLIPHER': 0,
    'SLIPP': 0,
    'SLIPPY': 0,
    'SLISH': 0,
    'SLISHER': 0,
    'SLISZ': 0,
    'SLITER': 0,
    'SLIVA': 0,
    'SLIVENSKY': 0,
    'SLIVER': 0,
    'SLIVERS': 0,
    'SLIVINSKI': 0,
    'SLIVINSKY': 0,
    'SLIVKA': 0,
    'SLIVKOFF': 0,
    'SLIWA': 0,
    'SLIWICKI': 0,
    'SLIWINSKI': 0,
    'SLIWKA': 0,
    'SLIWOSKI': 0,
    'SLIZ': 0,
    'SLIZEWSKI': 0,
    'SLOAD': 0,
    'SLOAN': 0,
    'SLOANE': 0,
    'SLOAS': 0,
    'SLOAT': 0,
    'SLOATE': 0,
    'SLOBIN': 0,
    'SLOBODA': 0,
    'SLOBODIAN': 0,
    'SLOBODNIK': 0,
    'SLOBODZIAN': 0,
    'SLOCKBOWER': 0,
    'SLOCOMB': 0,
    'SLOCOMBE': 0,
    'SLOCUM': 0,
    'SLOCUMB': 0,
    'SLODERBECK': 0,
    'SLOGAR': 0,
    'SLOGGETT': 0,
    'SLOLEY': 0,
    'SLOMA': 0,
    'SLOMAN': 0,
    'SLOMBA': 0,
    'SLOME': 0,
    'SLOMINSKI': 0,
    'SLOMKA': 0,
    'SLOMKOWSKI': 0,
    'SLOMSKI': 0,
    'SLON': 0,
    'SLONAKER': 0,
    'SLONE': 0,
    'SLONECKER': 0,
    'SLONEKER': 0,
    'SLONIGER': 0,
    'SLONIKER': 0,
    'SLONIM': 0,
    'SLONINA': 0,
    'SLONKA': 0,
    'SLONSKI': 0,
    'SLOOP': 0,
    'SLOPER': 0,
    'SLOPPY': 0,
    'SLOSAR': 0,
    'SLOSBERG': 0,
    'SLOSEK': 0,
    'SLOSKY': 0,
    'SLOSS': 0,
    'SLOSSER': 0,
    'SLOSSON': 0,
    'SLOT': 0,
    'SLOTA': 0,
    'SLOTE': 0,
    'SLOTER': 0,
    'SLOTH': 0,
    'SLOTHOUR': 0,
    'SLOTHOWER': 0,
    'SLOTKIN': 0,
    'SLOTMAN': 0,
    'SLOTNICK': 0,
    'SLOTT': 0,
    'SLOTTA': 0,
    'SLOTTEN': 0,
    'SLOTTER': 0,
    'SLOTTERBACK': 0,
    'SLOTWINSKI': 0,
    'SLOUGH': 0,
    'SLOUP': 0,
    'SLOVACEK': 0,
    'SLOVAK': 0,
    'SLOVE': 0,
    'SLOVENSKY': 0,
    'SLOVER': 0,
    'SLOVES': 0,
    'SLOVICK': 0,
    'SLOVIK': 0,
    'SLOVIN': 0,
    'SLOVINSKI': 0,
    'SLOVINSKY': 0,
    'SLOW': 0,
    'SLOWE': 0,
    'SLOWEY': 0,
    'SLOWIAK': 0,
    'SLOWICK': 0,
    'SLOWIK': 0,
    'SLOWIKOWSKI': 0,
    'SLOWINSKI': 0,
    'SLOYAN': 0,
    'SLOYER': 0,
    'SLUBOWSKI': 0,
    'SLUCHER': 0,
    'SLUCK': 0,
    'SLUDER': 0,
    'SLUGA': 0,
    'SLUIS': 0,
    'SLUITER': 0,
    'SLUKA': 0,
    'SLUNAKER': 0,
    'SLUPE': 0,
    'SLUPSKI': 0,
    'SLUSAR': 0,
    'SLUSARCZYK': 0,
    'SLUSAREK': 0,
    'SLUSARSKI': 0,
    'SLUSARZ': 0,
    'SLUSHER': 0,
    'SLUSS': 0,
    'SLUSSER': 0,
    'SLUTSKAYA': 0,
    'SLUTSKY': 0,
    'SLUTTER': 0,
    'SLUTZ': 0,
    'SLUTZKY': 0,
    'SLUYS': 0,
    'SLUYTER': 0,
    'SLY': 0,
    'SLYCORD': 0,
    'SLYDER': 0,
    'SLYE': 0,
    'SLYFIELD': 0,
    'SLYGH': 0,
    'SLYH': 0,
    'SLYKER': 0,
    'SLYKHUIS': 0,
    'SLYMAN': 0,
    'SLYTER': 0,
    'SLYVIA': 1,
    'SLYWKA': 0,
    'SM': 0,
    'SMABY': 0,
    'SMACK': 0,
    'SMADES': 0,
    'SMAGA': 0,
    'SMAGACZ': 0,
    'SMAGALA': 0,
    'SMAHA': 0,
    'SMAII': 0,
    'SMAIL': 0,
    'SMAILES': 0,
    'SMAISTRLA': 0,
    'SMAJIC': 0,
    'SMAJLOVIC': 0,
    'SMALARZ': 0,
    'SMALDINO': 0,
    'SMALDONE': 0,
    'SMALE': 0,
    'SMALEC': 0,
    'SMALES': 0,
    'SMALL': 0,
    'SMALLACOMBE': 0,
    'SMALLCANYON': 0,
    'SMALLCOMB': 0,
    'SMALLEGAN': 0,
    'SMALLEN': 0,
    'SMALLER': 0,
    'SMALLEY': 0,
    'SMALLIDGE': 0,
    'SMALLIE': 0,
    'SMALLING': 0,
    'SMALLMAN': 0,
    'SMALLRIDGE': 0,
    'SMALLS': 0,
    'SMALLWOOD': 0,
    'SMALLY': 0,
    'SMALT': 0,
    'SMALTZ': 0,
    'SMANIOTTO': 0,
    'SMAR': 0,
    'SMARGIASSI': 0,
    'SMARR': 0,
    'SMARRA': 0,
    'SMARSH': 0,
    'SMART': 0,
    'SMARTNICK': 0,
    'SMARTT': 0,
    'SMARZ': 0,
    'SMASAL': 0,
    'SMASHEY': 0,
    'SMATHERS': 0,
    'SMAW': 0,
    'SMAWLEY': 0,
    'SMAY': 0,
    'SMAYDA': 0,
    'SMAZAL': 0,
    'SMEAD': 0,
    'SMEAL': 0,
    'SMEARMAN': 0,
    'SMEATON': 0,
    'SMEBY': 0,
    'SMECK': 0,
    'SMEDBERG': 0,
    'SMEDES': 0,
    'SMEDILE': 0,
    'SMEDLEY': 0,
    'SMEDRA': 0,
    'SMEDSRUD': 0,
    'SMEDSTAD': 0,
    'SMEE': 0,
    'SMEED': 0,
    'SMEENK': 0,
    'SMEESTER': 0,
    'SMEETS': 0,
    'SMEGAL': 0,
    'SMEGO': 0,
    'SMEIGH': 0,
    'SMEJKAL': 0,
    'SMELA': 0,
    'SMELAND': 0,
    'SMELCER': 0,
    'SMELKER': 0,
    'SMELKO': 0,
    'SMELL': 0,
    'SMELLEY': 0,
    'SMELLIE': 0,
    'SMELSER': 0,
    'SMELT': 0,
    'SMELTER': 0,
    'SMELTZ': 0,
    'SMELTZER': 0,
    'SMENTEK': 0,
    'SMENTKOWSKI': 0,
    'SMERAGLIA': 0,
    'SMERDEL': 0,
    'SMERDON': 0,
    'SMEREK': 0,
    'SMERIGLIO': 0,
    'SMERKER': 0,
    'SMERLING': 0,
    'SMERUD': 0,
    'SMERZ': 0,
    'SMESTAD': 0,
    'SMET': 0,
    'SMETAK': 0,
    'SMETANA': 0,
    'SMETANKA': 0,
    'SMETHERS': 0,
    'SMETHURST': 0,
    'SMETS': 0,
    'SMETTERS': 0,
    'SMETZER': 0,
    'SMI': 0,
    'SMIALEK': 0,
    'SMIAROWSKI': 0,
    'SMICK': 0,
    'SMID': 0,
    'SMIDA': 0,
    'SMIDDY': 0,
    'SMIDT': 0,
    'SMIECHOWSKI': 0,
    'SMIECINSKI': 0,
    'SMIEJA': 0,
    'SMIERCIAK': 0,
    'SMIES': 0,
    'SMIETANA': 0,
    'SMIGA': 0,
    'SMIGEL': 0,
    'SMIGELSKI': 0,
    'SMIGIEL': 0,
    'SMIGIELSKI': 0,
    'SMIKLE': 0,
    'SMILANICH': 0,
    'SMILE': 0,
    'SMILEK': 0,
    'SMILER': 0,
    'SMILES': 0,
    'SMILEY': 0,
    'SMILIE': 0,
    'SMILING': 0,
    'SMILLIE': 0,
    'SMILOWITZ': 0,
    'SMINK': 0,
    'SMINKEY': 0,
    'SMINY': 0,
    'SMIRES': 0,
    'SMIRL': 0,
    'SMIRNOFF': 0,
    'SMIRNOV': 0,
    'SMIRNOVA': 0,
    'SMIROLDO': 0,
    'SMISEK': 0,
    'SMIT': 0,
    'SMITH': 0,
    'SMITHAM': 0,
    'SMITHART': 0,
    'SMITHBACK': 0,
    'SMITHBERG': 0,
    'SMITHBERGER': 0,
    'SMITHBROWN': 0,
    'SMITHBURG': 0,
    'SMITHEE': 0,
    'SMITHEN': 0,
    'SMITHER': 0,
    'SMITHERMAN': 0,
    'SMITHERS': 0,
    'SMITHEY': 0,
    'SMITHGALL': 0,
    'SMITHHART': 0,
    'SMITHHISLER': 0,
    'SMITHIES': 0,
    'SMITHINGELL': 0,
    'SMITHJOHNSON': 0,
    'SMITHJONES': 0,
    'SMITHJUNIOR': 0,
    'SMITHLEE': 0,
    'SMITHLEY': 0,
    'SMITHLINE': 0,
    'SMITHLING': 0,
    'SMITHMIER': 0,
    'SMITHMYER': 0,
    'SMITHPETERS': 0,
    'SMITHSON': 0,
    'SMITHWICK': 0,
    'SMITHWILLIAMS': 0,
    'SMITHYMAN': 0,
    'SMITKA': 0,
    'SMITLEY': 0,
    'SMITS': 0,
    'SMITSON': 0,
    'SMITT': 0,
    'SMITTIE': 0,
    'SMITTLE': 0,
    'SMITTY': 0,
    'SMITZ': 0,
    'SMIZER': 0,
    'SMOAK': 0,
    'SMOCK': 0,
    'SMOCZYNSKI': 0,
    'SMOGER': 0,
    'SMOKE': 0,
    'SMOKER': 0,
    'SMOKES': 0,
    'SMOLA': 0,
    'SMOLAK': 0,
    'SMOLAR': 0,
    'SMOLAREK': 0,
    'SMOLDT': 0,
    'SMOLE': 0,
    'SMOLEK': 0,
    'SMOLEN': 0,
    'SMOLENS': 0,
    'SMOLENSKI': 0,
    'SMOLENSKY': 0,
    'SMOLER': 0,
    'SMOLEY': 0,
    'SMOLIC': 0,
    'SMOLICH': 0,
    'SMOLIK': 0,
    'SMOLIN': 0,
    'SMOLINSKI': 0,
    'SMOLINSKY': 0,
    'SMOLKA': 0,
    'SMOLKO': 0,
    'SMOLL': 0,
    'SMOLLEN': 0,
    'SMOLLER': 0,
    'SMOLLEY': 0,
    'SMOLNIK': 0,
    'SMOLSKI': 0,
    'SMOLSKY': 0,
    'SMOLYAR': 0,
    'SMOODY': 0,
    'SMOOK': 0,
    'SMOOKLER': 0,
    'SMOOT': 0,
    'SMOOTH': 0,
    'SMOOTS': 0,
    'SMOTER': 0,
    'SMOTHERMAN': 0,
    'SMOTHERMON': 0,
    'SMOTHERS': 0,
    'SMOUSE': 0,
    'SMOUT': 0,
    'SMOYER': 0,
    'SMRCINA': 0,
    'SMREKAR': 0,
    'SMRZ': 0,
    'SMTIH': 0,
    'SMUCK': 0,
    'SMUCKER': 0,
    'SMUCKLER': 0,
    'SMUDA': 0,
    'SMUDDE': 0,
    'SMUDE': 0,
    'SMUGALA': 0,
    'SMUIN': 0,
    'SMUK': 0,
    'SMUKLER': 0,
    'SMULL': 0,
    'SMULLEN': 0,
    'SMULLIN': 0,
    'SMULSKI': 0,
    'SMURR': 0,
    'SMURTHWAITE': 0,
    'SMUSZ': 0,
    'SMUTEK': 0,
    'SMUTKO': 0,
    'SMUTNY': 0,
    'SMUTS': 0,
    'SMUTZ': 0,
    'SMUTZER': 0,
    'SMYCZEK': 0,
    'SMYCZYNSKI': 0,
    'SMYDER': 0,
    'SMYER': 0,
    'SMYERS': 0,
    'SMYK': 0,
    'SMYKOWSKI': 0,
    'SMYLES': 0,
    'SMYLIE': 0,
    'SMYLY': 0,
    'SMYRE': 0,
    'SMYRL': 0,
    'SMYRSKI': 0,
    'SMYSER': 0,
    'SMYTH': 0,
    'SMYTHE': 0,
    'SMYTHERS': 0,
    'SNACK': 0,
    'SNADER': 0,
    'SNAER': 0,
    'SNAGG': 0,
    'SNAIR': 0,
    'SNAITH': 0,
    'SNAKENBERG': 0,
    'SNAPE': 0,
    'SNAPP': 0,
    'SNAPPER': 0,
    'SNARE': 0,
    'SNARR': 0,
    'SNARSKI': 0,
    'SNATCHKO': 0,
    'SNAVELY': 0,
    'SNAVLEY': 0,
    'SNAWDER': 0,
    'SNAY': 0,
    'SNAZA': 0,
    'SNEAD': 0,
    'SNEADE': 0,
    'SNEARLY': 0,
    'SNEARY': 0,
    'SNEATH': 0,
    'SNEATHEN': 0,
    'SNEDAKER': 0,
    'SNEDDEN': 0,
    'SNEDDON': 0,
    'SNEDECOR': 0,
    'SNEDEGAR': 0,
    'SNEDEGER': 0,
    'SNEDEKER': 0,
    'SNEDEN': 0,
    'SNEDIGAR': 0,
    'SNEDIKER': 0,
    'SNEE': 0,
    'SNEED': 0,
    'SNEEDEN': 0,
    'SNEEN': 0,
    'SNEERINGER': 0,
    'SNEESBY': 0,
    'SNEEZE': 0,
    'SNEGIREV': 0,
    'SNEIDER': 0,
    'SNELBAKER': 0,
    'SNELGROVE': 0,
    'SNELL': 0,
    'SNELLBAKER': 0,
    'SNELLEN': 0,
    'SNELLENBERGER': 0,
    'SNELLER': 0,
    'SNELLGROVE': 0,
    'SNELLING': 0,
    'SNELLINGS': 0,
    'SNELLMAN': 0,
    'SNELSON': 0,
    'SNERLING': 0,
    'SNETHEN': 0,
    'SNETSINGER': 0,
    'SNEVE': 0,
    'SNEYD': 0,
    'SNIADACH': 0,
    'SNIADECKI': 0,
    'SNICKLES': 0,
    'SNIDARICH': 0,
    'SNIDE': 0,
    'SNIDER': 0,
    'SNIDERMAN': 0,
    'SNIDOW': 0,
    'SNIEGOCKI': 0,
    'SNIEGOWSKI': 0,
    'SNIEZEK': 0,
    'SNIFF': 0,
    'SNIFFEN': 0,
    'SNIFFIN': 0,
    'SNIPE': 0,
    'SNIPES': 0,
    'SNIPP': 0,
    'SNITCHLER': 0,
    'SNITKER': 0,
    'SNITKIN': 0,
    'SNITKO': 0,
    'SNITZER': 0,
    'SNIVELY': 0,
    'SNIZEK': 0,
    'SNOBERGER': 0,
    'SNOCK': 0,
    'SNODDERLY': 0,
    'SNODDY': 0,
    'SNODE': 0,
    'SNODERLY': 0,
    'SNODGRASS': 0,
    'SNODGRESS': 0,
    'SNODY': 0,
    'SNOE': 0,
    'SNOEBERGER': 0,
    'SNOEYINK': 0,
    'SNOKE': 0,
    'SNOOK': 0,
    'SNOOKS': 0,
    'SNOOTS': 0,
    'SNOOZY': 0,
    'SNOPEK': 0,
    'SNOPKOWSKI': 0,
    'SNOREK': 0,
    'SNORTON': 0,
    'SNOUFFER': 0,
    'SNOVER': 0,
    'SNOW': 0,
    'SNOWBALL': 0,
    'SNOWBARGER': 0,
    'SNOWBERGER': 0,
    'SNOWDEN': 0,
    'SNOWDER': 0,
    'SNOWDON': 0,
    'SNOWDY': 0,
    'SNOWMAN': 0,
    'SNOWTON': 0,
    'SNUFFER': 0,
    'SNUGGS': 0,
    'SNURE': 0,
    'SNURR': 0,
    'SNYDER': 0,
    'SNYDERMAN': 0,
    'SNYDERS': 0,
    'SNYPE': 0,
    'SO': 0.46403712296983757,
    'SOAP': 0,
    'SOAPE': 0,
    'SOAPER': 0,
    'SOAPES': 0,
    'SOAR': 0,
    'SOARD': 0,
    'SOARE': 0,
    'SOARES': 0,
    'SOAT': 0,
    'SOAVE': 0,
    'SOBA': 0,
    'SOBALVARRO': 0,
    'SOBANIA': 0,
    'SOBANSKI': 0,
    'SOBARZO': 0,
    'SOBASKI': 0,
    'SOBBA': 0,
    'SOBCZAK': 0,
    'SOBCZYK': 0,
    'SOBCZYNSKI': 0,
    'SOBECK': 0,
    'SOBECKI': 0,
    'SOBEK': 0,
    'SOBEL': 0,
    'SOBELMAN': 0,
    'SOBER': 0,
    'SOBERAL': 0,
    'SOBERANES': 0,
    'SOBERANIS': 0,
    'SOBERANO': 0,
    'SOBERG': 0,
    'SOBERON': 0,
    'SOBERS': 0,
    'SOBESKI': 0,
    'SOBEY': 0,
    'SOBH': 0,
    'SOBHANI': 0,
    'SOBIE': 0,
    'SOBIECH': 0,
    'SOBIECK': 0,
    'SOBIERAJ': 0,
    'SOBIERAJSKI': 0,
    'SOBIERALSKI': 0,
    'SOBIESKI': 0,
    'SOBILO': 0,
    'SOBIN': 0,
    'SOBKOWIAK': 0,
    'SOBKOWICZ': 0,
    'SOBLE': 0,
    'SOBLESKI': 0,
    'SOBO': 0,
    'SOBOCINSKI': 0,
    'SOBOL': 0,
    'SOBOLAK': 0,
    'SOBOLESKI': 0,
    'SOBOLEV': 0,
    'SOBOLEWSKI': 0,
    'SOBOLIK': 0,
    'SOBON': 0,
    'SOBOSLAY': 0,
    'SOBOTA': 0,
    'SOBOTIK': 0,
    'SOBOTKA': 0,
    'SOBOTTA': 0,
    'SOBOTTKA': 0,
    'SOBRADO': 0,
    'SOBRAL': 0,
    'SOBREPENA': 0,
    'SOBRERO': 0,
    'SOBREVILLA': 0,
    'SOBRINO': 0,
    'SOBUS': 0,
    'SOBY': 0,
    'SOC': 0,
    'SOCA': 0,
    'SOCARRAS': 0,
    'SOCASH': 0,
    'SOCCI': 0,
    'SOCCIO': 0,
    'SOCH': 0,
    'SOCHA': 0,
    'SOCHACKI': 0,
    'SOCHAN': 0,
    'SOCHER': 0,
    'SOCHIA': 0,
    'SOCHOCKI': 0,
    'SOCHOR': 0,
    'SOCIA': 0,
    'SOCIAS': 0,
    'SOCIE': 0,
    'SOCK': 0,
    'SOCKEL': 0,
    'SOCKEY': 0,
    'SOCKMAN': 0,
    'SOCKNESS': 0,
    'SOCKO': 0,
    'SOCKOL': 0,
    'SOCKRIDER': 0,
    'SOCKRITER': 0,
    'SOCKS': 0,
    'SOCKWELL': 0,
    'SOCOL': 0,
    'SOCORRO': 0.9876543209876544,
    'SOCRATES': 0,
    'SOCZKA': 0,
    'SODA': 0,
    'SODANO': 0,
    'SODARO': 0,
    'SODD': 0,
    'SODDERS': 0,
    'SODDY': 0,
    'SODE': 0,
    'SODEK': 0,
    'SODEMAN': 0,
    'SODEMANN': 0,
    'SODEN': 0,
    'SODER': 0,
    'SODERBECK': 0,
    'SODERBERG': 0,
    'SODERBLOM': 0,
    'SODERGREN': 0,
    'SODERHOLM': 0,
    'SODERLIND': 0,
    'SODERLING': 0,
    'SODERLUND': 0,
    'SODERMAN': 0,
    'SODERQUIST': 0,
    'SODERS': 0,
    'SODERSTROM': 0,
    'SODHI': 0,
    'SODINI': 0,
    'SODL': 0,
    'SODOLAK': 0,
    'SODOMA': 0,
    'SODORFF': 0,
    'SODOWSKY': 0,
    'SODT': 0,
    'SOE': 0,
    'SOEBBING': 0,
    'SOECHTING': 0,
    'SOEDER': 0,
    'SOEHL': 0,
    'SOEHNER': 0,
    'SOEHNGEN': 0,
    'SOEHNLEIN': 0,
    'SOEHNLEN': 0,
    'SOEHREN': 0,
    'SOELBERG': 0,
    'SOELL': 0,
    'SOELLNER': 0,
    'SOELTER': 0,
    'SOENDKER': 0,
    'SOENEN': 0,
    'SOENKSEN': 0,
    'SOENS': 0,
    'SOERENS': 0,
    'SOERGEL': 0,
    'SOESBE': 0,
    'SOEST': 0,
    'SOETAERT': 0,
    'SOETE': 0,
    'SOETH': 0,
    'SOEUN': 0,
    'SOEUNG': 0,
    'SOEUR': 0,
    'SOFER': 0,
    'SOFFA': 0,
    'SOFFE': 0,
    'SOFFEL': 0,
    'SOFFER': 0,
    'SOFGE': 0,
    'SOFIA': 0.9745127436281859,
    'SOFIE': 0,
    'SOFIELD': 0,
    'SOFIO': 0,
    'SOFKA': 0,
    'SOFO': 0,
    'SOFRANKO': 0,
    'SOFTIC': 0,
    'SOFTLEY': 0,
    'SOGA': 0,
    'SOGARD': 0,
    'SOGGE': 0,
    'SOGHOMONIAN': 0,
    'SOGN': 0,
    'SOH': 0,
    'SOHA': 0,
    'SOHAIL': 0,
    'SOHAL': 0,
    'SOHAN': 0,
    'SOHI': 0,
    'SOHL': 0,
    'SOHLER': 0,
    'SOHM': 0,
    'SOHMER': 0,
    'SOHN': 0,
    'SOHNS': 0,
    'SOHOLT': 0,
    'SOHR': 0,
    'SOHRABI': 0,
    'SOHRE': 0,
    'SOI': 0,
    'SOICH': 0,
    'SOIFER': 0,
    'SOIGNET': 0,
    'SOIGNIER': 0,
    'SOIK': 0,
    'SOIKA': 0,
    'SOIKE': 0,
    'SOILA': 1,
    'SOILEAU': 0,
    'SOINE': 0,
    'SOINI': 0,
    'SOISETH': 0,
    'SOISSON': 0,
    'SOISTMAN': 0,
    'SOITO': 0,
    'SOJA': 0,
    'SOJDA': 0,
    'SOJKA': 0,
    'SOJO': 0,
    'SOJOURNER': 0,
    'SOK': 0,
    'SOKAL': 0,
    'SOKALSKI': 0,
    'SOKE': 0,
    'SOKEL': 0,
    'SOKIRA': 0,
    'SOKOL': 0,
    'SOKOLA': 0,
    'SOKOLICH': 0,
    'SOKOLIK': 0,
    'SOKOLIS': 0,
    'SOKOLL': 0,
    'SOKOLNICKI': 0,
    'SOKOLOFF': 0,
    'SOKOLOSKI': 0,
    'SOKOLOSKY': 0,
    'SOKOLOV': 0,
    'SOKOLOVA': 0,
    'SOKOLOVSKY': 0,
    'SOKOLOW': 0,
    'SOKOLOWSKI': 0,
    'SOKOLOWSKY': 0,
    'SOKOLSKI': 0,
    'SOKOLSKY': 0,
    'SOKUP': 0,
    'SOL': 0.9523809523809524,
    'SOLA': 0,
    'SOLAAS': 0,
    'SOLACE': 0,
    'SOLACHE': 0,
    'SOLACK': 0,
    'SOLADA': 0,
    'SOLAIMAN': 0,
    'SOLAK': 0,
    'SOLAKIAN': 0,
    'SOLAN': 0,
    'SOLANA': 0,
    'SOLAND': 0,
    'SOLANDER': 0,
    'SOLANGE': 1,
    'SOLANKI': 0,
    'SOLANO': 0,
    'SOLAR': 0,
    'SOLARCZYK': 0,
    'SOLAREK': 0,
    'SOLARES': 0,
    'SOLAREZ': 0,
    'SOLARI': 0,
    'SOLARIO': 0,
    'SOLARSKI': 0,
    'SOLARTE': 0,
    'SOLARZ': 0,
    'SOLAS': 0,
    'SOLAZZO': 0,
    'SOLBACH': 0,
    'SOLBERG': 0,
    'SOLBRIG': 0,
    'SOLCHENBERGER': 0,
    'SOLDAN': 0,
    'SOLDANI': 0,
    'SOLDANO': 0,
    'SOLDAT': 0,
    'SOLDATI': 0,
    'SOLDAVINI': 0,
    'SOLDEVILLA': 0,
    'SOLDI': 0,
    'SOLDNER': 0,
    'SOLDO': 0,
    'SOLDWISCH': 0,
    'SOLE': 0,
    'SOLEAU': 0,
    'SOLECKI': 0,
    'SOLEDAD': 0.9776536312849162,
    'SOLEE': 0,
    'SOLEIMANI': 0,
    'SOLEK': 0,
    'SOLEM': 0,
    'SOLEMAN': 0,
    'SOLENBERGER': 0,
    'SOLENSKY': 0,
    'SOLER': 0,
    'SOLERA': 0,
    'SOLERO': 0,
    'SOLES': 0,
    'SOLESBEE': 0,
    'SOLESKY': 0,
    'SOLET': 0,
    'SOLETA': 0,
    'SOLEY': 0,
    'SOLEYMANI': 0,
    'SOLEYN': 0,
    'SOLFEST': 0,
    'SOLGA': 0,
    'SOLGOT': 0,
    'SOLHEID': 0,
    'SOLHEIM': 0,
    'SOLI': 0,
    'SOLIC': 0,
    'SOLICE': 0,
    'SOLICH': 0,
    'SOLID': 0,
    'SOLIDA': 0,
    'SOLIDAY': 0,
    'SOLIDUM': 0,
    'SOLIE': 0,
    'SOLIEN': 0,
    'SOLIMAN': 0,
    'SOLIMANDO': 0,
    'SOLIMINE': 0,
    'SOLIMINI': 0,
    'SOLIN': 0,
    'SOLINA': 0,
    'SOLINGER': 0,
    'SOLINSKI': 0,
    'SOLINSKY': 0,
    'SOLIS': 0,
    'SOLITAIRE': 0,
    'SOLITARIO': 0,
    'SOLITO': 0,
    'SOLITRO': 0,
    'SOLIVAN': 0,
    'SOLIVEN': 0,
    'SOLIWODA': 0,
    'SOLIZ': 0,
    'SOLKA': 0,
    'SOLKO': 0,
    'SOLL': 0,
    'SOLLA': 0,
    'SOLLAMI': 0,
    'SOLLARS': 0,
    'SOLLAZZO': 0,
    'SOLLBERGER': 0,
    'SOLLE': 0,
    'SOLLECITO': 0,
    'SOLLENBERGER': 0,
    'SOLLER': 0,
    'SOLLERS': 0,
    'SOLLEY': 0,
    'SOLLID': 0,
    'SOLLIDAY': 0,
    'SOLLIE': 0,
    'SOLLINGER': 0,
    'SOLLIS': 0,
    'SOLLITTO': 0,
    'SOLLMAN': 0,
    'SOLLMANN': 0,
    'SOLLOCK': 0,
    'SOLLOM': 0,
    'SOLLOWAY': 0,
    'SOLLY': 0,
    'SOLMAN': 0,
    'SOLMON': 0,
    'SOLMONSON': 0,
    'SOLMS': 0,
    'SOLNER': 0,
    'SOLNICK': 0,
    'SOLO': 0,
    'SOLOFF': 0,
    'SOLOM': 0,
    'SOLOMAN': 0,
    'SOLOMITA': 0,
    'SOLOMITO': 0,
    'SOLOMON': 0.45013850415512463,
    'SOLOMONA': 0,
    'SOLOMONS': 0,
    'SOLOMONSON': 0,
    'SOLOMOS': 0,
    'SOLON': 0,
    'SOLORIO': 0,
    'SOLORSANO': 0,
    'SOLORZA': 0,
    'SOLORZANO': 0,
    'SOLOSKI': 0,
    'SOLOSKY': 0,
    'SOLOVEY': 0,
    'SOLOVYEV': 0,
    'SOLOW': 0,
    'SOLOWAY': 0,
    'SOLOWEY': 0,
    'SOLSKI': 0,
    'SOLSKY': 0,
    'SOLSTAD': 0,
    'SOLT': 0,
    'SOLTAN': 0,
    'SOLTANI': 0,
    'SOLTAU': 0,
    'SOLTER': 0,
    'SOLTERO': 0,
    'SOLTES': 0,
    'SOLTESZ': 0,
    'SOLTIS': 0,
    'SOLTOW': 0,
    'SOLTREN': 0,
    'SOLTWEDEL': 0,
    'SOLTYS': 0,
    'SOLTYSIAK': 0,
    'SOLTYSIK': 0,
    'SOLTZ': 0,
    'SOLUM': 0,
    'SOLURI': 0,
    'SOLUS': 0,
    'SOLVANG': 0,
    'SOLVERSON': 0,
    'SOLVIE': 0,
    'SOLWAY': 0,
    'SOM': 0,
    'SOMA': 0,
    'SOMAN': 0,
    'SOMANI': 0,
    'SOMAR': 0,
    'SOMARRIBA': 0,
    'SOMASUNDARAM': 0,
    'SOMBERG': 0,
    'SOMBKE': 0,
    'SOMEILLAN': 0,
    'SOMER': 0.8849557522123894,
    'SOMERA': 0,
    'SOMERFIELD': 0,
    'SOMERHALDER': 0,
    'SOMERLOTT': 0,
    'SOMERO': 0,
    'SOMERS': 0,
    'SOMERSALL': 0,
    'SOMERSET': 0,
    'SOMERSTEIN': 0,
    'SOMERVELL': 0,
    'SOMERVILLE': 0,
    'SOMES': 0,
    'SOMICH': 0,
    'SOMMA': 0,
    'SOMMARS': 0,
    'SOMMER': 0.3169572107765452,
    'SOMMERER': 0,
    'SOMMERFELD': 0,
    'SOMMERFELDT': 0,
    'SOMMERFELT': 0,
    'SOMMERFIELD': 0,
    'SOMMERHAUSER': 0,
    'SOMMERKAMP': 0,
    'SOMMERS': 0,
    'SOMMERVILLE': 0,
    'SOMMERVOLD': 0,
    'SOMMESE': 0,
    'SOMMO': 0,
    'SOMO': 0,
    'SOMOANO': 0,
    'SOMODI': 0,
    'SOMOGYI': 0,
    'SOMORA': 0,
    'SOMOZA': 0,
    'SOMPPI': 0,
    'SOMRAK': 0,
    'SOMSANITH': 0,
    'SOMSEL': 0,
    'SOMSEN': 0,
    'SOMWARU': 0,
    'SON': 0.8279124778237729,
    'SONA': 0.9090909090909091,
    'SONBERG': 0,
    'SONCRANT': 0,
    'SONDAG': 0,
    'SONDAY': 0,
    'SONDEJ': 0,
    'SONDER': 0,
    'SONDEREGGER': 0,
    'SONDERGAARD': 0,
    'SONDERGARD': 0,
    'SONDERGELD': 0,
    'SONDERMAN': 0,
    'SONDERMANN': 0,
    'SONDERS': 0,
    'SONDEY': 0,
    'SONDGEROTH': 0,
    'SONDHI': 0,
    'SONDRA': 1,
    'SONDREAL': 0,
    'SONDRINI': 0,
    'SONDROL': 0,
    'SONDRUP': 0,
    'SONE': 0,
    'SONENBERG': 0,
    'SONERA': 0,
    'SONES': 0,
    'SONESON': 0,
    'SONG': 0.24242424242424246,
    'SONGCO': 0,
    'SONGE': 0,
    'SONGER': 0,
    'SONGSTAD': 0,
    'SONGSTER': 0,
    'SONGY': 0,
    'SONI': 0,
    'SONIA': 0.9979454065159964,
    'SONIAT': 0,
    'SONIER': 0,
    'SONIFRANK': 0,
    'SONJA': 1,
    'SONJU': 0,
    'SONKA': 0,
    'SONKE': 0,
    'SONKIN': 0,
    'SONKSEN': 0,
    'SONMEZ': 0,
    'SONN': 0,
    'SONNABEND': 0,
    'SONNE': 0,
    'SONNEBORN': 0,
    'SONNEFELD': 0,
    'SONNEK': 0,
    'SONNEMAN': 0,
    'SONNEMANN': 0,
    'SONNEN': 0,
    'SONNENBERG': 0,
    'SONNENBURG': 0,
    'SONNENFELD': 0,
    'SONNENSCHEIN': 0,
    'SONNENTAG': 0,
    'SONNER': 0,
    'SONNETT': 0,
    'SONNEVILLE': 0,
    'SONNEY': 0,
    'SONNICHSEN': 0,
    'SONNIE': 0,
    'SONNIER': 0,
    'SONNLEITNER': 0,
    'SONNTAG': 0,
    'SONNY': 0.9913258983890954,
    'SONODA': 0,
    'SONON': 0,
    'SONORA': 0,
    'SONS': 0,
    'SONSALLA': 0,
    'SONSINI': 0,
    'SONSON': 0,
    'SONSTEGARD': 0,
    'SONSTENG': 0,
    'SONTAG': 0,
    'SONTAY': 0,
    'SONTHEIMER': 0,
    'SONY': 0,
    'SONYA': 1,
    'SONZA': 0,
    'SONZOGNI': 0,
    'SOO': 0.8333333333333334,
    'SOOD': 0,
    'SOODSMA': 0,
    'SOOFI': 0,
    'SOOGRIM': 0,
    'SOOHOO': 0,
    'SOOK': 0.9478672985781991,
    'SOOKDEO': 0,
    'SOOKHOO': 0,
    'SOOKLAL': 0,
    'SOOKNANAN': 0,
    'SOOKOO': 0,
    'SOOKRAJ': 0,
    'SOOKRAM': 0,
    'SOOMRO': 0,
    'SOON': 0.9389671361502347,
    'SOONG': 0,
    'SOOS': 0,
    'SOOTER': 0,
    'SOOTS': 0,
    'SOOY': 0,
    'SOP': 0,
    'SOPA': 0,
    'SOPATA': 0,
    'SOPCAK': 0,
    'SOPCHAK': 0,
    'SOPCZAK': 0,
    'SOPEL': 0,
    'SOPER': 0,
    'SOPHA': 0,
    'SOPHER': 0,
    'SOPHIA': 0.9984399375975038,
    'SOPHIE': 0.9982788296041307,
    'SOPHUS': 0,
    'SOPHY': 0,
    'SOPKO': 0,
    'SOPOCI': 0,
    'SOPP': 0,
    'SOPPE': 0,
    'SOPPELAND': 0,
    'SOPRANO': 0,
    'SOQUI': 0,
    'SOR': 0,
    'SORA': 0,
    'SORACCO': 0,
    'SORACE': 0,
    'SORAGHAN': 0,
    'SORAH': 0,
    'SORAN': 0,
    'SORANNO': 0,
    'SORANO': 0,
    'SORAPURU': 0,
    'SORATHIA': 0,
    'SORAYA': 1,
    'SORBARA': 0,
    'SORBEL': 0,
    'SORBELLO': 0,
    'SORBER': 0,
    'SORBERA': 0,
    'SORBO': 0,
    'SORBY': 0,
    'SORCE': 0,
    'SORCI': 0,
    'SORDAHL': 0,
    'SORDELET': 0,
    'SORDELLO': 0,
    'SORDEN': 0,
    'SORDI': 0,
    'SORDIA': 0,
    'SORDILLO': 0,
    'SORDO': 0,
    'SORDYL': 0,
    'SOREANO': 0,
    'SOREL': 0,
    'SORELL': 0,
    'SORELLE': 0,
    'SOREM': 0,
    'SOREN': 0,
    'SORENSEN': 0,
    'SORENSON': 0,
    'SORENTINO': 0,
    'SOREY': 0,
    'SORG': 0,
    'SORGATZ': 0,
    'SORGE': 0,
    'SORGEN': 0,
    'SORGENFREI': 0,
    'SORGER': 0,
    'SORGI': 0,
    'SORI': 0,
    'SORIA': 0,
    'SORIAL': 0,
    'SORIANO': 0,
    'SORICE': 0,
    'SORICELLI': 0,
    'SORICH': 0,
    'SORIERO': 0,
    'SORIN': 0,
    'SORINA': 0,
    'SORINO': 0,
    'SORK': 0,
    'SORKIN': 0,
    'SORKNESS': 0,
    'SORLEY': 0,
    'SORLIE': 0,
    'SORLIEN': 0,
    'SORMAN': 0,
    'SORN': 0,
    'SORNBERGER': 0,
    'SORNSON': 0,
    'SORO': 0,
    'SOROKA': 0,
    'SOROKIN': 0,
    'SOROKO': 0,
    'SOROLA': 0,
    'SORONDO': 0,
    'SORONEN': 0,
    'SOROS': 0,
    'SORREL': 0,
    'SORRELL': 0,
    'SORRELLS': 0,
    'SORRELS': 0,
    'SORRENTI': 0,
    'SORRENTINO': 0,
    'SORRENTO': 0,
    'SORRICK': 0,
    'SORROW': 0,
    'SORROWS': 0,
    'SORSBY': 0,
    'SORSCHER': 0,
    'SORSEN': 0,
    'SORTEBERG': 0,
    'SORTER': 0,
    'SORTINO': 0,
    'SORTLAND': 0,
    'SORTMAN': 0,
    'SORTO': 0,
    'SORTOR': 0,
    'SORTORE': 0,
    'SORUM': 0,
    'SORVARI': 0,
    'SORVILLO': 0,
    'SORY': 0,
    'SORZANO': 0,
    'SOS': 0,
    'SOSA': 0,
    'SOSALLA': 0,
    'SOSBE': 0,
    'SOSBEE': 0,
    'SOSBY': 0,
    'SOSCIA': 0,
    'SOSEBEE': 0,
    'SOSENKO': 0,
    'SOSH': 0,
    'SOSIN': 0,
    'SOSINSKI': 0,
    'SOSINSKY': 0,
    'SOSKA': 0,
    'SOSKIN': 0,
    'SOSKO': 0,
    'SOSNA': 0,
    'SOSNICK': 0,
    'SOSNICKI': 0,
    'SOSNOSKI': 0,
    'SOSNOW': 0,
    'SOSNOWSKI': 0,
    'SOSO': 0,
    'SOSS': 0,
    'SOSSA': 0,
    'SOSSAMAN': 0,
    'SOSSAMON': 0,
    'SOSSI': 0,
    'SOSSONG': 0,
    'SOSTAK': 0,
    'SOSTARICH': 0,
    'SOSTENES': 0,
    'SOSTER': 0,
    'SOSTRE': 0,
    'SOT': 0,
    'SOTA': 0,
    'SOTACK': 0,
    'SOTAK': 0,
    'SOTELLO': 0,
    'SOTELO': 0,
    'SOTER': 0,
    'SOTERO': 0,
    'SOTH': 0,
    'SOTHEN': 0,
    'SOTHERDEN': 0,
    'SOTHERLAND': 0,
    'SOTILE': 0,
    'SOTILLO': 0,
    'SOTIR': 0,
    'SOTIRIOU': 0,
    'SOTIROPOULOS': 0,
    'SOTKA': 0,
    'SOTO': 0,
    'SOTOLONGO': 0,
    'SOTOMAYOR': 0,
    'SOTOS': 0,
    'SOTT': 0,
    'SOTTILE': 0,
    'SOTTO': 0,
    'SOTTOSANTI': 0,
    'SOTUYO': 0,
    'SOU': 0,
    'SOUBA': 0,
    'SOUBLET': 0,
    'SOUCEK': 0,
    'SOUCHEK': 0,
    'SOUCHET': 0,
    'SOUCIE': 0,
    'SOUCIER': 0,
    'SOUCY': 0,
    'SOUD': 0,
    'SOUDELIER': 0,
    'SOUDEN': 0,
    'SOUDER': 0,
    'SOUDERS': 0,
    'SOUERS': 0,
    'SOUFFRANT': 0,
    'SOUFFRONT': 0,
    'SOUHRADA': 0,
    'SOUKUP': 0,
    'SOUL': 0,
    'SOULARD': 0,
    'SOULAS': 0,
    'SOULE': 0,
    'SOULEK': 0,
    'SOULEN': 0,
    'SOULES': 0,
    'SOULIA': 0,
    'SOULIER': 0,
    'SOULIERE': 0,
    'SOULIOTIS': 0,
    'SOULIS': 0,
    'SOULLIER': 0,
    'SOULLIERE': 0,
    'SOULSBY': 0,
    'SOULT': 0,
    'SOUMPHOLPHAKDY': 0,
    'SOUN': 0,
    'SOUNDARA': 0,
    'SOUNDARARAJAN': 0,
    'SOUNG': 0,
    'SOUPIR': 0,
    'SOUR': 0,
    'SOURBEER': 0,
    'SOURI': 0,
    'SOURIS': 0,
    'SOURIVONG': 0,
    'SOURIYAVONG': 0,
    'SOURS': 0,
    'SOURWINE': 0,
    'SOUS': 0,
    'SOUSA': 0,
    'SOUSEK': 0,
    'SOUSER': 0,
    'SOUSIE': 0,
    'SOUSIS': 0,
    'SOUSLEY': 0,
    'SOUTAR': 0,
    'SOUTER': 0,
    'SOUTH': 0,
    'SOUTHALL': 0,
    'SOUTHAM': 0,
    'SOUTHAMMAVONG': 0,
    'SOUTHARD': 0,
    'SOUTHARDS': 0,
    'SOUTHCOTT': 0,
    'SOUTHER': 0,
    'SOUTHERLAND': 0,
    'SOUTHERLIN': 0,
    'SOUTHERLY': 0,
    'SOUTHERN': 0,
    'SOUTHERS': 0,
    'SOUTHERTON': 0,
    'SOUTHEY': 0,
    'SOUTHGATE': 0,
    'SOUTHLAND': 0,
    'SOUTHMAYD': 0,
    'SOUTHWARD': 0,
    'SOUTHWELL': 0,
    'SOUTHWICK': 0,
    'SOUTHWOOD': 0,
    'SOUTHWORTH': 0,
    'SOUTO': 0,
    'SOUTTER': 0,
    'SOUTULLO': 0,
    'SOUVA': 0,
    'SOUVANNARATH': 0,
    'SOUVANNASANE': 0,
    'SOUVANNAVONG': 0,
    'SOUVENIR': 0,
    'SOUZA': 0,
    'SOVA': 0,
    'SOVAK': 0,
    'SOVEL': 0,
    'SOVELL': 0,
    'SOVEREIGN': 0,
    'SOVERN': 0,
    'SOVERNS': 0,
    'SOVEY': 0,
    'SOVIA': 0,
    'SOVICH': 0,
    'SOVIE': 0,
    'SOVIERO': 0,
    'SOVIK': 0,
    'SOVINE': 0,
    'SOVINSKI': 0,
    'SOVINSKY': 0,
    'SOVIS': 0,
    'SOVOCOOL': 0,
    'SOW': 0,
    'SOWA': 0,
    'SOWADA': 0,
    'SOWAH': 0,
    'SOWARD': 0,
    'SOWARDS': 0,
    'SOWASH': 0,
    'SOWDEN': 0,
    'SOWDER': 0,
    'SOWDERS': 0,
    'SOWE': 0,
    'SOWELL': 0,
    'SOWELLS': 0,
    'SOWELS': 0,
    'SOWER': 0,
    'SOWERBY': 0,
    'SOWERS': 0,
    'SOWERSBY': 0,
    'SOWIEJA': 0,
    'SOWINSKI': 0,
    'SOWKA': 0,
    'SOWL': 0,
    'SOWLE': 0,
    'SOWLES': 0,
    'SOWRY': 0,
    'SOWUL': 0,
    'SOX': 0,
    'SOY': 0,
    'SOYA': 0,
    'SOYARS': 0,
    'SOYER': 0,
    'SOYFER': 0,
    'SOYK': 0,
    'SOYKA': 0,
    'SOYLAND': 0,
    'SOYRING': 0,
    'SOYSTER': 0,
    'SOZA': 0,
    'SOZANSKI': 0,
    'SOZIO': 0,
    'SOZZI': 0,
    'SPAAN': 0,
    'SPAANS': 0,
    'SPAAR': 0,
    'SPACE': 0,
    'SPACEK': 0,
    'SPACH': 0,
    'SPACHT': 0,
    'SPACK': 0,
    'SPACKMAN': 0,
    'SPACONE': 0,
    'SPADA': 0,
    'SPADACCINI': 0,
    'SPADACCINO': 0,
    'SPADAFINO': 0,
    'SPADAFORA': 0,
    'SPADAFORE': 0,
    'SPADARO': 0,
    'SPADAVECCHIA': 0,
    'SPADE': 0,
    'SPADEA': 0,
    'SPADER': 0,
    'SPADOLA': 0,
    'SPADONE': 0,
    'SPADONI': 0,
    'SPADT': 0,
    'SPADY': 0,
    'SPAEDER': 0,
    'SPAETH': 0,
    'SPAETHE': 0,
    'SPAFFORD': 0,
    'SPAGNA': 0,
    'SPAGNOLA': 0,
    'SPAGNOLETTI': 0,
    'SPAGNOLI': 0,
    'SPAGNOLIA': 0,
    'SPAGNOLO': 0,
    'SPAGNUOLO': 0,
    'SPAH': 0,
    'SPAHIC': 0,
    'SPAHN': 0,
    'SPAHR': 0,
    'SPAID': 0,
    'SPAIDE': 0,
    'SPAIGHT': 0,
    'SPAIN': 0,
    'SPAINE': 0,
    'SPAINHOUR': 0,
    'SPAINHOWARD': 0,
    'SPAINHOWER': 0,
    'SPAITS': 0,
    'SPAK': 0,
    'SPAKE': 0,
    'SPAKES': 0,
    'SPAKOWSKI': 0,
    'SPALDING': 0,
    'SPALE': 0,
    'SPALETTA': 0,
    'SPALINGER': 0,
    'SPALL': 0,
    'SPALLA': 0,
    'SPALLER': 0,
    'SPALLINA': 0,
    'SPALLINGER': 0,
    'SPALLINO': 0,
    'SPALLONE': 0,
    'SPALSBURY': 0,
    'SPALT': 0,
    'SPALTER': 0,
    'SPAMAN': 0,
    'SPAMER': 0,
    'SPAMPINATO': 0,
    'SPAN': 0,
    'SPANA': 0,
    'SPANBAUER': 0,
    'SPANDE': 0,
    'SPANE': 0,
    'SPANEL': 0,
    'SPANG': 0,
    'SPANGENBERG': 0,
    'SPANGENBERGER': 0,
    'SPANGENBURG': 0,
    'SPANGLE': 0,
    'SPANGLER': 0,
    'SPANGRUD': 0,
    'SPANI': 0,
    'SPANIEL': 0,
    'SPANIER': 0,
    'SPANIOL': 0,
    'SPANISH': 0,
    'SPANITZ': 0,
    'SPANJER': 0,
    'SPANJERS': 0,
    'SPANKE': 0,
    'SPANKS': 0,
    'SPANN': 0,
    'SPANNAGEL': 0,
    'SPANNBAUER': 0,
    'SPANNER': 0,
    'SPANNUTH': 0,
    'SPANO': 0,
    'SPANOS': 0,
    'SPANOVICH': 0,
    'SPANSKI': 0,
    'SPANSWICK': 0,
    'SPANTON': 0,
    'SPAR': 0,
    'SPARA': 0,
    'SPARACELLO': 0,
    'SPARACINO': 0,
    'SPARACIO': 0,
    'SPARACO': 0,
    'SPARAGNA': 0,
    'SPARANO': 0,
    'SPARAPANI': 0,
    'SPARBEL': 0,
    'SPARBER': 0,
    'SPARBY': 0,
    'SPARE': 0,
    'SPARENBERG': 0,
    'SPARER': 0,
    'SPARGER': 0,
    'SPARGO': 0,
    'SPARGUR': 0,
    'SPARHAWK': 0,
    'SPARK': 0,
    'SPARKE': 0,
    'SPARKES': 0,
    'SPARKLE': 1,
    'SPARKLIN': 0,
    'SPARKMAN': 0,
    'SPARKS': 0,
    'SPARLIN': 0,
    'SPARLING': 0,
    'SPARMAN': 0,
    'SPARR': 0,
    'SPARRE': 0,
    'SPARRER': 0,
    'SPARROW': 0,
    'SPARTA': 0,
    'SPARTZ': 0,
    'SPAS': 0,
    'SPASOJEVIC': 0,
    'SPATA': 0,
    'SPATAFORA': 0,
    'SPATAFORE': 0,
    'SPATARO': 0,
    'SPATCHER': 0,
    'SPATE': 0,
    'SPATES': 0,
    'SPATH': 0,
    'SPATIG': 0,
    'SPATOLA': 0,
    'SPATT': 0,
    'SPATZ': 0,
    'SPAUDE': 0,
    'SPAUGH': 0,
    'SPAUGY': 0,
    'SPAULDING': 0,
    'SPAUN': 0,
    'SPAUR': 0,
    'SPAVEN': 0,
    'SPAVENTA': 0,
    'SPAW': 0,
    'SPAWN': 0,
    'SPAYD': 0,
    'SPAYDE': 0,
    'SPAZIANI': 0,
    'SPAZIANO': 0,
    'SPEACH': 0,
    'SPEAGLE': 0,
    'SPEAK': 0,
    'SPEAKE': 0,
    'SPEAKER': 0,
    'SPEAKES': 0,
    'SPEAKMAN': 0,
    'SPEAKS': 0,
    'SPEALMAN': 0,
    'SPEANBURG': 0,
    'SPEAR': 0,
    'SPEARE': 0,
    'SPEARIN': 0,
    'SPEARING': 0,
    'SPEARMAN': 0,
    'SPEARMON': 0,
    'SPEARS': 0,
    'SPEARY': 0,
    'SPEAS': 0,
    'SPEASE': 0,
    'SPECA': 0,
    'SPECCHIO': 0,
    'SPECE': 0,
    'SPECHT': 0,
    'SPECIAL': 0,
    'SPECIALE': 0,
    'SPECK': 0,
    'SPECKELS': 0,
    'SPECKER': 0,
    'SPECKERT': 0,
    'SPECKHALS': 0,
    'SPECKHART': 0,
    'SPECKIN': 0,
    'SPECKMAN': 0,
    'SPECKMANN': 0,
    'SPECKS': 0,
    'SPECTER': 0,
    'SPECTOR': 0,
    'SPEDALE': 0,
    'SPEDDEN': 0,
    'SPEDDING': 0,
    'SPEECE': 0,
    'SPEECH': 0,
    'SPEECHLEY': 0,
    'SPEED': 0,
    'SPEEDLING': 0,
    'SPEEDY': 0,
    'SPEEG': 0,
    'SPEEGLE': 0,
    'SPEEKS': 0,
    'SPEELMAN': 0,
    'SPEER': 0,
    'SPEERS': 0,
    'SPEES': 0,
    'SPEESE': 0,
    'SPEET': 0,
    'SPEGAL': 0,
    'SPEH': 0,
    'SPEHAR': 0,
    'SPEHN': 0,
    'SPEICE': 0,
    'SPEICH': 0,
    'SPEICHER': 0,
    'SPEICHINGER': 0,
    'SPEIDEL': 0,
    'SPEIDELL': 0,
    'SPEIDEN': 0,
    'SPEIER': 0,
    'SPEIGEL': 0,
    'SPEIGHT': 0,
    'SPEIGHTS': 0,
    'SPEIGLE': 0,
    'SPEIGNER': 0,
    'SPEIKER': 0,
    'SPEIR': 0,
    'SPEIRS': 0,
    'SPEIS': 0,
    'SPEISER': 0,
    'SPEIZER': 0,
    'SPEKTOR': 0,
    'SPELBRING': 0,
    'SPELCE': 0,
    'SPELICH': 0,
    'SPELL': 0,
    'SPELLACY': 0,
    'SPELLER': 0,
    'SPELLERBERG': 0,
    'SPELLICY': 0,
    'SPELLINGS': 0,
    'SPELLMAN': 0,
    'SPELLMEYER': 0,
    'SPELLS': 0,
    'SPELMAN': 0,
    'SPELTS': 0,
    'SPELTZ': 0,
    'SPENA': 0,
    'SPENARD': 0,
    'SPENCE': 0,
    'SPENCER': 0.37575150300601196,
    'SPENCLEY': 0,
    'SPENDER': 0,
    'SPENDLOVE': 0,
    'SPENGEL': 0,
    'SPENGLER': 0,
    'SPENNATO': 0,
    'SPENNER': 0,
    'SPENNY': 0,
    'SPENO': 0,
    'SPENRATH': 0,
    'SPENS': 0,
    'SPENSER': 0,
    'SPENSIERI': 0,
    'SPENSLEY': 0,
    'SPENST': 0,
    'SPER': 0,
    'SPERA': 0,
    'SPERANDEO': 0,
    'SPERANDIO': 0,
    'SPERANDO': 0,
    'SPERANZA': 0,
    'SPERANZO': 0,
    'SPERAW': 0,
    'SPERBECK': 0,
    'SPERBER': 0,
    'SPERBERG': 0,
    'SPERDUTI': 0,
    'SPERDUTO': 0,
    'SPERFSLAGE': 0,
    'SPERGEL': 0,
    'SPERGER': 0,
    'SPERING': 0,
    'SPERKA': 0,
    'SPERL': 0,
    'SPERLAZZA': 0,
    'SPERLE': 0,
    'SPERLICH': 0,
    'SPERLING': 0,
    'SPERO': 0,
    'SPERONI': 0,
    'SPEROS': 0,
    'SPEROW': 0,
    'SPERR': 0,
    'SPERRAZZA': 0,
    'SPERRING': 0,
    'SPERRY': 0,
    'SPERZEL': 0,
    'SPESS': 0,
    'SPESSARD': 0,
    'SPETA': 0,
    'SPETH': 0,
    'SPETTEL': 0,
    'SPETTER': 0,
    'SPETZ': 0,
    'SPEVACEK': 0,
    'SPEVACK': 0,
    'SPEVAK': 0,
    'SPEXARTH': 0,
    'SPEYER': 0,
    'SPEYRER': 0,
    'SPEZIA': 0,
    'SPEZIALE': 0,
    'SPEZIO': 0,
    'SPEZZANO': 0,
    'SPHAR': 0,
    'SPHON': 0,
    'SPIAK': 0,
    'SPICA': 0,
    'SPICE': 0,
    'SPICELAND': 0,
    'SPICER': 0,
    'SPICHER': 0,
    'SPICKA': 0,
    'SPICKARD': 0,
    'SPICKELMIER': 0,
    'SPICKER': 0,
    'SPICKERMAN': 0,
    'SPICKLER': 0,
    'SPICKNALL': 0,
    'SPICOLA': 0,
    'SPICUZZA': 0,
    'SPICZKA': 0,
    'SPIDEL': 0,
    'SPIDELL': 0,
    'SPIDLE': 0,
    'SPIECE': 0,
    'SPIECKER': 0,
    'SPIEGEL': 0,
    'SPIEGELBERG': 0,
    'SPIEGELHALTER': 0,
    'SPIEGELHOFF': 0,
    'SPIEGELMAN': 0,
    'SPIEGL': 0,
    'SPIEGLE': 0,
    'SPIEGLER': 0,
    'SPIEHS': 0,
    'SPIEKER': 0,
    'SPIEKERMAN': 0,
    'SPIEL': 0,
    'SPIELBAUER': 0,
    'SPIELBERG': 0,
    'SPIELBERGER': 0,
    'SPIELBUSCH': 0,
    'SPIELDENNER': 0,
    'SPIELER': 0,
    'SPIELES': 0,
    'SPIELMAKER': 0,
    'SPIELMAN': 0,
    'SPIELMANN': 0,
    'SPIELVOGEL': 0,
    'SPIER': 0,
    'SPIERER': 0,
    'SPIERING': 0,
    'SPIERLING': 0,
    'SPIERS': 0,
    'SPIES': 0,
    'SPIESE': 0,
    'SPIESMAN': 0,
    'SPIESS': 0,
    'SPIETH': 0,
    'SPIEWAK': 0,
    'SPIEZIO': 0,
    'SPIGARELLI': 0,
    'SPIGEL': 0,
    'SPIGELMAN': 0,
    'SPIGELMYER': 0,
    'SPIGENER': 0,
    'SPIGGLE': 0,
    'SPIGHT': 0,
    'SPIGLER': 0,
    'SPIGNER': 0,
    'SPIKA': 0,
    'SPIKE': 0,
    'SPIKER': 0,
    'SPIKES': 0,
    'SPILDE': 0,
    'SPILGER': 0,
    'SPILIOS': 0,
    'SPILIOTIS': 0,
    'SPILKA': 0,
    'SPILKER': 0,
    'SPILL': 0,
    'SPILLAN': 0,
    'SPILLANE': 0,
    'SPILLAR': 0,
    'SPILLARS': 0,
    'SPILLE': 0,
    'SPILLER': 0,
    'SPILLERS': 0,
    'SPILLETT': 0,
    'SPILLMAN': 0,
    'SPILLNER': 0,
    'SPILLUM': 0,
    'SPILMAN': 0,
    'SPILOTRO': 0,
    'SPILSBURY': 0,
    'SPIN': 0,
    'SPINA': 0,
    'SPINALE': 0,
    'SPINALI': 0,
    'SPINAR': 0,
    'SPINATO': 0,
    'SPINAZOLA': 0,
    'SPINAZZOLA': 0,
    'SPINDEL': 0,
    'SPINDEN': 0,
    'SPINDER': 0,
    'SPINDLE': 0,
    'SPINDLER': 0,
    'SPINDOLA': 0,
    'SPINE': 0,
    'SPINELL': 0,
    'SPINELLA': 0,
    'SPINELLI': 0,
    'SPINELLO': 0,
    'SPINETTI': 0,
    'SPINGARN': 0,
    'SPINGLER': 0,
    'SPINGOLA': 0,
    'SPINK': 0,
    'SPINKA': 0,
    'SPINKS': 0,
    'SPINLER': 0,
    'SPINN': 0,
    'SPINNATO': 0,
    'SPINNENWEBER': 0,
    'SPINNER': 0,
    'SPINNEY': 0,
    'SPINNING': 0,
    'SPINNLER': 0,
    'SPINO': 0,
    'SPINOLA': 0,
    'SPINOS': 0,
    'SPINOSA': 0,
    'SPINOSI': 0,
    'SPINOSO': 0,
    'SPINOZA': 0,
    'SPINOZZI': 0,
    'SPINRAD': 0,
    'SPINUZZA': 0,
    'SPINUZZI': 0,
    'SPIOTTA': 0,
    'SPIOTTO': 0,
    'SPIRA': 0,
    'SPIRE': 0,
    'SPIREK': 0,
    'SPIRER': 0,
    'SPIRES': 0,
    'SPIRIDIGLIOZZI': 0,
    'SPIRITO': 0,
    'SPIRK': 0,
    'SPIRKO': 0,
    'SPIRO': 0,
    'SPIROFF': 0,
    'SPIROPOULOS': 0,
    'SPIROS': 0,
    'SPIROU': 0,
    'SPIRY': 0,
    'SPISAK': 0,
    'SPISHOCK': 0,
    'SPITALE': 0,
    'SPITALERI': 0,
    'SPITERI': 0,
    'SPITLER': 0,
    'SPITNALE': 0,
    'SPITTAL': 0,
    'SPITTEL': 0,
    'SPITTLE': 0,
    'SPITTLER': 0,
    'SPITZ': 0,
    'SPITZA': 0,
    'SPITZACK': 0,
    'SPITZENBERGER': 0,
    'SPITZER': 0,
    'SPITZFADEN': 0,
    'SPITZIG': 0,
    'SPITZLEY': 0,
    'SPITZMILLER': 0,
    'SPITZNAGEL': 0,
    'SPITZNAGLE': 0,
    'SPITZNER': 0,
    'SPITZNOGLE': 0,
    'SPIVA': 0,
    'SPIVACK': 0,
    'SPIVAK': 0,
    'SPIVERY': 0,
    'SPIVEY': 0,
    'SPIVY': 0,
    'SPIWAK': 0,
    'SPIZZIRRI': 0,
    'SPJUT': 0,
    'SPLAIN': 0,
    'SPLAINE': 0,
    'SPLAN': 0,
    'SPLANE': 0,
    'SPLAWN': 0,
    'SPLETT': 0,
    'SPLETTER': 0,
    'SPLETZER': 0,
    'SPLICHAL': 0,
    'SPLIETHOF': 0,
    'SPLINTER': 0,
    'SPLITSTONE': 0,
    'SPLITT': 0,
    'SPLITTER': 0,
    'SPLITTGERBER': 0,
    'SPLITTSTOESSER': 0,
    'SPLONSKOWSKI': 0,
    'SPLUNGE': 0,
    'SPOCK': 0,
    'SPODEK': 0,
    'SPODEN': 0,
    'SPOEHR': 0,
    'SPOELHOF': 0,
    'SPOELMAN': 0,
    'SPOELSTRA': 0,
    'SPOERL': 0,
    'SPOFFORD': 0,
    'SPOHN': 0,
    'SPOHR': 0,
    'SPOHRER': 0,
    'SPOKAS': 0,
    'SPOKES': 0,
    'SPOLAR': 0,
    'SPOLARICH': 0,
    'SPOLJARIC': 0,
    'SPOLLEN': 0,
    'SPOLTORE': 0,
    'SPOMER': 0,
    'SPONABLE': 0,
    'SPONAUGLE': 0,
    'SPONBERG': 0,
    'SPONDER': 0,
    'SPONENBERG': 0,
    'SPONG': 0,
    'SPONGBERG': 0,
    'SPONHEIM': 0,
    'SPONHEIMER': 0,
    'SPONHOLTZ': 0,
    'SPONHOLZ': 0,
    'SPONSEL': 0,
    'SPONSELLER': 0,
    'SPONSLER': 0,
    'SPONTAK': 0,
    'SPOO': 0,
    'SPOOLSTRA': 0,
    'SPOON': 0,
    'SPOONAMORE': 0,
    'SPOONE': 0,
    'SPOONEMORE': 0,
    'SPOONER': 0,
    'SPOONHOUR': 0,
    'SPOONHUNTER': 0,
    'SPOONMORE': 0,
    'SPOONTS': 0,
    'SPOOR': 0,
    'SPOORS': 0,
    'SPOR': 0,
    'SPORBERT': 0,
    'SPORCIC': 0,
    'SPORE': 0,
    'SPORER': 0,
    'SPORES': 0,
    'SPORING': 0,
    'SPORL': 0,
    'SPORLEDER': 0,
    'SPORMAN': 0,
    'SPORN': 0,
    'SPORRE': 0,
    'SPORRER': 0,
    'SPORS': 0,
    'SPORT': 0,
    'SPORTEL': 0,
    'SPORTELLI': 0,
    'SPORTIELLO': 0,
    'SPORTS': 0,
    'SPORTSMAN': 0,
    'SPORY': 0,
    'SPOSATO': 0,
    'SPOSITO': 0,
    'SPOTANSKI': 0,
    'SPOTH': 0,
    'SPOTO': 0,
    'SPOTSWOOD': 0,
    'SPOTT': 0,
    'SPOTTEDBEAR': 0,
    'SPOTTEDEAGLE': 0,
    'SPOTTEDELK': 0,
    'SPOTTEDHORSE': 0,
    'SPOTTEN': 0,
    'SPOTTS': 0,
    'SPOTTSVILLE': 0,
    'SPOTTSWOOD': 0,
    'SPOTWOOD': 0,
    'SPOTZ': 0,
    'SPOWART': 0,
    'SPRABARY': 0,
    'SPRABERRY': 0,
    'SPRACKLEN': 0,
    'SPRACKLIN': 0,
    'SPRADER': 0,
    'SPRADLEY': 0,
    'SPRADLIN': 0,
    'SPRADLING': 0,
    'SPRAGG': 0,
    'SPRAGGINS': 0,
    'SPRAGGS': 0,
    'SPRAGINS': 0,
    'SPRAGLIN': 0,
    'SPRAGUE': 0,
    'SPRAIN': 0,
    'SPRAKER': 0,
    'SPRANCE': 0,
    'SPRANDEL': 0,
    'SPRANG': 0,
    'SPRANGER': 0,
    'SPRANGERS': 0,
    'SPRANKLE': 0,
    'SPRATLEN': 0,
    'SPRATLEY': 0,
    'SPRATLIN': 0,
    'SPRATLING': 0,
    'SPRATT': 0,
    'SPRATTE': 0,
    'SPRAU': 0,
    'SPRAUER': 0,
    'SPRAUL': 0,
    'SPRAUVE': 0,
    'SPRAWLS': 0,
    'SPRAY': 0,
    'SPRAYBERRY': 0,
    'SPREADBOROUGH': 0,
    'SPREADBURY': 0,
    'SPRECHER': 0,
    'SPRECKER': 0,
    'SPREEMAN': 0,
    'SPREEN': 0,
    'SPREER': 0,
    'SPREHE': 0,
    'SPREIER': 0,
    'SPREITZER': 0,
    'SPREMULLI': 0,
    'SPRENG': 0,
    'SPRENGEL': 0,
    'SPRENGELER': 0,
    'SPRENGER': 0,
    'SPRENKEL': 0,
    'SPRENKLE': 0,
    'SPRESSER': 0,
    'SPREWELL': 0,
    'SPREWER': 0,
    'SPRICK': 0,
    'SPRIESTERSBACH': 0,
    'SPRIET': 0,
    'SPRIGG': 0,
    'SPRIGGLE': 0,
    'SPRIGGS': 0,
    'SPRIGLER': 0,
    'SPRIK': 0,
    'SPRING': 0.38610038610038616,
    'SPRINGATE': 0,
    'SPRINGBORN': 0,
    'SPRINGER': 0,
    'SPRINGETT': 0,
    'SPRINGFIELD': 0,
    'SPRINGHETTI': 0,
    'SPRINGLE': 0,
    'SPRINGMAN': 0,
    'SPRINGMANN': 0,
    'SPRINGMEYER': 0,
    'SPRINGOB': 0,
    'SPRINGS': 0,
    'SPRINGSTEAD': 0,
    'SPRINGSTED': 0,
    'SPRINGSTEEL': 0,
    'SPRINGSTEEN': 0,
    'SPRINGSTON': 0,
    'SPRINGSTROH': 0,
    'SPRINGSTUBE': 0,
    'SPRINGWATER': 0,
    'SPRINKEL': 0,
    'SPRINKLE': 0,
    'SPRINKLES': 0,
    'SPRISSLER': 0,
    'SPRITZ': 0,
    'SPRITZER': 0,
    'SPROAT': 0,
    'SPROCH': 0,
    'SPROCK': 0,
    'SPROFERA': 0,
    'SPROLE': 0,
    'SPROLES': 0,
    'SPRONG': 0,
    'SPRONK': 0,
    'SPROSS': 0,
    'SPROSTON': 0,
    'SPROSTY': 0,
    'SPROTT': 0,
    'SPROTTE': 0,
    'SPROUL': 0,
    'SPROULE': 0,
    'SPROULL': 0,
    'SPROULS': 0,
    'SPROUS': 0,
    'SPROUSE': 0,
    'SPROUT': 0,
    'SPROVIERO': 0,
    'SPROW': 0,
    'SPROWL': 0,
    'SPROWLES': 0,
    'SPROWLS': 0,
    'SPRUANCE': 0,
    'SPRUCE': 0,
    'SPRUCK': 0,
    'SPRUEL': 0,
    'SPRUELL': 0,
    'SPRUIELL': 0,
    'SPRUILL': 0,
    'SPRUIT': 0,
    'SPRULL': 0,
    'SPRUNG': 0,
    'SPRUNGER': 0,
    'SPRUNK': 0,
    'SPRUNT': 0,
    'SPRUTE': 0,
    'SPRY': 0,
    'SPUCK': 0,
    'SPUDE': 0,
    'SPUDIC': 0,
    'SPUDICH': 0,
    'SPUEHLER': 0,
    'SPUHLER': 0,
    'SPULER': 0,
    'SPULLER': 0,
    'SPUNAUGLE': 0,
    'SPUNG': 0,
    'SPURBECK': 0,
    'SPURGEON': 0,
    'SPURGER': 0,
    'SPURGIN': 0,
    'SPURLEY': 0,
    'SPURLIN': 0,
    'SPURLING': 0,
    'SPURLOCK': 0,
    'SPURR': 0,
    'SPURRELL': 0,
    'SPURRIER': 0,
    'SPYCHALA': 0,
    'SPYCHALLA': 0,
    'SPYCHALSKI': 0,
    'SPYKE': 0,
    'SPYKER': 0,
    'SPYKERMAN': 0,
    'SPYRES': 0,
    'SPYRKA': 0,
    'SPYROPOULOS': 0,
    'SQUADRITO': 0,
    'SQUALLS': 0,
    'SQUARE': 0,
    'SQUATRITO': 0,
    'SQUEGLIA': 0,
    'SQUEO': 0,
    'SQUERI': 0,
    'SQUIBB': 0,
    'SQUIBBS': 0,
    'SQUICCIARINI': 0,
    'SQUIER': 0,
    'SQUIERS': 0,
    'SQUILLA': 0,
    'SQUILLACE': 0,
    'SQUILLACIOTI': 0,
    'SQUILLANTE': 0,
    'SQUIRE': 0,
    'SQUIRES': 0,
    'SQUIREWELL': 0,
    'SQUIRREL': 0,
    'SQUIRRELL': 0,
    'SQUITIERI': 0,
    'SQUYRES': 0,
    'SR': 0,
    'SRADER': 0,
    'SRAMEK': 0,
    'SRAN': 0,
    'SRAY': 0,
    'SRB': 0,
    'SREBRO': 0,
    'SREDNICKI': 0,
    'SREENIVASAN': 0,
    'SREY': 0,
    'SRIDHAR': 0,
    'SRIDHARAN': 0,
    'SRIKANTH': 0,
    'SRINATH': 0,
    'SRINIVAS': 0,
    'SRINIVASA': 0,
    'SRINIVASAN': 0,
    'SRIRAM': 0,
    'SRIVASTAVA': 0,
    'SRNEC': 0,
    'SRNKA': 0,
    'SROCK': 0,
    'SROCZYNSKI': 0,
    'SRODA': 0,
    'SROFE': 0,
    'SROGA': 0,
    'SROKA': 0,
    'SRONCE': 0,
    'SROUFE': 0,
    'SROUJI': 0,
    'SROUR': 0,
    'SRP': 0,
    'SRSEN': 0,
    'SRUBAR': 0,
    'SRYGLEY': 0,
    'STAAB': 0,
    'STAACK': 0,
    'STAAF': 0,
    'STAAKE': 0,
    'STAAL': 0,
    'STAANA': 0,
    'STAAS': 0,
    'STAAT': 0,
    'STAATS': 0,
    'STAATZ': 0,
    'STABB': 0,
    'STABE': 0,
    'STABEL': 0,
    'STABELL': 0,
    'STABEN': 0,
    'STABENOW': 0,
    'STABER': 0,
    'STABERG': 0,
    'STABILE': 0,
    'STABINSKI': 0,
    'STABINSKY': 0,
    'STABLE': 0,
    'STABLEIN': 0,
    'STABLER': 0,
    'STABLES': 0,
    'STABLEY': 0,
    'STABNOW': 0,
    'STACE': 0,
    'STACEE': 1,
    'STACER': 0,
    'STACEY': 0.9714632665452337,
    'STACH': 0,
    'STACHE': 0,
    'STACHEL': 0,
    'STACHELEK': 0,
    'STACHELSKI': 0,
    'STACHER': 0,
    'STACHERSKI': 0,
    'STACHEWICZ': 0,
    'STACHLER': 0,
    'STACHNIK': 0,
    'STACHO': 0,
    'STACHON': 0,
    'STACHOWIAK': 0,
    'STACHOWICZ': 0,
    'STACHOWSKI': 0,
    'STACHURA': 0,
    'STACHURSKI': 0,
    'STACHYRA': 0,
    'STACI': 1,
    'STACIA': 1,
    'STACIE': 1,
    'STACK': 0,
    'STACKEN': 0,
    'STACKER': 0,
    'STACKHOUSE': 0,
    'STACKLEY': 0,
    'STACKLIN': 0,
    'STACKMAN': 0,
    'STACKPOLE': 0,
    'STACKPOOLE': 0,
    'STACKS': 0,
    'STACY': 0.9527754763877382,
    'STADDEN': 0,
    'STADDON': 0,
    'STADE': 0,
    'STADEL': 0,
    'STADELI': 0,
    'STADELMAIER': 0,
    'STADELMAN': 0,
    'STADELMANN': 0,
    'STADER': 0,
    'STADHEIM': 0,
    'STADICK': 0,
    'STADIE': 0,
    'STADIG': 0,
    'STADING': 0,
    'STADLER': 0,
    'STADNICK': 0,
    'STADNICKI': 0,
    'STADNIK': 0,
    'STADNYK': 0,
    'STADT': 0,
    'STADTER': 0,
    'STADTFELD': 0,
    'STADTHER': 0,
    'STADTHERR': 0,
    'STADTLANDER': 0,
    'STADTLER': 0,
    'STADTMILLER': 0,
    'STADTMUELLER': 0,
    'STADUM': 0,
    'STADY': 0,
    'STAEBELL': 0,
    'STAEBLER': 0,
    'STAEGE': 0,
    'STAEGER': 0,
    'STAEHELI': 0,
    'STAEHLE': 0,
    'STAEHLER': 0,
    'STAEHLIN': 0,
    'STAEHLING': 0,
    'STAEHR': 0,
    'STAELENS': 0,
    'STAERKEL': 0,
    'STAES': 0,
    'STAFF': 0,
    'STAFFA': 0,
    'STAFFAN': 0,
    'STAFFARONI': 0,
    'STAFFELD': 0,
    'STAFFELDT': 0,
    'STAFFEN': 0,
    'STAFFIER': 0,
    'STAFFIERI': 0,
    'STAFFIN': 0,
    'STAFFNEY': 0,
    'STAFFON': 0,
    'STAFFORD': 0,
    'STAFKI': 0,
    'STAFNE': 0,
    'STAFORD': 0,
    'STAGE': 0,
    'STAGEBERG': 0,
    'STAGEMAN': 0,
    'STAGER': 0,
    'STAGG': 0,
    'STAGGE': 0,
    'STAGGERS': 0,
    'STAGGS': 0,
    'STAGI': 0,
    'STAGL': 0,
    'STAGLIANO': 0,
    'STAGMAN': 0,
    'STAGNARO': 0,
    'STAGNER': 0,
    'STAGNITTA': 0,
    'STAGNO': 0,
    'STAHEL': 0,
    'STAHELI': 0,
    'STAHL': 0,
    'STAHLA': 0,
    'STAHLBERG': 0,
    'STAHLE': 0,
    'STAHLECKER': 0,
    'STAHLER': 0,
    'STAHLEY': 0,
    'STAHLHEBER': 0,
    'STAHLHUT': 0,
    'STAHLI': 0,
    'STAHLIN': 0,
    'STAHLKE': 0,
    'STAHLMAN': 0,
    'STAHLMANN': 0,
    'STAHLNECKER': 0,
    'STAHLSCHMIDT': 0,
    'STAHLY': 0,
    'STAHMANN': 0,
    'STAHMER': 0,
    'STAHN': 0,
    'STAHNKE': 0,
    'STAHR': 0,
    'STAHULAK': 0,
    'STAHURA': 0,
    'STAI': 0,
    'STAIANO': 0,
    'STAIB': 0,
    'STAIE': 0,
    'STAIERT': 0,
    'STAIGER': 0,
    'STAILEY': 0,
    'STAIN': 0,
    'STAINBACK': 0,
    'STAINBROOK': 0,
    'STAINE': 0,
    'STAINER': 0,
    'STAINES': 0,
    'STAINO': 0,
    'STAINS': 0,
    'STAINTON': 0,
    'STAIR': 0,
    'STAIRES': 0,
    'STAIRS': 0,
    'STAITI': 0,
    'STAJDUHAR': 0,
    'STAKE': 0,
    'STAKELIN': 0,
    'STAKELY': 0,
    'STAKEM': 0,
    'STAKER': 0,
    'STAKES': 0,
    'STAKEY': 0,
    'STAKLEY': 0,
    'STALA': 0,
    'STALANS': 0,
    'STALBAUM': 0,
    'STALBERGER': 0,
    'STALBOERGER': 0,
    'STALCUP': 0,
    'STALDER': 0,
    'STALEY': 0,
    'STALF': 0,
    'STALFORD': 0,
    'STALHEIM': 0,
    'STALICA': 0,
    'STALIONS': 0,
    'STALK': 0,
    'STALKER': 0,
    'STALKFLEET': 0,
    'STALL': 0,
    'STALLARD': 0,
    'STALLBAUMER': 0,
    'STALLCOP': 0,
    'STALLCUP': 0,
    'STALLER': 0,
    'STALLEY': 0,
    'STALLING': 0,
    'STALLINGS': 0,
    'STALLINS': 0,
    'STALLION': 0,
    'STALLIONS': 0,
    'STALLKAMP': 0,
    'STALLMAN': 0,
    'STALLMANN': 0,
    'STALLO': 0,
    'STALLONE': 0,
    'STALLONS': 0,
    'STALLS': 0,
    'STALLSMITH': 0,
    'STALLSWORTH': 0,
    'STALLWORTH': 0,
    'STALNAKER': 0,
    'STALNECKER': 0,
    'STALOCH': 0,
    'STALSBERG': 0,
    'STALTER': 0,
    'STALTERI': 0,
    'STALVEY': 0,
    'STALWORTH': 0,
    'STALZER': 0,
    'STAM': 0,
    'STAMAN': 0,
    'STAMAND': 0,
    'STAMANT': 0,
    'STAMARIA': 0,
    'STAMAS': 0,
    'STAMATAKIS': 0,
    'STAMATAKOS': 0,
    'STAMATELOS': 0,
    'STAMATIS': 0,
    'STAMATO': 0,
    'STAMATOPOULOS': 0,
    'STAMBACH': 0,
    'STAMBACK': 0,
    'STAMBAUGH': 0,
    'STAMBERGER': 0,
    'STAMBLER': 0,
    'STAMER': 0,
    'STAMETS': 0,
    'STAMEY': 0,
    'STAMFORD': 0,
    'STAMILE': 0,
    'STAMLER': 0,
    'STAMM': 0,
    'STAMMEL': 0,
    'STAMMEN': 0,
    'STAMMER': 0,
    'STAMMERS': 0,
    'STAMMLER': 0,
    'STAMOS': 0,
    'STAMOULIS': 0,
    'STAMOUR': 0,
    'STAMP': 0,
    'STAMPE': 0,
    'STAMPER': 0,
    'STAMPFEL': 0,
    'STAMPFER': 0,
    'STAMPFL': 0,
    'STAMPFLI': 0,
    'STAMPLER': 0,
    'STAMPLEY': 0,
    'STAMPONE': 0,
    'STAMPS': 0,
    'STAMY': 0,
    'STAN': 0.9797517962116264,
    'STANA': 0,
    'STANAFORD': 0,
    'STANAGE': 0,
    'STANAITIS': 0,
    'STANALAND': 0,
    'STANARD': 0,
    'STANART': 0,
    'STANAWAY': 0,
    'STANBACK': 0,
    'STANBERRY': 0,
    'STANBERY': 0,
    'STANBRIDGE': 0,
    'STANBRO': 0,
    'STANBROUGH': 0,
    'STANBURY': 0,
    'STANCAMPIANO': 0,
    'STANCATI': 0,
    'STANCATO': 0,
    'STANCAVAGE': 0,
    'STANCE': 0,
    'STANCEL': 0,
    'STANCELL': 0,
    'STANCER': 0,
    'STANCH': 0,
    'STANCHAK': 0,
    'STANCHFIELD': 0,
    'STANCHIK': 0,
    'STANCHINA': 0,
    'STANCIEL': 0,
    'STANCIK': 0,
    'STANCIL': 0,
    'STANCILL': 0,
    'STANCIU': 0,
    'STANCLIFF': 0,
    'STANCLIFFE': 0,
    'STANCO': 0,
    'STANCOMBE': 0,
    'STANCU': 0,
    'STANCZAK': 0,
    'STANCZYK': 0,
    'STAND': 0,
    'STANDAERT': 0,
    'STANDAFER': 0,
    'STANDAGE': 0,
    'STANDAL': 0,
    'STANDARD': 0,
    'STANDBERRY': 0,
    'STANDEFER': 0,
    'STANDEFORD': 0,
    'STANDEN': 0,
    'STANDER': 0,
    'STANDERFER': 0,
    'STANDEVEN': 0,
    'STANDFIELD': 0,
    'STANDFILL': 0,
    'STANDFORD': 0,
    'STANDIFER': 0,
    'STANDIFIRD': 0,
    'STANDIFORD': 0,
    'STANDING': 0,
    'STANDINGBEAR': 0,
    'STANDINGROCK': 0,
    'STANDINGWATER': 0,
    'STANDISH': 0,
    'STANDKE': 0,
    'STANDLEE': 0,
    'STANDLEY': 0,
    'STANDLY': 0,
    'STANDRE': 0,
    'STANDREW': 0,
    'STANDREWS': 0,
    'STANDRIDGE': 0,
    'STANDRING': 0,
    'STANDS': 0,
    'STANE': 0,
    'STANEART': 0,
    'STANEK': 0,
    'STANELLE': 0,
    'STANELY': 0,
    'STANER': 0,
    'STANESCU': 0,
    'STANEY': 0,
    'STANFA': 0,
    'STANFEL': 0,
    'STANFIELD': 0,
    'STANFILL': 0,
    'STANFORD': 0.39556962025316456,
    'STANFORTH': 0,
    'STANG': 0,
    'STANGA': 0,
    'STANGARONE': 0,
    'STANGE': 0,
    'STANGEL': 0,
    'STANGELAND': 0,
    'STANGELO': 0,
    'STANGER': 0,
    'STANGL': 0,
    'STANGLAND': 0,
    'STANGLE': 0,
    'STANGLER': 0,
    'STANGLIN': 0,
    'STANGO': 0,
    'STANHOPE': 0,
    'STANHOUSE': 0,
    'STANIC': 0,
    'STANICH': 0,
    'STANICK': 0,
    'STANIEC': 0,
    'STANIEWICZ': 0,
    'STANIFER': 0,
    'STANIFORD': 0,
    'STANIFORTH': 0,
    'STANIK': 0,
    'STANIS': 0,
    'STANISCI': 0,
    'STANISH': 0,
    'STANISIC': 0,
    'STANISLAS': 0,
    'STANISLAUS': 0,
    'STANISLAV': 0,
    'STANISLAW': 0,
    'STANISLAWCZYK': 0,
    'STANISLAWSKI': 0,
    'STANISLOWSKI': 0,
    'STANISZ': 0,
    'STANISZEWSKI': 0,
    'STANK': 0,
    'STANKARD': 0,
    'STANKE': 0,
    'STANKER': 0,
    'STANKEVICH': 0,
    'STANKEVITZ': 0,
    'STANKEWICZ': 0,
    'STANKEWITZ': 0,
    'STANKEY': 0,
    'STANKIEWICZ': 0,
    'STANKO': 0,
    'STANKOSKI': 0,
    'STANKOV': 0,
    'STANKOVIC': 0,
    'STANKOVICH': 0,
    'STANKOWSKI': 0,
    'STANKUS': 0,
    'STANLEY': 0.8424676148201831,
    'STANLY': 0,
    'STANN': 0,
    'STANNARD': 0,
    'STANNER': 0,
    'STANO': 0,
    'STANOCH': 0,
    'STANOJEVIC': 0,
    'STANONIK': 0,
    'STANOVICH': 0,
    'STANOWSKI': 0,
    'STANPHILL': 0,
    'STANS': 0,
    'STANSBERRY': 0,
    'STANSBERY': 0,
    'STANSBURY': 0,
    'STANSEL': 0,
    'STANSELL': 0,
    'STANSFIELD': 0,
    'STANSIFER': 0,
    'STANSILL': 0,
    'STANSKI': 0,
    'STANSKY': 0,
    'STANSON': 0,
    'STANT': 0,
    'STANTOINE': 0,
    'STANTON': 0.23668639053254442,
    'STANTS': 0,
    'STANTZ': 0,
    'STANULIS': 0,
    'STANUSH': 0,
    'STANWICK': 0,
    'STANWIX': 0,
    'STANWOOD': 0,
    'STANWORTH': 0,
    'STANYARD': 0,
    'STANZ': 0,
    'STANZEL': 0,
    'STANZIALE': 0,
    'STANZIANO': 0,
    'STANZIOLA': 0,
    'STANZIONE': 0,
    'STAP': 0,
    'STAPE': 0,
    'STAPEL': 0,
    'STAPELTON': 0,
    'STAPERT': 0,
    'STAPF': 0,
    'STAPH': 0,
    'STAPINSKI': 0,
    'STAPISH': 0,
    'STAPLE': 0,
    'STAPLEFORD': 0,
    'STAPLER': 0,
    'STAPLES': 0,
    'STAPLETON': 0,
    'STAPLEY': 0,
    'STAPOR': 0,
    'STAPP': 0,
    'STAPPENBECK': 0,
    'STAPPER': 0,
    'STAR': 0.8174386920980927,
    'STARA': 0,
    'STARACE': 0,
    'STARAL': 0,
    'STARBARD': 0,
    'STARBIRD': 0,
    'STARBUCK': 0,
    'STARCEVIC': 0,
    'STARCEVICH': 0,
    'STARCH': 0,
    'STARCHER': 0,
    'STARCHMAN': 0,
    'STARCK': 0,
    'STARCZEWSKI': 0,
    'STARE': 0,
    'STAREK': 0,
    'STARER': 0,
    'STARGARDT': 0,
    'STARGEL': 0,
    'STARGELL': 0,
    'STARGHILL': 0,
    'STARICH': 0,
    'STARIHA': 0,
    'STARIN': 0,
    'STARING': 0,
    'STARINSKY': 0,
    'STARITA': 0,
    'STARK': 0,
    'STARKE': 0,
    'STARKEBAUM': 0,
    'STARKEL': 0,
    'STARKEN': 0,
    'STARKENBURG': 0,
    'STARKER': 0,
    'STARKES': 0,
    'STARKEY': 0,
    'STARKIE': 0,
    'STARKMAN': 0,
    'STARKOVICH': 0,
    'STARKS': 0,
    'STARKSON': 0,
    'STARKWEATHER': 0,
    'STARKY': 0,
    'STARLA': 1,
    'STARLEY': 0,
    'STARLIN': 0,
    'STARLING': 0,
    'STARLINGS': 0,
    'STARLIPER': 0,
    'STARMAN': 0,
    'STARMAND': 0,
    'STARMER': 0,
    'STARN': 0,
    'STARNAUD': 0,
    'STARNAULD': 0,
    'STARNER': 0,
    'STARNES': 0,
    'STARNOLD': 0,
    'STARNS': 0,
    'STAROBA': 0,
    'STAROBIN': 0,
    'STARON': 0,
    'STAROPOLI': 0,
    'STAROSCIAK': 0,
    'STAROSTA': 0,
    'STAROSTKA': 0,
    'STAROWICZ': 0,
    'STARR': 0.276625172890733,
    'STARRATT': 0,
    'STARRETT': 0,
    'STARRICK': 0,
    'STARRING': 0,
    'STARRITT': 0,
    'STARRS': 0,
    'STARRY': 0,
    'STARSIAK': 0,
    'START': 0,
    'STARTIN': 0,
    'STARTS': 0,
    'STARTT': 0,
    'STARTUP': 0,
    'STARTZ': 0,
    'STARTZEL': 0,
    'STARTZMAN': 0,
    'STARUCH': 0,
    'STARWALT': 0,
    'STARY': 0,
    'STARZ': 0,
    'STARZEC': 0,
    'STARZYK': 0,
    'STARZYNSKI': 0,
    'STAS': 0,
    'STASA': 0,
    'STASAK': 0,
    'STASCH': 0,
    'STASCHKE': 0,
    'STASEK': 0,
    'STASEL': 0,
    'STASER': 0,
    'STASH': 0,
    'STASHAK': 0,
    'STASI': 0,
    'STASIA': 1,
    'STASIAK': 0,
    'STASIEWICZ': 0,
    'STASIK': 0,
    'STASINOS': 0,
    'STASINSKI': 0,
    'STASIO': 0,
    'STASIOWSKI': 0,
    'STASIUK': 0,
    'STASKA': 0,
    'STASKAL': 0,
    'STASKIEWICZ': 0,
    'STASKO': 0,
    'STASKOWSKI': 0,
    'STASKUS': 0,
    'STASKY': 0,
    'STASNEY': 0,
    'STASNY': 0,
    'STASO': 0,
    'STASS': 0,
    'STASSEN': 0,
    'STASSI': 0,
    'STASTNY': 0,
    'STASZAK': 0,
    'STASZEL': 0,
    'STASZEWSKI': 0,
    'STASZKO': 0,
    'STATA': 0,
    'STATE': 0,
    'STATELER': 0,
    'STATELY': 0,
    'STATEMA': 0,
    'STATEMAN': 0,
    'STATEN': 0,
    'STATER': 0,
    'STATES': 0,
    'STATH': 0,
    'STATHAKIS': 0,
    'STATHAM': 0,
    'STATHAS': 0,
    'STATHATOS': 0,
    'STATHEM': 0,
    'STATHES': 0,
    'STATHIS': 0,
    'STATHOPOULOS': 0,
    'STATHOS': 0,
    'STATILE': 0,
    'STATION': 0,
    'STATKIEWICZ': 0,
    'STATKUS': 0,
    'STATLER': 0,
    'STATMAN': 0,
    'STATOM': 0,
    'STATON': 0,
    'STATS': 0,
    'STATT': 0,
    'STATTELMAN': 0,
    'STATTER': 0,
    'STATTON': 0,
    'STATTS': 0,
    'STATUM': 0,
    'STATZ': 0,
    'STATZER': 0,
    'STAUB': 0,
    'STAUBACH': 0,
    'STAUBER': 0,
    'STAUBIN': 0,
    'STAUBITZ': 0,
    'STAUBLE': 0,
    'STAUBS': 0,
    'STAUBUS': 0,
    'STAUCH': 0,
    'STAUD': 0,
    'STAUDACHER': 0,
    'STAUDE': 0,
    'STAUDENMAIER': 0,
    'STAUDENMAYER': 0,
    'STAUDER': 0,
    'STAUDINGER': 0,
    'STAUDT': 0,
    'STAUFENBERG': 0,
    'STAUFENBERGER': 0,
    'STAUFER': 0,
    'STAUFF': 0,
    'STAUFFACHER': 0,
    'STAUFFENBERG': 0,
    'STAUFFER': 0,
    'STAUGLER': 0,
    'STAUM': 0,
    'STAUNER': 0,
    'STAUNTON': 0,
    'STAUP': 0,
    'STAUPE': 0,
    'STAURING': 0,
    'STAUS': 0,
    'STAUSS': 0,
    'STAUTBERG': 0,
    'STAUTER': 0,
    'STAUTS': 0,
    'STAUTZ': 0,
    'STAUTZENBERGER': 0,
    'STAVA': 0,
    'STAVALE': 0,
    'STAVE': 0,
    'STAVELEY': 0,
    'STAVELY': 0,
    'STAVEN': 0,
    'STAVER': 0,
    'STAVES': 0,
    'STAVIG': 0,
    'STAVINOHA': 0,
    'STAVIS': 0,
    'STAVISH': 0,
    'STAVISKY': 0,
    'STAVOLA': 0,
    'STAVRAKIS': 0,
    'STAVROPOULOS': 0,
    'STAVROS': 0,
    'STAVROU': 0,
    'STAWARZ': 0,
    'STAWASZ': 0,
    'STAWECKI': 0,
    'STAWIARSKI': 0,
    'STAWICKI': 0,
    'STAWINSKI': 0,
    'STAWSKI': 0,
    'STAY': 0,
    'STAYDUHAR': 0,
    'STAYER': 0,
    'STAYLOR': 0,
    'STAYMAN': 0,
    'STAYNER': 0,
    'STAYROOK': 0,
    'STAYTON': 0,
    'STAZZONE': 0,
    'STBERNARD': 0,
    'STCHARLES': 0,
    'STCIN': 0,
    'STCLAIR': 0,
    'STCLAIRE': 0,
    'STCLOUD': 0,
    'STCROIX': 0,
    'STCYR': 0,
    'STDENIS': 0,
    'STDENNIS': 0,
    'STDON': 0,
    'STEA': 0,
    'STEACH': 0,
    'STEACY': 0,
    'STEAD': 0,
    'STEADHAM': 0,
    'STEADING': 0,
    'STEADMAN': 0,
    'STEADY': 0,
    'STEAGALL': 0,
    'STEAGER': 0,
    'STEAKLEY': 0,
    'STEALEY': 0,
    'STEALY': 0,
    'STEAMER': 0,
    'STEAN': 0,
    'STEANS': 0,
    'STEAR': 0,
    'STEARLEY': 0,
    'STEARMAN': 0,
    'STEARN': 0,
    'STEARNES': 0,
    'STEARNS': 0,
    'STEARS': 0,
    'STEAVENS': 0,
    'STEBBING': 0,
    'STEBBINGS': 0,
    'STEBBINS': 0,
    'STEBE': 0,
    'STEBEL': 0,
    'STEBELTON': 0,
    'STEBEN': 0,
    'STEBENNE': 0,
    'STEBENS': 0,
    'STEBER': 0,
    'STEBLER': 0,
    'STEBLETON': 0,
    'STEBNER': 0,
    'STEC': 0,
    'STECH': 0,
    'STECHER': 0,
    'STECHMAN': 0,
    'STECHMANN': 0,
    'STECHSCHULTE': 0,
    'STECK': 0,
    'STECKBAUER': 0,
    'STECKBECK': 0,
    'STECKEL': 0,
    'STECKELBERG': 0,
    'STECKER': 0,
    'STECKERT': 0,
    'STECKI': 0,
    'STECKLEIN': 0,
    'STECKLER': 0,
    'STECKLEY': 0,
    'STECKLINE': 0,
    'STECKLING': 0,
    'STECKLY': 0,
    'STECKMAN': 0,
    'STECKO': 0,
    'STECYK': 0,
    'STECZ': 0,
    'STEDDUM': 0,
    'STEDER': 0,
    'STEDGE': 0,
    'STEDHAM': 0,
    'STEDING': 0,
    'STEDMAN': 0,
    'STEDNITZ': 0,
    'STEDRONSKY': 0,
    'STEDRY': 0,
    'STEEB': 0,
    'STEEBER': 0,
    'STEEBY': 0,
    'STEECE': 0,
    'STEED': 0,
    'STEEDE': 0,
    'STEEDLE': 0,
    'STEEDLEY': 0,
    'STEEDLY': 0,
    'STEEDMAN': 0,
    'STEEG': 0,
    'STEEGE': 0,
    'STEEGER': 0,
    'STEEL': 0,
    'STEELE': 0,
    'STEELEY': 0,
    'STEELHAMMER': 0,
    'STEELMAN': 0,
    'STEELS': 0,
    'STEELSMITH': 0,
    'STEELY': 0,
    'STEEN': 0,
    'STEENBERG': 0,
    'STEENBERGEN': 0,
    'STEENBERGH': 0,
    'STEENBLIK': 0,
    'STEENBLOCK': 0,
    'STEENBOCK': 0,
    'STEENBURG': 0,
    'STEENBURGH': 0,
    'STEENECK': 0,
    'STEENERSON': 0,
    'STEENHARD': 0,
    'STEENHOEK': 0,
    'STEENHOVEN': 0,
    'STEENKEN': 0,
    'STEENLAND': 0,
    'STEENO': 0,
    'STEENROD': 0,
    'STEENSEN': 0,
    'STEENSLAND': 0,
    'STEENSMA': 0,
    'STEENSON': 0,
    'STEENSTRA': 0,
    'STEENWYK': 0,
    'STEEP': 0,
    'STEEPLES': 0,
    'STEEPLETON': 0,
    'STEER': 0,
    'STEERE': 0,
    'STEERMAN': 0,
    'STEERS': 0,
    'STEES': 0,
    'STEESE': 0,
    'STEETS': 0,
    'STEEVE': 0,
    'STEEVENS': 0,
    'STEEVER': 0,
    'STEEVES': 0,
    'STEFAN': 0.8991008991008991,
    'STEFANAC': 0,
    'STEFANACCI': 0,
    'STEFANAK': 0,
    'STEFANCIC': 0,
    'STEFANCIK': 0,
    'STEFANCIN': 0,
    'STEFANEK': 0,
    'STEFANELLI': 0,
    'STEFANESCU': 0,
    'STEFANI': 0.8287292817679558,
    'STEFANIA': 1,
    'STEFANIAK': 0,
    'STEFANIC': 0,
    'STEFANICH': 0,
    'STEFANICK': 0,
    'STEFANIDES': 0,
    'STEFANIDIS': 0,
    'STEFANIE': 0.997624703087886,
    'STEFANIK': 0,
    'STEFANINI': 0,
    'STEFANKO': 0,
    'STEFANO': 0,
    'STEFANOFF': 0,
    'STEFANONI': 0,
    'STEFANOPOULOS': 0,
    'STEFANOS': 0,
    'STEFANOU': 0,
    'STEFANOV': 0,
    'STEFANOVIC': 0,
    'STEFANOVICH': 0,
    'STEFANOVSKI': 0,
    'STEFANOW': 0,
    'STEFANOWICZ': 0,
    'STEFANOWSKI': 0,
    'STEFANS': 0,
    'STEFANSKI': 0,
    'STEFANSKY': 0,
    'STEFANY': 0.9433962264150944,
    'STEFEK': 0,
    'STEFF': 0,
    'STEFFA': 0,
    'STEFFAN': 0,
    'STEFFANI': 0,
    'STEFFANIE': 1,
    'STEFFANS': 0,
    'STEFFE': 0,
    'STEFFEE': 0,
    'STEFFEK': 0,
    'STEFFEL': 0,
    'STEFFEN': 0,
    'STEFFENHAGEN': 0,
    'STEFFENS': 0,
    'STEFFENSEN': 0,
    'STEFFENSMEIER': 0,
    'STEFFENSON': 0,
    'STEFFER': 0,
    'STEFFES': 0,
    'STEFFEY': 0,
    'STEFFKE': 0,
    'STEFFL': 0,
    'STEFFLER': 0,
    'STEFFY': 0,
    'STEFKA': 0,
    'STEFKO': 0,
    'STEFKOVICH': 0,
    'STEFL': 0,
    'STEFONEK': 0,
    'STEFURAK': 0,
    'STEG': 0,
    'STEGAL': 0,
    'STEGALL': 0,
    'STEGBAUER': 0,
    'STEGE': 0,
    'STEGEMAN': 0,
    'STEGEMANN': 0,
    'STEGEMILLER': 0,
    'STEGEMOLLER': 0,
    'STEGEN': 0,
    'STEGENGA': 0,
    'STEGER': 0,
    'STEGGALL': 0,
    'STEGGELL': 0,
    'STEGGERDA': 0,
    'STEGINK': 0,
    'STEGLICH': 0,
    'STEGMAIER': 0,
    'STEGMAN': 0,
    'STEGMANN': 0,
    'STEGMEIER': 0,
    'STEGMILLER': 0,
    'STEGNER': 0,
    'STEGURA': 0,
    'STEHL': 0,
    'STEHLE': 0,
    'STEHLEY': 0,
    'STEHLI': 0,
    'STEHLIK': 0,
    'STEHLIN': 0,
    'STEHLING': 0,
    'STEHLY': 0,
    'STEHMAN': 0,
    'STEHN': 0,
    'STEHNO': 0,
    'STEHOUWER': 0,
    'STEHR': 0,
    'STEIB': 0,
    'STEIBEL': 0,
    'STEIBER': 0,
    'STEICH': 0,
    'STEICHEN': 0,
    'STEIDEL': 0,
    'STEIDER': 0,
    'STEIDING': 0,
    'STEIDINGER': 0,
    'STEIDL': 0,
    'STEIDLE': 0,
    'STEIDLER': 0,
    'STEIDLEY': 0,
    'STEIER': 0,
    'STEIERT': 0,
    'STEIF': 0,
    'STEIG': 0,
    'STEIGAUF': 0,
    'STEIGELMAN': 0,
    'STEIGER': 0,
    'STEIGERWALD': 0,
    'STEIGERWALT': 0,
    'STEIGHNER': 0,
    'STEIGLEDER': 0,
    'STEIGLEMAN': 0,
    'STEIGLER': 0,
    'STEIGMAN': 0,
    'STEIGMEYER': 0,
    'STEIGNER': 0,
    'STEIK': 0,
    'STEIL': 0,
    'STEILEN': 0,
    'STEIMAN': 0,
    'STEIMEL': 0,
    'STEIMER': 0,
    'STEIMLE': 0,
    'STEIN': 0,
    'STEINACHER': 0,
    'STEINACKER': 0,
    'STEINAGEL': 0,
    'STEINAU': 0,
    'STEINAUER': 0,
    'STEINBACH': 0,
    'STEINBACHER': 0,
    'STEINBACK': 0,
    'STEINBAUER': 0,
    'STEINBAUGH': 0,
    'STEINBAUM': 0,
    'STEINBECK': 0,
    'STEINBECKER': 0,
    'STEINBERG': 0,
    'STEINBERGER': 0,
    'STEINBOCK': 0,
    'STEINBORN': 0,
    'STEINBRECHER': 0,
    'STEINBRENNER': 0,
    'STEINBRING': 0,
    'STEINBRINK': 0,
    'STEINBRONN': 0,
    'STEINBROOK': 0,
    'STEINBRUECK': 0,
    'STEINBRUEGGE': 0,
    'STEINBRUNNER': 0,
    'STEINBURG': 0,
    'STEINDEL': 0,
    'STEINDL': 0,
    'STEINDLER': 0,
    'STEINDORF': 0,
    'STEINE': 0,
    'STEINEBACH': 0,
    'STEINECKE': 0,
    'STEINEKE': 0,
    'STEINEL': 0,
    'STEINEMAN': 0,
    'STEINEMANN': 0,
    'STEINER': 0,
    'STEINERT': 0,
    'STEINES': 0,
    'STEINFELD': 0,
    'STEINFELDT': 0,
    'STEINFORT': 0,
    'STEINFURTH': 0,
    'STEINGART': 0,
    'STEINGASS': 0,
    'STEINGOLD': 0,
    'STEINGRABER': 0,
    'STEINHAGEN': 0,
    'STEINHARDT': 0,
    'STEINHART': 0,
    'STEINHAUER': 0,
    'STEINHAUS': 0,
    'STEINHAUSER': 0,
    'STEINHEBEL': 0,
    'STEINHEIMER': 0,
    'STEINHEISER': 0,
    'STEINHILBER': 0,
    'STEINHOFER': 0,
    'STEINHOFF': 0,
    'STEINHORN': 0,
    'STEINHORST': 0,
    'STEINHOUR': 0,
    'STEINHOUSE': 0,
    'STEINIGER': 0,
    'STEINIKE': 0,
    'STEININGER': 0,
    'STEINITZ': 0,
    'STEINKAMP': 0,
    'STEINKE': 0,
    'STEINKIRCHNER': 0,
    'STEINKOENIG': 0,
    'STEINKOPF': 0,
    'STEINKRAUS': 0,
    'STEINKRUGER': 0,
    'STEINKUEHLER': 0,
    'STEINLAGE': 0,
    'STEINLAUF': 0,
    'STEINLE': 0,
    'STEINLEY': 0,
    'STEINLICHT': 0,
    'STEINLY': 0,
    'STEINMACHER': 0,
    'STEINMAN': 0,
    'STEINMANN': 0,
    'STEINMARK': 0,
    'STEINMEIER': 0,
    'STEINMETZ': 0,
    'STEINMEYER': 0,
    'STEINMILLER': 0,
    'STEINMULLER': 0,
    'STEINOCHER': 0,
    'STEINOUR': 0,
    'STEINRUCK': 0,
    'STEINS': 0,
    'STEINSIEK': 0,
    'STEINWACHS': 0,
    'STEINWAND': 0,
    'STEINWAY': 0,
    'STEINWEG': 0,
    'STEINWINDER': 0,
    'STEIR': 0,
    'STEIRER': 0,
    'STEIS': 0,
    'STEISKAL': 0,
    'STEITZ': 0,
    'STEJSKAL': 0,
    'STEK': 0,
    'STEKETEE': 0,
    'STELE': 0,
    'STELFOX': 0,
    'STELIGA': 0,
    'STELK': 0,
    'STELL': 0,
    'STELLA': 0.9827725748641462,
    'STELLABOTTE': 0,
    'STELLAR': 0,
    'STELLATO': 0,
    'STELLE': 0,
    'STELLEMA': 0,
    'STELLER': 0,
    'STELLEY': 0,
    'STELLFOX': 0,
    'STELLHORN': 0,
    'STELLICK': 0,
    'STELLING': 0,
    'STELLINGWERF': 0,
    'STELLINI': 0,
    'STELLJES': 0,
    'STELLMACH': 0,
    'STELLMACHER': 0,
    'STELLMAN': 0,
    'STELLNER': 0,
    'STELLO': 0,
    'STELLOH': 0,
    'STELLON': 0,
    'STELLPFLUG': 0,
    'STELLRECHT': 0,
    'STELLUTO': 0,
    'STELLWAG': 0,
    'STELLWAGEN': 0,
    'STELLY': 0,
    'STELMA': 0,
    'STELMACH': 0,
    'STELMACK': 0,
    'STELMAN': 0,
    'STELMASZEK': 0,
    'STELPFLUG': 0,
    'STELTENPOHL': 0,
    'STELTER': 0,
    'STELTING': 0,
    'STELTON': 0,
    'STELTS': 0,
    'STELTZ': 0,
    'STELTZER': 0,
    'STELZEL': 0,
    'STELZER': 0,
    'STELZIG': 0,
    'STELZNER': 0,
    'STEM': 0,
    'STEMARIE': 0,
    'STEMBER': 0,
    'STEMBERGER': 0,
    'STEMBRIDGE': 0,
    'STEMEN': 0,
    'STEMKOWSKI': 0,
    'STEMLE': 0,
    'STEMLER': 0,
    'STEMLEY': 0,
    'STEMM': 0,
    'STEMME': 0,
    'STEMMER': 0,
    'STEMMERMAN': 0,
    'STEMMLE': 0,
    'STEMMLER': 0,
    'STEMMONS': 0,
    'STEMP': 0,
    'STEMPEL': 0,
    'STEMPER': 0,
    'STEMPIEN': 0,
    'STEMPIN': 0,
    'STEMPINSKI': 0,
    'STEMPKOWSKI': 0,
    'STEMPKY': 0,
    'STEMPLE': 0,
    'STEMPLER': 0,
    'STEMPOWSKI': 0,
    'STEMRICH': 0,
    'STEMWEDEL': 0,
    'STEN': 0,
    'STENART': 0,
    'STENBACK': 0,
    'STENBECK': 0,
    'STENBERG': 0,
    'STENCE': 0,
    'STENCEL': 0,
    'STENCIL': 0,
    'STENDAHL': 0,
    'STENDARDO': 0,
    'STENDEL': 0,
    'STENDER': 0,
    'STENE': 0,
    'STENECK': 0,
    'STENEHJEM': 0,
    'STENERSEN': 0,
    'STENERSON': 0,
    'STENFTENAGEL': 0,
    'STENGEL': 0,
    'STENGER': 0,
    'STENGL': 0,
    'STENGLE': 0,
    'STENGLEIN': 0,
    'STENHOLM': 0,
    'STENHOUSE': 0,
    'STENKE': 0,
    'STENLUND': 0,
    'STENMAN': 0,
    'STENMARK': 0,
    'STENNER': 0,
    'STENNES': 0,
    'STENNETT': 0,
    'STENNIS': 0,
    'STENQUIST': 0,
    'STENROOS': 0,
    'STENSAAS': 0,
    'STENSBY': 0,
    'STENSEN': 0,
    'STENSETH': 0,
    'STENSGAARD': 0,
    'STENSGARD': 0,
    'STENSLAND': 0,
    'STENSLIE': 0,
    'STENSON': 0,
    'STENSRUD': 0,
    'STENSTROM': 0,
    'STENT': 0,
    'STENTA': 0,
    'STENTIFORD': 0,
    'STENTO': 0,
    'STENTON': 0,
    'STENTZ': 0,
    'STENULSON': 0,
    'STENZ': 0,
    'STENZEL': 0,
    'STEO': 0,
    'STEORTS': 0,
    'STEP': 0,
    'STEPAN': 0,
    'STEPANEK': 0,
    'STEPANENKO': 0,
    'STEPANIAK': 0,
    'STEPANIAN': 0,
    'STEPANIE': 1,
    'STEPANIK': 0,
    'STEPANOFF': 0,
    'STEPANOV': 0,
    'STEPANOVIC': 0,
    'STEPANOVICH': 0,
    'STEPANSKI': 0,
    'STEPANSKY': 0,
    'STEPANYAN': 0,
    'STEPEK': 0,
    'STEPH': 0,
    'STEPHAINE': 1,
    'STEPHAN': 0.8633093525179857,
    'STEPHANE': 1,
    'STEPHANI': 0.9404388714733541,
    'STEPHANIA': 1,
    'STEPHANIAN': 0,
    'STEPHANIC': 0,
    'STEPHANIE': 0.999550202408916,
    'STEPHANO': 0,
    'STEPHANOFF': 0,
    'STEPHANOS': 0,
    'STEPHANS': 0,
    'STEPHANSEN': 0,
    'STEPHANSON': 0,
    'STEPHANY': 0.931098696461825,
    'STEPHEN': 0.9939300581320716,
    'STEPHENIE': 1,
    'STEPHENS': 0,
    'STEPHENSEN': 0,
    'STEPHENSON': 0,
    'STEPHERSON': 0,
    'STEPHESON': 0,
    'STEPHEY': 0,
    'STEPHINE': 1,
    'STEPHNEY': 0,
    'STEPHNIE': 1,
    'STEPHON': 0,
    'STEPHSON': 0,
    'STEPIC': 0,
    'STEPIEN': 0,
    'STEPINA': 0,
    'STEPKA': 0,
    'STEPKE': 0,
    'STEPLER': 0,
    'STEPLETON': 0,
    'STEPLIGHT': 0,
    'STEPNEY': 0,
    'STEPNIAK': 0,
    'STEPNICK': 0,
    'STEPNIEWSKI': 0,
    'STEPNOSKI': 0,
    'STEPNOWSKI': 0,
    'STEPP': 0,
    'STEPPE': 0,
    'STEPPER': 0,
    'STEPPS': 0,
    'STEPRO': 0,
    'STEPTER': 0,
    'STEPTOE': 0,
    'STER': 0,
    'STERANKA': 0,
    'STERANKO': 0,
    'STERBA': 0,
    'STERBENZ': 0,
    'STERCHI': 0,
    'STERE': 0,
    'STERENBERG': 0,
    'STERETT': 0,
    'STERGAR': 0,
    'STERGER': 0,
    'STERGION': 0,
    'STERGIOS': 0,
    'STERGIOU': 0,
    'STERIA': 0,
    'STERIO': 0,
    'STERITI': 0,
    'STERK': 0,
    'STERKEL': 0,
    'STERKEN': 0,
    'STERKENBURG': 0,
    'STERLACCI': 0,
    'STERLACE': 0,
    'STERLE': 0,
    'STERLEY': 0,
    'STERLIN': 0,
    'STERLING': 0.6397441023590564,
    'STERMAN': 0,
    'STERMER': 0,
    'STERN': 0,
    'STERNA': 0,
    'STERNAD': 0,
    'STERNADEL': 0,
    'STERNAL': 0,
    'STERNAMAN': 0,
    'STERNARD': 0,
    'STERNAT': 0,
    'STERNBACH': 0,
    'STERNBERG': 0,
    'STERNBERGER': 0,
    'STERNE': 0,
    'STERNER': 0,
    'STERNES': 0,
    'STERNFELD': 0,
    'STERNFELS': 0,
    'STERNHAGEN': 0,
    'STERNICK': 0,
    'STERNIG': 0,
    'STERNIK': 0,
    'STERNISHA': 0,
    'STERNITZKE': 0,
    'STERNITZKY': 0,
    'STERNLICHT': 0,
    'STERNLIEB': 0,
    'STERNQUIST': 0,
    'STERNS': 0,
    'STERNSTEIN': 0,
    'STERNTHAL': 0,
    'STERR': 0,
    'STERRENBERG': 0,
    'STERRETT': 0,
    'STERRITT': 0,
    'STERRY': 0,
    'STERTZ': 0,
    'STERTZBACH': 0,
    'STERUD': 0,
    'STERWERF': 0,
    'STERZER': 0,
    'STERZINGER': 0,
    'STESKAL': 0,
    'STESNEY': 0,
    'STESSMAN': 0,
    'STETAR': 0,
    'STETHEM': 0,
    'STETINA': 0,
    'STETKA': 0,
    'STETLER': 0,
    'STETS': 0,
    'STETSER': 0,
    'STETSON': 0,
    'STETTER': 0,
    'STETTIN': 0,
    'STETTLER': 0,
    'STETTNER': 0,
    'STETTS': 0,
    'STETZ': 0,
    'STETZEL': 0,
    'STETZER': 0,
    'STETZLER': 0,
    'STEUART': 0,
    'STEUBE': 0,
    'STEUBEN': 0,
    'STEUBER': 0,
    'STEUBING': 0,
    'STEUCK': 0,
    'STEUDLE': 0,
    'STEUDLER': 0,
    'STEUER': 0,
    'STEUERNAGEL': 0,
    'STEUERWALD': 0,
    'STEUP': 0,
    'STEURER': 0,
    'STEURY': 0,
    'STEVA': 0,
    'STEVANOVIC': 0,
    'STEVANS': 0,
    'STEVANUS': 0,
    'STEVE': 0.9969604863221884,
    'STEVEN': 0.998531571218796,
    'STEVENER': 0,
    'STEVENS': 0,
    'STEVENSEN': 0,
    'STEVENSON': 0,
    'STEVENTON': 0,
    'STEVER': 0,
    'STEVERMAN': 0,
    'STEVERMER': 0,
    'STEVERS': 0,
    'STEVERSON': 0,
    'STEVES': 0,
    'STEVESON': 0,
    'STEVEY': 0,
    'STEVIC': 0,
    'STEVICK': 0,
    'STEVIE': 0.994475138121547,
    'STEVINSON': 0,
    'STEVISON': 0,
    'STEWARD': 0,
    'STEWARDSON': 0,
    'STEWART': 0.15943184288716575,
    'STEWMAN': 0,
    'STEYAERT': 0,
    'STEYER': 0,
    'STEYN': 0,
    'STFELIX': 0,
    'STFLEUR': 0,
    'STFORT': 0,
    'STFRANCIS': 0,
    'STGELAIS': 0,
    'STGEORGE': 0,
    'STGERMAIN': 0,
    'STGERMAINE': 0,
    'STHILAIRE': 0,
    'STHILL': 0,
    'STHUBERT': 0,
    'STIBAL': 0,
    'STIBB': 0,
    'STIBBE': 0,
    'STIBER': 0,
    'STIBICH': 0,
    'STIBITZ': 0,
    'STICCA': 0,
    'STICCO': 0,
    'STICE': 0,
    'STICH': 0,
    'STICHA': 0,
    'STICHER': 0,
    'STICHLER': 0,
    'STICHMAN': 0,
    'STICHT': 0,
    'STICHTER': 0,
    'STICK': 0,
    'STICKA': 0,
    'STICKEL': 0,
    'STICKELL': 0,
    'STICKELMAN': 0,
    'STICKELS': 0,
    'STICKER': 0,
    'STICKFORD': 0,
    'STICKFORT': 0,
    'STICKLAND': 0,
    'STICKLE': 0,
    'STICKLEN': 0,
    'STICKLER': 0,
    'STICKLES': 0,
    'STICKLEY': 0,
    'STICKMAN': 0,
    'STICKNEY': 0,
    'STICKROD': 0,
    'STIDAM': 0,
    'STIDD': 0,
    'STIDFOLE': 0,
    'STIDGER': 0,
    'STIDHAM': 0,
    'STIDHUM': 0,
    'STIDMAN': 0,
    'STIDOM': 0,
    'STIDUM': 0,
    'STIEB': 0,
    'STIEBEL': 0,
    'STIEBEN': 0,
    'STIEBER': 0,
    'STIEBING': 0,
    'STIEBS': 0,
    'STIEF': 0,
    'STIEFEL': 0,
    'STIEFER': 0,
    'STIEFERMAN': 0,
    'STIEFF': 0,
    'STIEFVATER': 0,
    'STIEG': 0,
    'STIEGEL': 0,
    'STIEGELMEIER': 0,
    'STIEGELMEYER': 0,
    'STIEGEMEIER': 0,
    'STIEGER': 0,
    'STIEGLER': 0,
    'STIEGLITZ': 0,
    'STIEGMAN': 0,
    'STIEHL': 0,
    'STIEHLER': 0,
    'STIEHM': 0,
    'STIEHR': 0,
    'STIEL': 0,
    'STIELER': 0,
    'STIELOW': 0,
    'STIELY': 0,
    'STIEMKE': 0,
    'STIEMSMA': 0,
    'STIEN': 0,
    'STIENBARGER': 0,
    'STIENE': 0,
    'STIENECKER': 0,
    'STIENER': 0,
    'STIENS': 0,
    'STIENSTRA': 0,
    'STIER': 0,
    'STIEREN': 0,
    'STIERHOFF': 0,
    'STIERLE': 0,
    'STIERMAN': 0,
    'STIERS': 0,
    'STIERWALT': 0,
    'STIETZ': 0,
    'STIEVE': 0,
    'STIFEL': 0,
    'STIFF': 0,
    'STIFFARM': 0,
    'STIFFEY': 0,
    'STIFFLEMIRE': 0,
    'STIFFLER': 0,
    'STIFLE': 0,
    'STIFLER': 0,
    'STIFT': 0,
    'STIFTER': 0,
    'STIGALL': 0,
    'STIGEN': 0,
    'STIGER': 0,
    'STIGERS': 0,
    'STIGGE': 0,
    'STIGGER': 0,
    'STIGGERS': 0,
    'STIGGINS': 0,
    'STIGLEMAN': 0,
    'STIGLER': 0,
    'STIGLETS': 0,
    'STIGLIANO': 0,
    'STIGLICH': 0,
    'STIGLITZ': 0,
    'STIKA': 0,
    'STIKE': 0,
    'STIKELEATHER': 0,
    'STIKES': 0,
    'STILE': 0,
    'STILEN': 0,
    'STILES': 0,
    'STILGENBAUER': 0,
    'STILGER': 0,
    'STILL': 0,
    'STILLABOWER': 0,
    'STILLDAY': 0,
    'STILLE': 0,
    'STILLER': 0,
    'STILLERMAN': 0,
    'STILLEY': 0,
    'STILLING': 0,
    'STILLINGER': 0,
    'STILLINGS': 0,
    'STILLION': 0,
    'STILLIONS': 0,
    'STILLITANO': 0,
    'STILLMAN': 0,
    'STILLO': 0,
    'STILLS': 0,
    'STILLSON': 0,
    'STILLWAGGON': 0,
    'STILLWAGON': 0,
    'STILLWELL': 0,
    'STILO': 0,
    'STILP': 0,
    'STILPHEN': 0,
    'STILSON': 0,
    'STILTNER': 0,
    'STILTS': 0,
    'STILTZ': 0,
    'STILWELL': 0,
    'STILWILL': 0,
    'STILZ': 0,
    'STIMA': 0,
    'STIMAC': 0,
    'STIMACH': 0,
    'STIMAGE': 0,
    'STIMATZE': 0,
    'STIMELING': 0,
    'STIMELY': 0,
    'STIMER': 0,
    'STIMLER': 0,
    'STIMMEL': 0,
    'STIMMELL': 0,
    'STIMMLER': 0,
    'STIMPERT': 0,
    'STIMPLE': 0,
    'STIMPSON': 0,
    'STIMSON': 0,
    'STINAR': 0,
    'STINARD': 0,
    'STINCHCOMB': 0,
    'STINCHFIELD': 0,
    'STINDT': 0,
    'STINE': 0,
    'STINEBAUGH': 0,
    'STINEBISER': 0,
    'STINEDURF': 0,
    'STINEHART': 0,
    'STINEHELFER': 0,
    'STINEHOUR': 0,
    'STINEMAN': 0,
    'STINEMETZ': 0,
    'STINER': 0,
    'STINES': 0,
    'STINESPRING': 0,
    'STINETT': 0,
    'STING': 0,
    'STINGEL': 0,
    'STINGER': 0,
    'STINGL': 0,
    'STINGLE': 0,
    'STINGLEY': 0,
    'STINGO': 0,
    'STINN': 0,
    'STINNER': 0,
    'STINNET': 0,
    'STINNETT': 0,
    'STINNETTE': 0,
    'STINNEY': 0,
    'STINNIE': 0,
    'STINSKI': 0,
    'STINSMAN': 0,
    'STINSON': 0,
    'STINTON': 0,
    'STIO': 0,
    'STIPA': 0,
    'STIPANOVIC': 0,
    'STIPANOVICH': 0,
    'STIPE': 0,
    'STIPEK': 0,
    'STIPES': 0,
    'STIPETICH': 0,
    'STIPP': 0,
    'STIPPICH': 0,
    'STIRE': 0,
    'STIRES': 0,
    'STIREWALT': 0,
    'STIRGUS': 0,
    'STIRK': 0,
    'STIRLAND': 0,
    'STIRLING': 0,
    'STIRM': 0,
    'STIRMAN': 0,
    'STIRN': 0,
    'STIRNAMAN': 0,
    'STIRPE': 0,
    'STIRRAT': 0,
    'STIRRETT': 0,
    'STIRRUP': 0,
    'STIRSMAN': 0,
    'STIRTON': 0,
    'STISH': 0,
    'STISO': 0,
    'STISSER': 0,
    'STITCH': 0,
    'STITCHER': 0,
    'STITELER': 0,
    'STITELY': 0,
    'STITES': 0,
    'STITH': 0,
    'STITHAM': 0,
    'STITHEM': 0,
    'STITT': 0,
    'STITTS': 0,
    'STITTSWORTH': 0,
    'STITZ': 0,
    'STITZEL': 0,
    'STITZER': 0,
    'STITZINGER': 0,
    'STITZLEIN': 0,
    'STIVALA': 0,
    'STIVASON': 0,
    'STIVENDER': 0,
    'STIVER': 0,
    'STIVERS': 0,
    'STIVERSON': 0,
    'STIVES': 0,
    'STIVISON': 0,
    'STIWINTER': 0,
    'STIX': 0,
    'STJACQUES': 0,
    'STJAMES': 0,
    'STJEAN': 0,
    'STJOHN': 0,
    'STJOHNS': 0,
    'STJULES': 0,
    'STJULIAN': 0,
    'STJULIEN': 0,
    'STJUSTE': 0,
    'STLAURENT': 0,
    'STLAWRENCE': 0,
    'STLEDGER': 0,
    'STLEGER': 0,
    'STLOUIS': 0,
    'STLUKA': 0,
    'STMARIE': 0,
    'STMARTIN': 0,
    'STMARY': 0,
    'STMICHEL': 0,
    'STMYERS': 0,
    'STOA': 0,
    'STOAKES': 0,
    'STOAKLEY': 0,
    'STOAKS': 0,
    'STOB': 0,
    'STOBART': 0,
    'STOBAUGH': 0,
    'STOBB': 0,
    'STOBBE': 0,
    'STOBBS': 0,
    'STOBER': 0,
    'STOBERT': 0,
    'STOBIE': 0,
    'STOBIERSKI': 0,
    'STOCCO': 0,
    'STOCH': 0,
    'STOCHL': 0,
    'STOCK': 0,
    'STOCKAM': 0,
    'STOCKAMP': 0,
    'STOCKARD': 0,
    'STOCKBAUER': 0,
    'STOCKBERGER': 0,
    'STOCKBRIDGE': 0,
    'STOCKBURGER': 0,
    'STOCKDALE': 0,
    'STOCKDALL': 0,
    'STOCKDILL': 0,
    'STOCKE': 0,
    'STOCKEBRAND': 0,
    'STOCKEL': 0,
    'STOCKELMAN': 0,
    'STOCKEMER': 0,
    'STOCKER': 0,
    'STOCKERT': 0,
    'STOCKETT': 0,
    'STOCKEY': 0,
    'STOCKFISH': 0,
    'STOCKFLETH': 0,
    'STOCKFORD': 0,
    'STOCKHAM': 0,
    'STOCKHAUS': 0,
    'STOCKHAUSEN': 0,
    'STOCKHOFF': 0,
    'STOCKHOLM': 0,
    'STOCKI': 0,
    'STOCKING': 0,
    'STOCKINGER': 0,
    'STOCKL': 0,
    'STOCKLAND': 0,
    'STOCKLER': 0,
    'STOCKLEY': 0,
    'STOCKLI': 0,
    'STOCKLIN': 0,
    'STOCKMAL': 0,
    'STOCKMAN': 0,
    'STOCKMANN': 0,
    'STOCKMASTER': 0,
    'STOCKMEYER': 0,
    'STOCKNER': 0,
    'STOCKS': 0,
    'STOCKSDALE': 0,
    'STOCKSLAGER': 0,
    'STOCKSTAD': 0,
    'STOCKSTILL': 0,
    'STOCKTON': 0,
    'STOCKUM': 0,
    'STOCKWELL': 0,
    'STOCUM': 0,
    'STODART': 0,
    'STODDARD': 0,
    'STODDART': 0,
    'STODDEN': 0,
    'STODDER': 0,
    'STODGEL': 0,
    'STODGELL': 0,
    'STODGHILL': 0,
    'STODOLA': 0,
    'STODOLAK': 0,
    'STODOLKA': 0,
    'STODOMINGO': 0,
    'STOE': 0,
    'STOEBE': 0,
    'STOEBER': 0,
    'STOEBERL': 0,
    'STOEBNER': 0,
    'STOECK': 0,
    'STOECKEL': 0,
    'STOECKER': 0,
    'STOECKERT': 0,
    'STOECKL': 0,
    'STOECKLE': 0,
    'STOECKLEIN': 0,
    'STOECKLIN': 0,
    'STOECKMANN': 0,
    'STOEFFLER': 0,
    'STOEGER': 0,
    'STOEHR': 0,
    'STOEL': 0,
    'STOELTING': 0,
    'STOEN': 0,
    'STOEPKER': 0,
    'STOER': 0,
    'STOERGER': 0,
    'STOERKEL': 0,
    'STOERMER': 0,
    'STOERZINGER': 0,
    'STOESER': 0,
    'STOESS': 0,
    'STOESSEL': 0,
    'STOESSER': 0,
    'STOESZ': 0,
    'STOETZEL': 0,
    'STOETZER': 0,
    'STOEVER': 0,
    'STOFA': 0,
    'STOFAN': 0,
    'STOFEL': 0,
    'STOFER': 0,
    'STOFF': 0,
    'STOFFA': 0,
    'STOFFEL': 0,
    'STOFFELS': 0,
    'STOFFER': 0,
    'STOFFERAHN': 0,
    'STOFFERAN': 0,
    'STOFFERS': 0,
    'STOFFEY': 0,
    'STOFFLE': 0,
    'STOFFLET': 0,
    'STOFFREGEN': 0,
    'STOFKO': 0,
    'STOFLE': 0,
    'STOFLET': 0,
    'STOFLETH': 0,
    'STOGDALE': 0,
    'STOGDEN': 0,
    'STOGDILL': 0,
    'STOGLIN': 0,
    'STOGNER': 0,
    'STOGSDILL': 0,
    'STOHL': 0,
    'STOHLER': 0,
    'STOHLMAN': 0,
    'STOHLMANN': 0,
    'STOHR': 0,
    'STOHRER': 0,
    'STOHS': 0,
    'STOIA': 0,
    'STOIAN': 0,
    'STOIBER': 0,
    'STOICA': 0,
    'STOICK': 0,
    'STOINSKI': 0,
    'STOJ': 0,
    'STOJAK': 0,
    'STOJANOV': 0,
    'STOJANOVIC': 0,
    'STOJANOVICH': 0,
    'STOJANOVSKI': 0,
    'STOJEK': 0,
    'STOJIC': 0,
    'STOJKOVIC': 0,
    'STOJSAVLJEVIC': 0,
    'STOK': 0,
    'STOKAN': 0,
    'STOKE': 0,
    'STOKELY': 0,
    'STOKEN': 0,
    'STOKER': 0,
    'STOKES': 0,
    'STOKESBARY': 0,
    'STOKESBERRY': 0,
    'STOKEY': 0,
    'STOKKA': 0,
    'STOKKE': 0,
    'STOKLASA': 0,
    'STOKLEY': 0,
    'STOKLOSA': 0,
    'STOKMAN': 0,
    'STOKOE': 0,
    'STOKOWSKI': 0,
    'STOKS': 0,
    'STOLA': 0,
    'STOLAR': 0,
    'STOLARCZYK': 0,
    'STOLARIK': 0,
    'STOLARSKI': 0,
    'STOLARZ': 0,
    'STOLBA': 0,
    'STOLBERG': 0,
    'STOLDT': 0,
    'STOLE': 0,
    'STOLEN': 0,
    'STOLER': 0,
    'STOLFA': 0,
    'STOLFI': 0,
    'STOLFO': 0,
    'STOLFUS': 0,
    'STOLHAND': 0,
    'STOLICKER': 0,
    'STOLIKER': 0,
    'STOLINSKI': 0,
    'STOLK': 0,
    'STOLL': 0,
    'STOLLAR': 0,
    'STOLLBERG': 0,
    'STOLLE': 0,
    'STOLLENWERK': 0,
    'STOLLER': 0,
    'STOLLEY': 0,
    'STOLLINGS': 0,
    'STOLLMAN': 0,
    'STOLLSTEIMER': 0,
    'STOLOFF': 0,
    'STOLOWSKI': 0,
    'STOLP': 0,
    'STOLPA': 0,
    'STOLPE': 0,
    'STOLPER': 0,
    'STOLT': 0,
    'STOLTE': 0,
    'STOLTENBERG': 0,
    'STOLTENBURG': 0,
    'STOLTENOW': 0,
    'STOLTING': 0,
    'STOLTMAN': 0,
    'STOLTZ': 0,
    'STOLTZE': 0,
    'STOLTZFOOS': 0,
    'STOLTZFUS': 0,
    'STOLTZMAN': 0,
    'STOLWORTHY': 0,
    'STOLYAR': 0,
    'STOLZ': 0,
    'STOLZE': 0,
    'STOLZENBACH': 0,
    'STOLZENBERG': 0,
    'STOLZENBURG': 0,
    'STOLZER': 0,
    'STOLZMAN': 0,
    'STOM': 0,
    'STOMA': 0,
    'STOMBAUGH': 0,
    'STOMBERG': 0,
    'STOMER': 0,
    'STOMMEL': 0,
    'STOMMES': 0,
    'STOMP': 0,
    'STOMPS': 0,
    'STOMS': 0,
    'STOMSKI': 0,
    'STONAKER': 0,
    'STONE': 0,
    'STONEBACK': 0,
    'STONEBARGER': 0,
    'STONEBERG': 0,
    'STONEBERGER': 0,
    'STONEBRAKER': 0,
    'STONEBREAKER': 0,
    'STONEBROOK': 0,
    'STONEBURG': 0,
    'STONEBURNER': 0,
    'STONECIPHER': 0,
    'STONECYPHER': 0,
    'STONEFIELD': 0,
    'STONEHAM': 0,
    'STONEHILL': 0,
    'STONEHOCKER': 0,
    'STONEHOUSE': 0,
    'STONEKING': 0,
    'STONELAKE': 0,
    'STONEMAN': 0,
    'STONEMETZ': 0,
    'STONER': 0,
    'STONEROAD': 0,
    'STONEROCK': 0,
    'STONEROOK': 0,
    'STONES': 0,
    'STONESIFER': 0,
    'STONESTREET': 0,
    'STONEWALL': 0,
    'STONEY': 0,
    'STONG': 0,
    'STONGE': 0,
    'STONGER': 0,
    'STONICH': 0,
    'STONICK': 0,
    'STONIER': 0,
    'STONIS': 0,
    'STONITSCH': 0,
    'STONNER': 0,
    'STONUM': 0,
    'STOODLEY': 0,
    'STOOKEY': 0,
    'STOOKSBERRY': 0,
    'STOOKSBURY': 0,
    'STOOP': 0,
    'STOOPS': 0,
    'STOOR': 0,
    'STOOS': 0,
    'STOOT': 0,
    'STOOTHOFF': 0,
    'STOOTS': 0,
    'STOPA': 0,
    'STOPAK': 0,
    'STOPANI': 0,
    'STOPAR': 0,
    'STOPCZYNSKI': 0,
    'STOPERA': 0,
    'STOPFORD': 0,
    'STOPHEL': 0,
    'STOPHER': 0,
    'STOPINSKI': 0,
    'STOPKA': 0,
    'STOPP': 0,
    'STOPPA': 0,
    'STOPPEL': 0,
    'STOPPELMAN': 0,
    'STOPPENHAGEN': 0,
    'STOPPER': 0,
    'STOPS': 0,
    'STOPYRA': 0,
    'STORA': 0,
    'STORACE': 0,
    'STORANDT': 0,
    'STORAY': 0,
    'STORBAKKEN': 0,
    'STORBECK': 0,
    'STORC': 0,
    'STORCH': 0,
    'STORCK': 0,
    'STORDAHL': 0,
    'STORDEUR': 0,
    'STORE': 0,
    'STORELLI': 0,
    'STOREMSKI': 0,
    'STOREN': 0,
    'STORER': 0,
    'STORES': 0,
    'STOREY': 0,
    'STORHAUG': 0,
    'STORIE': 0,
    'STORINO': 0,
    'STORJOHANN': 0,
    'STORK': 0,
    'STORKAMP': 0,
    'STORKE': 0,
    'STORKEL': 0,
    'STORKS': 0,
    'STORKSON': 0,
    'STORLEY': 0,
    'STORLIE': 0,
    'STORLIEN': 0,
    'STORM': 0,
    'STORMAN': 0,
    'STORMANT': 0,
    'STORME': 0,
    'STORMENT': 0,
    'STORMER': 0,
    'STORMES': 0,
    'STORMO': 0,
    'STORMOEN': 0,
    'STORMONT': 0,
    'STORMS': 0,
    'STORMY': 1,
    'STORNELLI': 0,
    'STORNETTA': 0,
    'STORNIOLO': 0,
    'STORO': 0,
    'STOROZUK': 0,
    'STORR': 0,
    'STORRER': 0,
    'STORRIE': 0,
    'STORROW': 0,
    'STORRS': 0,
    'STORSETH': 0,
    'STORTI': 0,
    'STORTO': 0,
    'STORTROEN': 0,
    'STORTS': 0,
    'STORTZ': 0,
    'STORTZUM': 0,
    'STORVICK': 0,
    'STORY': 0,
    'STORZ': 0,
    'STOS': 0,
    'STOSE': 0,
    'STOSIC': 0,
    'STOSICH': 0,
    'STOSKOPF': 0,
    'STOSS': 0,
    'STOSSEL': 0,
    'STOTELMYER': 0,
    'STOTERAU': 0,
    'STOTESBERY': 0,
    'STOTESBURY': 0,
    'STOTHARD': 0,
    'STOTHERS': 0,
    'STOTLAND': 0,
    'STOTLAR': 0,
    'STOTLER': 0,
    'STOTSKY': 0,
    'STOTT': 0,
    'STOTTER': 0,
    'STOTTLEMIRE': 0,
    'STOTTLEMYER': 0,
    'STOTTLEMYRE': 0,
    'STOTTLER': 0,
    'STOTTS': 0,
    'STOTTSBERRY': 0,
    'STOTZ': 0,
    'STOTZER': 0,
    'STOUCH': 0,
    'STOUDEMIRE': 0,
    'STOUDENMIRE': 0,
    'STOUDER': 0,
    'STOUDMIRE': 0,
    'STOUDT': 0,
    'STOUFER': 0,
    'STOUFFER': 0,
    'STOUFFLET': 0,
    'STOUGH': 0,
    'STOUGHTENGER': 0,
    'STOUGHTON': 0,
    'STOULIL': 0,
    'STOUMBAUGH': 0,
    'STOUP': 0,
    'STOURS': 0,
    'STOUSE': 0,
    'STOUT': 0,
    'STOUTAMIRE': 0,
    'STOUTE': 0,
    'STOUTEN': 0,
    'STOUTENBOROUGH': 0,
    'STOUTENBURG': 0,
    'STOUTENBURGH': 0,
    'STOUTENGER': 0,
    'STOUTER': 0,
    'STOUTMIRE': 0,
    'STOUTT': 0,
    'STOUTZENBERGER': 0,
    'STOVAL': 0,
    'STOVALL': 0,
    'STOVE': 0,
    'STOVEKEN': 0,
    'STOVELL': 0,
    'STOVER': 0,
    'STOVERINK': 0,
    'STOVERN': 0,
    'STOVES': 0,
    'STOW': 0,
    'STOWASSER': 0,
    'STOWE': 0,
    'STOWELL': 0,
    'STOWER': 0,
    'STOWERS': 0,
    'STOWES': 0,
    'STOWMAN': 0,
    'STOXEN': 0,
    'STOY': 0,
    'STOYANOFF': 0,
    'STOYANOV': 0,
    'STOYE': 0,
    'STOYER': 0,
    'STOYKA': 0,
    'STOYKO': 0,
    'STOYLE': 0,
    'STPAUL': 0,
    'STPETER': 0,
    'STPETERS': 0,
    'STPHARD': 0,
    'STPIERRE': 0,
    'STPREUX': 0,
    'STRAATMANN': 0,
    'STRABALA': 0,
    'STRABEL': 0,
    'STRABLE': 0,
    'STRABLEY': 0,
    'STRACENER': 0,
    'STRACH': 0,
    'STRACHAN': 0,
    'STRACHE': 0,
    'STRACHN': 0,
    'STRACHOTA': 0,
    'STRACK': 0,
    'STRACKBEIN': 0,
    'STRACKE': 0,
    'STRACNER': 0,
    'STRACUZZI': 0,
    'STRADA': 0,
    'STRADE': 0,
    'STRADER': 0,
    'STRADFORD': 0,
    'STRADINGER': 0,
    'STRADLEY': 0,
    'STRADLING': 0,
    'STRADTMAN': 0,
    'STRADTNER': 0,
    'STRAESSLE': 0,
    'STRAFACE': 0,
    'STRAFFORD': 0,
    'STRAH': 0,
    'STRAHAN': 0,
    'STRAHIN': 0,
    'STRAHL': 0,
    'STRAHLE': 0,
    'STRAHLER': 0,
    'STRAHLEY': 0,
    'STRAHM': 0,
    'STRAHORN': 0,
    'STRAHOTA': 0,
    'STRAIGHT': 0,
    'STRAILY': 0,
    'STRAIN': 0,
    'STRAINER': 0,
    'STRAIT': 0,
    'STRAITE': 0,
    'STRAITIFF': 0,
    'STRAITON': 0,
    'STRAITS': 0,
    'STRAKA': 0,
    'STRAKE': 0,
    'STRAKER': 0,
    'STRALEY': 0,
    'STRALKA': 0,
    'STRALOW': 0,
    'STRAM': 0,
    'STRAMA': 0,
    'STRAMAGLIA': 0,
    'STRAMBLER': 0,
    'STRAMEL': 0,
    'STRAMER': 0,
    'STRAMIELLO': 0,
    'STRAMPE': 0,
    'STRAN': 0,
    'STRANAHAN': 0,
    'STRANATHAN': 0,
    'STRANBERG': 0,
    'STRANC': 0,
    'STRAND': 0,
    'STRANDBERG': 0,
    'STRANDE': 0,
    'STRANDELL': 0,
    'STRANDER': 0,
    'STRANDLUND': 0,
    'STRANDQUIST': 0,
    'STRANDT': 0,
    'STRANE': 0,
    'STRANEY': 0,
    'STRANG': 0,
    'STRANGE': 0,
    'STRANGER': 0,
    'STRANGES': 0,
    'STRANGFELD': 0,
    'STRANGIO': 0,
    'STRANGIS': 0,
    'STRANGMAN': 0,
    'STRANIERI': 0,
    'STRANIERO': 0,
    'STRANIX': 0,
    'STRANKO': 0,
    'STRANO': 0,
    'STRANSKY': 0,
    'STRANTZ': 0,
    'STRANZ': 0,
    'STRANZL': 0,
    'STRAPP': 0,
    'STRASBAUGH': 0,
    'STRASBERG': 0,
    'STRASBURG': 0,
    'STRASBURGER': 0,
    'STRASEN': 0,
    'STRASHEIM': 0,
    'STRASNER': 0,
    'STRASS': 0,
    'STRASSBERG': 0,
    'STRASSBURG': 0,
    'STRASSBURGER': 0,
    'STRASSEL': 0,
    'STRASSELL': 0,
    'STRASSER': 0,
    'STRASSLE': 0,
    'STRASSLER': 0,
    'STRASSMAN': 0,
    'STRASSNER': 0,
    'STRASZEWSKI': 0,
    'STRATE': 0,
    'STRATEMEYER': 0,
    'STRATEN': 0,
    'STRATER': 0,
    'STRATFORD': 0,
    'STRATHEARN': 0,
    'STRATHMAN': 0,
    'STRATHMANN': 0,
    'STRATI': 0,
    'STRATIGOS': 0,
    'STRATING': 0,
    'STRATIS': 0,
    'STRATMAN': 0,
    'STRATMANN': 0,
    'STRATMEYER': 0,
    'STRATON': 0,
    'STRATOS': 0,
    'STRATTA': 0,
    'STRATTAN': 0,
    'STRATTEN': 0,
    'STRATTMAN': 0,
    'STRATTON': 0,
    'STRATZ': 0,
    'STRAUB': 0,
    'STRAUBE': 0,
    'STRAUBEL': 0,
    'STRAUBHAAR': 0,
    'STRAUBINGER': 0,
    'STRAUCH': 0,
    'STRAUDER': 0,
    'STRAUGHAN': 0,
    'STRAUGHN': 0,
    'STRAUGHTER': 0,
    'STRAUP': 0,
    'STRAUS': 0,
    'STRAUSBAUGH': 0,
    'STRAUSBERG': 0,
    'STRAUSBURG': 0,
    'STRAUSE': 0,
    'STRAUSER': 0,
    'STRAUSS': 0,
    'STRAUSSER': 0,
    'STRAUT': 0,
    'STRAUTHER': 0,
    'STRAUTMAN': 0,
    'STRAVATO': 0,
    'STRAVERS': 0,
    'STRAVINSKY': 0,
    'STRAW': 0,
    'STRAWBERRY': 0,
    'STRAWBRIDGE': 0,
    'STRAWDER': 0,
    'STRAWDERMAN': 0,
    'STRAWHACKER': 0,
    'STRAWHORN': 0,
    'STRAWHUN': 0,
    'STRAWN': 0,
    'STRAWS': 0,
    'STRAWSBURG': 0,
    'STRAWSER': 0,
    'STRAWTER': 0,
    'STRAWTHER': 0,
    'STRAY': 0,
    'STRAYER': 0,
    'STRAYHORN': 0,
    'STRAZZA': 0,
    'STRAZZERI': 0,
    'STRAZZULLA': 0,
    'STRAZZULLO': 0,
    'STREACKER': 0,
    'STREAKER': 0,
    'STREALY': 0,
    'STREAM': 0,
    'STREAMS': 0,
    'STREAN': 0,
    'STREAT': 0,
    'STREATER': 0,
    'STREATOR': 0,
    'STREB': 0,
    'STREBE': 0,
    'STREBECK': 0,
    'STREBEL': 0,
    'STREBER': 0,
    'STREBIG': 0,
    'STREBLER': 0,
    'STREBLOW': 0,
    'STREBY': 0,
    'STRECH': 0,
    'STRECK': 0,
    'STRECKER': 0,
    'STRECKFUS': 0,
    'STRECKFUSS': 0,
    'STREDWICK': 0,
    'STREED': 0,
    'STREELMAN': 0,
    'STREEPER': 0,
    'STREEPY': 0,
    'STREET': 0,
    'STREETE': 0,
    'STREETER': 0,
    'STREETMAN': 0,
    'STREETS': 0,
    'STREETT': 0,
    'STREETY': 0,
    'STREEVAL': 0,
    'STREFF': 0,
    'STREFLING': 0,
    'STREGE': 0,
    'STREHL': 0,
    'STREHLE': 0,
    'STREHLER': 0,
    'STREHLOW': 0,
    'STREI': 0,
    'STREIB': 0,
    'STREIBLE': 0,
    'STREICH': 0,
    'STREICHER': 0,
    'STREICHERT': 0,
    'STREIF': 0,
    'STREIFEL': 0,
    'STREIFF': 0,
    'STREIGHT': 0,
    'STREIGHTIFF': 0,
    'STREIN': 0,
    'STREISEL': 0,
    'STREIT': 0,
    'STREITENBERGER': 0,
    'STREITMATTER': 0,
    'STREITZ': 0,
    'STREJC': 0,
    'STREK': 0,
    'STRELAU': 0,
    'STRELEC': 0,
    'STRELECKI': 0,
    'STRELITZ': 0,
    'STRELKA': 0,
    'STRELL': 0,
    'STRELLA': 0,
    'STRELOW': 0,
    'STREM': 0,
    'STREMCHA': 0,
    'STREMEL': 0,
    'STREMICK': 0,
    'STREMLAU': 0,
    'STREMMEL': 0,
    'STREMMING': 0,
    'STREMPEL': 0,
    'STREMPKE': 0,
    'STREMY': 0,
    'STRENG': 0,
    'STRENGE': 0,
    'STRENGER': 0,
    'STRENGTH': 0,
    'STRENK': 0,
    'STRENKE': 0,
    'STRENO': 0,
    'STREPPONE': 0,
    'STRESE': 0,
    'STRESING': 0,
    'STRESS': 0,
    'STRESSMAN': 0,
    'STRETCH': 0,
    'STRETTON': 0,
    'STRETZ': 0,
    'STREU': 0,
    'STREUFERT': 0,
    'STREULI': 0,
    'STREUN': 0,
    'STREUR': 0,
    'STREVA': 0,
    'STREVEL': 0,
    'STREVELER': 0,
    'STREVER': 0,
    'STREVIG': 0,
    'STREY': 0,
    'STREYLE': 0,
    'STREZO': 0,
    'STRIANESE': 0,
    'STRIANO': 0,
    'STRIBLEY': 0,
    'STRIBLIN': 0,
    'STRIBLING': 0,
    'STRICH': 0,
    'STRICHERZ': 0,
    'STRICK': 0,
    'STRICKER': 0,
    'STRICKERT': 0,
    'STRICKFADEN': 0,
    'STRICKHOUSER': 0,
    'STRICKLAN': 0,
    'STRICKLAND': 0,
    'STRICKLEN': 0,
    'STRICKLER': 0,
    'STRICKLETT': 0,
    'STRICKLEY': 0,
    'STRICKLIN': 0,
    'STRICKLING': 0,
    'STRICKMAN': 0,
    'STRID': 0,
    'STRIDE': 0,
    'STRIDER': 0,
    'STRIDIRON': 0,
    'STRIEBEL': 0,
    'STRIEBICH': 0,
    'STRIEBY': 0,
    'STRIEDER': 0,
    'STRIEF': 0,
    'STRIEFF': 0,
    'STRIEGEL': 0,
    'STRIEKER': 0,
    'STRIETELMEIER': 0,
    'STRIETER': 0,
    'STRIFE': 0,
    'STRIFFLER': 0,
    'STRIFLER': 0,
    'STRIGEL': 0,
    'STRIGGLES': 0,
    'STRIGGOW': 0,
    'STRIGHT': 0,
    'STRIGLE': 0,
    'STRIKE': 0,
    'STRIKER': 0,
    'STRILEY': 0,
    'STRIMBU': 0,
    'STRIMEL': 0,
    'STRIMPEL': 0,
    'STRIMPLE': 0,
    'STRINE': 0,
    'STRING': 0,
    'STRINGARI': 0,
    'STRINGER': 0,
    'STRINGFELLOW': 0,
    'STRINGFIELD': 0,
    'STRINGHAM': 0,
    'STRINI': 0,
    'STRIPE': 0,
    'STRIPLIN': 0,
    'STRIPLING': 0,
    'STRIPP': 0,
    'STRIPPOLI': 0,
    'STRISSEL': 0,
    'STRITCH': 0,
    'STRITE': 0,
    'STRITT': 0,
    'STRITTMATER': 0,
    'STRITTMATTER': 0,
    'STRITZEL': 0,
    'STRITZINGER': 0,
    'STRIZAK': 0,
    'STRIZICH': 0,
    'STRMISKA': 0,
    'STRNAD': 0,
    'STROBACH': 0,
    'STROBBE': 0,
    'STROBECK': 0,
    'STROBEHN': 0,
    'STROBEL': 0,
    'STROBER': 0,
    'STROBERG': 0,
    'STROBERT': 0,
    'STROBL': 0,
    'STROBLE': 0,
    'STROBRIDGE': 0,
    'STROCCHIA': 0,
    'STROCK': 0,
    'STROCKBINE': 0,
    'STRODA': 0,
    'STRODE': 0,
    'STRODEL': 0,
    'STRODER': 0,
    'STRODTBECK': 0,
    'STRODTMAN': 0,
    'STROEBEL': 0,
    'STROEDE': 0,
    'STROEHLEIN': 0,
    'STROEMER': 0,
    'STROER': 0,
    'STROFFOLINO': 0,
    'STROGEN': 0,
    'STROH': 0,
    'STROHACKER': 0,
    'STROHBECK': 0,
    'STROHBEHN': 0,
    'STROHBUSCH': 0,
    'STROHECKER': 0,
    'STROHFUS': 0,
    'STROHKIRCH': 0,
    'STROHL': 0,
    'STROHM': 0,
    'STROHMAIER': 0,
    'STROHMAN': 0,
    'STROHMAYER': 0,
    'STROHMEIER': 0,
    'STROHMENGER': 0,
    'STROHMEYER': 0,
    'STROHMIER': 0,
    'STROHSCHEIN': 0,
    'STROIA': 0,
    'STROIK': 0,
    'STROINSKI': 0,
    'STROJNY': 0,
    'STROK': 0,
    'STROKA': 0,
    'STROKE': 0,
    'STROKER': 0,
    'STROLE': 0,
    'STROLL': 0,
    'STROLLO': 0,
    'STROM': 0,
    'STROMAIN': 0,
    'STROMAN': 0,
    'STROMATT': 0,
    'STROMBACK': 0,
    'STROMBECK': 0,
    'STROMBERG': 0,
    'STROMBERGER': 0,
    'STROME': 0,
    'STROMER': 0,
    'STROMEYER': 0,
    'STROMGREN': 0,
    'STROMING': 0,
    'STROMINGER': 0,
    'STROMLEY': 0,
    'STROMME': 0,
    'STROMMEN': 0,
    'STROMMER': 0,
    'STROMQUIST': 0,
    'STROMSKI': 0,
    'STROMSTAD': 0,
    'STRONA': 0,
    'STRONACH': 0,
    'STRONCZEK': 0,
    'STRONER': 0,
    'STRONG': 0,
    'STRONGIN': 0,
    'STRONGMAN': 0,
    'STRONSKI': 0,
    'STROOP': 0,
    'STROOPE': 0,
    'STROOT': 0,
    'STROP': 0,
    'STROPE': 0,
    'STROPES': 0,
    'STROPKI': 0,
    'STROPKO': 0,
    'STROPLE': 0,
    'STROPOLI': 0,
    'STROPPEL': 0,
    'STROSAHL': 0,
    'STROSCHEIN': 0,
    'STROSE': 0,
    'STROSHINE': 0,
    'STROSNIDER': 0,
    'STROSS': 0,
    'STROSSER': 0,
    'STROTH': 0,
    'STROTHEIDE': 0,
    'STROTHER': 0,
    'STROTHERS': 0,
    'STROTHKAMP': 0,
    'STROTHMAN': 0,
    'STROTHMANN': 0,
    'STROTMAN': 0,
    'STROTT': 0,
    'STROTZ': 0,
    'STROUB': 0,
    'STROUBE': 0,
    'STROUBLE': 0,
    'STROUD': 0,
    'STROUDE': 0,
    'STROUF': 0,
    'STROUGH': 0,
    'STROUGHTER': 0,
    'STROUHAL': 0,
    'STROUP': 0,
    'STROUPE': 0,
    'STROUS': 0,
    'STROUSE': 0,
    'STROUSS': 0,
    'STROUT': 0,
    'STROUTH': 0,
    'STROVEN': 0,
    'STROW': 0,
    'STROWBRIDGE': 0,
    'STROWD': 0,
    'STROWDER': 0,
    'STROWMATT': 0,
    'STROY': 0,
    'STROYAN': 0,
    'STROZ': 0,
    'STROZESKI': 0,
    'STROZEWSKI': 0,
    'STROZIER': 0,
    'STROZYK': 0,
    'STRUB': 0,
    'STRUBBE': 0,
    'STRUBBERG': 0,
    'STRUBE': 0,
    'STRUBECK': 0,
    'STRUBEL': 0,
    'STRUBHAR': 0,
    'STRUBHART': 0,
    'STRUBINGER': 0,
    'STRUBLE': 0,
    'STRUCHEN': 0,
    'STRUCK': 0,
    'STRUCKHOFF': 0,
    'STRUCKMAN': 0,
    'STRUCKMANN': 0,
    'STRUCKMEYER': 0,
    'STRUDWICK': 0,
    'STRUEBING': 0,
    'STRUEMPH': 0,
    'STRUEWING': 0,
    'STRUFFERT': 0,
    'STRUG': 0,
    'STRUGALA': 0,
    'STRUGGS': 0,
    'STRUHAR': 0,
    'STRUHS': 0,
    'STRUIKSMA': 0,
    'STRUK': 0,
    'STRUKEL': 0,
    'STRULL': 0,
    'STRUM': 0,
    'STRUMOLO': 0,
    'STRUMPF': 0,
    'STRUMWASSER': 0,
    'STRUNA': 0,
    'STRUNC': 0,
    'STRUNCK': 0,
    'STRUNK': 0,
    'STRUNTZ': 0,
    'STRUNZ': 0,
    'STRUP': 0,
    'STRUPE': 0,
    'STRUPP': 0,
    'STRUS': 0,
    'STRUSE': 0,
    'STRUSS': 0,
    'STRUSZ': 0,
    'STRUTH': 0,
    'STRUTHERS': 0,
    'STRUTT': 0,
    'STRUTTMANN': 0,
    'STRUTTON': 0,
    'STRUTZ': 0,
    'STRUTZEL': 0,
    'STRUVE': 0,
    'STRUWE': 0,
    'STRUXNESS': 0,
    'STRUYK': 0,
    'STRUZIK': 0,
    'STRUZINSKI': 0,
    'STRUZYK': 0,
    'STRUZYNSKI': 0,
    'STRYCHALSKI': 0,
    'STRYCHARZ': 0,
    'STRYCKER': 0,
    'STRYCZEK': 0,
    'STRYFFELER': 0,
    'STRYJEWSKI': 0,
    'STRYK': 0,
    'STRYKER': 0,
    'STRYKOWSKI': 0,
    'STRYSICK': 0,
    'STRZALKA': 0,
    'STRZALKOWSKI': 0,
    'STRZELCZYK': 0,
    'STRZELEC': 0,
    'STRZELECKI': 0,
    'STRZELEWICZ': 0,
    'STRZEPEK': 0,
    'STRZYZEWSKI': 0,
    'STSAUVER': 0,
    'STSAUVEUR': 0,
    'STSURIN': 0,
    'STTHOMAS': 0,
    'STUARD': 0,
    'STUART': 0.7688275380045431,
    'STUBB': 0,
    'STUBBE': 0,
    'STUBBEN': 0,
    'STUBBENDICK': 0,
    'STUBBERFIELD': 0,
    'STUBBERT': 0,
    'STUBBINGS': 0,
    'STUBBINS': 0,
    'STUBBLEBINE': 0,
    'STUBBLEFIELD': 0,
    'STUBBS': 0,
    'STUBBY': 0,
    'STUBE': 0,
    'STUBENRAUCH': 0,
    'STUBENVOLL': 0,
    'STUBER': 0,
    'STUBING': 0,
    'STUBITS': 0,
    'STUBLER': 0,
    'STUBSTAD': 0,
    'STUBY': 0,
    'STUCHAL': 0,
    'STUCHEL': 0,
    'STUCHELL': 0,
    'STUCHLIK': 0,
    'STUCHLY': 0,
    'STUCK': 0,
    'STUCKART': 0,
    'STUCKE': 0,
    'STUCKEL': 0,
    'STUCKEMEYER': 0,
    'STUCKENSCHNEIDE': 0,
    'STUCKER': 0,
    'STUCKERT': 0,
    'STUCKEY': 0,
    'STUCKI': 0,
    'STUCKMAN': 0,
    'STUCKMEYER': 0,
    'STUCKO': 0,
    'STUCKS': 0,
    'STUCKWISCH': 0,
    'STUCKWISH': 0,
    'STUCKY': 0,
    'STUCZYNSKI': 0,
    'STUDD': 0,
    'STUDDARD': 0,
    'STUDDERT': 0,
    'STUDDS': 0,
    'STUDE': 0,
    'STUDEBAKER': 0,
    'STUDEMAN': 0,
    'STUDENSKI': 0,
    'STUDENT': 0,
    'STUDENY': 0,
    'STUDER': 0,
    'STUDHOLME': 0,
    'STUDIE': 0,
    'STUDIER': 0,
    'STUDINSKI': 0,
    'STUDIVANT': 0,
    'STUDLER': 0,
    'STUDLEY': 0,
    'STUDNICKA': 0,
    'STUDNICKI': 0,
    'STUDSTILL': 0,
    'STUDT': 0,
    'STUDTMANN': 0,
    'STUDWELL': 0,
    'STUDY': 0,
    'STUDYVIN': 0,
    'STUDZINSKI': 0,
    'STUEBE': 0,
    'STUEBEN': 0,
    'STUEBER': 0,
    'STUEBING': 0,
    'STUEBNER': 0,
    'STUEBS': 0,
    'STUECK': 0,
    'STUECKLE': 0,
    'STUEDEMANN': 0,
    'STUEFEN': 0,
    'STUEHLER': 0,
    'STUEHM': 0,
    'STUELAND': 0,
    'STUEMKE': 0,
    'STUENKEL': 0,
    'STUER': 0,
    'STUERKE': 0,
    'STUERMER': 0,
    'STUESSY': 0,
    'STUETTGEN': 0,
    'STUEVE': 0,
    'STUEVEN': 0,
    'STUEVER': 0,
    'STUEWE': 0,
    'STUEWER': 0,
    'STUFF': 0,
    'STUFFEL': 0,
    'STUFFLE': 0,
    'STUFFLEBEAM': 0,
    'STUFFLEBEAN': 0,
    'STUFFLEBEEM': 0,
    'STUFFLET': 0,
    'STUFFT': 0,
    'STUGART': 0,
    'STUHL': 0,
    'STUHLDREHER': 0,
    'STUHLER': 0,
    'STUHLMAN': 0,
    'STUHLMILLER': 0,
    'STUHLSATZ': 0,
    'STUHMER': 0,
    'STUHR': 0,
    'STUIBER': 0,
    'STUIT': 0,
    'STUK': 0,
    'STUKAS': 0,
    'STUKE': 0,
    'STUKEL': 0,
    'STUKENBERG': 0,
    'STUKENBORG': 0,
    'STUKENHOLTZ': 0,
    'STUKER': 0,
    'STUKES': 0,
    'STUKEY': 0,
    'STULBERG': 0,
    'STULC': 0,
    'STULCE': 0,
    'STULKEN': 0,
    'STULL': 0,
    'STULLER': 0,
    'STULPIN': 0,
    'STULTS': 0,
    'STULTZ': 0,
    'STULZ': 0,
    'STUM': 0,
    'STUMAN': 0,
    'STUMBAUGH': 0,
    'STUMBERG': 0,
    'STUMBO': 0,
    'STUMLER': 0,
    'STUMM': 0,
    'STUMME': 0,
    'STUMMER': 0,
    'STUMP': 0,
    'STUMPE': 0,
    'STUMPER': 0,
    'STUMPF': 0,
    'STUMPFF': 0,
    'STUMPH': 0,
    'STUMPNER': 0,
    'STUMPO': 0,
    'STUMPP': 0,
    'STUMPS': 0,
    'STUNKARD': 0,
    'STUNKEL': 0,
    'STUNTEBECK': 0,
    'STUNTZ': 0,
    'STUNZ': 0,
    'STUP': 0,
    'STUPAK': 0,
    'STUPAR': 0,
    'STUPER': 0,
    'STUPI': 0,
    'STUPIN': 0,
    'STUPKA': 0,
    'STUPP': 0,
    'STUPPLEBEEN': 0,
    'STUPPY': 0,
    'STURCH': 0,
    'STURCHIO': 0,
    'STURDAVANT': 0,
    'STURDEVANT': 0,
    'STURDIVAN': 0,
    'STURDIVANT': 0,
    'STURDY': 0,
    'STUREK': 0,
    'STURGE': 0,
    'STURGELL': 0,
    'STURGEON': 0,
    'STURGES': 0,
    'STURGESS': 0,
    'STURGHILL': 0,
    'STURGILL': 0,
    'STURGIS': 0,
    'STURIALE': 0,
    'STURINO': 0,
    'STURK': 0,
    'STURKEY': 0,
    'STURKIE': 0,
    'STURLA': 0,
    'STURLAUGSON': 0,
    'STURM': 0,
    'STURMA': 0,
    'STURMAN': 0,
    'STURMER': 0,
    'STURMS': 0,
    'STURN': 0,
    'STURNER': 0,
    'STURNIOLO': 0,
    'STUROS': 0,
    'STURR': 0,
    'STURROCK': 0,
    'STURRUP': 0,
    'STURSA': 0,
    'STURT': 0,
    'STURTEVANT': 0,
    'STURTZ': 0,
    'STURWOLD': 0,
    'STURZ': 0,
    'STURZA': 0,
    'STURZENEGGER': 0,
    'STURZL': 0,
    'STUSSE': 0,
    'STUSSY': 0,
    'STUTE': 0,
    'STUTER': 0,
    'STUTES': 0,
    'STUTESMAN': 0,
    'STUTEVILLE': 0,
    'STUTH': 0,
    'STUTHEIT': 0,
    'STUTHERS': 0,
    'STUTLER': 0,
    'STUTMAN': 0,
    'STUTO': 0,
    'STUTSMAN': 0,
    'STUTSON': 0,
    'STUTT': 0,
    'STUTTE': 0,
    'STUTTGEN': 0,
    'STUTTLE': 0,
    'STUTTLER': 0,
    'STUTTS': 0,
    'STUTZ': 0,
    'STUTZER': 0,
    'STUTZKE': 0,
    'STUTZMAN': 0,
    'STUVA': 0,
    'STUVE': 0,
    'STUVER': 0,
    'STUWART': 0,
    'STUYVESANT': 0,
    'STVICTOR': 0,
    'STVIL': 0,
    'STVINCENT': 0,
    'STWALLEY': 0,
    'STYBORSKI': 0,
    'STYCH': 0,
    'STYCK': 0,
    'STYCZYNSKI': 0,
    'STYER': 0,
    'STYERS': 0,
    'STYES': 0,
    'STYGAR': 0,
    'STYGLES': 0,
    'STYKA': 0,
    'STYLE': 0,
    'STYLER': 0,
    'STYLES': 0,
    'STYLIANOU': 0,
    'STYMIEST': 0,
    'STYN': 0,
    'STYNE': 0,
    'STYNER': 0,
    'STYNES': 0,
    'STYONS': 0,
    'STYPA': 0,
    'STYPINSKI': 0,
    'STYPULA': 0,
    'STYPULKOWSKI': 0,
    'STYRCZULA': 0,
    'STYRON': 0,
    'STYS': 0,
    'STYSKAL': 0,
    'STYSLINGER': 0,
    'STYVES': 0,
    'STYX': 0,
    'SU': 0.4878048780487805,
    'SUA': 0,
    'SUAN': 0,
    'SUANNE': 1,
    'SUARES': 0,
    'SUAREZ': 0,
    'SUASTE': 0,
    'SUASTEGUI': 0,
    'SUAZO': 0,
    'SUBA': 0,
    'SUBACH': 0,
    'SUBASIC': 0,
    'SUBBARAO': 0,
    'SUBBERT': 0,
    'SUBBIAH': 0,
    'SUBE': 0,
    'SUBER': 0,
    'SUBERO': 0,
    'SUBERS': 0,
    'SUBERVI': 0,
    'SUBHAN': 0,
    'SUBIA': 0,
    'SUBIAS': 0,
    'SUBICK': 0,
    'SUBIDO': 0,
    'SUBIK': 0,
    'SUBIN': 0,
    'SUBJECT': 0,
    'SUBLER': 0,
    'SUBLET': 0,
    'SUBLETT': 0,
    'SUBLETTE': 0,
    'SUBOTIC': 0,
    'SUBRAMANI': 0,
    'SUBRAMANIAM': 0,
    'SUBRAMANIAN': 0,
    'SUBRAMANYAM': 0,
    'SUBY': 0,
    'SUCATO': 0,
    'SUCCAR': 0,
    'SUCCI': 0,
    'SUCCO': 0,
    'SUCCOP': 0,
    'SUCH': 0,
    'SUCHA': 0,
    'SUCHAN': 0,
    'SUCHANEK': 0,
    'SUCHAR': 0,
    'SUCHARSKI': 0,
    'SUCHECKI': 0,
    'SUCHER': 0,
    'SUCHEY': 0,
    'SUCHIL': 0,
    'SUCHITE': 0,
    'SUCHLA': 0,
    'SUCHLAND': 0,
    'SUCHMAN': 0,
    'SUCHOCKI': 0,
    'SUCHODOLSKI': 0,
    'SUCHOMEL': 0,
    'SUCHOMSKI': 0,
    'SUCHON': 0,
    'SUCHOR': 0,
    'SUCHOSKI': 0,
    'SUCHSLAND': 0,
    'SUCHY': 0,
    'SUCHYTA': 0,
    'SUCIC': 0,
    'SUCICH': 0,
    'SUCIU': 0,
    'SUCKLING': 0,
    'SUCKOW': 0,
    'SUCRE': 0,
    'SUD': 0,
    'SUDA': 0,
    'SUDAC': 0,
    'SUDAK': 0,
    'SUDAN': 0,
    'SUDANO': 0,
    'SUDAR': 0,
    'SUDBECK': 0,
    'SUDBERRY': 0,
    'SUDBRINK': 0,
    'SUDBROCK': 0,
    'SUDBURY': 0,
    'SUDDARTH': 0,
    'SUDDATH': 0,
    'SUDDERTH': 0,
    'SUDDETH': 0,
    'SUDDITH': 0,
    'SUDDOTH': 0,
    'SUDDRETH': 0,
    'SUDDS': 0,
    'SUDDUTH': 0,
    'SUDEKUM': 0,
    'SUDELL': 0,
    'SUDEN': 0,
    'SUDER': 0,
    'SUDERMAN': 0,
    'SUDERS': 0,
    'SUDHAKAR': 0,
    'SUDHOFF': 0,
    'SUDHOLT': 0,
    'SUDIA': 0,
    'SUDIE': 1,
    'SUDIK': 0,
    'SUDING': 0,
    'SUDKAMP': 0,
    'SUDLER': 0,
    'SUDLOW': 0,
    'SUDMAN': 0,
    'SUDMEIER': 0,
    'SUDNICK': 0,
    'SUDNIK': 0,
    'SUDO': 0,
    'SUDOL': 0,
    'SUDUL': 0,
    'SUDWEEKS': 0,
    'SUDYKA': 0,
    'SUE': 0.9952479153590963,
    'SUEANN': 1,
    'SUEDA': 0,
    'SUEDKAMP': 0,
    'SUEDMEYER': 0,
    'SUEHIRO': 0,
    'SUEHR': 0,
    'SUEHS': 0,
    'SUEING': 0,
    'SUEIRO': 0,
    'SUEK': 0,
    'SUEL': 0,
    'SUELFLOW': 0,
    'SUELL': 0,
    'SUELLEN': 1,
    'SUELLENTROP': 0,
    'SUELTER': 0,
    'SUELZLE': 0,
    'SUEN': 0,
    'SUENAGA': 0,
    'SUENRAM': 0,
    'SUEOKA': 0,
    'SUEPER': 0,
    'SUER': 0,
    'SUERMANN': 0,
    'SUERO': 0,
    'SUERTH': 0,
    'SUES': 0,
    'SUESS': 0,
    'SUEVER': 0,
    'SUEY': 0,
    'SUEYOSHI': 0,
    'SUFFECOOL': 0,
    'SUFFEL': 0,
    'SUFFERN': 0,
    'SUFFICOOL': 0,
    'SUFFIELD': 0,
    'SUFFOLETTO': 0,
    'SUFFREDINI': 0,
    'SUFFRIDGE': 0,
    'SUFI': 0,
    'SUFKA': 0,
    'SUFRIN': 0,
    'SUGA': 0,
    'SUGAHARA': 0,
    'SUGAI': 0,
    'SUGALSKI': 0,
    'SUGANO': 0,
    'SUGANUMA': 0,
    'SUGAR': 0,
    'SUGARBAKER': 0,
    'SUGARMAN': 0,
    'SUGARS': 0,
    'SUGAWARA': 0,
    'SUGAY': 0,
    'SUGDEN': 0,
    'SUGERMAN': 0,
    'SUGG': 0,
    'SUGGETT': 0,
    'SUGGITT': 0,
    'SUGGS': 0,
    'SUGHROUE': 0,
    'SUGHRUE': 0,
    'SUGIHARA': 0,
    'SUGIMOTO': 0,
    'SUGIMURA': 0,
    'SUGINO': 0,
    'SUGIOKA': 0,
    'SUGITA': 0,
    'SUGIURA': 0,
    'SUGIYAMA': 0,
    'SUGLIA': 0,
    'SUGRIM': 0,
    'SUGRUE': 0,
    'SUGUITAN': 0,
    'SUH': 0,
    'SUHADOLNIK': 0,
    'SUHAIL': 0,
    'SUHAJDA': 0,
    'SUHAR': 0,
    'SUHAY': 0,
    'SUHAYDA': 0,
    'SUHL': 0,
    'SUHLER': 0,
    'SUHLING': 0,
    'SUHM': 0,
    'SUHR': 0,
    'SUHRE': 0,
    'SUHY': 0,
    'SUI': 0,
    'SUICH': 0,
    'SUICO': 0,
    'SUIDA': 0,
    'SUIHKONEN': 0,
    'SUINA': 0,
    'SUING': 0,
    'SUIRE': 0,
    'SUISSA': 0,
    'SUIT': 0,
    'SUITE': 0,
    'SUITER': 0,
    'SUITERS': 0,
    'SUITOR': 0,
    'SUITS': 0,
    'SUITT': 0,
    'SUITTER': 0,
    'SUK': 0.8474576271186441,
    'SUKA': 0,
    'SUKALSKI': 0,
    'SUKE': 0,
    'SUKEFORTH': 0,
    'SUKEL': 0,
    'SUKENIK': 0,
    'SUKER': 0,
    'SUKHAI': 0,
    'SUKHDEO': 0,
    'SUKHNANDAN': 0,
    'SUKHRAM': 0,
    'SUKHU': 0,
    'SUKIENNIK': 0,
    'SUKKAR': 0,
    'SUKO': 0,
    'SUKOVICH': 0,
    'SUKOW': 0,
    'SUKRAW': 0,
    'SUKUMAR': 0,
    'SUKUP': 0,
    'SUKUT': 0,
    'SUL': 0,
    'SULA': 0,
    'SULAICA': 0,
    'SULAIMAN': 0,
    'SULAK': 0,
    'SULARZ': 0,
    'SULC': 0,
    'SULCA': 0,
    'SULCER': 0,
    'SULE': 0,
    'SULECKI': 0,
    'SULEIMAN': 0,
    'SULEJMANI': 0,
    'SULEK': 0,
    'SULEMA': 1,
    'SULEMAN': 0,
    'SULENSKI': 0,
    'SULENTIC': 0,
    'SULESKI': 0,
    'SULEWSKI': 0,
    'SULEYMANOV': 0,
    'SULFARO': 0,
    'SULFRIDGE': 0,
    'SULGER': 0,
    'SULGROVE': 0,
    'SULHAM': 0,
    'SULICH': 0,
    'SULICK': 0,
    'SULIEMAN': 0,
    'SULIER': 0,
    'SULIK': 0,
    'SULIKOWSKI': 0,
    'SULIMA': 0,
    'SULIMAN': 0,
    'SULIN': 0,
    'SULINSKI': 0,
    'SULIT': 0,
    'SULJIC': 0,
    'SULKA': 0,
    'SULKEY': 0,
    'SULKIN': 0,
    'SULKOSKY': 0,
    'SULKOWSKI': 0,
    'SULL': 0,
    'SULLA': 0,
    'SULLEN': 0,
    'SULLENBERGER': 0,
    'SULLENDER': 0,
    'SULLENGER': 0,
    'SULLENS': 0,
    'SULLENTRUP': 0,
    'SULLEY': 0,
    'SULLI': 0,
    'SULLINGER': 0,
    'SULLINS': 0,
    'SULLIVAN': 0,
    'SULLIVANT': 0,
    'SULLIVENT': 0,
    'SULLO': 0,
    'SULLWOLD': 0,
    'SULLY': 0,
    'SULOFF': 0,
    'SULOUFF': 0,
    'SULPIZIO': 0,
    'SULSER': 0,
    'SULSKI': 0,
    'SULSONA': 0,
    'SULT': 0,
    'SULTAN': 0,
    'SULTANA': 0,
    'SULTANI': 0,
    'SULTEMEIER': 0,
    'SULTENFUSS': 0,
    'SULTON': 0,
    'SULTZ': 0,
    'SULTZBACH': 0,
    'SULTZBAUGH': 0,
    'SULTZER': 0,
    'SULZBACH': 0,
    'SULZBERGER': 0,
    'SULZEN': 0,
    'SULZER': 0,
    'SULZMAN': 0,
    'SUM': 0,
    'SUMA': 0,
    'SUMABAT': 0,
    'SUMAN': 0,
    'SUMANO': 0,
    'SUMARA': 0,
    'SUMAYA': 0,
    'SUMBA': 0,
    'SUMBERA': 0,
    'SUMBERG': 0,
    'SUMBLER': 0,
    'SUMBLIN': 0,
    'SUMBRY': 0,
    'SUMER': 0,
    'SUMERA': 0,
    'SUMERALL': 0,
    'SUMEREL': 0,
    'SUMERIX': 0,
    'SUMERLIN': 0,
    'SUMERS': 0,
    'SUMEY': 0,
    'SUMI': 0,
    'SUMIBCAY': 0,
    'SUMIDA': 0,
    'SUMIKO': 1,
    'SUMINSKI': 0,
    'SUMLAR': 0,
    'SUMLER': 0,
    'SUMLIN': 0,
    'SUMLING': 0,
    'SUMM': 0,
    'SUMMA': 0,
    'SUMMAGE': 0,
    'SUMMAR': 0,
    'SUMMARELL': 0,
    'SUMME': 0,
    'SUMMER': 0.9356081452944414,
    'SUMMERALL': 0,
    'SUMMERELL': 0,
    'SUMMERER': 0,
    'SUMMERFELT': 0,
    'SUMMERFIELD': 0,
    'SUMMERFORD': 0,
    'SUMMERHAYS': 0,
    'SUMMERHILL': 0,
    'SUMMERILL': 0,
    'SUMMERLAND': 0,
    'SUMMERLIN': 0,
    'SUMMERLOT': 0,
    'SUMMEROUR': 0,
    'SUMMEROW': 0,
    'SUMMERS': 0,
    'SUMMERSET': 0,
    'SUMMERSETT': 0,
    'SUMMERSGILL': 0,
    'SUMMERSILL': 0,
    'SUMMERSON': 0,
    'SUMMERTON': 0,
    'SUMMERVILLE': 0,
    'SUMMEY': 0,
    'SUMMIT': 0,
    'SUMMITT': 0,
    'SUMMO': 0,
    'SUMMONS': 0,
    'SUMMY': 0,
    'SUMNER': 0,
    'SUMNERS': 0,
    'SUMNEY': 0,
    'SUMNICHT': 0,
    'SUMO': 0,
    'SUMOSKI': 0,
    'SUMP': 0,
    'SUMPTER': 0,
    'SUMPTION': 0,
    'SUMRALL': 0,
    'SUMRELL': 0,
    'SUMROW': 0,
    'SUMSER': 0,
    'SUMSION': 0,
    'SUMSKI': 0,
    'SUMSTAD': 0,
    'SUMTER': 0,
    'SUMULONG': 0,
    'SUMWALT': 0,
    'SUN': 0.5577689243027888,
    'SUNADA': 0,
    'SUNAHARA': 0,
    'SUNBERG': 0,
    'SUNBURY': 0,
    'SUNCIN': 0,
    'SUND': 0,
    'SUNDA': 0,
    'SUNDAHL': 0,
    'SUNDAL': 0,
    'SUNDAR': 0,
    'SUNDARA': 0,
    'SUNDARAM': 0,
    'SUNDARARAJAN': 0,
    'SUNDARESAN': 0,
    'SUNDAY': 0.4444444444444445,
    'SUNDBERG': 0,
    'SUNDBLAD': 0,
    'SUNDBLOM': 0,
    'SUNDBY': 0,
    'SUNDE': 0,
    'SUNDEEN': 0,
    'SUNDELL': 0,
    'SUNDEM': 0,
    'SUNDEN': 0,
    'SUNDER': 0,
    'SUNDERHAUS': 0,
    'SUNDERLAGE': 0,
    'SUNDERLAND': 0,
    'SUNDERLIN': 0,
    'SUNDERMAN': 0,
    'SUNDERMANN': 0,
    'SUNDERMEIER': 0,
    'SUNDERMEYER': 0,
    'SUNDET': 0,
    'SUNDGREN': 0,
    'SUNDHEIM': 0,
    'SUNDHEIMER': 0,
    'SUNDHOLM': 0,
    'SUNDIN': 0,
    'SUNDINE': 0,
    'SUNDLIE': 0,
    'SUNDLING': 0,
    'SUNDMAN': 0,
    'SUNDQUIST': 0,
    'SUNDSETH': 0,
    'SUNDSTROM': 0,
    'SUNDT': 0,
    'SUNDVALL': 0,
    'SUNDWALL': 0,
    'SUNDY': 0,
    'SUNESON': 0,
    'SUNG': 0.7760532150776053,
    'SUNGA': 0,
    'SUNIA': 0,
    'SUNIGA': 0,
    'SUNKARA': 0,
    'SUNKEL': 0,
    'SUNKEN': 0,
    'SUNKLE': 0,
    'SUNLEY': 0,
    'SUNN': 0,
    'SUNNARBORG': 0,
    'SUNNER': 0,
    'SUNNI': 1,
    'SUNNY': 0.9727626459143969,
    'SUNQUIST': 0,
    'SUNSERI': 0,
    'SUNSHINE': 0.9009009009009008,
    'SUNSTROM': 0,
    'SUNTER': 0,
    'SUNTKEN': 0,
    'SUNWOO': 0,
    'SUNYAK': 0,
    'SUNZERI': 0,
    'SUO': 0,
    'SUOMELA': 0,
    'SUOMI': 0,
    'SUOMINEN': 0,
    'SUON': 0,
    'SUONG': 0,
    'SUOS': 0,
    'SUOZZI': 0,
    'SUOZZO': 0,
    'SUP': 0,
    'SUPAK': 0,
    'SUPAN': 0,
    'SUPANCIC': 0,
    'SUPANICH': 0,
    'SUPE': 0,
    'SUPEL': 0,
    'SUPER': 0,
    'SUPERCZYNSKI': 0,
    'SUPERNAULT': 0,
    'SUPERNAW': 0,
    'SUPERNOR': 0,
    'SUPERVILLE': 0,
    'SUPIK': 0,
    'SUPINA': 0,
    'SUPINGER': 0,
    'SUPINO': 0,
    'SUPINSKI': 0,
    'SUPKO': 0,
    'SUPLEE': 0,
    'SUPLER': 0,
    'SUPLICKI': 0,
    'SUPNET': 0,
    'SUPON': 0,
    'SUPP': 0,
    'SUPPA': 0,
    'SUPPAN': 0,
    'SUPPE': 0,
    'SUPPER': 0,
    'SUPPES': 0,
    'SUPPLE': 0,
    'SUPPLEE': 0,
    'SUPPLES': 0,
    'SUPRENANT': 0,
    'SUPRISE': 0,
    'SUR': 0,
    'SURA': 0,
    'SURABIAN': 0,
    'SURACE': 0,
    'SURACI': 0,
    'SURAK': 0,
    'SURAN': 0,
    'SURANA': 0,
    'SURANI': 0,
    'SURAPANENI': 0,
    'SURAT': 0,
    'SURATI': 0,
    'SURATT': 0,
    'SURBAUGH': 0,
    'SURBECK': 0,
    'SURBER': 0,
    'SURBROOK': 0,
    'SURDAM': 0,
    'SURDEL': 0,
    'SURDEZ': 0,
    'SURDI': 0,
    'SURDO': 0,
    'SURDYK': 0,
    'SURDYKA': 0,
    'SUREN': 0,
    'SURERUS': 0,
    'SURESH': 0,
    'SURETTE': 0,
    'SURFACE': 0,
    'SURFUS': 0,
    'SURGENER': 0,
    'SURGENOR': 0,
    'SURGENT': 0,
    'SURGEON': 0,
    'SURGES': 0,
    'SURGINER': 0,
    'SURGUY': 0,
    'SURH': 0,
    'SURI': 0,
    'SURIA': 0,
    'SURIAN': 0,
    'SURIANI': 0,
    'SURIANO': 0,
    'SURICO': 0,
    'SURIEL': 0,
    'SURIN': 0,
    'SURINA': 0,
    'SURINE': 0,
    'SURIS': 0,
    'SURITA': 0,
    'SURKIN': 0,
    'SURLA': 0,
    'SURLES': 0,
    'SURLINE': 0,
    'SURLS': 0,
    'SURMA': 0,
    'SURMACZ': 0,
    'SURMAN': 0,
    'SURMEIER': 0,
    'SURO': 0,
    'SUROVEC': 0,
    'SUROVIK': 0,
    'SUROVY': 0,
    'SUROWIEC': 0,
    'SURPLUS': 0,
    'SURPRENANT': 0,
    'SURPRIS': 0,
    'SURPRISE': 0,
    'SURRAN': 0,
    'SURRATT': 0,
    'SURRELL': 0,
    'SURRENA': 0,
    'SURRENCY': 0,
    'SURRETT': 0,
    'SURRETTE': 0,
    'SURREY': 0,
    'SURRIDGE': 0,
    'SURRITT': 0,
    'SURRITTE': 0,
    'SURRY': 0,
    'SURSA': 0,
    'SURSELY': 0,
    'SURTEES': 0,
    'SURTI': 0,
    'SURVANCE': 0,
    'SURVANT': 0,
    'SURY': 0,
    'SURYA': 0,
    'SURYADEVARA': 0,
    'SURYAN': 0,
    'SUS': 0,
    'SUSA': 0,
    'SUSAG': 0,
    'SUSAK': 0,
    'SUSALLA': 0,
    'SUSAN': 0.9996600652171177,
    'SUSANA': 0.9947643979057592,
    'SUSANN': 1,
    'SUSANNA': 1,
    'SUSANNAH': 1,
    'SUSANNE': 1,
    'SUSANO': 0,
    'SUSANTO': 0,
    'SUSCA': 0,
    'SUSCO': 0,
    'SUSDORF': 0,
    'SUSEE': 0,
    'SUSEN': 0,
    'SUSHKO': 0,
    'SUSI': 0,
    'SUSICH': 0,
    'SUSICK': 0,
    'SUSIE': 0.9979633401221996,
    'SUSIN': 0,
    'SUSINO': 0,
    'SUSKA': 0,
    'SUSKI': 0,
    'SUSKIE': 0,
    'SUSKIN': 0,
    'SUSKIND': 0,
    'SUSKO': 0,
    'SUSMAN': 0,
    'SUSNIK': 0,
    'SUSOEFF': 0,
    'SUSON': 0,
    'SUSONG': 0,
    'SUSOR': 0,
    'SUSS': 0,
    'SUSSAN': 0,
    'SUSSER': 0,
    'SUSSEX': 0,
    'SUSSKIND': 0,
    'SUSSMAN': 0,
    'SUSSMANN': 0,
    'SUSTACHE': 0,
    'SUSTAIRE': 0,
    'SUSTAITA': 0,
    'SUSTAR': 0,
    'SUSTARSIC': 0,
    'SUSTER': 0,
    'SUSTERSIC': 0,
    'SUSY': 1,
    'SUSZEK': 0,
    'SUSZKO': 0,
    'SUSZYNSKI': 0,
    'SUTA': 0,
    'SUTAK': 0,
    'SUTANTO': 0,
    'SUTARIA': 0,
    'SUTCH': 0,
    'SUTCLIFF': 0,
    'SUTCLIFFE': 0,
    'SUTER': 0,
    'SUTERA': 0,
    'SUTFIN': 0,
    'SUTH': 0,
    'SUTHAR': 0,
    'SUTHARD': 0,
    'SUTHER': 0,
    'SUTHERBY': 0,
    'SUTHERIN': 0,
    'SUTHERLAND': 0,
    'SUTHERLIN': 0,
    'SUTHERLY': 0,
    'SUTHERS': 0,
    'SUTICH': 0,
    'SUTIN': 0,
    'SUTKA': 0,
    'SUTKER': 0,
    'SUTKO': 0,
    'SUTKOWSKI': 0,
    'SUTKUS': 0,
    'SUTLER': 0,
    'SUTLEY': 0,
    'SUTLIFF': 0,
    'SUTLIFFE': 0,
    'SUTO': 0,
    'SUTOR': 0,
    'SUTORIUS': 0,
    'SUTPHEN': 0,
    'SUTPHIN': 0,
    'SUTRICK': 0,
    'SUTRO': 0,
    'SUTT': 0,
    'SUTTELL': 0,
    'SUTTEN': 0,
    'SUTTER': 0,
    'SUTTERBY': 0,
    'SUTTERER': 0,
    'SUTTERFIELD': 0,
    'SUTTERLIN': 0,
    'SUTTERS': 0,
    'SUTTIE': 0,
    'SUTTLE': 0,
    'SUTTLES': 0,
    'SUTTMAN': 0,
    'SUTTMILLER': 0,
    'SUTTNER': 0,
    'SUTTON': 0,
    'SUTULA': 0,
    'SUTYAK': 0,
    'SUVA': 0,
    'SUVAK': 0,
    'SUVER': 0,
    'SUWA': 0,
    'SUWALSKI': 0,
    'SUWINSKI': 0,
    'SUWYN': 0,
    'SUY': 0,
    'SUYAMA': 0,
    'SUYAT': 0,
    'SUYDAM': 0,
    'SUZAN': 0.9933774834437086,
    'SUZANN': 1,
    'SUZANNA': 1,
    'SUZANNE': 1,
    'SUZETTE': 1,
    'SUZI': 1,
    'SUZIE': 1,
    'SUZOR': 0,
    'SUZUKI': 0,
    'SUZY': 1,
    'SVACINA': 0,
    'SVALDI': 0,
    'SVANCARA': 0,
    'SVANDA': 0,
    'SVARE': 0,
    'SVATEK': 0,
    'SVATOS': 0,
    'SVAY': 0,
    'SVEC': 0,
    'SVEDA': 0,
    'SVEDBERG': 0,
    'SVEDIN': 0,
    'SVEE': 0,
    'SVEEN': 0,
    'SVEHLA': 0,
    'SVEHLAK': 0,
    'SVEJDA': 0,
    'SVEJKOVSKY': 0,
    'SVENDSEN': 0,
    'SVENNINGSEN': 0,
    'SVENSEN': 0,
    'SVENSON': 0,
    'SVENSSON': 0,
    'SVERDLOV': 0,
    'SVESTKA': 0,
    'SVETICH': 0,
    'SVETLANA': 1,
    'SVETLIK': 0,
    'SVETZ': 0,
    'SVEUM': 0,
    'SVIEN': 0,
    'SVIHEL': 0,
    'SVIHLA': 0,
    'SVILAR': 0,
    'SVIR': 0,
    'SVIRSKY': 0,
    'SVITAK': 0,
    'SVITEK': 0,
    'SVOBODA': 0,
    'SVOBODNY': 0,
    'SVRCEK': 0,
    'SWAB': 0,
    'SWABB': 0,
    'SWABY': 0,
    'SWACK': 0,
    'SWACKER': 0,
    'SWACKHAMER': 0,
    'SWACKHAMMER': 0,
    'SWADE': 0,
    'SWADENER': 0,
    'SWADER': 0,
    'SWADLEY': 0,
    'SWADLING': 0,
    'SWAFFAR': 0,
    'SWAFFER': 0,
    'SWAFFIELD': 0,
    'SWAFFORD': 0,
    'SWAGEL': 0,
    'SWAGER': 0,
    'SWAGERTY': 0,
    'SWAGGARD': 0,
    'SWAGGART': 0,
    'SWAGGER': 0,
    'SWAGGERT': 0,
    'SWAGGERTY': 0,
    'SWAGLER': 0,
    'SWAHN': 0,
    'SWAIDNER': 0,
    'SWAILES': 0,
    'SWAILS': 0,
    'SWAIM': 0,
    'SWAIN': 0,
    'SWAINE': 0,
    'SWAINSON': 0,
    'SWAINSTON': 0,
    'SWAISGOOD': 0,
    'SWAIT': 0,
    'SWALE': 0,
    'SWALES': 0,
    'SWALL': 0,
    'SWALLEN': 0,
    'SWALLEY': 0,
    'SWALLIE': 0,
    'SWALLOW': 0,
    'SWALLOWS': 0,
    'SWALLS': 0,
    'SWALM': 0,
    'SWALVE': 0,
    'SWALWELL': 0,
    'SWAM': 0,
    'SWAMI': 0,
    'SWAMINATHAN': 0,
    'SWAMP': 0,
    'SWAMY': 0,
    'SWAN': 0,
    'SWANAGAN': 0,
    'SWANBECK': 0,
    'SWANBERG': 0,
    'SWANCEY': 0,
    'SWANCUTT': 0,
    'SWANCY': 0,
    'SWANDA': 0,
    'SWANDER': 0,
    'SWANE': 0,
    'SWANEK': 0,
    'SWANEPOEL': 0,
    'SWANER': 0,
    'SWANEY': 0,
    'SWANGER': 0,
    'SWANGIN': 0,
    'SWANGLER': 0,
    'SWANGO': 0,
    'SWANHART': 0,
    'SWANICK': 0,
    'SWANIER': 0,
    'SWANIGAN': 0,
    'SWANK': 0,
    'SWANKE': 0,
    'SWANLUND': 0,
    'SWANN': 0,
    'SWANNACK': 0,
    'SWANNER': 0,
    'SWANSEN': 0,
    'SWANSEY': 0,
    'SWANSIGER': 0,
    'SWANSON': 0,
    'SWANSTON': 0,
    'SWANSTROM': 0,
    'SWANT': 0,
    'SWANTEK': 0,
    'SWANTNER': 0,
    'SWANTON': 0,
    'SWANTZ': 0,
    'SWANWICK': 0,
    'SWANZY': 0,
    'SWAPP': 0,
    'SWARBRICK': 0,
    'SWARD': 0,
    'SWARENS': 0,
    'SWAREY': 0,
    'SWARINGEN': 0,
    'SWARINGIM': 0,
    'SWARM': 0,
    'SWARMER': 0,
    'SWARN': 0,
    'SWARNER': 0,
    'SWARR': 0,
    'SWART': 0,
    'SWARTHOUT': 0,
    'SWARTLEY': 0,
    'SWARTOUT': 0,
    'SWARTS': 0,
    'SWARTWOOD': 0,
    'SWARTWOUT': 0,
    'SWARTZ': 0,
    'SWARTZBAUGH': 0,
    'SWARTZEL': 0,
    'SWARTZELL': 0,
    'SWARTZENDRUBER': 0,
    'SWARTZENTRUBER': 0,
    'SWARTZFAGER': 0,
    'SWARTZLANDER': 0,
    'SWARTZMAN': 0,
    'SWARTZMILLER': 0,
    'SWARTZWELDER': 0,
    'SWARY': 0,
    'SWASEY': 0,
    'SWATEK': 0,
    'SWATHWOOD': 0,
    'SWATKOWSKI': 0,
    'SWATMAN': 0,
    'SWATOSH': 0,
    'SWATSWORTH': 0,
    'SWATT': 0,
    'SWATTS': 0,
    'SWATZELL': 0,
    'SWAUGER': 0,
    'SWAVELY': 0,
    'SWAW': 0,
    'SWAY': 0,
    'SWAYER': 0,
    'SWAYNE': 0,
    'SWAYNEY': 0,
    'SWAYNGIM': 0,
    'SWAYZE': 0,
    'SWAYZER': 0,
    'SWAZEY': 0,
    'SWE': 0,
    'SWEANEY': 0,
    'SWEANY': 0,
    'SWEARENGEN': 0,
    'SWEARENGIN': 0,
    'SWEARER': 0,
    'SWEARINGEN': 0,
    'SWEARINGER': 0,
    'SWEARINGIN': 0,
    'SWEARINGTON': 0,
    'SWEARNGIN': 0,
    'SWEARS': 0,
    'SWEASY': 0,
    'SWEAT': 0,
    'SWEATLAND': 0,
    'SWEATMAN': 0,
    'SWEATT': 0,
    'SWEATTE': 0,
    'SWEAZEY': 0,
    'SWEAZY': 0,
    'SWECKER': 0,
    'SWED': 0,
    'SWEDA': 0,
    'SWEDBERG': 0,
    'SWEDE': 0,
    'SWEDEEN': 0,
    'SWEDEN': 0,
    'SWEDENBURG': 0,
    'SWEDER': 0,
    'SWEDIN': 0,
    'SWEDISH': 0,
    'SWEDLOW': 0,
    'SWEDLUND': 0,
    'SWEDO': 0,
    'SWEE': 0,
    'SWEEBE': 0,
    'SWEED': 0,
    'SWEEDEN': 0,
    'SWEEDLER': 0,
    'SWEEK': 0,
    'SWEELEY': 0,
    'SWEELY': 0,
    'SWEEM': 0,
    'SWEEN': 0,
    'SWEENEY': 0,
    'SWEENIE': 0,
    'SWEENY': 0,
    'SWEEP': 0,
    'SWEEPER': 0,
    'SWEERE': 0,
    'SWEERS': 0,
    'SWEESY': 0,
    'SWEET': 0,
    'SWEETAPPLE': 0,
    'SWEETEN': 0,
    'SWEETENBURG': 0,
    'SWEETER': 0,
    'SWEETIN': 0,
    'SWEETING': 0,
    'SWEETLAND': 0,
    'SWEETMAN': 0,
    'SWEETNAM': 0,
    'SWEETON': 0,
    'SWEETS': 0,
    'SWEETSER': 0,
    'SWEETWOOD': 0,
    'SWEEZER': 0,
    'SWEEZEY': 0,
    'SWEEZY': 0,
    'SWEGAN': 0,
    'SWEGER': 0,
    'SWEGLE': 0,
    'SWEGLES': 0,
    'SWEGMAN': 0,
    'SWEHLA': 0,
    'SWEIDAN': 0,
    'SWEIG': 0,
    'SWEIGARD': 0,
    'SWEIGART': 0,
    'SWEIGER': 0,
    'SWEIGERT': 0,
    'SWEINHART': 0,
    'SWEIS': 0,
    'SWEISS': 0,
    'SWEITZER': 0,
    'SWELL': 0,
    'SWEM': 0,
    'SWEN': 0,
    'SWENDER': 0,
    'SWENDROWSKI': 0,
    'SWENDSEN': 0,
    'SWENDSON': 0,
    'SWENEY': 0,
    'SWENGEL': 0,
    'SWENK': 0,
    'SWENNES': 0,
    'SWENNING': 0,
    'SWENO': 0,
    'SWENOR': 0,
    'SWENSEN': 0,
    'SWENSON': 0,
    'SWENSSON': 0,
    'SWENTON': 0,
    'SWENTY': 0,
    'SWEPSON': 0,
    'SWEPSTON': 0,
    'SWERDLOFF': 0,
    'SWERDLOW': 0,
    'SWERINGEN': 0,
    'SWERSKY': 0,
    'SWERTFAGER': 0,
    'SWESEY': 0,
    'SWETLAND': 0,
    'SWETLIK': 0,
    'SWETMAN': 0,
    'SWETNAM': 0,
    'SWETS': 0,
    'SWETT': 0,
    'SWETZ': 0,
    'SWEZEY': 0,
    'SWIADER': 0,
    'SWIANTEK': 0,
    'SWIAT': 0,
    'SWIATEK': 0,
    'SWIATKOWSKI': 0,
    'SWIATLOWSKI': 0,
    'SWIATOCHA': 0,
    'SWIATOWY': 0,
    'SWICEGOOD': 0,
    'SWICK': 0,
    'SWICKARD': 0,
    'SWICKER': 0,
    'SWICORD': 0,
    'SWIDER': 0,
    'SWIDEREK': 0,
    'SWIDERSKI': 0,
    'SWIDLER': 0,
    'SWIDZINSKI': 0,
    'SWIECA': 0,
    'SWIECH': 0,
    'SWIECICHOWSKI': 0,
    'SWIECICKI': 0,
    'SWIECKI': 0,
    'SWIECZKOWSKI': 0,
    'SWIENTON': 0,
    'SWIER': 0,
    'SWIERC': 0,
    'SWIERCZ': 0,
    'SWIERCZEK': 0,
    'SWIERCZEWSKI': 0,
    'SWIERCZYNSKI': 0,
    'SWIERENGA': 0,
    'SWIERINGA': 0,
    'SWIERK': 0,
    'SWIERKOWSKI': 0,
    'SWIERS': 0,
    'SWIES': 0,
    'SWIETEK': 0,
    'SWIETER': 0,
    'SWIETLIK': 0,
    'SWIETON': 0,
    'SWIFT': 0,
    'SWIGART': 0,
    'SWIGER': 0,
    'SWIGERT': 0,
    'SWIGGART': 0,
    'SWIGGETT': 0,
    'SWIGGUM': 0,
    'SWIGONSKI': 0,
    'SWIHART': 0,
    'SWILER': 0,
    'SWILLEY': 0,
    'SWILLING': 0,
    'SWILLINGER': 0,
    'SWIM': 0,
    'SWIMLEY': 0,
    'SWIMM': 0,
    'SWIMMER': 0,
    'SWIMS': 0,
    'SWINARSKI': 0,
    'SWINBURN': 0,
    'SWINBURNE': 0,
    'SWINDAL': 0,
    'SWINDALL': 0,
    'SWINDEL': 0,
    'SWINDELL': 0,
    'SWINDELLS': 0,
    'SWINDERMAN': 0,
    'SWINDLE': 0,
    'SWINDLEHURST': 0,
    'SWINDLER': 0,
    'SWINDOLL': 0,
    'SWINEA': 0,
    'SWINEFORD': 0,
    'SWINEHART': 0,
    'SWINEY': 0,
    'SWINFORD': 0,
    'SWING': 0,
    'SWINGEN': 0,
    'SWINGER': 0,
    'SWINGLE': 0,
    'SWINGLER': 0,
    'SWINGLEY': 0,
    'SWINHART': 0,
    'SWINIARSKI': 0,
    'SWINK': 0,
    'SWINNEA': 0,
    'SWINNERTON': 0,
    'SWINNEY': 0,
    'SWINNIE': 0,
    'SWINSON': 0,
    'SWINT': 0,
    'SWINTEK': 0,
    'SWINTON': 0,
    'SWINYER': 0,
    'SWIONTEK': 0,
    'SWIRCZYNSKI': 0,
    'SWIRE': 0,
    'SWIRES': 0,
    'SWIRSKY': 0,
    'SWISHER': 0,
    'SWISS': 0,
    'SWISSHELM': 0,
    'SWIST': 0,
    'SWISTAK': 0,
    'SWISTON': 0,
    'SWITAJ': 0,
    'SWITALA': 0,
    'SWITALSKI': 0,
    'SWITCH': 0,
    'SWITCHER': 0,
    'SWITEK': 0,
    'SWITHENBANK': 0,
    'SWITHERS': 0,
    'SWITLICK': 0,
    'SWITSER': 0,
    'SWITZ': 0,
    'SWITZENBERG': 0,
    'SWITZER': 0,
    'SWITZLER': 0,
    'SWOAP': 0,
    'SWOAPE': 0,
    'SWOBODA': 0,
    'SWOFFER': 0,
    'SWOFFORD': 0,
    'SWOGER': 0,
    'SWOGGER': 0,
    'SWOISH': 0,
    'SWOL': 0,
    'SWOMLEY': 0,
    'SWON': 0,
    'SWONGER': 0,
    'SWONKE': 0,
    'SWOOPE': 0,
    'SWOOPES': 0,
    'SWOPE': 0,
    'SWOPES': 0,
    'SWOR': 0,
    'SWORD': 0,
    'SWORDS': 0,
    'SWORTZEL': 0,
    'SWOVELAND': 0,
    'SWOVERLAND': 0,
    'SWOYER': 0,
    'SWYDEN': 0,
    'SWYERS': 0,
    'SWYGART': 0,
    'SWYGERT': 0,
    'SWYMER': 0,
    'SY': 0,
    'SYAL': 0,
    'SYAS': 0,
    'SYBERG': 0,
    'SYBERT': 0,
    'SYBESMA': 0,
    'SYBIL': 1,
    'SYBLE': 1,
    'SYBRANT': 0,
    'SYCH': 0,
    'SYCK': 0,
    'SYCKS': 0,
    'SYCZ': 0,
    'SYDDALL': 0,
    'SYDENSTRICKER': 0,
    'SYDLOWSKI': 0,
    'SYDNES': 0,
    'SYDNEY': 0.985545335085414,
    'SYDNOR': 0,
    'SYDOR': 0,
    'SYDOW': 0,
    'SYE': 0,
    'SYED': 0,
    'SYEDA': 0,
    'SYER': 0,
    'SYERS': 0,
    'SYFERT': 0,
    'SYFRETT': 0,
    'SYHARATH': 0,
    'SYKES': 0,
    'SYKORA': 0,
    'SYLA': 0,
    'SYLER': 0,
    'SYLESTINE': 0,
    'SYLLA': 0,
    'SYLTE': 0,
    'SYLVA': 0,
    'SYLVAIN': 0,
    'SYLVAN': 0,
    'SYLVANUS': 0,
    'SYLVAS': 0,
    'SYLVE': 0,
    'SYLVER': 0,
    'SYLVERS': 0,
    'SYLVEST': 0,
    'SYLVESTER': 0.8036739380022963,
    'SYLVESTRE': 0,
    'SYLVESTRI': 0,
    'SYLVESTRO': 0,
    'SYLVIA': 0.9879437374413931,
    'SYLVIE': 1,
    'SYLVIS': 0,
    'SYMANIETZ': 0,
    'SYMANK': 0,
    'SYMANSKI': 0,
    'SYME': 0,
    'SYMENS': 0,
    'SYMER': 0,
    'SYMES': 0,
    'SYMINGTON': 0,
    'SYMMES': 0,
    'SYMMONDS': 0,
    'SYMMS': 0,
    'SYMON': 0,
    'SYMONDS': 0,
    'SYMONETTE': 0,
    'SYMONS': 0,
    'SYMPSON': 0,
    'SYMS': 0,
    'SYNAKOWSKI': 0,
    'SYNAN': 0,
    'SYNDER': 0,
    'SYNDERGAARD': 0,
    'SYNEK': 0,
    'SYNER': 0,
    'SYNESAEL': 0,
    'SYNHORST': 0,
    'SYNN': 0,
    'SYNNESTVEDT': 0,
    'SYNNOTT': 0,
    'SYNOVEC': 0,
    'SYNOWIEC': 0,
    'SYNSTELIEN': 0,
    'SYNTHIA': 1,
    'SYPEK': 0,
    'SYPERT': 0,
    'SYPHAX': 0,
    'SYPHER': 0,
    'SYPHERD': 0,
    'SYPHERS': 0,
    'SYPHRETT': 0,
    'SYPHRIT': 0,
    'SYPHUS': 0,
    'SYPIEN': 0,
    'SYPNIEWSKI': 0,
    'SYPOLT': 0,
    'SYPULT': 0,
    'SYRACUSE': 0,
    'SYRE': 0,
    'SYREETA': 1,
    'SYREK': 0,
    'SYRELL': 0,
    'SYREN': 0,
    'SYRES': 0,
    'SYRETT': 0,
    'SYRIA': 0,
    'SYRIAC': 0,
    'SYRING': 0,
    'SYRJALA': 0,
    'SYRON': 0,
    'SYRSTAD': 0,
    'SYRUS': 0,
    'SYSAK': 0,
    'SYSAVATH': 0,
    'SYSKA': 0,
    'SYSKO': 0,
    'SYSLO': 0,
    'SYSOL': 0,
    'SYSWERDA': 0,
    'SYTEK': 0,
    'SYTH': 0,
    'SYTSMA': 0,
    'SYVERSEN': 0,
    'SYVERSON': 0,
    'SYVERTSEN': 0,
    'SYVERTSON': 0,
    'SYVRUD': 0,
    'SYX': 0,
    'SYZDEK': 0,
    'SZABADOS': 0,
    'SZABAT': 0,
    'SZABLA': 0,
    'SZABLEWSKI': 0,
    'SZABLOWSKI': 0,
    'SZABO': 0,
    'SZACHTA': 0,
    'SZADKOWSKI': 0,
    'SZADY': 0,
    'SZAFLARSKI': 0,
    'SZAFRAN': 0,
    'SZAFRANIEC': 0,
    'SZAFRANSKI': 0,
    'SZAJNA': 0,
    'SZAKACS': 0,
    'SZAKAL': 0,
    'SZAKALY': 0,
    'SZAL': 0,
    'SZALA': 0,
    'SZALAI': 0,
    'SZALANKIEWICZ': 0,
    'SZALANSKI': 0,
    'SZALAY': 0,
    'SZALEWSKI': 0,
    'SZALKIEWICZ': 0,
    'SZALKOWSKI': 0,
    'SZALWINSKI': 0,
    'SZANTO': 0,
    'SZANYI': 0,
    'SZAREK': 0,
    'SZARKA': 0,
    'SZARKO': 0,
    'SZARKOWSKI': 0,
    'SZARMACH': 0,
    'SZARO': 0,
    'SZAROWICZ': 0,
    'SZARY': 0,
    'SZARZYNSKI': 0,
    'SZASZ': 0,
    'SZATHMARY': 0,
    'SZATKO': 0,
    'SZATKOWSKI': 0,
    'SZATMARY': 0,
    'SZCZECH': 0,
    'SZCZECHOWICZ': 0,
    'SZCZECHOWSKI': 0,
    'SZCZECINSKI': 0,
    'SZCZEPANEK': 0,
    'SZCZEPANIAK': 0,
    'SZCZEPANIK': 0,
    'SZCZEPANSKI': 0,
    'SZCZEPKOWSKI': 0,
    'SZCZERBA': 0,
    'SZCZESNIAK': 0,
    'SZCZESNY': 0,
    'SZCZOTKA': 0,
    'SZCZUBLEWSKI': 0,
    'SZCZUR': 0,
    'SZCZUREK': 0,
    'SZCZYGIEL': 0,
    'SZCZYPINSKI': 0,
    'SZE': 0,
    'SZEGDA': 0,
    'SZEGEDI': 0,
    'SZEKELY': 0,
    'SZEKERES': 0,
    'SZELA': 0,
    'SZELAG': 0,
    'SZELC': 0,
    'SZELES': 0,
    'SZELEST': 0,
    'SZELIGA': 0,
    'SZELL': 0,
    'SZELUGA': 0,
    'SZEMAN': 0,
    'SZEMBORSKI': 0,
    'SZEMPRUCH': 0,
    'SZEP': 0,
    'SZEPANSKI': 0,
    'SZERSZEN': 0,
    'SZETELA': 0,
    'SZETO': 0,
    'SZEWC': 0,
    'SZEWCZAK': 0,
    'SZEWCZUK': 0,
    'SZEWCZYK': 0,
    'SZIGETHY': 0,
    'SZIGETI': 0,
    'SZILAGYI': 0,
    'SZKLARSKI': 0,
    'SZKLARZ': 0,
    'SZLACHETKA': 0,
    'SZLACHTA': 0,
    'SZLOSEK': 0,
    'SZMANIA': 0,
    'SZMURLO': 0,
    'SZMYD': 0,
    'SZOKA': 0,
    'SZOKE': 0,
    'SZOLLOSI': 0,
    'SZOPA': 0,
    'SZOPINSKI': 0,
    'SZORC': 0,
    'SZOSTAK': 0,
    'SZOSTEK': 0,
    'SZOSZOREK': 0,
    'SZOT': 0,
    'SZOTT': 0,
    'SZOZDA': 0,
    'SZPAK': 0,
    'SZPAKOWSKI': 0,
    'SZPARA': 0,
    'SZPILA': 0,
    'SZPUNAR': 0,
    'SZTABA': 0,
    'SZTUKOWSKI': 0,
    'SZUBA': 0,
    'SZUBINSKI': 0,
    'SZUCH': 0,
    'SZUCS': 0,
    'SZUKALA': 0,
    'SZUKALSKI': 0,
    'SZUL': 0,
    'SZULBORSKI': 0,
    'SZULC': 0,
    'SZULCZEWSKI': 0,
    'SZULEWSKI': 0,
    'SZUMIGALA': 0,
    'SZUMINSKI': 0,
    'SZUMOWSKI': 0,
    'SZUMSKI': 0,
    'SZURA': 0,
    'SZUREK': 0,
    'SZURGOT': 0,
    'SZWAJA': 0,
    'SZWAJKOWSKI': 0,
    'SZWARC': 0,
    'SZWAST': 0,
    'SZWEC': 0,
    'SZWED': 0,
    'SZWEDA': 0,
    'SZWEDO': 0,
    'SZYCH': 0,
    'SZYCHOWSKI': 0,
    'SZYDEL': 0,
    'SZYDLIK': 0,
    'SZYDLO': 0,
    'SZYDLOWSKI': 0,
    'SZYJKA': 0,
    'SZYKOWNY': 0,
    'SZYMANEK': 0,
    'SZYMANIAK': 0,
    'SZYMANIK': 0,
    'SZYMANOWSKI': 0,
    'SZYMANSKI': 0,
    'SZYMASZEK': 0,
    'SZYMBORSKI': 0,
    'SZYMCZAK': 0,
    'SZYMCZYK': 0,
    'SZYMKIEWICZ': 0,
    'SZYMKOWIAK': 0,
    'SZYMKOWICZ': 0,
    'SZYMKOWSKI': 0,
    'SZYMONIAK': 0,
    'SZYMONIK': 0,
    'SZYMULA': 0,
    'SZYMUSIAK': 0,
    'SZYNAL': 0,
    'SZYNKOWSKI': 0,
    'SZYPER': 0,
    'SZYPERSKI': 0,
    'SZYPULA': 0,
    'SZYPULSKI': 0,
    'SZYSZKA': 0,
    'SZYSZKO': 0,
    'TA': 0.31645569620253167,
    'TAA': 0,
    'TAAFFE': 0,
    'TAAKE': 0,
    'TAAL': 0,
    'TAAPKEN': 0,
    'TAATJES': 0,
    'TABA': 0,
    'TABACCHI': 0,
    'TABACCO': 0,
    'TABACHNICK': 0,
    'TABACHNIK': 0,
    'TABACK': 0,
    'TABACZYNSKI': 0,
    'TABAG': 0,
    'TABAHA': 0,
    'TABAK': 0,
    'TABAKA': 0,
    'TABAKIN': 0,
    'TABAKOVIC': 0,
    'TABALDO': 0,
    'TABAN': 0,
    'TABANGCURA': 0,
    'TABANO': 0,
    'TABAR': 0,
    'TABARES': 0,
    'TABAREZ': 0,
    'TABAS': 0,
    'TABASCO': 0,
    'TABASSUM': 0,
    'TABAT': 0,
    'TABATA': 0,
    'TABATABAI': 0,
    'TABATHA': 1,
    'TABATT': 0,
    'TABAYOYONG': 0,
    'TABB': 0,
    'TABBAA': 0,
    'TABBARA': 0,
    'TABBERT': 0,
    'TABBI': 0,
    'TABBS': 0,
    'TABBUTT': 0,
    'TABEEK': 0,
    'TABEL': 0,
    'TABELING': 0,
    'TABELLION': 0,
    'TABER': 0,
    'TABERA': 0,
    'TABERNA': 0,
    'TABERS': 0,
    'TABERSKI': 0,
    'TABERT': 0,
    'TABERY': 0,
    'TABET': 0,
    'TABETHA': 1,
    'TABIB': 0,
    'TABIBI': 0,
    'TABIBIAN': 0,
    'TABIN': 0,
    'TABION': 0,
    'TABIOS': 0,
    'TABISH': 0,
    'TABISZ': 0,
    'TABIT': 0,
    'TABITA': 0,
    'TABITHA': 1,
    'TABLADA': 0,
    'TABLANTE': 0,
    'TABLAS': 0,
    'TABLE': 0,
    'TABLER': 0,
    'TABOADA': 0,
    'TABOLT': 0,
    'TABON': 0,
    'TABONE': 0,
    'TABOR': 0,
    'TABORA': 0,
    'TABORDA': 0,
    'TABORGA': 0,
    'TABORN': 0,
    'TABORS': 0,
    'TABORSKY': 0,
    'TABRIZI': 0,
    'TABRON': 0,
    'TABUCHI': 0,
    'TABULLO': 0,
    'TABUYO': 0,
    'TACADENA': 0,
    'TACCETTA': 0,
    'TACCHI': 0,
    'TACCONE': 0,
    'TACCONELLI': 0,
    'TACCONI': 0,
    'TACEY': 0,
    'TACHA': 0,
    'TACHE': 0,
    'TACHELL': 0,
    'TACHENY': 0,
    'TACHER': 0,
    'TACHIBANA': 0,
    'TACHICK': 0,
    'TACHINE': 0,
    'TACHIQUIN': 0,
    'TACIA': 0,
    'TACINELLI': 0,
    'TACK': 0,
    'TACKA': 0,
    'TACKABERRY': 0,
    'TACKE': 0,
    'TACKEL': 0,
    'TACKER': 0,
    'TACKES': 0,
    'TACKET': 0,
    'TACKETT': 0,
    'TACKITT': 0,
    'TACKMAN': 0,
    'TACOMA': 0,
    'TACON': 0,
    'TACORONTE': 0,
    'TACQUARD': 0,
    'TACURI': 0,
    'TACY': 0,
    'TAD': 1,
    'TADA': 0,
    'TADAJEWSKI': 0,
    'TADAKI': 0,
    'TADAYON': 0,
    'TADD': 0,
    'TADDEI': 0,
    'TADDEO': 0,
    'TADDER': 0,
    'TADDIA': 0,
    'TADDIE': 0,
    'TADDONIO': 0,
    'TADDY': 0,
    'TADE': 0,
    'TADEMY': 0,
    'TADENA': 0,
    'TADEO': 0,
    'TADESSE': 0,
    'TADEVOSYAN': 0,
    'TADIC': 0,
    'TADINA': 0,
    'TADLOCK': 0,
    'TADMAN': 0,
    'TADROS': 0,
    'TADSEN': 0,
    'TADY': 0,
    'TADYCH': 0,
    'TAE': 0,
    'TAEGE': 0,
    'TAEGER': 0,
    'TAETS': 0,
    'TAFARO': 0,
    'TAFE': 0,
    'TAFEL': 0,
    'TAFELSKI': 0,
    'TAFESSE': 0,
    'TAFF': 0,
    'TAFFE': 0,
    'TAFFEL': 0,
    'TAFFER': 0,
    'TAFFET': 0,
    'TAFFNER': 0,
    'TAFLINGER': 0,
    'TAFOLLA': 0,
    'TAFOYA': 0,
    'TAFRESHI': 0,
    'TAFT': 0,
    'TAFUA': 0,
    'TAFUR': 0,
    'TAFURI': 0,
    'TAG': 0,
    'TAGA': 0,
    'TAGALICUD': 0,
    'TAGALOA': 0,
    'TAGAMI': 0,
    'TAGART': 0,
    'TAGATA': 0,
    'TAGATAC': 0,
    'TAGAWA': 0,
    'TAGER': 0,
    'TAGERT': 0,
    'TAGG': 0,
    'TAGGARD': 0,
    'TAGGART': 0,
    'TAGGE': 0,
    'TAGGER': 0,
    'TAGGERT': 0,
    'TAGGETT': 0,
    'TAGHAVI': 0,
    'TAGHIZADEH': 0,
    'TAGHON': 0,
    'TAGLE': 0,
    'TAGLER': 0,
    'TAGLIA': 0,
    'TAGLIABUE': 0,
    'TAGLIAFERRI': 0,
    'TAGLIAFERRO': 0,
    'TAGLIAMONTE': 0,
    'TAGLIANETTI': 0,
    'TAGLIARENI': 0,
    'TAGLIARINI': 0,
    'TAGLIARINO': 0,
    'TAGLIAVIA': 0,
    'TAGLIENTE': 0,
    'TAGLIENTI': 0,
    'TAGLIERI': 0,
    'TAGLIONE': 0,
    'TAGO': 0,
    'TAGOE': 0,
    'TAGORDA': 0,
    'TAGTMEYER': 0,
    'TAGUCHI': 0,
    'TAGUE': 0,
    'TAGUINOD': 0,
    'TAGUPA': 0,
    'TAH': 0,
    'TAHA': 0,
    'TAHAN': 0,
    'TAHANEY': 0,
    'TAHARA': 0,
    'TAHE': 0,
    'TAHER': 0,
    'TAHERI': 0,
    'TAHIR': 0,
    'TAHIRI': 0,
    'TAHIROVIC': 0,
    'TAHMASIAN': 0,
    'TAHTINEN': 0,
    'TAHY': 0,
    'TAI': 0.4201680672268908,
    'TAIBI': 0,
    'TAIBL': 0,
    'TAICLET': 0,
    'TAIJERON': 0,
    'TAIL': 0,
    'TAILLEFER': 0,
    'TAILLON': 0,
    'TAILOR': 0,
    'TAIN': 0,
    'TAINA': 1,
    'TAING': 0,
    'TAINTER': 0,
    'TAINTOR': 0,
    'TAIPALE': 0,
    'TAIRA': 0,
    'TAISEY': 0,
    'TAISHA': 1,
    'TAIT': 0,
    'TAITAGUE': 0,
    'TAITANO': 0,
    'TAITE': 0,
    'TAITO': 0,
    'TAITT': 0,
    'TAITZ': 0,
    'TAIWO': 0,
    'TAJ': 0,
    'TAJALLE': 0,
    'TAJCHMAN': 0,
    'TAJIMA': 0,
    'TAJIRI': 0,
    'TAJUANA': 1,
    'TAK': 0,
    'TAKA': 0,
    'TAKABAYASHI': 0,
    'TAKAC': 0,
    'TAKACH': 0,
    'TAKACS': 0,
    'TAKADA': 0,
    'TAKAGI': 0,
    'TAKAHARA': 0,
    'TAKAHASHI': 0,
    'TAKAHATA': 0,
    'TAKAI': 0,
    'TAKAKI': 0,
    'TAKAKO': 1,
    'TAKALA': 0,
    'TAKAMATSU': 0,
    'TAKAMI': 0,
    'TAKAMINE': 0,
    'TAKAMIYA': 0,
    'TAKAMORI': 0,
    'TAKAMOTO': 0,
    'TAKAMURA': 0,
    'TAKANO': 0,
    'TAKAO': 0,
    'TAKAOKA': 0,
    'TAKARA': 0,
    'TAKAS': 0,
    'TAKASAKI': 0,
    'TAKASE': 0,
    'TAKASH': 0,
    'TAKASHIMA': 0,
    'TAKASUGI': 0,
    'TAKATA': 0,
    'TAKATS': 0,
    'TAKAYAMA': 0,
    'TAKAYESU': 0,
    'TAKE': 0,
    'TAKEDA': 0,
    'TAKEHARA': 0,
    'TAKEI': 0,
    'TAKEKAWA': 0,
    'TAKEMORI': 0,
    'TAKEMOTO': 0,
    'TAKEMURA': 0,
    'TAKEN': 0,
    'TAKENAKA': 0,
    'TAKES': 0,
    'TAKESHITA': 0,
    'TAKETA': 0,
    'TAKEUCHI': 0,
    'TAKEYAMA': 0,
    'TAKHAR': 0,
    'TAKI': 0,
    'TAKIGUCHI': 0,
    'TAKIMOTO': 0,
    'TAKIS': 0,
    'TAKISHA': 1,
    'TAKITA': 0,
    'TAKIZAWA': 0,
    'TAKLA': 0,
    'TAKO': 0,
    'TAKOS': 0,
    'TAKUSHI': 0,
    'TAKVORIAN': 0,
    'TAL': 0,
    'TALA': 0,
    'TALABER': 0,
    'TALABERA': 0,
    'TALABI': 0,
    'TALADA': 0,
    'TALADAY': 0,
    'TALAFUSE': 0,
    'TALAGA': 0,
    'TALAMANTE': 0,
    'TALAMANTES': 0,
    'TALAMANTEZ': 0,
    'TALAMAS': 0,
    'TALAMINI': 0,
    'TALAMO': 0,
    'TALAN': 0,
    'TALANCON': 0,
    'TALANIAN': 0,
    'TALARCZYK': 0,
    'TALAREK': 0,
    'TALARICO': 0,
    'TALARO': 0,
    'TALAS': 0,
    'TALASEK': 0,
    'TALASKA': 0,
    'TALASKI': 0,
    'TALATI': 0,
    'TALAVERA': 0,
    'TALAYUMPTEWA': 0,
    'TALBERG': 0,
    'TALBERT': 0,
    'TALBOT': 0,
    'TALBOTT': 0,
    'TALBURT': 0,
    'TALCOTT': 0,
    'TALE': 0,
    'TALEB': 0,
    'TALEBI': 0,
    'TALEN': 0,
    'TALENO': 0,
    'TALENS': 0,
    'TALENT': 0,
    'TALENTO': 0,
    'TALERICO': 0,
    'TALFORD': 0,
    'TALGO': 0,
    'TALHELM': 0,
    'TALIA': 0.9615384615384616,
    'TALIAFERRO': 0,
    'TALIAN': 0,
    'TALIANCICH': 0,
    'TALIANI': 0,
    'TALIB': 0,
    'TALIC': 0,
    'TALICH': 0,
    'TALIENTO': 0,
    'TALIERCIO': 0,
    'TALIFERRO': 0,
    'TALIK': 0,
    'TALIS': 0,
    'TALISHA': 1,
    'TALISMAN': 0,
    'TALITHA': 1,
    'TALK': 0,
    'TALKEN': 0,
    'TALKINGTON': 0,
    'TALKOWSKI': 0,
    'TALL': 0,
    'TALLA': 0,
    'TALLABAS': 0,
    'TALLADA': 0,
    'TALLAKSEN': 0,
    'TALLAKSON': 0,
    'TALLANT': 0,
    'TALLARICO': 0,
    'TALLARIDA': 0,
    'TALLAS': 0,
    'TALLBULL': 0,
    'TALLCHIEF': 0,
    'TALLE': 0,
    'TALLEDO': 0,
    'TALLEN': 0,
    'TALLENT': 0,
    'TALLER': 0,
    'TALLERICO': 0,
    'TALLETT': 0,
    'TALLEUR': 0,
    'TALLEY': 0,
    'TALLIA': 0,
    'TALLIE': 0,
    'TALLINI': 0,
    'TALLIS': 0,
    'TALLMADGE': 0,
    'TALLMAN': 0,
    'TALLMON': 0,
    'TALLO': 0,
    'TALLON': 0,
    'TALLURI': 0,
    'TALLUTO': 0,
    'TALLY': 0,
    'TALMADGE': 0,
    'TALMAGE': 0,
    'TALMAN': 0,
    'TALMO': 0,
    'TALMON': 0,
    'TALO': 0,
    'TALON': 0,
    'TALONE': 0,
    'TALOTTA': 0,
    'TALPAS': 0,
    'TALREJA': 0,
    'TALSKY': 0,
    'TALSMA': 0,
    'TALT': 0,
    'TALTON': 0,
    'TALTY': 0,
    'TALUCCI': 0,
    'TALUKDAR': 0,
    'TALUKDER': 0,
    'TALWAR': 0,
    'TAM': 0.30769230769230765,
    'TAMA': 0.9259259259259258,
    'TAMACCIO': 0,
    'TAMAGNI': 0,
    'TAMAI': 0,
    'TAMAKI': 0,
    'TAMALA': 1,
    'TAMAN': 0,
    'TAMANAHA': 0,
    'TAMANG': 0,
    'TAMANINI': 0,
    'TAMAR': 1,
    'TAMARA': 0.9994568169473113,
    'TAMAREZ': 0,
    'TAMARGO': 0,
    'TAMARIZ': 0,
    'TAMARKIN': 0,
    'TAMARO': 0,
    'TAMARU': 0,
    'TAMAS': 0,
    'TAMASHIRD': 0,
    'TAMASHIRO': 0,
    'TAMASI': 0,
    'TAMASY': 0,
    'TAMATHA': 1,
    'TAMAY': 0,
    'TAMAYO': 0,
    'TAMAYOSE': 0,
    'TAMBA': 0,
    'TAMBASCO': 0,
    'TAMBE': 0,
    'TAMBELLINI': 0,
    'TAMBER': 0,
    'TAMBERINO': 0,
    'TAMBINI': 0,
    'TAMBLIN': 0,
    'TAMBLING': 0,
    'TAMBLYN': 0,
    'TAMBOLI': 0,
    'TAMBONE': 0,
    'TAMBOR': 0,
    'TAMBORELLO': 0,
    'TAMBORINI': 0,
    'TAMBORNINO': 0,
    'TAMBORSKI': 0,
    'TAMBRA': 1,
    'TAMBUNGA': 0,
    'TAMBURELLI': 0,
    'TAMBURELLO': 0,
    'TAMBURINI': 0,
    'TAMBURINO': 0,
    'TAMBURO': 0,
    'TAMBURRI': 0,
    'TAMBURRINO': 0,
    'TAMBURRO': 0,
    'TAME': 0,
    'TAMEIKA': 1,
    'TAMEKA': 1,
    'TAMEKIA': 1,
    'TAMELA': 1,
    'TAMELING': 0,
    'TAMER': 0,
    'TAMERA': 1,
    'TAMES': 0,
    'TAMESHA': 1,
    'TAMEZ': 0,
    'TAMI': 0.9977827050997782,
    'TAMICA': 1,
    'TAMIE': 1,
    'TAMIKA': 1,
    'TAMIKO': 1,
    'TAMILIO': 0,
    'TAMILLO': 0,
    'TAMIMI': 0,
    'TAMIR': 0,
    'TAMISHA': 1,
    'TAMKE': 0,
    'TAMKIN': 0,
    'TAMLIN': 0,
    'TAMLYN': 0,
    'TAMM': 0,
    'TAMMANY': 0,
    'TAMMARA': 1,
    'TAMMARO': 0,
    'TAMME': 0,
    'TAMMEN': 0,
    'TAMMERA': 1,
    'TAMMI': 0.9963768115942029,
    'TAMMIE': 1,
    'TAMMINEN': 0,
    'TAMMINGA': 0,
    'TAMMY': 1,
    'TAMONDONG': 0,
    'TAMOSAITIS': 0,
    'TAMPA': 0,
    'TAMPLAIN': 0,
    'TAMPLEN': 0,
    'TAMPLIN': 0,
    'TAMPON': 0,
    'TAMRA': 1,
    'TAMRAT': 0,
    'TAMRAZ': 0,
    'TAMS': 0,
    'TAMULEVICH': 0,
    'TAMULIS': 0,
    'TAMULONIS': 0,
    'TAMURA': 0,
    'TAN': 0,
    'TANA': 0.9819967266775776,
    'TANABE': 0,
    'TANADA': 0,
    'TANAKA': 0,
    'TANANA': 0,
    'TANASE': 0,
    'TANBERG': 0,
    'TANCER': 0,
    'TANCHEZ': 0,
    'TANCK': 0,
    'TANCO': 0,
    'TANCREDE': 0,
    'TANCREDI': 0,
    'TANCRETI': 0,
    'TANCZOS': 0,
    'TANDA': 0,
    'TANDBERG': 0,
    'TANDE': 0,
    'TANDEL': 0,
    'TANDESKI': 0,
    'TANDLER': 0,
    'TANDO': 0,
    'TANDOC': 0,
    'TANDON': 0,
    'TANDRA': 1,
    'TANDY': 0.5617977528089888,
    'TANE': 0,
    'TANEDO': 0,
    'TANEGA': 0,
    'TANEJA': 0,
    'TANEKA': 1,
    'TANEN': 0,
    'TANENBAUM': 0,
    'TANER': 0,
    'TANESHA': 1,
    'TANEY': 0,
    'TANG': 0,
    'TANGA': 0,
    'TANGARIFE': 0,
    'TANGARO': 0,
    'TANGE': 0,
    'TANGEL': 0,
    'TANGELA': 1,
    'TANGEMAN': 0,
    'TANGEN': 0,
    'TANGER': 0,
    'TANGHE': 0,
    'TANGHERLINI': 0,
    'TANGI': 0,
    'TANGLAO': 0,
    'TANGMAN': 0,
    'TANGNEY': 0,
    'TANGO': 0,
    'TANGONAN': 0,
    'TANGORA': 0,
    'TANGORRA': 0,
    'TANGREDI': 0,
    'TANGREN': 0,
    'TANGUAY': 0,
    'TANGUMA': 0,
    'TANGUY': 0,
    'TANI': 0,
    'TANIA': 1,
    'TANIELIAN': 0,
    'TANIELU': 0,
    'TANIGAWA': 0,
    'TANIGUCHI': 0,
    'TANIKA': 1,
    'TANIMOTO': 0,
    'TANIMURA': 0,
    'TANIOKA': 0,
    'TANIS': 0,
    'TANISHA': 1,
    'TANITA': 0,
    'TANJA': 1,
    'TANJI': 0,
    'TANK': 0,
    'TANKARD': 0,
    'TANKE': 0,
    'TANKEL': 0,
    'TANKER': 0,
    'TANKERSLEY': 0,
    'TANKERSLY': 0,
    'TANKESLEY': 0,
    'TANKING': 0,
    'TANKO': 0,
    'TANKS': 0,
    'TANKSLEY': 0,
    'TANKSON': 0,
    'TANLEY': 0,
    'TANN': 0,
    'TANNA': 0.9433962264150944,
    'TANNAHILL': 0,
    'TANNEHILL': 0,
    'TANNEN': 0,
    'TANNENBAUM': 0,
    'TANNER': 0.25862068965517243,
    'TANNERT': 0,
    'TANNERY': 0,
    'TANNEY': 0,
    'TANNIAN': 0,
    'TANNIEHILL': 0,
    'TANNIS': 0,
    'TANNLER': 0,
    'TANNO': 0,
    'TANNOUS': 0,
    'TANNY': 0,
    'TANO': 0,
    'TANON': 0,
    'TANORI': 0,
    'TANOUE': 0,
    'TANOUS': 0,
    'TANOUYE': 0,
    'TANQUARY': 0,
    'TANSEL': 0,
    'TANSEY': 0,
    'TANSIL': 0,
    'TANSILL': 0,
    'TANSKI': 0,
    'TANSKY': 0,
    'TANSLEY': 0,
    'TANSY': 0,
    'TANT': 0,
    'TANTALO': 0,
    'TANTILLO': 0,
    'TANTLINGER': 0,
    'TANTOCO': 0,
    'TANTON': 0,
    'TANTUM': 0,
    'TANUVASA': 0,
    'TANVEER': 0,
    'TANYA': 1,
    'TANZ': 0,
    'TANZELLA': 0,
    'TANZER': 0,
    'TANZI': 0,
    'TANZILLO': 0,
    'TANZINI': 0,
    'TANZMAN': 0,
    'TANZOLA': 0,
    'TANZY': 0,
    'TAO': 0,
    'TAOKA': 0,
    'TAORMINA': 0,
    'TAORMINO': 0,
    'TAP': 0,
    'TAPAHA': 0,
    'TAPANES': 0,
    'TAPANG': 0,
    'TAPANI': 0,
    'TAPE': 0,
    'TAPELLA': 0,
    'TAPER': 0,
    'TAPERT': 0,
    'TAPHORN': 0,
    'TAPHOUSE': 0,
    'TAPIA': 0,
    'TAPIAS': 0,
    'TAPIE': 0,
    'TAPIO': 0,
    'TAPIZ': 0,
    'TAPKE': 0,
    'TAPKEN': 0,
    'TAPLER': 0,
    'TAPLEY': 0,
    'TAPLIN': 0,
    'TAPP': 0,
    'TAPPA': 0,
    'TAPPAN': 0,
    'TAPPARO': 0,
    'TAPPE': 0,
    'TAPPEN': 0,
    'TAPPENDORF': 0,
    'TAPPER': 0,
    'TAPPERO': 0,
    'TAPPERT': 0,
    'TAPPIN': 0,
    'TAPPS': 0,
    'TAPPY': 0,
    'TAPSCOTT': 0,
    'TAQUINO': 0,
    'TAR': 0,
    'TARA': 0.998227446590167,
    'TARABA': 0,
    'TARABAY': 0,
    'TARABOCCHIA': 0,
    'TARABOCHIA': 0,
    'TARABORELLI': 0,
    'TARABORRELLI': 0,
    'TARACENA': 0,
    'TARADASH': 0,
    'TARAFA': 0,
    'TARAH': 1,
    'TARALA': 0,
    'TARALLO': 0,
    'TARAN': 0,
    'TARANGO': 0,
    'TARANTELLI': 0,
    'TARANTINI': 0,
    'TARANTINO': 0,
    'TARANTO': 0,
    'TARANTOLA': 0,
    'TARARA': 0,
    'TARAS': 0,
    'TARASCHI': 0,
    'TARASCIO': 0,
    'TARASCO': 0,
    'TARASENKO': 0,
    'TARASEVICH': 0,
    'TARASEWICZ': 0,
    'TARASI': 0,
    'TARASIEWICZ': 0,
    'TARASKA': 0,
    'TARASOV': 0,
    'TARASUK': 0,
    'TARASYUK': 0,
    'TARATUTA': 0,
    'TARAVELLA': 0,
    'TARAZI': 0,
    'TARAZON': 0,
    'TARAZONA': 0,
    'TARBELL': 0,
    'TARBER': 0,
    'TARBERT': 0,
    'TARBET': 0,
    'TARBILL': 0,
    'TARBOX': 0,
    'TARBUCK': 0,
    'TARBUSH': 0,
    'TARBUTTON': 0,
    'TARBY': 0,
    'TARCA': 0,
    'TARCHALA': 0,
    'TARCZYNSKI': 0,
    'TARD': 0,
    'TARDI': 0,
    'TARDIBUONO': 0,
    'TARDIE': 0,
    'TARDIF': 0,
    'TARDIFF': 0,
    'TARDIO': 0,
    'TARDO': 0,
    'TARDUGNO': 0,
    'TARDY': 0,
    'TAREEN': 0,
    'TAREN': 1,
    'TARGETT': 0,
    'TARGGART': 0,
    'TARGONSKI': 0,
    'TARGOS': 0,
    'TARGOSZ': 0,
    'TARI': 0.9345794392523364,
    'TARICA': 0,
    'TARIN': 0,
    'TARINI': 0,
    'TARIO': 0,
    'TARIQ': 0,
    'TARIS': 0,
    'TARK': 0,
    'TARKA': 0,
    'TARKENTON': 0,
    'TARKET': 0,
    'TARKINGTON': 0,
    'TARKOWSKI': 0,
    'TARLETON': 0,
    'TARLEY': 0,
    'TARLING': 0,
    'TARLOW': 0,
    'TARLTON': 0,
    'TARMAN': 0,
    'TARMANN': 0,
    'TARMEY': 0,
    'TARN': 0,
    'TARNACKI': 0,
    'TARNAWSKI': 0,
    'TARNER': 0,
    'TARNEY': 0,
    'TARNO': 0,
    'TARNOFF': 0,
    'TARNOW': 0,
    'TARNOWSKI': 0,
    'TARO': 0,
    'TAROLI': 0,
    'TAROLLI': 0,
    'TARON': 0,
    'TARONE': 0,
    'TARP': 0,
    'TARPENNING': 0,
    'TARPEY': 0,
    'TARPINIAN': 0,
    'TARPLEY': 0,
    'TARPY': 0,
    'TARQUINI': 0,
    'TARQUINIO': 0,
    'TARQUINO': 0,
    'TARR': 0,
    'TARRA': 1,
    'TARRAGO': 0,
    'TARRAN': 0,
    'TARRANCE': 0,
    'TARRANT': 0,
    'TARRANTS': 0,
    'TARRAS': 0,
    'TARRATS': 0,
    'TARRELL': 0,
    'TARRENCE': 0,
    'TARRER': 0,
    'TARRICONE': 0,
    'TARRILLION': 0,
    'TARRIO': 0,
    'TARRIS': 0,
    'TARRO': 0,
    'TARROW': 0,
    'TARRY': 0,
    'TARSA': 0,
    'TARSHA': 1,
    'TARSHIS': 0,
    'TARSI': 0,
    'TARSIA': 0,
    'TARSITANO': 0,
    'TARSON': 0,
    'TART': 0,
    'TARTAGLIA': 0,
    'TARTAGLIO': 0,
    'TARTAGLIONE': 0,
    'TARTAKOVSKY': 0,
    'TARTAL': 0,
    'TARTAMELLA': 0,
    'TARTAR': 0,
    'TARTARO': 0,
    'TARTE': 0,
    'TARTELL': 0,
    'TARTER': 0,
    'TARTSAH': 0,
    'TARTT': 0,
    'TARUC': 0,
    'TARULA': 0,
    'TARULLI': 0,
    'TARULLO': 0,
    'TARVER': 0,
    'TARVES': 0,
    'TARVIN': 0,
    'TARVIS': 0,
    'TARWATER': 0,
    'TARY': 0,
    'TARYN': 1,
    'TARZIA': 0,
    'TARZIAN': 0,
    'TARZWELL': 0,
    'TAS': 0,
    'TASA': 0,
    'TASAKA': 0,
    'TASAKI': 0,
    'TASBY': 0,
    'TASCA': 0,
    'TASCH': 0,
    'TASCHE': 0,
    'TASCHEREAU': 0,
    'TASCHLER': 0,
    'TASCHNER': 0,
    'TASCIONE': 0,
    'TASCO': 0,
    'TASCON': 0,
    'TASE': 0,
    'TASEVSKI': 0,
    'TASH': 0,
    'TASHA': 1,
    'TASHCHYAN': 0,
    'TASHER': 0,
    'TASHIA': 1,
    'TASHIMA': 0,
    'TASHINA': 1,
    'TASHIRD': 0,
    'TASHIRO': 0,
    'TASHJIAN': 0,
    'TASHMAN': 0,
    'TASI': 0,
    'TASIA': 1,
    'TASIC': 0,
    'TASILLO': 0,
    'TASKA': 0,
    'TASKER': 0,
    'TASKEY': 0,
    'TASLER': 0,
    'TASMAN': 0,
    'TASS': 0,
    'TASSARA': 0,
    'TASSE': 0,
    'TASSELL': 0,
    'TASSET': 0,
    'TASSEY': 0,
    'TASSI': 0,
    'TASSIE': 0,
    'TASSIN': 0,
    'TASSINARI': 0,
    'TASSLER': 0,
    'TASSO': 0,
    'TASSON': 0,
    'TASSONE': 0,
    'TASSONI': 0,
    'TASSOS': 0,
    'TASSOUL': 0,
    'TASSY': 0,
    'TAST': 0,
    'TASTAD': 0,
    'TASTE': 0,
    'TASTET': 0,
    'TASTO': 0,
    'TASWELL': 0,
    'TAT': 0,
    'TATA': 0,
    'TATALOVICH': 0,
    'TATAR': 0,
    'TATARA': 0,
    'TATAREK': 0,
    'TATARIAN': 0,
    'TATARKA': 0,
    'TATARSKY': 0,
    'TATASCIORE': 0,
    'TATE': 0,
    'TATEISHI': 0,
    'TATEL': 0,
    'TATELMAN': 0,
    'TATEM': 0,
    'TATEOSIAN': 0,
    'TATER': 0,
    'TATERA': 0,
    'TATES': 0,
    'TATEYAMA': 0,
    'TATGE': 0,
    'TATGENHORST': 0,
    'TATHAM': 0,
    'TATIANA': 1,
    'TATIS': 0,
    'TATKO': 0,
    'TATLOCK': 0,
    'TATLONGHARI': 0,
    'TATLOW': 0,
    'TATMAN': 0,
    'TATMON': 0,
    'TATNALL': 0,
    'TATO': 0,
    'TATOM': 0,
    'TATON': 0,
    'TATONE': 0,
    'TATOR': 0,
    'TATOSIAN': 0,
    'TATREAU': 0,
    'TATRO': 0,
    'TATROE': 0,
    'TATROW': 0,
    'TATSCH': 0,
    'TATSEY': 0,
    'TATSUMI': 0,
    'TATSUNO': 0,
    'TATTA': 0,
    'TATTEN': 0,
    'TATTERS': 0,
    'TATTERSALL': 0,
    'TATTERSHALL': 0,
    'TATTERSON': 0,
    'TATTI': 0,
    'TATTOLI': 0,
    'TATTON': 0,
    'TATTRIE': 0,
    'TATU': 0,
    'TATULLI': 0,
    'TATUM': 0.1037344398340249,
    'TATUSKO': 0,
    'TATYANA': 1,
    'TATZ': 0,
    'TAU': 0,
    'TAUA': 0,
    'TAUANUU': 0,
    'TAUB': 0,
    'TAUBE': 0,
    'TAUBEL': 0,
    'TAUBENFELD': 0,
    'TAUBENHEIM': 0,
    'TAUBER': 0,
    'TAUBERT': 0,
    'TAUBITZ': 0,
    'TAUBMAN': 0,
    'TAUCH': 0,
    'TAUCHEN': 0,
    'TAUCHER': 0,
    'TAUER': 0,
    'TAUFA': 0,
    'TAUFER': 0,
    'TAUGHER': 0,
    'TAUILIILI': 0,
    'TAUKE': 0,
    'TAUL': 0,
    'TAULA': 0,
    'TAULBEE': 0,
    'TAULLI': 0,
    'TAULMAN': 0,
    'TAULTON': 0,
    'TAUNT': 0,
    'TAUNTON': 0,
    'TAUNYA': 1,
    'TAUPIER': 0,
    'TAURA': 0,
    'TAURIAC': 0,
    'TAURIAINEN': 0,
    'TAURIELLO': 0,
    'TAURMAN': 0,
    'TAURO': 0,
    'TAUS': 0,
    'TAUSCH': 0,
    'TAUSCHEK': 0,
    'TAUSCHER': 0,
    'TAUSEND': 0,
    'TAUSINGA': 0,
    'TAUSSIG': 0,
    'TAUTE': 0,
    'TAUTFEST': 0,
    'TAUTGES': 0,
    'TAUTKUS': 0,
    'TAUTOLO': 0,
    'TAUZIN': 0,
    'TAVAGLIONE': 0,
    'TAVAI': 0,
    'TAVAKOLI': 0,
    'TAVANA': 0,
    'TAVANI': 0,
    'TAVANO': 0,
    'TAVARA': 0,
    'TAVARES': 0,
    'TAVAREZ': 0,
    'TAVASSOLI': 0,
    'TAVE': 0,
    'TAVEIRA': 0,
    'TAVEL': 0,
    'TAVELLA': 0,
    'TAVELLI': 0,
    'TAVENER': 0,
    'TAVENNER': 0,
    'TAVER': 0,
    'TAVERA': 0,
    'TAVERAS': 0,
    'TAVERNA': 0,
    'TAVERNER': 0,
    'TAVERNESE': 0,
    'TAVERNIA': 0,
    'TAVERNIER': 0,
    'TAVES': 0,
    'TAVIRA': 0,
    'TAVIS': 0,
    'TAVITA': 0,
    'TAVITAS': 0,
    'TAVITIAN': 0,
    'TAVIZON': 0,
    'TAVOLACCI': 0,
    'TAVORMINA': 0,
    'TAW': 0,
    'TAWA': 0,
    'TAWADROS': 0,
    'TAWANA': 1,
    'TAWANDA': 1,
    'TAWANNA': 1,
    'TAWASHA': 0,
    'TAWATER': 0,
    'TAWEEL': 0,
    'TAWES': 0,
    'TAWFIK': 0,
    'TAWIAH': 0,
    'TAWIL': 0,
    'TAWNA': 1,
    'TAWNEY': 0,
    'TAWNY': 1,
    'TAWNYA': 1,
    'TAWZER': 0,
    'TAX': 0,
    'TAXIS': 0,
    'TAXTER': 0,
    'TAY': 0,
    'TAYAG': 0,
    'TAYBRON': 0,
    'TAYCO': 0,
    'TAYE': 0,
    'TAYEH': 0,
    'TAYES': 0,
    'TAYLAN': 0,
    'TAYLER': 0,
    'TAYLO': 0,
    'TAYLOE': 0,
    'TAYLOR': 0.1187961985216473,
    'TAYLORSON': 0,
    'TAYMAN': 0,
    'TAYNA': 1,
    'TAYNOR': 0,
    'TAYO': 0,
    'TAYON': 0,
    'TAYRIEN': 0,
    'TAYS': 0,
    'TAYSE': 0,
    'TAYSOM': 0,
    'TAYSON': 0,
    'TAZELAAR': 0,
    'TAZEWELL': 0,
    'TAZI': 0,
    'TCHANG': 0,
    'TCHEN': 0,
    'TCHIDA': 0,
    'TE': 0,
    'TEA': 0,
    'TEABO': 0,
    'TEACH': 0,
    'TEACHER': 0,
    'TEACHEY': 0,
    'TEACHMAN': 0,
    'TEACHOUT': 0,
    'TEACHWORTH': 0,
    'TEADT': 0,
    'TEAFATILLER': 0,
    'TEAFF': 0,
    'TEAFORD': 0,
    'TEAGARDEN': 0,
    'TEAGER': 0,
    'TEAGLE': 0,
    'TEAGUE': 0,
    'TEAHAN': 0,
    'TEAKELL': 0,
    'TEAL': 0,
    'TEALE': 0,
    'TEALER': 0,
    'TEALL': 0,
    'TEAM': 0,
    'TEAMAN': 0,
    'TEAMER': 0,
    'TEANEY': 0,
    'TEANO': 0,
    'TEAR': 0,
    'TEARE': 0,
    'TEARNEY': 0,
    'TEARS': 0,
    'TEAS': 0,
    'TEASDALE': 0,
    'TEASE': 0,
    'TEASLEY': 0,
    'TEASTER': 0,
    'TEAT': 0,
    'TEATE': 0,
    'TEATER': 0,
    'TEATERS': 0,
    'TEATES': 0,
    'TEATOR': 0,
    'TEATS': 0,
    'TEBALDI': 0,
    'TEBAY': 0,
    'TEBBE': 0,
    'TEBBEN': 0,
    'TEBBETTS': 0,
    'TEBBS': 0,
    'TEBBUTT': 0,
    'TEBEAU': 0,
    'TEBEDO': 0,
    'TEBEEST': 0,
    'TEBERG': 0,
    'TEBO': 0,
    'TEBOE': 0,
    'TEBOW': 0,
    'TEC': 0,
    'TECCA': 0,
    'TECCE': 0,
    'TECCO': 0,
    'TECH': 0,
    'TECHAU': 0,
    'TECHLIN': 0,
    'TECK': 0,
    'TECKENBROCK': 0,
    'TECKLENBURG': 0,
    'TECLE': 0,
    'TECSON': 0,
    'TECUMSEH': 0,
    'TECUN': 0,
    'TECZA': 0,
    'TED': 0.9984399375975038,
    'TEDALDI': 0,
    'TEDDER': 0,
    'TEDDERS': 0,
    'TEDDLIE': 0,
    'TEDDY': 0.9933774834437086,
    'TEDERS': 0,
    'TEDESCHI': 0,
    'TEDESCO': 0,
    'TEDFORD': 0,
    'TEDLA': 0,
    'TEDLOCK': 0,
    'TEDONE': 0,
    'TEDORE': 0,
    'TEDRICK': 0,
    'TEDROW': 0,
    'TEE': 0,
    'TEECE': 0,
    'TEED': 0,
    'TEEGARDEN': 0,
    'TEEGARDIN': 0,
    'TEEHAN': 0,
    'TEEHEE': 0,
    'TEEKELL': 0,
    'TEEL': 0,
    'TEELE': 0,
    'TEELING': 0,
    'TEELUCKSINGH': 0,
    'TEEM': 0,
    'TEEMAN': 0,
    'TEEMER': 0,
    'TEEMS': 0,
    'TEEN': 0,
    'TEENA': 1,
    'TEEPE': 0,
    'TEEPLE': 0,
    'TEEPLES': 0,
    'TEER': 0,
    'TEERLINK': 0,
    'TEES': 0,
    'TEESDALE': 0,
    'TEESE': 0,
    'TEET': 0,
    'TEETER': 0,
    'TEETERS': 0,
    'TEETOR': 0,
    'TEETS': 0,
    'TEETSEL': 0,
    'TEETZ': 0,
    'TEETZEL': 0,
    'TEETZEN': 0,
    'TEEVAN': 0,
    'TEFERA': 0,
    'TEFERI': 0,
    'TEFERRA': 0,
    'TEFERTILLER': 0,
    'TEFF': 0,
    'TEFFETELLER': 0,
    'TEFFT': 0,
    'TEFTELLER': 0,
    'TEGAN': 0.9433962264150944,
    'TEGARDEN': 0,
    'TEGEDER': 0,
    'TEGEL': 0,
    'TEGELER': 0,
    'TEGELS': 0,
    'TEGEN': 0,
    'TEGENKAMP': 0,
    'TEGETHOFF': 0,
    'TEGG': 0,
    'TEGGE': 0,
    'TEGLAND': 0,
    'TEGLER': 0,
    'TEGNER': 0,
    'TEGTMAN': 0,
    'TEGTMEIER': 0,
    'TEGTMEYER': 0,
    'TEH': 0,
    'TEHAN': 0,
    'TEHANDON': 0,
    'TEHRANCHI': 0,
    'TEHRANI': 0,
    'TEI': 0,
    'TEIBEL': 0,
    'TEICH': 0,
    'TEICHEIRA': 0,
    'TEICHER': 0,
    'TEICHERT': 0,
    'TEICHMAN': 0,
    'TEICHMANN': 0,
    'TEICHMILLER': 0,
    'TEICHNER': 0,
    'TEICHROEB': 0,
    'TEIFER': 0,
    'TEIFKE': 0,
    'TEIG': 0,
    'TEIGE': 0,
    'TEIGEN': 0,
    'TEIGLAND': 0,
    'TEIKEN': 0,
    'TEINERT': 0,
    'TEIPEL': 0,
    'TEIS': 0,
    'TEISHA': 1,
    'TEITEL': 0,
    'TEITELBAUM': 0,
    'TEITELMAN': 0,
    'TEITLER': 0,
    'TEITSMA': 0,
    'TEITSWORTH': 0,
    'TEITZ': 0,
    'TEITZEL': 0,
    'TEIXEIRA': 0,
    'TEJA': 0,
    'TEJADA': 0,
    'TEJANI': 0,
    'TEJANO': 0,
    'TEJEDA': 0,
    'TEJEDOR': 0,
    'TEJERA': 0,
    'TEJERO': 0,
    'TEJRAL': 0,
    'TEK': 0,
    'TEKAVEC': 0,
    'TEKELL': 0,
    'TEKESTE': 0,
    'TEKIE': 0,
    'TEKIN': 0,
    'TEKIPPE': 0,
    'TEKLE': 0,
    'TEKLU': 0,
    'TEKULVE': 0,
    'TELA': 0,
    'TELANDER': 0,
    'TELANO': 0,
    'TELECKY': 0,
    'TELEGA': 0,
    'TELEMAQUE': 0,
    'TELENKO': 0,
    'TELEP': 0,
    'TELES': 0,
    'TELESCA': 0,
    'TELESCO': 0,
    'TELESE': 0,
    'TELESFORD': 0,
    'TELESZ': 0,
    'TELFAIR': 0,
    'TELFER': 0,
    'TELFOR': 0,
    'TELFORD': 0,
    'TELFORT': 0,
    'TELIS': 0,
    'TELIZ': 0,
    'TELKAMP': 0,
    'TELKER': 0,
    'TELL': 0,
    'TELLA': 0,
    'TELLADO': 0,
    'TELLAS': 0,
    'TELLE': 0,
    'TELLECHEA': 0,
    'TELLEEN': 0,
    'TELLEFSEN': 0,
    'TELLEFSON': 0,
    'TELLER': 0,
    'TELLERIA': 0,
    'TELLERS': 0,
    'TELLES': 0,
    'TELLEY': 0,
    'TELLEZ': 0,
    'TELLIER': 0,
    'TELLING': 0,
    'TELLINGHUISEN': 0,
    'TELLIS': 0,
    'TELLMAN': 0,
    'TELLO': 0,
    'TELLOCK': 0,
    'TELLONE': 0,
    'TELLOR': 0,
    'TELLY': 0,
    'TELMA': 1,
    'TELMAN': 0,
    'TELO': 0,
    'TELON': 0,
    'TELSCHOW': 0,
    'TELSON': 0,
    'TELTOW': 0,
    'TELUSMA': 0,
    'TEMAN': 0,
    'TEMBLADOR': 0,
    'TEMBREULL': 0,
    'TEMBY': 0,
    'TEMEKA': 1,
    'TEMES': 0,
    'TEMIKA': 1,
    'TEMKIN': 0,
    'TEMME': 0,
    'TEMMEN': 0,
    'TEMONEY': 0,
    'TEMORES': 0,
    'TEMP': 0,
    'TEMPEL': 0,
    'TEMPERLY': 0,
    'TEMPERO': 0,
    'TEMPEST': 0,
    'TEMPESTA': 0,
    'TEMPIE': 1,
    'TEMPIO': 0,
    'TEMPLAR': 0,
    'TEMPLE': 0.11025358324145536,
    'TEMPLEMAN': 0,
    'TEMPLER': 0,
    'TEMPLES': 0,
    'TEMPLET': 0,
    'TEMPLETON': 0,
    'TEMPLIN': 0,
    'TEMPLO': 0,
    'TEMPONE': 0,
    'TEMTE': 0,
    'TEN': 0,
    'TENA': 0.8503401360544217,
    'TENACE': 0,
    'TENAGLIA': 0,
    'TENAN': 0,
    'TENANT': 0,
    'TENAS': 0,
    'TENBARGE': 0,
    'TENBERG': 0,
    'TENBRINK': 0,
    'TENBROECK': 0,
    'TENBROOK': 0,
    'TENBUSCH': 0,
    'TENCATE': 0,
    'TENCER': 0,
    'TENCH': 0,
    'TENCZA': 0,
    'TENCZAR': 0,
    'TENDALL': 0,
    'TENDER': 0,
    'TENDICK': 0,
    'TENDLER': 0,
    'TENE': 0,
    'TENEBRUSO': 0,
    'TENECELA': 0,
    'TENEN': 0,
    'TENENBAUM': 0,
    'TENER': 0,
    'TENERELLI': 0,
    'TENEROWICZ': 0,
    'TENERY': 0,
    'TENESACA': 0,
    'TENESHA': 1,
    'TENEYCK': 0,
    'TENEYUQUE': 0,
    'TENEZACA': 0,
    'TENG': 0,
    'TENGAN': 0,
    'TENGCO': 0,
    'TENGE': 0,
    'TENGLER': 0,
    'TENGWALL': 0,
    'TENHAGEN': 0,
    'TENHAKEN': 0,
    'TENHARMSEL': 0,
    'TENHAVE': 0,
    'TENHET': 0,
    'TENHOEVE': 0,
    'TENHOFF': 0,
    'TENHOLDER': 0,
    'TENHUNDFELD': 0,
    'TENIENTE': 0,
    'TENINTY': 0,
    'TENISHA': 1,
    'TENISON': 0,
    'TENKATE': 0,
    'TENLEY': 0,
    'TENN': 0,
    'TENNANT': 0,
    'TENNAPEL': 0,
    'TENNELL': 0,
    'TENNENBAUM': 0,
    'TENNENT': 0,
    'TENNER': 0,
    'TENNERY': 0,
    'TENNESEN': 0,
    'TENNESON': 0,
    'TENNESSEE': 0,
    'TENNESSEN': 0,
    'TENNETT': 0,
    'TENNEY': 0,
    'TENNIAL': 0,
    'TENNIE': 0.9523809523809523,
    'TENNIES': 0,
    'TENNILL': 0,
    'TENNILLE': 0.9615384615384616,
    'TENNIS': 0,
    'TENNISON': 0,
    'TENNISWOOD': 0,
    'TENNITY': 0,
    'TENNON': 0,
    'TENNY': 0,
    'TENNYSON': 0,
    'TENO': 0,
    'TENOLD': 0,
    'TENOR': 0,
    'TENORE': 0,
    'TENORIO': 0,
    'TENPAS': 0,
    'TENPENNY': 0,
    'TENREIRO': 0,
    'TENSEN': 0,
    'TENSLEY': 0,
    'TENTINGER': 0,
    'TENTION': 0,
    'TENTIS': 0,
    'TENTLER': 0,
    'TENUTA': 0,
    'TENUTO': 0,
    'TENWALDE': 0,
    'TENZER': 0,
    'TEO': 0,
    'TEODORA': 1,
    'TEODORESCU': 0,
    'TEODORO': 0.9363295880149812,
    'TEODOSIO': 0,
    'TEOFILA': 1,
    'TEOFILO': 0,
    'TEOH': 0,
    'TEOLI': 0,
    'TEOLIS': 0,
    'TEP': 0,
    'TEPALE': 0,
    'TEPAS': 0,
    'TEPE': 0,
    'TEPEDINO': 0,
    'TEPEN': 0,
    'TEPER': 0,
    'TEPERA': 0,
    'TEPETATE': 0,
    'TEPEZANO': 0,
    'TEPFER': 0,
    'TEPLEY': 0,
    'TEPLITSKY': 0,
    'TEPLITZ': 0,
    'TEPLY': 0,
    'TEPOX': 0,
    'TEPP': 0,
    'TEPPER': 0,
    'TEPPERMAN': 0,
    'TEPPO': 0,
    'TEPSIC': 0,
    'TEQUILA': 1,
    'TERA': 1,
    'TERADA': 0,
    'TERAI': 0,
    'TERAMOTO': 0,
    'TERAN': 0,
    'TERANDO': 0,
    'TERANISHI': 0,
    'TERAO': 0,
    'TERAOKA': 0,
    'TERASHIMA': 0,
    'TERBEEK': 0,
    'TERBEEST': 0,
    'TERBORG': 0,
    'TERBRACK': 0,
    'TERBROCK': 0,
    'TERBUSH': 0,
    'TERC': 0,
    'TERCEIRA': 0,
    'TERCEK': 0,
    'TERCERD': 0,
    'TERCERO': 0,
    'TERCHA': 0,
    'TEREASA': 1,
    'TEREFENKO': 0,
    'TEREK': 0,
    'TERELL': 0,
    'TERENCE': 1,
    'TERENZI': 0,
    'TERENZIO': 0,
    'TERESA': 0.9996727261908304,
    'TERESE': 1,
    'TERESI': 0,
    'TERESIA': 1,
    'TERESINSKI': 0,
    'TERESITA': 1,
    'TERESO': 0,
    'TERESSA': 1,
    'TERFEHR': 0,
    'TERHAAR': 0,
    'TERHARK': 0,
    'TERHORST': 0,
    'TERHUNE': 0,
    'TERI': 0.9978832778953733,
    'TERIBURY': 0,
    'TERICA': 1,
    'TERILLI': 0,
    'TERINA': 1,
    'TERINO': 0,
    'TERISA': 1,
    'TERJESEN': 0,
    'TERK': 0,
    'TERKELSEN': 0,
    'TERKEURST': 0,
    'TERKILDSEN': 0,
    'TERLECKI': 0,
    'TERLECKY': 0,
    'TERLEP': 0,
    'TERLESKY': 0,
    'TERLINDEN': 0,
    'TERLISNER': 0,
    'TERLIZZI': 0,
    'TERLOUW': 0,
    'TERMAAT': 0,
    'TERMAN': 0,
    'TERMEER': 0,
    'TERMIN': 0,
    'TERMINE': 0,
    'TERMINI': 0,
    'TERNER': 0,
    'TERNES': 0,
    'TERNET': 0,
    'TERNEUS': 0,
    'TERNEY': 0,
    'TERNULLO': 0,
    'TERNUS': 0,
    'TERO': 0,
    'TERON': 0,
    'TERP': 0,
    'TERPAK': 0,
    'TERPENING': 0,
    'TERPENNING': 0,
    'TERPIN': 0,
    'TERPSTRA': 0,
    'TERR': 0,
    'TERRA': 0.9535160905840286,
    'TERRACCIANO': 0,
    'TERRACE': 0,
    'TERRACIANO': 0,
    'TERRACINA': 0,
    'TERRACINO': 0,
    'TERRADO': 0,
    'TERRAL': 0,
    'TERRALL': 0,
    'TERRAN': 0,
    'TERRANA': 0,
    'TERRANCE': 0.9946125155408205,
    'TERRANELLA': 0,
    'TERRANO': 0,
    'TERRANOVA': 0,
    'TERRAS': 0,
    'TERRASAS': 0,
    'TERRASI': 0,
    'TERRAZA': 0,
    'TERRAZAS': 0,
    'TERRE': 0,
    'TERREAULT': 0,
    'TERREBONNE': 0,
    'TERREII': 0,
    'TERREL': 0,
    'TERRELL': 0.6255585344057195,
    'TERRELONGE': 0,
    'TERRENCE': 0.9983007646559048,
    'TERRERI': 0,
    'TERRERO': 0,
    'TERREROS': 0,
    'TERRES': 0,
    'TERRESA': 1,
    'TERRETT': 0,
    'TERREY': 0,
    'TERRI': 0.9994288977727014,
    'TERRIAN': 0,
    'TERRIBILE': 0,
    'TERRIBLE': 0,
    'TERRIE': 1,
    'TERRIEN': 0,
    'TERRIER': 0,
    'TERRIGNO': 0,
    'TERRIL': 0,
    'TERRILL': 0,
    'TERRILLION': 0,
    'TERRILYN': 1,
    'TERRIO': 0,
    'TERRIQUEZ': 0,
    'TERRIS': 0,
    'TERRITO': 0,
    'TERRIZZI': 0,
    'TERRO': 0,
    'TERRON': 0,
    'TERRONE': 0,
    'TERRONES': 0,
    'TERRONEZ': 0,
    'TERRUSO': 0,
    'TERRY': 0.9266940013746355,
    'TERRYBERRY': 0,
    'TERRYN': 0,
    'TERSIGNI': 0,
    'TERSTEEG': 0,
    'TERTEL': 0,
    'TERTERYAN': 0,
    'TERUEL': 0,
    'TERUYA': 0,
    'TERVEEN': 0,
    'TERVEER': 0,
    'TERVO': 0,
    'TERVORT': 0,
    'TERWELP': 0,
    'TERWEY': 0,
    'TERWILLEGAR': 0,
    'TERWILLEGER': 0,
    'TERWILLIGER': 0,
    'TERZANO': 0,
    'TERZI': 0,
    'TERZIAN': 0,
    'TERZIC': 0,
    'TERZICH': 0,
    'TERZIS': 0,
    'TERZO': 0,
    'TERZYAN': 0,
    'TES': 0,
    'TESAR': 0,
    'TESAREK': 0,
    'TESAURO': 0,
    'TESCH': 0,
    'TESCHENDORF': 0,
    'TESCHER': 0,
    'TESCHKE': 0,
    'TESCHLER': 0,
    'TESCHNER': 0,
    'TESDAHL': 0,
    'TESDALL': 0,
    'TESELLE': 0,
    'TESENIAR': 0,
    'TESFA': 0,
    'TESFAI': 0,
    'TESFAMARIAM': 0,
    'TESFAMICHAEL': 0,
    'TESFAY': 0,
    'TESFAYE': 0,
    'TESH': 0,
    'TESHA': 1,
    'TESHIMA': 0,
    'TESHOME': 0,
    'TESI': 0,
    'TESILLO': 0,
    'TESKA': 0,
    'TESKE': 0,
    'TESKEY': 0,
    'TESKY': 0,
    'TESLA': 0,
    'TESLAA': 0,
    'TESLER': 0,
    'TESLOW': 0,
    'TESLUK': 0,
    'TESMAN': 0,
    'TESMER': 0,
    'TESNER': 0,
    'TESNEY': 0,
    'TESNOW': 0,
    'TESO': 0,
    'TESON': 0,
    'TESONE': 0,
    'TESORD': 0,
    'TESORIERO': 0,
    'TESORO': 0,
    'TESREAU': 0,
    'TESS': 0.9345794392523364,
    'TESSA': 1,
    'TESSAR': 0,
    'TESSARI': 0,
    'TESSARO': 0,
    'TESSAY': 0,
    'TESSEMA': 0,
    'TESSEN': 0,
    'TESSENDORF': 0,
    'TESSENEER': 0,
    'TESSER': 0,
    'TESSIE': 1,
    'TESSIER': 0,
    'TESSIN': 0,
    'TESSITORE': 0,
    'TESSLER': 0,
    'TESSMAN': 0,
    'TESSMANN': 0,
    'TESSMER': 0,
    'TESSNEAR': 0,
    'TESSNEER': 0,
    'TESSNER': 0,
    'TESSO': 0,
    'TESSON': 0,
    'TEST': 0,
    'TESTA': 0,
    'TESTANI': 0,
    'TESTAVERDE': 0,
    'TESTER': 0,
    'TESTERMAN': 0,
    'TESTI': 0,
    'TESTIN': 0,
    'TESTINO': 0,
    'TESTMAN': 0,
    'TESTO': 0,
    'TESTOLIN': 0,
    'TESTON': 0,
    'TESTONE': 0,
    'TESTUT': 0,
    'TETA': 0,
    'TETEAK': 0,
    'TETEN': 0,
    'TETENS': 0,
    'TETER': 0,
    'TETERS': 0,
    'TETHER': 0,
    'TETI': 0,
    'TETLAK': 0,
    'TETLEY': 0,
    'TETLOW': 0,
    'TETMEYER': 0,
    'TETO': 0,
    'TETON': 0,
    'TETRAULT': 0,
    'TETREAU': 0,
    'TETREAULT': 0,
    'TETRICK': 0,
    'TETRO': 0,
    'TETT': 0,
    'TETTE': 0,
    'TETTEH': 0,
    'TETTEMER': 0,
    'TETTER': 0,
    'TETTERTON': 0,
    'TETTING': 0,
    'TETTLETON': 0,
    'TETU': 0,
    'TETUAN': 0,
    'TETZ': 0,
    'TETZLAFF': 0,
    'TETZLOFF': 0,
    'TETZNER': 0,
    'TEUBER': 0,
    'TEUBERT': 0,
    'TEUBNER': 0,
    'TEUFEL': 0,
    'TEUNE': 0,
    'TEUNIS': 0,
    'TEUNISSEN': 0,
    'TEUSCH': 0,
    'TEUSCHER': 0,
    'TEUSINK': 0,
    'TEUTEBERG': 0,
    'TEUTON': 0,
    'TEUTSCH': 0,
    'TEVAULT': 0,
    'TEVEBAUGH': 0,
    'TEVELDE': 0,
    'TEVEPAUGH': 0,
    'TEVERBAUGH': 0,
    'TEVES': 0,
    'TEVIS': 0,
    'TEVLIN': 0,
    'TEW': 0,
    'TEWALT': 0,
    'TEWARI': 0,
    'TEWELDE': 0,
    'TEWELL': 0,
    'TEWES': 0,
    'TEWEY': 0,
    'TEWKSBURY': 0,
    'TEWOLDE': 0,
    'TEWS': 0,
    'TEX': 0,
    'TEXADA': 0,
    'TEXAS': 0,
    'TEXEIRA': 0,
    'TEXIDOR': 0,
    'TEXIERA': 0,
    'TEXLEY': 0,
    'TEXTER': 0,
    'TEXTOR': 0,
    'TEY': 0,
    'TEYNOR': 0,
    'TEYSSIER': 0,
    'TEZAK': 0,
    'TEZENO': 0,
    'TH': 0,
    'THA': 0,
    'THABET': 0,
    'THABIT': 0,
    'THACH': 0,
    'THACHER': 0,
    'THACKER': 0,
    'THACKERAY': 0,
    'THACKERSON': 0,
    'THACKERY': 0,
    'THACKRAH': 0,
    'THACKRAY': 0,
    'THACKREY': 0,
    'THACKSTON': 0,
    'THAD': 1,
    'THADANI': 0,
    'THADDEUS': 1,
    'THADEN': 0,
    'THAEMERT': 0,
    'THAETE': 0,
    'THAGARD': 0,
    'THAGGARD': 0,
    'THAI': 0,
    'THAIN': 0,
    'THAIS': 0,
    'THAKAR': 0,
    'THAKE': 0,
    'THAKER': 0,
    'THAKKAR': 0,
    'THAKKER': 0,
    'THAKOR': 0,
    'THAKORE': 0,
    'THAKRAR': 0,
    'THAKUR': 0,
    'THAL': 0,
    'THALACKER': 0,
    'THALE': 0,
    'THALER': 0,
    'THALHAMMER': 0,
    'THALHEIMER': 0,
    'THALIA': 1,
    'THALKEN': 0,
    'THALL': 0,
    'THALLER': 0,
    'THALMAN': 0,
    'THALMANN': 0,
    'THAM': 0,
    'THAMAN': 0,
    'THAMANN': 0,
    'THAMERT': 0,
    'THAMES': 0,
    'THAMM': 0,
    'THAMMAVONG': 0,
    'THAMMAVONGSA': 0,
    'THAMS': 0,
    'THAN': 0,
    'THANDI': 0,
    'THANE': 0,
    'THANG': 0,
    'THANH': 0.9873060648801129,
    'THANKACHAN': 0,
    'THANNER': 0,
    'THANOS': 0,
    'THAO': 0.258732212160414,
    'THAPA': 0,
    'THAPAR': 0,
    'THAR': 0,
    'THARAKAN': 0,
    'THARALDSON': 0,
    'THARES': 0,
    'THARIN': 0,
    'THARNISH': 0,
    'THARP': 0,
    'THARPE': 0,
    'THARPS': 0,
    'THARRETT': 0,
    'THARRINGTON': 0,
    'THATCH': 0,
    'THATCHER': 0,
    'THATE': 0,
    'THATER': 0,
    'THAU': 0,
    'THAUER': 0,
    'THAUT': 0,
    'THAW': 0,
    'THAWLEY': 0,
    'THAXTER': 0,
    'THAXTON': 0,
    'THAY': 0,
    'THAYER': 0,
    'THAYN': 0,
    'THAYNE': 0,
    'THE': 0,
    'THEA': 1,
    'THEAD': 0,
    'THEADO': 0,
    'THEAGENE': 0,
    'THEAKER': 0,
    'THEAKSTON': 0,
    'THEAL': 0,
    'THEALL': 0,
    'THEARD': 0,
    'THEBARGE': 0,
    'THEBAUD': 0,
    'THEBEAU': 0,
    'THEBERGE': 0,
    'THEBO': 0,
    'THEDA': 1,
    'THEDE': 0,
    'THEDENS': 0,
    'THEDFORD': 0,
    'THEE': 0,
    'THEECK': 0,
    'THEEDE': 0,
    'THEEL': 0,
    'THEER': 0,
    'THEES': 0,
    'THEESFELD': 0,
    'THEETGE': 0,
    'THEIBERT': 0,
    'THEIGE': 0,
    'THEIL': 0,
    'THEILACKER': 0,
    'THEILE': 0,
    'THEILEN': 0,
    'THEILER': 0,
    'THEILIG': 0,
    'THEILING': 0,
    'THEILMAN': 0,
    'THEIMER': 0,
    'THEIN': 0,
    'THEIS': 0,
    'THEISEN': 0,
    'THEISING': 0,
    'THEISMANN': 0,
    'THEISS': 0,
    'THEISSEN': 0,
    'THELANDER': 0,
    'THELE': 0,
    'THELEMANN': 0,
    'THELEMAQUE': 0,
    'THELEN': 0,
    'THELIN': 0,
    'THELL': 0,
    'THELLMAN': 0,
    'THELMA': 1,
    'THELUSMA': 0,
    'THELWELL': 0,
    'THEM': 0,
    'THEMELIS': 0,
    'THEMER': 0,
    'THEMM': 0,
    'THEN': 0,
    'THENG': 0,
    'THENNES': 0,
    'THENO': 0,
    'THEO': 0.9900990099009901,
    'THEOBALD': 0,
    'THEOBOLD': 0,
    'THEODOR': 0,
    'THEODORA': 1,
    'THEODORAKIS': 0,
    'THEODORE': 0.9880311671620211,
    'THEODORIDIS': 0,
    'THEODOROPOULOS': 0,
    'THEODOROU': 0,
    'THEODOS': 0,
    'THEODOSIS': 0,
    'THEODOSOPOULOS': 0,
    'THEODULE': 0,
    'THEOHARIS': 0,
    'THEOLA': 1,
    'THEOPHILE': 0,
    'THEOPHILUS': 0,
    'THEORET': 0,
    'THEOS': 0,
    'THERESA': 0.9998155321896329,
    'THERESE': 1,
    'THERESIA': 1,
    'THERESSA': 1,
    'THERIAC': 0,
    'THERIAQUE': 0,
    'THERIAULT': 0,
    'THERIEN': 0,
    'THERING': 0,
    'THERIOT': 0,
    'THERKELSEN': 0,
    'THERKILDSEN': 0,
    'THERMAN': 0,
    'THERMIDOR': 0,
    'THERMITUS': 0,
    'THERMOS': 0,
    'THERN': 0,
    'THEROFF': 0,
    'THERON': 0.9950248756218906,
    'THEROS': 0,
    'THEROUX': 0,
    'THERRELL': 0,
    'THERRES': 0,
    'THERRIAN': 0,
    'THERRIAULT': 0,
    'THERRIEN': 0,
    'THERSA': 1,
    'THERVIL': 0,
    'THERY': 0,
    'THESENVITZ': 0,
    'THESIER': 0,
    'THESING': 0,
    'THESSEN': 0,
    'THET': 0,
    'THETFORD': 0,
    'THEUER': 0,
    'THEUERKAUF': 0,
    'THEUNE': 0,
    'THEUNISSEN': 0,
    'THEURER': 0,
    'THEURET': 0,
    'THEUS': 0,
    'THEUSCH': 0,
    'THEUT': 0,
    'THEVENIN': 0,
    'THEVENOT': 0,
    'THEVIS': 0,
    'THEW': 0,
    'THEWES': 0,
    'THEWLIS': 0,
    'THEWS': 0,
    'THEXTON': 0,
    'THEYE': 0,
    'THEYS': 0,
    'THI': 0.7751937984496124,
    'THIAGARAJAN': 0,
    'THIAM': 0,
    'THIARA': 0,
    'THIAS': 0,
    'THIBADEAU': 0,
    'THIBADO': 0,
    'THIBAUDEAU': 0,
    'THIBAULT': 0,
    'THIBAUT': 0,
    'THIBEAU': 0,
    'THIBEAULT': 0,
    'THIBEAUX': 0,
    'THIBEDEAU': 0,
    'THIBERT': 0,
    'THIBIDEAU': 0,
    'THIBO': 0,
    'THIBODAUX': 0,
    'THIBODEAU': 0,
    'THIBODEAUX': 0,
    'THIBODO': 0,
    'THIBOU': 0,
    'THIBOUTOT': 0,
    'THICH': 0,
    'THICK': 0,
    'THICKLIN': 0,
    'THIE': 0,
    'THIEBAUD': 0,
    'THIEBAUT': 0,
    'THIEDE': 0,
    'THIEKE': 0,
    'THIEKEN': 0,
    'THIEL': 0,
    'THIELBAR': 0,
    'THIELE': 0,
    'THIELEMAN': 0,
    'THIELEMANN': 0,
    'THIELEMIER': 0,
    'THIELEN': 0,
    'THIELER': 0,
    'THIELGES': 0,
    'THIELING': 0,
    'THIELKE': 0,
    'THIELKER': 0,
    'THIELKING': 0,
    'THIELMAN': 0,
    'THIELMANN': 0,
    'THIELS': 0,
    'THIELSEN': 0,
    'THIEM': 0,
    'THIEMAN': 0,
    'THIEMANN': 0,
    'THIEME': 0,
    'THIEMER': 0,
    'THIEN': 0,
    'THIENEMAN': 0,
    'THIENES': 0,
    'THIER': 0,
    'THIERBACH': 0,
    'THIERER': 0,
    'THIERET': 0,
    'THIERFELDER': 0,
    'THIERJUNG': 0,
    'THIERMAN': 0,
    'THIEROFF': 0,
    'THIEROLF': 0,
    'THIERRY': 0,
    'THIERS': 0,
    'THIERY': 0,
    'THIES': 0,
    'THIESCHAFER': 0,
    'THIESEN': 0,
    'THIESFELD': 0,
    'THIESING': 0,
    'THIESS': 0,
    'THIESSE': 0,
    'THIESSEN': 0,
    'THIEU': 0,
    'THIFFAULT': 0,
    'THIGPEN': 0,
    'THIGPIN': 0,
    'THILGES': 0,
    'THILL': 0,
    'THILLET': 0,
    'THILMAN': 0,
    'THILMANY': 0,
    'THILMONY': 0,
    'THILTGEN': 0,
    'THIM': 0,
    'THIMESCH': 0,
    'THIMM': 0,
    'THIMMES': 0,
    'THIMMESCH': 0,
    'THIMMIG': 0,
    'THIMONS': 0,
    'THIMSEN': 0,
    'THIND': 0,
    'THINER': 0,
    'THING': 0,
    'THINGELSTAD': 0,
    'THINGVOLD': 0,
    'THINN': 0,
    'THINNES': 0,
    'THIO': 0,
    'THIRION': 0,
    'THIRKIELD': 0,
    'THIRKILL': 0,
    'THIRSK': 0,
    'THIRTYACRE': 0,
    'THIRY': 0,
    'THISSELL': 0,
    'THISSEN': 0,
    'THISTIE': 0,
    'THISTLE': 0,
    'THISTLETHWAITE': 0,
    'THISTLEWOOD': 0,
    'THIVENER': 0,
    'THIVIERGE': 0,
    'THIXTON': 0,
    'THO': 0,
    'THOAMS': 0,
    'THOBE': 0,
    'THOBURN': 0,
    'THODE': 0,
    'THODEN': 0,
    'THODY': 0,
    'THOE': 0,
    'THOEL': 0,
    'THOELE': 0,
    'THOELKE': 0,
    'THOEMKE': 0,
    'THOEN': 0,
    'THOENE': 0,
    'THOENEN': 0,
    'THOENI': 0,
    'THOENNES': 0,
    'THOENSEN': 0,
    'THOENY': 0,
    'THOGERSEN': 0,
    'THOGMARTIN': 0,
    'THOI': 0,
    'THOITS': 0,
    'THOLE': 0,
    'THOLEN': 0,
    'THOLL': 0,
    'THOM': 0,
    'THOMA': 0,
    'THOMACK': 0,
    'THOMAE': 0,
    'THOMALLA': 0,
    'THOMAN': 0,
    'THOMANN': 0,
    'THOMAS': 0.8399890673874093,
    'THOMASEN': 0,
    'THOMASENA': 1,
    'THOMASIAN': 0,
    'THOMASINA': 1,
    'THOMASINE': 1,
    'THOMASMA': 0,
    'THOMASON': 0,
    'THOMASSEE': 0,
    'THOMASSEN': 0,
    'THOMASSIAN': 0,
    'THOMASSIE': 0,
    'THOMASSON': 0,
    'THOMASTON': 0,
    'THOMAZIN': 0,
    'THOMBS': 0,
    'THOME': 0,
    'THOMECZEK': 0,
    'THOMEN': 0,
    'THOMER': 0,
    'THOMERSON': 0,
    'THOMES': 0,
    'THOMETZ': 0,
    'THOMEY': 0,
    'THOMFORDE': 0,
    'THOMISEE': 0,
    'THOMISON': 0,
    'THOMKINS': 0,
    'THOMLEY': 0,
    'THOMLINSON': 0,
    'THOMLISON': 0,
    'THOMMA': 0,
    'THOMMEN': 0,
    'THOMMES': 0,
    'THOMOPOULOS': 0,
    'THOMOSON': 0,
    'THOMPKINS': 0,
    'THOMPSEN': 0,
    'THOMPSOM': 0,
    'THOMPSON': 0,
    'THOMS': 0,
    'THOMSEN': 0,
    'THOMSON': 0,
    'THOMSPON': 0,
    'THOMURE': 0,
    'THON': 0,
    'THONE': 0,
    'THONEN': 0,
    'THONG': 0,
    'THONGKHAM': 0,
    'THONGSAVANH': 0,
    'THONI': 0,
    'THONN': 0,
    'THONY': 0,
    'THOOFT': 0,
    'THOPSON': 0,
    'THOR': 0,
    'THORA': 1,
    'THORBAHN': 0,
    'THORBJORNSEN': 0,
    'THORBOURNE': 0,
    'THORBURN': 0,
    'THORDARSON': 0,
    'THORDSEN': 0,
    'THORE': 0,
    'THOREEN': 0,
    'THORELL': 0,
    'THOREN': 0,
    'THORESEN': 0,
    'THORESON': 0,
    'THORFINNSON': 0,
    'THORIN': 0,
    'THORINGTON': 0,
    'THORKELSON': 0,
    'THORKILDSEN': 0,
    'THORLAKSON': 0,
    'THORLEY': 0,
    'THORMAHLEN': 0,
    'THORMAN': 0,
    'THORMANN': 0,
    'THORN': 0,
    'THORNAL': 0,
    'THORNBER': 0,
    'THORNBERG': 0,
    'THORNBERRY': 0,
    'THORNBLAD': 0,
    'THORNBLOOM': 0,
    'THORNBROUGH': 0,
    'THORNBRUE': 0,
    'THORNBRUGH': 0,
    'THORNBURG': 0,
    'THORNBURGH': 0,
    'THORNBURY': 0,
    'THORNDIKE': 0,
    'THORNDYKE': 0,
    'THORNE': 0,
    'THORNELL': 0,
    'THORNER': 0,
    'THORNES': 0,
    'THORNG': 0,
    'THORNGATE': 0,
    'THORNGREN': 0,
    'THORNHILL': 0,
    'THORNING': 0,
    'THORNLEY': 0,
    'THORNOCK': 0,
    'THORNQUIST': 0,
    'THORNS': 0,
    'THORNSBERRY': 0,
    'THORNSBURG': 0,
    'THORNSBURY': 0,
    'THORNSLEY': 0,
    'THORNTON': 0,
    'THORNWELL': 0,
    'THOROGOOD': 0,
    'THOROMAN': 0,
    'THOROUGHGOOD': 0,
    'THOROUGHMAN': 0,
    'THORP': 0,
    'THORPE': 0,
    'THORSBY': 0,
    'THORSELL': 0,
    'THORSEN': 0,
    'THORSHEIM': 0,
    'THORSLAND': 0,
    'THORSNESS': 0,
    'THORSON': 0,
    'THORSTAD': 0,
    'THORSTED': 0,
    'THORSTEINSON': 0,
    'THORSTEN': 0,
    'THORSTENSEN': 0,
    'THORSTENSON': 0,
    'THORUD': 0,
    'THORUP': 0,
    'THORVILSON': 0,
    'THORWART': 0,
    'THOSS': 0,
    'THOSTENSON': 0,
    'THOTA': 0,
    'THOU': 0,
    'THOUIN': 0,
    'THOUNE': 0,
    'THOUSAND': 0,
    'THOUVENIN': 0,
    'THOW': 0,
    'THRAEN': 0,
    'THRAILKILL': 0,
    'THRALL': 0,
    'THRALLS': 0,
    'THRAMER': 0,
    'THRAMS': 0,
    'THRAN': 0,
    'THRANE': 0,
    'THRAPP': 0,
    'THRASH': 0,
    'THRASHER': 0,
    'THREADGILL': 0,
    'THREAT': 0,
    'THREATS': 0,
    'THREATT': 0,
    'THREATTE': 0,
    'THREATTS': 0,
    'THREET': 0,
    'THREETON': 0,
    'THREETS': 0,
    'THRELFALL': 0,
    'THRELKEL': 0,
    'THRELKELD': 0,
    'THREM': 0,
    'THREN': 0,
    'THRESA': 1,
    'THRESHER': 0,
    'THRESS': 0,
    'THRIFT': 0,
    'THRO': 0,
    'THROCKMORTON': 0,
    'THROENER': 0,
    'THROESCH': 0,
    'THROGMORTON': 0,
    'THROM': 0,
    'THRON': 0,
    'THRONDSON': 0,
    'THRONE': 0,
    'THRONEBERRY': 0,
    'THRONEBURG': 0,
    'THRONSON': 0,
    'THROOP': 0,
    'THROPE': 0,
    'THROPP': 0,
    'THROW': 0,
    'THROWER': 0,
    'THRUMAN': 0,
    'THRUN': 0,
    'THRUSH': 0,
    'THRUSTON': 0,
    'THU': 0.9478672985781991,
    'THUDIUM': 0,
    'THUE': 0,
    'THUENTE': 0,
    'THUESEN': 0,
    'THUESON': 0,
    'THUET': 0,
    'THUKRAL': 0,
    'THUL': 0,
    'THULIN': 0,
    'THULL': 0,
    'THULLEN': 0,
    'THUM': 0,
    'THUMA': 0,
    'THUMAN': 0,
    'THUMANN': 0,
    'THUMM': 0,
    'THUMMA': 0,
    'THUMMEL': 0,
    'THUMS': 0,
    'THUMSER': 0,
    'THUN': 0,
    'THUNBERG': 0,
    'THUNDER': 0,
    'THUNDERCLOUD': 0,
    'THUNDERHAWK': 0,
    'THUNE': 0,
    'THUNELL': 0,
    'THUNSTROM': 0,
    'THUOT': 0,
    'THUOTTE': 0,
    'THUR': 0,
    'THURAU': 0,
    'THURBER': 0,
    'THURBY': 0,
    'THURGOOD': 0,
    'THURIN': 0,
    'THURINGER': 0,
    'THURK': 0,
    'THURKETTLE': 0,
    'THURLBY': 0,
    'THURLEY': 0,
    'THURLKILL': 0,
    'THURLO': 0,
    'THURLOW': 0,
    'THURM': 0,
    'THURMAN': 0.5893909626719057,
    'THURMER': 0,
    'THURMES': 0,
    'THURMON': 0,
    'THURMOND': 0,
    'THURN': 0,
    'THURNAU': 0,
    'THURNER': 0,
    'THUROW': 0,
    'THURS': 0,
    'THURSBY': 0,
    'THURSTON': 0,
    'THURY': 0,
    'THUSS': 0,
    'THUSTON': 0,
    'THUT': 0,
    'THUY': 0.99009900990099,
    'THWAITES': 0,
    'THWAITS': 0,
    'THWEATT': 0,
    'THWING': 0,
    'THY': 0,
    'THYAGARAJAN': 0,
    'THYBERG': 0,
    'THYE': 0,
    'THYEN': 0,
    'THYER': 0,
    'THYFAULT': 0,
    'THYGERSON': 0,
    'THYGESEN': 0,
    'THYGESON': 0,
    'THYMES': 0,
    'THYNE': 0,
    'THYNG': 0,
    'THYRION': 0,
    'THYS': 0,
    'THYSELL': 0,
    'THYSSEN': 0,
    'TI': 0,
    'TIA': 0.9929078014184397,
    'TIAGO': 0,
    'TIAMZON': 0,
    'TIAN': 0,
    'TIANA': 1,
    'TIANGCO': 0,
    'TIANI': 0,
    'TIANNA': 1,
    'TIANO': 0,
    'TIAO': 0,
    'TIARA': 1,
    'TIARKS': 0,
    'TIBALDI': 0,
    'TIBAYAN': 0,
    'TIBBALS': 0,
    'TIBBE': 0,
    'TIBBELS': 0,
    'TIBBEN': 0,
    'TIBBENS': 0,
    'TIBBET': 0,
    'TIBBETS': 0,
    'TIBBETT': 0,
    'TIBBETTS': 0,
    'TIBBIT': 0,
    'TIBBITS': 0,
    'TIBBITT': 0,
    'TIBBITTS': 0,
    'TIBBLE': 0,
    'TIBBLES': 0,
    'TIBBOTT': 0,
    'TIBBS': 0,
    'TIBER': 0,
    'TIBERI': 0,
    'TIBERIA': 0,
    'TIBERIO': 0,
    'TIBERT': 0,
    'TIBKE': 0,
    'TIBLIER': 0,
    'TIBONI': 0,
    'TIBOR': 0,
    'TIBURCIO': 0,
    'TIBURZI': 0,
    'TIBUS': 0,
    'TICA': 0,
    'TICAS': 0,
    'TICE': 0,
    'TICEHURST': 0,
    'TICEN': 0,
    'TICER': 0,
    'TICEY': 0,
    'TICHACEK': 0,
    'TICHELAAR': 0,
    'TICHENOR': 0,
    'TICHINEL': 0,
    'TICHNELL': 0,
    'TICHNOR': 0,
    'TICHOTA': 0,
    'TICHY': 0,
    'TICK': 0,
    'TICKEL': 0,
    'TICKELL': 0,
    'TICKER': 0,
    'TICKLE': 0,
    'TICKLER': 0,
    'TICKLES': 0,
    'TICKNER': 0,
    'TICKNOR': 0,
    'TICZON': 0,
    'TIDABACK': 0,
    'TIDBALL': 0,
    'TIDD': 0,
    'TIDEMAN': 0,
    'TIDEMANN': 0,
    'TIDERMAN': 0,
    'TIDEY': 0,
    'TIDLER': 0,
    'TIDMAN': 0,
    'TIDMARSH': 0,
    'TIDMORE': 0,
    'TIDRICK': 0,
    'TIDROW': 0,
    'TIDSWELL': 0,
    'TIDWELL': 0,
    'TIDYMAN': 0,
    'TIE': 0,
    'TIEBEN': 0,
    'TIEBOUT': 0,
    'TIECHE': 0,
    'TIEDE': 0,
    'TIEDEKEN': 0,
    'TIEDEMAN': 0,
    'TIEDEMANN': 0,
    'TIEDGE': 0,
    'TIEDJE': 0,
    'TIEDMAN': 0,
    'TIEDT': 0,
    'TIEDTKE': 0,
    'TIEFEL': 0,
    'TIEFENAUER': 0,
    'TIEFENBACH': 0,
    'TIEFENTHALER': 0,
    'TIEGER': 0,
    'TIEGS': 0,
    'TIEHEN': 0,
    'TIEKEN': 0,
    'TIELENS': 0,
    'TIELKE': 0,
    'TIELKING': 0,
    'TIELL': 0,
    'TIEMAN': 0,
    'TIEMANN': 0,
    'TIEMEIER': 0,
    'TIEMENS': 0,
    'TIEMERSMA': 0,
    'TIEMEYER': 0,
    'TIEN': 0.5847953216374269,
    'TIENDA': 0,
    'TIENG': 0,
    'TIENHAARA': 0,
    'TIENKEN': 0,
    'TIENSVOLD': 0,
    'TIENTER': 0,
    'TIEPELMAN': 0,
    'TIER': 0,
    'TIERA': 1,
    'TIERCE': 0,
    'TIERI': 0,
    'TIERMAN': 0,
    'TIERNAN': 0,
    'TIERNEY': 0,
    'TIERNO': 0,
    'TIERRA': 0.9876543209876544,
    'TIERRABLANCA': 0,
    'TIERSON': 0,
    'TIES': 0,
    'TIESHA': 1,
    'TIESI': 0,
    'TIESLER': 0,
    'TIESMAN': 0,
    'TIESO': 0,
    'TIESSEN': 0,
    'TIESZEN': 0,
    'TIET': 0,
    'TIETGE': 0,
    'TIETGEN': 0,
    'TIETJE': 0,
    'TIETJEN': 0,
    'TIETJENS': 0,
    'TIETSORT': 0,
    'TIETZ': 0,
    'TIETZE': 0,
    'TIEU': 0,
    'TIEZZI': 0,
    'TIFANY': 1,
    'TIFF': 0,
    'TIFFANEY': 1,
    'TIFFANI': 1,
    'TIFFANIE': 1,
    'TIFFANY': 0.9909040093500685,
    'TIFFEE': 0,
    'TIFFER': 0,
    'TIFFIN': 0,
    'TIFFINY': 1,
    'TIFFNER': 0,
    'TIFFT': 0,
    'TIFT': 0,
    'TIGANI': 0,
    'TIGAR': 0,
    'TIGER': 0,
    'TIGERT': 0,
    'TIGGELAAR': 0,
    'TIGGES': 0,
    'TIGGETT': 0,
    'TIGGLE': 0,
    'TIGGS': 0,
    'TIGHE': 0,
    'TIGLAO': 0,
    'TIGNANELLI': 0,
    'TIGNER': 0,
    'TIGNEY': 0,
    'TIGNO': 0,
    'TIGNOR': 0,
    'TIGRE': 0,
    'TIGRETT': 0,
    'TIGUE': 0,
    'TIJERINA': 0,
    'TIJERINO': 0,
    'TIJERO': 0,
    'TIJUANA': 1,
    'TIKALSKY': 0,
    'TIKHONOV': 0,
    'TIKKA': 0,
    'TIKKANEN': 0,
    'TILAHUN': 0,
    'TILAK': 0,
    'TILANDER': 0,
    'TILBE': 0,
    'TILBERG': 0,
    'TILBURG': 0,
    'TILBURY': 0,
    'TILBY': 0,
    'TILDA': 1,
    'TILDEN': 0,
    'TILDON': 0,
    'TILELLI': 0,
    'TILESTON': 0,
    'TILEY': 0,
    'TILFORD': 0,
    'TILGER': 0,
    'TILGHMAN': 0,
    'TILGNER': 0,
    'TILIAKOS': 0,
    'TILK': 0,
    'TILKENS': 0,
    'TILL': 0,
    'TILLACK': 0,
    'TILLAGE': 0,
    'TILLAPAUGH': 0,
    'TILLAR': 0,
    'TILLBERG': 0,
    'TILLBERRY': 0,
    'TILLE': 0,
    'TILLEMA': 0,
    'TILLEMAN': 0,
    'TILLEMANS': 0,
    'TILLER': 0,
    'TILLERSON': 0,
    'TILLERY': 0,
    'TILLES': 0,
    'TILLET': 0,
    'TILLETT': 0,
    'TILLEY': 0,
    'TILLI': 0,
    'TILLIA': 0,
    'TILLIE': 0.9762900976290098,
    'TILLING': 0,
    'TILLINGER': 0,
    'TILLINGHAST': 0,
    'TILLIS': 0,
    'TILLISCH': 0,
    'TILLISON': 0,
    'TILLITSON': 0,
    'TILLITT': 0,
    'TILLMAN': 0,
    'TILLMANN': 0,
    'TILLMON': 0,
    'TILLO': 0,
    'TILLOTSON': 0,
    'TILLOU': 0,
    'TILLS': 0,
    'TILLSON': 0,
    'TILLY': 0,
    'TILMA': 0,
    'TILMAN': 0,
    'TILMANN': 0,
    'TILMON': 0,
    'TILNEY': 0,
    'TILOT': 0,
    'TILOTTA': 0,
    'TILSON': 0,
    'TILSTRA': 0,
    'TILT': 0,
    'TILTON': 0,
    'TILUS': 0,
    'TIM': 0.9974105687158339,
    'TIMA': 0,
    'TIMAN': 0,
    'TIMAR': 0,
    'TIMAS': 0,
    'TIMBER': 0,
    'TIMBERLAKE': 0,
    'TIMBERMAN': 0,
    'TIMBERS': 0,
    'TIMBES': 0,
    'TIMBLIN': 0,
    'TIMBO': 0,
    'TIMBOL': 0,
    'TIMBREZA': 0,
    'TIMBROOK': 0,
    'TIMBS': 0,
    'TIMBY': 0,
    'TIMCHAK': 0,
    'TIMEK': 0,
    'TIMER': 0,
    'TIMERMAN': 0,
    'TIMES': 0,
    'TIMIAN': 0,
    'TIMIKA': 1,
    'TIMINSKI': 0,
    'TIMKE': 0,
    'TIMKEN': 0,
    'TIMKO': 0,
    'TIMLER': 0,
    'TIMLICK': 0,
    'TIMLIN': 0,
    'TIMM': 0,
    'TIMME': 0,
    'TIMMEL': 0,
    'TIMMER': 0,
    'TIMMERBERG': 0,
    'TIMMERMAN': 0,
    'TIMMERMANN': 0,
    'TIMMERMANS': 0,
    'TIMMERMEYER': 0,
    'TIMMERS': 0,
    'TIMMES': 0,
    'TIMMINS': 0,
    'TIMMIS': 0,
    'TIMMONS': 0,
    'TIMMRECK': 0,
    'TIMMS': 0,
    'TIMMY': 1,
    'TIMNEY': 0,
    'TIMO': 0,
    'TIMOFEYEV': 0,
    'TIMON': 0,
    'TIMONEN': 0,
    'TIMONEY': 0,
    'TIMONY': 0,
    'TIMOTEO': 0,
    'TIMOTHEE': 0,
    'TIMOTHY': 0.9985979124474217,
    'TIMP': 0,
    'TIMPA': 0,
    'TIMPANARO': 0,
    'TIMPANI': 0,
    'TIMPANO': 0,
    'TIMPE': 0,
    'TIMPER': 0,
    'TIMPERIO': 0,
    'TIMPERLEY': 0,
    'TIMPONE': 0,
    'TIMPSON': 0,
    'TIMS': 0,
    'TIMSON': 0,
    'TIMURA': 0,
    'TIN': 0,
    'TINA': 0.9994094398764366,
    'TINAJERO': 0,
    'TINARI': 0,
    'TINBERG': 0,
    'TINCH': 0,
    'TINCHER': 0,
    'TINCKNELL': 0,
    'TINDAL': 0,
    'TINDALE': 0,
    'TINDALL': 0,
    'TINDEL': 0,
    'TINDELL': 0,
    'TINDER': 0,
    'TINDLE': 0,
    'TINDLEY': 0,
    'TINDOL': 0,
    'TINE': 0,
    'TINELLI': 0,
    'TINEO': 0,
    'TINER': 0,
    'TINERELLA': 0,
    'TINES': 0,
    'TINETTI': 0,
    'TING': 0,
    'TINGELSTAD': 0,
    'TINGEN': 0,
    'TINGER': 0,
    'TINGEY': 0,
    'TINGLE': 0,
    'TINGLER': 0,
    'TINGLEY': 0,
    'TINGLING': 0,
    'TINGSTAD': 0,
    'TINGSTROM': 0,
    'TINGUE': 0,
    'TINGWALD': 0,
    'TINI': 0,
    'TININ': 0,
    'TINIO': 0,
    'TINISHA': 1,
    'TINIUS': 0,
    'TINJUM': 0,
    'TINK': 0,
    'TINKEL': 0,
    'TINKER': 0,
    'TINKEY': 0,
    'TINKHAM': 0,
    'TINKLE': 0,
    'TINKLENBERG': 0,
    'TINKLEPAUGH': 0,
    'TINKLER': 0,
    'TINLEY': 0,
    'TINLIN': 0,
    'TINMAN': 0,
    'TINNEL': 0,
    'TINNELL': 0,
    'TINNEN': 0,
    'TINNER': 0,
    'TINNES': 0,
    'TINNEY': 0,
    'TINNIN': 0,
    'TINNIRELLO': 0,
    'TINNON': 0,
    'TINO': 0,
    'TINOCO': 0,
    'TINSLEY': 0,
    'TINSMAN': 0,
    'TINSON': 0,
    'TINSTMAN': 0,
    'TINT': 0,
    'TINTER': 0,
    'TINTERA': 0,
    'TINTI': 0,
    'TINTLE': 0,
    'TINTO': 0,
    'TINUCCI': 0,
    'TINY': 1,
    'TIO': 0,
    'TIONG': 0,
    'TIONGCO': 0,
    'TIONGSON': 0,
    'TIPA': 0,
    'TIPLADY': 0,
    'TIPLER': 0,
    'TIPP': 0,
    'TIPPEL': 0,
    'TIPPEN': 0,
    'TIPPENS': 0,
    'TIPPER': 0,
    'TIPPERY': 0,
    'TIPPET': 0,
    'TIPPETS': 0,
    'TIPPETT': 0,
    'TIPPETTS': 0,
    'TIPPEY': 0,
    'TIPPIE': 0,
    'TIPPIN': 0,
    'TIPPING': 0,
    'TIPPINS': 0,
    'TIPPIT': 0,
    'TIPPITT': 0,
    'TIPPLE': 0,
    'TIPPMANN': 0,
    'TIPPS': 0,
    'TIPPY': 0,
    'TIPS': 0,
    'TIPSORD': 0,
    'TIPSWORD': 0,
    'TIPTON': 0,
    'TIRA': 0,
    'TIRABASSI': 0,
    'TIRADO': 0,
    'TIRADOR': 0,
    'TIRCUIT': 0,
    'TIRELLA': 0,
    'TIRELLI': 0,
    'TIREY': 0,
    'TIRICO': 0,
    'TIRINO': 0,
    'TIRITILLI': 0,
    'TIRK': 0,
    'TIRMIZI': 0,
    'TIRO': 0,
    'TIRONA': 0,
    'TIRONE': 0,
    'TIRONI': 0,
    'TIROTTA': 0,
    'TIRPAK': 0,
    'TIRRE': 0,
    'TIRRELL': 0,
    'TIRRI': 0,
    'TIRRITO': 0,
    'TIRRO': 0,
    'TIRU': 0,
    'TIRY': 0,
    'TISA': 0.9345794392523364,
    'TISBY': 0,
    'TISCARENO': 0,
    'TISCH': 0,
    'TISCHENDORF': 0,
    'TISCHER': 0,
    'TISCHHAUSER': 0,
    'TISCHLER': 0,
    'TISCHNER': 0,
    'TISCIONE': 0,
    'TISCORNIA': 0,
    'TISDALE': 0,
    'TISDALL': 0,
    'TISDEL': 0,
    'TISDELL': 0,
    'TISE': 0,
    'TISEO': 0,
    'TISH': 0.8264462809917356,
    'TISHA': 1,
    'TISHCHENKO': 0,
    'TISHER': 0,
    'TISHLER': 0,
    'TISHMAN': 0,
    'TISI': 0,
    'TISINGER': 0,
    'TISKA': 0,
    'TISLER': 0,
    'TISLOW': 0,
    'TISNADO': 0,
    'TISO': 0,
    'TISON': 0,
    'TISONE': 0,
    'TISOR': 0,
    'TISS': 0,
    'TISSOT': 0,
    'TISSUE': 0,
    'TISTHAMMER': 0,
    'TISUE': 0,
    'TISZA': 0,
    'TITA': 0,
    'TITCH': 0,
    'TITCHENAL': 0,
    'TITCHENELL': 0,
    'TITCOMB': 0,
    'TITCOMBE': 0,
    'TITE': 0,
    'TITEL': 0,
    'TITENSOR': 0,
    'TITERA': 0,
    'TITH': 0,
    'TITHOF': 0,
    'TITLE': 0,
    'TITLER': 0,
    'TITLEY': 0,
    'TITLOW': 0,
    'TITMAN': 0,
    'TITMAS': 0,
    'TITMUS': 0,
    'TITO': 0,
    'TITOLO': 0,
    'TITONE': 0,
    'TITOV': 0,
    'TITSHAW': 0,
    'TITSWORTH': 0,
    'TITTEL': 0,
    'TITTER': 0,
    'TITTERINGTON': 0,
    'TITTERTON': 0,
    'TITTLE': 0,
    'TITTSWORTH': 0,
    'TITUS': 0.41322314049586784,
    'TITZE': 0,
    'TITZER': 0,
    'TIU': 0,
    'TIVEY': 0,
    'TIVIS': 0,
    'TIVNAN': 0,
    'TIWANA': 0,
    'TIWARI': 0,
    'TIX': 0,
    'TIXIER': 0,
    'TIZIANI': 0,
    'TIZIO': 0,
    'TIZNADO': 0,
    'TIZOL': 0,
    'TIZON': 0,
    'TIZZANO': 0,
    'TJADEN': 0,
    'TJADER': 0,
    'TJAN': 0,
    'TJANDRA': 0,
    'TJAPKES': 0,
    'TJARKS': 0,
    'TJEERDSMA': 0,
    'TJELMELAND': 0,
    'TJEPKEMA': 0,
    'TJEPKES': 0,
    'TJERNAGEL': 0,
    'TJIA': 0,
    'TJOA': 0,
    'TJOELKER': 0,
    'TJON': 0,
    'TJONG': 0,
    'TJOSSEM': 0,
    'TKAC': 0,
    'TKACH': 0,
    'TKACHENKO': 0,
    'TKACHEV': 0,
    'TKACHUK': 0,
    'TKACIK': 0,
    'TKACS': 0,
    'TKACZ': 0,
    'TKACZUK': 0,
    'TKACZYK': 0,
    'TKATCH': 0,
    'TLACHAC': 0,
    'TLAPA': 0,
    'TLAPANCO': 0,
    'TLASECA': 0,
    'TLATELPA': 0,
    'TLATENCHI': 0,
    'TLOUGAN': 0,
    'TLUSTY': 0,
    'TO': 0,
    'TOA': 0,
    'TOADVINE': 0,
    'TOAL': 0,
    'TOALA': 0,
    'TOALE': 0,
    'TOALSON': 0,
    'TOALSTON': 0,
    'TOAN': 0,
    'TOATLEY': 0,
    'TOAVS': 0,
    'TOAY': 0,
    'TOBA': 0,
    'TOBABEN': 0,
    'TOBACCO': 0,
    'TOBACK': 0,
    'TOBAK': 0,
    'TOBAL': 0,
    'TOBAR': 0,
    'TOBBE': 0,
    'TOBBEN': 0,
    'TOBE': 0,
    'TOBECK': 0,
    'TOBEL': 0,
    'TOBEN': 0,
    'TOBER': 0,
    'TOBERGTE': 0,
    'TOBERMAN': 0,
    'TOBERT': 0,
    'TOBERY': 0,
    'TOBEY': 0,
    'TOBI': 0.9615384615384616,
    'TOBIA': 0,
    'TOBIAN': 0,
    'TOBIAS': 0.5070993914807302,
    'TOBIASON': 0,
    'TOBIASSEN': 0,
    'TOBIASSON': 0,
    'TOBIASZ': 0,
    'TOBIE': 0.9090909090909091,
    'TOBIN': 0,
    'TOBIS': 0,
    'TOBITT': 0,
    'TOBKIN': 0,
    'TOBLER': 0,
    'TOBOLA': 0,
    'TOBOLSKI': 0,
    'TOBON': 0,
    'TOBORG': 0,
    'TOBUREN': 0,
    'TOBY': 0.9783071033602723,
    'TOC': 0,
    'TOCA': 0,
    'TOCCARA': 1,
    'TOCCHIO': 0,
    'TOCCI': 0,
    'TOCCO': 0,
    'TOCE': 0,
    'TOCH': 0,
    'TOCHE': 0,
    'TOCHER': 0,
    'TOCHIMANI': 0,
    'TOCHTERMAN': 0,
    'TOCHTROP': 0,
    'TOCI': 0,
    'TOCK': 0,
    'TOCKER': 0,
    'TOCKEY': 0,
    'TOCKSTEIN': 0,
    'TOCZEK': 0,
    'TOCZKO': 0,
    'TOCZYLOWSKI': 0,
    'TOCZYNSKI': 0,
    'TOD': 0.9803921568627452,
    'TODA': 0,
    'TODACHEENE': 0,
    'TODACHEENIE': 0,
    'TODARO': 0,
    'TODD': 0.8916610850636303,
    'TODDY': 0,
    'TODECHINE': 0,
    'TODER': 0,
    'TODERO': 0,
    'TODESCO': 0,
    'TODHUNTER': 0,
    'TODINO': 0,
    'TODISCO': 0,
    'TODMAN': 0,
    'TODOR': 0,
    'TODORA': 0,
    'TODOROFF': 0,
    'TODOROV': 0,
    'TODOROVIC': 0,
    'TODOROVICH': 0,
    'TODT': 0,
    'TODY': 0,
    'TOE': 0,
    'TOEBBE': 0,
    'TOEBBEN': 0,
    'TOEBE': 0,
    'TOEDT': 0,
    'TOEDTER': 0,
    'TOELKE': 0,
    'TOELLE': 0,
    'TOELLER': 0,
    'TOELLNER': 0,
    'TOENGES': 0,
    'TOENIES': 0,
    'TOENISKOETTER': 0,
    'TOENJES': 0,
    'TOENNIES': 0,
    'TOENNIS': 0,
    'TOENSING': 0,
    'TOEPEL': 0,
    'TOEPFER': 0,
    'TOEPKE': 0,
    'TOEPP': 0,
    'TOEPPE': 0,
    'TOEPPER': 0,
    'TOERING': 0,
    'TOERNER': 0,
    'TOEVS': 0,
    'TOEWS': 0,
    'TOFANELLI': 0,
    'TOFANI': 0,
    'TOFEL': 0,
    'TOFFEL': 0,
    'TOFFLEMIRE': 0,
    'TOFFOLI': 0,
    'TOFFOLO': 0,
    'TOFIL': 0,
    'TOFT': 0,
    'TOFTE': 0,
    'TOFTELAND': 0,
    'TOGAMI': 0,
    'TOGASHI': 0,
    'TOGBA': 0,
    'TOGHER': 0,
    'TOGIA': 0,
    'TOGLIA': 0,
    'TOGLIATTI': 0,
    'TOGNARELLI': 0,
    'TOGNAZZINI': 0,
    'TOGNERI': 0,
    'TOGNETTI': 0,
    'TOGNI': 0,
    'TOGNO': 0,
    'TOGNOLI': 0,
    'TOGO': 0,
    'TOGSTAD': 0,
    'TOGUCHI': 0,
    'TOH': 0,
    'TOHER': 0,
    'TOHILL': 0,
    'TOHM': 0,
    'TOHME': 0,
    'TOI': 1,
    'TOIA': 0,
    'TOICH': 0,
    'TOIGO': 0,
    'TOILOLO': 0,
    'TOIVONEN': 0,
    'TOJO': 0,
    'TOK': 0,
    'TOKACH': 0,
    'TOKAR': 0,
    'TOKARCIK': 0,
    'TOKARCZYK': 0,
    'TOKAREV': 0,
    'TOKARSKI': 0,
    'TOKARSKY': 0,
    'TOKARZ': 0,
    'TOKASH': 0,
    'TOKAY': 0,
    'TOKE': 0,
    'TOKER': 0,
    'TOKESHI': 0,
    'TOKHEIM': 0,
    'TOKHI': 0,
    'TOKI': 0,
    'TOKIE': 0,
    'TOKITA': 0,
    'TOKOS': 0,
    'TOKUDA': 0,
    'TOKUMOTO': 0,
    'TOKUNAGA': 0,
    'TOL': 0,
    'TOLA': 0,
    'TOLAN': 0,
    'TOLAND': 0,
    'TOLANI': 0,
    'TOLANO': 0,
    'TOLAR': 0,
    'TOLBERT': 0,
    'TOLBIRD': 0,
    'TOLCHIN': 0,
    'TOLCHINSKY': 0,
    'TOLDEN': 0,
    'TOLE': 0,
    'TOLEDANO': 0,
    'TOLEDO': 0,
    'TOLEFREE': 0,
    'TOLEMAN': 0,
    'TOLEN': 0,
    'TOLENO': 0,
    'TOLENTINO': 0,
    'TOLENTO': 0,
    'TOLER': 0,
    'TOLERICO': 0,
    'TOLES': 0,
    'TOLF': 0,
    'TOLFA': 0,
    'TOLFREE': 0,
    'TOLHURST': 0,
    'TOLI': 0,
    'TOLIA': 0,
    'TOLIFSON': 0,
    'TOLIN': 0,
    'TOLINO': 0,
    'TOLIS': 0,
    'TOLISANO': 0,
    'TOLISON': 0,
    'TOLIVER': 0,
    'TOLK': 0,
    'TOLKSDORF': 0,
    'TOLL': 0,
    'TOLLA': 0,
    'TOLLAKSON': 0,
    'TOLLAND': 0,
    'TOLLAR': 0,
    'TOLLARD': 0,
    'TOLLAS': 0,
    'TOLLE': 0,
    'TOLLEFSEN': 0,
    'TOLLEFSON': 0,
    'TOLLEFSRUD': 0,
    'TOLLEN': 0,
    'TOLLENAAR': 0,
    'TOLLER': 0,
    'TOLLERSON': 0,
    'TOLLERUD': 0,
    'TOLLES': 0,
    'TOLLESON': 0,
    'TOLLETT': 0,
    'TOLLETTE': 0,
    'TOLLEY': 0,
    'TOLLI': 0,
    'TOLLIN': 0,
    'TOLLINCHI': 0,
    'TOLLINGER': 0,
    'TOLLIS': 0,
    'TOLLISON': 0,
    'TOLLIVER': 0,
    'TOLLMAN': 0,
    'TOLLNER': 0,
    'TOLLY': 0,
    'TOLMACHOFF': 0,
    'TOLMAN': 0,
    'TOLMASOFF': 0,
    'TOLMICH': 0,
    'TOLMIE': 0,
    'TOLNAI': 0,
    'TOLNAY': 0,
    'TOLO': 0,
    'TOLOCZKO': 0,
    'TOLOMEI': 0,
    'TOLOMEO': 0,
    'TOLON': 0,
    'TOLONEN': 0,
    'TOLOSA': 0,
    'TOLOTTI': 0,
    'TOLOZA': 0,
    'TOLPA': 0,
    'TOLSDORF': 0,
    'TOLSMA': 0,
    'TOLSON': 0,
    'TOLSTON': 0,
    'TOLTON': 0,
    'TOLVE': 0,
    'TOLVER': 0,
    'TOLZMAN': 0,
    'TOLZMANN': 0,
    'TOM': 0.9703906444389151,
    'TOMA': 0,
    'TOMAC': 0,
    'TOMAH': 0,
    'TOMAINE': 0,
    'TOMAINO': 0,
    'TOMAK': 0,
    'TOMAKA': 0,
    'TOMAL': 0,
    'TOMALA': 0,
    'TOMAN': 0,
    'TOMANEK': 0,
    'TOMANELLI': 0,
    'TOMANIO': 0,
    'TOMANY': 0,
    'TOMAO': 0,
    'TOMAR': 0,
    'TOMARAS': 0,
    'TOMARCHIO': 0,
    'TOMARO': 0,
    'TOMAS': 0.9270455461507456,
    'TOMASA': 1,
    'TOMASCH': 0,
    'TOMASCO': 0,
    'TOMASEK': 0,
    'TOMASELLI': 0,
    'TOMASELLO': 0,
    'TOMASETTI': 0,
    'TOMASEVICH': 0,
    'TOMASHEK': 0,
    'TOMASI': 0,
    'TOMASIAN': 0,
    'TOMASIC': 0,
    'TOMASIELLO': 0,
    'TOMASIEWICZ': 0,
    'TOMASIK': 0,
    'TOMASINI': 0,
    'TOMASINO': 0,
    'TOMASKI': 0,
    'TOMASKO': 0,
    'TOMASKOVIC': 0,
    'TOMASO': 0,
    'TOMASON': 0,
    'TOMASOVIC': 0,
    'TOMASOVICH': 0,
    'TOMASSETTI': 0,
    'TOMASSI': 0,
    'TOMASSIAN': 0,
    'TOMASSINI': 0,
    'TOMASSO': 0,
    'TOMASSONI': 0,
    'TOMASULA': 0,
    'TOMASULO': 0,
    'TOMASZEK': 0,
    'TOMASZEWSKI': 0,
    'TOMAYKO': 0,
    'TOMAZ': 0,
    'TOMAZIC': 0,
    'TOMAZIN': 0,
    'TOMB': 0,
    'TOMBARI': 0,
    'TOMBAUGH': 0,
    'TOMBERG': 0,
    'TOMBERLIN': 0,
    'TOMBLESON': 0,
    'TOMBLIN': 0,
    'TOMBLINSON': 0,
    'TOMBOC': 0,
    'TOMBRELLO': 0,
    'TOMBS': 0,
    'TOMCHAK': 0,
    'TOMCHECK': 0,
    'TOMCHEK': 0,
    'TOMCHICK': 0,
    'TOMCHIK': 0,
    'TOMCHO': 0,
    'TOMCIK': 0,
    'TOMCO': 0,
    'TOMCZAK': 0,
    'TOMCZIK': 0,
    'TOMCZUK': 0,
    'TOMCZYK': 0,
    'TOME': 0,
    'TOMECEK': 0,
    'TOMECKO': 0,
    'TOMEI': 0,
    'TOMEK': 0,
    'TOMEKA': 1,
    'TOMENY': 0,
    'TOMEO': 0,
    'TOMER': 0,
    'TOMERA': 0,
    'TOMERLIN': 0,
    'TOMES': 0,
    'TOMETICH': 0,
    'TOMEY': 0,
    'TOMFORD': 0,
    'TOMHAVE': 0,
    'TOMI': 0.9615384615384616,
    'TOMIC': 0,
    'TOMICH': 0,
    'TOMICICH': 0,
    'TOMIKA': 1,
    'TOMIKO': 1,
    'TOMILSON': 0,
    'TOMINAGA': 0,
    'TOMINO': 0,
    'TOMITA': 0,
    'TOMIYAMA': 0,
    'TOMJACK': 0,
    'TOMKA': 0,
    'TOMKIEL': 0,
    'TOMKIEWICZ': 0,
    'TOMKIN': 0,
    'TOMKINS': 0,
    'TOMKINSON': 0,
    'TOMKO': 0,
    'TOMKOWIAK': 0,
    'TOMLIN': 0,
    'TOMLINS': 0,
    'TOMLINSON': 0,
    'TOMLISON': 0,
    'TOMM': 0,
    'TOMMARELLO': 0,
    'TOMMASI': 0,
    'TOMMASINI': 0,
    'TOMMASINO': 0,
    'TOMMASO': 0,
    'TOMME': 0,
    'TOMMER': 0,
    'TOMMERDAHL': 0,
    'TOMMEY': 0,
    'TOMMIE': 0.9975816203143894,
    'TOMMILA': 0,
    'TOMMY': 0.9993048314216197,
    'TOMMYE': 1,
    'TOMOKO': 1,
    'TOMOLONIS': 0,
    'TOMON': 0,
    'TOMOOKA': 0,
    'TOMORI': 0,
    'TOMORY': 0,
    'TOMPA': 0,
    'TOMPKIN': 0,
    'TOMPKINS': 0,
    'TOMPLAIT': 0,
    'TOMPOROWSKI': 0,
    'TOMPOS': 0,
    'TOMPSETT': 0,
    'TOMPSON': 0,
    'TOMS': 0,
    'TOMSA': 0,
    'TOMSEN': 0,
    'TOMSHA': 0,
    'TOMSHACK': 0,
    'TOMSHECK': 0,
    'TOMSIC': 0,
    'TOMSICH': 0,
    'TOMSICK': 0,
    'TOMSIK': 0,
    'TOMSKI': 0,
    'TOMSKY': 0,
    'TOMSON': 0,
    'TOMSOVIC': 0,
    'TON': 0,
    'TONA': 0.9090909090909091,
    'TONAK': 0,
    'TONARELLI': 0,
    'TONASKET': 0,
    'TONCHE': 0,
    'TONCRAY': 0,
    'TONDA': 0.9756097560975611,
    'TONDEE': 0,
    'TONDER': 0,
    'TONDI': 0,
    'TONDINI': 0,
    'TONDO': 0,
    'TONDRE': 0,
    'TONDREAU': 0,
    'TONE': 0,
    'TONELLI': 0,
    'TONELLO': 0,
    'TONER': 0,
    'TONES': 0,
    'TONETTE': 1,
    'TONETTI': 0,
    'TONEY': 0.3816793893129771,
    'TONG': 0,
    'TONGA': 0,
    'TONGATE': 0,
    'TONGCO': 0,
    'TONGE': 0,
    'TONGEN': 0,
    'TONGOL': 0,
    'TONGSON': 0,
    'TONGUE': 0,
    'TONI': 0.9982841990329122,
    'TONIA': 1,
    'TONIC': 0,
    'TONIE': 1,
    'TONINI': 0,
    'TONIOLO': 0,
    'TONISHA': 1,
    'TONITA': 1,
    'TONJA': 1,
    'TONJES': 0,
    'TONKEL': 0,
    'TONKERY': 0,
    'TONKIN': 0,
    'TONKINS': 0,
    'TONKINSON': 0,
    'TONKOVICH': 0,
    'TONKS': 0,
    'TONN': 0,
    'TONNA': 0,
    'TONNE': 0,
    'TONNEMACHER': 0,
    'TONNER': 0,
    'TONNESEN': 0,
    'TONNESON': 0,
    'TONNESSEN': 0,
    'TONNIES': 0,
    'TONNIGES': 0,
    'TONNING': 0,
    'TONNU': 0,
    'TONON': 0,
    'TONOYAN': 0,
    'TONOZZI': 0,
    'TONRY': 0,
    'TONSAGER': 0,
    'TONSFELDT': 0,
    'TONSING': 0,
    'TONSOR': 0,
    'TONTHAT': 0,
    'TONTI': 0,
    'TONUCCI': 0,
    'TONY': 0.9978910549868835,
    'TONYA': 1,
    'TONYAN': 0,
    'TOO': 0,
    'TOOD': 0,
    'TOODLE': 0,
    'TOOF': 0,
    'TOOGOOD': 0,
    'TOOHER': 0,
    'TOOHEY': 0,
    'TOOHILL': 0,
    'TOOKE': 0,
    'TOOKER': 0,
    'TOOKES': 0,
    'TOOKEY': 0,
    'TOOKS': 0,
    'TOOL': 0,
    'TOOLAN': 0,
    'TOOLE': 0,
    'TOOLEN': 0,
    'TOOLES': 0,
    'TOOLEY': 0,
    'TOOLIN': 0,
    'TOOLSIE': 0,
    'TOOLSON': 0,
    'TOOM': 0,
    'TOOMA': 0,
    'TOOMALATAI': 0,
    'TOOMAN': 0,
    'TOOMBS': 0,
    'TOOMER': 0,
    'TOOMES': 0,
    'TOOMEY': 0,
    'TOOMIRE': 0,
    'TOON': 0,
    'TOONE': 0,
    'TOONEN': 0,
    'TOOP': 0,
    'TOOPS': 0,
    'TOOR': 0,
    'TOOSON': 0,
    'TOOT': 0,
    'TOOTELL': 0,
    'TOOTH': 0,
    'TOOTHAKER': 0,
    'TOOTHMAN': 0,
    'TOOTLE': 0,
    'TOOVEY': 0,
    'TOOZE': 0,
    'TOP': 0,
    'TOPA': 0,
    'TOPACIO': 0,
    'TOPAL': 0,
    'TOPALIAN': 0,
    'TOPALOVIC': 0,
    'TOPASNA': 0,
    'TOPAZ': 0,
    'TOPCZEWSKI': 0,
    'TOPE': 0,
    'TOPEL': 0,
    'TOPER': 0,
    'TOPETE': 0,
    'TOPF': 0,
    'TOPHAM': 0,
    'TOPIC': 0,
    'TOPINKA': 0,
    'TOPIWALA': 0,
    'TOPJIAN': 0,
    'TOPKA': 0,
    'TOPLE': 0,
    'TOPLEY': 0,
    'TOPLIFF': 0,
    'TOPLIN': 0,
    'TOPMILLER': 0,
    'TOPOL': 0,
    'TOPOLESKI': 0,
    'TOPOLEWSKI': 0,
    'TOPOLINSKI': 0,
    'TOPOLOSKY': 0,
    'TOPOLSKI': 0,
    'TOPOR': 0,
    'TOPOREK': 0,
    'TOPOROWSKI': 0,
    'TOPP': 0,
    'TOPPA': 0,
    'TOPPE': 0,
    'TOPPEL': 0,
    'TOPPEN': 0,
    'TOPPER': 0,
    'TOPPI': 0,
    'TOPPIN': 0,
    'TOPPING': 0,
    'TOPPINGS': 0,
    'TOPPINS': 0,
    'TOPPS': 0,
    'TOQUINTO': 0,
    'TOR': 0,
    'TORA': 1,
    'TORABI': 0,
    'TORAIN': 0,
    'TORAL': 0,
    'TORALBA': 0,
    'TORALES': 0,
    'TORAN': 0,
    'TORANO': 0,
    'TORANZO': 0,
    'TORBA': 0,
    'TORBATI': 0,
    'TORBECK': 0,
    'TORBENSON': 0,
    'TORBERT': 0,
    'TORBET': 0,
    'TORBETT': 0,
    'TORBIK': 0,
    'TORBIT': 0,
    'TORBITT': 0,
    'TORBORG': 0,
    'TORBUSH': 0,
    'TORCASIO': 0,
    'TORCASO': 0,
    'TORCH': 0,
    'TORCHIA': 0,
    'TORCHIO': 0,
    'TORCHON': 0,
    'TORCIVIA': 0,
    'TORCZON': 0,
    'TORDA': 0,
    'TORDOFF': 0,
    'TORDSEN': 0,
    'TORELL': 0,
    'TORELLA': 0,
    'TORELLI': 0,
    'TORELLO': 0,
    'TOREN': 0,
    'TOREY': 0,
    'TORFIN': 0,
    'TORGERSEN': 0,
    'TORGERSON': 0,
    'TORGESEN': 0,
    'TORGESON': 0,
    'TORGLER': 0,
    'TORGRIMSON': 0,
    'TORGUSON': 0,
    'TORHAN': 0,
    'TORI': 0.9876543209876544,
    'TORIAN': 0,
    'TORIBIO': 0,
    'TORIE': 1,
    'TORIELLO': 0,
    'TORIGIAN': 0,
    'TORIGOE': 0,
    'TORII': 0,
    'TORINA': 0,
    'TORINO': 0,
    'TORIO': 0,
    'TORIS': 0,
    'TORIVIO': 0,
    'TORIX': 0,
    'TORIZ': 0,
    'TORK': 0,
    'TORKE': 0,
    'TORKELSON': 0,
    'TORKILDSON': 0,
    'TORLEY': 0,
    'TORLINE': 0,
    'TORLONE': 0,
    'TORMA': 0,
    'TORMALA': 0,
    'TORMAN': 0,
    'TORMANEN': 0,
    'TORMEY': 0,
    'TORMOEHLEN': 0,
    'TORMOS': 0,
    'TORN': 0,
    'TORNA': 0,
    'TORNABENE': 0,
    'TORNAMBE': 0,
    'TORNATORE': 0,
    'TORNBERG': 0,
    'TORNBLOM': 0,
    'TORNELL': 0,
    'TORNELLO': 0,
    'TORNER': 0,
    'TORNERO': 0,
    'TORNES': 0,
    'TORNETTA': 0,
    'TORNEY': 0,
    'TORNEZ': 0,
    'TORNGA': 0,
    'TORNGREN': 0,
    'TORNO': 0,
    'TORNOW': 0,
    'TORNQUIST': 0,
    'TORO': 0,
    'TORODE': 0,
    'TOROK': 0,
    'TOROLA': 0,
    'TORONTO': 0,
    'TOROSIAN': 0,
    'TOROSSIAN': 0,
    'TOROSYAN': 0,
    'TORP': 0,
    'TORPEY': 0,
    'TORPHY': 0,
    'TORPY': 0,
    'TORQUATO': 0,
    'TORR': 0,
    'TORRA': 0,
    'TORRACA': 0,
    'TORRACO': 0,
    'TORRADO': 0,
    'TORRALBA': 0,
    'TORRALVA': 0,
    'TORRANCE': 0,
    'TORRANO': 0,
    'TORRANS': 0,
    'TORRAS': 0,
    'TORRE': 0,
    'TORREALBA': 0,
    'TORREANO': 0,
    'TORREBLANCA': 0,
    'TORRECILLAS': 0,
    'TORREGANO': 0,
    'TORREGROSA': 0,
    'TORREGROSSA': 0,
    'TORREJON': 0,
    'TORRELL': 0,
    'TORRELLA': 0,
    'TORRELLAS': 0,
    'TORRELLI': 0,
    'TORRENCE': 0,
    'TORRENS': 0,
    'TORRENT': 0,
    'TORRENTE': 0,
    'TORRENTO': 0,
    'TORRERO': 0,
    'TORRES': 0,
    'TORRESCANO': 0,
    'TORRESGARCIA': 0,
    'TORRESHERNANDE': 0,
    'TORRESLOPEZ': 0,
    'TORRESMARTINEZ': 0,
    'TORRESPEREZ': 0,
    'TORRESRIVERA': 0,
    'TORRESRODRIGUE': 0,
    'TORRESTORRES': 0,
    'TORRETTA': 0,
    'TORRETTI': 0,
    'TORREY': 0,
    'TORREYSON': 0,
    'TORREZ': 0,
    'TORRI': 0.8771929824561403,
    'TORRICE': 0,
    'TORRICELLI': 0,
    'TORRICER': 0,
    'TORRICO': 0,
    'TORRIE': 0.9174311926605505,
    'TORRIENTE': 0,
    'TORRIERI': 0,
    'TORRIES': 0,
    'TORRIJOS': 0,
    'TORRILLO': 0,
    'TORRINGTON': 0,
    'TORRIS': 0,
    'TORRISI': 0,
    'TORRISON': 0,
    'TORRO': 0,
    'TORRONE': 0,
    'TORRUELLA': 0,
    'TORRUELLAS': 0,
    'TORRY': 0,
    'TORSCH': 0,
    'TORSELL': 0,
    'TORSETH': 0,
    'TORSIELLO': 0,
    'TORSKE': 0,
    'TORSON': 0,
    'TORSTENSON': 0,
    'TORT': 0,
    'TORTI': 0,
    'TORTO': 0,
    'TORTOLA': 0,
    'TORTOLANI': 0,
    'TORTOLANO': 0,
    'TORTOLEDO': 0,
    'TORTOMASI': 0,
    'TORTORA': 0,
    'TORTORELLA': 0,
    'TORTORELLI': 0,
    'TORTORELLO': 0,
    'TORTORICE': 0,
    'TORTORICH': 0,
    'TORTORICI': 0,
    'TORTORIELLO': 0,
    'TORUNO': 0,
    'TORVIK': 0,
    'TORVINEN': 0,
    'TORY': 0.9740259740259739,
    'TORZEWSKI': 0,
    'TOSA': 0,
    'TOSADO': 0,
    'TOSCA': 0,
    'TOSCANI': 0,
    'TOSCANO': 0,
    'TOSCH': 0,
    'TOSCHES': 0,
    'TOSCHI': 0,
    'TOSCHLOG': 0,
    'TOSCO': 0,
    'TOSE': 0,
    'TOSH': 0,
    'TOSHA': 1,
    'TOSHIA': 1,
    'TOSHIKO': 1,
    'TOSI': 0,
    'TOSIC': 0,
    'TOSKA': 0,
    'TOSO': 0,
    'TOSON': 0,
    'TOSSEY': 0,
    'TOST': 0,
    'TOSTA': 0,
    'TOSTADO': 0,
    'TOSTANOSKI': 0,
    'TOSTE': 0,
    'TOSTEN': 0,
    'TOSTENSON': 0,
    'TOSTI': 0,
    'TOSTO': 0,
    'TOSTON': 0,
    'TOTA': 0,
    'TOTAH': 0,
    'TOTARO': 0,
    'TOTE': 0,
    'TOTEN': 0,
    'TOTH': 0,
    'TOTHEROW': 0,
    'TOTI': 0,
    'TOTILLO': 0,
    'TOTIN': 0,
    'TOTINO': 0,
    'TOTLAND': 0,
    'TOTMAN': 0,
    'TOTO': 0,
    'TOTON': 0,
    'TOTORA': 0,
    'TOTORO': 0,
    'TOTSCH': 0,
    'TOTSKY': 0,
    'TOTT': 0,
    'TOTTA': 0,
    'TOTTE': 0,
    'TOTTEN': 0,
    'TOTTENHAM': 0,
    'TOTTER': 0,
    'TOTTINGHAM': 0,
    'TOTTLE': 0,
    'TOTTON': 0,
    'TOTTRESS': 0,
    'TOTTY': 0,
    'TOTZ': 0,
    'TOTZKE': 0,
    'TOU': 0,
    'TOUART': 0,
    'TOUB': 0,
    'TOUCH': 0,
    'TOUCHARD': 0,
    'TOUCHBERRY': 0,
    'TOUCHE': 0,
    'TOUCHET': 0,
    'TOUCHETTE': 0,
    'TOUCHSTONE': 0,
    'TOUCHTON': 0,
    'TOUEY': 0,
    'TOUGAS': 0,
    'TOUGAW': 0,
    'TOUGH': 0,
    'TOUHEY': 0,
    'TOUHY': 0,
    'TOULON': 0,
    'TOULOUSE': 0,
    'TOULSON': 0,
    'TOUMA': 0,
    'TOUMEY': 0,
    'TOUN': 0,
    'TOUNG': 0,
    'TOUNGATE': 0,
    'TOUNTAS': 0,
    'TOUNZEN': 0,
    'TOUPAL': 0,
    'TOUPIN': 0,
    'TOUPS': 0,
    'TOUR': 0,
    'TOURANGEAU': 0,
    'TOURAY': 0,
    'TOURDOT': 0,
    'TOURE': 0,
    'TOUREK': 0,
    'TOURGEE': 0,
    'TOURIGNY': 0,
    'TOURJEE': 0,
    'TOURNAS': 0,
    'TOURNAY': 0,
    'TOURNEAR': 0,
    'TOURNEY': 0,
    'TOURNIER': 0,
    'TOURTELLOT': 0,
    'TOURTELLOTTE': 0,
    'TOURTELOTTE': 0,
    'TOURTILLOTT': 0,
    'TOURVILLE': 0,
    'TOUS': 0,
    'TOUSANT': 0,
    'TOUSEY': 0,
    'TOUSIGNANT': 0,
    'TOUSLEY': 0,
    'TOUSSAINT': 0,
    'TOUSSANT': 0,
    'TOUT': 0,
    'TOUTANT': 0,
    'TOUTGES': 0,
    'TOUVELL': 0,
    'TOUW': 0,
    'TOVA': 1,
    'TOVAL': 0,
    'TOVALIN': 0,
    'TOVANI': 0,
    'TOVAR': 0,
    'TOVER': 0,
    'TOVES': 0,
    'TOVEY': 0,
    'TOVIAS': 0,
    'TOVMASYAN': 0,
    'TOVO': 0,
    'TOVREA': 0,
    'TOVSEN': 0,
    'TOW': 0,
    'TOWANDA': 1,
    'TOWARD': 0,
    'TOWBIN': 0,
    'TOWE': 0,
    'TOWELL': 0,
    'TOWER': 0,
    'TOWERS': 0,
    'TOWERY': 0,
    'TOWEY': 0,
    'TOWLE': 0,
    'TOWLER': 0,
    'TOWLES': 0,
    'TOWN': 0,
    'TOWNDROW': 0,
    'TOWNE': 0,
    'TOWNEND': 0,
    'TOWNER': 0,
    'TOWNES': 0,
    'TOWNLEY': 0,
    'TOWNS': 0,
    'TOWNSAND': 0,
    'TOWNSEL': 0,
    'TOWNSELL': 0,
    'TOWNSEN': 0,
    'TOWNSEND': 0,
    'TOWNSHEND': 0,
    'TOWNSLEY': 0,
    'TOWNSON': 0,
    'TOWNZEN': 0,
    'TOWRY': 0,
    'TOWSE': 0,
    'TOWSEND': 0,
    'TOWSEY': 0,
    'TOWSLEE': 0,
    'TOWSLEY': 0,
    'TOWSON': 0,
    'TOXEY': 0,
    'TOXQUI': 0,
    'TOY': 0,
    'TOYA': 0.9592326139088729,
    'TOYAMA': 0,
    'TOYE': 0,
    'TOYER': 0,
    'TOYLOY': 0,
    'TOYNE': 0,
    'TOYODA': 0,
    'TOYOFUKU': 0,
    'TOYOOKA': 0,
    'TOYOS': 0,
    'TOYOSHIMA': 0,
    'TOYOTA': 0,
    'TOZER': 0,
    'TOZIER': 0,
    'TOZZI': 0,
    'TOZZO': 0,
    'TRA': 0,
    'TRAAS': 0,
    'TRABAL': 0,
    'TRABAND': 0,
    'TRABANINO': 0,
    'TRABER': 0,
    'TRABERT': 0,
    'TRABING': 0,
    'TRABOLD': 0,
    'TRABOSH': 0,
    'TRABUCCO': 0,
    'TRABUE': 0,
    'TRABULSI': 0,
    'TRAC': 0,
    'TRACE': 0,
    'TRACEE': 1,
    'TRACER': 0,
    'TRACEWELL': 0,
    'TRACEY': 0.9622689288427451,
    'TRACH': 0,
    'TRACHSEL': 0,
    'TRACHT': 0,
    'TRACHTA': 0,
    'TRACHTE': 0,
    'TRACHTENBERG': 0,
    'TRACHTMAN': 0,
    'TRACHY': 0,
    'TRACI': 1,
    'TRACIE': 1,
    'TRACK': 0,
    'TRACKWELL': 0,
    'TRACY': 0.9575174893500606,
    'TRACZ': 0,
    'TRACZYK': 0,
    'TRAD': 0,
    'TRADER': 0,
    'TRADEWELL': 0,
    'TRADRE': 0,
    'TRAEGER': 0,
    'TRAENKNER': 0,
    'TRAFELET': 0,
    'TRAFF': 0,
    'TRAFFANSTEDT': 0,
    'TRAFFAS': 0,
    'TRAFFIE': 0,
    'TRAFFORD': 0,
    'TRAFICANTE': 0,
    'TRAFICANTI': 0,
    'TRAFT': 0,
    'TRAFTON': 0,
    'TRAGER': 0,
    'TRAGESER': 0,
    'TRAGESSER': 0,
    'TRAGLIA': 0,
    'TRAGO': 0,
    'TRAHAN': 0,
    'TRAHANT': 0,
    'TRAHERN': 0,
    'TRAHEY': 0,
    'TRAHIN': 0,
    'TRAICOFF': 0,
    'TRAIGLE': 0,
    'TRAIL': 0,
    'TRAILER': 0,
    'TRAILL': 0,
    'TRAILOR': 0,
    'TRAIN': 0,
    'TRAINA': 0,
    'TRAINER': 0,
    'TRAINHAM': 0,
    'TRAINI': 0,
    'TRAINO': 0,
    'TRAINOR': 0,
    'TRAINUM': 0,
    'TRAISTER': 0,
    'TRAJANO': 0,
    'TRAJKOVSKI': 0,
    'TRAKAS': 0,
    'TRAKHTENBERG': 0,
    'TRALA': 0,
    'TRALONGO': 0,
    'TRAM': 0,
    'TRAMA': 0,
    'TRAMBLE': 0,
    'TRAMBLEY': 0,
    'TRAME': 0,
    'TRAMEL': 0,
    'TRAMELL': 0,
    'TRAMILL': 0,
    'TRAMM': 0,
    'TRAMMEL': 0,
    'TRAMMELL': 0,
    'TRAMMER': 0,
    'TRAMONT': 0,
    'TRAMONTANA': 0,
    'TRAMONTANO': 0,
    'TRAMONTE': 0,
    'TRAMONTIN': 0,
    'TRAMONTOZZI': 0,
    'TRAMP': 0,
    'TRAMPE': 0,
    'TRAMPEL': 0,
    'TRAMPOSCH': 0,
    'TRAMUTA': 0,
    'TRAMUTOLA': 0,
    'TRAMUTOLO': 0,
    'TRAN': 0.01943634596695821,
    'TRANA': 0,
    'TRANBARGER': 0,
    'TRANBERG': 0,
    'TRANBY': 0,
    'TRANCHIDA': 0,
    'TRANCHINA': 0,
    'TRANCHITA': 0,
    'TRANCOSA': 0,
    'TRANCOSO': 0,
    'TRANDEM': 0,
    'TRANE': 0,
    'TRANEL': 0,
    'TRANER': 0,
    'TRANFAGLIA': 0,
    'TRANG': 0.7407407407407407,
    'TRANGHESE': 0,
    'TRANGSRUD': 0,
    'TRANI': 0,
    'TRANIELLO': 0,
    'TRANK': 0,
    'TRANKINA': 0,
    'TRANKLE': 0,
    'TRANMER': 0,
    'TRANNGUYEN': 0,
    'TRANOVICH': 0,
    'TRANQUILINO': 0,
    'TRANQUILLI': 0,
    'TRANQUILLO': 0,
    'TRANSFIGURACION': 0,
    'TRANSON': 0,
    'TRANSOU': 0,
    'TRANSTRUM': 0,
    'TRANSUE': 0,
    'TRANT': 0,
    'TRANTER': 0,
    'TRANTHAM': 0,
    'TRANTHI': 0,
    'TRANTINA': 0,
    'TRANTOW': 0,
    'TRANUM': 0,
    'TRANVAN': 0,
    'TRAORE': 0,
    'TRAPANE': 0,
    'TRAPANESE': 0,
    'TRAPANI': 0,
    'TRAPASSO': 0,
    'TRAPHAGAN': 0,
    'TRAPHAGEN': 0,
    'TRAPNELL': 0,
    'TRAPP': 0,
    'TRAPPE': 0,
    'TRAPPEN': 0,
    'TRAPPER': 0,
    'TRAPPIER': 0,
    'TRAPPS': 0,
    'TRAPUZZANO': 0,
    'TRASATTI': 0,
    'TRASK': 0,
    'TRASKA': 0,
    'TRASKOS': 0,
    'TRASLAVINA': 0,
    'TRASS': 0,
    'TRASTER': 0,
    'TRASVINA': 0,
    'TRATE': 0,
    'TRATHEN': 0,
    'TRATT': 0,
    'TRATTLES': 0,
    'TRATTNER': 0,
    'TRAU': 0,
    'TRAUB': 0,
    'TRAUBE': 0,
    'TRAUD': 0,
    'TRAUDT': 0,
    'TRAUERNICHT': 0,
    'TRAUFLER': 0,
    'TRAUGER': 0,
    'TRAUGH': 0,
    'TRAUGHBER': 0,
    'TRAUGOTT': 0,
    'TRAULSEN': 0,
    'TRAUM': 0,
    'TRAUN': 0,
    'TRAUNER': 0,
    'TRAUPMAN': 0,
    'TRAURIG': 0,
    'TRAUSCH': 0,
    'TRAUSCHT': 0,
    'TRAUT': 0,
    'TRAUTH': 0,
    'TRAUTHWEIN': 0,
    'TRAUTMAN': 0,
    'TRAUTMANN': 0,
    'TRAUTNER': 0,
    'TRAUTSCH': 0,
    'TRAUTVETTER': 0,
    'TRAUTWEIN': 0,
    'TRAUTZ': 0,
    'TRAVAGLINI': 0,
    'TRAVAGLIO': 0,
    'TRAVAGLIONE': 0,
    'TRAVAILLE': 0,
    'TRAVALINE': 0,
    'TRAVASSOS': 0,
    'TRAVELBEE': 0,
    'TRAVELSTEAD': 0,
    'TRAVEN': 0,
    'TRAVER': 0,
    'TRAVERS': 0,
    'TRAVERSA': 0,
    'TRAVERSE': 0,
    'TRAVERSI': 0,
    'TRAVERSIE': 0,
    'TRAVERSO': 0,
    'TRAVES': 0,
    'TRAVIA': 0,
    'TRAVICK': 0,
    'TRAVIESO': 0,
    'TRAVILLIAN': 0,
    'TRAVILLION': 0,
    'TRAVINO': 0,
    'TRAVIOLI': 0,
    'TRAVIS': 0.9310883140053524,
    'TRAVISANO': 0,
    'TRAVISS': 0,
    'TRAVITZ': 0,
    'TRAVLOS': 0,
    'TRAVNICEK': 0,
    'TRAW': 0,
    'TRAWEEK': 0,
    'TRAWICK': 0,
    'TRAWICKI': 0,
    'TRAWINSKI': 0,
    'TRAX': 0,
    'TRAXEL': 0,
    'TRAXINGER': 0,
    'TRAXLER': 0,
    'TRAY': 0,
    'TRAYAH': 0,
    'TRAYER': 0,
    'TRAYERS': 0,
    'TRAYES': 0,
    'TRAYLER': 0,
    'TRAYLOR': 0,
    'TRAYNER': 0,
    'TRAYNHAM': 0,
    'TRAYNOR': 0,
    'TRAYNUM': 0,
    'TRAYWICK': 0,
    'TRBOVICH': 0,
    'TRCKA': 0,
    'TREACE': 0,
    'TREACY': 0,
    'TREADAWAY': 0,
    'TREADO': 0,
    'TREADWAY': 0,
    'TREADWELL': 0,
    'TREAKLE': 0,
    'TREANOR': 0,
    'TREAS': 0,
    'TREASA': 1,
    'TREASE': 0,
    'TREASH': 0,
    'TREASTER': 0,
    'TREASURE': 0,
    'TREAT': 0,
    'TREBBE': 0,
    'TREBELHORN': 0,
    'TREBER': 0,
    'TREBES': 0,
    'TREBESCH': 0,
    'TREBIL': 0,
    'TREBILCOCK': 0,
    'TREBING': 0,
    'TREBINO': 0,
    'TREBLE': 0,
    'TREBON': 0,
    'TREBUS': 0,
    'TRECARTIN': 0,
    'TRECEK': 0,
    'TRECKER': 0,
    'TRECO': 0,
    'TREDE': 0,
    'TREDER': 0,
    'TREDINNICK': 0,
    'TREDO': 0,
    'TREDWAY': 0,
    'TREDWELL': 0,
    'TREE': 0,
    'TREECE': 0,
    'TREEN': 0,
    'TREENA': 1,
    'TREES': 0,
    'TREESE': 0,
    'TREESH': 0,
    'TREFETHEN': 0,
    'TREFF': 0,
    'TREFFERT': 0,
    'TREFFINGER': 0,
    'TREFNY': 0,
    'TREFREN': 0,
    'TREFRY': 0,
    'TREFT': 0,
    'TREFTS': 0,
    'TREFTZ': 0,
    'TREFZ': 0,
    'TREFZGER': 0,
    'TREGASKIS': 0,
    'TREGELLAS': 0,
    'TREGEMBO': 0,
    'TREGER': 0,
    'TREGLE': 0,
    'TREGLIA': 0,
    'TREGLOWN': 0,
    'TREGO': 0,
    'TREGONING': 0,
    'TREGRE': 0,
    'TREGUBOFF': 0,
    'TREHAN': 0,
    'TREHARN': 0,
    'TREHARNE': 0,
    'TREHERN': 0,
    'TREHERNE': 0,
    'TREHY': 0,
    'TREI': 0,
    'TREIB': 0,
    'TREIBER': 0,
    'TREIBLE': 0,
    'TREICHEL': 0,
    'TREICHLER': 0,
    'TREIDER': 0,
    'TREIER': 0,
    'TREINEN': 0,
    'TREIS': 0,
    'TREISCH': 0,
    'TREJO': 0,
    'TREJOS': 0,
    'TREKELL': 0,
    'TRELA': 0,
    'TRELEASE': 0,
    'TRELEAVEN': 0,
    'TRELEVEN': 0,
    'TRELFA': 0,
    'TRELLA': 0,
    'TRELLES': 0,
    'TRELLO': 0,
    'TRELOAR': 0,
    'TRELSTAD': 0,
    'TREMAGLIO': 0,
    'TREMAIN': 0,
    'TREMAINE': 0,
    'TREMAYNE': 0,
    'TREMBA': 0,
    'TREMBATH': 0,
    'TREMBLAY': 0,
    'TREMBLE': 0,
    'TREMBLEY': 0,
    'TREMBLY': 0,
    'TREME': 0,
    'TREMEL': 0,
    'TREMELLING': 0,
    'TREMER': 0,
    'TREMILLO': 0,
    'TREMINIO': 0,
    'TREML': 0,
    'TREMMEL': 0,
    'TREMONT': 0,
    'TREMONTE': 0,
    'TREMONTI': 0,
    'TREMPE': 0,
    'TREMPER': 0,
    'TREN': 0,
    'TRENA': 1,
    'TRENADO': 0,
    'TRENARY': 0,
    'TRENCH': 0,
    'TRENCHARD': 0,
    'TREND': 0,
    'TRENDA': 0,
    'TRENDE': 0,
    'TRENDEL': 0,
    'TRENDELL': 0,
    'TRENDLE': 0,
    'TRENDLER': 0,
    'TRENERY': 0,
    'TRENHAILE': 0,
    'TRENHOLM': 0,
    'TRENK': 0,
    'TRENKAMP': 0,
    'TRENKLE': 0,
    'TRENKLER': 0,
    'TRENN': 0,
    'TRENNEPOHL': 0,
    'TRENNER': 0,
    'TRENOR': 0,
    'TRENT': 0.7223113964686998,
    'TRENTA': 0,
    'TRENTACOSTA': 0,
    'TRENTACOSTE': 0,
    'TRENTADUE': 0,
    'TRENTER': 0,
    'TRENTHAM': 0,
    'TRENTINI': 0,
    'TRENTLY': 0,
    'TRENTMAN': 0,
    'TRENTMANN': 0,
    'TRENTO': 0,
    'TRENTON': 0.9857612267250822,
    'TRENTZ': 0,
    'TRENUM': 0,
    'TRENZ': 0,
    'TREON': 0,
    'TREPAGNIER': 0,
    'TREPANIER': 0,
    'TREPASSO': 0,
    'TREPP': 0,
    'TREPPA': 0,
    'TREPTON': 0,
    'TREPTOW': 0,
    'TREROTOLA': 0,
    'TRES': 0,
    'TRESA': 1,
    'TRESCA': 0,
    'TRESCH': 0,
    'TRESCO': 0,
    'TRESCOTT': 0,
    'TRESEDER': 0,
    'TRESEMER': 0,
    'TRESIDDER': 0,
    'TRESKA': 0,
    'TRESLER': 0,
    'TRESNAK': 0,
    'TRESNER': 0,
    'TRESPALACIOS': 0,
    'TRESS': 0,
    'TRESSA': 0.9876543209876544,
    'TRESSEL': 0,
    'TRESSELT': 0,
    'TRESSER': 0,
    'TRESSIE': 1,
    'TRESSLAR': 0,
    'TRESSLER': 0,
    'TREST': 0,
    'TRESTER': 0,
    'TRESTON': 0,
    'TRESTRAIL': 0,
    'TRESVANT': 0,
    'TRETHAWAY': 0,
    'TRETHEWAY': 0,
    'TRETHEWEY': 0,
    'TRETIAK': 0,
    'TRETO': 0,
    'TRETOLA': 0,
    'TRETT': 0,
    'TRETTEL': 0,
    'TRETTER': 0,
    'TRETTIN': 0,
    'TREU': 0,
    'TREUBIG': 0,
    'TREUHAFT': 0,
    'TREUSCH': 0,
    'TREUTEL': 0,
    'TREUTING': 0,
    'TREVA': 1,
    'TREVARROW': 0,
    'TREVARTHEN': 0,
    'TREVASKIS': 0,
    'TREVATHAN': 0,
    'TREVENA': 0,
    'TREVER': 0,
    'TREVETHAN': 0,
    'TREVETT': 0,
    'TREVEY': 0,
    'TREVILLIAN': 0,
    'TREVILLION': 0,
    'TREVILLYAN': 0,
    'TREVINIO': 0,
    'TREVINO': 0,
    'TREVIS': 0,
    'TREVISAN': 0,
    'TREVISANI': 0,
    'TREVISO': 0,
    'TREVITHICK': 0,
    'TREVIZO': 0,
    'TREVOR': 0.9932952570151478,
    'TREVORAH': 0,
    'TREVORROW': 0,
    'TREW': 0,
    'TREWARTHA': 0,
    'TREWEEK': 0,
    'TREWHELLA': 0,
    'TREWHITT': 0,
    'TREWIN': 0,
    'TREWORGY': 0,
    'TREWYN': 0,
    'TREXEL': 0,
    'TREXLER': 0,
    'TREY': 0.986842105263158,
    'TREYBIG': 0,
    'TREZEVANT': 0,
    'TREZISE': 0,
    'TREZONA': 0,
    'TREZVANT': 0,
    'TREZZA': 0,
    'TRI': 0,
    'TRIA': 0,
    'TRIAL': 0,
    'TRIANA': 0,
    'TRIANO': 0,
    'TRIANTAFILLOU': 0,
    'TRIANTIS': 0,
    'TRIANTOS': 0,
    'TRIAS': 0,
    'TRIAY': 0,
    'TRIBBETT': 0,
    'TRIBBEY': 0,
    'TRIBBITT': 0,
    'TRIBBLE': 0,
    'TRIBBY': 0,
    'TRIBE': 0,
    'TRIBETT': 0,
    'TRIBLE': 0,
    'TRIBLEY': 0,
    'TRIBOLET': 0,
    'TRIBOU': 0,
    'TRIBOUT': 0,
    'TRIBUE': 0,
    'TRIBUZIO': 0,
    'TRICAMO': 0,
    'TRICARICO': 0,
    'TRICE': 0,
    'TRICHE': 0,
    'TRICHEL': 0,
    'TRICHELL': 0,
    'TRICHILO': 0,
    'TRICIA': 1,
    'TRICK': 0,
    'TRICKEL': 0,
    'TRICKER': 0,
    'TRICKETT': 0,
    'TRICKEY': 0,
    'TRICKLE': 0,
    'TRICKLER': 0,
    'TRICOCHE': 0,
    'TRICOLI': 0,
    'TRICOMI': 0,
    'TRIDICO': 0,
    'TRIDLE': 0,
    'TRIEB': 0,
    'TRIEBEL': 0,
    'TRIEBER': 0,
    'TRIEBOLD': 0,
    'TRIEBWASSER': 0,
    'TRIELOFF': 0,
    'TRIEM': 0,
    'TRIEMERT': 0,
    'TRIEMSTRA': 0,
    'TRIER': 0,
    'TRIERWEILER': 0,
    'TRIESCH': 0,
    'TRIESCHMAN': 0,
    'TRIESCHMANN': 0,
    'TRIEST': 0,
    'TRIETSCH': 0,
    'TRIEU': 0,
    'TRIEVEL': 0,
    'TRIEZENBERG': 0,
    'TRIFARI': 0,
    'TRIFILETTI': 0,
    'TRIFILIO': 0,
    'TRIFILO': 0,
    'TRIFIRO': 0,
    'TRIFONE': 0,
    'TRIFUNOVIC': 0,
    'TRIGG': 0,
    'TRIGGER': 0,
    'TRIGGS': 0,
    'TRIGILIO': 0,
    'TRIGLETH': 0,
    'TRIGLIA': 0,
    'TRIGO': 0,
    'TRIGUEIRO': 0,
    'TRIGUERO': 0,
    'TRIGUEROS': 0,
    'TRIKHA': 0,
    'TRILL': 0,
    'TRILLER': 0,
    'TRILLI': 0,
    'TRILLING': 0,
    'TRILLO': 0,
    'TRIM': 0,
    'TRIMARCHI': 0,
    'TRIMARCO': 0,
    'TRIMBACH': 0,
    'TRIMBATH': 0,
    'TRIMBERGER': 0,
    'TRIMBLE': 0,
    'TRIMBO': 0,
    'TRIMBOLI': 0,
    'TRIMBORN': 0,
    'TRIMBUR': 0,
    'TRIMBY': 0,
    'TRIMINO': 0,
    'TRIMM': 0,
    'TRIMMELL': 0,
    'TRIMMER': 0,
    'TRIMMIER': 0,
    'TRIMMINGS': 0,
    'TRIMNAL': 0,
    'TRIMNELL': 0,
    'TRIMPE': 0,
    'TRIMPER': 0,
    'TRIMPEY': 0,
    'TRIMUEL': 0,
    'TRINA': 0.9975062344139651,
    'TRINCA': 0,
    'TRINDADE': 0,
    'TRINDER': 0,
    'TRINDLE': 0,
    'TRINE': 0,
    'TRINER': 0,
    'TRINGALE': 0,
    'TRINGALI': 0,
    'TRINH': 0.189753320683112,
    'TRINIDAD': 0.7628294036061026,
    'TRINITY': 0.966183574879227,
    'TRINKA': 0,
    'TRINKAUS': 0,
    'TRINKL': 0,
    'TRINKLE': 0,
    'TRINKLEIN': 0,
    'TRINKLEY': 0,
    'TRINKNER': 0,
    'TRINKO': 0,
    'TRINKS': 0,
    'TRINQUE': 0,
    'TRIO': 0,
    'TRIOLA': 0,
    'TRIOLO': 0,
    'TRIONE': 0,
    'TRIONFO': 0,
    'TRIP': 0,
    'TRIPALDI': 0,
    'TRIPATHI': 0,
    'TRIPATHY': 0,
    'TRIPI': 0,
    'TRIPICCHIO': 0,
    'TRIPLER': 0,
    'TRIPLET': 0,
    'TRIPLETT': 0,
    'TRIPLETTE': 0,
    'TRIPLIN': 0,
    'TRIPLITT': 0,
    'TRIPODI': 0,
    'TRIPODO': 0,
    'TRIPOLI': 0,
    'TRIPP': 0,
    'TRIPPANY': 0,
    'TRIPPE': 0,
    'TRIPPEL': 0,
    'TRIPPETT': 0,
    'TRIPPI': 0,
    'TRIPPIEDI': 0,
    'TRIPPLE': 0,
    'TRIPPLER': 0,
    'TRIPPLET': 0,
    'TRIPPLETT': 0,
    'TRIPPY': 0,
    'TRISCARI': 0,
    'TRISCH': 0,
    'TRISCHITTA': 0,
    'TRISCHLER': 0,
    'TRISDALE': 0,
    'TRISEL': 0,
    'TRISH': 0.9771986970684039,
    'TRISHA': 1,
    'TRISKA': 0,
    'TRISKO': 0,
    'TRISLER': 0,
    'TRISSEL': 0,
    'TRISSELL': 0,
    'TRISTA': 1,
    'TRISTAN': 0.8841732979664013,
    'TRISTANI': 0,
    'TRISTANO': 0,
    'TRISTE': 0,
    'TRITAPOE': 0,
    'TRITCH': 0,
    'TRITCHLER': 0,
    'TRITES': 0,
    'TRITICO': 0,
    'TRITLE': 0,
    'TRITSCH': 0,
    'TRITSCHLER': 0,
    'TRITT': 0,
    'TRITTEN': 0,
    'TRITTIN': 0,
    'TRITTIPO': 0,
    'TRITTO': 0,
    'TRITTSCHUH': 0,
    'TRITZ': 0,
    'TRIVEDI': 0,
    'TRIVELLI': 0,
    'TRIVELPIECE': 0,
    'TRIVERS': 0,
    'TRIVETT': 0,
    'TRIVETTE': 0,
    'TRIVIGNO': 0,
    'TRIVINO': 0,
    'TRIVISON': 0,
    'TRIVISONNO': 0,
    'TRIVITT': 0,
    'TRIZZINO': 0,
    'TRNKA': 0,
    'TROAST': 0,
    'TROBAUGH': 0,
    'TROBEC': 0,
    'TROBRIDGE': 0,
    'TROCANO': 0,
    'TROCCHIA': 0,
    'TROCCHIO': 0,
    'TROCCOLI': 0,
    'TROCH': 0,
    'TROCHA': 0,
    'TROCHE': 0,
    'TROCHESSET': 0,
    'TROCHEZ': 0,
    'TROCINO': 0,
    'TROCK': 0,
    'TROCKI': 0,
    'TRODDEN': 0,
    'TROEGER': 0,
    'TROELL': 0,
    'TROELLER': 0,
    'TROEMEL': 0,
    'TROENDLE': 0,
    'TROESCH': 0,
    'TROESCHER': 0,
    'TROESSER': 0,
    'TROESTER': 0,
    'TROFA': 0,
    'TROFF': 0,
    'TROFHOLZ': 0,
    'TROG': 0,
    'TROGDEN': 0,
    'TROGDON': 0,
    'TROGE': 0,
    'TROGLEN': 0,
    'TROGLIA': 0,
    'TROGLIN': 0,
    'TROGSTAD': 0,
    'TROHA': 0,
    'TROIA': 0,
    'TROIANI': 0,
    'TROIANO': 0,
    'TROIDL': 0,
    'TROIKE': 0,
    'TROILO': 0,
    'TROISE': 0,
    'TROISI': 0,
    'TROJACEK': 0,
    'TROJAHN': 0,
    'TROJAK': 0,
    'TROJAN': 0,
    'TROJANEK': 0,
    'TROJANOWSKI': 0,
    'TROJCAK': 0,
    'TROJE': 0,
    'TROKA': 0,
    'TROKE': 0,
    'TROKEY': 0,
    'TROLAND': 0,
    'TROLINDER': 0,
    'TROLINGER': 0,
    'TROLIO': 0,
    'TROLL': 0,
    'TROLLER': 0,
    'TROLLEY': 0,
    'TROLLINGER': 0,
    'TROLLOPE': 0,
    'TROM': 0,
    'TROMBA': 0,
    'TROMBATORE': 0,
    'TROMBETTA': 0,
    'TROMBETTI': 0,
    'TROMBINO': 0,
    'TROMBLAY': 0,
    'TROMBLE': 0,
    'TROMBLEE': 0,
    'TROMBLEY': 0,
    'TROMBLY': 0,
    'TROMETER': 0,
    'TROMLEY': 0,
    'TROMM': 0,
    'TROMMER': 0,
    'TROMP': 0,
    'TROMPETER': 0,
    'TROMPKE': 0,
    'TRON': 0,
    'TRONCALE': 0,
    'TRONCIN': 0,
    'TRONCO': 0,
    'TRONCONE': 0,
    'TRONCOSO': 0,
    'TRONDSON': 0,
    'TRONE': 0,
    'TRONG': 0,
    'TRONGONE': 0,
    'TRONNES': 0,
    'TRONO': 0,
    'TRONOLONE': 0,
    'TRONSON': 0,
    'TRONSTAD': 0,
    'TRONT': 0,
    'TRONZO': 0,
    'TROOK': 0,
    'TROOP': 0,
    'TROOPE': 0,
    'TROOST': 0,
    'TROP': 0,
    'TROPE': 0,
    'TROPEA': 0,
    'TROPEANO': 0,
    'TROPF': 0,
    'TROPIANO': 0,
    'TROPP': 0,
    'TROPPER': 0,
    'TROQUILLE': 0,
    'TROSCH': 0,
    'TROSCLAIR': 0,
    'TROSEN': 0,
    'TROSETH': 0,
    'TROSIN': 0,
    'TROSKA': 0,
    'TROSKE': 0,
    'TROSKO': 0,
    'TROSKY': 0,
    'TROSPER': 0,
    'TROSS': 0,
    'TROSSBACH': 0,
    'TROSSEN': 0,
    'TROST': 0,
    'TROSTEL': 0,
    'TROSTLE': 0,
    'TROTH': 0,
    'TROTMAN': 0,
    'TROTSKY': 0,
    'TROTT': 0,
    'TROTTA': 0,
    'TROTTER': 0,
    'TROTTI': 0,
    'TROTTIE': 0,
    'TROTTIER': 0,
    'TROTTMAN': 0,
    'TROTTO': 0,
    'TROTTY': 0,
    'TROTZ': 0,
    'TROUB': 0,
    'TROUBA': 0,
    'TROUBLEFIELD': 0,
    'TROUDT': 0,
    'TROUGHT': 0,
    'TROUGHTON': 0,
    'TROUMBLY': 0,
    'TROUNG': 0,
    'TROUP': 0,
    'TROUPE': 0,
    'TROUSDALE': 0,
    'TROUSIL': 0,
    'TROUT': 0,
    'TROUTE': 0,
    'TROUTEN': 0,
    'TROUTMAN': 0,
    'TROUTNER': 0,
    'TROUTT': 0,
    'TROUTWINE': 0,
    'TROVATO': 0,
    'TROVER': 0,
    'TROVILLION': 0,
    'TROVINGER': 0,
    'TROW': 0,
    'TROWBRIDGE': 0,
    'TROWEL': 0,
    'TROWELL': 0,
    'TROWER': 0,
    'TROWERS': 0,
    'TROXCLAIR': 0,
    'TROXEL': 0,
    'TROXELL': 0,
    'TROXLER': 0,
    'TROXTEL': 0,
    'TROXTELL': 0,
    'TROY': 0.9792870226856418,
    'TROYA': 0,
    'TROYAN': 0,
    'TROYANO': 0,
    'TROYER': 0,
    'TROZZI': 0,
    'TROZZO': 0,
    'TRUAN': 0,
    'TRUAX': 0,
    'TRUBE': 0,
    'TRUBEE': 0,
    'TRUBEY': 0,
    'TRUBIA': 0,
    'TRUBIANO': 0,
    'TRUBY': 0,
    'TRUCANO': 0,
    'TRUCCO': 0,
    'TRUCHAN': 0,
    'TRUCHON': 0,
    'TRUCKE': 0,
    'TRUCKENBROD': 0,
    'TRUCKENMILLER': 0,
    'TRUCKEY': 0,
    'TRUCKS': 0,
    'TRUCKSESS': 0,
    'TRUDE': 0,
    'TRUDEAU': 0,
    'TRUDEL': 0,
    'TRUDELL': 0,
    'TRUDELLE': 0,
    'TRUDGEN': 0,
    'TRUDGEON': 0,
    'TRUDI': 1,
    'TRUDIE': 1,
    'TRUDNAK': 0,
    'TRUDO': 0,
    'TRUDY': 1,
    'TRUE': 0,
    'TRUEAX': 0,
    'TRUEB': 0,
    'TRUEBA': 0,
    'TRUEBENBACH': 0,
    'TRUEBLOOD': 0,
    'TRUEDSON': 0,
    'TRUEHART': 0,
    'TRUEHEART': 0,
    'TRUEHILL': 0,
    'TRUELL': 0,
    'TRUELOCK': 0,
    'TRUELOVE': 0,
    'TRUELSEN': 0,
    'TRUELSON': 0,
    'TRUEMAN': 0,
    'TRUEMPER': 0,
    'TRUESDAIL': 0,
    'TRUESDALE': 0,
    'TRUESDELL': 0,
    'TRUETT': 0,
    'TRUEWORTHY': 0,
    'TRUEX': 0,
    'TRUFANT': 0,
    'TRUFFA': 0,
    'TRUGILLO': 0,
    'TRUGLIA': 0,
    'TRUGLIO': 0,
    'TRUHAN': 0,
    'TRUHE': 0,
    'TRUHLAR': 0,
    'TRUHN': 0,
    'TRUILLO': 0,
    'TRUINI': 0,
    'TRUITT': 0,
    'TRUJANO': 0,
    'TRUJEQUE': 0,
    'TRUJILLO': 0,
    'TRUKA': 0,
    'TRULA': 1,
    'TRULL': 0,
    'TRULLI': 0,
    'TRULLINGER': 0,
    'TRULOCK': 0,
    'TRULOVE': 0,
    'TRULSON': 0,
    'TRULUCK': 0,
    'TRULY': 0,
    'TRUM': 0,
    'TRUMAN': 0.8166969147005444,
    'TRUMBAUER': 0,
    'TRUMBLE': 0,
    'TRUMBLEY': 0,
    'TRUMBLY': 0,
    'TRUMBO': 0,
    'TRUMBORE': 0,
    'TRUMBOWER': 0,
    'TRUMBULL': 0,
    'TRUMM': 0,
    'TRUMMEL': 0,
    'TRUMMER': 0,
    'TRUMP': 0,
    'TRUMPER': 0,
    'TRUMPET': 0,
    'TRUMPLER': 0,
    'TRUMPOWER': 0,
    'TRUMPP': 0,
    'TRUMPS': 0,
    'TRUMPY': 0,
    'TRUNCALE': 0,
    'TRUNCALI': 0,
    'TRUNCELLITO': 0,
    'TRUNDLE': 0,
    'TRUNDY': 0,
    'TRUNFIO': 0,
    'TRUNG': 0,
    'TRUNICK': 0,
    'TRUNK': 0,
    'TRUNKO': 0,
    'TRUNNELL': 0,
    'TRUNZO': 0,
    'TRUOG': 0,
    'TRUONG': 0,
    'TRUPE': 0,
    'TRUPIA': 0,
    'TRUPIAND': 0,
    'TRUPIANO': 0,
    'TRUPP': 0,
    'TRUPPA': 0,
    'TRUPPI': 0,
    'TRUPPO': 0,
    'TRURAN': 0,
    'TRUSCELLO': 0,
    'TRUSCHEL': 0,
    'TRUSCOTT': 0,
    'TRUSDALE': 0,
    'TRUSDELL': 0,
    'TRUSH': 0,
    'TRUSHEL': 0,
    'TRUSKEY': 0,
    'TRUSKOLASKI': 0,
    'TRUSKOWSKI': 0,
    'TRUSKY': 0,
    'TRUSLER': 0,
    'TRUSLEY': 0,
    'TRUSLOW': 0,
    'TRUSS': 0,
    'TRUSSEL': 0,
    'TRUSSELL': 0,
    'TRUSSLER': 0,
    'TRUSSO': 0,
    'TRUSSONI': 0,
    'TRUST': 0,
    'TRUSTER': 0,
    'TRUSTY': 0,
    'TRUSZ': 0,
    'TRUSZKOWSKI': 0,
    'TRUTE': 0,
    'TRUTNA': 0,
    'TRUTT': 0,
    'TRUTTMANN': 0,
    'TRUTWIN': 0,
    'TRUTY': 0,
    'TRUVER': 0,
    'TRUVILLION': 0,
    'TRUXAL': 0,
    'TRUXALL': 0,
    'TRUXEL': 0,
    'TRUXELL': 0,
    'TRUXILLO': 0,
    'TRUXTON': 0,
    'TRY': 0,
    'TRYAN': 0,
    'TRYBA': 0,
    'TRYBAN': 0,
    'TRYBULA': 0,
    'TRYBULSKI': 0,
    'TRYBUS': 0,
    'TRYGAR': 0,
    'TRYGG': 0,
    'TRYGGESTAD': 0,
    'TRYGSTAD': 0,
    'TRYKOWSKI': 0,
    'TRYON': 0,
    'TRYTEK': 0,
    'TRYTHALL': 0,
    'TRYTTEN': 0,
    'TRZASKA': 0,
    'TRZASKOS': 0,
    'TRZCINSKI': 0,
    'TRZEBIATOWSKI': 0,
    'TRZECIAK': 0,
    'TRZEPACZ': 0,
    'TRZNADEL': 0,
    'TRZYNA': 0,
    'TSAGARIS': 0,
    'TSAI': 0,
    'TSAKIRIS': 0,
    'TSAKONAS': 0,
    'TSAKOS': 0,
    'TSAN': 0,
    'TSANG': 0,
    'TSANGARIS': 0,
    'TSAO': 0,
    'TSARNAS': 0,
    'TSATURYAN': 0,
    'TSAY': 0,
    'TSCHACHER': 0,
    'TSCHAKERT': 0,
    'TSCHANNEN': 0,
    'TSCHANTZ': 0,
    'TSCHANZ': 0,
    'TSCHAPPAT': 0,
    'TSCHERNE': 0,
    'TSCHETTER': 0,
    'TSCHIDA': 0,
    'TSCHINKEL': 0,
    'TSCHIRGI': 0,
    'TSCHIRHART': 0,
    'TSCHOEPE': 0,
    'TSCHOPP': 0,
    'TSCHOSIK': 0,
    'TSCHUDI': 0,
    'TSCHUDIN': 0,
    'TSCHUDY': 0,
    'TSCHUMPER': 0,
    'TSCHUPP': 0,
    'TSE': 0,
    'TSEGAI': 0,
    'TSEGAYE': 0,
    'TSEN': 0,
    'TSENG': 0,
    'TSERING': 0,
    'TSETHLIKAI': 0,
    'TSHUDY': 0,
    'TSIEN': 0,
    'TSINNIE': 0,
    'TSINNIJINNIE': 0,
    'TSO': 0,
    'TSOI': 0,
    'TSONIS': 0,
    'TSOODLE': 0,
    'TSOSIE': 0,
    'TSOU': 0,
    'TSOUKALAS': 0,
    'TSU': 0,
    'TSUBOI': 0,
    'TSUBOTA': 0,
    'TSUCHIDA': 0,
    'TSUCHIYA': 0,
    'TSUCHIYAMA': 0,
    'TSUDA': 0,
    'TSUE': 0,
    'TSUEI': 0,
    'TSUGAWA': 0,
    'TSUHA': 0,
    'TSUI': 0,
    'TSUJI': 0,
    'TSUJIMOTO': 0,
    'TSUJIMURA': 0,
    'TSUKADA': 0,
    'TSUKAMOTO': 0,
    'TSUKAYAMA': 0,
    'TSUKERMAN': 0,
    'TSUKIYAMA': 0,
    'TSUMURA': 0,
    'TSUNG': 0,
    'TSUNODA': 0,
    'TSURUDA': 0,
    'TSURUTA': 0,
    'TSUSHIMA': 0,
    'TSUTSUI': 0,
    'TSUTSUMI': 0,
    'TSUYUKI': 0,
    'TSUZUKI': 0,
    'TU': 0.28328611898017003,
    'TUA': 0,
    'TUALA': 0,
    'TUALLA': 0,
    'TUAN': 0.966183574879227,
    'TUASON': 0,
    'TUAZON': 0,
    'TUBA': 0,
    'TUBACH': 0,
    'TUBAUGH': 0,
    'TUBB': 0,
    'TUBBESING': 0,
    'TUBBS': 0,
    'TUBBY': 0,
    'TUBENS': 0,
    'TUBER': 0,
    'TUBERA': 0,
    'TUBERGEN': 0,
    'TUBERVILLE': 0,
    'TUBIG': 0,
    'TUBIOLO': 0,
    'TUBIS': 0,
    'TUBMAN': 0,
    'TUBO': 0,
    'TUBOLINO': 0,
    'TUBON': 0,
    'TUBRE': 0,
    'TUBRIDY': 0,
    'TUCAY': 0,
    'TUCCERI': 0,
    'TUCCI': 0,
    'TUCCIARONE': 0,
    'TUCCILLO': 0,
    'TUCCINARDI': 0,
    'TUCCIO': 0,
    'TUCCITTO': 0,
    'TUCEK': 0,
    'TUCH': 0,
    'TUCHALSKI': 0,
    'TUCHEK': 0,
    'TUCHEL': 0,
    'TUCHER': 0,
    'TUCHMAN': 0,
    'TUCHOLSKI': 0,
    'TUCHSCHERER': 0,
    'TUCK': 0,
    'TUCKE': 0,
    'TUCKER': 0,
    'TUCKERMAN': 0,
    'TUCKETT': 0,
    'TUCKEY': 0,
    'TUCKFIELD': 0,
    'TUCKMAN': 0,
    'TUCKNER': 0,
    'TUCKNESS': 0,
    'TUCKSON': 0,
    'TUCKWILLER': 0,
    'TUCSON': 0,
    'TUCZYNSKI': 0,
    'TUDELA': 0,
    'TUDER': 0,
    'TUDERS': 0,
    'TUDHOPE': 0,
    'TUDINO': 0,
    'TUDISCO': 0,
    'TUDON': 0,
    'TUDOR': 0,
    'TUDRYN': 0,
    'TUE': 0,
    'TUEL': 0,
    'TUELL': 0,
    'TUELLER': 0,
    'TUEMLER': 0,
    'TUENGE': 0,
    'TUEPKER': 0,
    'TUER': 0,
    'TUERCK': 0,
    'TUERK': 0,
    'TUERO': 0,
    'TUERS': 0,
    'TUESCHER': 0,
    'TUESTA': 0,
    'TUETKEN': 0,
    'TUEY': 0,
    'TUFAIL': 0,
    'TUFANO': 0,
    'TUFARIELLO': 0,
    'TUFARO': 0,
    'TUFF': 0,
    'TUFFIN': 0,
    'TUFFLEY': 0,
    'TUFFORD': 0,
    'TUFFS': 0,
    'TUFFY': 0,
    'TUFINO': 0,
    'TUFNELL': 0,
    'TUFO': 0,
    'TUFT': 0,
    'TUFTE': 0,
    'TUFTS': 0,
    'TUGADE': 0,
    'TUGEND': 0,
    'TUGGLE': 0,
    'TUGGLES': 0,
    'TUGMAN': 0,
    'TUGWELL': 0,
    'TUHOLSKI': 0,
    'TUHY': 0,
    'TUI': 0,
    'TUIA': 0,
    'TUIASOSOPO': 0,
    'TUIFUA': 0,
    'TUIN': 0,
    'TUINEI': 0,
    'TUININGA': 0,
    'TUINSTRA': 0,
    'TUIPULOTU': 0,
    'TUITASI': 0,
    'TUITE': 0,
    'TUITELE': 0,
    'TUITT': 0,
    'TUJAGUE': 0,
    'TUKE': 0,
    'TUKES': 0,
    'TUKEY': 0,
    'TUKUA': 0,
    'TUKUAFU': 0,
    'TULA': 0.8849557522123894,
    'TULAK': 0,
    'TULBERT': 0,
    'TULCHINSKY': 0,
    'TULE': 0,
    'TULEJA': 0,
    'TULENKO': 0,
    'TULEY': 0,
    'TULI': 0,
    'TULIAO': 0,
    'TULIN': 0,
    'TULINO': 0,
    'TULIO': 0,
    'TULIP': 0,
    'TULIPANO': 0,
    'TULIS': 0,
    'TULK': 0,
    'TULL': 0,
    'TULLAR': 0,
    'TULLBERG': 0,
    'TULLER': 0,
    'TULLEY': 0,
    'TULLGREN': 0,
    'TULLI': 0,
    'TULLIE': 0,
    'TULLIER': 0,
    'TULLIO': 0,
    'TULLIS': 0,
    'TULLIUS': 0,
    'TULLMAN': 0,
    'TULLO': 0,
    'TULLOCH': 0,
    'TULLOCK': 0,
    'TULLOH': 0,
    'TULLOS': 0,
    'TULLOSS': 0,
    'TULLOUS': 0,
    'TULLY': 0,
    'TULMAN': 0,
    'TULP': 0,
    'TULUMELLO': 0,
    'TUM': 0,
    'TUMA': 0,
    'TUMACDER': 0,
    'TUMAN': 0,
    'TUMANENG': 0,
    'TUMANG': 0,
    'TUMANYAN': 0,
    'TUMAS': 0,
    'TUMAX': 0,
    'TUMBAGA': 0,
    'TUMBARELLO': 0,
    'TUMBER': 0,
    'TUMBERG': 0,
    'TUMBLESON': 0,
    'TUMBLESTON': 0,
    'TUMBLIN': 0,
    'TUMBLING': 0,
    'TUMELTY': 0,
    'TUMER': 0,
    'TUMEY': 0,
    'TUMILTY': 0,
    'TUMINARO': 0,
    'TUMINELLI': 0,
    'TUMINELLO': 0,
    'TUMINO': 0,
    'TUMLIN': 0,
    'TUMLINSON': 0,
    'TUMM': 0,
    'TUMMALA': 0,
    'TUMMEL': 0,
    'TUMMILLO': 0,
    'TUMMINARO': 0,
    'TUMMINELLI': 0,
    'TUMMINELLO': 0,
    'TUMMINIA': 0,
    'TUMMINO': 0,
    'TUMMINS': 0,
    'TUMMONS': 0,
    'TUMOLO': 0,
    'TUMPKIN': 0,
    'TUMULTY': 0,
    'TUN': 0,
    'TUNA': 0,
    'TUNBERG': 0,
    'TUNCHEZ': 0,
    'TUNDIDOR': 0,
    'TUNDO': 0,
    'TUNE': 0,
    'TUNELL': 0,
    'TUNER': 0,
    'TUNG': 0,
    'TUNGATE': 0,
    'TUNGET': 0,
    'TUNGETT': 0,
    'TUNGOL': 0,
    'TUNGPALAN': 0,
    'TUNGSETH': 0,
    'TUNHEIM': 0,
    'TUNICK': 0,
    'TUNING': 0,
    'TUNINK': 0,
    'TUNIS': 0,
    'TUNISON': 0,
    'TUNKARA': 0,
    'TUNKEL': 0,
    'TUNKS': 0,
    'TUNLEY': 0,
    'TUNNELL': 0,
    'TUNNER': 0,
    'TUNNEY': 0,
    'TUNNICLIFF': 0,
    'TUNNICLIFFE': 0,
    'TUNNING': 0,
    'TUNNO': 0,
    'TUNNY': 0,
    'TUNON': 0,
    'TUNSIL': 0,
    'TUNSON': 0,
    'TUNSTALL': 0,
    'TUNSTILL': 0,
    'TUNTLAND': 0,
    'TUNZI': 0,
    'TUOHEY': 0,
    'TUOHY': 0,
    'TUOMALA': 0,
    'TUOMEY': 0,
    'TUOMI': 0,
    'TUOMINEN': 0,
    'TUON': 0,
    'TUONG': 0,
    'TUORTO': 0,
    'TUOSTO': 0,
    'TUOZZO': 0,
    'TUPA': 0,
    'TUPAS': 0,
    'TUPAZ': 0,
    'TUPER': 0,
    'TUPIN': 0,
    'TUPLING': 0,
    'TUPMAN': 0,
    'TUPOU': 0,
    'TUPPER': 0,
    'TUPPS': 0,
    'TUPUA': 0,
    'TUPUOLA': 0,
    'TUPY': 0,
    'TUR': 0,
    'TURA': 0,
    'TURAK': 0,
    'TURAN': 0,
    'TURANO': 0,
    'TURANSKY': 0,
    'TURAY': 0,
    'TURBA': 0,
    'TURBAK': 0,
    'TURBEN': 0,
    'TURBERVILLE': 0,
    'TURBES': 0,
    'TURBETT': 0,
    'TURBEVILLE': 0,
    'TURBIDE': 0,
    'TURBIN': 0,
    'TURBITT': 0,
    'TURBYFILL': 0,
    'TURCHAN': 0,
    'TURCHETTA': 0,
    'TURCHETTI': 0,
    'TURCHI': 0,
    'TURCHIANO': 0,
    'TURCHIN': 0,
    'TURCIC': 0,
    'TURCIO': 0,
    'TURCIOS': 0,
    'TURCK': 0,
    'TURCO': 0,
    'TURCOTT': 0,
    'TURCOTTE': 0,
    'TURCZYN': 0,
    'TURCZYNSKI': 0,
    'TURDIK': 0,
    'TURDO': 0,
    'TURE': 0,
    'TUREAUD': 0,
    'TURECEK': 0,
    'TURECHEK': 0,
    'TUREK': 0,
    'TUREL': 0,
    'TURELL': 0,
    'TURENNE': 0,
    'TURENTINE': 0,
    'TURER': 0,
    'TURES': 0,
    'TURESON': 0,
    'TURETSKY': 0,
    'TURETZKY': 0,
    'TURGEON': 0,
    'TURI': 0,
    'TURIANO': 0,
    'TURICK': 0,
    'TURIELLO': 0,
    'TURILLI': 0,
    'TURIN': 0,
    'TURINA': 0,
    'TURINI': 0,
    'TURINO': 0,
    'TURINSKY': 0,
    'TURITTO': 0,
    'TURK': 0,
    'TURKAL': 0,
    'TURKALY': 0,
    'TURKE': 0,
    'TURKEL': 0,
    'TURKEN': 0,
    'TURKER': 0,
    'TURKETT': 0,
    'TURKIEWICZ': 0,
    'TURKIN': 0,
    'TURKINGTON': 0,
    'TURKLE': 0,
    'TURKNETT': 0,
    'TURKO': 0,
    'TURKOVIC': 0,
    'TURKOVICH': 0,
    'TURKOWSKI': 0,
    'TURKS': 0,
    'TURKSON': 0,
    'TURKUS': 0,
    'TURL': 0,
    'TURLA': 0,
    'TURLEY': 0,
    'TURLINGTON': 0,
    'TURMAN': 0,
    'TURMEL': 0,
    'TURMELLE': 0,
    'TURMENNE': 0,
    'TURMER': 0,
    'TURMON': 0,
    'TURN': 0,
    'TURNAGE': 0,
    'TURNBACH': 0,
    'TURNBAUGH': 0,
    'TURNBEAUGH': 0,
    'TURNBERG': 0,
    'TURNBILL': 0,
    'TURNBLOM': 0,
    'TURNBO': 0,
    'TURNBOUGH': 0,
    'TURNBOW': 0,
    'TURNBULL': 0,
    'TURNELL': 0,
    'TURNER': 0,
    'TURNES': 0,
    'TURNEY': 0,
    'TURNHAM': 0,
    'TURNIDGE': 0,
    'TURNIER': 0,
    'TURNIPSEED': 0,
    'TURNIS': 0,
    'TURNLEY': 0,
    'TURNMIRE': 0,
    'TURNOCK': 0,
    'TURNPAUGH': 0,
    'TURNQUEST': 0,
    'TURNQUIST': 0,
    'TURNS': 0,
    'TURNTINE': 0,
    'TURNURE': 0,
    'TURNWALD': 0,
    'TURNWALL': 0,
    'TURO': 0,
    'TUROCY': 0,
    'TUROCZY': 0,
    'TUROFF': 0,
    'TUROK': 0,
    'TURON': 0,
    'TUROS': 0,
    'TUROSKI': 0,
    'TUROW': 0,
    'TUROWSKI': 0,
    'TURPEAU': 0,
    'TURPEL': 0,
    'TURPEN': 0,
    'TURPENING': 0,
    'TURPIN': 0,
    'TURRELL': 0,
    'TURRENTINE': 0,
    'TURREY': 0,
    'TURRI': 0,
    'TURRIETA': 0,
    'TURRIETTA': 0,
    'TURRIFF': 0,
    'TURRILL': 0,
    'TURRIN': 0,
    'TURRISI': 0,
    'TURRO': 0,
    'TURRUBIARTES': 0,
    'TURRUBIATE': 0,
    'TURRUBIATES': 0,
    'TURSE': 0,
    'TURSI': 0,
    'TURSKI': 0,
    'TURSKY': 0,
    'TURSO': 0,
    'TURTLE': 0,
    'TURTON': 0,
    'TURTURICI': 0,
    'TURTURRO': 0,
    'TURVAVILLE': 0,
    'TURVEY': 0,
    'TURVILLE': 0,
    'TURVIN': 0,
    'TURY': 0,
    'TURZA': 0,
    'TURZAK': 0,
    'TURZANSKI': 0,
    'TURZINSKI': 0,
    'TUSA': 0,
    'TUSCAN': 0,
    'TUSCANO': 0,
    'TUSCANY': 0,
    'TUSCH': 0,
    'TUSCHEN': 0,
    'TUSCHER': 0,
    'TUSCHHOFF': 0,
    'TUSH': 0,
    'TUSHAR': 0,
    'TUSI': 0,
    'TUSING': 0,
    'TUSKAN': 0,
    'TUSKEY': 0,
    'TUSLER': 0,
    'TUSO': 0,
    'TUSON': 0,
    'TUSS': 0,
    'TUSSEY': 0,
    'TUSSING': 0,
    'TUSTIN': 0,
    'TUSTISON': 0,
    'TUSZYNSKI': 0,
    'TUT': 0,
    'TUTAJ': 0,
    'TUTAK': 0,
    'TUTAS': 0,
    'TUTEIN': 0,
    'TUTELA': 0,
    'TUTEN': 0,
    'TUTER': 0,
    'TUTERA': 0,
    'TUTEWOHL': 0,
    'TUTHILL': 0,
    'TUTINO': 0,
    'TUTKA': 0,
    'TUTKO': 0,
    'TUTOLO': 0,
    'TUTON': 0,
    'TUTONE': 0,
    'TUTOR': 0,
    'TUTOROW': 0,
    'TUTRONE': 0,
    'TUTSON': 0,
    'TUTT': 0,
    'TUTTEROW': 0,
    'TUTTERROW': 0,
    'TUTTLE': 0,
    'TUTTOBENE': 0,
    'TUTTON': 0,
    'TUTTY': 0,
    'TUTUNJIAN': 0,
    'TUTWILER': 0,
    'TUURA': 0,
    'TUURI': 0,
    'TUVELL': 0,
    'TUVESON': 0,
    'TUXBURY': 0,
    'TUXHORN': 0,
    'TUY': 0,
    'TUYET': 1,
    'TUYLS': 0,
    'TUZ': 0,
    'TUZINSKI': 0,
    'TUZON': 0,
    'TUZZIO': 0,
    'TUZZO': 0,
    'TUZZOLINO': 0,
    'TUZZOLO': 0,
    'TVEDT': 0,
    'TVEIT': 0,
    'TVERBERG': 0,
    'TVETEN': 0,
    'TVETER': 0,
    'TVRDIK': 0,
    'TVRDY': 0,
    'TWA': 0,
    'TWADDELL': 0,
    'TWADDLE': 0,
    'TWAIT': 0,
    'TWAMLEY': 0,
    'TWANA': 1,
    'TWANDA': 1,
    'TWANNA': 1,
    'TWARDOSKI': 0,
    'TWARDOWSKI': 0,
    'TWARDY': 0,
    'TWARDZIK': 0,
    'TWAROG': 0,
    'TWAROWSKI': 0,
    'TWAY': 0,
    'TWEDDELL': 0,
    'TWEDDLE': 0,
    'TWEDE': 0,
    'TWEDELL': 0,
    'TWEDT': 0,
    'TWEED': 0,
    'TWEEDALE': 0,
    'TWEEDEL': 0,
    'TWEEDELL': 0,
    'TWEEDIE': 0,
    'TWEEDLE': 0,
    'TWEEDT': 0,
    'TWEEDY': 0,
    'TWEET': 0,
    'TWEETEN': 0,
    'TWEETON': 0,
    'TWEHUES': 0,
    'TWELE': 0,
    'TWELLMAN': 0,
    'TWENTE': 0,
    'TWENTER': 0,
    'TWERSKY': 0,
    'TWETE': 0,
    'TWETEN': 0,
    'TWIBELL': 0,
    'TWICHELL': 0,
    'TWIDDY': 0,
    'TWIDWELL': 0,
    'TWIETMEYER': 0,
    'TWIFORD': 0,
    'TWIGG': 0,
    'TWIGGER': 0,
    'TWIGGS': 0,
    'TWILA': 1,
    'TWILLA': 0,
    'TWILLEY': 0,
    'TWILLIE': 0,
    'TWILLIGEAR': 0,
    'TWILLING': 0,
    'TWINAM': 0,
    'TWINE': 0,
    'TWINEM': 0,
    'TWINER': 0,
    'TWING': 0,
    'TWINING': 0,
    'TWINN': 0,
    'TWISDALE': 0,
    'TWISS': 0,
    'TWISSELMAN': 0,
    'TWIST': 0,
    'TWITCHELL': 0,
    'TWITE': 0,
    'TWITO': 0,
    'TWITTY': 0,
    'TWOBULLS': 0,
    'TWOCROW': 0,
    'TWOGOOD': 0,
    'TWOHEY': 0,
    'TWOHIG': 0,
    'TWOHILL': 0,
    'TWOHY': 0,
    'TWOMBLEY': 0,
    'TWOMBLY': 0,
    'TWOMEY': 0,
    'TWOREK': 0,
    'TWORK': 0,
    'TWORKOWSKI': 0,
    'TWUMASI': 0,
    'TWYFORD': 0,
    'TWYLA': 1,
    'TWYMAN': 0,
    'TWYMON': 0,
    'TWYNE': 0,
    'TY': 0.975177304964539,
    'TYACK': 0,
    'TYACKE': 0,
    'TYAGI': 0,
    'TYAN': 0,
    'TYAS': 0,
    'TYAU': 0,
    'TYBERG': 0,
    'TYBOR': 0,
    'TYBURCZY': 0,
    'TYBURSKI': 0,
    'TYCE': 0,
    'TYCKSEN': 0,
    'TYCZ': 0,
    'TYCZKOWSKI': 0,
    'TYDINGS': 0,
    'TYE': 0,
    'TYER': 0,
    'TYERS': 0,
    'TYERYAR': 0,
    'TYES': 0,
    'TYESHA': 1,
    'TYGART': 0,
    'TYGER': 0,
    'TYGRETT': 0,
    'TYHURST': 0,
    'TYIER': 0,
    'TYISHA': 1,
    'TYISKA': 0,
    'TYK': 0,
    'TYL': 0,
    'TYLE': 0,
    'TYLEE': 0,
    'TYLENDA': 0,
    'TYLER': 0.7969872131721842,
    'TYLICKI': 0,
    'TYLINSKI': 0,
    'TYLKA': 0,
    'TYLL': 0,
    'TYLMAN': 0,
    'TYLOCK': 0,
    'TYLUS': 0,
    'TYLUTKI': 0,
    'TYM': 0,
    'TYMA': 0,
    'TYMAN': 0,
    'TYMES': 0,
    'TYMESON': 0,
    'TYMINSKI': 0,
    'TYMON': 0,
    'TYMS': 0,
    'TYNAN': 0,
    'TYNDAL': 0,
    'TYNDALE': 0,
    'TYNDALL': 0,
    'TYNDELL': 0,
    'TYNE': 0,
    'TYNER': 0,
    'TYNES': 0,
    'TYNISHA': 1,
    'TYNON': 0,
    'TYO': 0,
    'TYRA': 0.8849557522123893,
    'TYRE': 0,
    'TYREE': 0.5882352941176471,
    'TYRELL': 0.9009009009009009,
    'TYRER': 0,
    'TYRIE': 0,
    'TYRNER': 0,
    'TYROL': 0,
    'TYRON': 0.9900990099009901,
    'TYRONE': 0.995798973082309,
    'TYRPAK': 0,
    'TYRREL': 0,
    'TYRRELL': 0,
    'TYRUS': 0,
    'TYSDAL': 0,
    'TYSER': 0,
    'TYSINGER': 0,
    'TYSKA': 0,
    'TYSON': 0.5749486652977414,
    'TYSOR': 0,
    'TYSVER': 0,
    'TYSZKA': 0,
    'TYSZKIEWICZ': 0,
    'TYSZKO': 0,
    'TYTLER': 0,
    'TYUS': 0,
    'TZENG': 0,
    'TZINTZUN': 0,
    'TZOC': 0,
    'TZORTZIS': 0,
    'TZOU': 0,
    'TZUL': 0,
    'UBA': 0,
    'UBALDO': 0,
    'UBALLE': 0,
    'UBANDO': 0,
    'UBANKS': 0,
    'UBBEN': 0,
    'UBEDA': 0,
    'UBEL': 0,
    'UBELHOR': 0,
    'UBER': 0,
    'UBERSOX': 0,
    'UBERT': 0,
    'UBERTI': 0,
    'UBIAS': 0,
    'UBIERA': 0,
    'UBILES': 0,
    'UBILLA': 0,
    'UBILLUS': 0,
    'UBINA': 0,
    'UBINAS': 0,
    'UBINGER': 0,
    'UBL': 0,
    'UBRIACO': 0,
    'UBUNGEN': 0,
    'UC': 0,
    'UCCELLO': 0,
    'UCCI': 0,
    'UCEDA': 0,
    'UCETA': 0,
    'UCH': 0,
    'UCHE': 0,
    'UCHIDA': 0,
    'UCHIMA': 0,
    'UCHIMURA': 0,
    'UCHINO': 0,
    'UCHITEL': 0,
    'UCHIYAMA': 0,
    'UCHMAN': 0,
    'UCHTMAN': 0,
    'UCHYTIL': 0,
    'UCKER': 0,
    'UDA': 0,
    'UDALL': 0,
    'UDANI': 0,
    'UDARBE': 0,
    'UDAVE': 0,
    'UDD': 0,
    'UDDIN': 0,
    'UDE': 0,
    'UDEH': 0,
    'UDELHOFEN': 0,
    'UDELHOVEN': 0,
    'UDELL': 0,
    'UDEN': 0,
    'UDESHI': 0,
    'UDING': 0,
    'UDO': 0,
    'UDOH': 0,
    'UDOVICH': 0,
    'UDY': 0,
    'UEBBING': 0,
    'UEBEL': 0,
    'UEBELACKER': 0,
    'UEBELE': 0,
    'UEBELHOER': 0,
    'UEBELHOR': 0,
    'UEBERROTH': 0,
    'UECHI': 0,
    'UECKE': 0,
    'UECKER': 0,
    'UECKERT': 0,
    'UEDA': 0,
    'UEHARA': 0,
    'UEHLEIN': 0,
    'UEHLING': 0,
    'UEKI': 0,
    'UELAND': 0,
    'UELMEN': 0,
    'UELTSCHI': 0,
    'UEMURA': 0,
    'UENO': 0,
    'UESUGI': 0,
    'UETRECHT': 0,
    'UETZ': 0,
    'UFER': 0,
    'UFFELMAN': 0,
    'UFFER': 0,
    'UFFMAN': 0,
    'UFFNER': 0,
    'UFFORD': 0,
    'UFKES': 0,
    'UGALDE': 0,
    'UGALE': 0,
    'UGARTE': 0,
    'UGARTECHEA': 0,
    'UGAS': 0,
    'UGAZ': 0,
    'UGENTI': 0,
    'UGLAND': 0,
    'UGLOW': 0,
    'UGO': 0,
    'UGOLINI': 0,
    'UGWU': 0,
    'UH': 0,
    'UHAS': 0,
    'UHDE': 0,
    'UHDEN': 0,
    'UHE': 0,
    'UHER': 0,
    'UHING': 0,
    'UHL': 0,
    'UHLAND': 0,
    'UHLAR': 0,
    'UHLE': 0,
    'UHLENBRAUCK': 0,
    'UHLENBROCK': 0,
    'UHLENHAKE': 0,
    'UHLENHOPP': 0,
    'UHLENKAMP': 0,
    'UHLENKOTT': 0,
    'UHLER': 0,
    'UHLES': 0,
    'UHLHORN': 0,
    'UHLICH': 0,
    'UHLIG': 0,
    'UHLIK': 0,
    'UHLIR': 0,
    'UHLMAN': 0,
    'UHLMANN': 0,
    'UHLMANSIEK': 0,
    'UHLMEYER': 0,
    'UHLRICH': 0,
    'UHLS': 0,
    'UHM': 0,
    'UHR': 0,
    'UHREN': 0,
    'UHRICH': 0,
    'UHRICK': 0,
    'UHRIG': 0,
    'UHRIK': 0,
    'UHRIN': 0,
    'UHRMACHER': 0,
    'UIHLEIN': 0,
    'UITERMARKT': 0,
    'UITHOVEN': 0,
    'UITZ': 0,
    'UJVARI': 0,
    'UK': 0,
    'UKANI': 0,
    'UKEN': 0,
    'UKENA': 0,
    'UKLEJA': 0,
    'ULA': 1,
    'ULAK': 0,
    'ULAM': 0,
    'ULAN': 0,
    'ULAND': 0,
    'ULANDAY': 0,
    'ULANDER': 0,
    'ULANOWSKI': 0,
    'ULANSKI': 0,
    'ULASZEK': 0,
    'ULATE': 0,
    'ULATOWSKI': 0,
    'ULBERG': 0,
    'ULBRICH': 0,
    'ULBRICHT': 0,
    'ULBRIGHT': 0,
    'ULCH': 0,
    'ULDRICH': 0,
    'ULDRICK': 0,
    'ULE': 0,
    'ULEN': 0,
    'ULEP': 0,
    'ULERICK': 0,
    'ULERIO': 0,
    'ULERY': 0,
    'ULETT': 0,
    'ULEWICZ': 0,
    'ULFERS': 0,
    'ULFERTS': 0,
    'ULFIG': 0,
    'ULI': 0,
    'ULIANA': 0,
    'ULIANO': 0,
    'ULIASZ': 0,
    'ULIBARRI': 0,
    'ULICH': 0,
    'ULICHNEY': 0,
    'ULICKI': 0,
    'ULICNY': 0,
    'ULIK': 0,
    'ULIN': 0,
    'ULINE': 0,
    'ULINSKI': 0,
    'ULIS': 0,
    'ULISHNEY': 0,
    'ULISSE': 0,
    'ULIZIO': 0,
    'ULLA': 0,
    'ULLAH': 0,
    'ULLAND': 0,
    'ULLE': 0,
    'ULLERICH': 0,
    'ULLERY': 0,
    'ULLIAN': 0,
    'ULLMAN': 0,
    'ULLMANN': 0,
    'ULLMER': 0,
    'ULLO': 0,
    'ULLOA': 0,
    'ULLOM': 0,
    'ULLREY': 0,
    'ULLRICH': 0,
    'ULLSPERGER': 0,
    'ULLSTROM': 0,
    'ULLUM': 0,
    'ULM': 0,
    'ULMAN': 0,
    'ULMEN': 0,
    'ULMER': 0,
    'ULMSCHNEIDER': 0,
    'ULNESS': 0,
    'ULOTH': 0,
    'ULREICH': 0,
    'ULREY': 0,
    'ULRICH': 0,
    'ULRICK': 0,
    'ULRICKSON': 0,
    'ULRIKE': 1,
    'ULRY': 0,
    'ULSES': 0,
    'ULSETH': 0,
    'ULSH': 0,
    'ULSHAFER': 0,
    'ULSTAD': 0,
    'ULTRERAS': 0,
    'ULTSCH': 0,
    'ULU': 0,
    'ULVEN': 0,
    'ULVESTAD': 0,
    'ULWELLING': 0,
    'ULYSSE': 0,
    'ULYSSES': 1,
    'UM': 0,
    'UMALI': 0,
    'UMAN': 0,
    'UMANA': 0,
    'UMANSKAYA': 0,
    'UMANSKY': 0,
    'UMANZOR': 0,
    'UMAR': 0,
    'UMAYAM': 0,
    'UMBACH': 0,
    'UMBARGER': 0,
    'UMBAUGH': 0,
    'UMBDENSTOCK': 0,
    'UMBEL': 0,
    'UMBENHAUER': 0,
    'UMBENHOWER': 0,
    'UMBER': 0,
    'UMBERGER': 0,
    'UMBLE': 0,
    'UMBREIT': 0,
    'UMBRELL': 0,
    'UMBRO': 0,
    'UMEDA': 0,
    'UMEH': 0,
    'UMEK': 0,
    'UMEMOTO': 0,
    'UMENTUM': 0,
    'UMER': 0,
    'UMETSU': 0,
    'UMFLEET': 0,
    'UMFRESS': 0,
    'UMHOEFER': 0,
    'UMHOLTZ': 0,
    'UMILE': 0,
    'UMINA': 0,
    'UMINSKI': 0,
    'UMIPIG': 0,
    'UMLAH': 0,
    'UMLAND': 0,
    'UMLAUF': 0,
    'UMLOR': 0,
    'UMMEL': 0,
    'UMNUS': 0,
    'UMOH': 0,
    'UMPHENOUR': 0,
    'UMPHLETT': 0,
    'UMPHRES': 0,
    'UMPHRESS': 0,
    'UMPHREY': 0,
    'UMPHRIES': 0,
    'UMPIERRE': 0,
    'UMPLEBY': 0,
    'UMRANI': 0,
    'UMSCHEID': 0,
    'UMSTATTD': 0,
    'UMSTEAD': 0,
    'UMSTED': 0,
    'UMSTOT': 0,
    'UN': 0.8333333333333334,
    'UNA': 1,
    'UNAL': 0,
    'UNANDER': 0,
    'UNANGST': 0,
    'UNAVAILABLE': 0,
    'UNBEHAGEN': 0,
    'UNBEHAUN': 0,
    'UNCAPHER': 0,
    'UNCIANO': 0,
    'UNCK': 0,
    'UNDA': 0,
    'UNDEM': 0,
    'UNDERBERG': 0,
    'UNDERBRINK': 0,
    'UNDERCOFFER': 0,
    'UNDERCUFFLER': 0,
    'UNDERDAHL': 0,
    'UNDERDOWN': 0,
    'UNDERDUE': 0,
    'UNDERHILL': 0,
    'UNDERKOFFLER': 0,
    'UNDERKOFLER': 0,
    'UNDERLAND': 0,
    'UNDERLY': 0,
    'UNDERWOOD': 0,
    'UNDLIN': 0,
    'UNERTL': 0,
    'UNFRIED': 0,
    'UNG': 0,
    'UNGA': 0,
    'UNGAR': 0,
    'UNGARD': 0,
    'UNGARO': 0,
    'UNGASHICK': 0,
    'UNGEMACH': 0,
    'UNGER': 0,
    'UNGERECHT': 0,
    'UNGERER': 0,
    'UNGERLEIDER': 0,
    'UNGERMAN': 0,
    'UNGLAUB': 0,
    'UNGLES': 0,
    'UNGLESBEE': 0,
    'UNGOS': 0,
    'UNGS': 0,
    'UNGUREANU': 0,
    'UNGVARSKY': 0,
    'UNIACKE': 0,
    'UNIATOWSKI': 0,
    'UNICE': 0,
    'UNICK': 0,
    'UNION': 0,
    'UNIS': 0,
    'UNK': 0,
    'UNKE': 0,
    'UNKEFER': 0,
    'UNKEL': 0,
    'UNKLE': 0,
    'UNKLESBAY': 0,
    'UNKRICH': 0,
    'UNLAND': 0,
    'UNNASCH': 0,
    'UNNERSTALL': 0,
    'UNNI': 0,
    'UNO': 0,
    'UNPINGCO': 0,
    'UNRATH': 0,
    'UNRAU': 0,
    'UNREIN': 0,
    'UNROE': 0,
    'UNRUE': 0,
    'UNRUH': 0,
    'UNSELD': 0,
    'UNSELL': 0,
    'UNSER': 0,
    'UNSETH': 0,
    'UNSICKER': 0,
    'UNSON': 0,
    'UNSWORTH': 0,
    'UNTALAN': 0,
    'UNTCH': 0,
    'UNTERBERG': 0,
    'UNTERBERGER': 0,
    'UNTERBORN': 0,
    'UNTERBRINK': 0,
    'UNTERMAN': 0,
    'UNTERMEYER': 0,
    'UNTERREINER': 0,
    'UNTERSEHER': 0,
    'UNTHANK': 0,
    'UNTI': 0,
    'UNTIED': 0,
    'UNTIEDT': 0,
    'UNTZ': 0,
    'UNUTOA': 0,
    'UNVERFERTH': 0,
    'UNVERZAGT': 0,
    'UNWIN': 0,
    'UNZEN': 0,
    'UNZICKER': 0,
    'UNZUETA': 0,
    'UONG': 0,
    'UPADHYAY': 0,
    'UPADHYAYA': 0,
    'UPAH': 0,
    'UPCHURCH': 0,
    'UPCRAFT': 0,
    'UPDEGRAFF': 0,
    'UPDEGRAVE': 0,
    'UPDEGROVE': 0,
    'UPDIKE': 0,
    'UPDYKE': 0,
    'UPEGUI': 0,
    'UPHAM': 0,
    'UPHAUS': 0,
    'UPHOFF': 0,
    'UPHOLD': 0,
    'UPHOUSE': 0,
    'UPHUS': 0,
    'UPJOHN': 0,
    'UPKINS': 0,
    'UPLEGER': 0,
    'UPLINGER': 0,
    'UPMAN': 0,
    'UPMEYER': 0,
    'UPOLE': 0,
    'UPP': 0,
    'UPPAL': 0,
    'UPPER': 0,
    'UPPERMAN': 0,
    'UPPINGHOUSE': 0,
    'UPPOLE': 0,
    'UPRIGHT': 0,
    'UPSHAW': 0,
    'UPSHER': 0,
    'UPSHUR': 0,
    'UPSON': 0,
    'UPTAGRAFFT': 0,
    'UPTAIN': 0,
    'UPTEGROVE': 0,
    'UPTERGROVE': 0,
    'UPTHEGROVE': 0,
    'UPTMOR': 0,
    'UPTMORE': 0,
    'UPTON': 0,
    'UQDAH': 0,
    'UR': 0,
    'URA': 0,
    'URABE': 0,
    'URAGA': 0,
    'URAL': 0,
    'URAM': 0,
    'URAN': 0,
    'URANGA': 0,
    'URANGO': 0,
    'URANKAR': 0,
    'URANO': 0,
    'URATA': 0,
    'URBA': 0,
    'URBACH': 0,
    'URBAEZ': 0,
    'URBAIN': 0,
    'URBALEJO': 0,
    'URBAN': 0,
    'URBANCIC': 0,
    'URBANCZYK': 0,
    'URBANEC': 0,
    'URBANEK': 0,
    'URBANI': 0,
    'URBANIAK': 0,
    'URBANIC': 0,
    'URBANIK': 0,
    'URBANK': 0,
    'URBANO': 0,
    'URBANOVSKY': 0,
    'URBANOWICZ': 0,
    'URBANOWSKI': 0,
    'URBANSKI': 0,
    'URBANSKY': 0,
    'URBANUS': 0,
    'URBANY': 0,
    'URBAS': 0,
    'URBAUER': 0,
    'URBAY': 0,
    'URBEN': 0,
    'URBICK': 0,
    'URBIETA': 0,
    'URBIN': 0,
    'URBINA': 0,
    'URBINATI': 0,
    'URBINE': 0,
    'URBINO': 0,
    'URBON': 0,
    'URBONAS': 0,
    'URCH': 0,
    'URCINO': 0,
    'URCIUOLI': 0,
    'URCUYO': 0,
    'URDA': 0,
    'URDAHL': 0,
    'URDANETA': 0,
    'URDANG': 0,
    'URDIALES': 0,
    'URDIALEZ': 0,
    'URE': 0,
    'URECHE': 0,
    'UREEL': 0,
    'URELL': 0,
    'UREMOVICH': 0,
    'UREN': 0,
    'URENA': 0,
    'URENDA': 0,
    'URENO': 0,
    'URESTE': 0,
    'URESTI': 0,
    'URETA': 0,
    'URETSKY': 0,
    'UREVIG': 0,
    'UREY': 0,
    'URFER': 0,
    'URFFER': 0,
    'URGELLES': 0,
    'URGILES': 0,
    'URGO': 0,
    'URI': 0,
    'URIA': 0,
    'URIAN': 0,
    'URIARTE': 0,
    'URIAS': 0,
    'URIBE': 0,
    'URIBES': 0,
    'URICCHIO': 0,
    'URICH': 0,
    'URICK': 0,
    'URIE': 0,
    'URIEGAS': 0,
    'URIEL': 0,
    'URIETA': 0,
    'URIG': 0,
    'URIOSTE': 0,
    'URIOSTEGUI': 0,
    'URISH': 0,
    'URISTA': 0,
    'URIVE': 0,
    'URIZAR': 0,
    'URLACHER': 0,
    'URLAUB': 0,
    'URLING': 0,
    'URMAN': 0,
    'URMANN': 0,
    'URMANSKI': 0,
    'URMSON': 0,
    'URMSTON': 0,
    'URNER': 0,
    'URNESS': 0,
    'UROZA': 0,
    'URQUHART': 0,
    'URQUIA': 0,
    'URQUIAGA': 0,
    'URQUIDES': 0,
    'URQUIDEZ': 0,
    'URQUIDI': 0,
    'URQUIETA': 0,
    'URQUIJO': 0,
    'URQUILLA': 0,
    'URQUIOLA': 0,
    'URQUIZA': 0,
    'URQUIZO': 0,
    'URQUIZU': 0,
    'URRA': 0,
    'URRABAZO': 0,
    'URREA': 0,
    'URREGO': 0,
    'URRIETA': 0,
    'URROZ': 0,
    'URRUTIA': 0,
    'URRY': 0,
    'URSCHEL': 0,
    'URSERY': 0,
    'URSIC': 0,
    'URSICH': 0,
    'URSILLO': 0,
    'URSIN': 0,
    'URSINI': 0,
    'URSINO': 0,
    'URSITTI': 0,
    'URSO': 0,
    'URSPRUNG': 0,
    'URSU': 0,
    'URSUA': 0,
    'URSULA': 1,
    'URTADO': 0,
    'URTEAGA': 0,
    'URTECHO': 0,
    'URTEL': 0,
    'URTIAGA': 0,
    'URTIZ': 0,
    'URTON': 0,
    'URTZ': 0,
    'URUCHIMA': 0,
    'URUETA': 0,
    'URVINA': 0,
    'URWILER': 0,
    'URWILLER': 0,
    'URWIN': 0,
    'URY': 0,
    'URYGA': 0,
    'URZUA': 0,
    'US': 0,
    'USCANGA': 0,
    'USCHOLD': 0,
    'USE': 0,
    'USECHE': 0,
    'USEDA': 0,
    'USELDING': 0,
    'USELMAN': 0,
    'USELTON': 0,
    'USERA': 0,
    'USERY': 0,
    'USEY': 0,
    'USHA': 1,
    'USHER': 0,
    'USHERWOOD': 0,
    'USHERY': 0,
    'USHIJIMA': 0,
    'USHMAN': 0,
    'USI': 0,
    'USIAK': 0,
    'USIE': 0,
    'USILTON': 0,
    'USINA': 0,
    'USINGER': 0,
    'USITALO': 0,
    'USKO': 0,
    'USKOSKI': 0,
    'USLAN': 0,
    'USMAN': 0,
    'USMANI': 0,
    'USNER': 0,
    'USON': 0,
    'USREY': 0,
    'USRY': 0,
    'USS': 0,
    'USSELMAN': 0,
    'USSERY': 0,
    'USSIN': 0,
    'UST': 0,
    'USTASZEWSKI': 0,
    'USTICK': 0,
    'USUI': 0,
    'UTE': 0.9615384615384616,
    'UTECH': 0,
    'UTECHT': 0,
    'UTEGG': 0,
    'UTER': 0,
    'UTESCH': 0,
    'UTH': 0,
    'UTHE': 0,
    'UTHMAN': 0,
    'UTHOFF': 0,
    'UTKE': 0,
    'UTLEY': 0,
    'UTNE': 0,
    'UTO': 0,
    'UTRERA': 0,
    'UTRUP': 0,
    'UTSCH': 0,
    'UTSCHIG': 0,
    'UTSEY': 0,
    'UTSINGER': 0,
    'UTSLER': 0,
    'UTSMAN': 0,
    'UTSUMI': 0,
    'UTT': 0,
    'UTTARO': 0,
    'UTTECH': 0,
    'UTTECHT': 0,
    'UTTER': 0,
    'UTTERBACK': 0,
    'UTTING': 0,
    'UTTKE': 0,
    'UTTLEY': 0,
    'UTTON': 0,
    'UTU': 0,
    'UTZ': 0,
    'UTZIG': 0,
    'UTZINGER': 0,
    'UTZMAN': 0,
    'UU': 0,
    'UVA': 0,
    'UVALLE': 0,
    'UVAYDOV': 0,
    'UVEGES': 0,
    'UWANAWICH': 0,
    'UY': 0,
    'UYEDA': 0,
    'UYEHARA': 0,
    'UYEMA': 0,
    'UYEMATSU': 0,
    'UYEMURA': 0,
    'UYENO': 0,
    'UYESUGI': 0,
    'UZAR': 0,
    'UZARSKI': 0,
    'UZCATEGUI': 0,
    'UZEE': 0,
    'UZEL': 0,
    'UZELAC': 0,
    'UZETA': 0,
    'UZHCA': 0,
    'UZIEL': 0,
    'UZOMA': 0,
    'UZUETA': 0,
    'UZUN': 0,
    'UZZEL': 0,
    'UZZELL': 0,
    'UZZI': 0,
    'UZZLE': 0,
    'UZZO': 0,
    'VAA': 0,
    'VAAGE': 0,
    'VAAGEN': 0,
    'VAAL': 0,
    'VAALER': 0,
    'VAAS': 0,
    'VAASSEN': 0,
    'VACA': 0,
    'VACANTE': 0,
    'VACANTI': 0,
    'VACCA': 0,
    'VACCARELLA': 0,
    'VACCARELLI': 0,
    'VACCARELLO': 0,
    'VACCAREZZA': 0,
    'VACCARI': 0,
    'VACCARIELLO': 0,
    'VACCARINO': 0,
    'VACCARO': 0,
    'VACCHIANO': 0,
    'VACCHIO': 0,
    'VACCO': 0,
    'VACEK': 0,
    'VACH': 0,
    'VACHA': 0,
    'VACHAL': 0,
    'VACHE': 0,
    'VACHER': 0,
    'VACHHANI': 0,
    'VACHON': 0,
    'VACIO': 0,
    'VACIRCA': 0,
    'VACKAR': 0,
    'VACLAVIK': 0,
    'VACQUEZ': 0,
    'VACTOR': 0,
    'VACULA': 0,
    'VACULIK': 0,
    'VACURA': 0,
    'VADA': 1,
    'VADAKIN': 0,
    'VADALA': 0,
    'VADAS': 0,
    'VADASZ': 0,
    'VADEBONCOEUR': 0,
    'VADELL': 0,
    'VADEN': 0,
    'VADENAIS': 0,
    'VADER': 0,
    'VADI': 0,
    'VADILLO': 0,
    'VADINO': 0,
    'VADLAMUDI': 0,
    'VADNAIS': 0,
    'VADNER': 0,
    'VADNEY': 0,
    'VADO': 0,
    'VAESSEN': 0,
    'VAETH': 0,
    'VAEZ': 0,
    'VAFIADIS': 0,
    'VAGA': 0,
    'VAGAS': 0,
    'VAGEDES': 0,
    'VAGENAS': 0,
    'VAGHELA': 0,
    'VAGLE': 0,
    'VAGLICA': 0,
    'VAGLIENTY': 0,
    'VAGNER': 0,
    'VAGNINI': 0,
    'VAGNONE': 0,
    'VAGNONI': 0,
    'VAGNOZZI': 0,
    'VAGO': 0,
    'VAGT': 0,
    'VAGTS': 0,
    'VAGUE': 0,
    'VAH': 0,
    'VAHALIK': 0,
    'VAHDAT': 0,
    'VAHEY': 0,
    'VAHID': 0,
    'VAHL': 0,
    'VAHLE': 0,
    'VAHLING': 0,
    'VAHLKAMP': 0,
    'VAHORA': 0,
    'VAHSHOLTZ': 0,
    'VAI': 0,
    'VAIA': 0,
    'VAIANA': 0,
    'VAID': 0,
    'VAIDA': 0,
    'VAIDEN': 0,
    'VAIDEZ': 0,
    'VAIDYA': 0,
    'VAIDYANATHAN': 0,
    'VAIL': 0,
    'VAILE': 0,
    'VAILES': 0,
    'VAILL': 0,
    'VAILLANCOURT': 0,
    'VAILLANT': 0,
    'VAILLETTE': 0,
    'VAILS': 0,
    'VAIN': 0,
    'VAINE': 0,
    'VAINER': 0,
    'VAIR': 0,
    'VAIRA': 0,
    'VAIRO': 0,
    'VAIS': 0,
    'VAISHNAV': 0,
    'VAISMAN': 0,
    'VAITH': 0,
    'VAITKUS': 0,
    'VAIZ': 0,
    'VAJDA': 0,
    'VAJGRT': 0,
    'VAKA': 0,
    'VAKHARIA': 0,
    'VAKIL': 0,
    'VAKILI': 0,
    'VAKNIN': 0,
    'VAKOC': 0,
    'VAKS': 0,
    'VAL': 0.9708737864077669,
    'VALA': 0,
    'VALACH': 0,
    'VALACHOVIC': 0,
    'VALADAO': 0,
    'VALADARES': 0,
    'VALADE': 0,
    'VALADES': 0,
    'VALADEZ': 0,
    'VALAITIS': 0,
    'VALANCE': 0,
    'VALANDINGHAM': 0,
    'VALANDRA': 0,
    'VALANT': 0,
    'VALANTINE': 0,
    'VALANZOLA': 0,
    'VALAREZO': 0,
    'VALARIE': 1,
    'VALAS': 0,
    'VALASCO': 0,
    'VALASEK': 0,
    'VALASTRO': 0,
    'VALAVANIS': 0,
    'VALAZQUEZ': 0,
    'VALBRUN': 0,
    'VALBUENA': 0,
    'VALCARCE': 0,
    'VALCARCEL': 0,
    'VALCHAR': 0,
    'VALCICH': 0,
    'VALCIN': 0,
    'VALCO': 0,
    'VALCOUR': 0,
    'VALCOURT': 0,
    'VALDA': 1,
    'VALDE': 0,
    'VALDELAMAR': 0,
    'VALDEMAR': 0,
    'VALDENEGRO': 0,
    'VALDEPENA': 0,
    'VALDER': 0,
    'VALDERA': 0,
    'VALDERAMA': 0,
    'VALDERAS': 0,
    'VALDERRAMA': 0,
    'VALDES': 0,
    'VALDESPINO': 0,
    'VALDEZ': 0,
    'VALDILLEZ': 0,
    'VALDIVIA': 0,
    'VALDIVIAS': 0,
    'VALDIVIESO': 0,
    'VALDIVIEZ': 0,
    'VALDIVIEZO': 0,
    'VALDO': 0,
    'VALDOVINO': 0,
    'VALDOVINOS': 0,
    'VALE': 0,
    'VALEGA': 0,
    'VALEK': 0,
    'VALEN': 0,
    'VALENA': 0,
    'VALENCA': 0,
    'VALENCE': 0,
    'VALENCIA': 0.24449877750611249,
    'VALENCIANA': 0,
    'VALENCIAND': 0,
    'VALENCIANO': 0,
    'VALENCIC': 0,
    'VALENCOURT': 0,
    'VALENE': 1,
    'VALENSUELA': 0,
    'VALENT': 0,
    'VALENTA': 0,
    'VALENTE': 0,
    'VALENTI': 0,
    'VALENTIC': 0,
    'VALENTICH': 0,
    'VALENTIM': 0,
    'VALENTIN': 0.5617977528089888,
    'VALENTINA': 0.992063492063492,
    'VALENTINE': 0.30060120240480964,
    'VALENTINI': 0,
    'VALENTINO': 0,
    'VALENTO': 0,
    'VALENTOUR': 0,
    'VALENTY': 0,
    'VALENZA': 0,
    'VALENZANO': 0,
    'VALENZIA': 0,
    'VALENZIANO': 0,
    'VALENZO': 0,
    'VALENZUELA': 0,
    'VALEO': 0,
    'VALER': 0,
    'VALERA': 0,
    'VALERDI': 0,
    'VALERE': 0,
    'VALERI': 0.7299270072992701,
    'VALERIA': 0.9945750452079566,
    'VALERIAN': 0,
    'VALERIAND': 0,
    'VALERIANI': 0,
    'VALERIANO': 0,
    'VALERIE': 0.9992622895848703,
    'VALERINO': 0,
    'VALERIO': 0,
    'VALERIUS': 0,
    'VALERO': 0,
    'VALEROS': 0,
    'VALERY': 0.9345794392523364,
    'VALES': 0,
    'VALESANO': 0,
    'VALESKI': 0,
    'VALESKY': 0,
    'VALESQUEZ': 0,
    'VALET': 0,
    'VALETIN': 0,
    'VALETINE': 0,
    'VALETTE': 0,
    'VALI': 0,
    'VALIANI': 0,
    'VALIANT': 0,
    'VALIANTE': 0,
    'VALICENTI': 0,
    'VALIDO': 0,
    'VALIENTE': 0,
    'VALIER': 0,
    'VALIGA': 0,
    'VALIGURA': 0,
    'VALIMONT': 0,
    'VALIN': 0,
    'VALINE': 0,
    'VALINO': 0,
    'VALINOTI': 0,
    'VALINSKI': 0,
    'VALINSKY': 0,
    'VALINTINE': 0,
    'VALIQUETTE': 0,
    'VALIS': 0,
    'VALITON': 0,
    'VALK': 0,
    'VALKEMA': 0,
    'VALKENBURG': 0,
    'VALKER': 0,
    'VALKO': 0,
    'VALL': 0,
    'VALLA': 0,
    'VALLABHANENI': 0,
    'VALLAD': 0,
    'VALLADAO': 0,
    'VALLADARES': 0,
    'VALLADAREZ': 0,
    'VALLADE': 0,
    'VALLADO': 0,
    'VALLADOLID': 0,
    'VALLAIRE': 0,
    'VALLANCE': 0,
    'VALLANDINGHAM': 0,
    'VALLANTE': 0,
    'VALLAR': 0,
    'VALLARINO': 0,
    'VALLARIO': 0,
    'VALLARTA': 0,
    'VALLAS': 0,
    'VALLE': 0,
    'VALLEAU': 0,
    'VALLECILLO': 0,
    'VALLECORSA': 0,
    'VALLEDOR': 0,
    'VALLEE': 0,
    'VALLEGO': 0,
    'VALLEJO': 0,
    'VALLEJOS': 0,
    'VALLELUNGA': 0,
    'VALLELY': 0,
    'VALLEN': 0,
    'VALLENTE': 0,
    'VALLENTINE': 0,
    'VALLER': 0,
    'VALLERA': 0,
    'VALLERAND': 0,
    'VALLERGA': 0,
    'VALLERO': 0,
    'VALLEROY': 0,
    'VALLERY': 0,
    'VALLES': 0,
    'VALLESE': 0,
    'VALLESKEY': 0,
    'VALLESTEROS': 0,
    'VALLET': 0,
    'VALLETT': 0,
    'VALLETTA': 0,
    'VALLETTE': 0,
    'VALLEY': 0,
    'VALLEZ': 0,
    'VALLI': 0,
    'VALLIAN': 0,
    'VALLIANT': 0,
    'VALLIE': 0.9302325581395349,
    'VALLIER': 0,
    'VALLIERE': 0,
    'VALLIERES': 0,
    'VALLILLO': 0,
    'VALLIMONT': 0,
    'VALLIN': 0,
    'VALLINA': 0,
    'VALLIS': 0,
    'VALLO': 0,
    'VALLON': 0,
    'VALLONE': 0,
    'VALLOT': 0,
    'VALLOTTON': 0,
    'VALLOW': 0,
    'VALLS': 0,
    'VALLUZZI': 0,
    'VALME': 0,
    'VALMOJA': 0,
    'VALMONT': 0,
    'VALMONTE': 0,
    'VALMORES': 0,
    'VALO': 0,
    'VALOIS': 0,
    'VALONE': 0,
    'VALOR': 0,
    'VALORA': 0,
    'VALORE': 0,
    'VALORIE': 1,
    'VALOROSO': 0,
    'VALOS': 0,
    'VALOT': 0,
    'VALOY': 0,
    'VALPEY': 0,
    'VALQUEZ': 0,
    'VALRIE': 0.9345794392523364,
    'VALSAMIS': 0,
    'VALTIERRA': 0,
    'VALTIERREZ': 0,
    'VALTIN': 0,
    'VALURE': 0,
    'VALUSEK': 0,
    'VALVA': 0,
    'VALVANO': 0,
    'VALVERDE': 0,
    'VALVO': 0,
    'VALVODA': 0,
    'VALYO': 0,
    'VALYOU': 0,
    'VALZ': 0,
    'VAMOS': 0,
    'VAN': 0.8255159474671669,
    'VANA': 0,
    'VANABEL': 0,
    'VANACKER': 0,
    'VANACKEREN': 0,
    'VANACORE': 0,
    'VANADIA': 0,
    'VANAERNAM': 0,
    'VANAGS': 0,
    'VANAKEN': 0,
    'VANALLEN': 0,
    'VANALLSBURG': 0,
    'VANALPHEN': 0,
    'VANALST': 0,
    'VANALSTINE': 0,
    'VANALSTYNE': 0,
    'VANAMAN': 0,
    'VANAMBURG': 0,
    'VANAMBURGH': 0,
    'VANAMERONGEN': 0,
    'VANANDA': 0,
    'VANANDEL': 0,
    'VANANTWERP': 0,
    'VANANTWERPEN': 0,
    'VANARIA': 0,
    'VANARK': 0,
    'VANARKEL': 0,
    'VANARMAN': 0,
    'VANARNAM': 0,
    'VANARSDALE': 0,
    'VANARSDALEN': 0,
    'VANARSDALL': 0,
    'VANARSDEL': 0,
    'VANARSDELL': 0,
    'VANARTSDALEN': 0,
    'VANAS': 0,
    'VANASCH': 0,
    'VANASCO': 0,
    'VANASDALE': 0,
    'VANASPEREN': 0,
    'VANASSCHE': 0,
    'VANASSE': 0,
    'VANASTEN': 0,
    'VANATTA': 0,
    'VANATTER': 0,
    'VANATTI': 0,
    'VANAUKEN': 0,
    'VANAUKER': 0,
    'VANAUSDAL': 0,
    'VANAUSDALL': 0,
    'VANAUSDOLL': 0,
    'VANAVERY': 0,
    'VANBAALEN': 0,
    'VANBALEN': 0,
    'VANBAREN': 0,
    'VANBEBBER': 0,
    'VANBEBER': 0,
    'VANBECELAERE': 0,
    'VANBECK': 0,
    'VANBEEK': 0,
    'VANBELKUM': 0,
    'VANBELLE': 0,
    'VANBEMMEL': 0,
    'VANBENSCHOTEN': 0,
    'VANBENTHUYSEN': 0,
    'VANBERG': 0,
    'VANBERGEN': 0,
    'VANBERKEL': 0,
    'VANBERKOM': 0,
    'VANBERKUM': 0,
    'VANBEUSEKOM': 0,
    'VANBEVER': 0,
    'VANBEVEREN': 0,
    'VANBIBBER': 0,
    'VANBILLIARD': 0,
    'VANBLARCOM': 0,
    'VANBLARCUM': 0,
    'VANBLARGAN': 0,
    'VANBLARICOM': 0,
    'VANBLARICUM': 0,
    'VANBOCKERN': 0,
    'VANBOENING': 0,
    'VANBOOVEN': 0,
    'VANBOURGONDIEN': 0,
    'VANBOVEN': 0,
    'VANBOXEL': 0,
    'VANBOXTEL': 0,
    'VANBRACKLE': 0,
    'VANBRAKLE': 0,
    'VANBRAMER': 0,
    'VANBREE': 0,
    'VANBRIESEN': 0,
    'VANBRIGGLE': 0,
    'VANBROCKLIN': 0,
    'VANBRUGGEN': 0,
    'VANBRUNT': 0,
    'VANBUHLER': 0,
    'VANBUREN': 0,
    'VANBURKLEO': 0,
    'VANBUSKIRK': 0,
    'VANCAMP': 0,
    'VANCAMPEN': 0,
    'VANCAMPENHOUT': 0,
    'VANCASTER': 0,
    'VANCE': 0.45219638242894056,
    'VANCEL': 0,
    'VANCHERI': 0,
    'VANCHIERI': 0,
    'VANCIL': 0,
    'VANCISE': 0,
    'VANCLEAF': 0,
    'VANCLEAVE': 0,
    'VANCLEEF': 0,
    'VANCLEVE': 0,
    'VANCLIEF': 0,
    'VANCO': 0,
    'VANCOL': 0,
    'VANCONANT': 0,
    'VANCOPPENOLLE': 0,
    'VANCOR': 0,
    'VANCOTT': 0,
    'VANCOUR': 0,
    'VANCOURT': 0,
    'VANCURA': 0,
    'VANCUREN': 0,
    'VANCURLER': 0,
    'VAND': 0,
    'VANDA': 0.966183574879227,
    'VANDAELE': 0,
    'VANDAGRIFF': 0,
    'VANDAL': 0,
    'VANDALE': 0,
    'VANDALEN': 0,
    'VANDALL': 0,
    'VANDALSEM': 0,
    'VANDALSEN': 0,
    'VANDAM': 0,
    'VANDAME': 0,
    'VANDAMENT': 0,
    'VANDAMME': 0,
    'VANDAVEER': 0,
    'VANDE': 0,
    'VANDEBERG': 0,
    'VANDEBERGHE': 0,
    'VANDEBOGART': 0,
    'VANDEBRAKE': 0,
    'VANDEBUNTE': 0,
    'VANDEBURG': 0,
    'VANDECAR': 0,
    'VANDECOEVERING': 0,
    'VANDEE': 0,
    'VANDEEST': 0,
    'VANDEGRAAF': 0,
    'VANDEGRAFT': 0,
    'VANDEGRIEND': 0,
    'VANDEGRIFF': 0,
    'VANDEGRIFT': 0,
    'VANDEGUCHTE': 0,
    'VANDEHEI': 0,
    'VANDEHEY': 0,
    'VANDEHOEF': 0,
    'VANDEKAMP': 0,
    'VANDEKIEFT': 0,
    'VANDEKOP': 0,
    'VANDEKROL': 0,
    'VANDEL': 0,
    'VANDELDEN': 0,
    'VANDELINDE': 0,
    'VANDELINDER': 0,
    'VANDELL': 0,
    'VANDELLEN': 0,
    'VANDELOO': 0,
    'VANDELUNE': 0,
    'VANDEMAN': 0,
    'VANDEMARK': 0,
    'VANDEMERWE': 0,
    'VANDEMORE': 0,
    'VANDEMORTEL': 0,
    'VANDEN': 0,
    'VANDENACK': 0,
    'VANDENAKKER': 0,
    'VANDENAVOND': 0,
    'VANDENBARK': 0,
    'VANDENBERG': 0,
    'VANDENBERGE': 0,
    'VANDENBERGH': 0,
    'VANDENBERGHE': 0,
    'VANDENBOOM': 0,
    'VANDENBOS': 0,
    'VANDENBOSCH': 0,
    'VANDENBOSS': 0,
    'VANDENBOSSCHE': 0,
    'VANDENBRANDEN': 0,
    'VANDENBRINK': 0,
    'VANDENBROECK': 0,
    'VANDENBROEK': 0,
    'VANDENBROEKE': 0,
    'VANDENBROOK': 0,
    'VANDENBURG': 0,
    'VANDENBURGH': 0,
    'VANDENBUSCH': 0,
    'VANDENBUSH': 0,
    'VANDENBUSSCHE': 0,
    'VANDENDRIESSCHE': 0,
    'VANDENEINDE': 0,
    'VANDENELZEN': 0,
    'VANDENHEUVEL': 0,
    'VANDENHOEK': 0,
    'VANDENHOUTEN': 0,
    'VANDENLANGENBER': 0,
    'VANDENOEVER': 0,
    'VANDENPLAS': 0,
    'VANDENTOORN': 0,
    'VANDENTOP': 0,
    'VANDEPOL': 0,
    'VANDEPUTTE': 0,
    'VANDER': 0,
    'VANDERAA': 0,
    'VANDERARK': 0,
    'VANDERBAAN': 0,
    'VANDERBECK': 0,
    'VANDERBEEK': 0,
    'VANDERBERG': 0,
    'VANDERBILT': 0,
    'VANDERBLOEMEN': 0,
    'VANDERBOEGH': 0,
    'VANDERBOGART': 0,
    'VANDERBOOM': 0,
    'VANDERBOSCH': 0,
    'VANDERBRINK': 0,
    'VANDERBROEK': 0,
    'VANDERBROOK': 0,
    'VANDERBUR': 0,
    'VANDERBURG': 0,
    'VANDERBURGH': 0,
    'VANDERBUSH': 0,
    'VANDERCAR': 0,
    'VANDERCOOK': 0,
    'VANDERDOES': 0,
    'VANDERDUSSEN': 0,
    'VANDEREN': 0,
    'VANDERFORD': 0,
    'VANDERGALIEN': 0,
    'VANDERGEEST': 0,
    'VANDERGIESSEN': 0,
    'VANDERGRIEND': 0,
    'VANDERGRIFF': 0,
    'VANDERGRIFT': 0,
    'VANDERHAAR': 0,
    'VANDERHAGEN': 0,
    'VANDERHALL': 0,
    'VANDERHAM': 0,
    'VANDERHART': 0,
    'VANDERHEI': 0,
    'VANDERHEIDE': 0,
    'VANDERHEIDEN': 0,
    'VANDERHEYDEN': 0,
    'VANDERHILL': 0,
    'VANDERHOEF': 0,
    'VANDERHOEK': 0,
    'VANDERHOEVEN': 0,
    'VANDERHOFF': 0,
    'VANDERHOOF': 0,
    'VANDERHORN': 0,
    'VANDERHORST': 0,
    'VANDERHULST': 0,
    'VANDERHYDE': 0,
    'VANDERHYDEN': 0,
    'VANDERIET': 0,
    'VANDERJAGT': 0,
    'VANDERKAMP': 0,
    'VANDERKARR': 0,
    'VANDERKELEN': 0,
    'VANDERKIN': 0,
    'VANDERKLOK': 0,
    'VANDERKOLK': 0,
    'VANDERKOOI': 0,
    'VANDERKOOY': 0,
    'VANDERLAAN': 0,
    'VANDERLEE': 0,
    'VANDERLEEST': 0,
    'VANDERLEY': 0,
    'VANDERLICK': 0,
    'VANDERLIN': 0,
    'VANDERLIND': 0,
    'VANDERLINDE': 0,
    'VANDERLINDEN': 0,
    'VANDERLIP': 0,
    'VANDERLOO': 0,
    'VANDERLOOP': 0,
    'VANDERLUGT': 0,
    'VANDERMAAS': 0,
    'VANDERMARK': 0,
    'VANDERMAUSE': 0,
    'VANDERMAY': 0,
    'VANDERMEER': 0,
    'VANDERMERWE': 0,
    'VANDERMEULEN': 0,
    'VANDERMEY': 0,
    'VANDERMEYDEN': 0,
    'VANDERMOLEN': 0,
    'VANDERMYDE': 0,
    'VANDERNOOT': 0,
    'VANDEROSTYNE': 0,
    'VANDERPAS': 0,
    'VANDERPLAATS': 0,
    'VANDERPLAS': 0,
    'VANDERPLOEG': 0,
    'VANDERPLUYM': 0,
    'VANDERPOEL': 0,
    'VANDERPOL': 0,
    'VANDERPOOL': 0,
    'VANDERPUTTEN': 0,
    'VANDERROEST': 0,
    'VANDERSALL': 0,
    'VANDERSANDEN': 0,
    'VANDERSCHAAF': 0,
    'VANDERSCHUUR': 0,
    'VANDERSLICE': 0,
    'VANDERSLIK': 0,
    'VANDERSLOOT': 0,
    'VANDERSLUIS': 0,
    'VANDERSNICK': 0,
    'VANDERSON': 0,
    'VANDERSTEEN': 0,
    'VANDERSTEL': 0,
    'VANDERSTELT': 0,
    'VANDERSTOEP': 0,
    'VANDERTIE': 0,
    'VANDERTUIG': 0,
    'VANDERTUIN': 0,
    'VANDERVALK': 0,
    'VANDERVEEN': 0,
    'VANDERVEER': 0,
    'VANDERVEGT': 0,
    'VANDERVELDE': 0,
    'VANDERVELDEN': 0,
    'VANDERVEN': 0,
    'VANDERVENNET': 0,
    'VANDERVER': 0,
    'VANDERVEST': 0,
    'VANDERVEUR': 0,
    'VANDERVLIET': 0,
    'VANDERVOORT': 0,
    'VANDERVORST': 0,
    'VANDERVORT': 0,
    'VANDERWAAL': 0,
    'VANDERWAL': 0,
    'VANDERWALKER': 0,
    'VANDERWALL': 0,
    'VANDERWARKER': 0,
    'VANDERWATER': 0,
    'VANDERWEELE': 0,
    'VANDERWEGE': 0,
    'VANDERWEIDE': 0,
    'VANDERWEIT': 0,
    'VANDERWEL': 0,
    'VANDERWENDE': 0,
    'VANDERWERF': 0,
    'VANDERWERFF': 0,
    'VANDERWERKEN': 0,
    'VANDERWERKER': 0,
    'VANDERWEST': 0,
    'VANDERWEY': 0,
    'VANDERWIEL': 0,
    'VANDERWIELE': 0,
    'VANDERWIELEN': 0,
    'VANDERWILT': 0,
    'VANDERWOOD': 0,
    'VANDERWOUDE': 0,
    'VANDERWYST': 0,
    'VANDERYACHT': 0,
    'VANDERZANDEN': 0,
    'VANDERZEE': 0,
    'VANDERZIEL': 0,
    'VANDERZWAAG': 0,
    'VANDESANDE': 0,
    'VANDESLUNT': 0,
    'VANDESTEEG': 0,
    'VANDESTREEK': 0,
    'VANDETTA': 0,
    'VANDETTE': 0,
    'VANDEURSEN': 0,
    'VANDEURZEN': 0,
    'VANDEUSEN': 0,
    'VANDEVANDER': 0,
    'VANDEVANTER': 0,
    'VANDEVEER': 0,
    'VANDEVEGTE': 0,
    'VANDEVEIRE': 0,
    'VANDEVELDE': 0,
    'VANDEVEN': 0,
    'VANDEVENDER': 0,
    'VANDEVENTER': 0,
    'VANDEVER': 0,
    'VANDEVERE': 0,
    'VANDEVOORDE': 0,
    'VANDEVOORT': 0,
    'VANDEVORT': 0,
    'VANDEVUSSE': 0,
    'VANDEWALKER': 0,
    'VANDEWALL': 0,
    'VANDEWALLE': 0,
    'VANDEWARK': 0,
    'VANDEWARKER': 0,
    'VANDEWATER': 0,
    'VANDEWEERD': 0,
    'VANDEWEERT': 0,
    'VANDEWEGE': 0,
    'VANDEWEGHE': 0,
    'VANDEWETTERING': 0,
    'VANDEWIELE': 0,
    'VANDEWOESTYNE': 0,
    'VANDEYACHT': 0,
    'VANDEZANDE': 0,
    'VANDIEN': 0,
    'VANDIEPEN': 0,
    'VANDIEST': 0,
    'VANDIFORD': 0,
    'VANDIJK': 0,
    'VANDIKE': 0,
    'VANDILLEN': 0,
    'VANDINE': 0,
    'VANDINTER': 0,
    'VANDIVER': 0,
    'VANDIVIER': 0,
    'VANDIVNER': 0,
    'VANDIVORT': 0,
    'VANDOLAH': 0,
    'VANDOMELEN': 0,
    'VANDOMMELEN': 0,
    'VANDONGE': 0,
    'VANDONGEN': 0,
    'VANDONKELAAR': 0,
    'VANDONSEL': 0,
    'VANDONSELAAR': 0,
    'VANDOORN': 0,
    'VANDOORNE': 0,
    'VANDORAN': 0,
    'VANDOREN': 0,
    'VANDORN': 0,
    'VANDORP': 0,
    'VANDORPE': 0,
    'VANDORSTEN': 0,
    'VANDORT': 0,
    'VANDOVER': 0,
    'VANDRE': 0,
    'VANDREEL': 0,
    'VANDRESAR': 0,
    'VANDREW': 0,
    'VANDRIE': 0,
    'VANDRIEL': 0,
    'VANDRIESSCHE': 0,
    'VANDRIMMELEN': 0,
    'VANDROSS': 0,
    'VANDRUFF': 0,
    'VANDRUNEN': 0,
    'VANDUINE': 0,
    'VANDUINEN': 0,
    'VANDUNK': 0,
    'VANDUREN': 0,
    'VANDURME': 0,
    'VANDUSEN': 0,
    'VANDUSER': 0,
    'VANDUSSELDORP': 0,
    'VANDUSSEN': 0,
    'VANDUYN': 0,
    'VANDUYNE': 0,
    'VANDUZEE': 0,
    'VANDUZER': 0,
    'VANDY': 0,
    'VANDYCK': 0,
    'VANDYGRIFF': 0,
    'VANDYK': 0,
    'VANDYKE': 0,
    'VANDYKEN': 0,
    'VANDYNE': 0,
    'VANDYNHOVEN': 0,
    'VANE': 0,
    'VANEATON': 0,
    'VANECEK': 0,
    'VANECK': 0,
    'VANEE': 0,
    'VANEERDEN': 0,
    'VANEGAS': 0,
    'VANEGDOM': 0,
    'VANEGEREN': 0,
    'VANEGMOND': 0,
    'VANEK': 0,
    'VANELLA': 0,
    'VANELLI': 0,
    'VANELLS': 0,
    'VANEMAN': 0,
    'VANEMBURGH': 0,
    'VANEMMERIK': 0,
    'VANEMON': 0,
    'VANENGEN': 0,
    'VANENKEVORT': 0,
    'VANEPEREN': 0,
    'VANEPPS': 0,
    'VANEPS': 0,
    'VANEREM': 0,
    'VANERP': 0,
    'VANERT': 0,
    'VANES': 0,
    'VANESA': 1,
    'VANESS': 0,
    'VANESSA': 1,
    'VANESSEN': 0,
    'VANESSENDELFT': 0,
    'VANEST': 0,
    'VANETTA': 0.9259259259259258,
    'VANETTEN': 0,
    'VANETTI': 0,
    'VANEVENHOVEN': 0,
    'VANEVERA': 0,
    'VANEVERY': 0,
    'VANEYCK': 0,
    'VANEYK': 0,
    'VANFLEET': 0,
    'VANFLETEREN': 0,
    'VANFOSSAN': 0,
    'VANFOSSEN': 0,
    'VANFOSSON': 0,
    'VANG': 0,
    'VANGALDER': 0,
    'VANGAS': 0,
    'VANGEL': 0,
    'VANGELDER': 0,
    'VANGELDEREN': 0,
    'VANGELI': 0,
    'VANGEMERT': 0,
    'VANGEN': 0,
    'VANGENDEREN': 0,
    'VANGENNIP': 0,
    'VANGENT': 0,
    'VANGERPEN': 0,
    'VANGESSEL': 0,
    'VANGHEEM': 0,
    'VANGIESEN': 0,
    'VANGIESON': 0,
    'VANGILDER': 0,
    'VANGINKEL': 0,
    'VANGLAHN': 0,
    'VANGOETHEM': 0,
    'VANGOMPEL': 0,
    'VANGOOR': 0,
    'VANGORDEN': 0,
    'VANGORDER': 0,
    'VANGORDON': 0,
    'VANGORKOM': 0,
    'VANGORP': 0,
    'VANGOSEN': 0,
    'VANGRINSVEN': 0,
    'VANGROLL': 0,
    'VANGRONINGEN': 0,
    'VANGROUW': 0,
    'VANGSNESS': 0,
    'VANGUILDER': 0,
    'VANGUNDY': 0,
    'VANHAAFTEN': 0,
    'VANHAAREN': 0,
    'VANHAGEN': 0,
    'VANHAITSMA': 0,
    'VANHAL': 0,
    'VANHALL': 0,
    'VANHAM': 0,
    'VANHANDEL': 0,
    'VANHAREN': 0,
    'VANHARN': 0,
    'VANHART': 0,
    'VANHASSEL': 0,
    'VANHATTEN': 0,
    'VANHAUEN': 0,
    'VANHAVERBEKE': 0,
    'VANHECK': 0,
    'VANHECKE': 0,
    'VANHEE': 0,
    'VANHEEL': 0,
    'VANHEES': 0,
    'VANHEEST': 0,
    'VANHELDEN': 0,
    'VANHEMERT': 0,
    'VANHEUKLON': 0,
    'VANHEUSEN': 0,
    'VANHEYNINGEN': 0,
    'VANHILL': 0,
    'VANHISE': 0,
    'VANHOECKE': 0,
    'VANHOEK': 0,
    'VANHOESEN': 0,
    'VANHOFF': 0,
    'VANHOFWEGEN': 0,
    'VANHOLLAND': 0,
    'VANHOLLEBEKE': 0,
    'VANHOLT': 0,
    'VANHOOF': 0,
    'VANHOOK': 0,
    'VANHOOREBEKE': 0,
    'VANHOORN': 0,
    'VANHOOSE': 0,
    'VANHOOSEN': 0,
    'VANHOOSER': 0,
    'VANHOOSIER': 0,
    'VANHOOZER': 0,
    'VANHOOZIER': 0,
    'VANHORN': 0,
    'VANHORNE': 0,
    'VANHOUDT': 0,
    'VANHOUSE': 0,
    'VANHOUSEN': 0,
    'VANHOUT': 0,
    'VANHOUTAN': 0,
    'VANHOUTE': 0,
    'VANHOUTEN': 0,
    'VANHOUTTE': 0,
    'VANHOVE': 0,
    'VANHOVEN': 0,
    'VANHOWE': 0,
    'VANHOY': 0,
    'VANHUIS': 0,
    'VANHULLE': 0,
    'VANHULZEN': 0,
    'VANHUSEN': 0,
    'VANHUSS': 0,
    'VANHYFTE': 0,
    'VANHYNING': 0,
    'VANI': 0,
    'VANIA': 0.9523809523809523,
    'VANICEK': 0,
    'VANIDERSTINE': 0,
    'VANIER': 0,
    'VANIK': 0,
    'VANIMAN': 0,
    'VANINGEN': 0,
    'VANINWEGEN': 0,
    'VANIS': 0,
    'VANISH': 0,
    'VANISON': 0,
    'VANITA': 1,
    'VANKAMMEN': 0,
    'VANKAMPEN': 0,
    'VANKEMPEN': 0,
    'VANKEULEN': 0,
    'VANKEUREN': 0,
    'VANKIRK': 0,
    'VANKLAVEREN': 0,
    'VANKLEECK': 0,
    'VANKLEEF': 0,
    'VANKLEEK': 0,
    'VANKLEY': 0,
    'VANKLOMPENBERG': 0,
    'VANKO': 0,
    'VANKOEVERING': 0,
    'VANKOMEN': 0,
    'VANKOOTEN': 0,
    'VANKOUWENBERG': 0,
    'VANKUIKEN': 0,
    'VANKUREN': 0,
    'VANLAAN': 0,
    'VANLAANEN': 0,
    'VANLAAR': 0,
    'VANLAARHOVEN': 0,
    'VANLAERE': 0,
    'VANLANDINGHAM': 0,
    'VANLANDSCHOOT': 0,
    'VANLANDUYT': 0,
    'VANLANEN': 0,
    'VANLANGEN': 0,
    'VANLANINGHAM': 0,
    'VANLANNEN': 0,
    'VANLARE': 0,
    'VANLEAR': 0,
    'VANLEER': 0,
    'VANLEEUWEN': 0,
    'VANLENGEN': 0,
    'VANLENT': 0,
    'VANLENTE': 0,
    'VANLENTEN': 0,
    'VANLERBERGHE': 0,
    'VANLEUVAN': 0,
    'VANLEUVEN': 0,
    'VANLEW': 0,
    'VANLEY': 0,
    'VANLIER': 0,
    'VANLIERE': 0,
    'VANLIEROP': 0,
    'VANLIESHOUT': 0,
    'VANLIEU': 0,
    'VANLIEW': 0,
    'VANLINGEN': 0,
    'VANLITH': 0,
    'VANLOAN': 0,
    'VANLOENEN': 0,
    'VANLOH': 0,
    'VANLOO': 0,
    'VANLOON': 0,
    'VANLUE': 0,
    'VANLUVANEE': 0,
    'VANLUVEN': 0,
    'VANLUVENDER': 0,
    'VANMAANEN': 0,
    'VANMAAREN': 0,
    'VANMAELE': 0,
    'VANMANEN': 0,
    'VANMAREN': 0,
    'VANMARTER': 0,
    'VANMATER': 0,
    'VANMATRE': 0,
    'VANMEER': 0,
    'VANMEETEREN': 0,
    'VANMERSBERGEN': 0,
    'VANMETER': 0,
    'VANMETRE': 0,
    'VANMEVEREN': 0,
    'VANMIDDENDORP': 0,
    'VANMIDDLESWORTH': 0,
    'VANMOL': 0,
    'VANN': 0,
    'VANNA': 0.9523809523809523,
    'VANNAH': 0,
    'VANNAMAN': 0,
    'VANNAME': 0,
    'VANNARATH': 0,
    'VANNATTA': 0,
    'VANNATTAN': 0,
    'VANNATTEN': 0,
    'VANNATTER': 0,
    'VANNAVONG': 0,
    'VANNE': 0,
    'VANNELLI': 0,
    'VANNEMAN': 0,
    'VANNER': 0,
    'VANNERSON': 0,
    'VANNES': 0,
    'VANNESA': 1,
    'VANNESS': 0,
    'VANNESSA': 1,
    'VANNEST': 0,
    'VANNESTE': 0,
    'VANNETT': 0,
    'VANNETTE': 0,
    'VANNEVEL': 0,
    'VANNEWKIRK': 0,
    'VANNI': 0,
    'VANNICE': 0,
    'VANNICOLA': 0,
    'VANNIEKERK': 0,
    'VANNIEL': 0,
    'VANNIER': 0,
    'VANNIEUWENHOVEN': 0,
    'VANNOCKER': 0,
    'VANNOORD': 0,
    'VANNOORT': 0,
    'VANNORDEN': 0,
    'VANNORMAN': 0,
    'VANNORSTRAND': 0,
    'VANNORT': 0,
    'VANNORTWICK': 0,
    'VANNOSTRAN': 0,
    'VANNOSTRAND': 0,
    'VANNOTE': 0,
    'VANNOY': 0,
    'VANNOZZI': 0,
    'VANNUCCI': 0,
    'VANNULAND': 0,
    'VANNURDEN': 0,
    'VANNUYS': 0,
    'VANO': 0,
    'VANOCHTEN': 0,
    'VANOCKER': 0,
    'VANOMMEN': 0,
    'VANOMMEREN': 0,
    'VANONI': 0,
    'VANOORT': 0,
    'VANOOSTEN': 0,
    'VANOOYEN': 0,
    'VANOPDORP': 0,
    'VANORD': 0,
    'VANORDEN': 0,
    'VANORDER': 0,
    'VANORE': 0,
    'VANORMAN': 0,
    'VANORMER': 0,
    'VANORNUM': 0,
    'VANORSDALE': 0,
    'VANORSDEL': 0,
    'VANORSDOL': 0,
    'VANORT': 0,
    'VANOS': 0,
    'VANOSDEL': 0,
    'VANOSDELL': 0,
    'VANOSDOL': 0,
    'VANOSS': 0,
    'VANOSTEN': 0,
    'VANOSTENBRIDGE': 0,
    'VANOSTRAN': 0,
    'VANOSTRAND': 0,
    'VANOTTEN': 0,
    'VANOTTERLOO': 0,
    'VANOUS': 0,
    'VANOVER': 0,
    'VANOVERBEKE': 0,
    'VANOVERLOOP': 0,
    'VANOVERSCHELDE': 0,
    'VANOY': 0,
    'VANPARYS': 0,
    'VANPATTEN': 0,
    'VANPAY': 0,
    'VANPELT': 0,
    'VANPETTEN': 0,
    'VANPEURSEM': 0,
    'VANPOLEN': 0,
    'VANPOOL': 0,
    'VANPORTFLIET': 0,
    'VANPRAAG': 0,
    'VANPROOYEN': 0,
    'VANPUTTEN': 0,
    'VANRAALTE': 0,
    'VANRADEN': 0,
    'VANRAVENSWAAY': 0,
    'VANREENEN': 0,
    'VANREES': 0,
    'VANREGENMORTER': 0,
    'VANREMMEN': 0,
    'VANREMORTEL': 0,
    'VANRENS': 0,
    'VANRENSSELAER': 0,
    'VANRHEE': 0,
    'VANRHEENEN': 0,
    'VANRIEL': 0,
    'VANRIPER': 0,
    'VANRITE': 0,
    'VANROEKEL': 0,
    'VANROO': 0,
    'VANROOSENDAAL': 0,
    'VANROOY': 0,
    'VANROOYEN': 0,
    'VANROSSUM': 0,
    'VANROY': 0,
    'VANRUITEN': 0,
    'VANRYN': 0,
    'VANRYZIN': 0,
    'VANSADERS': 0,
    'VANSAMBEEK': 0,
    'VANSANDT': 0,
    'VANSANT': 0,
    'VANSANTEN': 0,
    'VANSAUN': 0,
    'VANSCHAACK': 0,
    'VANSCHAICK': 0,
    'VANSCHAIK': 0,
    'VANSCHEPEN': 0,
    'VANSCHOIACK': 0,
    'VANSCHOICK': 0,
    'VANSCHOONHOVEN': 0,
    'VANSCHOYCK': 0,
    'VANSCHUYVER': 0,
    'VANSCHYNDEL': 0,
    'VANSCIVER': 0,
    'VANSCODER': 0,
    'VANSCOIK': 0,
    'VANSCOTER': 0,
    'VANSCOY': 0,
    'VANSCOYK': 0,
    'VANSCOYOC': 0,
    'VANSCYOC': 0,
    'VANSELL': 0,
    'VANSELOW': 0,
    'VANSICE': 0,
    'VANSICKEL': 0,
    'VANSICKLE': 0,
    'VANSICKLER': 0,
    'VANSICLEN': 0,
    'VANSINGEL': 0,
    'VANSISE': 0,
    'VANSISTINE': 0,
    'VANSKIKE': 0,
    'VANSKIVER': 0,
    'VANSKYOCK': 0,
    'VANSLAMBROUCK': 0,
    'VANSLEET': 0,
    'VANSLETTE': 0,
    'VANSLOOTEN': 0,
    'VANSLOTEN': 0,
    'VANSLOUN': 0,
    'VANSLYKE': 0,
    'VANSOELEN': 0,
    'VANSOEST': 0,
    'VANSOLKEMA': 0,
    'VANSOMEREN': 0,
    'VANSON': 0,
    'VANSPRONSEN': 0,
    'VANSTAVEREN': 0,
    'VANSTAVERN': 0,
    'VANSTEDUM': 0,
    'VANSTEE': 0,
    'VANSTEEN': 0,
    'VANSTEENBERG': 0,
    'VANSTEENBERGEN': 0,
    'VANSTEENBURG': 0,
    'VANSTEENBURGH': 0,
    'VANSTEENKISTE': 0,
    'VANSTEENWYK': 0,
    'VANSTELLE': 0,
    'VANSTON': 0,
    'VANSTONE': 0,
    'VANSTORY': 0,
    'VANSTRALEN': 0,
    'VANSTRATEN': 0,
    'VANSTRIEN': 0,
    'VANSTROM': 0,
    'VANSUCH': 0,
    'VANSUMEREN': 0,
    'VANSURKSUM': 0,
    'VANSWEARINGEN': 0,
    'VANSWEDEN': 0,
    'VANSWOL': 0,
    'VANSYCKEL': 0,
    'VANSYCKLE': 0,
    'VANSYOC': 0,
    'VANT': 0,
    'VANTA': 0,
    'VANTASSEL': 0,
    'VANTASSELL': 0,
    'VANTATENHOVE': 0,
    'VANTERPOOL': 0,
    'VANTHIEL': 0,
    'VANTHOF': 0,
    'VANTHOURNOUT': 0,
    'VANTHUL': 0,
    'VANTIEM': 0,
    'VANTIL': 0,
    'VANTILBURG': 0,
    'VANTIMMEREN': 0,
    'VANTINE': 0,
    'VANTOL': 0,
    'VANTONGEREN': 0,
    'VANTREASE': 0,
    'VANTREECK': 0,
    'VANTREESE': 0,
    'VANTRESS': 0,
    'VANTRUMP': 0,
    'VANTUINEN': 0,
    'VANTUYL': 0,
    'VANTUYLE': 0,
    'VANUDEN': 0,
    'VANUNEN': 0,
    'VANVACTOR': 0,
    'VANVALEN': 0,
    'VANVALIN': 0,
    'VANVALKENBURG': 0,
    'VANVALKENBURGH': 0,
    'VANVECHTEN': 0,
    'VANVECKHOVEN': 0,
    'VANVEEN': 0,
    'VANVEGHEL': 0,
    'VANVELDHUIZEN': 0,
    'VANVELSOR': 0,
    'VANVELZEN': 0,
    'VANVELZER': 0,
    'VANVICKLE': 0,
    'VANVLACK': 0,
    'VANVLECK': 0,
    'VANVLEET': 0,
    'VANVLERAH': 0,
    'VANVLIET': 0,
    'VANVOAST': 0,
    'VANVOLKENBURG': 0,
    'VANVOLKENBURGH': 0,
    'VANVOLKINBURG': 0,
    'VANVONDEREN': 0,
    'VANVOOREN': 0,
    'VANVOORHEES': 0,
    'VANVOORHIS': 0,
    'VANVOORST': 0,
    'VANVORCE': 0,
    'VANVORST': 0,
    'VANVRANKEN': 0,
    'VANVREEDE': 0,
    'VANVUGT': 0,
    'VANVUREN': 0,
    'VANWAGENEN': 0,
    'VANWAGNER': 0,
    'VANWAGONER': 0,
    'VANWART': 0,
    'VANWASSENHOVE': 0,
    'VANWAY': 0,
    'VANWECHEL': 0,
    'VANWEELDEN': 0,
    'VANWELL': 0,
    'VANWERT': 0,
    'VANWESTEN': 0,
    'VANWETTERING': 0,
    'VANWEY': 0,
    'VANWHY': 0,
    'VANWICKLER': 0,
    'VANWIE': 0,
    'VANWIEREN': 0,
    'VANWIERINGEN': 0,
    'VANWINGERDEN': 0,
    'VANWINKLE': 0,
    'VANWOERKOM': 0,
    'VANWOERT': 0,
    'VANWORMER': 0,
    'VANWRIGHT': 0,
    'VANWYCHEN': 0,
    'VANWYCK': 0,
    'VANWYE': 0,
    'VANWYHE': 0,
    'VANWYK': 0,
    'VANWYNGARDEN': 0,
    'VANYA': 0,
    'VANYO': 0,
    'VANZANDT': 0,
    'VANZANT': 0,
    'VANZANTE': 0,
    'VANZANTEN': 0,
    'VANZEE': 0,
    'VANZEELAND': 0,
    'VANZILE': 0,
    'VANZO': 0,
    'VANZUIDEN': 0,
    'VAP': 0,
    'VAQUERA': 0,
    'VAQUERANO': 0,
    'VAQUERO': 0,
    'VAQUEZ': 0,
    'VAQUIZ': 0,
    'VAR': 0,
    'VARA': 0,
    'VARACALLI': 0,
    'VARADARAJAN': 0,
    'VARADI': 0,
    'VARADY': 0,
    'VARAJAS': 0,
    'VARALLI': 0,
    'VARALLO': 0,
    'VARANASI': 0,
    'VARANELLI': 0,
    'VARANESE': 0,
    'VARANI': 0,
    'VARANO': 0,
    'VARAO': 0,
    'VARAS': 0,
    'VARBEL': 0,
    'VARBLE': 0,
    'VARCA': 0,
    'VARCADIPANE': 0,
    'VARCHETTO': 0,
    'VARCO': 0,
    'VARCOE': 0,
    'VARDA': 0,
    'VARDAKIS': 0,
    'VARDAMAN': 0,
    'VARDANIAN': 0,
    'VARDANYAN': 0,
    'VARDARO': 0,
    'VARDELL': 0,
    'VARDEMAN': 0,
    'VARDEN': 0,
    'VARDI': 0,
    'VARDIMAN': 0,
    'VARDON': 0,
    'VARDY': 0,
    'VARE': 0,
    'VAREL': 0,
    'VARELA': 0,
    'VARELAS': 0,
    'VARELLA': 0,
    'VARENHORST': 0,
    'VARES': 0,
    'VARESE': 0,
    'VARGA': 0,
    'VARGAS': 0,
    'VARGASGARCIA': 0,
    'VARGASHERNANDE': 0,
    'VARGASON': 0,
    'VARGAZ': 0,
    'VARGES': 0,
    'VARGHESE': 0,
    'VARGO': 0,
    'VARGOS': 0,
    'VARGOVICH': 0,
    'VARGUS': 0,
    'VARHOL': 0,
    'VARHOLA': 0,
    'VARI': 0,
    'VARIAN': 0,
    'VARIAS': 0,
    'VARICHAK': 0,
    'VARICK': 0,
    'VARIEUR': 0,
    'VARILEK': 0,
    'VARILLA': 0,
    'VARILLAS': 0,
    'VARIN': 0,
    'VARIO': 0,
    'VARIS': 0,
    'VARISCO': 0,
    'VARISTE': 0,
    'VARJABEDIAN': 0,
    'VARJU': 0,
    'VARKER': 0,
    'VARKEY': 0,
    'VARLACK': 0,
    'VARLAND': 0,
    'VARLEY': 0,
    'VARMA': 0,
    'VARN': 0,
    'VARNADO': 0,
    'VARNADOE': 0,
    'VARNADORE': 0,
    'VARNAM': 0,
    'VARNAU': 0,
    'VARNDELL': 0,
    'VARNEDOE': 0,
    'VARNELL': 0,
    'VARNER': 0,
    'VARNES': 0,
    'VARNEY': 0,
    'VARNI': 0,
    'VARNO': 0,
    'VARNON': 0,
    'VARNS': 0,
    'VARNUM': 0,
    'VARO': 0,
    'VARON': 0,
    'VARONA': 0,
    'VARONE': 0,
    'VAROS': 0,
    'VAROZ': 0,
    'VARPNESS': 0,
    'VARQUEZ': 0,
    'VARRA': 0,
    'VARRASSO': 0,
    'VARRATO': 0,
    'VARRERA': 0,
    'VARRIALE': 0,
    'VARRIANO': 0,
    'VARRICCHIO': 0,
    'VARRICHIO': 0,
    'VARRO': 0,
    'VARRONE': 0,
    'VARS': 0,
    'VARSALONA': 0,
    'VARSHAVSKY': 0,
    'VARSHNEY': 0,
    'VARSHO': 0,
    'VARTABEDIAN': 0,
    'VARTAN': 0,
    'VARTANIAN': 0,
    'VARTANYAN': 0,
    'VARTULI': 0,
    'VARTY': 0,
    'VARUGHESE': 0,
    'VARVARA': 0,
    'VARVARO': 0,
    'VARVEL': 0,
    'VARVIL': 0,
    'VARWIG': 0,
    'VARY': 0,
    'VAS': 0,
    'VASA': 0,
    'VASALLO': 0,
    'VASAN': 0,
    'VASAPOLLI': 0,
    'VASAS': 0,
    'VASATURO': 0,
    'VASAVADA': 0,
    'VASBINDER': 0,
    'VASCIK': 0,
    'VASCO': 0,
    'VASCONCELLOS': 0,
    'VASCONCELOS': 0,
    'VASCONEZ': 0,
    'VASCONI': 0,
    'VASEK': 0,
    'VASEL': 0,
    'VASEY': 0,
    'VASGUEZ': 0,
    'VASH': 0,
    'VASHAW': 0,
    'VASHER': 0,
    'VASHI': 0,
    'VASHON': 0,
    'VASHTI': 1,
    'VASI': 0,
    'VASIC': 0,
    'VASICEK': 0,
    'VASICH': 0,
    'VASIL': 0,
    'VASILAKIS': 0,
    'VASILAKOS': 0,
    'VASILAS': 0,
    'VASILE': 0,
    'VASILENKO': 0,
    'VASILESCU': 0,
    'VASILEV': 0,
    'VASILIADES': 0,
    'VASILIADIS': 0,
    'VASILIAUSKAS': 0,
    'VASILIK': 0,
    'VASILIKI': 1,
    'VASILIOU': 0,
    'VASILKO': 0,
    'VASILOFF': 0,
    'VASILOPOULOS': 0,
    'VASILYEV': 0,
    'VASINA': 0,
    'VASKE': 0,
    'VASKO': 0,
    'VASOLD': 0,
    'VASON': 0,
    'VASOS': 0,
    'VASQEZ': 0,
    'VASQUE': 0,
    'VASQUES': 0,
    'VASQUEZ': 0,
    'VASQUEZGARCIA': 0,
    'VASS': 0,
    'VASSALL': 0,
    'VASSALLO': 0,
    'VASSALOTTI': 0,
    'VASSAR': 0,
    'VASSEL': 0,
    'VASSELL': 0,
    'VASSER': 0,
    'VASSERMAN': 0,
    'VASSEUR': 0,
    'VASSEY': 0,
    'VASSIL': 0,
    'VASSILAKIS': 0,
    'VASSILEV': 0,
    'VASSILIOU': 0,
    'VASSO': 0,
    'VASSOR': 0,
    'VASSOS': 0,
    'VASTA': 0,
    'VASTAG': 0,
    'VASTANO': 0,
    'VASTARDIS': 0,
    'VASTBINDER': 0,
    'VASTERLING': 0,
    'VASTI': 0,
    'VASTINE': 0,
    'VASTOLA': 0,
    'VASU': 0,
    'VASUDEVA': 0,
    'VASUDEVAN': 0,
    'VASUT': 0,
    'VASWANI': 0,
    'VATALARO': 0,
    'VATCHER': 0,
    'VATER': 0,
    'VATERLAUS': 0,
    'VATERS': 0,
    'VATH': 0,
    'VATLAND': 0,
    'VATNE': 0,
    'VATTER': 0,
    'VATTEROTT': 0,
    'VATTIMO': 0,
    'VAUBEL': 0,
    'VAUDO': 0,
    'VAUDREUIL': 0,
    'VAUDRIN': 0,
    'VAUDT': 0,
    'VAUGAN': 0,
    'VAUGH': 0,
    'VAUGHAN': 0,
    'VAUGHANS': 0,
    'VAUGHEN': 0,
    'VAUGHN': 0.2587017873941674,
    'VAUGHNER': 0,
    'VAUGHNS': 0,
    'VAUGHT': 0,
    'VAUGHTER': 0,
    'VAUGHTERS': 0,
    'VAUGN': 0,
    'VAULT': 0,
    'VAULX': 0,
    'VAUPEL': 0,
    'VAUSE': 0,
    'VAUTER': 0,
    'VAUTERS': 0,
    'VAUTIER': 0,
    'VAUTOUR': 0,
    'VAUTRIN': 0,
    'VAUX': 0,
    'VAVAK': 0,
    'VAVAL': 0,
    'VAVALA': 0,
    'VAVASSEUR': 0,
    'VAVERKA': 0,
    'VAVRA': 0,
    'VAVREK': 0,
    'VAVRICEK': 0,
    'VAVRICK': 0,
    'VAVRICKA': 0,
    'VAVRIK': 0,
    'VAVRINA': 0,
    'VAVRO': 0,
    'VAVROSKY': 0,
    'VAVRUSKA': 0,
    'VAWDREY': 0,
    'VAWSER': 0,
    'VAWTER': 0,
    'VAWTERS': 0,
    'VAXTER': 0,
    'VAY': 0,
    'VAYDA': 0,
    'VAYNBERG': 0,
    'VAYNER': 0,
    'VAYNSHTEYN': 0,
    'VAYO': 0,
    'VAYSBERG': 0,
    'VAYSMAN': 0,
    'VAZ': 0,
    'VAZGUEZ': 0,
    'VAZIRANI': 0,
    'VAZIRI': 0,
    'VAZQUES': 0,
    'VAZQUEZ': 0,
    'VAZQUEZGARCIA': 0,
    'VAZZANA': 0,
    'VAZZANO': 0,
    'VE': 0,
    'VEA': 0,
    'VEACH': 0,
    'VEADER': 0,
    'VEAL': 0,
    'VEALE': 0,
    'VEALEY': 0,
    'VEALS': 0,
    'VEAR': 0,
    'VEASEY': 0,
    'VEASLEY': 0,
    'VEASMAN': 0,
    'VEASY': 0,
    'VEATCH': 0,
    'VEATER': 0,
    'VEAZEY': 0,
    'VEAZIE': 0,
    'VEBER': 0,
    'VECA': 0,
    'VECCHI': 0,
    'VECCHIA': 0,
    'VECCHIARELLI': 0,
    'VECCHIARELLO': 0,
    'VECCHIO': 0,
    'VECCHIOLLA': 0,
    'VECCHIONE': 0,
    'VECCHIONI': 0,
    'VECCHITTO': 0,
    'VECCIA': 0,
    'VECE': 0,
    'VECELLIO': 0,
    'VECERA': 0,
    'VECERE': 0,
    'VECINO': 0,
    'VECSEY': 0,
    'VED': 0,
    'VEDA': 0.9873060648801129,
    'VEDDA': 0,
    'VEDDER': 0,
    'VEDIA': 0,
    'VEDRAL': 0,
    'VEDRINE': 0,
    'VEDROS': 0,
    'VEE': 0,
    'VEECH': 0,
    'VEECK': 0,
    'VEEDER': 0,
    'VEEN': 0,
    'VEENEMAN': 0,
    'VEENENDAAL': 0,
    'VEENHUIS': 0,
    'VEENKER': 0,
    'VEENSTRA': 0,
    'VEER': 0,
    'VEERKAMP': 0,
    'VEERMAN': 0,
    'VEESER': 0,
    'VEGA': 0,
    'VEGAS': 0,
    'VEGH': 0,
    'VEGLIA': 0,
    'VEGLIANTE': 0,
    'VEGO': 0,
    'VEGTER': 0,
    'VEGUILLA': 0,
    'VEHAR': 0,
    'VEHARA': 0,
    'VEHIGE': 0,
    'VEHIKITE': 0,
    'VEHLEWALD': 0,
    'VEHORN': 0,
    'VEHR': 0,
    'VEHRS': 0,
    'VEHSLAGE': 0,
    'VEIGA': 0,
    'VEIGEL': 0,
    'VEIHL': 0,
    'VEIK': 0,
    'VEIL': 0,
    'VEILE': 0,
    'VEILLARD': 0,
    'VEILLETTE': 0,
    'VEILLEUX': 0,
    'VEILLON': 0,
    'VEIN': 0,
    'VEINO': 0,
    'VEINOT': 0,
    'VEINTIMILLA': 0,
    'VEIRA': 0,
    'VEIRS': 0,
    'VEIS': 0,
    'VEIT': 0,
    'VEITCH': 0,
    'VEITENGRUBER': 0,
    'VEITENHEIMER': 0,
    'VEITH': 0,
    'VEITIA': 0,
    'VEITZ': 0,
    'VEIZAGA': 0,
    'VEJAR': 0,
    'VEJVODA': 0,
    'VEKSLER': 0,
    'VELA': 0,
    'VELADO': 0,
    'VELADOR': 0,
    'VELAND': 0,
    'VELANDER': 0,
    'VELANDIA': 0,
    'VELAQUEZ': 0,
    'VELARDE': 0,
    'VELARDEZ': 0,
    'VELARDI': 0,
    'VELARDO': 0,
    'VELAS': 0,
    'VELASCO': 0,
    'VELASGUEZ': 0,
    'VELASQUE': 0,
    'VELASQUES': 0,
    'VELASQUEZ': 0,
    'VELASTEGUI': 0,
    'VELAZCO': 0,
    'VELAZGUEZ': 0,
    'VELAZQUES': 0,
    'VELAZQUEZ': 0,
    'VELCICH': 0,
    'VELD': 0,
    'VELDA': 1,
    'VELDBOOM': 0,
    'VELDE': 0,
    'VELDER': 0,
    'VELDERRAIN': 0,
    'VELDHEER': 0,
    'VELDHOUSE': 0,
    'VELDHUIS': 0,
    'VELDHUIZEN': 0,
    'VELDKAMP': 0,
    'VELDMAN': 0,
    'VELE': 0,
    'VELEK': 0,
    'VELER': 0,
    'VELES': 0,
    'VELETA': 0,
    'VELEY': 0,
    'VELEZ': 0,
    'VELGARA': 0,
    'VELHO': 0,
    'VELIA': 1,
    'VELIC': 0,
    'VELICHKO': 0,
    'VELIE': 0,
    'VELIKY': 0,
    'VELILLA': 0,
    'VELIN': 0,
    'VELING': 0,
    'VELIQUETTE': 0,
    'VELIS': 0,
    'VELIZ': 0,
    'VELK': 0,
    'VELKER': 0,
    'VELKY': 0,
    'VELL': 0,
    'VELLA': 0.591715976331361,
    'VELLANKI': 0,
    'VELLECA': 0,
    'VELLENGA': 0,
    'VELLER': 0,
    'VELLINES': 0,
    'VELLINGA': 0,
    'VELLIOS': 0,
    'VELLIQUETTE': 0,
    'VELLON': 0,
    'VELLONE': 0,
    'VELLOS': 0,
    'VELLUCCI': 0,
    'VELMA': 1,
    'VELO': 0,
    'VELOCCI': 0,
    'VELONIS': 0,
    'VELORIA': 0,
    'VELOS': 0,
    'VELOSO': 0,
    'VELOTTA': 0,
    'VELOVIC': 0,
    'VELOZ': 0,
    'VELOZA': 0,
    'VELOZO': 0,
    'VELSOR': 0,
    'VELTE': 0,
    'VELTEMA': 0,
    'VELTEN': 0,
    'VELTHOUSE': 0,
    'VELTING': 0,
    'VELTKAMP': 0,
    'VELTMAN': 0,
    'VELTRAN': 0,
    'VELTRE': 0,
    'VELTRI': 0,
    'VELTROP': 0,
    'VELTZ': 0,
    'VELUZ': 0,
    'VELVA': 1,
    'VELVET': 1,
    'VELZY': 0,
    'VEMULAPALLI': 0,
    'VEMURI': 0,
    'VEN': 0,
    'VENA': 0.8438818565400844,
    'VENABLE': 0,
    'VENABLES': 0,
    'VENANCIO': 0,
    'VENANZI': 0,
    'VENARD': 0,
    'VENATOR': 0,
    'VENCE': 0,
    'VENCEL': 0,
    'VENCES': 0,
    'VENCIL': 0,
    'VENCILL': 0,
    'VENCKUS': 0,
    'VENDEGNA': 0,
    'VENDEL': 0,
    'VENDEMIA': 0,
    'VENDEN': 0,
    'VENDER': 0,
    'VENDETTA': 0,
    'VENDETTI': 0,
    'VENDITTELLI': 0,
    'VENDITTI': 0,
    'VENDITTO': 0,
    'VENDL': 0,
    'VENDOLA': 0,
    'VENDRELL': 0,
    'VENDRYES': 0,
    'VENDT': 0,
    'VENE': 0,
    'VENECIA': 0,
    'VENEGA': 0,
    'VENEGAS': 0,
    'VENEGONI': 0,
    'VENEKLASE': 0,
    'VENEKLASEN': 0,
    'VENEMA': 0,
    'VENEMAN': 0,
    'VENENGA': 0,
    'VENER': 0,
    'VENERABLE': 0,
    'VENERACION': 0,
    'VENERI': 0,
    'VENERIO': 0,
    'VENERO': 0,
    'VENES': 0,
    'VENESKY': 0,
    'VENESS': 0,
    'VENESSA': 1,
    'VENET': 0,
    'VENETIS': 0,
    'VENETTA': 1,
    'VENETTE': 0,
    'VENETUCCI': 0,
    'VENETZ': 0,
    'VENEY': 0,
    'VENEZIA': 0,
    'VENEZIALE': 0,
    'VENEZIANO': 0,
    'VENEZIO': 0,
    'VENEZUELA': 0,
    'VENGHAUS': 0,
    'VENGLAR': 0,
    'VENGOECHEA': 0,
    'VENHAM': 0,
    'VENHAUS': 0,
    'VENHUIZEN': 0,
    'VENICE': 0.9478672985781991,
    'VENIER': 0,
    'VENIS': 0,
    'VENITA': 1,
    'VENITEZ': 0,
    'VENJOHN': 0,
    'VENKAT': 0,
    'VENKATACHALAM': 0,
    'VENKATARAMAN': 0,
    'VENKATESAN': 0,
    'VENKATESH': 0,
    'VENKATESWARAN': 0,
    'VENKATRAMAN': 0,
    'VENKER': 0,
    'VENN': 0,
    'VENNARD': 0,
    'VENNE': 0,
    'VENNELL': 0,
    'VENNEMAN': 0,
    'VENNEMANN': 0,
    'VENNER': 0,
    'VENNERI': 0,
    'VENNES': 0,
    'VENNIE': 0.9523809523809523,
    'VENNING': 0,
    'VENNUM': 0,
    'VENO': 0,
    'VENOY': 0,
    'VENRICK': 0,
    'VENS': 0,
    'VENSEL': 0,
    'VENSKE': 0,
    'VENSKUS': 0,
    'VENSON': 0,
    'VENSOR': 0,
    'VENT': 0,
    'VENTA': 0,
    'VENTE': 0,
    'VENTEICHER': 0,
    'VENTER': 0,
    'VENTERS': 0,
    'VENTI': 0,
    'VENTICINQUE': 0,
    'VENTIMIGLIA': 0,
    'VENTLING': 0,
    'VENTO': 0,
    'VENTOLA': 0,
    'VENTON': 0,
    'VENTOUR': 0,
    'VENTRE': 0,
    'VENTRELLA': 0,
    'VENTRELLO': 0,
    'VENTRESCA': 0,
    'VENTRESCO': 0,
    'VENTRESS': 0,
    'VENTRICE': 0,
    'VENTRIGLIA': 0,
    'VENTRIS': 0,
    'VENTRONE': 0,
    'VENTRY': 0,
    'VENTURA': 0,
    'VENTURE': 0,
    'VENTURELLA': 0,
    'VENTURELLI': 0,
    'VENTURI': 0,
    'VENTURINA': 0,
    'VENTURINI': 0,
    'VENTURINO': 0,
    'VENTURO': 0,
    'VENTUS': 0,
    'VENUGOPAL': 0,
    'VENUS': 0.9584664536741214,
    'VENUTI': 0,
    'VENUTO': 0,
    'VENVERTLOH': 0,
    'VENZ': 0,
    'VENZA': 0,
    'VENZANT': 0,
    'VENZEN': 0,
    'VENZKE': 0,
    'VENZON': 0,
    'VENZOR': 0,
    'VEO': 0,
    'VEOLA': 1,
    'VEON': 0,
    'VER': 0,
    'VERA': 0.9150326797385622,
    'VERACRUZ': 0,
    'VERALDI': 0,
    'VERANO': 0,
    'VERARDI': 0,
    'VERARDO': 0,
    'VERAS': 0,
    'VERASTEGUI': 0,
    'VERBA': 0,
    'VERBAL': 0,
    'VERBANAC': 0,
    'VERBANIC': 0,
    'VERBARG': 0,
    'VERBECK': 0,
    'VERBEEK': 0,
    'VERBEKE': 0,
    'VERBER': 0,
    'VERBERKMOES': 0,
    'VERBETEN': 0,
    'VERBIC': 0,
    'VERBICK': 0,
    'VERBITSKY': 0,
    'VERBLE': 0,
    'VERBOIS': 0,
    'VERBOS': 0,
    'VERBOSKY': 0,
    'VERBOUT': 0,
    'VERBRIDGE': 0,
    'VERBRUGGE': 0,
    'VERBRUGGEN': 0,
    'VERBURG': 0,
    'VERBURGT': 0,
    'VERBUS': 0,
    'VERCAMMEN': 0,
    'VERCAUTEREN': 0,
    'VERCELES': 0,
    'VERCELLI': 0,
    'VERCELLINO': 0,
    'VERCELLOTTI': 0,
    'VERCH': 0,
    'VERCHER': 0,
    'VERCHICK': 0,
    'VERCILLO': 0,
    'VERCOE': 0,
    'VERCRUYSSE': 0,
    'VERD': 0,
    'VERDA': 0.9929078014184397,
    'VERDE': 0,
    'VERDECCHIA': 0,
    'VERDECIA': 0,
    'VERDEGAN': 0,
    'VERDEJA': 0,
    'VERDEJO': 0,
    'VERDEL': 0,
    'VERDELL': 0.9216589861751152,
    'VERDEN': 0,
    'VERDERAME': 0,
    'VERDERBER': 0,
    'VERDERESE': 0,
    'VERDEROSA': 0,
    'VERDERY': 0,
    'VERDES': 0,
    'VERDESOTO': 0,
    'VERDEYEN': 0,
    'VERDI': 0,
    'VERDICCHIO': 0,
    'VERDICK': 0,
    'VERDIE': 1,
    'VERDIER': 0,
    'VERDILE': 0,
    'VERDIN': 0,
    'VERDINE': 0,
    'VERDINI': 0,
    'VERDINO': 0,
    'VERDON': 0,
    'VERDONE': 0,
    'VERDONI': 0,
    'VERDOORN': 0,
    'VERDOZA': 0,
    'VERDU': 0,
    'VERDUCCI': 0,
    'VERDUGO': 0,
    'VERDUIN': 0,
    'VERDUN': 0,
    'VERDURA': 0,
    'VERDUSCO': 0,
    'VERDUZCO': 0,
    'VERE': 0,
    'VEREB': 0,
    'VEREECKE': 0,
    'VEREEKE': 0,
    'VEREEN': 0,
    'VERELLEN': 0,
    'VERENA': 1,
    'VERES': 0,
    'VERETTE': 0,
    'VERFAILLIE': 0,
    'VERFURTH': 0,
    'VERGA': 0,
    'VERGAMINI': 0,
    'VERGANO': 0,
    'VERGARA': 0,
    'VERGARI': 0,
    'VERGASON': 0,
    'VERGE': 0,
    'VERGEL': 0,
    'VERGELDEDIOS': 0,
    'VERGER': 0,
    'VERGES': 0,
    'VERGHESE': 0,
    'VERGIE': 1,
    'VERGIL': 0,
    'VERGIN': 0,
    'VERGIS': 0,
    'VERGITH': 0,
    'VERGO': 0,
    'VERGONA': 0,
    'VERGOS': 0,
    'VERHAAGH': 0,
    'VERHAEGHE': 0,
    'VERHAGE': 0,
    'VERHAGEN': 0,
    'VERHALEN': 0,
    'VERHASSELT': 0,
    'VERHELLE': 0,
    'VERHELST': 0,
    'VERHEUL': 0,
    'VERHEY': 0,
    'VERHEYDEN': 0,
    'VERHEYEN': 0,
    'VERHINE': 0,
    'VERHINES': 0,
    'VERHOEF': 0,
    'VERHOEFF': 0,
    'VERHOEVEN': 0,
    'VERHOFF': 0,
    'VERHOVEN': 0,
    'VERHULST': 0,
    'VERI': 0,
    'VERING': 0,
    'VERISSIMO': 0,
    'VERITY': 0,
    'VERKAIK': 0,
    'VERKAMP': 0,
    'VERKE': 0,
    'VERKEST': 0,
    'VERKLER': 0,
    'VERKUILEN': 0,
    'VERLA': 1,
    'VERLANDER': 0,
    'VERLENE': 1,
    'VERLEY': 0,
    'VERLIE': 1,
    'VERLIN': 0,
    'VERLINDE': 0,
    'VERLINDEN': 0,
    'VERLINE': 1,
    'VERMA': 0,
    'VERMAAS': 0,
    'VERMAAT': 0,
    'VERMAN': 0,
    'VERMEER': 0,
    'VERMEERSCH': 0,
    'VERMEESCH': 0,
    'VERMEIRE': 0,
    'VERMES': 0,
    'VERMETT': 0,
    'VERMETTE': 0,
    'VERMEULEN': 0,
    'VERMIGLIO': 0,
    'VERMILION': 0,
    'VERMILLION': 0,
    'VERMILYA': 0,
    'VERMILYE': 0,
    'VERMILYEA': 0,
    'VERMILYER': 0,
    'VERMONT': 0,
    'VERMULM': 0,
    'VERN': 0.9960159362549801,
    'VERNA': 0.9898948236749845,
    'VERNACCHIO': 0,
    'VERNACI': 0,
    'VERNAL': 0,
    'VERNALI': 0,
    'VERNAM': 0,
    'VERNATTER': 0,
    'VERNAZZA': 0,
    'VERNE': 0,
    'VERNELL': 0.9933774834437086,
    'VERNER': 0,
    'VERNET': 0,
    'VERNETTA': 1,
    'VERNETTI': 0,
    'VERNEY': 0,
    'VERNI': 0,
    'VERNIA': 0.9345794392523364,
    'VERNICE': 1,
    'VERNICK': 0,
    'VERNIE': 1,
    'VERNIER': 0,
    'VERNIERI': 0,
    'VERNIK': 0,
    'VERNITA': 1,
    'VERNO': 0,
    'VERNOLA': 0,
    'VERNON': 0.9386973180076628,
    'VERNOOY': 0,
    'VERNOR': 0,
    'VERNOT': 0,
    'VERNOY': 0,
    'VERO': 0,
    'VERON': 0,
    'VERONA': 0.9463722397476342,
    'VERONDA': 0,
    'VERONE': 0,
    'VERONEAU': 0,
    'VERONEE': 0,
    'VERONESE': 0,
    'VERONESI': 0,
    'VERONICA': 0.9986637597580702,
    'VERONIE': 0,
    'VERONIKA': 1,
    'VERONIQUE': 1,
    'VERONNEAU': 0,
    'VEROS': 0,
    'VEROST': 0,
    'VERPLANCK': 0,
    'VERPLANK': 0,
    'VERPLOEG': 0,
    'VERRA': 0,
    'VERRALL': 0,
    'VERRAN': 0,
    'VERRASTRO': 0,
    'VERRATTI': 0,
    'VERRE': 0,
    'VERRECCHIA': 0,
    'VERRECCHIO': 0,
    'VERRELL': 0,
    'VERRELLI': 0,
    'VERRENGIA': 0,
    'VERRET': 0,
    'VERRETT': 0,
    'VERRETTE': 0,
    'VERRI': 0,
    'VERRICO': 0,
    'VERRIER': 0,
    'VERRILL': 0,
    'VERRILLI': 0,
    'VERRILLO': 0,
    'VERRINDER': 0,
    'VERROCHI': 0,
    'VERRONE': 0,
    'VERROS': 0,
    'VERRY': 0,
    'VERSACE': 0,
    'VERSACI': 0,
    'VERSAGGI': 0,
    'VERSAILLES': 0,
    'VERSAW': 0,
    'VERSCH': 0,
    'VERSCHOOR': 0,
    'VERSCHUEREN': 0,
    'VERSE': 0,
    'VERSEMAN': 0,
    'VERSEN': 0,
    'VERSER': 0,
    'VERSEY': 0,
    'VERSHAY': 0,
    'VERSIE': 1,
    'VERSLUES': 0,
    'VERSLUIS': 0,
    'VERSLUYS': 0,
    'VERSO': 0,
    'VERSOZA': 0,
    'VERSTEEG': 0,
    'VERSTEEGH': 0,
    'VERSTEGEN': 0,
    'VERSTRAETE': 0,
    'VERSTRATE': 0,
    'VERSTUYFT': 0,
    'VERT': 0,
    'VERTEFEUILLE': 0,
    'VERTERAMO': 0,
    'VERTHEIN': 0,
    'VERTIE': 1,
    'VERTIN': 0,
    'VERTIZ': 0,
    'VERTNER': 0,
    'VERTREES': 0,
    'VERTUCCI': 0,
    'VERTULLO': 0,
    'VERTUS': 0,
    'VERTZ': 0,
    'VERVAECKE': 0,
    'VERVALIN': 0,
    'VERVELDE': 0,
    'VERVER': 0,
    'VERVERIS': 0,
    'VERVILLE': 0,
    'VERVOORT': 0,
    'VERWERS': 0,
    'VERWEY': 0,
    'VERWYS': 0,
    'VERY': 0,
    'VERZAL': 0,
    'VERZANI': 0,
    'VERZELLA': 0,
    'VERZI': 0,
    'VERZINO': 0,
    'VERZOSA': 0,
    'VERZWYVELT': 0,
    'VESA': 0,
    'VESCE': 0,
    'VESCERA': 0,
    'VESCI': 0,
    'VESCIO': 0,
    'VESCO': 0,
    'VESCOVI': 0,
    'VESCOVO': 0,
    'VESECKY': 0,
    'VESEL': 0,
    'VESELIK': 0,
    'VESELKA': 0,
    'VESELSKY': 0,
    'VESELY': 0,
    'VESEY': 0,
    'VESLEY': 0,
    'VESPA': 0,
    'VESPE': 0,
    'VESPER': 0,
    'VESPERMAN': 0,
    'VESPI': 0,
    'VESPIA': 0,
    'VESPIE': 0,
    'VESPO': 0,
    'VESPOLI': 0,
    'VESPUCCI': 0,
    'VESS': 0,
    'VESSA': 0,
    'VESSEL': 0,
    'VESSELL': 0,
    'VESSELLA': 0,
    'VESSELLS': 0,
    'VESSELS': 0,
    'VESSER': 0,
    'VESSEY': 0,
    'VEST': 0,
    'VESTA': 0.9900990099009901,
    'VESTAL': 0,
    'VESTER': 0,
    'VESTERBY': 0,
    'VESTRAND': 0,
    'VESTUTO': 0,
    'VETA': 1,
    'VETCH': 0,
    'VETERE': 0,
    'VETETO': 0,
    'VETH': 0,
    'VETO': 0,
    'VETOR': 0,
    'VETRAND': 0,
    'VETRANO': 0,
    'VETRI': 0,
    'VETRO': 0,
    'VETRONE': 0,
    'VETSCH': 0,
    'VETTE': 0,
    'VETTEL': 0,
    'VETTER': 0,
    'VETTERICK': 0,
    'VETTERLI': 0,
    'VETTERS': 0,
    'VETTESE': 0,
    'VETTLESON': 0,
    'VETTORI': 0,
    'VETTRAINO': 0,
    'VEULEMAN': 0,
    'VEUM': 0,
    'VEURINK': 0,
    'VEVE': 0,
    'VEVEA': 0,
    'VEVERKA': 0,
    'VEY': 0,
    'VEYNA': 0,
    'VEYSEY': 0,
    'VEYTIA': 0,
    'VEYTSMAN': 0,
    'VEZEAU': 0,
    'VEZINA': 0,
    'VEZZA': 0,
    'VEZZANI': 0,
    'VEZZETTI': 0,
    'VI': 0.7874015748031497,
    'VIA': 0,
    'VIADA': 0,
    'VIADO': 0,
    'VIAENE': 0,
    'VIAL': 0,
    'VIALE': 0,
    'VIALET': 0,
    'VIALL': 0,
    'VIALPANDO': 0,
    'VIALVA': 0,
    'VIAMONTE': 0,
    'VIAMONTES': 0,
    'VIAN': 0,
    'VIANA': 0,
    'VIANDS': 0,
    'VIANELLO': 0,
    'VIANI': 0,
    'VIANNA': 0,
    'VIANO': 0,
    'VIAR': 0,
    'VIARD': 0,
    'VIARENGO': 0,
    'VIARS': 0,
    'VIAS': 0,
    'VIATOR': 0,
    'VIATORO': 0,
    'VIAU': 0,
    'VIAUD': 0,
    'VIAZANKO': 0,
    'VIBAR': 0,
    'VIBBARD': 0,
    'VIBBER': 0,
    'VIBBERT': 0,
    'VIBERT': 0,
    'VICARI': 0,
    'VICARIO': 0,
    'VICARS': 0,
    'VICARY': 0,
    'VICCARO': 0,
    'VICCHIO': 0,
    'VICE': 0,
    'VICENCIO': 0,
    'VICENS': 0,
    'VICENT': 0,
    'VICENTA': 1,
    'VICENTE': 0.878099173553719,
    'VICENTI': 0,
    'VICENTY': 0,
    'VICENZI': 0,
    'VICH': 0,
    'VICHA': 0,
    'VICHICH': 0,
    'VICHOT': 0,
    'VICIAN': 0,
    'VICICH': 0,
    'VICIDOMINI': 0,
    'VICINANZA': 0,
    'VICINI': 0,
    'VICINO': 0,
    'VICIOSO': 0,
    'VICK': 0,
    'VICKER': 0,
    'VICKERMAN': 0,
    'VICKERS': 0,
    'VICKERSON': 0,
    'VICKERY': 0,
    'VICKEY': 0.9852216748768473,
    'VICKI': 0.9996331621423331,
    'VICKIE': 1,
    'VICKMAN': 0,
    'VICKNAIR': 0,
    'VICKORY': 0,
    'VICKREY': 0,
    'VICKROY': 0,
    'VICKS': 0,
    'VICKSTROM': 0,
    'VICKY': 1,
    'VICO': 0,
    'VICORY': 0,
    'VICTA': 0,
    'VICTOR': 0.9836354814520754,
    'VICTORERO': 0,
    'VICTORES': 0,
    'VICTORIA': 0.989990100098999,
    'VICTORIAN': 0,
    'VICTORIANO': 0,
    'VICTORIN': 0,
    'VICTORINA': 1,
    'VICTORINE': 0,
    'VICTORINO': 0,
    'VICTORIO': 0,
    'VICTORSON': 0,
    'VICTORY': 0,
    'VICUNA': 0,
    'VIDA': 0.9296148738379814,
    'VIDACA': 0,
    'VIDAD': 0,
    'VIDAK': 0,
    'VIDAKOVIC': 0,
    'VIDAKOVICH': 0,
    'VIDAL': 0,
    'VIDALE': 0,
    'VIDALES': 0,
    'VIDALEZ': 0,
    'VIDALS': 0,
    'VIDANA': 0,
    'VIDAS': 0,
    'VIDAURE': 0,
    'VIDAURI': 0,
    'VIDAURRAZAGA': 0,
    'VIDAURRE': 0,
    'VIDAURRI': 0,
    'VIDEAN': 0,
    'VIDEAU': 0,
    'VIDEEN': 0,
    'VIDELA': 0,
    'VIDELL': 0,
    'VIDER': 0,
    'VIDES': 0,
    'VIDETICH': 0,
    'VIDETTO': 0,
    'VIDIC': 0,
    'VIDICAN': 0,
    'VIDINHA': 0,
    'VIDITO': 0,
    'VIDLAK': 0,
    'VIDLER': 0,
    'VIDMAR': 0,
    'VIDO': 0,
    'VIDONI': 0,
    'VIDOR': 0,
    'VIDOS': 0,
    'VIDOT': 0,
    'VIDOVIC': 0,
    'VIDOVICH': 0,
    'VIDRA': 0,
    'VIDRINE': 0,
    'VIDRIO': 0,
    'VIDRIOS': 0,
    'VIDRO': 0,
    'VIDULICH': 0,
    'VIDUYA': 0,
    'VIE': 0,
    'VIEAU': 0,
    'VIEAUX': 0,
    'VIEBROCK': 0,
    'VIECELI': 0,
    'VIECK': 0,
    'VIED': 0,
    'VIEGAS': 0,
    'VIEGUT': 0,
    'VIEHL': 0,
    'VIEHLAND': 0,
    'VIEHMAN': 0,
    'VIEHMANN': 0,
    'VIEHWEG': 0,
    'VIEIRA': 0,
    'VIEJO': 0,
    'VIEL': 0,
    'VIELA': 0,
    'VIELBIG': 0,
    'VIELE': 0,
    'VIELHABER': 0,
    'VIELHAUER': 0,
    'VIELLE': 0,
    'VIELMA': 0,
    'VIELMAN': 0,
    'VIELMAS': 0,
    'VIELOT': 0,
    'VIEN': 0,
    'VIENA': 0,
    'VIENER': 0,
    'VIENI': 0,
    'VIENNA': 0,
    'VIENNE': 0,
    'VIENNEAU': 0,
    'VIENS': 0,
    'VIER': 0,
    'VIERA': 0,
    'VIERCK': 0,
    'VIERECK': 0,
    'VIEREGGE': 0,
    'VIERGUTZ': 0,
    'VIERHELLER': 0,
    'VIERING': 0,
    'VIERK': 0,
    'VIERKANT': 0,
    'VIERLING': 0,
    'VIERNES': 0,
    'VIEROW': 0,
    'VIERRA': 0,
    'VIERS': 0,
    'VIERSTRA': 0,
    'VIERTEL': 0,
    'VIERTHALER': 0,
    'VIESCA': 0,
    'VIESCAS': 0,
    'VIESSMAN': 0,
    'VIESTENZ': 0,
    'VIET': 0,
    'VIETA': 0,
    'VIETH': 0,
    'VIETHS': 0,
    'VIETMEIER': 0,
    'VIETOR': 0,
    'VIETRI': 0,
    'VIETS': 0,
    'VIETTI': 0,
    'VIETZ': 0,
    'VIETZE': 0,
    'VIETZKE': 0,
    'VIEU': 0,
    'VIEUX': 0,
    'VIEW': 0,
    'VIEWEG': 0,
    'VIEYRA': 0,
    'VIEZCAS': 0,
    'VIFQUAIN': 0,
    'VIG': 0,
    'VIGAR': 0,
    'VIGARIO': 0,
    'VIGE': 0,
    'VIGEANT': 0,
    'VIGEN': 0,
    'VIGER': 0,
    'VIGESAA': 0,
    'VIGGERS': 0,
    'VIGGIANI': 0,
    'VIGGIANO': 0,
    'VIGH': 0,
    'VIGIL': 0,
    'VIGILANTE': 0,
    'VIGILIA': 0,
    'VIGLIANCO': 0,
    'VIGLIANO': 0,
    'VIGLIAROLO': 0,
    'VIGLIETTA': 0,
    'VIGLIONE': 0,
    'VIGLIOTTA': 0,
    'VIGLIOTTI': 0,
    'VIGNA': 0,
    'VIGNALE': 0,
    'VIGNALI': 0,
    'VIGNATI': 0,
    'VIGNE': 0,
    'VIGNEAU': 0,
    'VIGNEAULT': 0,
    'VIGNEAUX': 0,
    'VIGNERI': 0,
    'VIGNERON': 0,
    'VIGNERY': 0,
    'VIGNES': 0,
    'VIGNESS': 0,
    'VIGNOLA': 0,
    'VIGNOLO': 0,
    'VIGNONE': 0,
    'VIGO': 0,
    'VIGOA': 0,
    'VIGOR': 0,
    'VIGOREN': 0,
    'VIGORITO': 0,
    'VIGRASS': 0,
    'VIGUE': 0,
    'VIGUERAS': 0,
    'VIGUERIA': 0,
    'VIGUERIE': 0,
    'VIGUS': 0,
    'VIJ': 0,
    'VIJARRO': 0,
    'VIJAY': 0,
    'VIJAYAKUMAR': 0,
    'VIJAYAN': 0,
    'VIJIL': 0,
    'VIK': 0,
    'VIKE': 0,
    'VIKEN': 0,
    'VIKER': 0,
    'VIKI': 1,
    'VIKKI': 1,
    'VIKTORA': 0,
    'VIL': 0,
    'VILA': 0,
    'VILAND': 0,
    'VILANDRE': 0,
    'VILANO': 0,
    'VILANOVA': 0,
    'VILAR': 0,
    'VILARDI': 0,
    'VILARDO': 0,
    'VILARINO': 0,
    'VILAS': 0,
    'VILAY': 0,
    'VILAYSACK': 0,
    'VILAYVANH': 0,
    'VILBRUN': 0,
    'VILCA': 0,
    'VILCHECK': 0,
    'VILCHES': 0,
    'VILCHEZ': 0,
    'VILCHIS': 0,
    'VILD': 0,
    'VILDOSOLA': 0,
    'VILE': 0,
    'VILELA': 0,
    'VILELLA': 0,
    'VILENSKY': 0,
    'VILES': 0,
    'VILETA': 0,
    'VILHAUER': 0,
    'VILINSKY': 0,
    'VILJOEN': 0,
    'VILK': 0,
    'VILL': 0,
    'VILLA': 0,
    'VILLABONA': 0,
    'VILLABOS': 0,
    'VILLACAMPA': 0,
    'VILLACANA': 0,
    'VILLACCI': 0,
    'VILLACIS': 0,
    'VILLACORTA': 0,
    'VILLACRES': 0,
    'VILLACRESES': 0,
    'VILLADA': 0,
    'VILLAESCUSA': 0,
    'VILLAFAN': 0,
    'VILLAFANA': 0,
    'VILLAFANE': 0,
    'VILLAFANIA': 0,
    'VILLAFLOR': 0,
    'VILLAFLORES': 0,
    'VILLAFRANCA': 0,
    'VILLAFRANCO': 0,
    'VILLAFUERTE': 0,
    'VILLAGOMES': 0,
    'VILLAGOMEZ': 0,
    'VILLAGRA': 0,
    'VILLAGRACIA': 0,
    'VILLAGRAN': 0,
    'VILLAGRANA': 0,
    'VILLAHERMOSA': 0,
    'VILLAIRE': 0,
    'VILLALBA': 0,
    'VILLALOBO': 0,
    'VILLALOBOS': 0,
    'VILLALOBOZ': 0,
    'VILLALON': 0,
    'VILLALONA': 0,
    'VILLALONGA': 0,
    'VILLALONGO': 0,
    'VILLALOVOS': 0,
    'VILLALPANDO': 0,
    'VILLALTA': 0,
    'VILLALUNA': 0,
    'VILLALUZ': 0,
    'VILLALVA': 0,
    'VILLALVAZO': 0,
    'VILLAMAN': 0,
    'VILLAMAR': 0,
    'VILLAMARIN': 0,
    'VILLAMAYOR': 0,
    'VILLAMIL': 0,
    'VILLAMIN': 0,
    'VILLAMIZAR': 0,
    'VILLAMOR': 0,
    'VILLANDRY': 0,
    'VILLANE': 0,
    'VILLANEDA': 0,
    'VILLANEUVA': 0,
    'VILLANEVA': 0,
    'VILLANI': 0,
    'VILLANO': 0,
    'VILLANOVA': 0,
    'VILLANTE': 0,
    'VILLANTI': 0,
    'VILLANUEBA': 0,
    'VILLANUEVA': 0,
    'VILLANUVA': 0,
    'VILLAO': 0,
    'VILLAPANDO': 0,
    'VILLAPUDUA': 0,
    'VILLAR': 0,
    'VILLARAMA': 0,
    'VILLARAN': 0,
    'VILLARD': 0,
    'VILLAREAL': 0,
    'VILLAREALE': 0,
    'VILLARES': 0,
    'VILLARI': 0,
    'VILLARIN': 0,
    'VILLARINI': 0,
    'VILLARINO': 0,
    'VILLAROMAN': 0,
    'VILLARONGA': 0,
    'VILLAROSA': 0,
    'VILLARREAL': 0,
    'VILLARREL': 0,
    'VILLARROEL': 0,
    'VILLARRUBIA': 0,
    'VILLARRUEL': 0,
    'VILLARS': 0,
    'VILLARTA': 0,
    'VILLARUEL': 0,
    'VILLARUZ': 0,
    'VILLAS': 0,
    'VILLASANA': 0,
    'VILLASANO': 0,
    'VILLASENOR': 0,
    'VILLASIN': 0,
    'VILLASTRIGO': 0,
    'VILLATA': 0,
    'VILLATE': 0,
    'VILLATORO': 0,
    'VILLAVASO': 0,
    'VILLAVERDE': 0,
    'VILLAVICENCIO': 0,
    'VILLAZANA': 0,
    'VILLAZON': 0,
    'VILLE': 0,
    'VILLEBRUN': 0,
    'VILLECCO': 0,
    'VILLEDA': 0,
    'VILLEGA': 0,
    'VILLEGAS': 0,
    'VILLELA': 0,
    'VILLELLA': 0,
    'VILLEMAIRE': 0,
    'VILLEMARETTE': 0,
    'VILLEMEZ': 0,
    'VILLEMURE': 0,
    'VILLENA': 0,
    'VILLENEUVE': 0,
    'VILLERE': 0,
    'VILLEREAL': 0,
    'VILLEROT': 0,
    'VILLERREAL': 0,
    'VILLERS': 0,
    'VILLERY': 0,
    'VILLESCA': 0,
    'VILLESCAS': 0,
    'VILLESCAZ': 0,
    'VILLEZCAS': 0,
    'VILLHAUER': 0,
    'VILLIARD': 0,
    'VILLICANA': 0,
    'VILLIERS': 0,
    'VILLIGER': 0,
    'VILLINES': 0,
    'VILLINGER': 0,
    'VILLMER': 0,
    'VILLNAVE': 0,
    'VILLNOW': 0,
    'VILLOCH': 0,
    'VILLODAS': 0,
    'VILLON': 0,
    'VILLONE': 0,
    'VILLOT': 0,
    'VILLOTA': 0,
    'VILLWOCK': 0,
    'VILMA': 1,
    'VILME': 0,
    'VILOA': 0,
    'VILORIA': 0,
    'VILORIO': 0,
    'VILSACK': 0,
    'VILSAINT': 0,
    'VILSON': 0,
    'VILT': 0,
    'VILTZ': 0,
    'VIN': 0,
    'VINA': 0.9345794392523364,
    'VINACCO': 0,
    'VINAGRE': 0,
    'VINAL': 0,
    'VINALAY': 0,
    'VINALES': 0,
    'VINALL': 0,
    'VINAR': 0,
    'VINAS': 0,
    'VINASCO': 0,
    'VINATIERI': 0,
    'VINCA': 0,
    'VINCE': 0.9389671361502347,
    'VINCEK': 0,
    'VINCELETTE': 0,
    'VINCELLI': 0,
    'VINCENT': 0.8995020613588905,
    'VINCENTE': 0,
    'VINCENTI': 0,
    'VINCENTY': 0,
    'VINCENZA': 1,
    'VINCENZI': 0,
    'VINCENZO': 0.9756097560975611,
    'VINCER': 0,
    'VINCES': 0,
    'VINCH': 0,
    'VINCI': 0,
    'VINCIGUERRA': 0,
    'VINCIK': 0,
    'VINCIL': 0,
    'VINCK': 0,
    'VINCZE': 0,
    'VIND': 0,
    'VINDAS': 0,
    'VINDEL': 0,
    'VINDELL': 0,
    'VINDIGNI': 0,
    'VINDIOLA': 0,
    'VINDUSKA': 0,
    'VINE': 0,
    'VINEBERG': 0,
    'VINEGAR': 0,
    'VINELLI': 0,
    'VINER': 0,
    'VINES': 0,
    'VINESETT': 0,
    'VINET': 0,
    'VINETTE': 0,
    'VINEY': 0,
    'VINEYARD': 0,
    'VINGE': 0,
    'VINGER': 0,
    'VINH': 0,
    'VINIEGRA': 0,
    'VINIK': 0,
    'VINING': 0,
    'VINION': 0,
    'VINITA': 1,
    'VINITSKY': 0,
    'VINJE': 0,
    'VINK': 0,
    'VINKE': 0,
    'VINKEMEIER': 0,
    'VINKLAREK': 0,
    'VINKLER': 0,
    'VINLUAN': 0,
    'VINNEDGE': 0,
    'VINNETT': 0,
    'VINNIE': 1,
    'VINNIK': 0,
    'VINNING': 0,
    'VINO': 0,
    'VINOD': 0,
    'VINOGRADOV': 0,
    'VINOKUR': 0,
    'VINOKUROV': 0,
    'VINOPAL': 0,
    'VINOVICH': 0,
    'VINOYA': 0,
    'VINSANT': 0,
    'VINSKI': 0,
    'VINSON': 0,
    'VINSONHALER': 0,
    'VINSTON': 0,
    'VINT': 0,
    'VINTI': 0,
    'VINTIMILLA': 0,
    'VINTON': 0,
    'VINTSON': 0,
    'VINUEZA': 0,
    'VINUP': 0,
    'VINYARD': 0,
    'VINZ': 0,
    'VINZANT': 0,
    'VIOHL': 0,
    'VIOL': 0,
    'VIOLA': 0.9732910819375282,
    'VIOLAND': 0,
    'VIOLANTE': 0,
    'VIOLANTI': 0,
    'VIOLET': 0.9952534068289695,
    'VIOLETA': 1,
    'VIOLETT': 0,
    'VIOLETTE': 0.6211180124223602,
    'VIOLI': 0,
    'VIORATO': 0,
    'VIOX': 0,
    'VIPOND': 0,
    'VIPPERMAN': 0,
    'VIQUEZ': 0,
    'VIRA': 0,
    'VIRAG': 0,
    'VIRAMONTES': 0,
    'VIRAMONTEZ': 0,
    'VIRANI': 0,
    'VIRANT': 0,
    'VIRATA': 0,
    'VIRAY': 0,
    'VIRCHOW': 0,
    'VIRDELL': 0,
    'VIRDEN': 0,
    'VIRDI': 0,
    'VIRE': 0,
    'VIRELLA': 0,
    'VIREN': 0,
    'VIRES': 0,
    'VIRGA': 0,
    'VIRGADAMO': 0,
    'VIRGEN': 0.4926108374384237,
    'VIRGES': 0,
    'VIRGIE': 1,
    'VIRGIL': 0.9813542688910698,
    'VIRGILE': 0,
    'VIRGILI': 0,
    'VIRGILIO': 0.8968609865470852,
    'VIRGILLO': 0,
    'VIRGIN': 0,
    'VIRGINA': 1,
    'VIRGINIA': 0.999651284435662,
    'VIRGO': 0,
    'VIRGONA': 0,
    'VIRISSIMO': 0,
    'VIRK': 0,
    'VIRKLER': 0,
    'VIRKUS': 0,
    'VIRMANI': 0,
    'VIRNIG': 0,
    'VIROLA': 0,
    'VIROSTEK': 0,
    'VIROSTKO': 0,
    'VIRREY': 0,
    'VIRRUETA': 0,
    'VIRTA': 0,
    'VIRTO': 0,
    'VIRTS': 0,
    'VIRTUE': 0,
    'VIRTUOSO': 0,
    'VIRUET': 0,
    'VIRULA': 0,
    'VIRUS': 0,
    'VIRVET': 0,
    'VIRZI': 0,
    'VIS': 0,
    'VISAGE': 0,
    'VISAGGIO': 0,
    'VISALLI': 0,
    'VISARRAGA': 0,
    'VISAYA': 0,
    'VISBAL': 0,
    'VISCA': 0,
    'VISCAINO': 0,
    'VISCARDI': 0,
    'VISCARIELLO': 0,
    'VISCARRA': 0,
    'VISCEGLIA': 0,
    'VISCHER': 0,
    'VISCIONE': 0,
    'VISCO': 0,
    'VISCOME': 0,
    'VISCOMI': 0,
    'VISCONTE': 0,
    'VISCONTI': 0,
    'VISCOSI': 0,
    'VISCOUNT': 0,
    'VISCOVICH': 0,
    'VISCUSI': 0,
    'VISCUSO': 0,
    'VISE': 0,
    'VISEK': 0,
    'VISEL': 0,
    'VISELLI': 0,
    'VISENTIN': 0,
    'VISER': 0,
    'VISGER': 0,
    'VISH': 0,
    'VISHER': 0,
    'VISHNEVSKY': 0,
    'VISHWANATH': 0,
    'VISICH': 0,
    'VISINTAINER': 0,
    'VISINTIN': 0,
    'VISINTINE': 0,
    'VISITACION': 0,
    'VISK': 0,
    'VISKER': 0,
    'VISKOCIL': 0,
    'VISLAY': 0,
    'VISLOCKY': 0,
    'VISLOSKY': 0,
    'VISNAW': 0,
    'VISNER': 0,
    'VISNIC': 0,
    'VISNICH': 0,
    'VISNICK': 0,
    'VISO': 0,
    'VISOCKY': 0,
    'VISON': 0,
    'VISONE': 0,
    'VISOR': 0,
    'VISOSKY': 0,
    'VISOSO': 0,
    'VISPERAS': 0,
    'VISS': 0,
    'VISSCHER': 0,
    'VISSER': 0,
    'VISSERING': 0,
    'VISSERS': 0,
    'VISSICCHIO': 0,
    'VISSING': 0,
    'VISTA': 0,
    'VISTE': 0,
    'VISWANATH': 0,
    'VISWANATHAN': 0,
    'VIT': 0,
    'VITA': 0.8356545961002786,
    'VITACCO': 0,
    'VITAGLIANO': 0,
    'VITAL': 0,
    'VITALE': 0,
    'VITALES': 0,
    'VITALI': 0,
    'VITALIANO': 0,
    'VITALICH': 0,
    'VITALIE': 0,
    'VITALIS': 0,
    'VITALO': 0,
    'VITALONE': 0,
    'VITANZA': 0,
    'VITARELLI': 0,
    'VITAS': 0,
    'VITATOE': 0,
    'VITE': 0,
    'VITEK': 0,
    'VITELA': 0,
    'VITELLA': 0,
    'VITELLARO': 0,
    'VITELLI': 0,
    'VITELLO': 0,
    'VITER': 0,
    'VITERBO': 0,
    'VITERI': 0,
    'VITERITTI': 0,
    'VITETTA': 0,
    'VITEZ': 0,
    'VITH': 0,
    'VITI': 0,
    'VITIELLO': 0,
    'VITITOE': 0,
    'VITKAUSKAS': 0,
    'VITKO': 0,
    'VITKUS': 0,
    'VITO': 0.9336099585062241,
    'VITOLA': 0,
    'VITOLD': 0,
    'VITOLO': 0,
    'VITOLS': 0,
    'VITON': 0,
    'VITONE': 0,
    'VITORINO': 0,
    'VITOSH': 0,
    'VITOUS': 0,
    'VITRAND': 0,
    'VITRANO': 0,
    'VITRO': 0,
    'VITT': 0,
    'VITTA': 0,
    'VITTAL': 0,
    'VITTER': 0,
    'VITTETOE': 0,
    'VITTI': 0,
    'VITTINI': 0,
    'VITTITOE': 0,
    'VITTITOW': 0,
    'VITTO': 0,
    'VITTONE': 0,
    'VITTORE': 0,
    'VITTORI': 0,
    'VITTORIA': 0,
    'VITTORINI': 0,
    'VITTORIO': 0,
    'VITTORIOSO': 0,
    'VITTUM': 0,
    'VITUCCI': 0,
    'VITUG': 0,
    'VITULLI': 0,
    'VITULLO': 0,
    'VITZ': 0,
    'VITZTHUM': 0,
    'VIVA': 1,
    'VIVACQUA': 0,
    'VIVALDI': 0,
    'VIVALDO': 0,
    'VIVAN': 1,
    'VIVANCO': 0,
    'VIVAR': 0,
    'VIVAS': 0,
    'VIVEIROS': 0,
    'VIVENS': 0,
    'VIVENZIO': 0,
    'VIVERETTE': 0,
    'VIVERITO': 0,
    'VIVERO': 0,
    'VIVEROS': 0,
    'VIVES': 0,
    'VIVIAN': 0.9917633215666499,
    'VIVIANA': 1,
    'VIVIANI': 0,
    'VIVIANO': 0,
    'VIVIANS': 0,
    'VIVIEN': 1,
    'VIVIENNE': 1,
    'VIVIER': 0,
    'VIVINO': 0,
    'VIVIO': 0,
    'VIVION': 0,
    'VIVIRITO': 0,
    'VIVO': 0,
    'VIVOLO': 0,
    'VIVONA': 0,
    'VIX': 0,
    'VIXAMA': 0,
    'VIXAMAR': 0,
    'VIZARD': 0,
    'VIZCAINO': 0,
    'VIZCARRA': 0,
    'VIZCARRONDO': 0,
    'VIZCAYA': 0,
    'VIZE': 0,
    'VIZENA': 0,
    'VIZENOR': 0,
    'VIZER': 0,
    'VIZI': 0,
    'VIZIER': 0,
    'VIZINA': 0,
    'VIZOSO': 0,
    'VIZUET': 0,
    'VIZUETE': 0,
    'VIZUETH': 0,
    'VIZZA': 0,
    'VIZZARD': 0,
    'VIZZERRA': 0,
    'VIZZI': 0,
    'VIZZINI': 0,
    'VIZZO': 0,
    'VIZZONE': 0,
    'VLACH': 0,
    'VLACHOS': 0,
    'VLACICH': 0,
    'VLACK': 0,
    'VLAD': 0,
    'VLADIC': 0,
    'VLADIMIROV': 0,
    'VLADYKA': 0,
    'VLAHAKIS': 0,
    'VLAHOS': 0,
    'VLAHOVIC': 0,
    'VLAHOVICH': 0,
    'VLAMINCK': 0,
    'VLAMIS': 0,
    'VLASAK': 0,
    'VLASATY': 0,
    'VLASEK': 0,
    'VLASENKO': 0,
    'VLASIC': 0,
    'VLASIN': 0,
    'VLASIS': 0,
    'VLASOV': 0,
    'VLASSIS': 0,
    'VLASYUK': 0,
    'VLAUN': 0,
    'VLCEK': 0,
    'VLECK': 0,
    'VLIEGER': 0,
    'VLIEK': 0,
    'VLIEM': 0,
    'VLIET': 0,
    'VLIETSTRA': 0,
    'VLK': 0,
    'VNUK': 0,
    'VO': 0,
    'VOAKES': 0,
    'VOAS': 0,
    'VOBORIL': 0,
    'VOCATURO': 0,
    'VOCCIA': 0,
    'VOCCIO': 0,
    'VOCCOLA': 0,
    'VOCE': 0,
    'VOCELKA': 0,
    'VOCHATZER': 0,
    'VOCI': 0,
    'VOCK': 0,
    'VOCKE': 0,
    'VODA': 0,
    'VODAK': 0,
    'VODDEN': 0,
    'VODEHNAL': 0,
    'VODICKA': 0,
    'VODOLA': 0,
    'VODOPICH': 0,
    'VODRASKA': 0,
    'VODVARKA': 0,
    'VODZAK': 0,
    'VOECKS': 0,
    'VOEGE': 0,
    'VOEGEL': 0,
    'VOEGELE': 0,
    'VOEGELI': 0,
    'VOEGERL': 0,
    'VOEGTLE': 0,
    'VOEGTLIN': 0,
    'VOEHL': 0,
    'VOEHRINGER': 0,
    'VOEKS': 0,
    'VOELCKER': 0,
    'VOELKEL': 0,
    'VOELKER': 0,
    'VOELKL': 0,
    'VOELL': 0,
    'VOELLER': 0,
    'VOELLINGER': 0,
    'VOELPEL': 0,
    'VOELS': 0,
    'VOELTNER': 0,
    'VOELTZ': 0,
    'VOELZ': 0,
    'VOELZKE': 0,
    'VOEPEL': 0,
    'VOET': 0,
    'VOETBERG': 0,
    'VOETSCH': 0,
    'VOEUN': 0,
    'VOGAN': 0,
    'VOGE': 0,
    'VOGEL': 0,
    'VOGELAAR': 0,
    'VOGELBACHER': 0,
    'VOGELE': 0,
    'VOGELER': 0,
    'VOGELEY': 0,
    'VOGELGESANG': 0,
    'VOGELI': 0,
    'VOGELMAN': 0,
    'VOGELMANN': 0,
    'VOGELPOHL': 0,
    'VOGELS': 0,
    'VOGELSANG': 0,
    'VOGELSBERG': 0,
    'VOGELSONG': 0,
    'VOGELZANG': 0,
    'VOGEN': 0,
    'VOGES': 0,
    'VOGHT': 0,
    'VOGL': 0,
    'VOGLE': 0,
    'VOGLER': 0,
    'VOGLEWEDE': 0,
    'VOGRIN': 0,
    'VOGT': 0,
    'VOGTMAN': 0,
    'VOGTS': 0,
    'VOGUS': 0,
    'VOHLAND': 0,
    'VOHNOUTKA': 0,
    'VOHRA': 0,
    'VOHS': 0,
    'VOHWINKEL': 0,
    'VOICE': 0,
    'VOICU': 0,
    'VOID': 0,
    'VOIE': 0,
    'VOIERS': 0,
    'VOIGHT': 0,
    'VOIGT': 0,
    'VOIGTLANDER': 0,
    'VOIGTS': 0,
    'VOILAND': 0,
    'VOILES': 0,
    'VOILS': 0,
    'VOINCHE': 0,
    'VOIRIN': 0,
    'VOIROL': 0,
    'VOISARD': 0,
    'VOISE': 0,
    'VOISELLE': 0,
    'VOISEY': 0,
    'VOISIN': 0,
    'VOISINE': 0,
    'VOISINET': 0,
    'VOIT': 0,
    'VOITH': 0,
    'VOITIK': 0,
    'VOJACEK': 0,
    'VOJTA': 0,
    'VOJTECH': 0,
    'VOJTEK': 0,
    'VOJTKO': 0,
    'VOJVODICH': 0,
    'VOKAC': 0,
    'VOKE': 0,
    'VOKES': 0,
    'VOKEY': 0,
    'VOKOUN': 0,
    'VOLA': 0,
    'VOLAK': 0,
    'VOLAND': 0,
    'VOLANSKY': 0,
    'VOLANTE': 0,
    'VOLANTI': 0,
    'VOLBERDING': 0,
    'VOLBERT': 0,
    'VOLBRECHT': 0,
    'VOLCHKO': 0,
    'VOLCY': 0,
    'VOLD': 0,
    'VOLDEN': 0,
    'VOLEK': 0,
    'VOLENEC': 0,
    'VOLENTINE': 0,
    'VOLESKY': 0,
    'VOLF': 0,
    'VOLFSON': 0,
    'VOLIN': 0,
    'VOLINI': 0,
    'VOLINO': 0,
    'VOLINSKI': 0,
    'VOLINSKY': 0,
    'VOLIVA': 0,
    'VOLK': 0,
    'VOLKART': 0,
    'VOLKE': 0,
    'VOLKEMA': 0,
    'VOLKENANT': 0,
    'VOLKENING': 0,
    'VOLKENS': 0,
    'VOLKER': 0,
    'VOLKERDING': 0,
    'VOLKERS': 0,
    'VOLKERT': 0,
    'VOLKING': 0,
    'VOLKMAN': 0,
    'VOLKMANN': 0,
    'VOLKMAR': 0,
    'VOLKMER': 0,
    'VOLKOFF': 0,
    'VOLKOV': 0,
    'VOLKOVA': 0,
    'VOLL': 0,
    'VOLLAN': 0,
    'VOLLAND': 0,
    'VOLLARO': 0,
    'VOLLBRACHT': 0,
    'VOLLBRECHT': 0,
    'VOLLE': 0,
    'VOLLEN': 0,
    'VOLLENDORF': 0,
    'VOLLENTINE': 0,
    'VOLLENWEIDER': 0,
    'VOLLER': 0,
    'VOLLERO': 0,
    'VOLLERS': 0,
    'VOLLERT': 0,
    'VOLLERTSEN': 0,
    'VOLLICK': 0,
    'VOLLING': 0,
    'VOLLINK': 0,
    'VOLLKOMMER': 0,
    'VOLLMAN': 0,
    'VOLLMANN': 0,
    'VOLLMAR': 0,
    'VOLLMER': 0,
    'VOLLMERHAUSEN': 0,
    'VOLLMERS': 0,
    'VOLLMUTH': 0,
    'VOLLRATH': 0,
    'VOLLSTEDT': 0,
    'VOLLWEILER': 0,
    'VOLM': 0,
    'VOLMAN': 0,
    'VOLMAR': 0,
    'VOLMER': 0,
    'VOLMERING': 0,
    'VOLMERT': 0,
    'VOLNER': 0,
    'VOLNEY': 0,
    'VOLNY': 0,
    'VOLO': 0,
    'VOLOSHIN': 0,
    'VOLOSIN': 0,
    'VOLP': 0,
    'VOLPE': 0,
    'VOLPENHEIN': 0,
    'VOLPER': 0,
    'VOLPERT': 0,
    'VOLPI': 0,
    'VOLPICELLA': 0,
    'VOLPICELLI': 0,
    'VOLPINI': 0,
    'VOLPONE': 0,
    'VOLPONI': 0,
    'VOLPP': 0,
    'VOLQUARDSEN': 0,
    'VOLQUEZ': 0,
    'VOLRATH': 0,
    'VOLSKY': 0,
    'VOLSTAD': 0,
    'VOLTA': 0,
    'VOLTAGGIO': 0,
    'VOLTAIRE': 0,
    'VOLTER': 0,
    'VOLTIN': 0,
    'VOLTMER': 0,
    'VOLTURO': 0,
    'VOLTZ': 0,
    'VOLZ': 0,
    'VOLZER': 0,
    'VOLZKE': 0,
    'VOMACKA': 0,
    'VOMERO': 0,
    'VOMUND': 0,
    'VON': 0.9685230024213075,
    'VONA': 0,
    'VONACHEN': 0,
    'VONADA': 0,
    'VONAHN': 0,
    'VONAHSEN': 0,
    'VONALLMEN': 0,
    'VONALMEN': 0,
    'VONARX': 0,
    'VONASEK': 0,
    'VONBANK': 0,
    'VONBARGEN': 0,
    'VONBEHREN': 0,
    'VONBERG': 0,
    'VONBERGEN': 0,
    'VONBORSTEL': 0,
    'VONBURG': 0,
    'VONCANNON': 0,
    'VONCANON': 0,
    'VONCILE': 1,
    'VONDA': 1,
    'VONDAL': 0,
    'VONDELL': 0,
    'VONDENHUEVEL': 0,
    'VONDERAHE': 0,
    'VONDERAU': 0,
    'VONDEREMBSE': 0,
    'VONDERHAAR': 0,
    'VONDERHARR': 0,
    'VONDERHEIDE': 0,
    'VONDERLIETH': 0,
    'VONDEROHE': 0,
    'VONDERSAAR': 0,
    'VONDERSCHMIDT': 0,
    'VONDETTE': 0,
    'VONDEYLEN': 0,
    'VONDIELINGEN': 0,
    'VONDOHLEN': 0,
    'VONDOLLEN': 0,
    'VONDRA': 0,
    'VONDRACEK': 0,
    'VONDRAK': 0,
    'VONDRAN': 0,
    'VONDRASEK': 0,
    'VONDRISKA': 0,
    'VONDRUSKA': 0,
    'VONDY': 0,
    'VONENDE': 0,
    'VONER': 0,
    'VONESCHEN': 0,
    'VONESH': 0,
    'VONESSEN': 0,
    'VONFANGE': 0,
    'VONFELDT': 0,
    'VONFRICKEN': 0,
    'VONG': 0,
    'VONGDARA': 0,
    'VONGKHAMCHANH': 0,
    'VONGLAHN': 0,
    'VONGONTEN': 0,
    'VONGPANYA': 0,
    'VONGPHACHANH': 0,
    'VONGPHAKDY': 0,
    'VONGPHRACHANH': 0,
    'VONGPRACHANH': 0,
    'VONGSA': 0,
    'VONGSAVATH': 0,
    'VONGSOUVANH': 0,
    'VONGUNTEN': 0,
    'VONGXAY': 0,
    'VONHADEN': 0,
    'VONHAGEL': 0,
    'VONHAGEN': 0,
    'VONHANDORF': 0,
    'VONHATTEN': 0,
    'VONHEEDER': 0,
    'VONHOENE': 0,
    'VONHOF': 0,
    'VONHOLDT': 0,
    'VONHOLT': 0,
    'VONHOLTEN': 0,
    'VONIER': 0,
    'VONK': 0,
    'VONKAENEL': 0,
    'VONKAMPEN': 0,
    'VONKANEL': 0,
    'VONLEHMDEN': 0,
    'VONLINTEL': 0,
    'VONLOH': 0,
    'VONMINDEN': 0,
    'VONMOOS': 0,
    'VONNAHME': 0,
    'VONNER': 0,
    'VONNIE': 1,
    'VONO': 0,
    'VONOHLEN': 0,
    'VONROHR': 0,
    'VONROSENBERG': 0,
    'VONROTZ': 0,
    'VONRUDEN': 0,
    'VONRUEDEN': 0,
    'VONSCHRILTZ': 0,
    'VONSEGGERN': 0,
    'VONSTEIN': 0,
    'VONTERSCH': 0,
    'VONTHADEN': 0,
    'VONTHUN': 0,
    'VONTOBEL': 0,
    'VONTRESS': 0,
    'VONTUNGELN': 0,
    'VONTZ': 0,
    'VONWAHLDE': 0,
    'VONWALD': 0,
    'VOOGD': 0,
    'VOOGT': 0,
    'VOONG': 0,
    'VOORHEES': 0,
    'VOORHEIS': 0,
    'VOORHES': 0,
    'VOORHIES': 0,
    'VOORHIS': 0,
    'VOORIS': 0,
    'VOORS': 0,
    'VOOS': 0,
    'VOPAT': 0,
    'VORA': 0,
    'VORACEK': 0,
    'VORACHACK': 0,
    'VORACHEK': 0,
    'VORAN': 0,
    'VORASANE': 0,
    'VORAVONG': 0,
    'VORBECK': 0,
    'VORCE': 0,
    'VORDERBRUGGEN': 0,
    'VORDERSTRASSE': 0,
    'VORE': 0,
    'VOREIS': 0,
    'VOREL': 0,
    'VORENKAMP': 0,
    'VORHAUER': 0,
    'VORHEES': 0,
    'VORHEIS': 0,
    'VORHES': 0,
    'VORHIES': 0,
    'VORHIS': 0,
    'VORHOLT': 0,
    'VORIES': 0,
    'VORIS': 0,
    'VORISEK': 0,
    'VORK': 0,
    'VORMITTAG': 0,
    'VORN': 0,
    'VORNBROCK': 0,
    'VORNDRAN': 0,
    'VORNHOLT': 0,
    'VORON': 0,
    'VORONIN': 0,
    'VOROS': 0,
    'VOROUS': 0,
    'VORPAGEL': 0,
    'VORPAHL': 0,
    'VORRATH': 0,
    'VORSE': 0,
    'VORST': 0,
    'VORTHERMS': 0,
    'VORWALD': 0,
    'VORWALLER': 0,
    'VORWERK': 0,
    'VOS': 0,
    'VOSBERG': 0,
    'VOSBURG': 0,
    'VOSBURGH': 0,
    'VOSE': 0,
    'VOSEJPKA': 0,
    'VOSEN': 0,
    'VOSHALL': 0,
    'VOSHEL': 0,
    'VOSHELL': 0,
    'VOSIKA': 0,
    'VOSKAMP': 0,
    'VOSKANIAN': 0,
    'VOSKANYAN': 0,
    'VOSKOBOYNIK': 0,
    'VOSKUHL': 0,
    'VOSKUIL': 0,
    'VOSLER': 0,
    'VOSPER': 0,
    'VOSS': 0,
    'VOSSBERG': 0,
    'VOSSEKUIL': 0,
    'VOSSELER': 0,
    'VOSSELLER': 0,
    'VOSSEN': 0,
    'VOSSLER': 0,
    'VOSSOUGHI': 0,
    'VOSTAD': 0,
    'VOSTERS': 0,
    'VOTA': 0,
    'VOTANO': 0,
    'VOTAVA': 0,
    'VOTAW': 0,
    'VOTE': 0,
    'VOTEL': 0,
    'VOTER': 0,
    'VOTH': 0,
    'VOTINO': 0,
    'VOTION': 0,
    'VOTO': 0,
    'VOTOLATO': 0,
    'VOTRA': 0,
    'VOTRUBA': 0,
    'VOTTA': 0,
    'VOTTERO': 0,
    'VOTTO': 0,
    'VOUDRIE': 0,
    'VOUGH': 0,
    'VOUGHT': 0,
    'VOUK': 0,
    'VOULGARIS': 0,
    'VOUNG': 0,
    'VOUTSINAS': 0,
    'VOVES': 0,
    'VOVK': 0,
    'VOWELL': 0,
    'VOWELS': 0,
    'VOWLES': 0,
    'VOXLAND': 0,
    'VOY': 0,
    'VOYCE': 0,
    'VOYDA': 0,
    'VOYE': 0,
    'VOYER': 0,
    'VOYLES': 0,
    'VOYTEK': 0,
    'VOYTILLA': 0,
    'VOYTKO': 0,
    'VOYTOVICH': 0,
    'VOZAR': 0,
    'VOZEL': 0,
    'VOZELLA': 0,
    'VOZENILEK': 0,
    'VOZNYUK': 0,
    'VOZZA': 0,
    'VOZZELLA': 0,
    'VOZZO': 0,
    'VRAA': 0,
    'VRABEC': 0,
    'VRABEL': 0,
    'VRABLE': 0,
    'VRABLIC': 0,
    'VRADENBURG': 0,
    'VRADENBURGH': 0,
    'VRANA': 0,
    'VRANAS': 0,
    'VRANEK': 0,
    'VRANES': 0,
    'VRANESH': 0,
    'VRANEY': 0,
    'VRANIC': 0,
    'VRANICAR': 0,
    'VRANICH': 0,
    'VRANISH': 0,
    'VRANJES': 0,
    'VRASPIR': 0,
    'VRAZEL': 0,
    'VRBA': 0,
    'VRBAS': 0,
    'VRBKA': 0,
    'VRCHOTA': 0,
    'VREDENBURG': 0,
    'VREDENBURGH': 0,
    'VREDEVELD': 0,
    'VREDEVOOGD': 0,
    'VREE': 0,
    'VREEKE': 0,
    'VREEKEN': 0,
    'VREELAND': 0,
    'VREEMAN': 0,
    'VRETTOS': 0,
    'VREUGDENHIL': 0,
    'VRIELING': 0,
    'VRIESMAN': 0,
    'VRIEZE': 0,
    'VROBEL': 0,
    'VROEGINDEWEY': 0,
    'VROMAN': 0,
    'VRONA': 0,
    'VROOM': 0,
    'VROOMAN': 0,
    'VROTSOS': 0,
    'VRTIS': 0,
    'VRTISKA': 0,
    'VRUGGINK': 0,
    'VRUWINK': 0,
    'VRYHOF': 0,
    'VSETECKA': 0,
    'VU': 0,
    'VUCCI': 0,
    'VUCIC': 0,
    'VUCICH': 0,
    'VUCKOVIC': 0,
    'VUCKOVICH': 0,
    'VUE': 0,
    'VUELVAS': 0,
    'VUGTEVEEN': 0,
    'VUICH': 0,
    'VUICHARD': 0,
    'VUILLEMOT': 0,
    'VUITTONET': 0,
    'VUJNOVICH': 0,
    'VUJOVICH': 0,
    'VUKAS': 0,
    'VUKASIN': 0,
    'VUKELIC': 0,
    'VUKELICH': 0,
    'VUKIC': 0,
    'VUKICH': 0,
    'VUKONICH': 0,
    'VUKOV': 0,
    'VUKOVIC': 0,
    'VUKOVICH': 0,
    'VUKSON': 0,
    'VULAJ': 0,
    'VULCAN': 0,
    'VULCANO': 0,
    'VULETICH': 0,
    'VULGAMORE': 0,
    'VULGAMOTT': 0,
    'VULIC': 0,
    'VULICH': 0,
    'VULLO': 0,
    'VULPIS': 0,
    'VULTAGGIO': 0,
    'VUNCANNON': 0,
    'VUNK': 0,
    'VUOCOLO': 0,
    'VUOLO': 0,
    'VUONG': 0,
    'VUONO': 0,
    'VUOSO': 0,
    'VUOTTO': 0,
    'VUU': 0,
    'VUYLSTEKE': 0,
    'VY': 0,
    'VYAS': 0,
    'VYBIRAL': 0,
    'VYBORNY': 0,
    'VYE': 0,
    'VYHLIDAL': 0,
    'VYSE': 0,
    'VYSKOCIL': 0,
    'VYVERBERG': 0,
    'VYVYAN': 0,
    'WA': 0,
    'WAACK': 0,
    'WAAG': 0,
    'WAAGE': 0,
    'WAAGEN': 0,
    'WAAK': 0,
    'WAALEN': 0,
    'WAALKES': 0,
    'WAARA': 0,
    'WAAS': 0,
    'WAASDORP': 0,
    'WABEKE': 0,
    'WABEL': 0,
    'WABER': 0,
    'WABLE': 0,
    'WABNITZ': 0,
    'WACASER': 0,
    'WACASEY': 0,
    'WACASTER': 0,
    'WACEK': 0,
    'WACH': 0,
    'WACHA': 0,
    'WACHAL': 0,
    'WACHALA': 0,
    'WACHEL': 0,
    'WACHENDORF': 0,
    'WACHHOLZ': 0,
    'WACHLIN': 0,
    'WACHMAN': 0,
    'WACHNER': 0,
    'WACHOB': 0,
    'WACHOLZ': 0,
    'WACHOWIAK': 0,
    'WACHOWICZ': 0,
    'WACHOWSKI': 0,
    'WACHS': 0,
    'WACHSMAN': 0,
    'WACHSMANN': 0,
    'WACHSMUTH': 0,
    'WACHT': 0,
    'WACHTEL': 0,
    'WACHTER': 0,
    'WACHTLER': 0,
    'WACHTMAN': 0,
    'WACK': 0,
    'WACKER': 0,
    'WACKERLE': 0,
    'WACKERLY': 0,
    'WACKERMAN': 0,
    'WACKETT': 0,
    'WACKLER': 0,
    'WACKS': 0,
    'WACLAWIK': 0,
    'WACLAWSKI': 0,
    'WACTOR': 0,
    'WADA': 0,
    'WADAS': 0,
    'WADD': 0,
    'WADDEL': 0,
    'WADDELL': 0,
    'WADDEN': 0,
    'WADDEY': 0,
    'WADDICK': 0,
    'WADDILL': 0,
    'WADDING': 0,
    'WADDINGHAM': 0,
    'WADDINGTON': 0,
    'WADDLE': 0,
    'WADDLES': 0,
    'WADDLETON': 0,
    'WADDOUPS': 0,
    'WADDY': 0,
    'WADE': 0.5666792595391009,
    'WADEL': 0,
    'WADELL': 0,
    'WADEMAN': 0,
    'WADEN': 0,
    'WADER': 0,
    'WADESON': 0,
    'WADEWITZ': 0,
    'WADFORD': 0,
    'WADHAMS': 0,
    'WADHWA': 0,
    'WADHWANI': 0,
    'WADI': 0,
    'WADIA': 0,
    'WADKINS': 0,
    'WADLE': 0,
    'WADLEIGH': 0,
    'WADLER': 0,
    'WADLEY': 0,
    'WADLINGER': 0,
    'WADLINGTON': 0,
    'WADLOW': 0,
    'WADMAN': 0,
    'WADOLOWSKI': 0,
    'WADSACK': 0,
    'WADSLEY': 0,
    'WADSWORTH': 0,
    'WADUD': 0,
    'WADY': 0,
    'WADZINSKI': 0,
    'WAECHTER': 0,
    'WAEGE': 0,
    'WAEGHE': 0,
    'WAELCHLI': 0,
    'WAELDE': 0,
    'WAELDER': 0,
    'WAELTI': 0,
    'WAELTZ': 0,
    'WAER': 0,
    'WAERS': 0,
    'WAESCHE': 0,
    'WAFER': 0,
    'WAFF': 0,
    'WAFFLE': 0,
    'WAFFORD': 0,
    'WAGA': 0,
    'WAGAMAN': 0,
    'WAGAR': 0,
    'WAGE': 0,
    'WAGEMAKER': 0,
    'WAGEMAN': 0,
    'WAGEMANN': 0,
    'WAGENAAR': 0,
    'WAGENBACH': 0,
    'WAGENBLAST': 0,
    'WAGENBRENNER': 0,
    'WAGENER': 0,
    'WAGENHALS': 0,
    'WAGENHAUSER': 0,
    'WAGENHEIM': 0,
    'WAGENHOFFER': 0,
    'WAGENKNECHT': 0,
    'WAGENMAKER': 0,
    'WAGENMAN': 0,
    'WAGENSCHUTZ': 0,
    'WAGENSELLER': 0,
    'WAGER': 0,
    'WAGERMAN': 0,
    'WAGERS': 0,
    'WAGES': 0,
    'WAGG': 0,
    'WAGGAMAN': 0,
    'WAGGANER': 0,
    'WAGGENER': 0,
    'WAGGENSPACK': 0,
    'WAGGETT': 0,
    'WAGGLE': 0,
    'WAGGNER': 0,
    'WAGGONER': 0,
    'WAGGY': 0,
    'WAGH': 0,
    'WAGHER': 0,
    'WAGLE': 0,
    'WAGLER': 0,
    'WAGLEY': 0,
    'WAGMAN': 0,
    'WAGNAC': 0,
    'WAGNER': 0,
    'WAGNITZ': 0,
    'WAGNON': 0,
    'WAGNOR': 0,
    'WAGON': 0,
    'WAGONER': 0,
    'WAGOR': 0,
    'WAGSCHAL': 0,
    'WAGSTAFF': 0,
    'WAGSTER': 0,
    'WAGUESPACK': 0,
    'WAGY': 0,
    'WAH': 0,
    'WAHAB': 0,
    'WAHBA': 0,
    'WAHBY': 0,
    'WAHDAN': 0,
    'WAHEED': 0,
    'WAHI': 0,
    'WAHID': 0,
    'WAHIDI': 0,
    'WAHL': 0,
    'WAHLBERG': 0,
    'WAHLBORG': 0,
    'WAHLBRINK': 0,
    'WAHLE': 0,
    'WAHLEN': 0,
    'WAHLER': 0,
    'WAHLERS': 0,
    'WAHLERT': 0,
    'WAHLGREN': 0,
    'WAHLIG': 0,
    'WAHLIN': 0,
    'WAHLMAN': 0,
    'WAHLMEIER': 0,
    'WAHLQUIST': 0,
    'WAHLS': 0,
    'WAHLSTROM': 0,
    'WAHLUND': 0,
    'WAHMAN': 0,
    'WAHN': 0,
    'WAHNER': 0,
    'WAHNON': 0,
    'WAHOFF': 0,
    'WAHR': 0,
    'WAHRER': 0,
    'WAHRMAN': 0,
    'WAHRMUND': 0,
    'WAI': 0.8474576271186441,
    'WAIBEL': 0,
    'WAIBLE': 0,
    'WAID': 0,
    'WAIDA': 0,
    'WAIDE': 0,
    'WAIDELICH': 0,
    'WAIDEN': 0,
    'WAIDNER': 0,
    'WAIER': 0,
    'WAIGAND': 0,
    'WAIGHT': 0,
    'WAIKEL': 0,
    'WAILES': 0,
    'WAIN': 0,
    'WAINE': 0,
    'WAINER': 0,
    'WAINIO': 0,
    'WAINMAN': 0,
    'WAINRIGHT': 0,
    'WAINSCOTT': 0,
    'WAINWRIGHT': 0,
    'WAIPA': 0,
    'WAIR': 0,
    'WAIRE': 0,
    'WAIS': 0,
    'WAISANEN': 0,
    'WAISMAN': 0,
    'WAISNER': 0,
    'WAISS': 0,
    'WAIT': 0,
    'WAITE': 0,
    'WAITER': 0,
    'WAITERS': 0,
    'WAITES': 0,
    'WAITH': 0,
    'WAITHE': 0,
    'WAITHOUR': 0,
    'WAITKUS': 0,
    'WAITLEY': 0,
    'WAITMAN': 0,
    'WAITON': 0,
    'WAITS': 0,
    'WAITT': 0,
    'WAITZ': 0,
    'WAITZMAN': 0,
    'WAIWAIOLE': 0,
    'WAIZ': 0,
    'WAJDA': 0,
    'WAJER': 0,
    'WAKABAYASHI': 0,
    'WAKAI': 0,
    'WAKAMATSU': 0,
    'WAKAYAMA': 0,
    'WAKE': 0,
    'WAKEEN': 0,
    'WAKEFIELD': 0,
    'WAKEFORD': 0,
    'WAKEHAM': 0,
    'WAKELAND': 0,
    'WAKELEE': 0,
    'WAKELEY': 0,
    'WAKELIN': 0,
    'WAKELING': 0,
    'WAKELY': 0,
    'WAKEM': 0,
    'WAKEMAN': 0,
    'WAKEN': 0,
    'WAKER': 0,
    'WAKI': 0,
    'WAKIDA': 0,
    'WAKIM': 0,
    'WAKIN': 0,
    'WAKINS': 0,
    'WAKITA': 0,
    'WAKLEY': 0,
    'WAKS': 0,
    'WAKSMAN': 0,
    'WAKSMUNSKI': 0,
    'WAKUMOTO': 0,
    'WAL': 0,
    'WALA': 0,
    'WALACE': 0,
    'WALACH': 0,
    'WALAS': 0,
    'WALASEK': 0,
    'WALASZEK': 0,
    'WALAT': 0,
    'WALAWENDER': 0,
    'WALBAUM': 0,
    'WALBECK': 0,
    'WALBER': 0,
    'WALBERG': 0,
    'WALBERT': 0,
    'WALBOLT': 0,
    'WALBORN': 0,
    'WALBRIDGE': 0,
    'WALBRUN': 0,
    'WALBURG': 0,
    'WALBURGER': 0,
    'WALBURN': 0,
    'WALBY': 0,
    'WALCH': 0,
    'WALCHAK': 0,
    'WALCHER': 0,
    'WALCHESKI': 0,
    'WALCHLE': 0,
    'WALCHLI': 0,
    'WALCK': 0,
    'WALCKER': 0,
    'WALCOFF': 0,
    'WALCOTT': 0,
    'WALCUTT': 0,
    'WALCZAK': 0,
    'WALCZEWSKI': 0,
    'WALCZUK': 0,
    'WALCZYK': 0,
    'WALD': 0,
    'WALDA': 0,
    'WALDAL': 0,
    'WALDBAUER': 0,
    'WALDBAUM': 0,
    'WALDBILLIG': 0,
    'WALDBURGER': 0,
    'WALDE': 0,
    'WALDECK': 0,
    'WALDECKER': 0,
    'WALDEMAR': 0,
    'WALDEN': 0,
    'WALDENMAIER': 0,
    'WALDER': 0,
    'WALDERA': 0,
    'WALDERS': 0,
    'WALDFOGEL': 0,
    'WALDHART': 0,
    'WALDHAUSER': 0,
    'WALDHEIM': 0,
    'WALDHERR': 0,
    'WALDHOFF': 0,
    'WALDIE': 0,
    'WALDING': 0,
    'WALDINGER': 0,
    'WALDKIRCH': 0,
    'WALDMAN': 0,
    'WALDMANN': 0,
    'WALDMILLER': 0,
    'WALDNER': 0,
    'WALDO': 0.744047619047619,
    'WALDOCH': 0,
    'WALDOCK': 0,
    'WALDON': 0,
    'WALDORF': 0,
    'WALDOW': 0,
    'WALDOWSKI': 0,
    'WALDRAM': 0,
    'WALDREN': 0,
    'WALDREP': 0,
    'WALDRIDGE': 0,
    'WALDRIP': 0,
    'WALDROFF': 0,
    'WALDRON': 0,
    'WALDROOP': 0,
    'WALDROP': 0,
    'WALDROUP': 0,
    'WALDRUM': 0,
    'WALDRUP': 0,
    'WALDSCHMIDT': 0,
    'WALDSMITH': 0,
    'WALDSTEIN': 0,
    'WALDT': 0,
    'WALDVOGEL': 0,
    'WALE': 0,
    'WALECKA': 0,
    'WALEGA': 0,
    'WALEK': 0,
    'WALEN': 0,
    'WALENDZIK': 0,
    'WALENGA': 0,
    'WALENT': 0,
    'WALENTA': 0,
    'WALENTINY': 0,
    'WALENTOWSKI': 0,
    'WALER': 0,
    'WALERIUS': 0,
    'WALES': 0,
    'WALESKI': 0,
    'WALETZKO': 0,
    'WALEWSKI': 0,
    'WALEY': 0,
    'WALFISH': 0,
    'WALFORD': 0,
    'WALGENBACH': 0,
    'WALGREN': 0,
    'WALHEIM': 0,
    'WALHOF': 0,
    'WALHOOD': 0,
    'WALI': 0,
    'WALIA': 0,
    'WALICKI': 0,
    'WALICZEK': 0,
    'WALIGORA': 0,
    'WALIGORSKI': 0,
    'WALIGURA': 0,
    'WALIN': 0,
    'WALING': 0,
    'WALINSKI': 0,
    'WALIS': 0,
    'WALISER': 0,
    'WALISZEWSKI': 0,
    'WALIZER': 0,
    'WALJI': 0,
    'WALK': 0,
    'WALKA': 0,
    'WALKAMA': 0,
    'WALKDEN': 0,
    'WALKE': 0,
    'WALKEN': 0,
    'WALKENBACH': 0,
    'WALKENHORST': 0,
    'WALKER': 0.026201331027616202,
    'WALKES': 0,
    'WALKEY': 0,
    'WALKIEWICZ': 0,
    'WALKIN': 0,
    'WALKINGEAGLE': 0,
    'WALKINGSTICK': 0,
    'WALKINGTON': 0,
    'WALKINS': 0,
    'WALKINSHAW': 0,
    'WALKLEY': 0,
    'WALKLING': 0,
    'WALKNER': 0,
    'WALKO': 0,
    'WALKOSZ': 0,
    'WALKOVIAK': 0,
    'WALKOWIAK': 0,
    'WALKOWICZ': 0,
    'WALKOWSKI': 0,
    'WALKS': 0,
    'WALKUP': 0,
    'WALKUSH': 0,
    'WALKUSKI': 0,
    'WALL': 0,
    'WALLA': 0,
    'WALLACE': 0.4419540683450399,
    'WALLACH': 0,
    'WALLACK': 0,
    'WALLAERT': 0,
    'WALLAKER': 0,
    'WALLAN': 0,
    'WALLANDER': 0,
    'WALLAR': 0,
    'WALLAS': 0,
    'WALLAT': 0,
    'WALLBANK': 0,
    'WALLBAUM': 0,
    'WALLBERG': 0,
    'WALLBROWN': 0,
    'WALLCE': 0,
    'WALLE': 0,
    'WALLECK': 0,
    'WALLEM': 0,
    'WALLEN': 0,
    'WALLENBERG': 0,
    'WALLENBURG': 0,
    'WALLENDAL': 0,
    'WALLENDER': 0,
    'WALLENDORF': 0,
    'WALLENFANG': 0,
    'WALLENHORST': 0,
    'WALLENIUS': 0,
    'WALLENS': 0,
    'WALLENSTEIN': 0,
    'WALLENTINE': 0,
    'WALLER': 0,
    'WALLERICH': 0,
    'WALLERIUS': 0,
    'WALLERS': 0,
    'WALLERSTEDT': 0,
    'WALLERSTEIN': 0,
    'WALLERT': 0,
    'WALLES': 0,
    'WALLESER': 0,
    'WALLET': 0,
    'WALLETT': 0,
    'WALLETTE': 0,
    'WALLEY': 0,
    'WALLGREN': 0,
    'WALLI': 0,
    'WALLICH': 0,
    'WALLICK': 0,
    'WALLIN': 0,
    'WALLINE': 0,
    'WALLING': 0,
    'WALLINGA': 0,
    'WALLINGER': 0,
    'WALLINGFORD': 0,
    'WALLINGSFORD': 0,
    'WALLINGTON': 0,
    'WALLIS': 0,
    'WALLISCH': 0,
    'WALLISER': 0,
    'WALLISH': 0,
    'WALLITSCH': 0,
    'WALLJASPER': 0,
    'WALLMAN': 0,
    'WALLNER': 0,
    'WALLO': 0,
    'WALLOCH': 0,
    'WALLOCK': 0,
    'WALLON': 0,
    'WALLOP': 0,
    'WALLPE': 0,
    'WALLRAFF': 0,
    'WALLRATH': 0,
    'WALLRICH': 0,
    'WALLS': 0,
    'WALLSCHLAEGER': 0,
    'WALLSMITH': 0,
    'WALLSTROM': 0,
    'WALLUM': 0,
    'WALLWORK': 0,
    'WALLY': 0.9546539379474941,
    'WALMA': 0,
    'WALMAN': 0,
    'WALMER': 0,
    'WALMSLEY': 0,
    'WALN': 0,
    'WALNER': 0,
    'WALNOHA': 0,
    'WALP': 0,
    'WALPER': 0,
    'WALPERT': 0,
    'WALPOLE': 0,
    'WALPOOL': 0,
    'WALQUIST': 0,
    'WALRATH': 0,
    'WALRAVEN': 0,
    'WALROD': 0,
    'WALROND': 0,
    'WALS': 0,
    'WALSCH': 0,
    'WALSDORF': 0,
    'WALSER': 0,
    'WALSETH': 0,
    'WALSH': 0,
    'WALSHAK': 0,
    'WALSHAW': 0,
    'WALSHE': 0,
    'WALSINGHAM': 0,
    'WALSKI': 0,
    'WALSKY': 0,
    'WALSON': 0,
    'WALSTAD': 0,
    'WALSTEAD': 0,
    'WALSTEN': 0,
    'WALSTON': 0,
    'WALSTRA': 0,
    'WALSTROM': 0,
    'WALSTRUM': 0,
    'WALSWORTH': 0,
    'WALT': 0,
    'WALTA': 0,
    'WALTEMATH': 0,
    'WALTEMEYER': 0,
    'WALTEMIRE': 0,
    'WALTEMYER': 0,
    'WALTENBAUGH': 0,
    'WALTENBURG': 0,
    'WALTER': 0.9578406783709543,
    'WALTERHOUSE': 0,
    'WALTERICK': 0,
    'WALTERMAN': 0,
    'WALTERMEYER': 0,
    'WALTERMIRE': 0,
    'WALTERMYER': 0,
    'WALTERS': 0,
    'WALTERSCHEID': 0,
    'WALTERSDORF': 0,
    'WALTH': 0,
    'WALTHALL': 0,
    'WALTHER': 0,
    'WALTHERS': 0,
    'WALTHOUR': 0,
    'WALTI': 0,
    'WALTIMYER': 0,
    'WALTJEN': 0,
    'WALTKE': 0,
    'WALTMAN': 0,
    'WALTMIRE': 0,
    'WALTMON': 0,
    'WALTNER': 0,
    'WALTO': 0,
    'WALTON': 0.13192612137203166,
    'WALTOS': 0,
    'WALTOWER': 0,
    'WALTRAUD': 1,
    'WALTRIP': 0,
    'WALTS': 0,
    'WALTY': 0,
    'WALTZ': 0,
    'WALTZER': 0,
    'WALUK': 0,
    'WALUS': 0,
    'WALVATNE': 0,
    'WALVOORD': 0,
    'WALWORTH': 0,
    'WALWYN': 0,
    'WALZ': 0,
    'WALZAK': 0,
    'WALZEL': 0,
    'WALZER': 0,
    'WAMACK': 0,
    'WAMBACH': 0,
    'WAMBAUGH': 0,
    'WAMBEKE': 0,
    'WAMBLE': 0,
    'WAMBLES': 0,
    'WAMBOLD': 0,
    'WAMBOLDT': 0,
    'WAMBOLT': 0,
    'WAMBSGANSS': 0,
    'WAMER': 0,
    'WAMHOFF': 0,
    'WAMMACK': 0,
    'WAMPLER': 0,
    'WAMPNER': 0,
    'WAMPOLE': 0,
    'WAMSER': 0,
    'WAMSHER': 0,
    'WAMSLEY': 0,
    'WAN': 0.36900369003690037,
    'WANAMAKER': 0,
    'WANAT': 0,
    'WANBAUGH': 0,
    'WANBERG': 0,
    'WANCA': 0,
    'WANCE': 0,
    'WANCZYK': 0,
    'WAND': 0,
    'WANDA': 0.9994251094503162,
    'WANDEL': 0,
    'WANDELL': 0,
    'WANDER': 0,
    'WANDERER': 0,
    'WANDERS': 0,
    'WANDERSCHEID': 0,
    'WANDERSEE': 0,
    'WANDICK': 0,
    'WANDLER': 0,
    'WANDLESS': 0,
    'WANDLING': 0,
    'WANDREI': 0,
    'WANDREY': 0,
    'WANDRIE': 0,
    'WANDS': 0,
    'WANDSCHNEIDER': 0,
    'WANDTKE': 0,
    'WANDZILAK': 0,
    'WANE': 0,
    'WANEK': 0,
    'WANER': 0,
    'WANETA': 1,
    'WANETTA': 1,
    'WANG': 0,
    'WANGBERG': 0,
    'WANGELIN': 0,
    'WANGEN': 0,
    'WANGER': 0,
    'WANGERIN': 0,
    'WANGLER': 0,
    'WANGSGARD': 0,
    'WANGSNESS': 0,
    'WANHALA': 0,
    'WANI': 0,
    'WANINGER': 0,
    'WANIS': 0,
    'WANISH': 0,
    'WANITA': 1,
    'WANK': 0,
    'WANKE': 0,
    'WANKEL': 0,
    'WANKER': 0,
    'WANKET': 0,
    'WANKIER': 0,
    'WANKO': 0,
    'WANKOWSKI': 0,
    'WANKUM': 0,
    'WANLASS': 0,
    'WANLESS': 0,
    'WANN': 0,
    'WANNA': 0,
    'WANNAMAKER': 0,
    'WANNEMACHER': 0,
    'WANNER': 0,
    'WANNINGER': 0,
    'WANO': 0,
    'WANOUS': 0,
    'WANSER': 0,
    'WANSERSKI': 0,
    'WANSING': 0,
    'WANSLEY': 0,
    'WANSOR': 0,
    'WANSTRATH': 0,
    'WANSTREET': 0,
    'WANT': 0,
    'WANTA': 0,
    'WANTLAND': 0,
    'WANTOCH': 0,
    'WANTON': 0,
    'WANTROBA': 0,
    'WANTUCH': 0,
    'WANTUCK': 0,
    'WANTY': 0,
    'WANTZ': 0,
    'WANYO': 0,
    'WANZA': 0,
    'WANZEK': 0,
    'WANZER': 0,
    'WANZO': 0,
    'WAPELHORST': 0,
    'WAPLE': 0,
    'WAPLES': 0,
    'WAPNER': 0,
    'WAPPEL': 0,
    'WAPPELHORST': 0,
    'WAPPES': 0,
    'WAPPLER': 0,
    'WAR': 0,
    'WARA': 0,
    'WARAICH': 0,
    'WARAKOMSKI': 0,
    'WARAKSA': 0,
    'WARANCH': 0,
    'WARBER': 0,
    'WARBINGTON': 0,
    'WARBLE': 0,
    'WARBRITTON': 0,
    'WARBURG': 0,
    'WARBURTON': 0,
    'WARBY': 0,
    'WARCHAL': 0,
    'WARCHOL': 0,
    'WARCHOLA': 0,
    'WARCUP': 0,
    'WARCZAK': 0,
    'WARD': 0.09596928982725529,
    'WARDA': 0,
    'WARDAK': 0,
    'WARDALL': 0,
    'WARDE': 0,
    'WARDELL': 0,
    'WARDEN': 0,
    'WARDENBURG': 0,
    'WARDER': 0,
    'WARDIAN': 0,
    'WARDIN': 0,
    'WARDLAW': 0,
    'WARDLE': 0,
    'WARDLEY': 0,
    'WARDLOW': 0,
    'WARDMAN': 0,
    'WARDNER': 0,
    'WARDRICK': 0,
    'WARDRIP': 0,
    'WARDROP': 0,
    'WARDROPE': 0,
    'WARDRUP': 0,
    'WARDSWORTH': 0,
    'WARDWELL': 0,
    'WARDYN': 0,
    'WARDYNSKI': 0,
    'WARDZALA': 0,
    'WARDZINSKI': 0,
    'WARE': 0,
    'WAREHAM': 0,
    'WAREHIME': 0,
    'WAREING': 0,
    'WAREN': 0,
    'WARENSKI': 0,
    'WARES': 0,
    'WARF': 0,
    'WARFEL': 0,
    'WARFIELD': 0,
    'WARFLE': 0,
    'WARFORD': 0,
    'WARG': 0,
    'WARGA': 0,
    'WARGACKI': 0,
    'WARGEL': 0,
    'WARGER': 0,
    'WARGIN': 0,
    'WARGNIER': 0,
    'WARGO': 0,
    'WARGOLET': 0,
    'WARGOWSKY': 0,
    'WARGULA': 0,
    'WARHEIT': 0,
    'WARHOL': 0,
    'WARHOLA': 0,
    'WARHOLAK': 0,
    'WARHOLIC': 0,
    'WARHURST': 0,
    'WARICK': 0,
    'WARILA': 0,
    'WARIN': 0,
    'WARINER': 0,
    'WARING': 0,
    'WARINNER': 0,
    'WARINO': 0,
    'WARIS': 0,
    'WARK': 0,
    'WARKE': 0,
    'WARKENTHIEN': 0,
    'WARKENTIEN': 0,
    'WARKENTIN': 0,
    'WARKENTINE': 0,
    'WARKER': 0,
    'WARKINS': 0,
    'WARLEY': 0,
    'WARLICK': 0,
    'WARLING': 0,
    'WARLOW': 0,
    'WARM': 0,
    'WARMACK': 0,
    'WARMAN': 0,
    'WARMANN': 0,
    'WARMATH': 0,
    'WARMBIER': 0,
    'WARMBOLD': 0,
    'WARMBRODT': 0,
    'WARME': 0,
    'WARMERDAM': 0,
    'WARMINGTON': 0,
    'WARMINSKI': 0,
    'WARMKA': 0,
    'WARMKE': 0,
    'WARMKESSEL': 0,
    'WARMOTH': 0,
    'WARMOUTH': 0,
    'WARMSLEY': 0,
    'WARMUS': 0,
    'WARMUTH': 0,
    'WARN': 0,
    'WARNACK': 0,
    'WARNBERG': 0,
    'WARNCKE': 0,
    'WARNE': 0,
    'WARNECK': 0,
    'WARNECKE': 0,
    'WARNEKE': 0,
    'WARNELL': 0,
    'WARNEMENT': 0,
    'WARNER': 0.11651616661811827,
    'WARNERS': 0,
    'WARNERT': 0,
    'WARNES': 0,
    'WARNEY': 0,
    'WARNICK': 0,
    'WARNICKE': 0,
    'WARNIMONT': 0,
    'WARNING': 0,
    'WARNKE': 0,
    'WARNKEN': 0,
    'WARNOCK': 0,
    'WARNS': 0,
    'WARNSLEY': 0,
    'WARP': 0,
    'WARPINSKI': 0,
    'WARPULA': 0,
    'WARR': 0,
    'WARRAICH': 0,
    'WARRAN': 0,
    'WARRELL': 0,
    'WARREN': 0.6673542437663047,
    'WARRENBURG': 0,
    'WARRENDER': 0,
    'WARRENER': 0,
    'WARRENFELTZ': 0,
    'WARRENS': 0,
    'WARRICK': 0,
    'WARRIER': 0,
    'WARRINER': 0,
    'WARRING': 0,
    'WARRINGTON': 0,
    'WARRIOR': 0,
    'WARRIX': 0,
    'WARRNER': 0,
    'WARRUM': 0,
    'WARS': 0,
    'WARSAME': 0,
    'WARSAW': 0,
    'WARSH': 0,
    'WARSHAUER': 0,
    'WARSHAW': 0,
    'WARSHAWSKY': 0,
    'WARSI': 0,
    'WARSING': 0,
    'WARSINSKI': 0,
    'WARSON': 0,
    'WARSOP': 0,
    'WARSTLER': 0,
    'WARSZAWSKI': 0,
    'WART': 0,
    'WARTA': 0,
    'WARTCHOW': 0,
    'WARTEL': 0,
    'WARTELL': 0,
    'WARTELLA': 0,
    'WARTELLE': 0,
    'WARTENBE': 0,
    'WARTENBERG': 0,
    'WARTER': 0,
    'WARTERS': 0,
    'WARTES': 0,
    'WARTGOW': 0,
    'WARTH': 0,
    'WARTHAN': 0,
    'WARTHEN': 0,
    'WARTHER': 0,
    'WARTHMAN': 0,
    'WARTICK': 0,
    'WARTINGER': 0,
    'WARTLUFT': 0,
    'WARTMAN': 0,
    'WARTNER': 0,
    'WARTON': 0,
    'WARUNEK': 0,
    'WARWAS': 0,
    'WARWICK': 0,
    'WARY': 0,
    'WARYAS': 0,
    'WARZALA': 0,
    'WARZECHA': 0,
    'WARZOCHA': 0,
    'WARZYNSKI': 0,
    'WAS': 0,
    'WASCH': 0,
    'WASCHAK': 0,
    'WASCHE': 0,
    'WASCHER': 0,
    'WASCO': 0,
    'WASCOM': 0,
    'WASDEN': 0,
    'WASDIN': 0,
    'WASE': 0,
    'WASEEM': 0,
    'WASEK': 0,
    'WASEL': 0,
    'WASELESKI': 0,
    'WASEM': 0,
    'WASEMILLER': 0,
    'WASER': 0,
    'WASETA': 0,
    'WASH': 0,
    'WASHA': 0,
    'WASHABAUGH': 0,
    'WASHAM': 0,
    'WASHBURN': 0,
    'WASHBURNE': 0,
    'WASHCO': 0,
    'WASHEK': 0,
    'WASHELESKI': 0,
    'WASHENBERGER': 0,
    'WASHER': 0,
    'WASHICK': 0,
    'WASHINGTON': 0,
    'WASHINTON': 0,
    'WASHKO': 0,
    'WASHKOWIAK': 0,
    'WASHMON': 0,
    'WASHNOCK': 0,
    'WASHO': 0,
    'WASHUM': 0,
    'WASHUTA': 0,
    'WASIAK': 0,
    'WASICEK': 0,
    'WASICK': 0,
    'WASICKI': 0,
    'WASIELESKI': 0,
    'WASIELEWSKI': 0,
    'WASIERSKI': 0,
    'WASIEWICZ': 0,
    'WASIK': 0,
    'WASIKOWSKI': 0,
    'WASIL': 0,
    'WASILENKO': 0,
    'WASILESKI': 0,
    'WASILEWSKI': 0,
    'WASILKO': 0,
    'WASILOWSKI': 0,
    'WASILUK': 0,
    'WASIM': 0,
    'WASINGER': 0,
    'WASINSKI': 0,
    'WASKA': 0,
    'WASKE': 0,
    'WASKEY': 0,
    'WASKI': 0,
    'WASKIEWICZ': 0,
    'WASKO': 0,
    'WASKOM': 0,
    'WASKOSKY': 0,
    'WASKOW': 0,
    'WASKOWIAK': 0,
    'WASLEY': 0,
    'WASMAN': 0,
    'WASMER': 0,
    'WASMUND': 0,
    'WASMUNDT': 0,
    'WASMUTH': 0,
    'WASNER': 0,
    'WASNICK': 0,
    'WASNIEWSKI': 0,
    'WASON': 0,
    'WASOWICZ': 0,
    'WASOWSKI': 0,
    'WASP': 0,
    'WASS': 0,
    'WASSALL': 0,
    'WASSAM': 0,
    'WASSBERG': 0,
    'WASSEF': 0,
    'WASSEL': 0,
    'WASSELL': 0,
    'WASSENAAR': 0,
    'WASSENBERG': 0,
    'WASSER': 0,
    'WASSERBURGER': 0,
    'WASSERMAN': 0,
    'WASSERMANN': 0,
    'WASSERSTEIN': 0,
    'WASSERSTROM': 0,
    'WASSIL': 0,
    'WASSILLIE': 0,
    'WASSINGER': 0,
    'WASSINK': 0,
    'WASSMAN': 0,
    'WASSMANN': 0,
    'WASSMER': 0,
    'WASSMUTH': 0,
    'WASSNER': 0,
    'WASSO': 0,
    'WASSOM': 0,
    'WASSON': 0,
    'WASSUM': 0,
    'WASTE': 0,
    'WASTI': 0,
    'WASTLER': 0,
    'WASTON': 0,
    'WASWICK': 0,
    'WASYLENKO': 0,
    'WASYLYK': 0,
    'WASZAK': 0,
    'WASZCZAK': 0,
    'WASZKIEWICZ': 0,
    'WAT': 0,
    'WATABE': 0,
    'WATANABE': 0,
    'WATARI': 0,
    'WATASHE': 0,
    'WATCH': 0,
    'WATCHMAN': 0,
    'WATCHORN': 0,
    'WATE': 0,
    'WATER': 0,
    'WATERBURY': 0,
    'WATERCUTTER': 0,
    'WATERFALL': 0,
    'WATERFIELD': 0,
    'WATERFORD': 0,
    'WATERHOUSE': 0,
    'WATERKOTTE': 0,
    'WATERLAND': 0,
    'WATERLOO': 0,
    'WATERMAN': 0,
    'WATERMANN': 0,
    'WATERMEIER': 0,
    'WATERMOLEN': 0,
    'WATEROUS': 0,
    'WATERS': 0,
    'WATERSON': 0,
    'WATERSTON': 0,
    'WATERSTRAAT': 0,
    'WATERSTRADT': 0,
    'WATERSTREET': 0,
    'WATERTON': 0,
    'WATERWORTH': 0,
    'WATES': 0,
    'WATFORD': 0,
    'WATHAN': 0,
    'WATHEN': 0,
    'WATHEY': 0,
    'WATHKE': 0,
    'WATI': 0,
    'WATIE': 0,
    'WATIER': 0,
    'WATJE': 0,
    'WATJEN': 0,
    'WATKIN': 0,
    'WATKINS': 0,
    'WATKINSON': 0,
    'WATKIS': 0,
    'WATKO': 0,
    'WATLAND': 0,
    'WATLER': 0,
    'WATLEY': 0,
    'WATLING': 0,
    'WATLINGTON': 0,
    'WATMAN': 0,
    'WATNE': 0,
    'WATNICK': 0,
    'WATRAL': 0,
    'WATRAS': 0,
    'WATRIN': 0,
    'WATRING': 0,
    'WATRO': 0,
    'WATROBA': 0,
    'WATROS': 0,
    'WATROUS': 0,
    'WATRY': 0,
    'WATSCHKE': 0,
    'WATSKY': 0,
    'WATSON': 0,
    'WATT': 0,
    'WATTAM': 0,
    'WATTE': 0,
    'WATTEN': 0,
    'WATTENBARGER': 0,
    'WATTENBERG': 0,
    'WATTER': 0,
    'WATTERS': 0,
    'WATTERSON': 0,
    'WATTERUD': 0,
    'WATTERWORTH': 0,
    'WATTIE': 0,
    'WATTIER': 0,
    'WATTIGNEY': 0,
    'WATTLES': 0,
    'WATTLEY': 0,
    'WATTMAN': 0,
    'WATTON': 0,
    'WATTS': 0,
    'WATTSON': 0,
    'WATTY': 0,
    'WATWOOD': 0,
    'WATZ': 0,
    'WATZKA': 0,
    'WATZKE': 0,
    'WAUCHOPE': 0,
    'WAUD': 0,
    'WAUDBY': 0,
    'WAUER': 0,
    'WAUFORD': 0,
    'WAUGAMAN': 0,
    'WAUGH': 0,
    'WAUGHTAL': 0,
    'WAUGHTEL': 0,
    'WAUKAU': 0,
    'WAUL': 0,
    'WAULK': 0,
    'WAUN': 0,
    'WAUNEKA': 0,
    'WAUPOOSE': 0,
    'WAUSON': 0,
    'WAUTERS': 0,
    'WAUTLET': 0,
    'WAVA': 1,
    'WAVE': 0,
    'WAVER': 0,
    'WAVERLY': 0,
    'WAVRA': 0,
    'WAVRUNEK': 0,
    'WAWAK': 0,
    'WAWERU': 0,
    'WAWRO': 0,
    'WAWRZASZEK': 0,
    'WAWRZONEK': 0,
    'WAWRZYNIAK': 0,
    'WAWRZYNSKI': 0,
    'WAX': 0,
    'WAXENBERG': 0,
    'WAXLER': 0,
    'WAXMAN': 0,
    'WAXTER': 0,
    'WAY': 0,
    'WAYAND': 0,
    'WAYBRANT': 0,
    'WAYBRIGHT': 0,
    'WAYCASTER': 0,
    'WAYCHOFF': 0,
    'WAYCOTT': 0,
    'WAYDA': 0,
    'WAYE': 0,
    'WAYER': 0,
    'WAYLAND': 0,
    'WAYLETT': 0,
    'WAYLON': 1,
    'WAYMACK': 0,
    'WAYMAN': 0,
    'WAYMENT': 0,
    'WAYMER': 0,
    'WAYMIRE': 0,
    'WAYMON': 0,
    'WAYNE': 0.9853191405167979,
    'WAYNER': 0,
    'WAYNES': 0,
    'WAYNICK': 0,
    'WAYRYNEN': 0,
    'WAYS': 0,
    'WAYSON': 0,
    'WAYT': 0,
    'WAYTASHEK': 0,
    'WAYTE': 0,
    'WAYTON': 0,
    'WAYTS': 0,
    'WAZ': 0,
    'WAZELLE': 0,
    'WAZIR': 0,
    'WAZIRI': 0,
    'WAZNY': 0,
    'WAZWAZ': 0,
    'WCISLO': 0,
    'WDOWIAK': 0,
    'WE': 0,
    'WEABER': 0,
    'WEACHTER': 0,
    'WEAD': 0,
    'WEADE': 0,
    'WEADER': 0,
    'WEADICK': 0,
    'WEADOCK': 0,
    'WEADON': 0,
    'WEAFER': 0,
    'WEAGLE': 0,
    'WEAGLEY': 0,
    'WEAGRAFF': 0,
    'WEAH': 0,
    'WEAK': 0,
    'WEAKLAND': 0,
    'WEAKLEY': 0,
    'WEAKLY': 0,
    'WEAKS': 0,
    'WEAL': 0,
    'WEALAND': 0,
    'WEALE': 0,
    'WEAMER': 0,
    'WEAN': 0,
    'WEAND': 0,
    'WEANER': 0,
    'WEANT': 0,
    'WEAR': 0,
    'WEARDEN': 0,
    'WEARE': 0,
    'WEARING': 0,
    'WEARMOUTH': 0,
    'WEARN': 0,
    'WEARNE': 0,
    'WEARREN': 0,
    'WEARS': 0,
    'WEARSCH': 0,
    'WEART': 0,
    'WEARY': 0,
    'WEAS': 0,
    'WEASE': 0,
    'WEASEL': 0,
    'WEASENFORTH': 0,
    'WEASNER': 0,
    'WEAST': 0,
    'WEATHER': 0,
    'WEATHERALL': 0,
    'WEATHERBEE': 0,
    'WEATHERBIE': 0,
    'WEATHERBY': 0,
    'WEATHERED': 0,
    'WEATHERFORD': 0,
    'WEATHERHEAD': 0,
    'WEATHERHOLT': 0,
    'WEATHERHOLTZ': 0,
    'WEATHERILL': 0,
    'WEATHERINGTON': 0,
    'WEATHERLEY': 0,
    'WEATHERLY': 0,
    'WEATHERMAN': 0,
    'WEATHERMON': 0,
    'WEATHERRED': 0,
    'WEATHERS': 0,
    'WEATHERSBEE': 0,
    'WEATHERSBY': 0,
    'WEATHERSON': 0,
    'WEATHERSPOON': 0,
    'WEATHERSTON': 0,
    'WEATHERTON': 0,
    'WEATHERUP': 0,
    'WEATHERWAX': 0,
    'WEATHINGTON': 0,
    'WEAVER': 0,
    'WEAVERLING': 0,
    'WEAVERS': 0,
    'WEAVIL': 0,
    'WEAVING': 0,
    'WEB': 0,
    'WEBB': 0,
    'WEBBE': 0,
    'WEBBER': 0,
    'WEBBERLEY': 0,
    'WEBBERT': 0,
    'WEBBS': 0,
    'WEBEL': 0,
    'WEBER': 0,
    'WEBERG': 0,
    'WEBERMAN': 0,
    'WEBERT': 0,
    'WEBLER': 0,
    'WEBLEY': 0,
    'WEBNER': 0,
    'WEBORG': 0,
    'WEBRE': 0,
    'WEBSTER': 0,
    'WECH': 0,
    'WECHSLER': 0,
    'WECHT': 0,
    'WECHTER': 0,
    'WECK': 0,
    'WECKBACHER': 0,
    'WECKEL': 0,
    'WECKER': 0,
    'WECKERLE': 0,
    'WECKERLY': 0,
    'WECKESSER': 0,
    'WECKLER': 0,
    'WECKMAN': 0,
    'WECKSTEIN': 0,
    'WECKWERTH': 0,
    'WEDAN': 0,
    'WEDBERG': 0,
    'WEDD': 0,
    'WEDDE': 0,
    'WEDDEL': 0,
    'WEDDELL': 0,
    'WEDDERBURN': 0,
    'WEDDING': 0,
    'WEDDINGTON': 0,
    'WEDDLE': 0,
    'WEDDLETON': 0,
    'WEDE': 0,
    'WEDEKIND': 0,
    'WEDEKING': 0,
    'WEDEL': 0,
    'WEDELL': 0,
    'WEDEMAN': 0,
    'WEDEMEIER': 0,
    'WEDEMEYER': 0,
    'WEDEN': 0,
    'WEDER': 0,
    'WEDERSKI': 0,
    'WEDGE': 0,
    'WEDGEWOOD': 0,
    'WEDGEWORTH': 0,
    'WEDGWOOD': 0,
    'WEDGWORTH': 0,
    'WEDIG': 0,
    'WEDIGE': 0,
    'WEDIN': 0,
    'WEDINGTON': 0,
    'WEDL': 0,
    'WEDLAKE': 0,
    'WEDLER': 0,
    'WEDLOCK': 0,
    'WEDLOW': 0,
    'WEDLUND': 0,
    'WEDMAN': 0,
    'WEDMORE': 0,
    'WEDNER': 0,
    'WEDO': 0,
    'WEDOW': 0,
    'WEDWICK': 0,
    'WEE': 0,
    'WEEBER': 0,
    'WEECE': 0,
    'WEECH': 0,
    'WEED': 0,
    'WEEDA': 0,
    'WEEDE': 0,
    'WEEDEN': 0,
    'WEEDER': 0,
    'WEEDIN': 0,
    'WEEDING': 0,
    'WEEDMAN': 0,
    'WEEDON': 0,
    'WEEG': 0,
    'WEEGAR': 0,
    'WEEGE': 0,
    'WEEK': 0,
    'WEEKES': 0,
    'WEEKLEY': 0,
    'WEEKLY': 0,
    'WEEKS': 0,
    'WEELDREYER': 0,
    'WEEMAN': 0,
    'WEEMES': 0,
    'WEEMHOFF': 0,
    'WEEMS': 0,
    'WEENER': 0,
    'WEENS': 0,
    'WEER': 0,
    'WEERASINGHE': 0,
    'WEERHEIM': 0,
    'WEERS': 0,
    'WEERSING': 0,
    'WEERTS': 0,
    'WEES': 0,
    'WEESE': 0,
    'WEESIES': 0,
    'WEESNER': 0,
    'WEETER': 0,
    'WEETHEE': 0,
    'WEETS': 0,
    'WEFEL': 0,
    'WEFER': 0,
    'WEFLEN': 0,
    'WEG': 0,
    'WEGE': 0,
    'WEGEHAUPT': 0,
    'WEGELE': 0,
    'WEGELIN': 0,
    'WEGENER': 0,
    'WEGENKA': 0,
    'WEGENKE': 0,
    'WEGER': 0,
    'WEGERER': 0,
    'WEGERT': 0,
    'WEGGE': 0,
    'WEGHER': 0,
    'WEGHORST': 0,
    'WEGIEL': 0,
    'WEGIENKA': 0,
    'WEGLARZ': 0,
    'WEGLEITNER': 0,
    'WEGLEY': 0,
    'WEGLINSKI': 0,
    'WEGMAN': 0,
    'WEGMANN': 0,
    'WEGNER': 0,
    'WEGRYN': 0,
    'WEGRZYN': 0,
    'WEGSCHEID': 0,
    'WEGSCHEIDER': 0,
    'WEGWERTH': 0,
    'WEH': 0,
    'WEHAGE': 0,
    'WEHAUSEN': 0,
    'WEHBA': 0,
    'WEHBE': 0,
    'WEHBY': 0,
    'WEHDE': 0,
    'WEHE': 0,
    'WEHINGER': 0,
    'WEHKING': 0,
    'WEHLAGE': 0,
    'WEHLAND': 0,
    'WEHLE': 0,
    'WEHLER': 0,
    'WEHLING': 0,
    'WEHMAN': 0,
    'WEHMANN': 0,
    'WEHMEIER': 0,
    'WEHMER': 0,
    'WEHMEYER': 0,
    'WEHN': 0,
    'WEHNER': 0,
    'WEHNERT': 0,
    'WEHNES': 0,
    'WEHR': 0,
    'WEHRENBERG': 0,
    'WEHRER': 0,
    'WEHRHEIM': 0,
    'WEHRI': 0,
    'WEHRING': 0,
    'WEHRKAMP': 0,
    'WEHRLE': 0,
    'WEHRLEY': 0,
    'WEHRLI': 0,
    'WEHRLY': 0,
    'WEHRMAN': 0,
    'WEHRMANN': 0,
    'WEHRMEISTER': 0,
    'WEHRMEYER': 0,
    'WEHRS': 0,
    'WEHRUNG': 0,
    'WEHRWEIN': 0,
    'WEHRY': 0,
    'WEHUNT': 0,
    'WEI': 0.4716981132075472,
    'WEIAND': 0,
    'WEIANT': 0,
    'WEIBEL': 0,
    'WEIBERG': 0,
    'WEIBERT': 0,
    'WEIBLE': 0,
    'WEIBLEY': 0,
    'WEIBRECHT': 0,
    'WEICH': 0,
    'WEICHBROD': 0,
    'WEICHBRODT': 0,
    'WEICHEL': 0,
    'WEICHELT': 0,
    'WEICHERS': 0,
    'WEICHERT': 0,
    'WEICHMAN': 0,
    'WEICHMANN': 0,
    'WEICHSELBAUM': 0,
    'WEICHT': 0,
    'WEICK': 0,
    'WEICKER': 0,
    'WEICKERT': 0,
    'WEICKUM': 0,
    'WEID': 0,
    'WEIDA': 0,
    'WEIDAUER': 0,
    'WEIDE': 0,
    'WEIDEL': 0,
    'WEIDELE': 0,
    'WEIDEMAN': 0,
    'WEIDEMANN': 0,
    'WEIDEN': 0,
    'WEIDENAAR': 0,
    'WEIDENBACH': 0,
    'WEIDENBACHER': 0,
    'WEIDENBENNER': 0,
    'WEIDENFELD': 0,
    'WEIDENFELLER': 0,
    'WEIDENHAMER': 0,
    'WEIDENHAMMER': 0,
    'WEIDENHOF': 0,
    'WEIDER': 0,
    'WEIDERMAN': 0,
    'WEIDERT': 0,
    'WEIDIG': 0,
    'WEIDINGER': 0,
    'WEIDL': 0,
    'WEIDLE': 0,
    'WEIDLEIN': 0,
    'WEIDLER': 0,
    'WEIDLICH': 0,
    'WEIDLING': 0,
    'WEIDMAN': 0,
    'WEIDMANN': 0,
    'WEIDNER': 0,
    'WEIDO': 0,
    'WEIDOW': 0,
    'WEIDT': 0,
    'WEIER': 0,
    'WEIERBACH': 0,
    'WEIERS': 0,
    'WEIFENBACH': 0,
    'WEIFFENBACH': 0,
    'WEIFORD': 0,
    'WEIG': 0,
    'WEIGAND': 0,
    'WEIGANDT': 0,
    'WEIGANT': 0,
    'WEIGART': 0,
    'WEIGEL': 0,
    'WEIGELE': 0,
    'WEIGELT': 0,
    'WEIGER': 0,
    'WEIGERT': 0,
    'WEIGHT': 0,
    'WEIGHTMAN': 0,
    'WEIGL': 0,
    'WEIGLE': 0,
    'WEIGLEIN': 0,
    'WEIGLER': 0,
    'WEIGMAN': 0,
    'WEIGNER': 0,
    'WEIGOLD': 0,
    'WEIGT': 0,
    'WEIGUM': 0,
    'WEIH': 0,
    'WEIHE': 0,
    'WEIHER': 0,
    'WEIHERT': 0,
    'WEIHING': 0,
    'WEIHL': 0,
    'WEIHRAUCH': 0,
    'WEIHS': 0,
    'WEIK': 0,
    'WEIKAL': 0,
    'WEIKART': 0,
    'WEIKEL': 0,
    'WEIKER': 0,
    'WEIKERT': 0,
    'WEIKLE': 0,
    'WEIKUM': 0,
    'WEIL': 0,
    'WEILACHER': 0,
    'WEILAGE': 0,
    'WEILAND': 0,
    'WEILBACHER': 0,
    'WEILBRENNER': 0,
    'WEILER': 0,
    'WEILERT': 0,
    'WEILL': 0,
    'WEILMUENSTER': 0,
    'WEILNAU': 0,
    'WEIMAN': 0,
    'WEIMANN': 0,
    'WEIMAR': 0,
    'WEIMER': 0,
    'WEIMERSKIRCH': 0,
    'WEIMERT': 0,
    'WEIN': 0,
    'WEINACHT': 0,
    'WEINAND': 0,
    'WEINANDT': 0,
    'WEINANDY': 0,
    'WEINARD': 0,
    'WEINBACH': 0,
    'WEINBAUM': 0,
    'WEINBENDER': 0,
    'WEINBERG': 0,
    'WEINBERGER': 0,
    'WEINBLATT': 0,
    'WEINBRECHT': 0,
    'WEINBRENNER': 0,
    'WEINBURG': 0,
    'WEINDEL': 0,
    'WEINDORF': 0,
    'WEINEL': 0,
    'WEINELL': 0,
    'WEINER': 0,
    'WEINERMAN': 0,
    'WEINERT': 0,
    'WEINERTH': 0,
    'WEINFELD': 0,
    'WEINFURTER': 0,
    'WEINFURTNER': 0,
    'WEINGARD': 0,
    'WEINGARDEN': 0,
    'WEINGARDT': 0,
    'WEINGART': 0,
    'WEINGARTEN': 0,
    'WEINGARTH': 0,
    'WEINGARTNER': 0,
    'WEINGARTZ': 0,
    'WEINGAST': 0,
    'WEINGER': 0,
    'WEINGRAD': 0,
    'WEINHANDL': 0,
    'WEINHARDT': 0,
    'WEINHEIMER': 0,
    'WEINHOFER': 0,
    'WEINHOLD': 0,
    'WEININGER': 0,
    'WEINKAM': 0,
    'WEINKAUF': 0,
    'WEINKE': 0,
    'WEINLAND': 0,
    'WEINLE': 0,
    'WEINLEIN': 0,
    'WEINMAN': 0,
    'WEINMANN': 0,
    'WEINMASTER': 0,
    'WEINMEISTER': 0,
    'WEINRAUB': 0,
    'WEINRAUCH': 0,
    'WEINREB': 0,
    'WEINREICH': 0,
    'WEINREIS': 0,
    'WEINRIB': 0,
    'WEINRICH': 0,
    'WEINROTH': 0,
    'WEINS': 0,
    'WEINSCHENK': 0,
    'WEINSHEIMER': 0,
    'WEINSTEIGER': 0,
    'WEINSTEIN': 0,
    'WEINSTOCK': 0,
    'WEINTRAUB': 0,
    'WEINTRAUT': 0,
    'WEINTZ': 0,
    'WEINZAPFEL': 0,
    'WEINZETL': 0,
    'WEINZIERL': 0,
    'WEINZIRL': 0,
    'WEIPERT': 0,
    'WEIPPERT': 0,
    'WEIR': 0,
    'WEIRATHER': 0,
    'WEIRAUCH': 0,
    'WEIRES': 0,
    'WEIRICH': 0,
    'WEIRICK': 0,
    'WEIS': 0,
    'WEISBACH': 0,
    'WEISBARD': 0,
    'WEISBART': 0,
    'WEISBARTH': 0,
    'WEISBAUM': 0,
    'WEISBECK': 0,
    'WEISBECKER': 0,
    'WEISBERG': 0,
    'WEISBERGER': 0,
    'WEISBLATT': 0,
    'WEISBORD': 0,
    'WEISBRICH': 0,
    'WEISBROD': 0,
    'WEISBRODT': 0,
    'WEISBROT': 0,
    'WEISCHEDEL': 0,
    'WEISE': 0,
    'WEISEL': 0,
    'WEISEMAN': 0,
    'WEISEN': 0,
    'WEISENBACH': 0,
    'WEISENBECK': 0,
    'WEISENBERG': 0,
    'WEISENBERGER': 0,
    'WEISENBORN': 0,
    'WEISENBURG': 0,
    'WEISENBURGER': 0,
    'WEISEND': 0,
    'WEISENFELD': 0,
    'WEISENFLUH': 0,
    'WEISENHORN': 0,
    'WEISENSEE': 0,
    'WEISENSEL': 0,
    'WEISENSTEIN': 0,
    'WEISER': 0,
    'WEISERT': 0,
    'WEISFELD': 0,
    'WEISGARBER': 0,
    'WEISGERBER': 0,
    'WEISGRAM': 0,
    'WEISH': 0,
    'WEISHAAR': 0,
    'WEISHAN': 0,
    'WEISHAR': 0,
    'WEISHAUPT': 0,
    'WEISHEIT': 0,
    'WEISHOFF': 0,
    'WEISHUHN': 0,
    'WEISIGER': 0,
    'WEISINGER': 0,
    'WEISKE': 0,
    'WEISKIRCHER': 0,
    'WEISKITTEL': 0,
    'WEISKOPF': 0,
    'WEISLER': 0,
    'WEISLO': 0,
    'WEISLOGEL': 0,
    'WEISMAN': 0,
    'WEISMANN': 0,
    'WEISMANTEL': 0,
    'WEISMILLER': 0,
    'WEISNER': 0,
    'WEISNICHT': 0,
    'WEISPFENNING': 0,
    'WEISS': 0,
    'WEISSBACH': 0,
    'WEISSBERG': 0,
    'WEISSBERGER': 0,
    'WEISSE': 0,
    'WEISSENBERG': 0,
    'WEISSENBERGER': 0,
    'WEISSENBORN': 0,
    'WEISSENBURGER': 0,
    'WEISSEND': 0,
    'WEISSENFLUH': 0,
    'WEISSER': 0,
    'WEISSERT': 0,
    'WEISSGERBER': 0,
    'WEISSHAAR': 0,
    'WEISSINGER': 0,
    'WEISSKOPF': 0,
    'WEISSLER': 0,
    'WEISSMAN': 0,
    'WEISSMANN': 0,
    'WEISSNER': 0,
    'WEIST': 0,
    'WEISTER': 0,
    'WEISZ': 0,
    'WEIT': 0,
    'WEITEKAMP': 0,
    'WEITER': 0,
    'WEITH': 0,
    'WEITHERS': 0,
    'WEITHMAN': 0,
    'WEITKAMP': 0,
    'WEITL': 0,
    'WEITLAUF': 0,
    'WEITMAN': 0,
    'WEITNAUER': 0,
    'WEITZ': 0,
    'WEITZEL': 0,
    'WEITZELL': 0,
    'WEITZER': 0,
    'WEITZMAN': 0,
    'WEITZNER': 0,
    'WEIX': 0,
    'WEIXEL': 0,
    'WEIXELMAN': 0,
    'WEIXLER': 0,
    'WEIZER': 0,
    'WEIZMAN': 0,
    'WEJROWSKI': 0,
    'WELAGE': 0,
    'WELAND': 0,
    'WELANDER': 0,
    'WELBAUM': 0,
    'WELBES': 0,
    'WELBIG': 0,
    'WELBON': 0,
    'WELBORN': 0,
    'WELBORNE': 0,
    'WELBOURN': 0,
    'WELBOURNE': 0,
    'WELBURN': 0,
    'WELBY': 0,
    'WELC': 0,
    'WELCH': 0,
    'WELCHEL': 0,
    'WELCHER': 0,
    'WELCHERT': 0,
    'WELCHES': 0,
    'WELCHMAN': 0,
    'WELCKER': 0,
    'WELCOME': 0,
    'WELD': 0,
    'WELDAY': 0,
    'WELDE': 0,
    'WELDELE': 0,
    'WELDEN': 0,
    'WELDER': 0,
    'WELDIN': 0,
    'WELDING': 0,
    'WELDON': 0.6338028169014085,
    'WELDY': 0,
    'WELENC': 0,
    'WELESKI': 0,
    'WELFARE': 0,
    'WELFEL': 0,
    'WELFLEY': 0,
    'WELFORD': 0,
    'WELGE': 0,
    'WELHAM': 0,
    'WELHOUSE': 0,
    'WELIN': 0,
    'WELINITZ': 0,
    'WELIVER': 0,
    'WELK': 0,
    'WELKA': 0,
    'WELKE': 0,
    'WELKER': 0,
    'WELKLEY': 0,
    'WELL': 0,
    'WELLAND': 0,
    'WELLARD': 0,
    'WELLBAUM': 0,
    'WELLBORN': 0,
    'WELLBROCK': 0,
    'WELLCOME': 0,
    'WELLE': 0,
    'WELLEMEYER': 0,
    'WELLEN': 0,
    'WELLENDORF': 0,
    'WELLENS': 0,
    'WELLENSTEIN': 0,
    'WELLER': 0,
    'WELLES': 0,
    'WELLESLEY': 0,
    'WELLFORD': 0,
    'WELLHAUSEN': 0,
    'WELLIK': 0,
    'WELLIN': 0,
    'WELLING': 0,
    'WELLINGER': 0,
    'WELLINGHOFF': 0,
    'WELLINGS': 0,
    'WELLINGTON': 0,
    'WELLINS': 0,
    'WELLISCH': 0,
    'WELLIVER': 0,
    'WELLMAKER': 0,
    'WELLMAN': 0,
    'WELLMANN': 0,
    'WELLMEIER': 0,
    'WELLMON': 0,
    'WELLNER': 0,
    'WELLNITZ': 0,
    'WELLOCK': 0,
    'WELLONS': 0,
    'WELLS': 0,
    'WELLSANDT': 0,
    'WELLSPEAK': 0,
    'WELLWOOD': 0,
    'WELLY': 0,
    'WELMAKER': 0,
    'WELMAN': 0,
    'WELNA': 0,
    'WELNER': 0,
    'WELNETZ': 0,
    'WELNIAK': 0,
    'WELNINSKI': 0,
    'WELP': 0,
    'WELPER': 0,
    'WELS': 0,
    'WELSBY': 0,
    'WELSCH': 0,
    'WELSCHER': 0,
    'WELSCHMEYER': 0,
    'WELSER': 0,
    'WELSH': 0,
    'WELSHANS': 0,
    'WELSHER': 0,
    'WELSHONS': 0,
    'WELSON': 0,
    'WELT': 0,
    'WELTCH': 0,
    'WELTE': 0,
    'WELTER': 0,
    'WELTEROTH': 0,
    'WELTERS': 0,
    'WELTHER': 0,
    'WELTI': 0,
    'WELTIN': 0,
    'WELTMAN': 0,
    'WELTMER': 0,
    'WELTNER': 0,
    'WELTON': 0,
    'WELTY': 0,
    'WELTZ': 0,
    'WELTZER': 0,
    'WELTZIEN': 0,
    'WELTZIN': 0,
    'WELU': 0,
    'WELVAERT': 0,
    'WELZ': 0,
    'WELZEL': 0,
    'WELZENBACH': 0,
    'WEMER': 0,
    'WEMETT': 0,
    'WEMETTE': 0,
    'WEMHOFF': 0,
    'WEMMER': 0,
    'WEMPE': 0,
    'WEMPEN': 0,
    'WEMPLE': 0,
    'WEMYSS': 0,
    'WEN': 0.425531914893617,
    'WENAAS': 0,
    'WENBERG': 0,
    'WENC': 0,
    'WENCE': 0,
    'WENCEL': 0,
    'WENCES': 0,
    'WENCESLAO': 0,
    'WENCK': 0,
    'WENCL': 0,
    'WEND': 0,
    'WENDA': 0,
    'WENDALL': 0,
    'WENDE': 0,
    'WENDEBORN': 0,
    'WENDEL': 0,
    'WENDELBOE': 0,
    'WENDELIN': 0,
    'WENDELKEN': 0,
    'WENDELL': 0.9672961768770152,
    'WENDELN': 0,
    'WENDER': 0,
    'WENDEROTH': 0,
    'WENDERSKI': 0,
    'WENDHOLT': 0,
    'WENDI': 1,
    'WENDIE': 1,
    'WENDINGER': 0,
    'WENDL': 0,
    'WENDLAND': 0,
    'WENDLANDT': 0,
    'WENDLE': 0,
    'WENDLER': 0,
    'WENDLICK': 0,
    'WENDLING': 0,
    'WENDOLOWSKI': 0,
    'WENDOLYN': 1,
    'WENDORF': 0,
    'WENDORFF': 0,
    'WENDOVER': 0,
    'WENDRICKS': 0,
    'WENDROFF': 0,
    'WENDT': 0,
    'WENDTE': 0,
    'WENDTLAND': 0,
    'WENDY': 0.9997298027560119,
    'WENDZEL': 0,
    'WENE': 0,
    'WENELL': 0,
    'WENER': 0,
    'WENG': 0,
    'WENGEL': 0,
    'WENGENROTH': 0,
    'WENGER': 0,
    'WENGERD': 0,
    'WENGERT': 0,
    'WENGLER': 0,
    'WENGLIKOWSKI': 0,
    'WENGREN': 0,
    'WENGRYN': 0,
    'WENHAM': 0,
    'WENHOLD': 0,
    'WENHOLZ': 0,
    'WENICK': 0,
    'WENIG': 0,
    'WENIGER': 0,
    'WENING': 0,
    'WENINGER': 0,
    'WENISCH': 0,
    'WENK': 0,
    'WENKE': 0,
    'WENKEL': 0,
    'WENKER': 0,
    'WENMAN': 0,
    'WENN': 0,
    'WENNBERG': 0,
    'WENNDT': 0,
    'WENNEKER': 0,
    'WENNER': 0,
    'WENNERBERG': 0,
    'WENNERS': 0,
    'WENNERSTEN': 0,
    'WENNERSTROM': 0,
    'WENNING': 0,
    'WENNINGER': 0,
    'WENNSTROM': 0,
    'WENONA': 1,
    'WENRICH': 0,
    'WENRICK': 0,
    'WENSEL': 0,
    'WENSIL': 0,
    'WENSING': 0,
    'WENSINK': 0,
    'WENSKE': 0,
    'WENSLEY': 0,
    'WENSMAN': 0,
    'WENSMANN': 0,
    'WENSON': 0,
    'WENSTRAND': 0,
    'WENSTROM': 0,
    'WENSTRUP': 0,
    'WENT': 0,
    'WENTA': 0,
    'WENTE': 0,
    'WENTHE': 0,
    'WENTHOLD': 0,
    'WENTINK': 0,
    'WENTLAND': 0,
    'WENTLER': 0,
    'WENTLING': 0,
    'WENTWORTH': 0,
    'WENTZ': 0,
    'WENTZEL': 0,
    'WENTZELL': 0,
    'WENTZLAFF': 0,
    'WENTZLOFF': 0,
    'WENZ': 0,
    'WENZEL': 0,
    'WENZELL': 0,
    'WENZINGER': 0,
    'WENZL': 0,
    'WENZLAFF': 0,
    'WENZLER': 0,
    'WENZLICK': 0,
    'WENZLOFF': 0,
    'WEPFER': 0,
    'WEPKING': 0,
    'WEPNER': 0,
    'WEPPLER': 0,
    'WEPPNER': 0,
    'WEPRIN': 0,
    'WERB': 0,
    'WERBA': 0,
    'WERBECK': 0,
    'WERBEL': 0,
    'WERBELOW': 0,
    'WERBER': 0,
    'WERBIN': 0,
    'WERBLOW': 0,
    'WERCH': 0,
    'WERCHAN': 0,
    'WERDA': 0,
    'WERDANN': 0,
    'WERDEBAUGH': 0,
    'WERDEHAUSEN': 0,
    'WERDEL': 0,
    'WERDEN': 0,
    'WERDER': 0,
    'WERDERMAN': 0,
    'WERDIN': 0,
    'WERFEL': 0,
    'WERGER': 0,
    'WERGES': 0,
    'WERGIN': 0,
    'WERHAN': 0,
    'WERHANE': 0,
    'WERITO': 0,
    'WERK': 0,
    'WERKEMA': 0,
    'WERKHEISER': 0,
    'WERKHOVEN': 0,
    'WERKING': 0,
    'WERKMAN': 0,
    'WERKMEISTER': 0,
    'WERLE': 0,
    'WERLEIN': 0,
    'WERLEY': 0,
    'WERLIN': 0,
    'WERLINE': 0,
    'WERLING': 0,
    'WERLINGER': 0,
    'WERLY': 0,
    'WERMAGER': 0,
    'WERMAN': 0,
    'WERME': 0,
    'WERMELING': 0,
    'WERMER': 0,
    'WERMERS': 0,
    'WERMERSKIRCHEN': 0,
    'WERMES': 0,
    'WERMTER': 0,
    'WERMUTH': 0,
    'WERN': 0,
    'WERNE': 0,
    'WERNECKE': 0,
    'WERNEKE': 0,
    'WERNER': 0.2820078962210942,
    'WERNERSBACH': 0,
    'WERNERT': 0,
    'WERNESS': 0,
    'WERNET': 0,
    'WERNETH': 0,
    'WERNETT': 0,
    'WERNETTE': 0,
    'WERNICK': 0,
    'WERNICKE': 0,
    'WERNICKI': 0,
    'WERNIG': 0,
    'WERNIMONT': 0,
    'WERNING': 0,
    'WERNKE': 0,
    'WERNLE': 0,
    'WERNLI': 0,
    'WERNSING': 0,
    'WERNSMAN': 0,
    'WERNTZ': 0,
    'WERNZ': 0,
    'WERR': 0,
    'WERRA': 0,
    'WERRE': 0,
    'WERRELL': 0,
    'WERREMEYER': 0,
    'WERREN': 0,
    'WERRIES': 0,
    'WERRING': 0,
    'WERRY': 0,
    'WERSAL': 0,
    'WERSCHING': 0,
    'WERSINGER': 0,
    'WERST': 0,
    'WERSTEIN': 0,
    'WERSTLER': 0,
    'WERT': 0,
    'WERTANEN': 0,
    'WERTEL': 0,
    'WERTENBERGER': 0,
    'WERTH': 0,
    'WERTHEIM': 0,
    'WERTHEIMER': 0,
    'WERTHER': 0,
    'WERTHMAN': 0,
    'WERTHMANN': 0,
    'WERTIN': 0,
    'WERTISH': 0,
    'WERTMAN': 0,
    'WERTS': 0,
    'WERTZ': 0,
    'WERTZBERGER': 0,
    'WERY': 0,
    'WERZBERGER': 0,
    'WES': 1,
    'WESA': 0,
    'WESAW': 0,
    'WESBECHER': 0,
    'WESBERRY': 0,
    'WESBROOK': 0,
    'WESBY': 0,
    'WESCH': 0,
    'WESCHE': 0,
    'WESCHLER': 0,
    'WESCO': 0,
    'WESCOAT': 0,
    'WESCOE': 0,
    'WESCOM': 0,
    'WESCOTT': 0,
    'WESCOVICH': 0,
    'WESEL': 0,
    'WESELOH': 0,
    'WESELY': 0,
    'WESEMAN': 0,
    'WESEMANN': 0,
    'WESEN': 0,
    'WESENBERG': 0,
    'WESENER': 0,
    'WESER': 0,
    'WESH': 0,
    'WESKAMP': 0,
    'WESKE': 0,
    'WESLER': 0,
    'WESLEY': 0.928710419246418,
    'WESLING': 0,
    'WESLOW': 0,
    'WESLOWSKI': 0,
    'WESNER': 0,
    'WESNESKI': 0,
    'WESNEY': 0,
    'WESNOFSKE': 0,
    'WESOLEK': 0,
    'WESOLOSKI': 0,
    'WESOLOWSKI': 0,
    'WESP': 0,
    'WESS': 0,
    'WESSEL': 0,
    'WESSELER': 0,
    'WESSELHOFF': 0,
    'WESSELHOFT': 0,
    'WESSELING': 0,
    'WESSELINK': 0,
    'WESSELIUS': 0,
    'WESSELL': 0,
    'WESSELLS': 0,
    'WESSELMAN': 0,
    'WESSELMANN': 0,
    'WESSELS': 0,
    'WESSELY': 0,
    'WESSENDORF': 0,
    'WESSER': 0,
    'WESSING': 0,
    'WESSINGER': 0,
    'WESSLER': 0,
    'WESSLEY': 0,
    'WESSLING': 0,
    'WESSMAN': 0,
    'WESSNER': 0,
    'WESSON': 0,
    'WEST': 0,
    'WESTABY': 0,
    'WESTAD': 0,
    'WESTALL': 0,
    'WESTAWAY': 0,
    'WESTBAY': 0,
    'WESTBERG': 0,
    'WESTBERRY': 0,
    'WESTBROCK': 0,
    'WESTBROOK': 0,
    'WESTBROOKE': 0,
    'WESTBROOKS': 0,
    'WESTBURG': 0,
    'WESTBURY': 0,
    'WESTBY': 0,
    'WESTCOAT': 0,
    'WESTCOTT': 0,
    'WESTDORP': 0,
    'WESTDYKE': 0,
    'WESTEMEIER': 0,
    'WESTEN': 0,
    'WESTENBARGER': 0,
    'WESTENBERG': 0,
    'WESTENBERGER': 0,
    'WESTENBURG': 0,
    'WESTENDORF': 0,
    'WESTENHAVER': 0,
    'WESTENSKOW': 0,
    'WESTER': 0,
    'WESTERBACK': 0,
    'WESTERBECK': 0,
    'WESTERBERG': 0,
    'WESTERBUR': 0,
    'WESTERBY': 0,
    'WESTERCAMP': 0,
    'WESTERDAHL': 0,
    'WESTERDALE': 0,
    'WESTERFELD': 0,
    'WESTERFER': 0,
    'WESTERFIELD': 0,
    'WESTERGAARD': 0,
    'WESTERGARD': 0,
    'WESTERGREEN': 0,
    'WESTERGREN': 0,
    'WESTERHAUS': 0,
    'WESTERHAUSEN': 0,
    'WESTERHEIDE': 0,
    'WESTERHOF': 0,
    'WESTERHOFF': 0,
    'WESTERHOLD': 0,
    'WESTERHOLM': 0,
    'WESTERHOUSE': 0,
    'WESTERKAMP': 0,
    'WESTERLIND': 0,
    'WESTERLING': 0,
    'WESTERLUND': 0,
    'WESTERMAN': 0,
    'WESTERMANN': 0,
    'WESTERMAYER': 0,
    'WESTERMEIER': 0,
    'WESTERMEYER': 0,
    'WESTERN': 0,
    'WESTERVELT': 0,
    'WESTFAHL': 0,
    'WESTFALL': 0,
    'WESTFIELD': 0,
    'WESTGAARD': 0,
    'WESTGARD': 0,
    'WESTGATE': 0,
    'WESTGERDES': 0,
    'WESTHAFER': 0,
    'WESTHAVER': 0,
    'WESTHEAD': 0,
    'WESTHEIMER': 0,
    'WESTHOFF': 0,
    'WESTHOUSE': 0,
    'WESTHOVEN': 0,
    'WESTHUES': 0,
    'WESTHUIS': 0,
    'WESTHUSING': 0,
    'WESTIN': 0,
    'WESTING': 0,
    'WESTJOHN': 0,
    'WESTLAKE': 0,
    'WESTLAND': 0,
    'WESTLEIGH': 0,
    'WESTLEY': 0,
    'WESTLIE': 0,
    'WESTLIN': 0,
    'WESTLING': 0,
    'WESTLUND': 0,
    'WESTLY': 0,
    'WESTMAAS': 0,
    'WESTMAN': 0,
    'WESTMARK': 0,
    'WESTMEYER': 0,
    'WESTMILLER': 0,
    'WESTMOLAND': 0,
    'WESTMORE': 0,
    'WESTMORELAND': 0,
    'WESTMORLAND': 0,
    'WESTNEY': 0,
    'WESTON': 0.39603960396039606,
    'WESTOVER': 0,
    'WESTPFAHL': 0,
    'WESTPHAL': 0,
    'WESTPHALEN': 0,
    'WESTPHALL': 0,
    'WESTRA': 0,
    'WESTRATE': 0,
    'WESTRAY': 0,
    'WESTRE': 0,
    'WESTREICH': 0,
    'WESTRICH': 0,
    'WESTRICK': 0,
    'WESTRING': 0,
    'WESTROM': 0,
    'WESTROPE': 0,
    'WESTRUM': 0,
    'WESTRUP': 0,
    'WESTRY': 0,
    'WESTVEER': 0,
    'WESTWATER': 0,
    'WESTWOOD': 0,
    'WETCH': 0,
    'WETENKAMP': 0,
    'WETER': 0,
    'WETHERALD': 0,
    'WETHERALL': 0,
    'WETHERBEE': 0,
    'WETHERBY': 0,
    'WETHERELL': 0,
    'WETHERFORD': 0,
    'WETHERHOLD': 0,
    'WETHERHOLT': 0,
    'WETHERILL': 0,
    'WETHERINGTON': 0,
    'WETHERN': 0,
    'WETHERS': 0,
    'WETHERSPOON': 0,
    'WETHERWAX': 0,
    'WETHEY': 0,
    'WETHINGTON': 0,
    'WETHY': 0,
    'WETJEN': 0,
    'WETLI': 0,
    'WETMORE': 0,
    'WETNIGHT': 0,
    'WETRICH': 0,
    'WETSCH': 0,
    'WETSEL': 0,
    'WETSTEIN': 0,
    'WETTA': 0,
    'WETTACH': 0,
    'WETTELAND': 0,
    'WETTENGEL': 0,
    'WETTER': 0,
    'WETTERAU': 0,
    'WETTERER': 0,
    'WETTERHAHN': 0,
    'WETTERLING': 0,
    'WETTERMAN': 0,
    'WETTERS': 0,
    'WETTERSTROM': 0,
    'WETTIG': 0,
    'WETTLAUFER': 0,
    'WETTON': 0,
    'WETTSTEIN': 0,
    'WETZ': 0,
    'WETZBARGER': 0,
    'WETZEL': 0,
    'WETZELL': 0,
    'WETZIG': 0,
    'WETZLER': 0,
    'WETZSTEIN': 0,
    'WEUM': 0,
    'WEUVE': 0,
    'WEVER': 0,
    'WEVERKA': 0,
    'WEVODAU': 0,
    'WEWER': 0,
    'WEWERS': 0,
    'WEXELL': 0,
    'WEXLER': 0,
    'WEY': 0,
    'WEYAND': 0,
    'WEYANDT': 0,
    'WEYANT': 0,
    'WEYBRIGHT': 0,
    'WEYBURN': 0,
    'WEYDERT': 0,
    'WEYEL': 0,
    'WEYENBERG': 0,
    'WEYENETH': 0,
    'WEYER': 0,
    'WEYERMAN': 0,
    'WEYERS': 0,
    'WEYGAND': 0,
    'WEYGANDT': 0,
    'WEYGANT': 0,
    'WEYH': 0,
    'WEYHER': 0,
    'WEYHRAUCH': 0,
    'WEYHRICH': 0,
    'WEYKER': 0,
    'WEYL': 0,
    'WEYLAND': 0,
    'WEYLER': 0,
    'WEYMAN': 0,
    'WEYMER': 0,
    'WEYMOUTH': 0,
    'WEYNAND': 0,
    'WEYRAUCH': 0,
    'WEYRICH': 0,
    'WEYRICK': 0,
    'WHACK': 0,
    'WHALE': 0,
    'WHALEN': 0,
    'WHALER': 0,
    'WHALEY': 0,
    'WHALIN': 0,
    'WHALING': 0,
    'WHALL': 0,
    'WHALLEY': 0,
    'WHALLON': 0,
    'WHALON': 0,
    'WHALUM': 0,
    'WHAM': 0,
    'WHAN': 0,
    'WHANG': 0,
    'WHANGER': 0,
    'WHANN': 0,
    'WHAPHAM': 0,
    'WHAPLES': 0,
    'WHARAM': 0,
    'WHARFF': 0,
    'WHARRAM': 0,
    'WHARRY': 0,
    'WHARTENBY': 0,
    'WHARTON': 0,
    'WHARY': 0,
    'WHATCOTT': 0,
    'WHATLEY': 0,
    'WHATTON': 0,
    'WHAYNE': 0,
    'WHEADON': 0,
    'WHEALDON': 0,
    'WHEALE': 0,
    'WHEALTON': 0,
    'WHEALY': 0,
    'WHEAR': 0,
    'WHEARTY': 0,
    'WHEARY': 0,
    'WHEAT': 0,
    'WHEATCRAFT': 0,
    'WHEATCROFT': 0,
    'WHEATER': 0,
    'WHEATFALL': 0,
    'WHEATLE': 0,
    'WHEATLEY': 0,
    'WHEATLY': 0,
    'WHEATMAN': 0,
    'WHEATON': 0,
    'WHEDBEE': 0,
    'WHEDON': 0,
    'WHEEL': 0,
    'WHEELAN': 0,
    'WHEELAND': 0,
    'WHEELBARGER': 0,
    'WHEELDEN': 0,
    'WHEELDON': 0,
    'WHEELEN': 0,
    'WHEELER': 0,
    'WHEELES': 0,
    'WHEELESS': 0,
    'WHEELEY': 0,
    'WHEELHOUSE': 0,
    'WHEELING': 0,
    'WHEELINGTON': 0,
    'WHEELIS': 0,
    'WHEELOCK': 0,
    'WHEELON': 0,
    'WHEELUS': 0,
    'WHEELWRIGHT': 0,
    'WHEET': 0,
    'WHEETLEY': 0,
    'WHELAN': 0,
    'WHELAND': 0,
    'WHELCHEL': 0,
    'WHELDEN': 0,
    'WHELDON': 0,
    'WHELEHAN': 0,
    'WHELEN': 0,
    'WHELER': 0,
    'WHELESS': 0,
    'WHELIHAN': 0,
    'WHELLER': 0,
    'WHELPLEY': 0,
    'WHELTON': 0,
    'WHERLEY': 0,
    'WHERRY': 0,
    'WHETHAM': 0,
    'WHETMAN': 0,
    'WHETSEL': 0,
    'WHETSELL': 0,
    'WHETSTINE': 0,
    'WHETSTONE': 0,
    'WHETTEN': 0,
    'WHETTER': 0,
    'WHETTON': 0,
    'WHETZEL': 0,
    'WHETZELL': 0,
    'WHEWELL': 0,
    'WHICHARD': 0,
    'WHICHER': 0,
    'WHICKER': 0,
    'WHIDBEE': 0,
    'WHIDBY': 0,
    'WHIDDEN': 0,
    'WHIDDON': 0,
    'WHIFFEN': 0,
    'WHIGHAM': 0,
    'WHIGHT': 0,
    'WHILBY': 0,
    'WHILDEN': 0,
    'WHILDIN': 0,
    'WHILE': 0,
    'WHILES': 0,
    'WHILEY': 0,
    'WHILLOCK': 0,
    'WHIMPEY': 0,
    'WHIMS': 0,
    'WHINERY': 0,
    'WHINNERY': 0,
    'WHIP': 0,
    'WHIPKEY': 0,
    'WHIPP': 0,
    'WHIPPIE': 0,
    'WHIPPLE': 0,
    'WHIPPO': 0,
    'WHIPPS': 0,
    'WHIRL': 0,
    'WHIRLEY': 0,
    'WHIRLOW': 0,
    'WHISBY': 0,
    'WHISENAND': 0,
    'WHISENANT': 0,
    'WHISENHUNT': 0,
    'WHISENTON': 0,
    'WHISKER': 0,
    'WHISLER': 0,
    'WHISMAN': 0,
    'WHISNANT': 0,
    'WHISNER': 0,
    'WHISONANT': 0,
    'WHISPELL': 0,
    'WHISTLE': 0,
    'WHISTLER': 0,
    'WHISTON': 0,
    'WHIT': 0,
    'WHITACRE': 0,
    'WHITAKER': 0,
    'WHITBECK': 0,
    'WHITBEY': 0,
    'WHITBREAD': 0,
    'WHITBURN': 0,
    'WHITBY': 0,
    'WHITCHER': 0,
    'WHITCHURCH': 0,
    'WHITCOMB': 0,
    'WHITCOMBE': 0,
    'WHITCOME': 0,
    'WHITCRAFT': 0,
    'WHITE': 0,
    'WHITEAKER': 0,
    'WHITEBEAR': 0,
    'WHITEBIRD': 0,
    'WHITEBREAD': 0,
    'WHITEBUFFALO': 0,
    'WHITEBULL': 0,
    'WHITECAR': 0,
    'WHITECAVAGE': 0,
    'WHITECLOUD': 0,
    'WHITECOTTON': 0,
    'WHITED': 0,
    'WHITEEAGLE': 0,
    'WHITEEYES': 0,
    'WHITEFACE': 0,
    'WHITEFEATHER': 0,
    'WHITEFIELD': 0,
    'WHITEFOOT': 0,
    'WHITEFORD': 0,
    'WHITEHAIR': 0,
    'WHITEHALL': 0,
    'WHITEHAT': 0,
    'WHITEHAWK': 0,
    'WHITEHEAD': 0,
    'WHITEHEART': 0,
    'WHITEHILL': 0,
    'WHITEHORN': 0,
    'WHITEHORNE': 0,
    'WHITEHORSE': 0,
    'WHITEHOUSE': 0,
    'WHITEHURST': 0,
    'WHITEING': 0,
    'WHITEIS': 0,
    'WHITEKER': 0,
    'WHITEKILLER': 0,
    'WHITELAW': 0,
    'WHITELEATHER': 0,
    'WHITELEY': 0,
    'WHITELOCK': 0,
    'WHITELOW': 0,
    'WHITELY': 0,
    'WHITEMAN': 0,
    'WHITEMORE': 0,
    'WHITEN': 0,
    'WHITENACK': 0,
    'WHITENECK': 0,
    'WHITENER': 0,
    'WHITENIGHT': 0,
    'WHITENTON': 0,
    'WHITEPLUME': 0,
    'WHITEROCK': 0,
    'WHITERS': 0,
    'WHITESCARVER': 0,
    'WHITESEL': 0,
    'WHITESELL': 0,
    'WHITESHIELD': 0,
    'WHITESIDE': 0,
    'WHITESIDES': 0,
    'WHITESITT': 0,
    'WHITESTONE': 0,
    'WHITETREE': 0,
    'WHITEWATER': 0,
    'WHITEWAY': 0,
    'WHITEWOLF': 0,
    'WHITFIELD': 0,
    'WHITFILL': 0,
    'WHITFORD': 0,
    'WHITHAM': 0,
    'WHITHEAD': 0,
    'WHITIKER': 0,
    'WHITING': 0,
    'WHITINGER': 0,
    'WHITINGTON': 0,
    'WHITIS': 0,
    'WHITISH': 0,
    'WHITKER': 0,
    'WHITLATCH': 0,
    'WHITLEDGE': 0,
    'WHITLER': 0,
    'WHITLEY': 0.09372071227741331,
    'WHITLING': 0,
    'WHITLINGER': 0,
    'WHITLOCK': 0,
    'WHITLOW': 0,
    'WHITMAN': 0,
    'WHITMARSH': 0,
    'WHITMER': 0,
    'WHITMEYER': 0,
    'WHITMILL': 0,
    'WHITMIRE': 0,
    'WHITMORE': 0,
    'WHITMOYER': 0,
    'WHITMYER': 0,
    'WHITMYRE': 0,
    'WHITNAH': 0,
    'WHITNELL': 0,
    'WHITNER': 0,
    'WHITNEY': 0.7974481658692186,
    'WHITON': 0,
    'WHITRIGHT': 0,
    'WHITROCK': 0,
    'WHITSEL': 0,
    'WHITSELL': 0,
    'WHITSETT': 0,
    'WHITSEY': 0,
    'WHITSITT': 0,
    'WHITSON': 0,
    'WHITSTINE': 0,
    'WHITT': 0,
    'WHITTAKER': 0,
    'WHITTALL': 0,
    'WHITTAM': 0,
    'WHITTAMORE': 0,
    'WHITTECAR': 0,
    'WHITTED': 0,
    'WHITTEKER': 0,
    'WHITTEMORE': 0,
    'WHITTEN': 0,
    'WHITTENBARGER': 0,
    'WHITTENBERG': 0,
    'WHITTENBERGER': 0,
    'WHITTENBURG': 0,
    'WHITTENTON': 0,
    'WHITTER': 0,
    'WHITTERS': 0,
    'WHITTET': 0,
    'WHITTEY': 0,
    'WHITTHORNE': 0,
    'WHITTICK': 0,
    'WHITTIE': 0,
    'WHITTIER': 0,
    'WHITTIKER': 0,
    'WHITTING': 0,
    'WHITTINGHAM': 0,
    'WHITTINGHILL': 0,
    'WHITTINGTON': 0,
    'WHITTLE': 0,
    'WHITTLER': 0,
    'WHITTLES': 0,
    'WHITTLESEY': 0,
    'WHITTLEY': 0,
    'WHITTMAN': 0,
    'WHITTMORE': 0,
    'WHITTOM': 0,
    'WHITTON': 0,
    'WHITTREDGE': 0,
    'WHITTUM': 0,
    'WHITTY': 0,
    'WHITUS': 0,
    'WHITVER': 0,
    'WHITWAM': 0,
    'WHITWELL': 0,
    'WHITWORTH': 0,
    'WHITZEL': 0,
    'WHOBREY': 0,
    'WHOLAVER': 0,
    'WHOLEY': 0,
    'WHOLLEY': 0,
    'WHOOLERY': 0,
    'WHOOLEY': 0,
    'WHORF': 0,
    'WHORL': 0,
    'WHORLEY': 0,
    'WHORRALL': 0,
    'WHORTON': 0,
    'WHRITENOUR': 0,
    'WHTIE': 0,
    'WHY': 0,
    'WHYATT': 0,
    'WHYBARK': 0,
    'WHYBREW': 0,
    'WHYDE': 0,
    'WHYE': 0,
    'WHYEL': 0,
    'WHYMAN': 0,
    'WHYMS': 0,
    'WHYNOT': 0,
    'WHYNOTT': 0,
    'WHYSONG': 0,
    'WHYTE': 0,
    'WHYTSELL': 0,
    'WI': 0,
    'WIACEK': 0,
    'WIAFE': 0,
    'WIAN': 0,
    'WIAND': 0,
    'WIANDT': 0,
    'WIANECKI': 0,
    'WIANS': 0,
    'WIANT': 0,
    'WIARD': 0,
    'WIARDA': 0,
    'WIATER': 0,
    'WIATR': 0,
    'WIATRAK': 0,
    'WIATREK': 0,
    'WIATROWSKI': 0,
    'WIATT': 0,
    'WIBBELS': 0,
    'WIBBEN': 0,
    'WIBBENMEYER': 0,
    'WIBBENS': 0,
    'WIBEL': 0,
    'WIBERG': 0,
    'WIBERT': 0,
    'WIBLE': 0,
    'WIBLIN': 0,
    'WIBORG': 0,
    'WIBOWO': 0,
    'WICAL': 0,
    'WICE': 0,
    'WICH': 0,
    'WICHAEL': 0,
    'WICHER': 0,
    'WICHERN': 0,
    'WICHERS': 0,
    'WICHERT': 0,
    'WICHLACZ': 0,
    'WICHMAN': 0,
    'WICHMANN': 0,
    'WICHNER': 0,
    'WICHOWSKI': 0,
    'WICHROWSKI': 0,
    'WICHSER': 0,
    'WICHT': 0,
    'WICHTENDAHL': 0,
    'WICHTERMAN': 0,
    'WICINSKI': 0,
    'WICK': 0,
    'WICKA': 0,
    'WICKAM': 0,
    'WICKARD': 0,
    'WICKBERG': 0,
    'WICKBOLDT': 0,
    'WICKE': 0,
    'WICKEL': 0,
    'WICKEN': 0,
    'WICKENDEN': 0,
    'WICKENHAUSER': 0,
    'WICKENHEISER': 0,
    'WICKENKAMP': 0,
    'WICKENS': 0,
    'WICKER': 0,
    'WICKERHAM': 0,
    'WICKERS': 0,
    'WICKERSHAM': 0,
    'WICKERSHEIM': 0,
    'WICKERSON': 0,
    'WICKERT': 0,
    'WICKES': 0,
    'WICKESBERG': 0,
    'WICKETT': 0,
    'WICKEY': 0,
    'WICKHAM': 0,
    'WICKINGS': 0,
    'WICKISER': 0,
    'WICKIZER': 0,
    'WICKLAND': 0,
    'WICKLANDER': 0,
    'WICKLEIN': 0,
    'WICKLER': 0,
    'WICKLIFF': 0,
    'WICKLIFFE': 0,
    'WICKLINE': 0,
    'WICKLUND': 0,
    'WICKMAN': 0,
    'WICKRE': 0,
    'WICKS': 0,
    'WICKSON': 0,
    'WICKSTROM': 0,
    'WICKUM': 0,
    'WICKWARE': 0,
    'WICKWIRE': 0,
    'WICOFF': 0,
    'WICZEK': 0,
    'WIDA': 0,
    'WIDAMAN': 0,
    'WIDBY': 0,
    'WIDDEL': 0,
    'WIDDER': 0,
    'WIDDERS': 0,
    'WIDDICOMBE': 0,
    'WIDDIFIELD': 0,
    'WIDDIS': 0,
    'WIDDISON': 0,
    'WIDDOES': 0,
    'WIDDOP': 0,
    'WIDDOSS': 0,
    'WIDDOWS': 0,
    'WIDDOWSON': 0,
    'WIDE': 0,
    'WIDEL': 0,
    'WIDELL': 0,
    'WIDELSKI': 0,
    'WIDEMAN': 0,
    'WIDEMON': 0,
    'WIDEN': 0,
    'WIDENER': 0,
    'WIDENHOFER': 0,
    'WIDENHOUSE': 0,
    'WIDER': 0,
    'WIDERMAN': 0,
    'WIDGEON': 0,
    'WIDGER': 0,
    'WIDGREN': 0,
    'WIDHALM': 0,
    'WIDHOLM': 0,
    'WIDICK': 0,
    'WIDING': 0,
    'WIDJAJA': 0,
    'WIDLAK': 0,
    'WIDLER': 0,
    'WIDLUND': 0,
    'WIDMAIER': 0,
    'WIDMAN': 0,
    'WIDMANN': 0,
    'WIDMAR': 0,
    'WIDMARK': 0,
    'WIDMAYER': 0,
    'WIDMER': 0,
    'WIDMEYER': 0,
    'WIDMYER': 0,
    'WIDNER': 0,
    'WIDNEY': 0,
    'WIDO': 0,
    'WIDOM': 0,
    'WIDOMSKI': 0,
    'WIDOWSKI': 0,
    'WIDRICK': 0,
    'WIDRIG': 0,
    'WIDSTROM': 0,
    'WIDTFELDT': 0,
    'WIDUCH': 0,
    'WIDUP': 0,
    'WIE': 0,
    'WIEAND': 0,
    'WIEBE': 0,
    'WIEBEL': 0,
    'WIEBELHAUS': 0,
    'WIEBELT': 0,
    'WIEBEN': 0,
    'WIEBENGA': 0,
    'WIEBER': 0,
    'WIEBERDINK': 0,
    'WIEBERG': 0,
    'WIEBERS': 0,
    'WIEBKE': 0,
    'WIEBLER': 0,
    'WIEBOLD': 0,
    'WIEBOLDT': 0,
    'WIEBUSCH': 0,
    'WIECEK': 0,
    'WIECH': 0,
    'WIECHART': 0,
    'WIECHEC': 0,
    'WIECHERS': 0,
    'WIECHERT': 0,
    'WIECHMAN': 0,
    'WIECHMANN': 0,
    'WIECK': 0,
    'WIECKOWSKI': 0,
    'WIECLAW': 0,
    'WIECZOREK': 0,
    'WIECZORKOWSKI': 0,
    'WIED': 0,
    'WIEDA': 0,
    'WIEDE': 0,
    'WIEDEL': 0,
    'WIEDEMAN': 0,
    'WIEDEMANN': 0,
    'WIEDEMEIER': 0,
    'WIEDEMER': 0,
    'WIEDEN': 0,
    'WIEDENBECK': 0,
    'WIEDENFELD': 0,
    'WIEDENHEFT': 0,
    'WIEDENHOEFT': 0,
    'WIEDENHOFT': 0,
    'WIEDENMAN': 0,
    'WIEDENMANN': 0,
    'WIEDER': 0,
    'WIEDERHOEFT': 0,
    'WIEDERHOLD': 0,
    'WIEDERHOLT': 0,
    'WIEDERIN': 0,
    'WIEDERKEHR': 0,
    'WIEDERMAN': 0,
    'WIEDERRICH': 0,
    'WIEDERSPAN': 0,
    'WIEDERSTEIN': 0,
    'WIEDIGER': 0,
    'WIEDL': 0,
    'WIEDMAIER': 0,
    'WIEDMAN': 0,
    'WIEDMANN': 0,
    'WIEDMEIER': 0,
    'WIEDMER': 0,
    'WIEDMEYER': 0,
    'WIEDNER': 0,
    'WIEDOW': 0,
    'WIEDOWER': 0,
    'WIEDRICH': 0,
    'WIEDRICK': 0,
    'WIEFERICH': 0,
    'WIEGAND': 0,
    'WIEGANDT': 0,
    'WIEGARD': 0,
    'WIEGE': 0,
    'WIEGEL': 0,
    'WIEGELE': 0,
    'WIEGER': 0,
    'WIEGERS': 0,
    'WIEGERT': 0,
    'WIEGMAN': 0,
    'WIEGMANN': 0,
    'WIEGNER': 0,
    'WIEHE': 0,
    'WIEHL': 0,
    'WIEHLE': 0,
    'WIEHN': 0,
    'WIEHOFF': 0,
    'WIEK': 0,
    'WIEKAMP': 0,
    'WIEKER': 0,
    'WIEL': 0,
    'WIELAND': 0,
    'WIELE': 0,
    'WIELENGA': 0,
    'WIELER': 0,
    'WIELGOS': 0,
    'WIELGOSZ': 0,
    'WIELGUS': 0,
    'WIELINSKI': 0,
    'WIELOCH': 0,
    'WIEMAN': 0,
    'WIEMANN': 0,
    'WIEME': 0,
    'WIEMELT': 0,
    'WIEMER': 0,
    'WIEMERS': 0,
    'WIEMERSLAGE': 0,
    'WIEMKEN': 0,
    'WIEN': 0,
    'WIENAND': 0,
    'WIENBERG': 0,
    'WIENCEK': 0,
    'WIENCKOWSKI': 0,
    'WIENCLAW': 0,
    'WIENCZKOWSKI': 0,
    'WIENECKE': 0,
    'WIENEKE': 0,
    'WIENER': 0,
    'WIENERS': 0,
    'WIENERT': 0,
    'WIENHOFF': 0,
    'WIENHOLD': 0,
    'WIENING': 0,
    'WIENK': 0,
    'WIENKE': 0,
    'WIENS': 0,
    'WIENTJES': 0,
    'WIEPERT': 0,
    'WIER': 0,
    'WIERCINSKI': 0,
    'WIERCIOCH': 0,
    'WIERDA': 0,
    'WIERENGA': 0,
    'WIERENGO': 0,
    'WIERING': 0,
    'WIERINGA': 0,
    'WIERMAN': 0,
    'WIERNICKI': 0,
    'WIERNIK': 0,
    'WIERS': 0,
    'WIERSCHEM': 0,
    'WIERSCHKE': 0,
    'WIERSEMA': 0,
    'WIERSMA': 0,
    'WIERSON': 0,
    'WIERSUM': 0,
    'WIERTEL': 0,
    'WIERTZEMA': 0,
    'WIERWILLE': 0,
    'WIERZBA': 0,
    'WIERZBICKI': 0,
    'WIERZBINSKI': 0,
    'WIERZBOWSKI': 0,
    'WIERZCHOWSKI': 0,
    'WIES': 0,
    'WIESBROCK': 0,
    'WIESE': 0,
    'WIESEHAN': 0,
    'WIESEL': 0,
    'WIESELER': 0,
    'WIESEMAN': 0,
    'WIESEMANN': 0,
    'WIESEN': 0,
    'WIESENBERG': 0,
    'WIESENDANGER': 0,
    'WIESENFELD': 0,
    'WIESENTHAL': 0,
    'WIESER': 0,
    'WIESINGER': 0,
    'WIESKAMP': 0,
    'WIESKE': 0,
    'WIESLER': 0,
    'WIESMAN': 0,
    'WIESMANN': 0,
    'WIESNER': 0,
    'WIESS': 0,
    'WIESSNER': 0,
    'WIEST': 0,
    'WIETECHA': 0,
    'WIETERS': 0,
    'WIETFELDT': 0,
    'WIETHOFF': 0,
    'WIETHOLTER': 0,
    'WIETHOP': 0,
    'WIETHORN': 0,
    'WIETING': 0,
    'WIETRZYKOWSKI': 0,
    'WIETZKE': 0,
    'WIEWEL': 0,
    'WIEZOREK': 0,
    'WIFE': 0,
    'WIFORD': 0,
    'WIG': 0,
    'WIGAL': 0,
    'WIGAND': 0,
    'WIGANT': 0,
    'WIGDAHL': 0,
    'WIGDER': 0,
    'WIGDOR': 0,
    'WIGEN': 0,
    'WIGENT': 0,
    'WIGER': 0,
    'WIGERT': 0,
    'WIGET': 0,
    'WIGFALL': 0,
    'WIGFIELD': 0,
    'WIGG': 0,
    'WIGGAM': 0,
    'WIGGAN': 0,
    'WIGGANS': 0,
    'WIGGEN': 0,
    'WIGGENS': 0,
    'WIGGER': 0,
    'WIGGERS': 0,
    'WIGGETT': 0,
    'WIGGIN': 0,
    'WIGGINGTON': 0,
    'WIGGINS': 0,
    'WIGGINTON': 0,
    'WIGGLESWORTH': 0,
    'WIGGLETON': 0,
    'WIGGS': 0,
    'WIGHAM': 0,
    'WIGHT': 0,
    'WIGHTMAN': 0,
    'WIGINGTON': 0,
    'WIGINTON': 0,
    'WIGLE': 0,
    'WIGLER': 0,
    'WIGLESWORTH': 0,
    'WIGLEY': 0,
    'WIGMAN': 0,
    'WIGMORE': 0,
    'WIGNALL': 0,
    'WIGNER': 0,
    'WIGREN': 0,
    'WIGTON': 0,
    'WIIG': 0,
    'WIIK': 0,
    'WIITA': 0,
    'WIITALA': 0,
    'WIITANEN': 0,
    'WIJAS': 0,
    'WIJAYA': 0,
    'WIJESINGHE': 0,
    'WIK': 0,
    'WIKA': 0,
    'WIKANDER': 0,
    'WIKE': 0,
    'WIKEL': 0,
    'WIKEN': 0,
    'WIKER': 0,
    'WIKERT': 0,
    'WIKLE': 0,
    'WIKLUND': 0,
    'WIKMAN': 0,
    'WIKOFF': 0,
    'WIKSTEN': 0,
    'WIKSTROM': 0,
    'WIKTOR': 0,
    'WIKTOREK': 0,
    'WIKTOROWSKI': 0,
    'WIL': 0,
    'WILABY': 0,
    'WILAMOWSKI': 0,
    'WILAND': 0,
    'WILANDER': 0,
    'WILBANKS': 0,
    'WILBAR': 0,
    'WILBECK': 0,
    'WILBER': 0.6430868167202572,
    'WILBERDING': 0,
    'WILBERG': 0,
    'WILBERGER': 0,
    'WILBERN': 0,
    'WILBERS': 0,
    'WILBERT': 0.962223806129722,
    'WILBON': 0,
    'WILBORN': 0,
    'WILBORNE': 0,
    'WILBOURN': 0,
    'WILBOURNE': 0,
    'WILBRAHAM': 0,
    'WILBUR': 0.9090909090909091,
    'WILBURN': 0.5591054313099042,
    'WILBY': 0,
    'WILCE': 0,
    'WILCH': 0,
    'WILCHER': 0,
    'WILCHES': 0,
    'WILCK': 0,
    'WILCKE': 0,
    'WILCKEN': 0,
    'WILCKENS': 0,
    'WILCOCK': 0,
    'WILCOCKSON': 0,
    'WILCOMB': 0,
    'WILCOTS': 0,
    'WILCOTT': 0,
    'WILCOX': 0,
    'WILCOXEN': 0,
    'WILCOXON': 0,
    'WILCOXSON': 0,
    'WILCUT': 0,
    'WILCUTT': 0,
    'WILCZAK': 0,
    'WILCZEK': 0,
    'WILCZEWSKI': 0,
    'WILCZYNSKI': 0,
    'WILD': 0,
    'WILDA': 0.9846827133479211,
    'WILDASIN': 0,
    'WILDAUER': 0,
    'WILDAY': 0,
    'WILDBERGER': 0,
    'WILDCAT': 0,
    'WILDE': 0,
    'WILDEBOER': 0,
    'WILDEMAN': 0,
    'WILDEN': 0,
    'WILDENBERG': 0,
    'WILDENSTEIN': 0,
    'WILDER': 0,
    'WILDERMAN': 0,
    'WILDERMUTH': 0,
    'WILDERS': 0,
    'WILDERSON': 0,
    'WILDES': 0,
    'WILDEY': 0,
    'WILDFEUER': 0,
    'WILDFONG': 0,
    'WILDGOOSE': 0,
    'WILDGRUBE': 0,
    'WILDHABER': 0,
    'WILDHAGEN': 0,
    'WILDIN': 0,
    'WILDING': 0,
    'WILDISH': 0,
    'WILDMAN': 0,
    'WILDMON': 0,
    'WILDNER': 0,
    'WILDONER': 0,
    'WILDONGER': 0,
    'WILDRICK': 0,
    'WILDRIDGE': 0,
    'WILDS': 0,
    'WILDSMITH': 0,
    'WILDSTEIN': 0,
    'WILDT': 0,
    'WILDUNG': 0,
    'WILDY': 0,
    'WILE': 0,
    'WILEBSKI': 0,
    'WILEMAN': 0,
    'WILEMON': 0,
    'WILEN': 0,
    'WILENS': 0,
    'WILENSKY': 0,
    'WILER': 0,
    'WILES': 0,
    'WILEY': 0.3844809507165327,
    'WILF': 0,
    'WILFAHRT': 0,
    'WILFER': 0,
    'WILFERT': 0,
    'WILFERTH': 0,
    'WILFINGER': 0,
    'WILFLEY': 0,
    'WILFONG': 0,
    'WILFORD': 0.89086859688196,
    'WILFRED': 0.9956709956709957,
    'WILFREDO': 1,
    'WILGA': 0,
    'WILGANOWSKI': 0,
    'WILGENBUSCH': 0,
    'WILGER': 0,
    'WILGERS': 0,
    'WILGES': 0,
    'WILGUS': 0,
    'WILHAM': 0,
    'WILHARM': 0,
    'WILHELM': 0,
    'WILHELMI': 0,
    'WILHELMINA': 1,
    'WILHELMS': 0,
    'WILHELMSEN': 0,
    'WILHELMSON': 0,
    'WILHELMY': 0,
    'WILHEMINA': 1,
    'WILHIDE': 0,
    'WILHITE': 0,
    'WILHOIT': 0,
    'WILHOITE': 0,
    'WILHOUR': 0,
    'WILICHOWSKI': 0,
    'WILIE': 0,
    'WILINSKI': 0,
    'WILK': 0,
    'WILKAS': 0,
    'WILKE': 0,
    'WILKEN': 0,
    'WILKENFELD': 0,
    'WILKENING': 0,
    'WILKENS': 0,
    'WILKENSON': 0,
    'WILKER': 0,
    'WILKERSON': 0,
    'WILKES': 0,
    'WILKESON': 0,
    'WILKEWITZ': 0,
    'WILKEY': 0,
    'WILKIE': 0,
    'WILKIN': 0,
    'WILKING': 0,
    'WILKINS': 0,
    'WILKINSON': 0,
    'WILKISON': 0,
    'WILKLOW': 0,
    'WILKOFF': 0,
    'WILKOS': 0,
    'WILKOSZ': 0,
    'WILKOWSKI': 0,
    'WILKS': 0,
    'WILKSON': 0,
    'WILKUS': 0,
    'WILL': 0.7867132867132868,
    'WILLA': 0.997506234413965,
    'WILLABY': 0,
    'WILLACKER': 0,
    'WILLADSEN': 0,
    'WILLAERT': 0,
    'WILLAFORD': 0,
    'WILLAIMS': 0,
    'WILLAM': 0,
    'WILLAMAN': 0,
    'WILLAMSON': 0,
    'WILLAN': 0,
    'WILLAND': 0,
    'WILLARD': 0.8643042350907519,
    'WILLARDSON': 0,
    'WILLARS': 0,
    'WILLAUER': 0,
    'WILLBANKS': 0,
    'WILLBERG': 0,
    'WILLBORN': 0,
    'WILLBRAND': 0,
    'WILLBRANDT': 0,
    'WILLBUR': 0,
    'WILLBURN': 0,
    'WILLCOCK': 0,
    'WILLCOCKS': 0,
    'WILLCOCKSON': 0,
    'WILLCOX': 0,
    'WILLCOXON': 0,
    'WILLCOXSON': 0,
    'WILLCUT': 0,
    'WILLCUTS': 0,
    'WILLCUTT': 0,
    'WILLDEN': 0,
    'WILLE': 0,
    'WILLEBY': 0,
    'WILLEFORD': 0,
    'WILLEKE': 0,
    'WILLEM': 0,
    'WILLEMAIN': 0,
    'WILLEMAN': 0,
    'WILLEMIN': 0,
    'WILLEMS': 0,
    'WILLEMSE': 0,
    'WILLEMSEN': 0,
    'WILLEMSSEN': 0,
    'WILLEN': 0,
    'WILLENA': 1,
    'WILLENBERG': 0,
    'WILLENBORG': 0,
    'WILLENBRING': 0,
    'WILLENBRINK': 0,
    'WILLENBROCK': 0,
    'WILLENBURG': 0,
    'WILLENE': 1,
    'WILLENS': 0,
    'WILLER': 0,
    'WILLERS': 0,
    'WILLERSON': 0,
    'WILLERT': 0,
    'WILLERTON': 0,
    'WILLES': 0,
    'WILLESS': 0,
    'WILLET': 0,
    'WILLETO': 0,
    'WILLETS': 0,
    'WILLETT': 0,
    'WILLETTA': 1,
    'WILLETTE': 0.5988023952095809,
    'WILLETTS': 0,
    'WILLEVER': 0,
    'WILLEY': 0,
    'WILLFONG': 0,
    'WILLFORD': 0,
    'WILLGER': 0,
    'WILLGING': 0,
    'WILLHAM': 0,
    'WILLHELM': 0,
    'WILLHIDE': 0,
    'WILLHITE': 0,
    'WILLHOFT': 0,
    'WILLHOIT': 0,
    'WILLHOITE': 0,
    'WILLI': 0,
    'WILLIA': 0.9803921568627452,
    'WILLIAM': 0.9974192082325634,
    'WILLIAMA': 0,
    'WILLIAME': 0,
    'WILLIAMH': 0,
    'WILLIAMMEE': 0,
    'WILLIAMON': 0,
    'WILLIAMS': 0.022349826359041362,
    'WILLIAMSBEY': 0,
    'WILLIAMSBROWN': 0,
    'WILLIAMSEN': 0,
    'WILLIAMSJONES': 0,
    'WILLIAMSLEE': 0,
    'WILLIAMSMAE': 0,
    'WILLIAMSON': 0,
    'WILLIAMSSMITH': 0,
    'WILLIAMSTON': 0,
    'WILLIAN': 0.9779951100244498,
    'WILLIANSON': 0,
    'WILLIARD': 0,
    'WILLIAS': 0,
    'WILLIBEY': 0,
    'WILLIBY': 0,
    'WILLICH': 0,
    'WILLICK': 0,
    'WILLIE': 0.995558660611807,
    'WILLIEMAE': 1,
    'WILLIER': 0,
    'WILLIFORD': 0,
    'WILLIG': 0,
    'WILLIM': 0,
    'WILLIMAN': 0,
    'WILLIMAS': 0,
    'WILLIMON': 0,
    'WILLIMSON': 0,
    'WILLIN': 0,
    'WILLING': 0,
    'WILLINGER': 0,
    'WILLINGHAM': 0,
    'WILLINGS': 0,
    'WILLINGTON': 0,
    'WILLINK': 0,
    'WILLINS': 0,
    'WILLIQUETTE': 0,
    'WILLIS': 0.42907931837685426,
    'WILLISON': 0,
    'WILLISTON': 0,
    'WILLITS': 0,
    'WILLITTS': 0,
    'WILLIX': 0,
    'WILLKE': 0,
    'WILLKIE': 0,
    'WILLKOM': 0,
    'WILLKOMM': 0,
    'WILLLIAMS': 0,
    'WILLMAN': 0,
    'WILLMANN': 0,
    'WILLMARTH': 0,
    'WILLMER': 0,
    'WILLMERT': 0,
    'WILLMES': 0,
    'WILLMETH': 0,
    'WILLMING': 0,
    'WILLMON': 0,
    'WILLMORE': 0,
    'WILLMOT': 0,
    'WILLMOTT': 0,
    'WILLMS': 0,
    'WILLNER': 0,
    'WILLNOW': 0,
    'WILLOBY': 0,
    'WILLOCK': 0,
    'WILLOCKS': 0,
    'WILLODEAN': 1,
    'WILLOUGHBY': 0,
    'WILLOUR': 0,
    'WILLOVER': 0,
    'WILLOW': 0.7692307692307693,
    'WILLOWS': 0,
    'WILLOX': 0,
    'WILLRICH': 0,
    'WILLS': 0,
    'WILLSE': 0,
    'WILLSEY': 0,
    'WILLSIE': 0,
    'WILLSON': 0,
    'WILLUWEIT': 0,
    'WILLWERTH': 0,
    'WILLY': 0.9345794392523366,
    'WILLYARD': 0,
    'WILLYERD': 0,
    'WILM': 0,
    'WILMA': 1,
    'WILMAN': 0,
    'WILMARTH': 0,
    'WILMATH': 0,
    'WILMER': 0.9090909090909091,
    'WILMERS': 0,
    'WILMES': 0,
    'WILMETH': 0,
    'WILMINGTON': 0,
    'WILMONT': 0,
    'WILMORE': 0,
    'WILMOT': 0,
    'WILMOTH': 0,
    'WILMOTT': 0,
    'WILMOUTH': 0,
    'WILMS': 0,
    'WILMSEN': 0,
    'WILMSMEYER': 0,
    'WILNER': 0,
    'WILPER': 0,
    'WILRIDGE': 0,
    'WILROY': 0,
    'WILS': 0,
    'WILSEY': 0,
    'WILSFORD': 0,
    'WILSHER': 0,
    'WILSHIRE': 0,
    'WILSHUSEN': 0,
    'WILSIE': 0,
    'WILSKE': 0,
    'WILSMAN': 0,
    'WILSOM': 0,
    'WILSON': 0.08797561818581709,
    'WILSTEAD': 0,
    'WILSTERMAN': 0,
    'WILSTON': 0,
    'WILT': 0,
    'WILTBANK': 0,
    'WILTBERGER': 0,
    'WILTCHER': 0,
    'WILTERDINK': 0,
    'WILTERMOOD': 0,
    'WILTFANG': 0,
    'WILTFONG': 0,
    'WILTGEN': 0,
    'WILTJER': 0,
    'WILTON': 0.8426966292134832,
    'WILTROUT': 0,
    'WILTS': 0,
    'WILTSE': 0,
    'WILTSEY': 0,
    'WILTSHIRE': 0,
    'WILTSIE': 0,
    'WILTZ': 0,
    'WILTZIUS': 0,
    'WILUSZ': 0,
    'WILVER': 0,
    'WILWERDING': 0,
    'WILWERT': 0,
    'WILY': 0,
    'WILZ': 0,
    'WILZBACH': 0,
    'WIMAN': 0,
    'WIMBER': 0,
    'WIMBERG': 0,
    'WIMBERLEY': 0,
    'WIMBERLY': 0,
    'WIMBISH': 0,
    'WIMBLE': 0,
    'WIMBLEY': 0,
    'WIMBROW': 0,
    'WIMBS': 0,
    'WIMBUSH': 0,
    'WIMBY': 0,
    'WIMER': 0,
    'WIMES': 0,
    'WIMETT': 0,
    'WIMLEY': 0,
    'WIMMER': 0,
    'WIMMERS': 0,
    'WIMMS': 0,
    'WIMP': 0,
    'WIMPEE': 0,
    'WIMPEY': 0,
    'WIMPFHEIMER': 0,
    'WIMPLE': 0,
    'WIMPY': 0,
    'WIMS': 0,
    'WIMSATT': 0,
    'WIMSETT': 0,
    'WIN': 0,
    'WINAND': 0,
    'WINANDY': 0,
    'WINANS': 0,
    'WINANT': 0,
    'WINARSKI': 0,
    'WINBERG': 0,
    'WINBERRY': 0,
    'WINBIGLER': 0,
    'WINBLAD': 0,
    'WINBORN': 0,
    'WINBORNE': 0,
    'WINBOURNE': 0,
    'WINBURN': 0,
    'WINBUSH': 0,
    'WINCE': 0,
    'WINCEK': 0,
    'WINCENTSEN': 0,
    'WINCH': 0,
    'WINCHEL': 0,
    'WINCHELL': 0,
    'WINCHENBACH': 0,
    'WINCHESTER': 0,
    'WINCKLER': 0,
    'WINCZEWSKI': 0,
    'WIND': 0,
    'WINDAU': 0,
    'WINDBIGLER': 0,
    'WINDBUSH': 0,
    'WINDECKER': 0,
    'WINDEL': 0,
    'WINDELER': 0,
    'WINDELL': 0,
    'WINDELS': 0,
    'WINDEMULLER': 0,
    'WINDEN': 0,
    'WINDER': 0,
    'WINDERL': 0,
    'WINDERS': 0,
    'WINDES': 0,
    'WINDEY': 0,
    'WINDFELDER': 0,
    'WINDFIELD': 0,
    'WINDHAM': 0,
    'WINDHAUSEN': 0,
    'WINDHOLZ': 0,
    'WINDHORN': 0,
    'WINDHORST': 0,
    'WINDING': 0,
    'WINDISCH': 0,
    'WINDISH': 0,
    'WINDLAND': 0,
    'WINDLE': 0,
    'WINDLER': 0,
    'WINDLESS': 0,
    'WINDLEY': 0,
    'WINDMILLER': 0,
    'WINDMON': 0,
    'WINDNAGLE': 0,
    'WINDOM': 0,
    'WINDON': 0,
    'WINDORSKI': 0,
    'WINDOVER': 0,
    'WINDOW': 0,
    'WINDOWS': 0,
    'WINDROW': 0,
    'WINDSCHITL': 0,
    'WINDSHEIMER': 0,
    'WINDSOR': 0,
    'WINDSPERGER': 0,
    'WINDSTEIN': 0,
    'WINDT': 0,
    'WINDUS': 0,
    'WINDY': 0.99009900990099,
    'WINE': 0,
    'WINEBARGER': 0,
    'WINEBERG': 0,
    'WINEBRENNER': 0,
    'WINECOFF': 0,
    'WINEGAR': 0,
    'WINEGARD': 0,
    'WINEGARDEN': 0,
    'WINEGARDNER': 0,
    'WINEGARNER': 0,
    'WINEGEART': 0,
    'WINEGLASS': 0,
    'WINEHOLT': 0,
    'WINEINGER': 0,
    'WINEK': 0,
    'WINEKE': 0,
    'WINELAND': 0,
    'WINEMAN': 0,
    'WINEMILLER': 0,
    'WINER': 0,
    'WINES': 0,
    'WINESBERRY': 0,
    'WINESBURG': 0,
    'WINESETT': 0,
    'WINESKI': 0,
    'WINETEER': 0,
    'WINEY': 0,
    'WINFIELD': 0,
    'WINFORD': 0.8968609865470852,
    'WINFRED': 1,
    'WINFREE': 0,
    'WINFREY': 0,
    'WING': 0,
    'WINGARD': 0,
    'WINGATE': 0,
    'WINGBERMUEHLE': 0,
    'WINGE': 0,
    'WINGEIER': 0,
    'WINGEN': 0,
    'WINGENBACH': 0,
    'WINGENDER': 0,
    'WINGENROTH': 0,
    'WINGER': 0,
    'WINGERD': 0,
    'WINGERS': 0,
    'WINGERSON': 0,
    'WINGERT': 0,
    'WINGERTER': 0,
    'WINGET': 0,
    'WINGETT': 0,
    'WINGFIELD': 0,
    'WINGHAM': 0,
    'WINGLE': 0,
    'WINGLER': 0,
    'WINGO': 0,
    'WINGREN': 0,
    'WINGROVE': 0,
    'WINGS': 0,
    'WINHAM': 0,
    'WINHEIM': 0,
    'WINIARCZYK': 0,
    'WINIARSKI': 0,
    'WINIARZ': 0,
    'WINICK': 0,
    'WINICKI': 0,
    'WINIECKI': 0,
    'WINIFRED': 1,
    'WINIGER': 0,
    'WINIK': 0,
    'WINIKOFF': 0,
    'WININGER': 0,
    'WININGHAM': 0,
    'WININGS': 0,
    'WINJE': 0,
    'WINJUM': 0,
    'WINK': 0,
    'WINKE': 0,
    'WINKEL': 0,
    'WINKELBAUER': 0,
    'WINKELER': 0,
    'WINKELJOHN': 0,
    'WINKELMAN': 0,
    'WINKELMANN': 0,
    'WINKELS': 0,
    'WINKELSPECHT': 0,
    'WINKENWERDER': 0,
    'WINKER': 0,
    'WINKERS': 0,
    'WINKEY': 0,
    'WINKFIELD': 0,
    'WINKHART': 0,
    'WINKIE': 0,
    'WINKING': 0,
    'WINKLE': 0,
    'WINKLEBLACK': 0,
    'WINKLEMAN': 0,
    'WINKLEPLECK': 0,
    'WINKLER': 0,
    'WINKLES': 0,
    'WINKLEY': 0,
    'WINKOWITSCH': 0,
    'WINKOWSKI': 0,
    'WINKS': 0,
    'WINKWORTH': 0,
    'WINLAND': 0,
    'WINLEY': 0,
    'WINLOCK': 0,
    'WINMILL': 0,
    'WINN': 0,
    'WINNARD': 0,
    'WINNE': 0,
    'WINNELL': 0,
    'WINNEN': 0,
    'WINNER': 0,
    'WINNERS': 0,
    'WINNETT': 0,
    'WINNEY': 0,
    'WINNICK': 0,
    'WINNICKI': 0,
    'WINNIE': 0.966183574879227,
    'WINNIFORD': 0,
    'WINNIFRED': 1,
    'WINNING': 0,
    'WINNINGER': 0,
    'WINNINGHAM': 0,
    'WINNINGS': 0,
    'WINNS': 0,
    'WINOGRAD': 0,
    'WINOKUR': 0,
    'WINONA': 1,
    'WINOVICH': 0,
    'WINOWIECKI': 0,
    'WINPIGLER': 0,
    'WINQUEST': 0,
    'WINQUIST': 0,
    'WINRICH': 0,
    'WINRIGHT': 0,
    'WINROW': 0,
    'WINSAUER': 0,
    'WINSBERG': 0,
    'WINSCHEL': 0,
    'WINSCHER': 0,
    'WINSCOTT': 0,
    'WINSELL': 0,
    'WINSER': 0,
    'WINSETT': 0,
    'WINSHIP': 0,
    'WINSKI': 0,
    'WINSKY': 0,
    'WINSLETT': 0,
    'WINSLEY': 0,
    'WINSLOW': 0,
    'WINSON': 0,
    'WINSOR': 0,
    'WINSPEAR': 0,
    'WINSPER': 0,
    'WINSTANLEY': 0,
    'WINSTEAD': 0,
    'WINSTED': 0,
    'WINSTEL': 0,
    'WINSTEN': 0,
    'WINSTON': 0.7140172867343103,
    'WINSTONE': 0,
    'WINT': 0,
    'WINTCH': 0,
    'WINTER': 0.08071025020177564,
    'WINTERBAUER': 0,
    'WINTERBERG': 0,
    'WINTERBERGER': 0,
    'WINTERBOTHAM': 0,
    'WINTERBOTTOM': 0,
    'WINTERBURN': 0,
    'WINTERER': 0,
    'WINTERFELD': 0,
    'WINTERFELDT': 0,
    'WINTERFIELD': 0,
    'WINTERHALDER': 0,
    'WINTERHALTER': 0,
    'WINTERHOLLER': 0,
    'WINTERKORN': 0,
    'WINTERLAND': 0,
    'WINTERLE': 0,
    'WINTERLING': 0,
    'WINTERMAN': 0,
    'WINTERMANTEL': 0,
    'WINTERMEYER': 0,
    'WINTERMOTE': 0,
    'WINTERMUTE': 0,
    'WINTERMYER': 0,
    'WINTERNHEIMER': 0,
    'WINTEROWD': 0,
    'WINTERRINGER': 0,
    'WINTERROTH': 0,
    'WINTERROWD': 0,
    'WINTERS': 0,
    'WINTERSCHEIDT': 0,
    'WINTERSON': 0,
    'WINTERSTEEN': 0,
    'WINTERSTEIN': 0,
    'WINTERTON': 0,
    'WINTHEISER': 0,
    'WINTHER': 0,
    'WINTHERS': 0,
    'WINTHROP': 0,
    'WINTJEN': 0,
    'WINTLE': 0,
    'WINTNER': 0,
    'WINTON': 0,
    'WINTRINGHAM': 0,
    'WINTRODE': 0,
    'WINTROW': 0,
    'WINTZ': 0,
    'WINWARD': 0,
    'WINWOOD': 0,
    'WINZ': 0,
    'WINZELER': 0,
    'WINZENBURG': 0,
    'WINZENRIED': 0,
    'WINZER': 0,
    'WION': 0,
    'WIORA': 0,
    'WIPER': 0,
    'WIPF': 0,
    'WIPFLER': 0,
    'WIPFLI': 0,
    'WIPPEL': 0,
    'WIPPER': 0,
    'WIPPERFURTH': 0,
    'WIPPERMAN': 0,
    'WIPPERT': 0,
    'WIPPICH': 0,
    'WIPPLER': 0,
    'WIRCH': 0,
    'WIRE': 0,
    'WIREBAUGH': 0,
    'WIREMAN': 0,
    'WIREN': 0,
    'WIRES': 0,
    'WIREY': 0,
    'WIRFEL': 0,
    'WIRFS': 0,
    'WIRGAU': 0,
    'WIRGES': 0,
    'WIRICK': 0,
    'WIRKKALA': 0,
    'WIRKUS': 0,
    'WIRSCH': 0,
    'WIRSCHING': 0,
    'WIRSIG': 0,
    'WIRSING': 0,
    'WIRT': 0,
    'WIRTA': 0,
    'WIRTALA': 0,
    'WIRTANEN': 0,
    'WIRTEL': 0,
    'WIRTES': 0,
    'WIRTH': 0,
    'WIRTHLIN': 0,
    'WIRTHMAN': 0,
    'WIRTHS': 0,
    'WIRTJES': 0,
    'WIRTS': 0,
    'WIRTZ': 0,
    'WIRZ': 0,
    'WISBEY': 0,
    'WISBY': 0,
    'WISCAVER': 0,
    'WISCH': 0,
    'WISCHER': 0,
    'WISCHHUSEN': 0,
    'WISCHMANN': 0,
    'WISCHMEIER': 0,
    'WISCHMEYER': 0,
    'WISCHNEWSKY': 0,
    'WISCOMB': 0,
    'WISCOMBE': 0,
    'WISCOVITCH': 0,
    'WISDA': 0,
    'WISDOM': 0,
    'WISE': 0,
    'WISECARVER': 0,
    'WISECUP': 0,
    'WISEGARVER': 0,
    'WISEHART': 0,
    'WISEHEART': 0,
    'WISEL': 0,
    'WISELEY': 0,
    'WISELL': 0,
    'WISELY': 0,
    'WISEMAN': 0,
    'WISEN': 0,
    'WISENBAKER': 0,
    'WISENBAUGH': 0,
    'WISENER': 0,
    'WISER': 0,
    'WISH': 0,
    'WISHAM': 0,
    'WISHARD': 0,
    'WISHART': 0,
    'WISHER': 0,
    'WISHERT': 0,
    'WISHMAN': 0,
    'WISHNER': 0,
    'WISHNOW': 0,
    'WISHON': 0,
    'WISIAN': 0,
    'WISINGER': 0,
    'WISINSKI': 0,
    'WISK': 0,
    'WISKER': 0,
    'WISKERCHEN': 0,
    'WISKIRCHEN': 0,
    'WISKOW': 0,
    'WISKUR': 0,
    'WISKUS': 0,
    'WISLER': 0,
    'WISLEY': 0,
    'WISLOCKI': 0,
    'WISMAN': 0,
    'WISMANN': 0,
    'WISMAR': 0,
    'WISMER': 0,
    'WISNASKY': 0,
    'WISNER': 0,
    'WISNESKI': 0,
    'WISNEWSKI': 0,
    'WISNIESKI': 0,
    'WISNIEWSKA': 0,
    'WISNIEWSKI': 0,
    'WISNIOWSKI': 0,
    'WISNISKI': 0,
    'WISNOSKI': 0,
    'WISNOSKY': 0,
    'WISNOWSKI': 0,
    'WISOCKI': 0,
    'WISON': 0,
    'WISOR': 0,
    'WISOTSKY': 0,
    'WISOTZKEY': 0,
    'WISOWATY': 0,
    'WISS': 0,
    'WISSA': 0,
    'WISSE': 0,
    'WISSEL': 0,
    'WISSELL': 0,
    'WISSEMAN': 0,
    'WISSEN': 0,
    'WISSENBACH': 0,
    'WISSER': 0,
    'WISSERT': 0,
    'WISSING': 0,
    'WISSINGER': 0,
    'WISSINK': 0,
    'WISSLER': 0,
    'WISSMAN': 0,
    'WISSMANN': 0,
    'WISSMILLER': 0,
    'WISSNER': 0,
    'WIST': 0,
    'WISTE': 0,
    'WISTED': 0,
    'WISTER': 0,
    'WISTHOFF': 0,
    'WISTI': 0,
    'WISTNER': 0,
    'WISTRAND': 0,
    'WISTROM': 0,
    'WISURI': 0,
    'WISWALL': 0,
    'WISWELL': 0,
    'WISZ': 0,
    'WISZOWATY': 0,
    'WIT': 0,
    'WITAKER': 0,
    'WITALIS': 0,
    'WITAS': 0,
    'WITASZEK': 0,
    'WITBECK': 0,
    'WITCHARD': 0,
    'WITCHELL': 0,
    'WITCHER': 0,
    'WITCHEY': 0,
    'WITCRAFT': 0,
    'WITCZAK': 0,
    'WITEK': 0,
    'WITH': 0,
    'WITHALL': 0,
    'WITHAM': 0,
    'WITHEE': 0,
    'WITHEM': 0,
    'WITHER': 0,
    'WITHERBEE': 0,
    'WITHERBY': 0,
    'WITHERELL': 0,
    'WITHERINGTON': 0,
    'WITHERITE': 0,
    'WITHEROW': 0,
    'WITHERS': 0,
    'WITHERSPOON': 0,
    'WITHERUP': 0,
    'WITHERWAX': 0,
    'WITHEY': 0,
    'WITHINGTON': 0,
    'WITHNELL': 0,
    'WITHROW': 0,
    'WITHYCOMBE': 0,
    'WITKE': 0,
    'WITKIEWICZ': 0,
    'WITKIN': 0,
    'WITKO': 0,
    'WITKOP': 0,
    'WITKOSKI': 0,
    'WITKOWSKI': 0,
    'WITKOWSKY': 0,
    'WITKUS': 0,
    'WITMAN': 0,
    'WITMER': 0,
    'WITMEYER': 0,
    'WITMORE': 0,
    'WITMYER': 0,
    'WITNER': 0,
    'WITNEY': 0,
    'WITOWSKI': 0,
    'WITRAGO': 0,
    'WITRY': 0,
    'WITSAMAN': 0,
    'WITSCHEN': 0,
    'WITSCHI': 0,
    'WITSELL': 0,
    'WITSKEN': 0,
    'WITSMAN': 0,
    'WITSON': 0,
    'WITT': 0,
    'WITTA': 0,
    'WITTBRODT': 0,
    'WITTCHOW': 0,
    'WITTE': 0,
    'WITTEBORT': 0,
    'WITTEK': 0,
    'WITTEKIND': 0,
    'WITTEL': 0,
    'WITTELS': 0,
    'WITTEMAN': 0,
    'WITTEMANN': 0,
    'WITTEN': 0,
    'WITTENAUER': 0,
    'WITTENBACH': 0,
    'WITTENBERG': 0,
    'WITTENBERGER': 0,
    'WITTENBORN': 0,
    'WITTENBRINK': 0,
    'WITTENBROOK': 0,
    'WITTENBURG': 0,
    'WITTENHAGEN': 0,
    'WITTENMYER': 0,
    'WITTENSTEIN': 0,
    'WITTER': 0,
    'WITTERN': 0,
    'WITTERS': 0,
    'WITTES': 0,
    'WITTEVEEN': 0,
    'WITTHAR': 0,
    'WITTHAUER': 0,
    'WITTHAUS': 0,
    'WITTHOEFT': 0,
    'WITTHOFT': 0,
    'WITTHUHN': 0,
    'WITTICH': 0,
    'WITTICK': 0,
    'WITTIE': 0,
    'WITTIG': 0,
    'WITTINE': 0,
    'WITTING': 0,
    'WITTKAMP': 0,
    'WITTKE': 0,
    'WITTKOP': 0,
    'WITTKOPF': 0,
    'WITTKOPP': 0,
    'WITTKOWSKI': 0,
    'WITTLE': 0,
    'WITTLER': 0,
    'WITTLIEF': 0,
    'WITTLIFF': 0,
    'WITTLIN': 0,
    'WITTLINGER': 0,
    'WITTMAN': 0,
    'WITTMANN': 0,
    'WITTMAYER': 0,
    'WITTMEIER': 0,
    'WITTMER': 0,
    'WITTMEYER': 0,
    'WITTMIER': 0,
    'WITTMUS': 0,
    'WITTNEBEL': 0,
    'WITTNEBEN': 0,
    'WITTNER': 0,
    'WITTREICH': 0,
    'WITTRIG': 0,
    'WITTROCK': 0,
    'WITTRUP': 0,
    'WITTRY': 0,
    'WITTS': 0,
    'WITTSTOCK': 0,
    'WITTSTRUCK': 0,
    'WITTUM': 0,
    'WITTWER': 0,
    'WITTY': 0,
    'WITUCKI': 0,
    'WITULSKI': 0,
    'WITVOET': 0,
    'WITWER': 0,
    'WITWICKI': 0,
    'WITZ': 0,
    'WITZEL': 0,
    'WITZENBURG': 0,
    'WITZGALL': 0,
    'WITZIG': 0,
    'WITZIGMAN': 0,
    'WITZKE': 0,
    'WITZMAN': 0,
    'WIUFF': 0,
    'WIVELL': 0,
    'WIX': 0,
    'WIXOM': 0,
    'WIXON': 0,
    'WIXSON': 0,
    'WIXTED': 0,
    'WIYGUL': 0,
    'WIZA': 0,
    'WIZE': 0,
    'WIZNER': 0,
    'WLADYKA': 0,
    'WLAKER': 0,
    'WLASCHIN': 0,
    'WLASIUK': 0,
    'WLAZLO': 0,
    'WLECZYK': 0,
    'WLEKLINSKI': 0,
    'WLOCH': 0,
    'WLODARCZYK': 0,
    'WLODARSKI': 0,
    'WLODEK': 0,
    'WLODKOWSKI': 0,
    'WLODYKA': 0,
    'WM': 1,
    'WNEK': 0,
    'WNOROWSKI': 0,
    'WNUK': 0,
    'WNUKOWSKI': 0,
    'WO': 0,
    'WOBBE': 0,
    'WOBBEMA': 0,
    'WOBIG': 0,
    'WOBSCHALL': 0,
    'WOBSER': 0,
    'WOCHNER': 0,
    'WOCHNICK': 0,
    'WOCK': 0,
    'WOCKENFUSS': 0,
    'WODA': 0,
    'WODARCZYK': 0,
    'WODARSKI': 0,
    'WODECKI': 0,
    'WODICKA': 0,
    'WODKA': 0,
    'WODKE': 0,
    'WODRICH': 0,
    'WODTKE': 0,
    'WODZINSKI': 0,
    'WODZISZ': 0,
    'WOEBER': 0,
    'WOEBKENBERG': 0,
    'WOECKENER': 0,
    'WOEHL': 0,
    'WOEHLER': 0,
    'WOEHLKE': 0,
    'WOEHR': 0,
    'WOEHRLE': 0,
    'WOELBER': 0,
    'WOELFEL': 0,
    'WOELFFER': 0,
    'WOELFLE': 0,
    'WOELK': 0,
    'WOELKE': 0,
    'WOELKERS': 0,
    'WOELLER': 0,
    'WOELLERT': 0,
    'WOELLNER': 0,
    'WOEMPNER': 0,
    'WOEPPEL': 0,
    'WOERMAN': 0,
    'WOERNER': 0,
    'WOERPEL': 0,
    'WOERTH': 0,
    'WOERTZ': 0,
    'WOERZ': 0,
    'WOESSNER': 0,
    'WOEST': 0,
    'WOESTE': 0,
    'WOESTMAN': 0,
    'WOFFARD': 0,
    'WOFFINDEN': 0,
    'WOFFORD': 0,
    'WOGAN': 0,
    'WOGEN': 0,
    'WOGGON': 0,
    'WOGOMAN': 0,
    'WOGOMON': 0,
    'WOGSLAND': 0,
    'WOHL': 0,
    'WOHLBERG': 0,
    'WOHLEBER': 0,
    'WOHLENHAUS': 0,
    'WOHLER': 0,
    'WOHLERS': 0,
    'WOHLERT': 0,
    'WOHLETZ': 0,
    'WOHLEVER': 0,
    'WOHLFAHRT': 0,
    'WOHLFARTH': 0,
    'WOHLFEIL': 0,
    'WOHLFERT': 0,
    'WOHLFORD': 0,
    'WOHLGAMUTH': 0,
    'WOHLGEMUTH': 0,
    'WOHLHUETER': 0,
    'WOHLLEBEN': 0,
    'WOHLLEBER': 0,
    'WOHLMAN': 0,
    'WOHLMUTH': 0,
    'WOHLRAB': 0,
    'WOHLRABE': 0,
    'WOHLSCHEID': 0,
    'WOHLSCHLAEGER': 0,
    'WOHLSCHLEGEL': 0,
    'WOHLT': 0,
    'WOHLTMAN': 0,
    'WOHLWEND': 0,
    'WOHN': 0,
    'WOHNER': 0,
    'WOHNOUTKA': 0,
    'WOHRLE': 0,
    'WOIDA': 0,
    'WOIKE': 0,
    'WOINAROWICZ': 0,
    'WOITA': 0,
    'WOITALLA': 0,
    'WOITAS': 0,
    'WOITH': 0,
    'WOJACK': 0,
    'WOJAHN': 0,
    'WOJAK': 0,
    'WOJAN': 0,
    'WOJCIAK': 0,
    'WOJCICKI': 0,
    'WOJCIECHOWICZ': 0,
    'WOJCIECHOWSKI': 0,
    'WOJCIEHOWSKI': 0,
    'WOJCIESZAK': 0,
    'WOJCIK': 0,
    'WOJCINSKI': 0,
    'WOJDA': 0,
    'WOJDYLA': 0,
    'WOJEWODA': 0,
    'WOJICK': 0,
    'WOJNAR': 0,
    'WOJNAROWICZ': 0,
    'WOJNAROWSKI': 0,
    'WOJNICKI': 0,
    'WOJNO': 0,
    'WOJNOWSKI': 0,
    'WOJT': 0,
    'WOJTACH': 0,
    'WOJTAK': 0,
    'WOJTAL': 0,
    'WOJTALA': 0,
    'WOJTALEWICZ': 0,
    'WOJTANOWSKI': 0,
    'WOJTAS': 0,
    'WOJTASIK': 0,
    'WOJTASZEK': 0,
    'WOJTCZAK': 0,
    'WOJTECKI': 0,
    'WOJTKIEWICZ': 0,
    'WOJTKOWIAK': 0,
    'WOJTKOWSKI': 0,
    'WOJTON': 0,
    'WOJTOWICZ': 0,
    'WOJTUSIK': 0,
    'WOJTYNA': 0,
    'WOJTYSIAK': 0,
    'WOKER': 0,
    'WOLAK': 0,
    'WOLAN': 0,
    'WOLANIN': 0,
    'WOLANSKI': 0,
    'WOLANSKY': 0,
    'WOLAVER': 0,
    'WOLBACH': 0,
    'WOLBECK': 0,
    'WOLBER': 0,
    'WOLBERG': 0,
    'WOLBERS': 0,
    'WOLBERT': 0,
    'WOLBRINK': 0,
    'WOLCOTT': 0,
    'WOLD': 0,
    'WOLDE': 0,
    'WOLDEMARIAM': 0,
    'WOLDEMICHAEL': 0,
    'WOLDEN': 0,
    'WOLDER': 0,
    'WOLDMAN': 0,
    'WOLDRIDGE': 0,
    'WOLDT': 0,
    'WOLDU': 0,
    'WOLEBEN': 0,
    'WOLEK': 0,
    'WOLENSKI': 0,
    'WOLENSKY': 0,
    'WOLERY': 0,
    'WOLESLAGLE': 0,
    'WOLEVER': 0,
    'WOLF': 0,
    'WOLFANGER': 0,
    'WOLFARD': 0,
    'WOLFARTH': 0,
    'WOLFBERG': 0,
    'WOLFCALE': 0,
    'WOLFE': 0,
    'WOLFEL': 0,
    'WOLFENBARGER': 0,
    'WOLFENBERGER': 0,
    'WOLFENDALE': 0,
    'WOLFENDEN': 0,
    'WOLFER': 0,
    'WOLFERMAN': 0,
    'WOLFERSBERGER': 0,
    'WOLFERT': 0,
    'WOLFF': 0,
    'WOLFFE': 0,
    'WOLFFIS': 0,
    'WOLFFORD': 0,
    'WOLFGANG': 0,
    'WOLFGRAM': 0,
    'WOLFGRAMM': 0,
    'WOLFHOPE': 0,
    'WOLFINBARGER': 0,
    'WOLFINGER': 0,
    'WOLFINGTON': 0,
    'WOLFKIEL': 0,
    'WOLFKILL': 0,
    'WOLFLA': 0,
    'WOLFLE': 0,
    'WOLFLEY': 0,
    'WOLFMAN': 0,
    'WOLFMEYER': 0,
    'WOLFOLK': 0,
    'WOLFORD': 0,
    'WOLFRAM': 0,
    'WOLFREY': 0,
    'WOLFROM': 0,
    'WOLFRUM': 0,
    'WOLFS': 0,
    'WOLFSBERGER': 0,
    'WOLFSEN': 0,
    'WOLFSKILL': 0,
    'WOLFSOHN': 0,
    'WOLFSON': 0,
    'WOLFSWINKEL': 0,
    'WOLGAMOT': 0,
    'WOLGAMOTT': 0,
    'WOLGAST': 0,
    'WOLGEMUTH': 0,
    'WOLHART': 0,
    'WOLICKI': 0,
    'WOLIN': 0,
    'WOLINSKI': 0,
    'WOLINSKY': 0,
    'WOLIVER': 0,
    'WOLK': 0,
    'WOLKE': 0,
    'WOLKEN': 0,
    'WOLKENHAUER': 0,
    'WOLKIEWICZ': 0,
    'WOLKIN': 0,
    'WOLKING': 0,
    'WOLKINS': 0,
    'WOLKOFF': 0,
    'WOLKOW': 0,
    'WOLKOWICZ': 0,
    'WOLKOWITZ': 0,
    'WOLL': 0,
    'WOLLACK': 0,
    'WOLLAK': 0,
    'WOLLAM': 0,
    'WOLLAN': 0,
    'WOLLARD': 0,
    'WOLLASTON': 0,
    'WOLLE': 0,
    'WOLLEN': 0,
    'WOLLENBERG': 0,
    'WOLLENBURG': 0,
    'WOLLENHAUPT': 0,
    'WOLLENWEBER': 0,
    'WOLLENZIEN': 0,
    'WOLLER': 0,
    'WOLLERMAN': 0,
    'WOLLERSHEIM': 0,
    'WOLLERT': 0,
    'WOLLESEN': 0,
    'WOLLET': 0,
    'WOLLETT': 0,
    'WOLLEY': 0,
    'WOLLIN': 0,
    'WOLLITZ': 0,
    'WOLLMAN': 0,
    'WOLLMANN': 0,
    'WOLLMER': 0,
    'WOLLMUTH': 0,
    'WOLLNER': 0,
    'WOLLNEY': 0,
    'WOLLSCHLAGER': 0,
    'WOLLUM': 0,
    'WOLMAN': 0,
    'WOLNER': 0,
    'WOLNEY': 0,
    'WOLNIAK': 0,
    'WOLNIEWICZ': 0,
    'WOLNIK': 0,
    'WOLNY': 0,
    'WOLOHAN': 0,
    'WOLOS': 0,
    'WOLOSEK': 0,
    'WOLOSHIN': 0,
    'WOLOSHYN': 0,
    'WOLOSZ': 0,
    'WOLOSZYK': 0,
    'WOLOSZYN': 0,
    'WOLOWICZ': 0,
    'WOLOWIEC': 0,
    'WOLOWITZ': 0,
    'WOLOWSKI': 0,
    'WOLPE': 0,
    'WOLPER': 0,
    'WOLPERT': 0,
    'WOLPIN': 0,
    'WOLSCHLAGER': 0,
    'WOLSCHLEGER': 0,
    'WOLSEY': 0,
    'WOLSKE': 0,
    'WOLSKI': 0,
    'WOLSKY': 0,
    'WOLSON': 0,
    'WOLSTENCROFT': 0,
    'WOLSTENHOLME': 0,
    'WOLT': 0,
    'WOLTEMATH': 0,
    'WOLTER': 0,
    'WOLTERING': 0,
    'WOLTERMAN': 0,
    'WOLTERS': 0,
    'WOLTERSDORF': 0,
    'WOLTERSTORFF': 0,
    'WOLTHUIS': 0,
    'WOLTJEN': 0,
    'WOLTJER': 0,
    'WOLTKAMP': 0,
    'WOLTMAN': 0,
    'WOLTMANN': 0,
    'WOLTZ': 0,
    'WOLVEN': 0,
    'WOLVER': 0,
    'WOLVERTON': 0,
    'WOLVIN': 0,
    'WOLYNIEC': 0,
    'WOLZ': 0,
    'WOMAC': 0,
    'WOMACK': 0,
    'WOMACKS': 0,
    'WOMBACHER': 0,
    'WOMBLE': 0,
    'WOMBLES': 0,
    'WOMBOLD': 0,
    'WOMBOLT': 0,
    'WOMBWELL': 0,
    'WOMELDORF': 0,
    'WOMELDORFF': 0,
    'WOMELSDORF': 0,
    'WOMER': 0,
    'WOMICK': 0,
    'WOMMACK': 0,
    'WOMMER': 0,
    'WON': 0,
    'WONACOTT': 0,
    'WONCH': 0,
    'WONDA': 1,
    'WONDER': 0,
    'WONDERCHECK': 0,
    'WONDERGEM': 0,
    'WONDERLICH': 0,
    'WONDERLIN': 0,
    'WONDERLING': 0,
    'WONDERLY': 0,
    'WONDERS': 0,
    'WONDOLOSKI': 0,
    'WONDOLOWSKI': 0,
    'WONDRA': 0,
    'WONDRASH': 0,
    'WONG': 0,
    'WONGUS': 0,
    'WONN': 0,
    'WONNACOTT': 0,
    'WONNELL': 0,
    'WONNER': 0,
    'WONS': 0,
    'WONSER': 0,
    'WONSEY': 0,
    'WONSLEY': 0,
    'WONSON': 0,
    'WONSOWICZ': 0,
    'WONTOR': 0,
    'WOO': 0,
    'WOOCK': 0,
    'WOOD': 0,
    'WOODAL': 0,
    'WOODALL': 0,
    'WOODARD': 0,
    'WOODARDS': 0,
    'WOODBECK': 0,
    'WOODBERRY': 0,
    'WOODBERY': 0,
    'WOODBINE': 0,
    'WOODBREY': 0,
    'WOODBRIDGE': 0,
    'WOODBURN': 0,
    'WOODBURY': 0,
    'WOODBY': 0,
    'WOODCOCK': 0,
    'WOODCOOK': 0,
    'WOODCOX': 0,
    'WOODDELL': 0,
    'WOODDY': 0,
    'WOODE': 0,
    'WOODEL': 0,
    'WOODELL': 0,
    'WOODEN': 0,
    'WOODEND': 0,
    'WOODERSON': 0,
    'WOODFALL': 0,
    'WOODFIELD': 0,
    'WOODFILL': 0,
    'WOODFIN': 0,
    'WOODFOLK': 0,
    'WOODFORD': 0,
    'WOODFORK': 0,
    'WOODGATE': 0,
    'WOODGEARD': 0,
    'WOODGETT': 0,
    'WOODHALL': 0,
    'WOODHAM': 0,
    'WOODHAMS': 0,
    'WOODHEAD': 0,
    'WOODHOUSE': 0,
    'WOODHULL': 0,
    'WOODHURST': 0,
    'WOODIE': 0,
    'WOODIEL': 0,
    'WOODILL': 0,
    'WOODIN': 0,
    'WOODING': 0,
    'WOODINGS': 0,
    'WOODINGTON': 0,
    'WOODIS': 0,
    'WOODIWISS': 0,
    'WOODKE': 0,
    'WOODLAND': 0,
    'WOODLE': 0,
    'WOODLEE': 0,
    'WOODLEY': 0,
    'WOODLIEF': 0,
    'WOODLIFF': 0,
    'WOODLIN': 0,
    'WOODLING': 0,
    'WOODLOCK': 0,
    'WOODLY': 0,
    'WOODMAN': 0,
    'WOODMANCY': 0,
    'WOODMANSEE': 0,
    'WOODMORE': 0,
    'WOODRAL': 0,
    'WOODRELL': 0,
    'WOODRICH': 0,
    'WOODRICK': 0,
    'WOODRIDGE': 0,
    'WOODRING': 0,
    'WOODROFFE': 0,
    'WOODROME': 0,
    'WOODROOF': 0,
    'WOODROW': 0.9619084263178145,
    'WOODRUFF': 0,
    'WOODRUM': 0,
    'WOODS': 0,
    'WOODSIDE': 0,
    'WOODSMALL': 0,
    'WOODSON': 0,
    'WOODSTOCK': 0,
    'WOODSUM': 0,
    'WOODUL': 0,
    'WOODWARD': 0,
    'WOODWELL': 0,
    'WOODWICK': 0,
    'WOODWORTH': 0,
    'WOODWYK': 0,
    'WOODY': 0,
    'WOODYARD': 0,
    'WOODYATT': 0,
    'WOODZELL': 0,
    'WOOFTER': 0,
    'WOOG': 0,
    'WOOKEY': 0,
    'WOOL': 0,
    'WOOLAM': 0,
    'WOOLARD': 0,
    'WOOLBERT': 0,
    'WOOLBRIGHT': 0,
    'WOOLCOCK': 0,
    'WOOLCOTT': 0,
    'WOOLDRIDGE': 0,
    'WOOLEDGE': 0,
    'WOOLEMS': 0,
    'WOOLEN': 0,
    'WOOLER': 0,
    'WOOLERY': 0,
    'WOOLETT': 0,
    'WOOLEVER': 0,
    'WOOLEY': 0,
    'WOOLF': 0,
    'WOOLFE': 0,
    'WOOLFENDEN': 0,
    'WOOLFOLK': 0,
    'WOOLFORD': 0,
    'WOOLFORK': 0,
    'WOOLFREY': 0,
    'WOOLFSON': 0,
    'WOOLHEATER': 0,
    'WOOLHISER': 0,
    'WOOLHOUSE': 0,
    'WOOLINGTON': 0,
    'WOOLIVER': 0,
    'WOOLLARD': 0,
    'WOOLLEN': 0,
    'WOOLLETT': 0,
    'WOOLLEY': 0,
    'WOOLLUMS': 0,
    'WOOLMAN': 0,
    'WOOLNER': 0,
    'WOOLPERT': 0,
    'WOOLRICH': 0,
    'WOOLRIDGE': 0,
    'WOOLS': 0,
    'WOOLSEY': 0,
    'WOOLSLAYER': 0,
    'WOOLSON': 0,
    'WOOLSTENHULME': 0,
    'WOOLSTON': 0,
    'WOOLUM': 0,
    'WOOLUMS': 0,
    'WOOLVERTON': 0,
    'WOOLWINE': 0,
    'WOOLWORTH': 0,
    'WOOMER': 0,
    'WOON': 0,
    'WOOP': 0,
    'WOOSLEY': 0,
    'WOOSTER': 0,
    'WOOTAN': 0,
    'WOOTEN': 0,
    'WOOTERS': 0,
    'WOOTON': 0,
    'WOOTSON': 0,
    'WOOTTEN': 0,
    'WOOTTON': 0,
    'WOPAT': 0,
    'WOPPERER': 0,
    'WORACHEK': 0,
    'WORBINGTON': 0,
    'WORBOYS': 0,
    'WORBY': 0,
    'WORCESTER': 0,
    'WORCH': 0,
    'WORD': 0,
    'WORDEKEMPER': 0,
    'WORDELL': 0,
    'WORDELMAN': 0,
    'WORDEN': 0,
    'WORDLAW': 0,
    'WORDLOW': 0,
    'WORDS': 0,
    'WORDSWORTH': 0,
    'WOREK': 0,
    'WOREL': 0,
    'WORFORD': 0,
    'WORGAN': 0,
    'WORGULL': 0,
    'WORK': 0,
    'WORKER': 0,
    'WORKING': 0,
    'WORKINGER': 0,
    'WORKLEY': 0,
    'WORKMAN': 0,
    'WORKMON': 0,
    'WORKS': 0,
    'WORKU': 0,
    'WORL': 0,
    'WORLAND': 0,
    'WORLD': 0,
    'WORLDS': 0,
    'WORLES': 0,
    'WORLEY': 0,
    'WORLINE': 0,
    'WORLOCK': 0,
    'WORLOW': 0,
    'WORLTON': 0,
    'WORLUND': 0,
    'WORM': 0,
    'WORMACK': 0,
    'WORMALD': 0,
    'WORMAN': 0,
    'WORMELL': 0,
    'WORMELY': 0,
    'WORMER': 0,
    'WORMINGTON': 0,
    'WORMLEY': 0,
    'WORMS': 0,
    'WORMSER': 0,
    'WORMSLEY': 0,
    'WORMUTH': 0,
    'WORMWOOD': 0,
    'WORN': 0,
    'WORNELL': 0,
    'WORNER': 0,
    'WORNICK': 0,
    'WORNOM': 0,
    'WORNSTAFF': 0,
    'WORNUM': 0,
    'WOROBEC': 0,
    'WOROBEL': 0,
    'WOROBEY': 0,
    'WORONA': 0,
    'WORONIECKI': 0,
    'WORONOWICZ': 0,
    'WOROSZ': 0,
    'WORRALL': 0,
    'WORREL': 0,
    'WORRELL': 0,
    'WORRELLS': 0,
    'WORRICK': 0,
    'WORRILOW': 0,
    'WORRIX': 0,
    'WORSFOLD': 0,
    'WORSHAM': 0,
    'WORSLEY': 0,
    'WORST': 0,
    'WORSTALL': 0,
    'WORSTELL': 0,
    'WORSTER': 0,
    'WORSWICK': 0,
    'WORT': 0,
    'WORTEL': 0,
    'WORTEN': 0,
    'WORTH': 0,
    'WORTHAM': 0,
    'WORTHAN': 0,
    'WORTHEM': 0,
    'WORTHEN': 0,
    'WORTHEY': 0,
    'WORTHING': 0,
    'WORTHINGTON': 0,
    'WORTHLEY': 0,
    'WORTHMAN': 0,
    'WORTHY': 0,
    'WORTINGER': 0,
    'WORTLEY': 0,
    'WORTMAN': 0,
    'WORTMANN': 0,
    'WORTON': 0,
    'WORTS': 0,
    'WORTZ': 0,
    'WORWA': 0,
    'WORZALLA': 0,
    'WORZEL': 0,
    'WORZELLA': 0,
    'WOS': 0,
    'WOSICK': 0,
    'WOSKA': 0,
    'WOSS': 0,
    'WOSTER': 0,
    'WOTEN': 0,
    'WOTHE': 0,
    'WOTHERSPOON': 0,
    'WOTIPKA': 0,
    'WOTRING': 0,
    'WOTRUBA': 0,
    'WOTTON': 0,
    'WOUDENBERG': 0,
    'WOUDSTRA': 0,
    'WOUGHTER': 0,
    'WOULARD': 0,
    'WOULF': 0,
    'WOULFE': 0,
    'WOULLARD': 0,
    'WOUNG': 0,
    'WOURMS': 0,
    'WOUTERS': 0,
    'WOWK': 0,
    'WOXLAND': 0,
    'WOY': 0,
    'WOYAK': 0,
    'WOYCHIK': 0,
    'WOYCIK': 0,
    'WOYTEK': 0,
    'WOYTKO': 0,
    'WOYTOVICH': 0,
    'WOYTOWICH': 0,
    'WOZENCRAFT': 0,
    'WOZNAK': 0,
    'WOZNEY': 0,
    'WOZNIAK': 0,
    'WOZNICA': 0,
    'WOZNICK': 0,
    'WOZNICKI': 0,
    'WOZNICZKA': 0,
    'WOZNY': 0,
    'WRABEL': 0,
    'WRAGE': 0,
    'WRAGG': 0,
    'WRAGGE': 0,
    'WRAGGS': 0,
    'WRAIGHT': 0,
    'WRAITH': 0,
    'WRAPE': 0,
    'WRASE': 0,
    'WRASMAN': 0,
    'WRASPIR': 0,
    'WRASSE': 0,
    'WRATCHFORD': 0,
    'WRATE': 0,
    'WRATH': 0,
    'WRATHALL': 0,
    'WRATHER': 0,
    'WRATTEN': 0,
    'WRAY': 0,
    'WRAZEN': 0,
    'WREATH': 0,
    'WREDE': 0,
    'WREEDE': 0,
    'WREGE': 0,
    'WREN': 0,
    'WRENCH': 0,
    'WRENCHER': 0,
    'WRENN': 0,
    'WRESTLER': 0,
    'WREYFORD': 0,
    'WRICE': 0,
    'WRICH': 0,
    'WRICK': 0,
    'WRIDE': 0,
    'WRIEDEN': 0,
    'WRIEDT': 0,
    'WRIGGLESWORTH': 0,
    'WRIGHT': 0,
    'WRIGHTEN': 0,
    'WRIGHTER': 0,
    'WRIGHTINGTON': 0,
    'WRIGHTMAN': 0,
    'WRIGHTON': 0,
    'WRIGHTSMAN': 0,
    'WRIGHTSON': 0,
    'WRIGHTSTONE': 0,
    'WRIGLESWORTH': 0,
    'WRIGLEY': 0,
    'WRIGT': 0,
    'WRIGTH': 0,
    'WRIN': 0,
    'WRING': 0,
    'WRINKLE': 0,
    'WRINN': 0,
    'WRISLEY': 0,
    'WRISTEN': 0,
    'WRISTON': 0,
    'WRITE': 0,
    'WRITER': 0,
    'WRITESEL': 0,
    'WRITT': 0,
    'WRITZ': 0,
    'WRIXON': 0,
    'WROBBEL': 0,
    'WROBEL': 0,
    'WROBLE': 0,
    'WROBLESKI': 0,
    'WROBLEWSKI': 0,
    'WROCKLAGE': 0,
    'WROE': 0,
    'WROLSON': 0,
    'WROLSTAD': 0,
    'WRONA': 0,
    'WRONKA': 0,
    'WRONKO': 0,
    'WRONOWSKI': 0,
    'WRONSKI': 0,
    'WROTEN': 0,
    'WROTH': 0,
    'WRUBEL': 0,
    'WRUBLE': 0,
    'WRUBLESKI': 0,
    'WRUCK': 0,
    'WRY': 0,
    'WRYE': 0,
    'WRYNN': 0,
    'WRZESIEN': 0,
    'WRZESINSKI': 0,
    'WRZOSEK': 0,
    'WSZOLEK': 0,
    'WU': 0,
    'WUBBEN': 0,
    'WUBBENA': 0,
    'WUBBENHORST': 0,
    'WUBKER': 0,
    'WUCHER': 0,
    'WUCHERER': 0,
    'WUCHTER': 0,
    'WUDEL': 0,
    'WUDTKE': 0,
    'WUEBBELS': 0,
    'WUEBBEN': 0,
    'WUEBKER': 0,
    'WUEHLER': 0,
    'WUELFING': 0,
    'WUELLNER': 0,
    'WUENSCH': 0,
    'WUENSCHE': 0,
    'WUENSCHEL': 0,
    'WUENSTEL': 0,
    'WUERCH': 0,
    'WUERDEMAN': 0,
    'WUERFEL': 0,
    'WUERTH': 0,
    'WUERTZ': 0,
    'WUERZ': 0,
    'WUEST': 0,
    'WUESTEFELD': 0,
    'WUESTENBERG': 0,
    'WUESTEWALD': 0,
    'WUESTHOFF': 0,
    'WUETHRICH': 0,
    'WUJCIK': 0,
    'WUJEK': 0,
    'WUKASCH': 0,
    'WULF': 0,
    'WULFECK': 0,
    'WULFEKUHLE': 0,
    'WULFERS': 0,
    'WULFERT': 0,
    'WULFF': 0,
    'WULFING': 0,
    'WULFORST': 0,
    'WULLENWEBER': 0,
    'WULLER': 0,
    'WULLSCHLEGER': 0,
    'WUN': 0,
    'WUNCH': 0,
    'WUNDER': 0,
    'WUNDERLE': 0,
    'WUNDERLICH': 0,
    'WUNDERLIN': 0,
    'WUNDERLY': 0,
    'WUNDROW': 0,
    'WUNG': 0,
    'WUNN': 0,
    'WUNNER': 0,
    'WUNROW': 0,
    'WUNSCH': 0,
    'WUNSCHEL': 0,
    'WUOLLET': 0,
    'WUORI': 0,
    'WUORINEN': 0,
    'WURDEMAN': 0,
    'WURDINGER': 0,
    'WURGLER': 0,
    'WURIE': 0,
    'WURL': 0,
    'WURM': 0,
    'WURMLINGER': 0,
    'WURR': 0,
    'WURST': 0,
    'WURSTER': 0,
    'WURSTNER': 0,
    'WURTELE': 0,
    'WURTH': 0,
    'WURTS': 0,
    'WURTZ': 0,
    'WURTZBACHER': 0,
    'WURTZEL': 0,
    'WURTZLER': 0,
    'WURZ': 0,
    'WURZBACH': 0,
    'WURZBACHER': 0,
    'WURZBURG': 0,
    'WURZBURGER': 0,
    'WURZEL': 0,
    'WURZELBACHER': 0,
    'WURZER': 0,
    'WUSSLER': 0,
    'WUSSOW': 0,
    'WUSSTIG': 0,
    'WUST': 0,
    'WUSTERBARTH': 0,
    'WUTHRICH': 0,
    'WUTKE': 0,
    'WUTTKE': 0,
    'WUTZ': 0,
    'WUTZKE': 0,
    'WUU': 0,
    'WYAN': 0,
    'WYAND': 0,
    'WYANDT': 0,
    'WYANT': 0,
    'WYATT': 0.2413515687851971,
    'WYATTE': 0,
    'WYBENGA': 0,
    'WYBLE': 0,
    'WYBORNY': 0,
    'WYCH': 0,
    'WYCHE': 0,
    'WYCKOFF': 0,
    'WYCOFF': 0,
    'WYCUFF': 0,
    'WYDA': 0,
    'WYDER': 0,
    'WYDEVEN': 0,
    'WYDICK': 0,
    'WYDNER': 0,
    'WYDRA': 0,
    'WYDRO': 0,
    'WYE': 0,
    'WYER': 0,
    'WYERS': 0,
    'WYETH': 0,
    'WYETT': 0,
    'WYFFELS': 0,
    'WYGAL': 0,
    'WYGANT': 0,
    'WYGLE': 0,
    'WYGONIK': 0,
    'WYKA': 0,
    'WYKE': 0,
    'WYKEL': 0,
    'WYKER': 0,
    'WYKERT': 0,
    'WYKES': 0,
    'WYKLE': 0,
    'WYKOFF': 0,
    'WYKOWSKI': 0,
    'WYKSTRA': 0,
    'WYLAM': 0,
    'WYLAND': 0,
    'WYLD': 0,
    'WYLDE': 0,
    'WYLDER': 0,
    'WYLE': 0,
    'WYLER': 0,
    'WYLES': 0,
    'WYLEY': 0,
    'WYLIE': 0,
    'WYLLIE': 0,
    'WYLLYS': 0,
    'WYLY': 0,
    'WYMA': 0,
    'WYMAN': 0,
    'WYMBS': 0,
    'WYMER': 0,
    'WYMES': 0,
    'WYMORE': 0,
    'WYMS': 0,
    'WYN': 0,
    'WYNALDA': 0,
    'WYNANT': 0,
    'WYND': 0,
    'WYNDER': 0,
    'WYNDHAM': 0,
    'WYNE': 0,
    'WYNECOOP': 0,
    'WYNEGAR': 0,
    'WYNELL': 1,
    'WYNER': 0,
    'WYNES': 0,
    'WYNGAARD': 0,
    'WYNGARDEN': 0,
    'WYNIA': 0,
    'WYNINGS': 0,
    'WYNKOOP': 0,
    'WYNN': 0,
    'WYNNE': 0,
    'WYNNS': 0,
    'WYNONA': 1,
    'WYNOTT': 0,
    'WYNS': 0,
    'WYNSMA': 0,
    'WYNSTRA': 0,
    'WYNTER': 0,
    'WYNVEEN': 0,
    'WYPASEK': 0,
    'WYPER': 0,
    'WYPYCH': 0,
    'WYRE': 0,
    'WYREMBELSKI': 0,
    'WYRES': 0,
    'WYRICK': 0,
    'WYROBEK': 0,
    'WYROSDICK': 0,
    'WYROSTEK': 0,
    'WYRSCH': 0,
    'WYRWAS': 0,
    'WYRZYKOWSKI': 0,
    'WYSE': 0,
    'WYSINGER': 0,
    'WYSK': 0,
    'WYSKIEL': 0,
    'WYSOCK': 0,
    'WYSOCKI': 0,
    'WYSOCKY': 0,
    'WYSONG': 0,
    'WYSOR': 0,
    'WYSS': 0,
    'WYSZKOWSKI': 0,
    'WYSZYNSKI': 0,
    'WYTASKE': 0,
    'WYTCHERLEY': 0,
    'WYTHE': 0,
    'WYTTENBACH': 0,
    'WYVILL': 0,
    'WYZARD': 0,
    'WYZYKOWSKI': 0,
    'WZOREK': 0,
    'XA': 0,
    'XANDER': 0,
    'XANDERS': 0,
    'XANTHOPOULOS': 0,
    'XANTHOS': 0,
    'XAVIER': 0.939306358381503,
    'XAYACHACK': 0,
    'XAYARATH': 0,
    'XAYASANE': 0,
    'XAYAVONG': 0,
    'XAYSANA': 0,
    'XENAKIS': 0,
    'XENIA': 1,
    'XENOS': 0,
    'XI': 0,
    'XIA': 0,
    'XIAN': 0,
    'XIANG': 0,
    'XIAO': 0.4926108374384237,
    'XIE': 0,
    'XIMENEZ': 0,
    'XIN': 0,
    'XING': 0,
    'XIOMARA': 1,
    'XIONG': 0,
    'XIQUE': 0,
    'XIQUES': 0,
    'XOCHITL': 1,
    'XU': 0,
    'XUAN': 0.9345794392523364,
    'XUE': 0,
    'XUEREB': 0,
    'YA': 0,
    'YABES': 0,
    'YABLON': 0,
    'YABLONSKI': 0,
    'YABLONSKY': 0,
    'YABUT': 0,
    'YAC': 0,
    'YACAVONE': 0,
    'YACCARINO': 0,
    'YACCINO': 0,
    'YACH': 0,
    'YACK': 0,
    'YACKEE': 0,
    'YACKEL': 0,
    'YACKER': 0,
    'YACKEY': 0,
    'YACKLE': 0,
    'YACKLEY': 0,
    'YACKO': 0,
    'YACKS': 0,
    'YACOB': 0,
    'YACOBELLIS': 0,
    'YACOBUCCI': 0,
    'YACONO': 0,
    'YACOOB': 0,
    'YACOUB': 0,
    'YACOUBIAN': 0,
    'YACOVELLI': 0,
    'YACOVONE': 0,
    'YACULLO': 0,
    'YADA': 0,
    'YADAO': 0,
    'YADAV': 0,
    'YADDOW': 0,
    'YADEGAR': 0,
    'YADEN': 0,
    'YADIRA': 1,
    'YADLOSKY': 0,
    'YADO': 0,
    'YADON': 0,
    'YAEGER': 0,
    'YAEKO': 1,
    'YAEL': 1,
    'YAFAI': 0,
    'YAFFA': 0,
    'YAFFE': 0,
    'YAFFEE': 0,
    'YAFUSO': 0,
    'YAGEL': 0,
    'YAGELSKI': 0,
    'YAGER': 0,
    'YAGGI': 0,
    'YAGGIE': 0,
    'YAGGY': 0,
    'YAGHI': 0,
    'YAGHOUBI': 0,
    'YAGHOUBIAN': 0,
    'YAGI': 0,
    'YAGIN': 0,
    'YAGLE': 0,
    'YAGO': 0,
    'YAGODA': 0,
    'YAGUAL': 0,
    'YAGUCHI': 0,
    'YAGUDAYEV': 0,
    'YAH': 0,
    'YAHAIRA': 1,
    'YAHIA': 0,
    'YAHL': 0,
    'YAHN': 0,
    'YAHNE': 0,
    'YAHNER': 0,
    'YAHNKE': 0,
    'YAHOLA': 0,
    'YAHR': 0,
    'YAHRAUS': 0,
    'YAHYA': 0,
    'YAICH': 0,
    'YAJAIRA': 1,
    'YAJIMA': 0,
    'YAKAITIS': 0,
    'YAKE': 0,
    'YAKEL': 0,
    'YAKER': 0,
    'YAKES': 0,
    'YAKEY': 0,
    'YAKICH': 0,
    'YAKIM': 0,
    'YAKISH': 0,
    'YAKLE': 0,
    'YAKLICH': 0,
    'YAKLIN': 0,
    'YAKO': 0,
    'YAKOVICH': 0,
    'YAKOVLEV': 0,
    'YAKSIC': 0,
    'YAKSICH': 0,
    'YAKUB': 0,
    'YAKUBIK': 0,
    'YAKUBOV': 0,
    'YAKUBOVA': 0,
    'YAKUBOVICH': 0,
    'YAKUSH': 0,
    'YALAMANCHILI': 0,
    'YALCH': 0,
    'YALCIN': 0,
    'YALDA': 0,
    'YALDO': 0,
    'YALDOO': 0,
    'YALE': 0,
    'YALEY': 0,
    'YALLUP': 0,
    'YALUNG': 0,
    'YAM': 0,
    'YAMA': 0,
    'YAMABE': 0,
    'YAMADA': 0,
    'YAMAGATA': 0,
    'YAMAGISHI': 0,
    'YAMAGUCHI': 0,
    'YAMAKAWA': 0,
    'YAMAKI': 0,
    'YAMAMOTO': 0,
    'YAMAMURA': 0,
    'YAMAN': 0,
    'YAMANAKA': 0,
    'YAMANE': 0,
    'YAMANI': 0,
    'YAMANO': 0,
    'YAMAOKA': 0,
    'YAMASAKI': 0,
    'YAMASHIRD': 0,
    'YAMASHIRO': 0,
    'YAMASHITA': 0,
    'YAMAT': 0,
    'YAMATE': 0,
    'YAMATO': 0,
    'YAMAUCHI': 0,
    'YAMAZAKI': 0,
    'YAMBAO': 0,
    'YAMBO': 0,
    'YAMBOR': 0,
    'YAMIN': 0,
    'YAMINI': 0,
    'YAMNITZ': 0,
    'YAMPOLSKY': 0,
    'YAN': 0.4024144869215292,
    'YANA': 0,
    'YANACEK': 0,
    'YANAGA': 0,
    'YANAGAWA': 0,
    'YANAGI': 0,
    'YANAGIDA': 0,
    'YANAGIHARA': 0,
    'YANAGISAWA': 0,
    'YANAI': 0,
    'YANAK': 0,
    'YANAS': 0,
    'YANASE': 0,
    'YANCE': 0,
    'YANCER': 0,
    'YANCEY': 0,
    'YANCHAK': 0,
    'YANCHEK': 0,
    'YANCHIK': 0,
    'YANCHUK': 0,
    'YANCOSKIE': 0,
    'YANCY': 0,
    'YAND': 0,
    'YANDA': 0,
    'YANDALL': 0,
    'YANDEL': 0,
    'YANDELL': 0,
    'YANDER': 0,
    'YANDERS': 0,
    'YANDLE': 0,
    'YANDO': 0,
    'YANDOLI': 0,
    'YANDOW': 0,
    'YANDURA': 0,
    'YANDYKE': 0,
    'YANEK': 0,
    'YANERO': 0,
    'YANES': 0,
    'YANEY': 0,
    'YANEZ': 0,
    'YANG': 0.06915629322268325,
    'YANHORN': 0,
    'YANICK': 0,
    'YANIGA': 0,
    'YANIK': 0,
    'YANIRA': 1,
    'YANIS': 0,
    'YANISH': 0,
    'YANITY': 0,
    'YANIZ': 0,
    'YANK': 0,
    'YANKAUSKAS': 0,
    'YANKE': 0,
    'YANKEE': 0,
    'YANKER': 0,
    'YANKEY': 0,
    'YANKIE': 0,
    'YANKO': 0,
    'YANKOSKI': 0,
    'YANKOSKY': 0,
    'YANKOVICH': 0,
    'YANKOWSKI': 0,
    'YANKOWSKY': 0,
    'YANKTON': 0,
    'YANKURA': 0,
    'YANKUS': 0,
    'YANN': 0,
    'YANNA': 0,
    'YANNACCI': 0,
    'YANNACONE': 0,
    'YANNARELLA': 0,
    'YANNAYON': 0,
    'YANNELLI': 0,
    'YANNELLO': 0,
    'YANNES': 0,
    'YANNETTI': 0,
    'YANNEY': 0,
    'YANNI': 0,
    'YANNIELLO': 0,
    'YANNO': 0,
    'YANNONE': 0,
    'YANNOTTA': 0,
    'YANNOTTI': 0,
    'YANNUCCI': 0,
    'YANNUZZI': 0,
    'YANO': 0,
    'YANOFF': 0,
    'YANOFSKY': 0,
    'YANOK': 0,
    'YANOS': 0,
    'YANOSIK': 0,
    'YANOSKY': 0,
    'YANOVER': 0,
    'YANOVICH': 0,
    'YANOVSKAYA': 0,
    'YANOVSKY': 0,
    'YANOW': 0,
    'YANOWITZ': 0,
    'YANPELT': 0,
    'YANSICK': 0,
    'YANSON': 0,
    'YANT': 0,
    'YANTA': 0,
    'YANTES': 0,
    'YANTIS': 0,
    'YANTZ': 0,
    'YANTZER': 0,
    'YANUS': 0,
    'YANUZZI': 0,
    'YANWINKLE': 0,
    'YANZ': 0,
    'YAO': 0,
    'YAP': 0,
    'YAPLE': 0,
    'YAPO': 0,
    'YAPP': 0,
    'YAQOOB': 0,
    'YAQUB': 0,
    'YAQUINTO': 0,
    'YAR': 0,
    'YARA': 0,
    'YARBER': 0,
    'YARBERRY': 0,
    'YARBOR': 0,
    'YARBORO': 0,
    'YARBOROUGH': 0,
    'YARBOUGH': 0,
    'YARBRO': 0,
    'YARBROUGH': 0,
    'YARD': 0,
    'YARDE': 0,
    'YARDLEY': 0,
    'YARDY': 0,
    'YARED': 0,
    'YAREMA': 0,
    'YAREMKO': 0,
    'YARGEAU': 0,
    'YARGER': 0,
    'YARIAN': 0,
    'YARINA': 0,
    'YARIS': 0,
    'YARISH': 0,
    'YARKOSKY': 0,
    'YARLAGADDA': 0,
    'YARLING': 0,
    'YARLOTT': 0,
    'YARMAN': 0,
    'YARMUSH': 0,
    'YARN': 0,
    'YARNAL': 0,
    'YARNALL': 0,
    'YARNELL': 0,
    'YARNES': 0,
    'YARNO': 0,
    'YARNOLD': 0,
    'YARNS': 0,
    'YAROCH': 0,
    'YARON': 0,
    'YAROS': 0,
    'YAROSH': 0,
    'YAROSZ': 0,
    'YARRELL': 0,
    'YARRINGTON': 0,
    'YARRIS': 0,
    'YARRISH': 0,
    'YARRISON': 0,
    'YARRITO': 0,
    'YARROW': 0,
    'YARTER': 0,
    'YARTZ': 0,
    'YARUS': 0,
    'YARUSSI': 0,
    'YARUSSO': 0,
    'YARWOOD': 0,
    'YARYAN': 0,
    'YASAY': 0,
    'YASEEN': 0,
    'YASENCHAK': 0,
    'YASH': 0,
    'YASHAR': 0,
    'YASHINSKI': 0,
    'YASI': 0,
    'YASIN': 0,
    'YASINSKI': 0,
    'YASKO': 0,
    'YASMIN': 0.9779951100244498,
    'YASMINE': 1,
    'YASQUEZ': 0,
    'YASSA': 0,
    'YASSIN': 0,
    'YASSINE': 0,
    'YASSO': 0,
    'YASTE': 0,
    'YASUDA': 0,
    'YASUHARA': 0,
    'YASUI': 0,
    'YASUKAWA': 0,
    'YASUKO': 1,
    'YASUNAGA': 0,
    'YASUTAKE': 0,
    'YAT': 0,
    'YATA': 0,
    'YATCO': 0,
    'YATER': 0,
    'YATES': 0,
    'YATH': 0,
    'YATOOMA': 0,
    'YATSKO': 0,
    'YATTAW': 0,
    'YAU': 0,
    'YAUCH': 0,
    'YAUGER': 0,
    'YAUGHN': 0,
    'YAUK': 0,
    'YAUKEY': 0,
    'YAUN': 0,
    'YAURI': 0,
    'YAUSSI': 0,
    'YAUSSY': 0,
    'YAVARI': 0,
    'YAVORSKI': 0,
    'YAVORSKY': 0,
    'YAVUZ': 0,
    'YAW': 0,
    'YAWGER': 0,
    'YAWN': 0,
    'YAWORSKI': 0,
    'YAWORSKY': 0,
    'YAWS': 0,
    'YAX': 0,
    'YAYA': 0,
    'YAZAWA': 0,
    'YAZBECK': 0,
    'YAZBEK': 0,
    'YAZDANI': 0,
    'YAZDI': 0,
    'YAZEL': 0,
    'YAZELL': 0,
    'YAZZA': 0,
    'YAZZIE': 0,
    'YAZZOLINO': 0,
    'YBANEZ': 0,
    'YBARBO': 0,
    'YBARRA': 0,
    'YCAZA': 0,
    'YDE': 0,
    'YE': 0,
    'YEA': 0,
    'YEADON': 0,
    'YEAGER': 0,
    'YEAGLE': 0,
    'YEAGLEY': 0,
    'YEAKEL': 0,
    'YEAKEY': 0,
    'YEAKLE': 0,
    'YEAKLEY': 0,
    'YEALY': 0,
    'YEAMAN': 0,
    'YEAMANS': 0,
    'YEAN': 0,
    'YEANEY': 0,
    'YEANY': 0,
    'YEAP': 0,
    'YEAPLE': 0,
    'YEARBY': 0,
    'YEARGAIN': 0,
    'YEARGAN': 0,
    'YEARGIN': 0,
    'YEARIAN': 0,
    'YEARICK': 0,
    'YEARICKS': 0,
    'YEARLEY': 0,
    'YEARLING': 0,
    'YEAROUS': 0,
    'YEAROUT': 0,
    'YEARSLEY': 0,
    'YEARTA': 0,
    'YEARTY': 0,
    'YEARWOOD': 0,
    'YEARY': 0,
    'YEAST': 0,
    'YEATER': 0,
    'YEATES': 0,
    'YEATMAN': 0,
    'YEATON': 0,
    'YEATS': 0,
    'YEATTS': 0,
    'YEAW': 0,
    'YEAZEL': 0,
    'YEAZELL': 0,
    'YEAZLE': 0,
    'YEBBA': 0,
    'YEBOAH': 0,
    'YEBRA': 0,
    'YECK': 0,
    'YECKEL': 0,
    'YECKLEY': 0,
    'YEDID': 0,
    'YEDINAK': 0,
    'YEDNAK': 0,
    'YEDNOCK': 0,
    'YEE': 0.2169197396963124,
    'YEEND': 0,
    'YEGA': 0,
    'YEGANEH': 0,
    'YEGGE': 0,
    'YEGGY': 0,
    'YEH': 0,
    'YEHIA': 0,
    'YEHL': 0,
    'YEHLE': 0,
    'YEHLING': 0,
    'YEICH': 0,
    'YEIDER': 0,
    'YEILDING': 0,
    'YEINGST': 0,
    'YEISER': 0,
    'YEISLEY': 0,
    'YEITER': 0,
    'YEKEL': 0,
    'YELA': 0,
    'YELDA': 0,
    'YELDELL': 0,
    'YELDER': 0,
    'YELEN': 0,
    'YELENA': 1,
    'YELEY': 0,
    'YELICH': 0,
    'YELIN': 0,
    'YELINEK': 0,
    'YELK': 0,
    'YELL': 0,
    'YELLAND': 0,
    'YELLE': 0,
    'YELLEN': 0,
    'YELLETS': 0,
    'YELLIN': 0,
    'YELLING': 0,
    'YELLOCK': 0,
    'YELLOTT': 0,
    'YELLOW': 0,
    'YELLOWBIRD': 0,
    'YELLOWBOY': 0,
    'YELLOWHAIR': 0,
    'YELLOWHORSE': 0,
    'YELLOWMAN': 0,
    'YELM': 0,
    'YELOVICH': 0,
    'YELTON': 0,
    'YELVERTON': 0,
    'YELVINGTON': 0,
    'YEM': 0,
    'YEMANE': 0,
    'YEMM': 0,
    'YEMMA': 0,
    'YEN': 0.5361930294906166,
    'YENCER': 0,
    'YENCHA': 0,
    'YENCHIK': 0,
    'YENCHO': 0,
    'YENG': 0,
    'YENGER': 0,
    'YENGLIN': 0,
    'YENNA': 0,
    'YENNE': 0,
    'YENNEY': 0,
    'YENNI': 0,
    'YENNIE': 0,
    'YENNY': 0,
    'YENOR': 0,
    'YENSEN': 0,
    'YENSER': 0,
    'YENT': 0,
    'YENTER': 0,
    'YENTES': 0,
    'YENTSCH': 0,
    'YENTZ': 0,
    'YENTZER': 0,
    'YENZER': 0,
    'YEO': 0,
    'YEOH': 0,
    'YEOM': 0,
    'YEOMAN': 0,
    'YEOMANS': 0,
    'YEON': 0,
    'YEP': 0,
    'YEPA': 0,
    'YEPES': 0,
    'YEPEZ': 0,
    'YEPIZ': 0,
    'YEPREMIAN': 0,
    'YEPSEN': 0,
    'YER': 1,
    'YERA': 0,
    'YERARDI': 0,
    'YERBY': 0,
    'YERDEN': 0,
    'YERDON': 0,
    'YEREMIAN': 0,
    'YERENA': 0,
    'YERG': 0,
    'YERGEAU': 0,
    'YERGENSEN': 0,
    'YERGER': 0,
    'YERGES': 0,
    'YERGEY': 0,
    'YERGIN': 0,
    'YERGLER': 0,
    'YERIAN': 0,
    'YERIGAN': 0,
    'YERINGTON': 0,
    'YERK': 0,
    'YERKA': 0,
    'YERKE': 0,
    'YERKES': 0,
    'YERKEY': 0,
    'YERKOVICH': 0,
    'YERKS': 0,
    'YERLY': 0,
    'YERMAN': 0,
    'YERO': 0,
    'YERRICK': 0,
    'YERRY': 0,
    'YERTON': 0,
    'YERUSHALMI': 0,
    'YERXA': 0,
    'YESAYAN': 0,
    'YESCAS': 0,
    'YESENIA': 1,
    'YESH': 0,
    'YESKA': 0,
    'YESKE': 0,
    'YESKEY': 0,
    'YESKO': 0,
    'YESS': 0,
    'YESSAYAN': 0,
    'YESSENIA': 1,
    'YESTER': 0,
    'YETKA': 0,
    'YETMAN': 0,
    'YETSKO': 0,
    'YETT': 0,
    'YETTA': 1,
    'YETTAW': 0,
    'YETTE': 0,
    'YETTER': 0,
    'YETTO': 0,
    'YETZER': 0,
    'YEUBANKS': 0,
    'YEUN': 0,
    'YEUNG': 0,
    'YEUTTER': 0,
    'YEVETTE': 1,
    'YEW': 0,
    'YEWELL': 0,
    'YEZAK': 0,
    'YEZEK': 0,
    'YEZZI': 0,
    'YGLECIAS': 0,
    'YGLESIAS': 0,
    'YHAP': 0,
    'YI': 0.26143790849673204,
    'YICK': 0,
    'YIELDING': 0,
    'YIENGST': 0,
    'YIH': 0,
    'YIK': 0,
    'YIKE': 0,
    'YILDIRIM': 0,
    'YILDIZ': 0,
    'YILEK': 0,
    'YILMA': 0,
    'YILMAZ': 0,
    'YIM': 0,
    'YIN': 0,
    'YING': 0.7633587786259542,
    'YINGER': 0,
    'YINGLING': 0,
    'YINGST': 0,
    'YIP': 0,
    'YIRKA': 0,
    'YISRAEL': 0,
    'YIU': 0,
    'YLAGAN': 0,
    'YLINEN': 0,
    'YLINIEMI': 0,
    'YLITALO': 0,
    'YLLESCAS': 0,
    'YLVISAKER': 0,
    'YMKER': 0,
    'YNCLAN': 0,
    'YNFANTE': 0,
    'YNIGUEZ': 0,
    'YNOA': 0,
    'YNOSTROSA': 0,
    'YNOSTROZA': 0,
    'YNTEMA': 0,
    'YO': 0,
    'YOACHUM': 0,
    'YOAK': 0,
    'YOAKAM': 0,
    'YOAKEM': 0,
    'YOAKUM': 0,
    'YOAS': 0,
    'YOAST': 0,
    'YOB': 0,
    'YOC': 0,
    'YOCCA': 0,
    'YOCCO': 0,
    'YOCH': 0,
    'YOCHAM': 0,
    'YOCHEM': 0,
    'YOCHIM': 0,
    'YOCHUM': 0,
    'YOCK': 0,
    'YOCKEL': 0,
    'YOCKEY': 0,
    'YOCOM': 0,
    'YOCUM': 0,
    'YODA': 0,
    'YODER': 0,
    'YODERS': 0,
    'YODICE': 0,
    'YODIS': 0,
    'YOE': 0,
    'YOERG': 0,
    'YOERGER': 0,
    'YOES': 0,
    'YOEST': 0,
    'YOESTING': 0,
    'YOEUN': 0,
    'YOFFE': 0,
    'YOGERST': 0,
    'YOGI': 0,
    'YOGUEZ': 0,
    'YOH': 0,
    'YOHANNAN': 0,
    'YOHANNES': 0,
    'YOHE': 0,
    'YOHEY': 0,
    'YOHMAN': 0,
    'YOHN': 0,
    'YOHO': 0,
    'YOKE': 0,
    'YOKEL': 0,
    'YOKELEY': 0,
    'YOKEM': 0,
    'YOKIEL': 0,
    'YOKLEY': 0,
    'YOKO': 1,
    'YOKOI': 0,
    'YOKOM': 0,
    'YOKOMIZO': 0,
    'YOKOTA': 0,
    'YOKOYAMA': 0,
    'YOKUM': 0,
    'YOLANDA': 1,
    'YOLANDE': 1,
    'YOLANDO': 1,
    'YOLLES': 0,
    'YOLONDA': 1,
    'YOLTON': 0,
    'YOM': 0,
    'YOMMER': 0,
    'YON': 0.4878048780487804,
    'YONA': 0,
    'YONAK': 0,
    'YONALLY': 0,
    'YONAMINE': 0,
    'YONAN': 0,
    'YONAS': 0,
    'YONCE': 0,
    'YONEDA': 0,
    'YONEK': 0,
    'YONEMOTO': 0,
    'YONEMURA': 0,
    'YONESHIGE': 0,
    'YONEY': 0,
    'YONEYAMA': 0,
    'YONEZAWA': 0,
    'YONG': 0.9084556254367576,
    'YONGE': 0,
    'YONGUE': 0,
    'YONIS': 0,
    'YONISH': 0,
    'YONKE': 0,
    'YONKER': 0,
    'YONKERS': 0,
    'YONKIN': 0,
    'YONKMAN': 0,
    'YONKO': 0,
    'YONN': 0,
    'YONO': 0,
    'YONTS': 0,
    'YONTZ': 0,
    'YOO': 0,
    'YOOK': 0,
    'YOON': 0,
    'YOONG': 0,
    'YOOS': 0,
    'YOPP': 0,
    'YOQUELET': 0,
    'YORBA': 0,
    'YORDAN': 0,
    'YORDY': 0,
    'YORE': 0,
    'YOREK': 0,
    'YORGASON': 0,
    'YORGENSEN': 0,
    'YORGEY': 0,
    'YORI': 0,
    'YORIO': 0,
    'YORITA': 0,
    'YORK': 0,
    'YORKE': 0,
    'YORKER': 0,
    'YORKEY': 0,
    'YORKO': 0,
    'YORKS': 0,
    'YORN': 0,
    'YORO': 0,
    'YORSTON': 0,
    'YORTON': 0,
    'YORTY': 0,
    'YOS': 0,
    'YOSEF': 0,
    'YOSHIDA': 0,
    'YOSHIE': 1,
    'YOSHIHARA': 0,
    'YOSHII': 0,
    'YOSHIKAWA': 0,
    'YOSHIKO': 1,
    'YOSHIMI': 0,
    'YOSHIMOTO': 0,
    'YOSHIMURA': 0,
    'YOSHINAGA': 0,
    'YOSHINO': 0,
    'YOSHIOKA': 0,
    'YOSHITAKE': 0,
    'YOSHIYAMA': 0,
    'YOSHIZAKI': 0,
    'YOSHIZAWA': 0,
    'YOSHIZUMI': 0,
    'YOSICK': 0,
    'YOSKO': 0,
    'YOSKOWITZ': 0,
    'YOSS': 0,
    'YOST': 0,
    'YOSTEN': 0,
    'YOTHER': 0,
    'YOTHERS': 0,
    'YOTT': 0,
    'YOTTER': 0,
    'YOU': 0,
    'YOUAKIM': 0,
    'YOUD': 0,
    'YOUEL': 0,
    'YOUELL': 0,
    'YOUELLS': 0,
    'YOUHANNA': 0,
    'YOUHAS': 0,
    'YOUK': 0,
    'YOUKER': 0,
    'YOUKERS': 0,
    'YOUKHANA': 0,
    'YOUKHANNA': 0,
    'YOULANDA': 1,
    'YOUM': 0,
    'YOUMAN': 0,
    'YOUMANS': 0,
    'YOUN': 0,
    'YOUNAN': 0,
    'YOUNAS': 0,
    'YOUNCE': 0,
    'YOUNDT': 0,
    'YOUNES': 0,
    'YOUNESS': 0,
    'YOUNG': 0.08960101196437043,
    'YOUNGBAR': 0,
    'YOUNGBAUER': 0,
    'YOUNGBEAR': 0,
    'YOUNGBERG': 0,
    'YOUNGBIRD': 0,
    'YOUNGBLOM': 0,
    'YOUNGBLOOD': 0,
    'YOUNGBLUT': 0,
    'YOUNGCLAUS': 0,
    'YOUNGDAHL': 0,
    'YOUNGDALE': 0,
    'YOUNGE': 0,
    'YOUNGER': 0,
    'YOUNGERMAN': 0,
    'YOUNGERS': 0,
    'YOUNGGREN': 0,
    'YOUNGHANS': 0,
    'YOUNGINER': 0,
    'YOUNGKER': 0,
    'YOUNGKIN': 0,
    'YOUNGLING': 0,
    'YOUNGLOVE': 0,
    'YOUNGMAN': 0,
    'YOUNGMARK': 0,
    'YOUNGPETER': 0,
    'YOUNGQUIST': 0,
    'YOUNGREN': 0,
    'YOUNGS': 0,
    'YOUNGSMA': 0,
    'YOUNGSON': 0,
    'YOUNGSTROM': 0,
    'YOUNGWIRTH': 0,
    'YOUNGWORTH': 0,
    'YOUNIE': 0,
    'YOUNIS': 0,
    'YOUNK': 0,
    'YOUNKER': 0,
    'YOUNKERS': 0,
    'YOUNKIN': 0,
    'YOUNKINS': 0,
    'YOUNT': 0,
    'YOUNTS': 0,
    'YOUNTZ': 0,
    'YOUNUS': 0,
    'YOUREE': 0,
    'YOUSAF': 0,
    'YOUSE': 0,
    'YOUSEF': 0,
    'YOUSEFI': 0,
    'YOUSEFIAN': 0,
    'YOUSEFZADEH': 0,
    'YOUSEY': 0,
    'YOUSIF': 0,
    'YOUSKO': 0,
    'YOUSO': 0,
    'YOUSSEF': 0,
    'YOUSSEFI': 0,
    'YOUST': 0,
    'YOUSUF': 0,
    'YOUSUFZAI': 0,
    'YOUTSEY': 0,
    'YOUTZ': 0,
    'YOUTZY': 0,
    'YOVANOVICH': 0,
    'YOVICH': 0,
    'YOVINO': 0,
    'YOW': 0,
    'YOWELL': 0,
    'YOWLER': 0,
    'YOX': 0,
    'YOXALL': 0,
    'YOXTHEIMER': 0,
    'YOZA': 0,
    'YOZZO': 0,
    'YPMA': 0,
    'YRACHETA': 0,
    'YRIARTE': 0,
    'YRIBE': 0,
    'YRIGOLLEN': 0,
    'YRIGOYEN': 0,
    'YRUEGAS': 0,
    'YSAGUIRRE': 0,
    'YSAIS': 0,
    'YSASAGA': 0,
    'YSASI': 0,
    'YSASSI': 0,
    'YSLAS': 0,
    'YSLAVA': 0,
    'YSQUIERDO': 0,
    'YTTRI': 0,
    'YTUARTE': 0,
    'YTURRALDE': 0,
    'YU': 0.18237082066869303,
    'YUAN': 0,
    'YUASA': 0,
    'YUBETA': 0,
    'YUCEL': 0,
    'YUCHA': 0,
    'YUDELL': 0,
    'YUDIN': 0,
    'YUDT': 0,
    'YUE': 0,
    'YUEH': 0,
    'YUEN': 0,
    'YUENGER': 0,
    'YUETTE': 1,
    'YUH': 0,
    'YUHAS': 0,
    'YUHASZ': 0,
    'YUI': 0,
    'YUILL': 0,
    'YUILLE': 0,
    'YUK': 0.9174311926605505,
    'YUKAWA': 0,
    'YUKI': 0.9345794392523364,
    'YUKICH': 0,
    'YUKIKO': 1,
    'YUKNIS': 0,
    'YUKO': 1,
    'YUKON': 0,
    'YUKSEL': 0,
    'YULANDA': 1,
    'YULE': 0,
    'YULFO': 0,
    'YULO': 0,
    'YUM': 0,
    'YUMAN': 0,
    'YUMANG': 0,
    'YUMUL': 0,
    'YUN': 0.43763676148796504,
    'YUNCKER': 0,
    'YUND': 0,
    'YUNDT': 0,
    'YUNES': 0,
    'YUNG': 0.38759689922480617,
    'YUNGA': 0,
    'YUNGBLUTH': 0,
    'YUNGER': 0,
    'YUNGINGER': 0,
    'YUNIS': 0,
    'YUNK': 0,
    'YUNKER': 0,
    'YUNT': 0,
    'YUNUS': 0,
    'YUONNE': 1,
    'YURA': 0,
    'YURAN': 0,
    'YURASEK': 0,
    'YURASITS': 0,
    'YURCAK': 0,
    'YURCHAK': 0,
    'YURCHENKO': 0,
    'YURCHO': 0,
    'YURCISIN': 0,
    'YURECHKO': 0,
    'YUREK': 0,
    'YURGEL': 0,
    'YURI': 1,
    'YURIAR': 0,
    'YURICH': 0,
    'YURICK': 0,
    'YURIK': 0,
    'YURIKO': 1,
    'YURISH': 0,
    'YURK': 0,
    'YURKANIN': 0,
    'YURKIEWICZ': 0,
    'YURKIN': 0,
    'YURKO': 0,
    'YURKONIS': 0,
    'YURKOVIC': 0,
    'YURKOVICH': 0,
    'YURMAN': 0,
    'YURO': 0,
    'YURT': 0,
    'YUSCHAK': 0,
    'YUSEF': 0,
    'YUSI': 0,
    'YUSIM': 0,
    'YUSKA': 0,
    'YUSKO': 0,
    'YUSON': 0,
    'YUSSUF': 0,
    'YUST': 0,
    'YUSTEN': 0,
    'YUSUF': 0,
    'YUSUFF': 0,
    'YUSUFI': 0,
    'YUSUFOV': 0,
    'YUSUPOV': 0,
    'YUTZY': 0,
    'YUZON': 0,
    'YVETTE': 1,
    'YVON': 0,
    'YVONE': 1,
    'YVONNE': 1,
    'YZAGUIRRE': 0,
    'YZNAGA': 0,
    'YZQUIERDO': 0,
    'ZAAGMAN': 0,
    'ZAAYER': 0,
    'ZABA': 0,
    'ZABACK': 0,
    'ZABALA': 0,
    'ZABALETA': 0,
    'ZABALZA': 0,
    'ZABANEH': 0,
    'ZABARSKY': 0,
    'ZABAT': 0,
    'ZABATTA': 0,
    'ZABAWA': 0,
    'ZABAWSKI': 0,
    'ZABEK': 0,
    'ZABEL': 0,
    'ZABELL': 0,
    'ZABEN': 0,
    'ZABER': 0,
    'ZABICKI': 0,
    'ZABIELSKI': 0,
    'ZABIK': 0,
    'ZABINSKI': 0,
    'ZABINSKY': 0,
    'ZABKA': 0,
    'ZABKAR': 0,
    'ZABLAN': 0,
    'ZABLE': 0,
    'ZABLER': 0,
    'ZABLOCKI': 0,
    'ZABLOTNY': 0,
    'ZABLOUDIL': 0,
    'ZABOJNIK': 0,
    'ZABOKRTSKY': 0,
    'ZABOR': 0,
    'ZABORAC': 0,
    'ZABORNY': 0,
    'ZABOROWSKI': 0,
    'ZABORSKI': 0,
    'ZABORSKY': 0,
    'ZABOWSKI': 0,
    'ZABRANSKY': 0,
    'ZABRISKIE': 0,
    'ZABROCKI': 0,
    'ZABROSKI': 0,
    'ZABROSKY': 0,
    'ZABROWSKI': 0,
    'ZACARIAS': 0,
    'ZACATENCO': 0,
    'ZACCAGNINI': 0,
    'ZACCAGNINO': 0,
    'ZACCARDELLI': 0,
    'ZACCARDI': 0,
    'ZACCARDO': 0,
    'ZACCARELLI': 0,
    'ZACCARI': 0,
    'ZACCARIA': 0,
    'ZACCARO': 0,
    'ZACCHEO': 0,
    'ZACCONE': 0,
    'ZACEK': 0,
    'ZACH': 0,
    'ZACHA': 0,
    'ZACHAR': 0,
    'ZACHARA': 0,
    'ZACHAREK': 0,
    'ZACHARIA': 0,
    'ZACHARIAH': 0.9578544061302682,
    'ZACHARIAS': 0,
    'ZACHARIASEN': 0,
    'ZACHARIE': 0,
    'ZACHARKO': 0,
    'ZACHARSKI': 0,
    'ZACHARY': 0.9765239692246991,
    'ZACHAU': 0,
    'ZACHEIS': 0,
    'ZACHER': 0,
    'ZACHERL': 0,
    'ZACHERY': 0.9269988412514484,
    'ZACHGO': 0,
    'ZACHMAN': 0,
    'ZACHMANN': 0,
    'ZACHMEYER': 0,
    'ZACHOS': 0,
    'ZACHOW': 0,
    'ZACHRICH': 0,
    'ZACHRY': 0,
    'ZACHWIEJA': 0,
    'ZACK': 0.7339449541284404,
    'ZACKARY': 0.9828009828009829,
    'ZACKER': 0,
    'ZACKERY': 0,
    'ZACKEY': 0,
    'ZACKOWSKI': 0,
    'ZACKS': 0,
    'ZACNY': 0,
    'ZACZEK': 0,
    'ZACZYK': 0,
    'ZADA': 0.9433962264150944,
    'ZADE': 0,
    'ZADEH': 0,
    'ZADEL': 0,
    'ZADINA': 0,
    'ZADLO': 0,
    'ZADNIK': 0,
    'ZADOK': 0,
    'ZADOR': 0,
    'ZADORA': 0,
    'ZADOROZNY': 0,
    'ZADOW': 0,
    'ZADRA': 0,
    'ZADRIMA': 0,
    'ZADROGA': 0,
    'ZADROZNY': 0,
    'ZAEBST': 0,
    'ZAEHRINGER': 0,
    'ZAENGLE': 0,
    'ZAENGLEIN': 0,
    'ZAEPFEL': 0,
    'ZAESKE': 0,
    'ZAFAR': 0,
    'ZAFER': 0,
    'ZAFFARANO': 0,
    'ZAFFINA': 0,
    'ZAFFINO': 0,
    'ZAFFIRO': 0,
    'ZAFFKE': 0,
    'ZAFFT': 0,
    'ZAFFUTO': 0,
    'ZAFIR': 0,
    'ZAFIRIS': 0,
    'ZAFIROPOULOS': 0,
    'ZAFONTE': 0,
    'ZAFRA': 0,
    'ZAFRAN': 0,
    'ZAFRANI': 0,
    'ZAFT': 0,
    'ZAGADA': 0,
    'ZAGAJA': 0,
    'ZAGAL': 0,
    'ZAGALA': 0,
    'ZAGAME': 0,
    'ZAGAMI': 0,
    'ZAGAR': 0,
    'ZAGARA': 0,
    'ZAGARELLA': 0,
    'ZAGARI': 0,
    'ZAGATA': 0,
    'ZAGER': 0,
    'ZAGHI': 0,
    'ZAGHLOUL': 0,
    'ZAGO': 0,
    'ZAGONE': 0,
    'ZAGORSKI': 0,
    'ZAGORSKY': 0,
    'ZAGRODNIK': 0,
    'ZAGULA': 0,
    'ZAGURSKI': 0,
    'ZAHA': 0,
    'ZAHAR': 0,
    'ZAHARA': 0,
    'ZAHARIA': 0,
    'ZAHARIAS': 0,
    'ZAHARIS': 0,
    'ZAHAROPOULOS': 0,
    'ZAHEDI': 0,
    'ZAHEER': 0,
    'ZAHER': 0,
    'ZAHID': 0,
    'ZAHIR': 0,
    'ZAHIROVIC': 0,
    'ZAHL': 0,
    'ZAHLER': 0,
    'ZAHLLER': 0,
    'ZAHM': 0,
    'ZAHN': 0,
    'ZAHND': 0,
    'ZAHNE': 0,
    'ZAHNER': 0,
    'ZAHNISER': 0,
    'ZAHNLE': 0,
    'ZAHNOW': 0,
    'ZAHORA': 0,
    'ZAHORCHAK': 0,
    'ZAHORIK': 0,
    'ZAHORSKY': 0,
    'ZAHR': 0,
    'ZAHRA': 0,
    'ZAHRADKA': 0,
    'ZAHRADNIK': 0,
    'ZAHRAN': 0,
    'ZAHRINGER': 0,
    'ZAHROBSKY': 0,
    'ZAHRT': 0,
    'ZAHURAK': 0,
    'ZAHURANEC': 0,
    'ZAIA': 0,
    'ZAIC': 0,
    'ZAID': 0,
    'ZAIDA': 1,
    'ZAIDAN': 0,
    'ZAIDEL': 0,
    'ZAIDI': 0,
    'ZAIDMAN': 0,
    'ZAIGER': 0,
    'ZAIKOWSKI': 0,
    'ZAIN': 0,
    'ZAINO': 0,
    'ZAIONTZ': 0,
    'ZAIS': 0,
    'ZAISER': 0,
    'ZAISS': 0,
    'ZAITER': 0,
    'ZAITSEV': 0,
    'ZAITZ': 0,
    'ZAJAC': 0,
    'ZAJACK': 0,
    'ZAJACZKOWSKI': 0,
    'ZAJDA': 0,
    'ZAJDEL': 0,
    'ZAJIC': 0,
    'ZAJICEK': 0,
    'ZAJKOWSKI': 0,
    'ZAK': 0,
    'ZAKA': 0,
    'ZAKAR': 0,
    'ZAKARIA': 0,
    'ZAKARIAN': 0,
    'ZAKARYAN': 0,
    'ZAKAS': 0,
    'ZAKEM': 0,
    'ZAKEN': 0,
    'ZAKER': 0,
    'ZAKES': 0,
    'ZAKHAROV': 0,
    'ZAKHARY': 0,
    'ZAKI': 0,
    'ZAKIAN': 0,
    'ZAKIN': 0,
    'ZAKIS': 0,
    'ZAKOS': 0,
    'ZAKOWSKI': 0,
    'ZAKRAJSEK': 0,
    'ZAKRZEWSKI': 0,
    'ZAKS': 0,
    'ZAKULA': 0,
    'ZAKY': 0,
    'ZALA': 0,
    'ZALABAK': 0,
    'ZALAC': 0,
    'ZALAR': 0,
    'ZALAS': 0,
    'ZALASAR': 0,
    'ZALAZAR': 0,
    'ZALAZNIK': 0,
    'ZALDANA': 0,
    'ZALDIVAR': 0,
    'ZALE': 0,
    'ZALECKI': 0,
    'ZALENSKI': 0,
    'ZALES': 0,
    'ZALESAK': 0,
    'ZALESKI': 0,
    'ZALESKY': 0,
    'ZALESNY': 0,
    'ZALETA': 0,
    'ZALETEL': 0,
    'ZALEWSKI': 0,
    'ZALINSKI': 0,
    'ZALIS': 0,
    'ZALK': 0,
    'ZALKIN': 0,
    'ZALKIND': 0,
    'ZALL': 0,
    'ZALLA': 0,
    'ZALLAR': 0,
    'ZALLER': 0,
    'ZALMAN': 0,
    'ZALOGA': 0,
    'ZALOKAR': 0,
    'ZALOOM': 0,
    'ZALOUDEK': 0,
    'ZALTA': 0,
    'ZALTSMAN': 0,
    'ZALUCKI': 0,
    'ZALUD': 0,
    'ZALUSKI': 0,
    'ZALUSKY': 0,
    'ZAM': 0,
    'ZAMACONA': 0,
    'ZAMAGO': 0,
    'ZAMAN': 0,
    'ZAMANI': 0,
    'ZAMANIAN': 0,
    'ZAMANO': 0,
    'ZAMARIPA': 0,
    'ZAMARRIPA': 0,
    'ZAMARRIPAS': 0,
    'ZAMARRON': 0,
    'ZAMBADA': 0,
    'ZAMBARANO': 0,
    'ZAMBELLI': 0,
    'ZAMBETTI': 0,
    'ZAMBITO': 0,
    'ZAMBO': 0,
    'ZAMBON': 0,
    'ZAMBONI': 0,
    'ZAMBORSKY': 0,
    'ZAMBORY': 0,
    'ZAMBOTTI': 0,
    'ZAMBRANA': 0,
    'ZAMBRANO': 0,
    'ZAMBRI': 0,
    'ZAMBRZYCKI': 0,
    'ZAMBUTO': 0,
    'ZAMECNIK': 0,
    'ZAMIR': 0,
    'ZAMISKA': 0,
    'ZAMMIELLO': 0,
    'ZAMMIT': 0,
    'ZAMMUTO': 0,
    'ZAMOJSKI': 0,
    'ZAMOR': 0,
    'ZAMORA': 0,
    'ZAMORANO': 0,
    'ZAMORE': 0,
    'ZAMORSKI': 0,
    'ZAMOT': 0,
    'ZAMPA': 0,
    'ZAMPANO': 0,
    'ZAMPARELLI': 0,
    'ZAMPEDRI': 0,
    'ZAMPELLA': 0,
    'ZAMPELLI': 0,
    'ZAMPERINI': 0,
    'ZAMPETTI': 0,
    'ZAMPIERI': 0,
    'ZAMPINI': 0,
    'ZAMPINO': 0,
    'ZAMPITELLA': 0,
    'ZAMPOGNA': 0,
    'ZAMSKY': 0,
    'ZAMUDIO': 0,
    'ZAMZOW': 0,
    'ZAN': 0,
    'ZANA': 0.9433962264150944,
    'ZANABRIA': 0,
    'ZANARDELLI': 0,
    'ZANARDI': 0,
    'ZANATTA': 0,
    'ZANCA': 0,
    'ZANCANELLA': 0,
    'ZANCHES': 0,
    'ZANCHI': 0,
    'ZANCO': 0,
    'ZAND': 0,
    'ZANDARSKI': 0,
    'ZANDBERGEN': 0,
    'ZANDE': 0,
    'ZANDER': 0,
    'ZANDERS': 0,
    'ZANDI': 0,
    'ZANDRA': 1,
    'ZANDSTRA': 0,
    'ZANDT': 0,
    'ZANDY': 0,
    'ZANE': 0.8728179551122194,
    'ZANELLA': 0,
    'ZANELLI': 0,
    'ZANER': 0,
    'ZANES': 0,
    'ZANESKI': 0,
    'ZANETTE': 0,
    'ZANETTI': 0,
    'ZANFARDINO': 0,
    'ZANG': 0,
    'ZANGARA': 0,
    'ZANGARI': 0,
    'ZANGARO': 0,
    'ZANGER': 0,
    'ZANGERLE': 0,
    'ZANGHI': 0,
    'ZANGL': 0,
    'ZANGLA': 0,
    'ZANGRILLI': 0,
    'ZANGRILLO': 0,
    'ZANI': 0,
    'ZANIBONI': 0,
    'ZANIEWSKI': 0,
    'ZANIN': 0,
    'ZANINI': 0,
    'ZANINOVICH': 0,
    'ZANIS': 0,
    'ZANJANI': 0,
    'ZANK': 0,
    'ZANKE': 0,
    'ZANKEL': 0,
    'ZANKER': 0,
    'ZANKICH': 0,
    'ZANKO': 0,
    'ZANKOWSKI': 0,
    'ZANN': 0,
    'ZANNETTI': 0,
    'ZANNI': 0,
    'ZANNINI': 0,
    'ZANNINO': 0,
    'ZANNIS': 0,
    'ZANNONI': 0,
    'ZANOL': 0,
    'ZANOLINI': 0,
    'ZANOLLI': 0,
    'ZANON': 0,
    'ZANONE': 0,
    'ZANONI': 0,
    'ZANOTELLI': 0,
    'ZANOTTI': 0,
    'ZANOTTO': 0,
    'ZANT': 0,
    'ZANTER': 0,
    'ZANTI': 0,
    'ZANTO': 0,
    'ZANTOW': 0,
    'ZANZIG': 0,
    'ZAORSKI': 0,
    'ZAPALA': 0,
    'ZAPALAC': 0,
    'ZAPANTA': 0,
    'ZAPANTIS': 0,
    'ZAPATA': 0,
    'ZAPATERO': 0,
    'ZAPATKA': 0,
    'ZAPETA': 0,
    'ZAPF': 0,
    'ZAPFE': 0,
    'ZAPICO': 0,
    'ZAPIEN': 0,
    'ZAPINSKI': 0,
    'ZAPKA': 0,
    'ZAPLETAL': 0,
    'ZAPOLSKI': 0,
    'ZAPOR': 0,
    'ZAPOTOCKY': 0,
    'ZAPOTOCZNY': 0,
    'ZAPOTOSKY': 0,
    'ZAPP': 0,
    'ZAPPA': 0,
    'ZAPPACOSTA': 0,
    'ZAPPALA': 0,
    'ZAPPAS': 0,
    'ZAPPE': 0,
    'ZAPPI': 0,
    'ZAPPIA': 0,
    'ZAPPITELLI': 0,
    'ZAPPOLA': 0,
    'ZAPPONE': 0,
    'ZAPPULLA': 0,
    'ZAR': 0,
    'ZARA': 0,
    'ZARABI': 0,
    'ZARAGOSA': 0,
    'ZARAGOZA': 0,
    'ZARATE': 0,
    'ZARAZUA': 0,
    'ZARB': 0,
    'ZARBA': 0,
    'ZARBAUGH': 0,
    'ZARBO': 0,
    'ZARBOCK': 0,
    'ZARCO': 0,
    'ZARCONE': 0,
    'ZARCZYNSKI': 0,
    'ZARD': 0,
    'ZARDA': 0,
    'ZARE': 0,
    'ZARECKI': 0,
    'ZARECKY': 0,
    'ZAREK': 0,
    'ZARELLA': 0,
    'ZARELLI': 0,
    'ZAREMBA': 0,
    'ZAREMBSKI': 0,
    'ZAREMSKI': 0,
    'ZAREN': 0,
    'ZARESKI': 0,
    'ZARET': 0,
    'ZARETSKY': 0,
    'ZARGARI': 0,
    'ZARGARIAN': 0,
    'ZARGARYAN': 0,
    'ZARGER': 0,
    'ZARI': 0,
    'ZARICK': 0,
    'ZARICOR': 0,
    'ZARIF': 0,
    'ZARIFIS': 0,
    'ZARILLO': 0,
    'ZARIN': 0,
    'ZARINANA': 0,
    'ZARING': 0,
    'ZARINS': 0,
    'ZARITSKY': 0,
    'ZARKA': 0,
    'ZARKO': 0,
    'ZARKOWSKI': 0,
    'ZARLENGA': 0,
    'ZARLENGO': 0,
    'ZARLEY': 0,
    'ZARLING': 0,
    'ZARLINGO': 0,
    'ZARN': 0,
    'ZARNDT': 0,
    'ZARNICK': 0,
    'ZARNOCH': 0,
    'ZARNOWSKI': 0,
    'ZARNSTORFF': 0,
    'ZARO': 0,
    'ZAROFF': 0,
    'ZAROU': 0,
    'ZAROUR': 0,
    'ZARR': 0,
    'ZARRA': 0,
    'ZARRABI': 0,
    'ZARRAGA': 0,
    'ZARRELLA': 0,
    'ZARRELLI': 0,
    'ZARRIELLO': 0,
    'ZARRILLI': 0,
    'ZARRILLO': 0,
    'ZARRO': 0,
    'ZARSE': 0,
    'ZARSKI': 0,
    'ZARSKY': 0,
    'ZART': 0,
    'ZARTARIAN': 0,
    'ZARTH': 0,
    'ZARTLER': 0,
    'ZARTMAN': 0,
    'ZARUBA': 0,
    'ZARYCKI': 0,
    'ZARZA': 0,
    'ZARZANA': 0,
    'ZARZECKI': 0,
    'ZARZOSA': 0,
    'ZARZOUR': 0,
    'ZARZUELA': 0,
    'ZARZYCKI': 0,
    'ZASA': 0,
    'ZASADA': 0,
    'ZASADNY': 0,
    'ZASKE': 0,
    'ZASLAVSKAYA': 0,
    'ZASLAVSKY': 0,
    'ZASLOW': 0,
    'ZASO': 0,
    'ZASOWSKI': 0,
    'ZASPEL': 0,
    'ZASTERA': 0,
    'ZASTOUPIL': 0,
    'ZASTROW': 0,
    'ZATARAIN': 0,
    'ZATEZALO': 0,
    'ZATKO': 0,
    'ZATOPEK': 0,
    'ZATOR': 0,
    'ZATORSKI': 0,
    'ZATZ': 0,
    'ZAUALA': 0,
    'ZAUCHA': 0,
    'ZAUDERER': 0,
    'ZAUG': 0,
    'ZAUGG': 0,
    'ZAUN': 0,
    'ZAUNBRECHER': 0,
    'ZAUNER': 0,
    'ZAUTKE': 0,
    'ZAUTNER': 0,
    'ZAVACKY': 0,
    'ZAVADA': 0,
    'ZAVADIL': 0,
    'ZAVAGLIA': 0,
    'ZAVALA': 0,
    'ZAVALETA': 0,
    'ZAVALLA': 0,
    'ZAVALZA': 0,
    'ZAVARELLA': 0,
    'ZAVATSKY': 0,
    'ZAVER': 0,
    'ZAVERI': 0,
    'ZAVERL': 0,
    'ZAVESKY': 0,
    'ZAVISLAK': 0,
    'ZAVITZ': 0,
    'ZAVODA': 0,
    'ZAVODNY': 0,
    'ZAVODSKY': 0,
    'ZAVORAL': 0,
    'ZAW': 0,
    'ZAWACKI': 0,
    'ZAWADA': 0,
    'ZAWADSKI': 0,
    'ZAWADZKI': 0,
    'ZAWALSKI': 0,
    'ZAWASKI': 0,
    'ZAWATSKI': 0,
    'ZAWATSKY': 0,
    'ZAWICKI': 0,
    'ZAWIERUCHA': 0,
    'ZAWILA': 0,
    'ZAWILINSKI': 0,
    'ZAWISA': 0,
    'ZAWISLAK': 0,
    'ZAWISTOWSKI': 0,
    'ZAWISZA': 0,
    'ZAWLOCKI': 0,
    'ZAWODNIAK': 0,
    'ZAWODNY': 0,
    'ZAWOJSKI': 0,
    'ZAWORSKI': 0,
    'ZAWROTNY': 0,
    'ZAY': 0,
    'ZAYA': 0,
    'ZAYAC': 0,
    'ZAYAS': 0,
    'ZAYASBAZAN': 0,
    'ZAYAT': 0,
    'ZAYATZ': 0,
    'ZAYED': 0,
    'ZAYTSEV': 0,
    'ZAYYAD': 0,
    'ZAZA': 0,
    'ZAZO': 0,
    'ZAZUETA': 0,
    'ZAZULA': 0,
    'ZAZZARA': 0,
    'ZAZZARINO': 0,
    'ZAZZARO': 0,
    'ZAZZERA': 0,
    'ZAZZI': 0,
    'ZBACNIK': 0,
    'ZBIEGIEN': 0,
    'ZBIKOWSKI': 0,
    'ZBINDEN': 0,
    'ZBLEWSKI': 0,
    'ZBORAY': 0,
    'ZBORIL': 0,
    'ZBOROWSKI': 0,
    'ZBRANEK': 0,
    'ZBYLUT': 0,
    'ZDAN': 0,
    'ZDANIS': 0,
    'ZDANOWICZ': 0,
    'ZDANOWSKI': 0,
    'ZDEB': 0,
    'ZDENEK': 0,
    'ZDON': 0,
    'ZDRODOWSKI': 0,
    'ZDROIK': 0,
    'ZDROJEWSKI': 0,
    'ZDUN': 0,
    'ZDUNCZYK': 0,
    'ZDUNEK': 0,
    'ZDUNICH': 0,
    'ZDYB': 0,
    'ZDZIARSKI': 0,
    'ZEA': 0,
    'ZEAGER': 0,
    'ZEAGLER': 0,
    'ZEAK': 0,
    'ZEAL': 0,
    'ZEAMER': 0,
    'ZEANAH': 0,
    'ZEARFOSS': 0,
    'ZEARLEY': 0,
    'ZEAS': 0,
    'ZEB': 0,
    'ZEBALLOS': 0,
    'ZEBARI': 0,
    'ZEBELL': 0,
    'ZEBERT': 0,
    'ZEBLEY': 0,
    'ZEBRACKI': 0,
    'ZEBRO': 0,
    'ZEBROSKI': 0,
    'ZEBROWSKI': 0,
    'ZEC': 0,
    'ZECCA': 0,
    'ZECCHIN': 0,
    'ZECCHINI': 0,
    'ZECCHINO': 0,
    'ZECCOLA': 0,
    'ZECENA': 0,
    'ZECEVIC': 0,
    'ZECH': 0,
    'ZECHA': 0,
    'ZECHER': 0,
    'ZECHES': 0,
    'ZECHIEL': 0,
    'ZECHMAN': 0,
    'ZECHMANN': 0,
    'ZECHMEISTER': 0,
    'ZECK': 0,
    'ZECKSER': 0,
    'ZEDAKER': 0,
    'ZEDALIS': 0,
    'ZEDAN': 0,
    'ZEDEK': 0,
    'ZEDIKER': 0,
    'ZEDILLO': 0,
    'ZEDLER': 0,
    'ZEDNIK': 0,
    'ZEE': 0,
    'ZEEB': 0,
    'ZEECK': 0,
    'ZEEDYK': 0,
    'ZEEFF': 0,
    'ZEEK': 0,
    'ZEEMAN': 0,
    'ZEERIP': 0,
    'ZEERYP': 0,
    'ZEESE': 0,
    'ZEFERINO': 0,
    'ZEFF': 0,
    'ZEFFER': 0,
    'ZEFFIRO': 0,
    'ZEGA': 0,
    'ZEGAR': 0,
    'ZEGARELLI': 0,
    'ZEGARRA': 0,
    'ZEGARSKI': 0,
    'ZEGEL': 0,
    'ZEGER': 0,
    'ZEGERS': 0,
    'ZEGLEN': 0,
    'ZEGLER': 0,
    'ZEGLIN': 0,
    'ZEH': 0,
    'ZEHE': 0,
    'ZEHEL': 0,
    'ZEHENDER': 0,
    'ZEHER': 0,
    'ZEHLER': 0,
    'ZEHM': 0,
    'ZEHMS': 0,
    'ZEHNDER': 0,
    'ZEHNER': 0,
    'ZEHNLE': 0,
    'ZEHR': 0,
    'ZEHREN': 0,
    'ZEHRER': 0,
    'ZEHRING': 0,
    'ZEHRINGER': 0,
    'ZEHRUNG': 0,
    'ZEI': 0,
    'ZEIBER': 0,
    'ZEICHNER': 0,
    'ZEID': 0,
    'ZEIDAN': 0,
    'ZEIDER': 0,
    'ZEIDERS': 0,
    'ZEIDLER': 0,
    'ZEIDMAN': 0,
    'ZEIDNER': 0,
    'ZEIEN': 0,
    'ZEIER': 0,
    'ZEIG': 0,
    'ZEIGENBEIN': 0,
    'ZEIGER': 0,
    'ZEIGLER': 0,
    'ZEIHER': 0,
    'ZEIK': 0,
    'ZEILE': 0,
    'ZEILENGA': 0,
    'ZEILER': 0,
    'ZEILINGER': 0,
    'ZEILMAN': 0,
    'ZEILSTRA': 0,
    'ZEIMER': 0,
    'ZEIMET': 0,
    'ZEIMETZ': 0,
    'ZEIN': 0,
    'ZEINER': 0,
    'ZEINERT': 0,
    'ZEINSTRA': 0,
    'ZEIS': 0,
    'ZEISE': 0,
    'ZEISEL': 0,
    'ZEISER': 0,
    'ZEISET': 0,
    'ZEISLER': 0,
    'ZEISLOFT': 0,
    'ZEISS': 0,
    'ZEISSET': 0,
    'ZEIT': 0,
    'ZEITER': 0,
    'ZEITERS': 0,
    'ZEITLER': 0,
    'ZEITLIN': 0,
    'ZEITNER': 0,
    'ZEITOUN': 0,
    'ZEITS': 0,
    'ZEITZ': 0,
    'ZEKA': 0,
    'ZEKAS': 0,
    'ZEKO': 0,
    'ZELADA': 0,
    'ZELANKO': 0,
    'ZELANO': 0,
    'ZELASKO': 0,
    'ZELAYA': 0,
    'ZELAYANDIA': 0,
    'ZELAZNY': 0,
    'ZELAZO': 0,
    'ZELCER': 0,
    'ZELCH': 0,
    'ZELDA': 1,
    'ZELDES': 0,
    'ZELDIN': 0,
    'ZELE': 0,
    'ZELECHOWSKI': 0,
    'ZELEDON': 0,
    'ZELEK': 0,
    'ZELEKE': 0,
    'ZELEN': 0,
    'ZELENAK': 0,
    'ZELENKA': 0,
    'ZELENKO': 0,
    'ZELENSKI': 0,
    'ZELENSKY': 0,
    'ZELENY': 0,
    'ZELESKI': 0,
    'ZELEZNIK': 0,
    'ZELEZNIKAR': 0,
    'ZELHART': 0,
    'ZELIFF': 0,
    'ZELIK': 0,
    'ZELIN': 0,
    'ZELINA': 0,
    'ZELINGER': 0,
    'ZELINKA': 0,
    'ZELINSKE': 0,
    'ZELINSKI': 0,
    'ZELINSKY': 0,
    'ZELISKO': 0,
    'ZELKO': 0,
    'ZELKOWITZ': 0,
    'ZELL': 0,
    'ZELLA': 0.9819967266775776,
    'ZELLAR': 0,
    'ZELLARS': 0,
    'ZELLE': 0,
    'ZELLEFROW': 0,
    'ZELLER': 0,
    'ZELLERS': 0,
    'ZELLEY': 0,
    'ZELLI': 0,
    'ZELLINGER': 0,
    'ZELLMAN': 0,
    'ZELLMANN': 0,
    'ZELLMER': 0,
    'ZELLNER': 0,
    'ZELLO': 0,
    'ZELLOUS': 0,
    'ZELLWEGER': 0,
    'ZELM': 0,
    'ZELMA': 1,
    'ZELMAN': 0,
    'ZELMANSKI': 0,
    'ZELMER': 0,
    'ZELMS': 0,
    'ZELNER': 0,
    'ZELNICK': 0,
    'ZELNIK': 0,
    'ZELNO': 0,
    'ZELONIS': 0,
    'ZELT': 0,
    'ZELTMANN': 0,
    'ZELTNER': 0,
    'ZELTSER': 0,
    'ZELTWANGER': 0,
    'ZELTZER': 0,
    'ZELUFF': 0,
    'ZEMA': 0,
    'ZEMAITIS': 0,
    'ZEMAN': 0,
    'ZEMANEK': 0,
    'ZEMBA': 0,
    'ZEMBAL': 0,
    'ZEMBER': 0,
    'ZEMBOWER': 0,
    'ZEMBRODT': 0,
    'ZEMBRUSKI': 0,
    'ZEMBRZUSKI': 0,
    'ZEMCIK': 0,
    'ZEMEK': 0,
    'ZEMEL': 0,
    'ZEMER': 0,
    'ZEMKE': 0,
    'ZEMKO': 0,
    'ZEMLA': 0,
    'ZEMLICKA': 0,
    'ZEMLOCK': 0,
    'ZEMO': 0,
    'ZEMP': 0,
    'ZEMPEL': 0,
    'ZEMPOALTECA': 0,
    'ZEMSKY': 0,
    'ZEN': 0,
    'ZENA': 0.9740259740259739,
    'ZENAIDA': 1,
    'ZENDA': 0,
    'ZENDEJAS': 0,
    'ZENDER': 0,
    'ZENDT': 0,
    'ZENER': 0,
    'ZENG': 0,
    'ZENGA': 0,
    'ZENGEL': 0,
    'ZENGER': 0,
    'ZENGERLE': 0,
    'ZENGLER': 0,
    'ZENI': 0,
    'ZENIA': 1,
    'ZENIL': 0,
    'ZENISEK': 0,
    'ZENK': 0,
    'ZENKE': 0,
    'ZENKER': 0,
    'ZENKO': 0,
    'ZENN': 0,
    'ZENNER': 0,
    'ZENO': 0,
    'ZENOBI': 0,
    'ZENOBIA': 1,
    'ZENON': 0,
    'ZENONE': 0,
    'ZENONI': 0,
    'ZENOR': 0,
    'ZENS': 0,
    'ZENSEN': 0,
    'ZENT': 0,
    'ZENTENO': 0,
    'ZENTGRAF': 0,
    'ZENTHOEFER': 0,
    'ZENTMEYER': 0,
    'ZENTMYER': 0,
    'ZENTNER': 0,
    'ZENTS': 0,
    'ZENTZ': 0,
    'ZENZ': 0,
    'ZENZEN': 0,
    'ZEOLI': 0,
    'ZEOLLA': 0,
    'ZEPEDA': 0,
    'ZEPERNICK': 0,
    'ZEPF': 0,
    'ZEPHIER': 0,
    'ZEPHIR': 0,
    'ZEPHIRIN': 0,
    'ZEPHYR': 0,
    'ZEPKA': 0,
    'ZEPLIN': 0,
    'ZEPNICK': 0,
    'ZEPP': 0,
    'ZEPPA': 0,
    'ZEPPIERI': 0,
    'ZEPPONI': 0,
    'ZEQIRI': 0,
    'ZEQUEIRA': 0,
    'ZERA': 0,
    'ZERAFA': 0,
    'ZERANCE': 0,
    'ZERANGUE': 0,
    'ZERBA': 0,
    'ZERBE': 0,
    'ZERBEL': 0,
    'ZERBEY': 0,
    'ZERBINI': 0,
    'ZERBO': 0,
    'ZERBST': 0,
    'ZERBY': 0,
    'ZERCHER': 0,
    'ZERDA': 0,
    'ZEREGA': 0,
    'ZEREN': 0,
    'ZERFAS': 0,
    'ZERFASS': 0,
    'ZERFOSS': 0,
    'ZERGER': 0,
    'ZERHUSEN': 0,
    'ZERILLI': 0,
    'ZERILLO': 0,
    'ZERINGUE': 0,
    'ZERKA': 0,
    'ZERKEL': 0,
    'ZERKLE': 0,
    'ZERMAN': 0,
    'ZERMENO': 0,
    'ZERN': 0,
    'ZERNECHEL': 0,
    'ZERNER': 0,
    'ZERNICKE': 0,
    'ZERO': 0,
    'ZERON': 0,
    'ZEROTH': 0,
    'ZERPA': 0,
    'ZERPHEY': 0,
    'ZERR': 0,
    'ZERRENNER': 0,
    'ZERRUSEN': 0,
    'ZERTUCHE': 0,
    'ZERULL': 0,
    'ZERVAS': 0,
    'ZERVOS': 0,
    'ZERWAS': 0,
    'ZESATI': 0,
    'ZESCH': 0,
    'ZESIGER': 0,
    'ZESS': 0,
    'ZESSIN': 0,
    'ZETAH': 0,
    'ZETH': 0,
    'ZETINA': 0,
    'ZETINO': 0,
    'ZETO': 0,
    'ZETT': 0,
    'ZETTA': 1,
    'ZETTEL': 0,
    'ZETTER': 0,
    'ZETTERBERG': 0,
    'ZETTERGREN': 0,
    'ZETTERLUND': 0,
    'ZETTL': 0,
    'ZETTLE': 0,
    'ZETTLEMOYER': 0,
    'ZETTLER': 0,
    'ZETTS': 0,
    'ZETTY': 0,
    'ZEUG': 0,
    'ZEUGIN': 0,
    'ZEULI': 0,
    'ZEUNER': 0,
    'ZEUTENHORST': 0,
    'ZEUTZIUS': 0,
    'ZEVALLOS': 0,
    'ZEVENBERGEN': 0,
    'ZEVIN': 0,
    'ZEWDIE': 0,
    'ZEWE': 0,
    'ZEY': 0,
    'ZEYEN': 0,
    'ZEZIMA': 0,
    'ZEZULA': 0,
    'ZEZULKA': 0,
    'ZEZZA': 0,
    'ZGLINICKI': 0,
    'ZGODA': 0,
    'ZGONC': 0,
    'ZHAGUI': 0,
    'ZHAI': 0,
    'ZHAN': 0,
    'ZHANG': 0,
    'ZHAO': 0,
    'ZHE': 0,
    'ZHELEZNYAK': 0,
    'ZHEN': 0,
    'ZHENG': 0,
    'ZHI': 0,
    'ZHININ': 0,
    'ZHONG': 0,
    'ZHOU': 0,
    'ZHU': 0,
    'ZHUANG': 0,
    'ZHUK': 0,
    'ZHUKOV': 0,
    'ZHUO': 0,
    'ZHURAVEL': 0,
    'ZI': 0,
    'ZIA': 0,
    'ZIAD': 0,
    'ZIADEH': 0,
    'ZIAJA': 0,
    'ZIARKO': 0,
    'ZIARNIK': 0,
    'ZIAS': 0,
    'ZIATS': 0,
    'ZIBELL': 0,
    'ZIBERT': 0,
    'ZIBILICH': 0,
    'ZIC': 0,
    'ZICAFOOSE': 0,
    'ZICARELLI': 0,
    'ZICARI': 0,
    'ZICCARDI': 0,
    'ZICCARELLI': 0,
    'ZICH': 0,
    'ZICHERMAN': 0,
    'ZICHICHI': 0,
    'ZICK': 0,
    'ZICKAFOOSE': 0,
    'ZICKEFOOSE': 0,
    'ZICKEL': 0,
    'ZICKERT': 0,
    'ZICKGRAF': 0,
    'ZICKLER': 0,
    'ZICKMUND': 0,
    'ZICKUHR': 0,
    'ZICKUS': 0,
    'ZIDAN': 0,
    'ZIDAR': 0,
    'ZIDE': 0,
    'ZIDEK': 0,
    'ZIDEL': 0,
    'ZIDELL': 0,
    'ZIDLICKY': 0,
    'ZIEBA': 0,
    'ZIEBART': 0,
    'ZIEBARTH': 0,
    'ZIEBELL': 0,
    'ZIEBER': 0,
    'ZIEBERT': 0,
    'ZIEBOL': 0,
    'ZIEBOLD': 0,
    'ZIECH': 0,
    'ZIEG': 0,
    'ZIEGEL': 0,
    'ZIEGELBAUER': 0,
    'ZIEGELHOFER': 0,
    'ZIEGELMAN': 0,
    'ZIEGELMANN': 0,
    'ZIEGELMEIER': 0,
    'ZIEGELMEYER': 0,
    'ZIEGENBEIN': 0,
    'ZIEGENFUS': 0,
    'ZIEGENFUSS': 0,
    'ZIEGENHAGEN': 0,
    'ZIEGENHORN': 0,
    'ZIEGER': 0,
    'ZIEGERT': 0,
    'ZIEGLAR': 0,
    'ZIEGLER': 0,
    'ZIEGLMEIER': 0,
    'ZIEGMAN': 0,
    'ZIEHL': 0,
    'ZIEHM': 0,
    'ZIEHMER': 0,
    'ZIEHR': 0,
    'ZIEL': 0,
    'ZIELENSKI': 0,
    'ZIELER': 0,
    'ZIELESCH': 0,
    'ZIELINSKA': 0,
    'ZIELINSKI': 0,
    'ZIELINSKY': 0,
    'ZIELKE': 0,
    'ZIELONKA': 0,
    'ZIELSDORF': 0,
    'ZIELSKE': 0,
    'ZIELSKI': 0,
    'ZIEM': 0,
    'ZIEMAK': 0,
    'ZIEMAN': 0,
    'ZIEMANN': 0,
    'ZIEMBA': 0,
    'ZIEMBO': 0,
    'ZIEMER': 0,
    'ZIEMIANSKI': 0,
    'ZIEMINSKI': 0,
    'ZIEMKE': 0,
    'ZIEMKIEWICZ': 0,
    'ZIEMKOWSKI': 0,
    'ZIEMS': 0,
    'ZIEMSKI': 0,
    'ZIEN': 0,
    'ZIENKIEWICZ': 0,
    'ZIENTARA': 0,
    'ZIENTARSKI': 0,
    'ZIENTEK': 0,
    'ZIENTY': 0,
    'ZIER': 0,
    'ZIERDEN': 0,
    'ZIERDT': 0,
    'ZIERENBERG': 0,
    'ZIERER': 0,
    'ZIERHUT': 0,
    'ZIERING': 0,
    'ZIERK': 0,
    'ZIERKE': 0,
    'ZIERLER': 0,
    'ZIERMAN': 0,
    'ZIEROTH': 0,
    'ZIES': 0,
    'ZIESCHANG': 0,
    'ZIESE': 0,
    'ZIESEMER': 0,
    'ZIESER': 0,
    'ZIESKE': 0,
    'ZIESMAN': 0,
    'ZIESMER': 0,
    'ZIETLOW': 0,
    'ZIETZ': 0,
    'ZIFF': 0,
    'ZIFFER': 0,
    'ZIGA': 0,
    'ZIGAN': 0,
    'ZIGICH': 0,
    'ZIGLAR': 0,
    'ZIGLER': 0,
    'ZIGMAN': 0,
    'ZIGMOND': 0,
    'ZIGMONT': 0,
    'ZIGMUND': 0,
    'ZIGNEGO': 0,
    'ZIGO': 0,
    'ZIGRANG': 0,
    'ZIHLMAN': 0,
    'ZIKA': 0,
    'ZIKE': 0,
    'ZIKMUND': 0,
    'ZIKO': 0,
    'ZIKOS': 0,
    'ZILA': 0,
    'ZILBER': 0,
    'ZILBERBERG': 0,
    'ZILBERMAN': 0,
    'ZILCH': 0,
    'ZILE': 0,
    'ZILER': 0,
    'ZILIAK': 0,
    'ZILINSKAS': 0,
    'ZILINSKI': 0,
    'ZILINSKY': 0,
    'ZILISCH': 0,
    'ZILK': 0,
    'ZILKA': 0,
    'ZILKE': 0,
    'ZILKO': 0,
    'ZILL': 0,
    'ZILLA': 0,
    'ZILLER': 0,
    'ZILLES': 0,
    'ZILLGITT': 0,
    'ZILLI': 0,
    'ZILLICH': 0,
    'ZILLIG': 0,
    'ZILLIGEN': 0,
    'ZILLINGER': 0,
    'ZILLIOX': 0,
    'ZILLMAN': 0,
    'ZILLMANN': 0,
    'ZILLMER': 0,
    'ZILLNER': 0,
    'ZILLS': 0,
    'ZILLY': 0,
    'ZILM': 0,
    'ZILMER': 0,
    'ZILZ': 0,
    'ZIM': 0,
    'ZIMA': 0,
    'ZIMAN': 0,
    'ZIMBA': 0,
    'ZIMBALIST': 0,
    'ZIMBARDI': 0,
    'ZIMBARDO': 0,
    'ZIMBELMAN': 0,
    'ZIMBERG': 0,
    'ZIMBLER': 0,
    'ZIMBRICK': 0,
    'ZIMBRO': 0,
    'ZIMDAHL': 0,
    'ZIMDARS': 0,
    'ZIMERMAN': 0,
    'ZIMET': 0,
    'ZIMIGA': 0,
    'ZIMIN': 0,
    'ZIMINSKI': 0,
    'ZIMINSKY': 0,
    'ZIMLICH': 0,
    'ZIMM': 0,
    'ZIMMEL': 0,
    'ZIMMER': 0,
    'ZIMMERER': 0,
    'ZIMMERHANZEL': 0,
    'ZIMMERLE': 0,
    'ZIMMERLEE': 0,
    'ZIMMERLI': 0,
    'ZIMMERLY': 0,
    'ZIMMERMAN': 0,
    'ZIMMERMANN': 0,
    'ZIMMERS': 0,
    'ZIMMERSCHIED': 0,
    'ZIMMET': 0,
    'ZIMMITTI': 0,
    'ZIMNEY': 0,
    'ZIMNOCH': 0,
    'ZIMNY': 0,
    'ZIMPEL': 0,
    'ZIMPELMAN': 0,
    'ZIMPFER': 0,
    'ZIMPRICH': 0,
    'ZIMRING': 0,
    'ZIN': 0,
    'ZINA': 0.9771986970684039,
    'ZINCHUK': 0,
    'ZINCK': 0,
    'ZINCKE': 0,
    'ZINDA': 0,
    'ZINDANI': 0,
    'ZINDARS': 0,
    'ZINDEL': 0,
    'ZINDELL': 0,
    'ZINDER': 0,
    'ZINDLE': 0,
    'ZINDLER': 0,
    'ZINE': 0,
    'ZINER': 0,
    'ZING': 0,
    'ZINGALE': 0,
    'ZINGALES': 0,
    'ZINGARELLI': 0,
    'ZINGARO': 0,
    'ZINGER': 0,
    'ZINGERMAN': 0,
    'ZINGG': 0,
    'ZINGLER': 0,
    'ZINGO': 0,
    'ZINGONE': 0,
    'ZINGSHEIM': 0,
    'ZINI': 0,
    'ZINICOLA': 0,
    'ZINK': 0,
    'ZINKAN': 0,
    'ZINKAND': 0,
    'ZINKE': 0,
    'ZINKEL': 0,
    'ZINKGRAF': 0,
    'ZINKHAN': 0,
    'ZINKIEWICZ': 0,
    'ZINMAN': 0,
    'ZINN': 0,
    'ZINNA': 0,
    'ZINNANTI': 0,
    'ZINNECKER': 0,
    'ZINNEL': 0,
    'ZINNER': 0,
    'ZINNERMAN': 0,
    'ZINNI': 0,
    'ZINNIEL': 0,
    'ZINNINGER': 0,
    'ZINNO': 0,
    'ZINO': 0,
    'ZINS': 0,
    'ZINSER': 0,
    'ZINSKI': 0,
    'ZINSKY': 0,
    'ZINSLI': 0,
    'ZINSMASTER': 0,
    'ZINSMEISTER': 0,
    'ZINSMEYER': 0,
    'ZINSSER': 0,
    'ZINT': 0,
    'ZINTAK': 0,
    'ZINTEL': 0,
    'ZINTER': 0,
    'ZINTZ': 0,
    'ZINZ': 0,
    'ZINZER': 0,
    'ZINZI': 0,
    'ZIOBRO': 0,
    'ZIOBRON': 0,
    'ZIOBROWSKI': 0,
    'ZIOGAS': 0,
    'ZIOLA': 0,
    'ZIOLKO': 0,
    'ZIOLKOWSKI': 0,
    'ZIOLO': 0,
    'ZIOMEK': 0,
    'ZION': 0,
    'ZIONS': 0,
    'ZIPAY': 0,
    'ZIPF': 0,
    'ZIPFEL': 0,
    'ZIPKIN': 0,
    'ZIPP': 0,
    'ZIPPAY': 0,
    'ZIPPEL': 0,
    'ZIPPER': 0,
    'ZIPPERER': 0,
    'ZIPPERIAN': 0,
    'ZIPPI': 0,
    'ZIPPILLI': 0,
    'ZIPPO': 0,
    'ZIPPRICH': 0,
    'ZIPSE': 0,
    'ZIPSER': 0,
    'ZIRBEL': 0,
    'ZIRBES': 0,
    'ZIRGER': 0,
    'ZIRILLI': 0,
    'ZIRK': 0,
    'ZIRKEL': 0,
    'ZIRKELBACH': 0,
    'ZIRKER': 0,
    'ZIRKLE': 0,
    'ZIRLOTT': 0,
    'ZIRNGIBL': 0,
    'ZIRNHELD': 0,
    'ZIRPEL': 0,
    'ZIRPOLI': 0,
    'ZIRPOLO': 0,
    'ZIRZOW': 0,
    'ZISA': 0,
    'ZISCHKE': 0,
    'ZISER': 0,
    'ZISK': 0,
    'ZISKA': 0,
    'ZISKIN': 0,
    'ZISKIND': 0,
    'ZISKO': 0,
    'ZISMAN': 0,
    'ZISS': 0,
    'ZISSER': 0,
    'ZISSLER': 0,
    'ZITA': 0.9523809523809523,
    'ZITEK': 0,
    'ZITELLI': 0,
    'ZITELLO': 0,
    'ZITER': 0,
    'ZITKA': 0,
    'ZITKO': 0,
    'ZITKUS': 0,
    'ZITNEY': 0,
    'ZITNIK': 0,
    'ZITO': 0,
    'ZITOMER': 0,
    'ZITT': 0,
    'ZITTA': 0,
    'ZITTEL': 0,
    'ZITTER': 0,
    'ZITTERICH': 0,
    'ZITTERKOPF': 0,
    'ZITTING': 0,
    'ZITTLE': 0,
    'ZITTLOW': 0,
    'ZITZ': 0,
    'ZITZELBERGER': 0,
    'ZITZELSBERGER': 0,
    'ZITZER': 0,
    'ZITZKA': 0,
    'ZITZMAN': 0,
    'ZITZMANN': 0,
    'ZITZNER': 0,
    'ZITZOW': 0,
    'ZIV': 0,
    'ZIVANOVIC': 0,
    'ZIVIC': 0,
    'ZIVKOVIC': 0,
    'ZIVKOVICH': 0,
    'ZIVNEY': 0,
    'ZIYAD': 0,
    'ZIZAK': 0,
    'ZIZELMAN': 0,
    'ZIZUMBO': 0,
    'ZIZZA': 0,
    'ZIZZI': 0,
    'ZIZZO': 0,
    'ZLATKIN': 0,
    'ZLOCK': 0,
    'ZLOMKE': 0,
    'ZLOTKOWSKI': 0,
    'ZLOTNICK': 0,
    'ZLOTNIK': 0,
    'ZMICH': 0,
    'ZMIJEWSKI': 0,
    'ZMOLEK': 0,
    'ZMOLIK': 0,
    'ZMUDA': 0,
    'ZMUDKA': 0,
    'ZMUDZINSKI': 0,
    'ZNIDARSIC': 0,
    'ZOBECK': 0,
    'ZOBEL': 0,
    'ZOBELL': 0,
    'ZOBRIST': 0,
    'ZOCCALI': 0,
    'ZOCCHI': 0,
    'ZOCCO': 0,
    'ZOCCOLA': 0,
    'ZOCCOLI': 0,
    'ZOCH': 0,
    'ZOCHER': 0,
    'ZOCHOWSKI': 0,
    'ZOCK': 0,
    'ZODA': 0,
    'ZODDA': 0,
    'ZODROW': 0,
    'ZODY': 0,
    'ZOE': 1,
    'ZOECKLER': 0,
    'ZOELLE': 0,
    'ZOELLER': 0,
    'ZOELLICK': 0,
    'ZOELLNER': 0,
    'ZOERB': 0,
    'ZOERNER': 0,
    'ZOESCH': 0,
    'ZOET': 0,
    'ZOETEWEY': 0,
    'ZOFCHAK': 0,
    'ZOFCIN': 0,
    'ZOFIA': 1,
    'ZOGBY': 0,
    'ZOGG': 0,
    'ZOGHBY': 0,
    'ZOGLIO': 0,
    'ZOGLMAN': 0,
    'ZOGLMANN': 0,
    'ZOGRAFOS': 0,
    'ZOHAR': 0,
    'ZOHN': 0,
    'ZOHNER': 0,
    'ZOILA': 1,
    'ZOIS': 0,
    'ZOLA': 0.9216589861751152,
    'ZOLADZ': 0,
    'ZOLAN': 0,
    'ZOLD': 0,
    'ZOLDAK': 0,
    'ZOLDAN': 0,
    'ZOLDOS': 0,
    'ZOLECKI': 0,
    'ZOLETA': 0,
    'ZOLEZZI': 0,
    'ZOLFAGHARI': 0,
    'ZOLIN': 0,
    'ZOLINSKI': 0,
    'ZOLKOWSKI': 0,
    'ZOLL': 0,
    'ZOLLA': 0,
    'ZOLLAR': 0,
    'ZOLLARS': 0,
    'ZOLLER': 0,
    'ZOLLERS': 0,
    'ZOLLI': 0,
    'ZOLLICOFFER': 0,
    'ZOLLINGER': 0,
    'ZOLLMAN': 0,
    'ZOLLNER': 0,
    'ZOLLO': 0,
    'ZOLLWEG': 0,
    'ZOLMAN': 0,
    'ZOLNA': 0,
    'ZOLNER': 0,
    'ZOLNOWSKI': 0,
    'ZOLOT': 0,
    'ZOLPER': 0,
    'ZOLTAK': 0,
    'ZOLTAN': 0,
    'ZOLTEK': 0,
    'ZOLTON': 0,
    'ZOLTOWSKI': 0,
    'ZOMA': 0,
    'ZOMBECK': 0,
    'ZOMBEK': 0,
    'ZOMBO': 0,
    'ZOMBRO': 0,
    'ZOMER': 0,
    'ZOMETA': 0,
    'ZOMPA': 0,
    'ZON': 0,
    'ZONA': 0.8571428571428571,
    'ZONCA': 0,
    'ZONDERVAN': 0,
    'ZONDLO': 0,
    'ZONE': 0,
    'ZONG': 0,
    'ZONGKER': 0,
    'ZONIA': 1,
    'ZONIS': 0,
    'ZONKER': 0,
    'ZONTINI': 0,
    'ZOOK': 0,
    'ZOPF': 0,
    'ZOPFI': 0,
    'ZOPP': 0,
    'ZOPPA': 0,
    'ZOPPI': 0,
    'ZOPPO': 0,
    'ZORA': 0.9615384615384616,
    'ZORAIDA': 1,
    'ZORAN': 0,
    'ZORBAS': 0,
    'ZORBAUGH': 0,
    'ZORC': 0,
    'ZORDAN': 0,
    'ZORDEL': 0,
    'ZORE': 0,
    'ZORETIC': 0,
    'ZORETICH': 0,
    'ZORGER': 0,
    'ZORIC': 0,
    'ZORICH': 0,
    'ZORILLA': 0,
    'ZORIO': 0,
    'ZORKO': 0,
    'ZORMAN': 0,
    'ZORN': 0,
    'ZORNES': 0,
    'ZORNOW': 0,
    'ZORNS': 0,
    'ZOROLA': 0,
    'ZOROMSKI': 0,
    'ZOROVICH': 0,
    'ZORRILLA': 0,
    'ZORTMAN': 0,
    'ZORZA': 0,
    'ZORZI': 0,
    'ZOSA': 0,
    'ZOSCHKE': 0,
    'ZOSEL': 0,
    'ZOSKE': 0,
    'ZOSS': 0,
    'ZOTO': 0,
    'ZOTOS': 0,
    'ZOTT': 0,
    'ZOTTA': 0,
    'ZOTTER': 0,
    'ZOTTI': 0,
    'ZOTTO': 0,
    'ZOTTOLA': 0,
    'ZOTTOLI': 0,
    'ZOTZ': 0,
    'ZOU': 0,
    'ZOUBEK': 0,
    'ZOUCHA': 0,
    'ZOULEK': 0,
    'ZOVKO': 0,
    'ZOZ': 0,
    'ZOZAYA': 0,
    'ZOZULA': 0,
    'ZOZZARO': 0,
    'ZREBIEC': 0,
    'ZREIK': 0,
    'ZRELAK': 0,
    'ZRUBEK': 0,
    'ZRUST': 0,
    'ZSCHOCHE': 0,
    'ZSCHOKKE': 0,
    'ZSIDO': 0,
    'ZSIGA': 0,
    'ZSOLDOS': 0,
    'ZU': 0,
    'ZUANICH': 0,
    'ZUAZO': 0,
    'ZUAZUA': 0,
    'ZUB': 0,
    'ZUBA': 0,
    'ZUBACK': 0,
    'ZUBAIR': 0,
    'ZUBAK': 0,
    'ZUBAL': 0,
    'ZUBE': 0,
    'ZUBECK': 0,
    'ZUBEK': 0,
    'ZUBEL': 0,
    'ZUBER': 0,
    'ZUBERBIER': 0,
    'ZUBERI': 0,
    'ZUBI': 0,
    'ZUBIA': 0,
    'ZUBIATE': 0,
    'ZUBIETA': 0,
    'ZUBIK': 0,
    'ZUBILLAGA': 0,
    'ZUBIRI': 0,
    'ZUBIZARRETA': 0,
    'ZUBKE': 0,
    'ZUBKO': 0,
    'ZUBLER': 0,
    'ZUBROD': 0,
    'ZUBROWSKI': 0,
    'ZUBRZYCKI': 0,
    'ZUCAL': 0,
    'ZUCARO': 0,
    'ZUCCA': 0,
    'ZUCCALA': 0,
    'ZUCCARELLI': 0,
    'ZUCCARELLO': 0,
    'ZUCCARINI': 0,
    'ZUCCARO': 0,
    'ZUCCATO': 0,
    'ZUCCHERO': 0,
    'ZUCCHI': 0,
    'ZUCCO': 0,
    'ZUCCONI': 0,
    'ZUCH': 0,
    'ZUCHELLI': 0,
    'ZUCHOWSKI': 0,
    'ZUCK': 0,
    'ZUCKER': 0,
    'ZUCKERBERG': 0,
    'ZUCKERMAN': 0,
    'ZUCZEK': 0,
    'ZUECH': 0,
    'ZUEGE': 0,
    'ZUEGER': 0,
    'ZUEHL': 0,
    'ZUEHLKE': 0,
    'ZUEHLSDORF': 0,
    'ZUEHLSDORFF': 0,
    'ZUELCH': 0,
    'ZUELKE': 0,
    'ZUELSDORF': 0,
    'ZUERCHER': 0,
    'ZUERLEIN': 0,
    'ZUERN': 0,
    'ZUFALL': 0,
    'ZUFELT': 0,
    'ZUFFANTE': 0,
    'ZUG': 0,
    'ZUGAY': 0,
    'ZUGEL': 0,
    'ZUGELDER': 0,
    'ZUGER': 0,
    'ZUGG': 0,
    'ZUHL': 0,
    'ZUHLKE': 0,
    'ZUHLSDORF': 0,
    'ZUIDEMA': 0,
    'ZUIDERVEEN': 0,
    'ZUIKER': 0,
    'ZUK': 0,
    'ZUKAITIS': 0,
    'ZUKAS': 0,
    'ZUKAUSKAS': 0,
    'ZUKE': 0,
    'ZUKER': 0,
    'ZUKERAN': 0,
    'ZUKERMAN': 0,
    'ZUKIC': 0,
    'ZUKIN': 0,
    'ZUKOR': 0,
    'ZUKOSKI': 0,
    'ZUKOSKY': 0,
    'ZUKOWSKI': 0,
    'ZUKOWSKY': 0,
    'ZUL': 0,
    'ZULA': 0.986842105263158,
    'ZULAICA': 0,
    'ZULAUF': 0,
    'ZULAWSKI': 0,
    'ZULCH': 0,
    'ZULE': 0,
    'ZULEGER': 0,
    'ZULEMA': 1,
    'ZULETA': 0,
    'ZULEWSKI': 0,
    'ZULIANI': 0,
    'ZULIC': 0,
    'ZULICK': 0,
    'ZULKA': 0,
    'ZULKOSKI': 0,
    'ZULKOWSKI': 0,
    'ZULL': 0,
    'ZULLA': 0,
    'ZULLI': 0,
    'ZULLINGER': 0,
    'ZULLO': 0,
    'ZULMA': 1,
    'ZULOAGA': 0,
    'ZULPO': 0,
    'ZULU': 0,
    'ZULUAGA': 0,
    'ZULUETA': 0,
    'ZUMACH': 0,
    'ZUMALT': 0,
    'ZUMARAN': 0,
    'ZUMAYA': 0,
    'ZUMBA': 0,
    'ZUMBACH': 0,
    'ZUMBADO': 0,
    'ZUMBAHLEN': 0,
    'ZUMBERGE': 0,
    'ZUMBO': 0,
    'ZUMBRO': 0,
    'ZUMBRUM': 0,
    'ZUMBRUN': 0,
    'ZUMBRUNN': 0,
    'ZUMBRUNNEN': 0,
    'ZUMMALLEN': 0,
    'ZUMMO': 0,
    'ZUMO': 0,
    'ZUMPANO': 0,
    'ZUMSTEG': 0,
    'ZUMSTEIN': 0,
    'ZUMWALDE': 0,
    'ZUMWALT': 0,
    'ZUNA': 0,
    'ZUNDEL': 0,
    'ZUNG': 0,
    'ZUNI': 0,
    'ZUNIC': 0,
    'ZUNICA': 0,
    'ZUNICH': 0,
    'ZUNIE': 0,
    'ZUNIGA': 0,
    'ZUNINO': 0,
    'ZUNK': 0,
    'ZUNKER': 0,
    'ZUNNO': 0,
    'ZUNO': 0,
    'ZUO': 0,
    'ZUPA': 0,
    'ZUPAN': 0,
    'ZUPANCIC': 0,
    'ZUPANCICH': 0,
    'ZUPFER': 0,
    'ZUPKE': 0,
    'ZUPKO': 0,
    'ZUPNICK': 0,
    'ZUPNIK': 0,
    'ZUPO': 0,
    'ZUPON': 0,
    'ZUPP': 0,
    'ZUPPA': 0,
    'ZUPPARDO': 0,
    'ZUPPE': 0,
    'ZUPPO': 0,
    'ZUR': 0,
    'ZURA': 0,
    'ZURAFF': 0,
    'ZURAKOWSKI': 0,
    'ZURASKI': 0,
    'ZURAW': 0,
    'ZURAWSKI': 0,
    'ZURBRICK': 0,
    'ZURBRIGGEN': 0,
    'ZURBRUGG': 0,
    'ZURBUCHEN': 0,
    'ZURCHER': 0,
    'ZUREK': 0,
    'ZURENDA': 0,
    'ZURFACE': 0,
    'ZURFLUH': 0,
    'ZURHEIDE': 0,
    'ZURICH': 0,
    'ZURICK': 0,
    'ZURITA': 0,
    'ZURKO': 0,
    'ZURLA': 0,
    'ZURLIENE': 0,
    'ZURLINDEN': 0,
    'ZURLO': 0,
    'ZURN': 0,
    'ZURO': 0,
    'ZUROFF': 0,
    'ZUROMSKI': 0,
    'ZUROSKI': 0,
    'ZUROVEC': 0,
    'ZUROWSKI': 0,
    'ZURZOLO': 0,
    'ZUSCHLAG': 0,
    'ZUSI': 0,
    'ZUSMAN': 0,
    'ZUSPAN': 0,
    'ZUSPANN': 0,
    'ZUSSMAN': 0,
    'ZUST': 0,
    'ZUTAVERN': 0,
    'ZUTELL': 0,
    'ZUTTER': 0,
    'ZUTZ': 0,
    'ZUVER': 0,
    'ZUVERINK': 0,
    'ZUVICH': 0,
    'ZUZA': 0,
    'ZUZAK': 0,
    'ZUZEK': 0,
    'ZUZGA': 0,
    'ZUZIAK': 0,
    'ZUZOLO': 0,
    'ZVARA': 0,
    'ZVOLANEK': 0,
    'ZVOLENSKY': 0,
    'ZVONAR': 0,
    'ZVONEK': 0,
    'ZWAAN': 0,
    'ZWACK': 0,
    'ZWAGERMAN': 0,
    'ZWAHLEN': 0,
    'ZWAHR': 0,
    'ZWAK': 0,
    'ZWALD': 0,
    'ZWALLY': 0,
    'ZWANG': 0,
    'ZWANZIGER': 0,
    'ZWART': 0,
    'ZWASCHKA': 0,
    'ZWAYER': 0,
    'ZWEBEN': 0,
    'ZWEBER': 0,
    'ZWECK': 0,
    'ZWEIBOHMER': 0,
    'ZWEIFEL': 0,
    'ZWEIG': 0,
    'ZWEIGART': 0,
    'ZWEIGLE': 0,
    'ZWEIZIG': 0,
    'ZWEMKE': 0,
    'ZWENG': 0,
    'ZWERIN': 0,
    'ZWERLING': 0,
    'ZWERNEMANN': 0,
    'ZWERNER': 0,
    'ZWETTLER': 0,
    'ZWETZIG': 0,
    'ZWEYGARDT': 0,
    'ZWICK': 0,
    'ZWICKE': 0,
    'ZWICKEL': 0,
    'ZWICKER': 0,
    'ZWICKEY': 0,
    'ZWICKL': 0,
    'ZWICKY': 0,
    'ZWIEBEL': 0,
    'ZWIEFEL': 0,
    'ZWIEFELHOFER': 0,
    'ZWIEG': 0,
    'ZWIENER': 0,
    'ZWIER': 0,
    'ZWIERS': 0,
    'ZWIERZYNSKI': 0,
    'ZWIESLER': 0,
    'ZWILLING': 0,
    'ZWINGER': 0,
    'ZWINK': 0,
    'ZWIRN': 0,
    'ZWIRNER': 0,
    'ZWISLER': 0,
    'ZWISSLER': 0,
    'ZWOLAK': 0,
    'ZWOLINSKI': 0,
    'ZWOLSKI': 0,
    'ZYBURA': 0,
    'ZYCH': 0,
    'ZYCHOWICZ': 0,
    'ZYCHOWSKI': 0,
    'ZYCK': 0,
    'ZYDEK': 0,
    'ZYDEL': 0,
    'ZYGADLO': 0,
    'ZYGMONT': 0,
    'ZYGMUNT': 0,
    'ZYKAN': 0,
    'ZYLA': 0,
    'ZYLBERBERG': 0,
    'ZYLINSKI': 0,
    'ZYLKA': 0,
    'ZYLLA': 0,
    'ZYLMAN': 0,
    'ZYLSTRA': 0,
    'ZYNDA': 0,
    'ZYRA': 0,
    'ZYSK': 0,
    'ZYSKOWSKI': 0,
    'ZYSMAN': 0,
    'ZYWICKI': 0,
    'ZYWIEC': 0}
